(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  17103673,     397810]*)
(*NotebookOutlinePosition[  17190619,     400535]*)
(*  CellTagsIndexPosition[  17179016,     400176]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Nonlinear Partial Differential Equations", "Title",
  CellTags->"c:1"],

Cell["", "Text"],

Cell["\<\
\tLinear partial  differential equations depend on only the first \
power of the unknown function. On the other hand, many natural phenomena \
require nonlinear partial differential equations for their description. These \
equations can depend on the unknown function in an arbitrary fashion, and \
consequently the principle of superposition no longer applies: the sum of two \
solutions to the homogenous PDE is no longer itself  a solution.  Therefore, \
the eigenmode and Fourier expansion methods developed previously for linear \
PDEs will not work on nonlinear PDEs. \
\>", "Text"],

Cell[TextData[{
  "\tGenerally, nonlinear PDEs require numerical methods for their solution. \
The Galerkin method and the grid methods discussed in Chapter ",
  ButtonBox["6",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  " can still be applied, and we will see examples in this chapter. We will \
also examine an advanced simulation method, the particle-in-cell method, for \
the numerical solution of some classes of nonlinear PDEs."
}], "Text"],

Cell["\<\
\tFirst, however, we will discuss an analytic method that can be \
applied to solve first-order nonlinear PDEs: the method of characteristics. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["7.1 The Method of Characteristics for First-Order PDEs", "Subtitle",
  CellTags->{"i:1", "c:3"}],

Cell[" ", "Text"],

Cell[CellGroupData[{

Cell["7.1.1 Characteristics", "Subsubtitle",
  CellTags->{"i:15", "c:4"}],

Cell[TextData[{
  "Consider the following PDE for a function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(x, t)\)\(:\)\)\)]]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \(v(x, t, 
              f)\) \[PartialD]f\/\[PartialD]x = s(x, t, f)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.1)"],

Cell["\<\
This equation is first-order in time, and so requires a single \
initial condition:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = \ \(f\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.2)"],

Cell[TextData[{
  "The equation is also first-order in space, and so in principle a single \
boundary condition could be imposed. However, this can lead to difficulties \
that are tangential to the discussion at hand.  In what follows, for \
simplicity we will solve the PDE on the entire real line without imposing \
boundary conditions, as we did in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFirst-order PDEs of this sort arise in a number of different physical \
contexts. For example, the energy and wave action equations ",
  ButtonBox["(5.2.59)",
    ButtonData:>{"Chapter5.nb", "(5.2.59)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(5.3.23)",
    ButtonData:>{"Chapter5.nb", "(5.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  describing wave-packet dynamics are of this general form.  We will also \
see that this equation and its generalizations describe dye in a fluid flow, \
nonlinear waves, ideal gases in an external force field, plasmas, and \
self-gravitating matter such as stars and galaxies. "
}], "Text"],

Cell[TextData[{
  "\tWe will solve Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  using the method of characteristics, which is specially suited for PDEs \
of this form, and which works whether or not the PDE is linear in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". In this method, by means of a coordinate transformation ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \ \(x\_o\)(x, t)\)]],
  " that takes us to a moving frame,  we convert the PDE into an ODE. The \
moving frame that we choose is one that moves with velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v(x, t, f)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t This is not a standard Galilean transformation, where the entire frame \
moves with the same velocity. Rather, the velocity varies from place to place \
and from time to time.  Because of this, it is best to think of the \
transformation in terms of an infinite number of moving observers, spread \
along the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(-\)\)\)]],
  "axis. Each observer moves along a trajectory ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, \ x\_o)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " is  the initial location of the observer:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x = x\_o\)\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(7.1.3)"],

Cell[TextData[{
  "The trajectory ",
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_o)\)]],
  " of some given observer is called a ",
  StyleBox["characteristic.",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:2"],

Cell[TextData[{
  "\tEach observer is responsible for recording the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at his or her own (moving) position.  Along this trajectory, ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x(t, x\_o), t)\)]],
  ". Taking a differential and applying the chain rule, we find that each \
observer sees a differential change in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\  = \(\[PartialD]f\/\[PartialD]t\) \
\[DifferentialD]t + \(\[PartialD]f\/\[PartialD]x\) \(\[DifferentialD]x\/\
\[DifferentialD]t\) \[DifferentialD]t\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "If we now divide by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  " and substitute for ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]t\)]],
  " from Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  " , we obtain the following equation for the ",
  StyleBox["total time derivative ",
    FontSlant->"Italic"],
  "of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " along the characteristic trajectory, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\)]],
  ":"
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \
\(\[PartialD]f\/\[PartialD]x\) \[DifferentialD]x\/\[DifferentialD]t + 
          s\  - \ \(\(v\)\(\ \)\(\[PartialD]f\/\[PartialD]x\)\(\ \)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.4)"],

Cell[TextData[{
  "This equation simplifies if we take  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ v\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \(\(s(x, t, 
          f)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.5)"],

Cell[TextData[{
  "With this choice the original PDE, Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  " , is converted into an ODE involving the total rate of change of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as seen by an observer moving along the characteristic.  The \
characteristic itself is defined by the ODE"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = 
        v(x, t, f)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.6)"],

Cell[TextData[{
  "with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". The solution to this ODE is our transformation ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, x\_o)\)]],
  ", and we use this solution in solving Eq. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tBefore we go on to solve Eq. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  " , it is instructive to compare it with Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  " . We can then  immediately make the following identification:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \
\[PartialD]f\/\[PartialD]t + v \[PartialD]f\/\[PartialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.7)"],

Cell[TextData[{
  "The total rate of change of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as seen by the moving observer consists of two terms. The origin of the \
first term, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]t\)]],
  ", is obvious. This term would occur even if the observer were stationary.  \
The second term,  ",
  Cell[BoxData[
      \(TraditionalForm\`v\ \[PartialD]f/\[PartialD]x\)]],
  ", would occur even if ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " were not a function of time. This term arises because  the observer sees \
a change in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " due to his or her own motion at velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThere is another useful way to write the total derivative ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(x(t, x\_o)\)\(\ \)\)\)]],
  " defines a transformation from coordinate ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ", we could write ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". If we now consider a general variation of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_o, t)\)]],
  ", as ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " are varied by infinitesimal amounts, we obtain the differential relation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f = \[PartialD]f\/\[PartialD]t\( | \
\_\(x\_o\)\)\[DifferentialD]t + \[PartialD]f\/\[PartialD]x\_o\( | \_t\)\ \
\[DifferentialD]x\_o\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(7.1.8)"],

Cell[TextData[{
  "However, a given characteristic is defined by a single initial condition \
",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  "that does not vary, so ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\_o = 0\)]],
  " along the characteristic. Dividing through by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  ", we then obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \
\(\(\[PartialD]f\/\[PartialD]t\)\( | \_\(x\_o\)\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.9)"],

Cell[TextData[{
  "Since the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " is a fixed parameter of the characteristic, it should hardly  be \
surprising that the total time derivative along a characteristic is the same \
as a partial derivative, holding ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " fixed.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.1.2 Linear Cases", "Subsubtitle",
  CellTags->"c:5"],

Cell[TextData[{
  "\tWe now turn to the solution of Eqs. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  " . These are coupled first-order ODEs. It is easiest to understand the \
solution  to these ODEs by first considering a linear case, where ",
  Cell[BoxData[
      \(TraditionalForm\`s = s(x, t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = v(x, t)\)]],
  ". Then Eqs. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  "  become"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[DifferentialD]f/\[DifferentialD]t = 
      s(x, t)\)\(,\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.10)"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ \(\(v(x, 
          t)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.11)"],

Cell[TextData[{
  "\tWe first solve Eq. ",
  ButtonBox["(7.1.11)",
    ButtonData:>{"Chapter7.nb", "(7.1.11)"},
    ButtonStyle->"Hyperlink"],
  "  for the characteristics.  This is a first",
  "-order",
  " ODE with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". We  write the solution as ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, x\_o)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNext, we use these characteristics in solving Eq. ",
  ButtonBox["(7.1.10)",
    ButtonData:>{"Chapter7.nb", "(7.1.10)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  ". Here, it must be remembered that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\)]],
  " is the ",
  StyleBox["total",
    FontSlant->"Italic"],
  " rate of change, as seen by the moving observer. Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " varies in time as ",
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_o)\)]],
  " along the characteristic, and ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " varies in time as  ",
  Cell[BoxData[
      \(TraditionalForm\`s(x(t, x\_o), t)\)]],
  ". The solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = s\)]],
  "  is therefore"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        f(0)\  + \ \[Integral]\_0\%t\( s(x(t\^\[Prime], x\_o), 
                t\^\[Prime])\) \[DifferentialD]t\^\[Prime]\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(7.1.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(0) = \(f\_o\)(x\_o)\)]],
  " is the initial value for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at position ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ", and where ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \(\(f(x, t)\)\( | \_\(x = x(t, x\_o)\)\)\)\)]],
  " is the value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " on the characteristic at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe ",
  "right-hand",
  " side is written in terms of  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", so we must invert ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, x\_o)\)]],
  " to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(x\_o\)(x, t)\)]],
  ". Using this equation in Eq. ",
  ButtonBox["(7.1.12)",
    ButtonData:>{"Chapter7.nb", "(7.1.12)"},
    ButtonStyle->"Hyperlink"],
  "  yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 
          t) = \(\(\(f\_o\)(\(x\_o\)(x, 
                t))\  + \ \[Integral]\_0\%t\( s(x(t\^\[Prime], x\_o), 
                  t\^\[Prime])\) \[DifferentialD]t\^\[Prime]\)\( | \_\(x\_o = \
\(x\_o\)(x, t)\)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.13)"],

Cell[TextData[{
  "This is our solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", written explicitly as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".  In order to clarify the meaning of this result, we consider several \
examples below. Other examples can be found in the exercises."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Example 1:  ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v(x, t, f) = c\)]]
}], "Section",
  CellTags->"c:6"],

Cell[TextData[{
  "Now Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \ 
          c\ \[PartialD]f\/\[PartialD]x = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.14)"],

Cell[TextData[{
  "We will see that the solutions to this equation are like those to the wave \
equation, except that propagation is now only in one direction. The solution \
is obtained using Eqs. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  " : "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 
      0, \[IndentingNewLine]\[DifferentialD]x/\[DifferentialD]t\  = \ \(\(c\)\
\(.\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "The solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ c\)]],
  " with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\  + \ c\ t\)]],
  ".  These straight parallel lines are the characteristics for the PDE for \
this example, and are shown for three initial positions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " in Fig. ",
  ButtonBox["7.1",
    ButtonData:>"Fig. 7.1",
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`f = constant\)]],
  " along these characteristics; that is,  along each characteristic the \
value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " remains unchanged from its initial value. For the characteristic starting \
at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  ", this value is ",
  Cell[BoxData[
      \(TraditionalForm\`f = \(f\_o\)(x\_o)\)]],
  ", according to Eq. ",
  ButtonBox["(7.1.2)",
    ButtonData:>{"Chapter7.nb", "(7.1.2)"},
    ButtonStyle->"Hyperlink"],
  " . Therefore, the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ \(f\_o\)(x\_o)\)], "NumberedEquation"], 
    "NumberedEquation"],
  StyleBox[",", "NumberedEquation"]
}], "NumberedEquation",
  CellTags->"(7.1.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \(\(f(x, t)\)\( | \_\(x = x\_o + \ c\ t\)\)\)\)]],
  " is the value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", evaluated along the characteristic."
}], "Text"],

Cell[TextData[{
  "\tThis equation could equally well have been obtained by using Eq.  ",
  ButtonBox["(7.1.9)",
    ButtonData:>{"Chapter7.nb", "(7.1.9)"},
    ButtonStyle->"Hyperlink"],
  " , which when combined with ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " yields\n \t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]f/\[PartialD]t\)\( | \_\(x\_o\)\)\) = 
        0\)]],
  ". \n The solution to this equation is clearly any function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_o)\)]],
  ", since any such function can be differentiated with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " (holding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_o\)\(\ \)\)\)]],
  "fixed) to yield zero.  To satisfy the initial condition, Eq. ",
  ButtonBox["(7.1.2)",
    ButtonData:>{"Chapter7.nb", "(7.1.2)"},
    ButtonStyle->"Hyperlink"],
  " , we require that ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_o) = \(f\_o\)(x\_o)\)]],
  " (because ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  "at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  "), and so we return to Eq. ",
  ButtonBox["(7.1.15)",
    ButtonData:>{"Chapter7.nb", "(7.1.15)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  "\t  To finish the solution, we now invert the characteristic equation ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o + \ c\ t\)]],
  " to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = x\  - \ c\ t\)]],
  ". Substituting into Eq. ",
  ButtonBox["(7.1.14)",
    ButtonData:>{"Chapter7.nb", "(7.1.14)"},
    ButtonStyle->"Hyperlink"],
  "  yields"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f(x, t)\  = \ \(f\_o\)(x - c\ t)\)], 
    "NumberedEquation"], "NumberedEquation"],
  StyleBox[".", "NumberedEquation"]
}], "UNNEQ"],

Cell[TextData[{
  "This solution is simply a disturbance that moves at velocity ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " without varying from its initial shape ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x)\)]],
  ". One can verify that this is the solution to Eq. ",
  ButtonBox["(7.1.14)",
    ButtonData:>{"Chapter7.nb", "(7.1.14)"},
    ButtonStyle->"Hyperlink"],
  "  by direct substitution:"
}], "Text",
  CellTags->"i:78"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      D[f[x, t], t]\  + \ c\ D[f[x, t], x] \[Equal] 0\  /. 
        f \[Rule] Function[{x, t}, f0[x\  - \ c\ t]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.1"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This form of  the solution is similar to d'Alembert's solution for the \
wave equation, Eq. ",
  ButtonBox["(5.1.11)",
    ButtonData:>{"Chapter5.nb", "(5.1.11)"},
    ButtonStyle->"Hyperlink"],
  " . Here, however, the disturbance moves only in one direction, because ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  is first-order rather than second-order  in time and space. The shape of \
the disturbance does not change, because ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " does not vary along each characteristic, and because the characteristics \
are  parallel lines. Thus, the entire solution is transported without change \
along the characteristics, as depicted in Fig. ",
  ButtonBox["7.1",
    ButtonData:>"Fig. 7.1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8808 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.08149 -0.0489684 1.08149 [
[.18494 .02919 -9.4794 -12 ]
[.18494 .02919 .5206 0 ]
[.83708 .32929 0 -7.96501 ]
[.83708 .32929 10 4.03499 ]
[-0.06873 .27044 -58 -3.77786 ]
[-0.06873 .27044 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .8808 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01448 .17452 m
.47602 0 L
s
gsave
.18494 .02919 -70.4794 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.47602 0 m
.98951 .64108 L
s
gsave
.83708 .32929 -61 -11.965 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01448 .17452 m
0 .31187 L
s
gsave
-0.06873 .27044 -119 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
105.000 13.000 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(L) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01448 .17452 m
0 .31187 L
s
0 .31187 m
.59195 .8808 L
s
.59195 .8808 m
.59083 .75623 L
s
.59083 .75623 m
.01448 .17452 L
s
.47602 0 m
.98951 .64108 L
s
.98951 .64108 m
1 .76863 L
s
1 .76863 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.01448 .17452 m
0 .31187 L
s
0 .31187 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.47602 0 m
.01448 .17452 L
s
.59083 .75623 m
.98951 .64108 L
s
.98951 .64108 m
1 .76863 L
s
1 .76863 m
.59195 .8808 L
s
.59195 .8808 m
.59083 .75623 L
s
0 0 m
1 0 L
1 .8808 L
0 .8808 L
closepath
clip
newpath
.5 Mabswid
.96219 .63323 m
.96988 .63455 L
s
.015 w
.967 .63341 m
.97005 .63673 L
s
.5 Mabswid
.95449 .63191 m
.96219 .63323 L
s
.94678 .63059 m
.95449 .63191 L
s
.93907 .62926 m
.94678 .63059 L
s
.015 w
.96394 .63018 m
.967 .63341 L
s
.5 Mabswid
.93134 .62794 m
.93907 .62926 L
s
.92361 .62662 m
.93134 .62794 L
s
.91587 .62529 m
.92361 .62662 L
s
.90813 .62396 m
.91587 .62529 L
s
.015 w
.96088 .62707 m
.96394 .63018 L
s
.5 Mabswid
.90037 .62263 m
.90813 .62396 L
s
.89261 .6213 m
.90037 .62263 L
s
.88484 .61997 m
.89261 .6213 L
s
.015 w
.95782 .62408 m
.96088 .62707 L
s
.5 Mabswid
.87707 .61864 m
.88484 .61997 L
s
.86928 .6173 m
.87707 .61864 L
s
.86149 .61596 m
.86928 .6173 L
s
.015 w
.95477 .62124 m
.95782 .62408 L
s
.5 Mabswid
.85369 .61463 m
.86149 .61596 L
s
.84589 .61329 m
.85369 .61463 L
s
.83807 .61195 m
.84589 .61329 L
s
.015 w
.95172 .61856 m
.95477 .62124 L
s
.5 Mabswid
.83025 .61061 m
.83807 .61195 L
s
.82242 .60927 m
.83025 .61061 L
s
.81458 .60792 m
.82242 .60927 L
s
.80674 .60658 m
.81458 .60792 L
s
.015 w
.94867 .61607 m
.95172 .61856 L
s
.5 Mabswid
.79889 .60523 m
.80674 .60658 L
s
.79103 .60388 m
.79889 .60523 L
s
.78316 .60253 m
.79103 .60388 L
s
.015 w
.94563 .61379 m
.94867 .61607 L
s
.5 Mabswid
.77528 .60118 m
.78316 .60253 L
s
.7674 .59983 m
.77528 .60118 L
s
.015 w
.77461 .60042 m
.778 .60383 L
s
.5 Mabswid
.75951 .59848 m
.7674 .59983 L
s
.75161 .59712 m
.75951 .59848 L
s
.015 w
.94259 .61174 m
.94563 .61379 L
s
.5 Mabswid
.7437 .59577 m
.75161 .59712 L
s
.015 w
.77122 .5971 m
.77461 .60042 L
s
.5 Mabswid
.73578 .59441 m
.7437 .59577 L
s
.72786 .59305 m
.73578 .59441 L
s
.015 w
.93956 .60993 m
.94259 .61174 L
s
.5 Mabswid
.71993 .59169 m
.72786 .59305 L
s
.015 w
.76782 .59389 m
.77122 .5971 L
s
.5 Mabswid
.71199 .59033 m
.71993 .59169 L
s
.70405 .58897 m
.71199 .59033 L
s
.69609 .58761 m
.70405 .58897 L
s
.015 w
.93655 .60839 m
.93956 .60993 L
s
.76441 .59082 m
.76782 .59389 L
s
.5 Mabswid
.68813 .58624 m
.69609 .58761 L
s
.68016 .58487 m
.68813 .58624 L
s
.67218 .58351 m
.68016 .58487 L
s
.6642 .58214 m
.67218 .58351 L
s
.015 w
.76101 .58789 m
.76441 .59082 L
s
.93354 .60713 m
.93655 .60839 L
s
.5 Mabswid
.6562 .58077 m
.6642 .58214 L
s
.6482 .57939 m
.6562 .58077 L
s
.64019 .57802 m
.6482 .57939 L
s
.015 w
.75759 .58512 m
.76101 .58789 L
s
.5 Mabswid
.63217 .57665 m
.64019 .57802 L
s
.015 w
.93054 .60617 m
.93354 .60713 L
s
.5 Mabswid
.62415 .57527 m
.63217 .57665 L
s
.61611 .57389 m
.62415 .57527 L
s
.015 w
.75417 .58254 m
.75759 .58512 L
s
.5 Mabswid
.60807 .57251 m
.61611 .57389 L
s
.60002 .57113 m
.60807 .57251 L
s
.015 w
.92755 .60552 m
.93054 .60617 L
s
.5 Mabswid
.59196 .56975 m
.60002 .57113 L
s
.5839 .56837 m
.59196 .56975 L
s
.015 w
.75075 .58017 m
.75417 .58254 L
s
.5 Mabswid
.57582 .56699 m
.5839 .56837 L
s
.56774 .5656 m
.57582 .56699 L
s
.015 w
.57749 .56661 m
.58122 .57012 L
s
.92457 .60518 m
.92755 .60552 L
s
.5 Mabswid
.55965 .56421 m
.56774 .5656 L
s
.015 w
.74733 .57803 m
.75075 .58017 L
s
.5 Mabswid
.55156 .56282 m
.55965 .56421 L
s
.54345 .56143 m
.55156 .56282 L
s
.015 w
.57374 .5632 m
.57749 .56661 L
s
.5 Mabswid
.53534 .56004 m
.54345 .56143 L
s
.015 w
.9216 .60516 m
.92457 .60518 L
s
.5 Mabswid
.52721 .55865 m
.53534 .56004 L
s
.015 w
.7439 .57614 m
.74733 .57803 L
s
.5 Mabswid
.51908 .55726 m
.52721 .55865 L
s
.015 w
.56998 .5599 m
.57374 .5632 L
s
.5 Mabswid
.51094 .55586 m
.51908 .55726 L
s
.5028 .55446 m
.51094 .55586 L
s
.015 w
.91864 .60545 m
.9216 .60516 L
s
.5 Mabswid
.49464 .55307 m
.5028 .55446 L
s
.015 w
.74047 .57452 m
.7439 .57614 L
s
.56622 .55673 m
.56998 .5599 L
s
.5 Mabswid
.48648 .55167 m
.49464 .55307 L
s
.47831 .55027 m
.48648 .55167 L
s
.47013 .54886 m
.47831 .55027 L
s
.015 w
.56243 .55371 m
.56622 .55673 L
s
.73704 .57318 m
.74047 .57452 L
s
.5 Mabswid
.46194 .54746 m
.47013 .54886 L
s
.015 w
.91569 .60603 m
.91864 .60545 L
s
.5 Mabswid
.45374 .54605 m
.46194 .54746 L
s
.44554 .54465 m
.45374 .54605 L
s
.43733 .54324 m
.44554 .54465 L
s
.015 w
.55864 .55085 m
.56243 .55371 L
s
.73361 .57214 m
.73704 .57318 L
s
.5 Mabswid
.42911 .54183 m
.43733 .54324 L
s
.015 w
.91274 .60689 m
.91569 .60603 L
s
.5 Mabswid
.42088 .54042 m
.42911 .54183 L
s
.41264 .53901 m
.42088 .54042 L
s
.015 w
.55484 .54818 m
.55864 .55085 L
s
.5 Mabswid
.4044 .53759 m
.41264 .53901 L
s
.015 w
.73017 .57141 m
.73361 .57214 L
s
.5 Mabswid
.39614 .53618 m
.4044 .53759 L
s
.38788 .53476 m
.39614 .53618 L
s
.015 w
.9098 .60801 m
.91274 .60689 L
s
.55102 .54572 m
.55484 .54818 L
s
.5 Mabswid
.37961 .53334 m
.38788 .53476 L
s
.015 w
.37544 .53196 m
.37954 .53556 L
s
.72673 .57099 m
.73017 .57141 L
s
.54719 .54349 m
.55102 .54572 L
s
.90685 .60934 m
.9098 .60801 L
s
.37133 .52845 m
.37544 .53196 L
s
.72329 .57089 m
.72673 .57099 L
s
.54334 .54151 m
.54719 .54349 L
s
.36719 .52506 m
.37133 .52845 L
s
.9039 .61086 m
.90685 .60934 L
s
.71984 .5711 m
.72329 .57089 L
s
.53948 .5398 m
.54334 .54151 L
s
.36304 .52179 m
.36719 .52506 L
s
.90095 .61249 m
.9039 .61086 L
s
.35887 .51867 m
.36304 .52179 L
s
.53561 .53837 m
.53948 .5398 L
s
.71638 .57162 m
.71984 .5711 L
s
.35468 .51571 m
.35887 .51867 L
s
.53172 .53725 m
.53561 .53837 L
s
.89798 .61419 m
.90095 .61249 L
s
.71292 .57241 m
.71638 .57162 L
s
.35047 .51295 m
.35468 .51571 L
s
.52781 .53644 m
.53172 .53725 L
s
.895 .6159 m
.89798 .61419 L
s
.70944 .57345 m
.71292 .57241 L
s
.34624 .51039 m
.35047 .51295 L
s
.52388 .53594 m
.52781 .53644 L
s
.34198 .50807 m
.34624 .51039 L
s
.70596 .57472 m
.70944 .57345 L
s
.892 .61754 m
.895 .6159 L
s
.51994 .53576 m
.52388 .53594 L
s
.3377 .506 m
.34198 .50807 L
s
.70247 .57616 m
.70596 .57472 L
s
.88897 .61903 m
.892 .61754 L
s
0 1 0 r
.5 Mabswid
.84914 .4848 m
.84924 .48645 L
s
0 g
.84096 .48333 m
.84914 .4848 L
s
.015 w
.51598 .53589 m
.51994 .53576 L
s
0 1 0 r
.5 Mabswid
.84924 .48645 m
.84933 .4881 L
s
0 g
.015 w
.33338 .5042 m
.3377 .506 L
s
.5 Mabswid
.83277 .48186 m
.84096 .48333 L
s
0 1 0 r
.84933 .4881 m
.84943 .48976 L
s
.84943 .48976 m
.84952 .49141 L
s
0 g
.82457 .48039 m
.83277 .48186 L
s
0 1 0 r
.84952 .49141 m
.84962 .49307 L
s
0 g
.81637 .47891 m
.82457 .48039 L
s
0 1 0 r
.84962 .49307 m
.84972 .49472 L
s
.84972 .49472 m
.84981 .49638 L
s
0 g
.80815 .47744 m
.81637 .47891 L
s
0 1 0 r
.84981 .49638 m
.84991 .49804 L
s
0 g
.015 w
.69896 .57773 m
.70247 .57616 L
s
.88592 .62031 m
.88897 .61903 L
s
.32904 .50268 m
.33338 .5042 L
s
0 1 0 r
.5 Mabswid
.84991 .49804 m
.85001 .4997 L
s
0 g
.79993 .47596 m
.80815 .47744 L
s
.015 w
.51199 .53633 m
.51598 .53589 L
s
0 1 0 r
.5 Mabswid
.85001 .4997 m
.8501 .50136 L
s
0 g
.7917 .47448 m
.79993 .47596 L
s
0 1 0 r
.8501 .50136 m
.8502 .50302 L
s
.8502 .50302 m
.8503 .50468 L
s
0 g
.78346 .473 m
.7917 .47448 L
s
0 1 0 r
.8503 .50468 m
.85039 .50635 L
s
.85039 .50635 m
.85049 .50801 L
s
0 g
.77521 .47152 m
.78346 .473 L
s
0 1 0 r
.85049 .50801 m
.85059 .50968 L
s
0 g
.015 w
.32467 .50147 m
.32904 .50268 L
s
.5 Mabswid
.76695 .47004 m
.77521 .47152 L
s
0 1 0 r
.85059 .50968 m
.85068 .51135 L
s
0 g
.015 w
.88282 .62128 m
.88592 .62031 L
s
.69543 .57936 m
.69896 .57773 L
s
.50799 .53704 m
.51199 .53633 L
s
0 1 0 r
.5 Mabswid
.85068 .51135 m
.85078 .51302 L
s
0 g
.75869 .46856 m
.76695 .47004 L
s
0 1 0 r
.85078 .51302 m
.85088 .51468 L
s
.85088 .51468 m
.85097 .51635 L
s
0 g
.75041 .46707 m
.75869 .46856 L
s
0 1 0 r
.85097 .51635 m
.85107 .51803 L
s
0 g
.74213 .46558 m
.75041 .46707 L
s
0 1 0 r
.85107 .51803 m
.85117 .5197 L
s
0 g
.015 w
.32027 .50057 m
.32467 .50147 L
s
0 1 0 r
.5 Mabswid
.85117 .5197 m
.85127 .52137 L
s
0 g
.73384 .46409 m
.74213 .46558 L
s
0 1 0 r
.85127 .52137 m
.85136 .52305 L
s
0 g
.015 w
.87969 .62188 m
.88282 .62128 L
s
0 1 0 r
.5 Mabswid
.85136 .52305 m
.85146 .52472 L
s
0 g
.72554 .4626 m
.73384 .46409 L
s
.015 w
.69189 .581 m
.69543 .57936 L
s
.50396 .53801 m
.50799 .53704 L
s
0 1 0 r
.5 Mabswid
.85146 .52472 m
.85156 .5264 L
s
0 g
.71723 .46111 m
.72554 .4626 L
s
0 1 0 r
.85156 .5264 m
.85166 .52808 L
s
.85166 .52808 m
.85175 .52975 L
s
0 g
.70891 .45962 m
.71723 .46111 L
s
0 1 0 r
.85175 .52975 m
.85185 .53143 L
s
0 g
.015 w
.31584 .49998 m
.32027 .50057 L
s
0 1 0 r
.5 Mabswid
.85185 .53143 m
.85195 .53311 L
s
0 g
.70059 .45812 m
.70891 .45962 L
s
0 1 0 r
.85195 .53311 m
.85205 .5348 L
s
0 g
.69225 .45663 m
.70059 .45812 L
s
0 1 0 r
.85205 .5348 m
.85214 .53648 L
s
0 g
.015 w
.87652 .62202 m
.87969 .62188 L
s
0 1 0 r
.5 Mabswid
.85214 .53648 m
.85224 .53816 L
s
0 g
.68391 .45513 m
.69225 .45663 L
s
.015 w
.49992 .53921 m
.50396 .53801 L
s
.68833 .58257 m
.69189 .581 L
s
0 1 0 r
.5 Mabswid
.85224 .53816 m
.85234 .53985 L
s
0 g
.67556 .45363 m
.68391 .45513 L
s
0 1 0 r
.85234 .53985 m
.85244 .54153 L
s
.85244 .54153 m
.85254 .54322 L
s
0 g
.015 w
.31137 .49972 m
.31584 .49998 L
s
.5 Mabswid
.6672 .45213 m
.67556 .45363 L
s
0 1 0 r
.85254 .54322 m
.85263 .54491 L
s
.85263 .54491 m
.85273 .5466 L
s
0 g
.65883 .45063 m
.6672 .45213 L
s
0 1 0 r
.85273 .5466 m
.85283 .54829 L
s
0 g
.015 w
.8733 .62163 m
.87652 .62202 L
s
.5 Mabswid
.65045 .44912 m
.65883 .45063 L
s
0 1 0 r
.85283 .54829 m
.85293 .54998 L
s
.85293 .54998 m
.85303 .55167 L
s
0 g
.64207 .44762 m
.65045 .44912 L
s
.015 w
.49585 .54057 m
.49992 .53921 L
s
.68474 .584 m
.68833 .58257 L
s
0 1 0 r
.5 Mabswid
.85303 .55167 m
.85313 .55337 L
s
.64486 .44812 m
.6449 .44978 L
s
.85313 .55337 m
.85323 .55506 L
s
0 g
.63367 .44611 m
.64207 .44762 L
s
.015 w
.30687 .49977 m
.31137 .49972 L
s
0 1 0 r
.5 Mabswid
.6449 .44978 m
.64493 .45144 L
s
.85323 .55506 m
.85332 .55676 L
s
.64493 .45144 m
.64496 .4531 L
s
0 g
.62527 .4446 m
.63367 .44611 L
s
0 1 0 r
.85332 .55676 m
.85342 .55845 L
s
.64496 .4531 m
.64499 .45477 L
s
.85342 .55845 m
.85352 .56015 L
s
0 g
.61685 .44309 m
.62527 .4446 L
s
0 1 0 r
.64499 .45477 m
.64503 .45643 L
s
0 g
.015 w
.87003 .62066 m
.8733 .62163 L
s
0 1 0 r
.5 Mabswid
.85352 .56015 m
.85362 .56185 L
s
.64503 .45643 m
.64506 .4581 L
s
.85362 .56185 m
.85372 .56355 L
s
0 g
.60843 .44158 m
.61685 .44309 L
s
0 1 0 r
.64506 .4581 m
.64509 .45977 L
s
.85372 .56355 m
.85382 .56525 L
s
.64509 .45977 m
.64513 .46144 L
s
0 g
.015 w
.49176 .54207 m
.49585 .54057 L
s
.5 Mabswid
.6 .44006 m
.60843 .44158 L
s
.015 w
.68113 .5852 m
.68474 .584 L
s
0 1 0 r
.5 Mabswid
.85382 .56525 m
.85392 .56695 L
s
.64513 .46144 m
.64516 .46311 L
s
.85392 .56695 m
.85402 .56866 L
s
0 g
.015 w
.30233 .50012 m
.30687 .49977 L
s
.5 Mabswid
.59156 .43855 m
.6 .44006 L
s
0 1 0 r
.64516 .46311 m
.64519 .46478 L
s
.85402 .56866 m
.85411 .57036 L
s
.64519 .46478 m
.64523 .46645 L
s
.85411 .57036 m
.85421 .57207 L
s
0 g
.58312 .43703 m
.59156 .43855 L
s
.015 w
.86671 .61903 m
.87003 .62066 L
s
0 1 0 r
.5 Mabswid
.64523 .46645 m
.64526 .46812 L
s
.85421 .57207 m
.85431 .57377 L
s
.64526 .46812 m
.64529 .4698 L
s
0 g
.57466 .43551 m
.58312 .43703 L
s
0 1 0 r
.85431 .57377 m
.85441 .57548 L
s
.64529 .4698 m
.64532 .47147 L
s
.85441 .57548 m
.85451 .57719 L
s
0 g
.56619 .43399 m
.57466 .43551 L
s
0 1 0 r
.64532 .47147 m
.64536 .47315 L
s
.85451 .57719 m
.85461 .5789 L
s
.64536 .47315 m
.64539 .47482 L
s
0 g
.015 w
.67749 .5861 m
.68113 .5852 L
s
.48765 .54363 m
.49176 .54207 L
s
0 1 0 r
.5 Mabswid
.85461 .5789 m
.85471 .58061 L
s
0 g
.55772 .43247 m
.56619 .43399 L
s
.015 w
.29776 .50076 m
.30233 .50012 L
s
0 1 0 r
.5 Mabswid
.64539 .47482 m
.64542 .4765 L
s
.85471 .58061 m
.85481 .58232 L
s
0 g
.015 w
.86333 .61671 m
.86671 .61903 L
s
0 1 0 r
.5 Mabswid
.64542 .4765 m
.64546 .47818 L
s
0 g
.54924 .43095 m
.55772 .43247 L
s
0 1 0 r
.85481 .58232 m
.85491 .58403 L
s
.64546 .47818 m
.64549 .47986 L
s
.85491 .58403 m
.85501 .58575 L
s
0 g
.54075 .42942 m
.54924 .43095 L
s
0 1 0 r
.64549 .47986 m
.64552 .48154 L
s
.85501 .58575 m
.85511 .58746 L
s
.64552 .48154 m
.64556 .48322 L
s
.85511 .58746 m
.85521 .58918 L
s
0 g
.53224 .4279 m
.54075 .42942 L
s
0 1 0 r
.64556 .48322 m
.64559 .48491 L
s
.85521 .58918 m
.85531 .5909 L
s
0 g
.52373 .42637 m
.53224 .4279 L
s
0 1 0 r
.64559 .48491 m
.64562 .48659 L
s
.85531 .5909 m
.85541 .59261 L
s
0 g
.015 w
.8599 .61366 m
.86333 .61671 L
s
.67383 .58662 m
.67749 .5861 L
s
0 1 0 r
.5 Mabswid
.64562 .48659 m
.64566 .48828 L
s
.85541 .59261 m
.85551 .59433 L
s
0 g
.015 w
.48351 .5452 m
.48765 .54363 L
s
.5 Mabswid
.51522 .42484 m
.52373 .42637 L
s
.015 w
.29316 .50165 m
.29776 .50076 L
s
0 1 0 r
.5 Mabswid
.64566 .48828 m
.64569 .48996 L
s
.85551 .59433 m
.85561 .59605 L
s
.64569 .48996 m
.64572 .49165 L
s
0 g
.50669 .42331 m
.51522 .42484 L
s
0 1 0 r
.85561 .59605 m
.85571 .59778 L
s
.64572 .49165 m
.64576 .49334 L
s
.85571 .59778 m
.85581 .5995 L
s
0 g
.49815 .42177 m
.50669 .42331 L
s
0 1 0 r
.64576 .49334 m
.64579 .49503 L
s
.85581 .5995 m
.85591 .60122 L
s
.64579 .49503 m
.64582 .49672 L
s
0 g
.015 w
.85641 .60986 m
.8599 .61366 L
s
0 1 0 r
.5 Mabswid
.85591 .60122 m
.85601 .60295 L
s
0 g
.48961 .42024 m
.49815 .42177 L
s
0 1 0 r
.64582 .49672 m
.64586 .49841 L
s
.85601 .60295 m
.85611 .60467 L
s
.64586 .49841 m
.64589 .50011 L
s
0 g
.48105 .4187 m
.48961 .42024 L
s
0 1 0 r
.85611 .60467 m
.85621 .6064 L
s
0 g
.015 w
.67013 .58668 m
.67383 .58662 L
s
0 1 0 r
.5 Mabswid
.64589 .50011 m
.64592 .5018 L
s
.85621 .6064 m
.85631 .60813 L
s
0 g
.015 w
.28852 .50277 m
.29316 .50165 L
s
.47936 .5467 m
.48351 .5452 L
s
.5 Mabswid
.47249 .41717 m
.48105 .4187 L
s
0 1 0 r
.64592 .5018 m
.64596 .5035 L
s
.85631 .60813 m
.85641 .60986 L
s
.64596 .5035 m
.64599 .50519 L
s
0 g
.015 w
.85287 .6053 m
.85641 .60986 L
s
.5 Mabswid
.46392 .41563 m
.47249 .41717 L
s
0 1 0 r
.64599 .50519 m
.64602 .50689 L
s
.64602 .50689 m
.64606 .50859 L
s
0 g
.45533 .41409 m
.46392 .41563 L
s
0 1 0 r
.64606 .50859 m
.64609 .51029 L
s
0 g
.44674 .41254 m
.45533 .41409 L
s
0 1 0 r
.64609 .51029 m
.64613 .51199 L
s
0 g
.015 w
.66641 .58621 m
.67013 .58668 L
s
.84928 .59998 m
.85287 .6053 L
s
0 1 0 r
.5 Mabswid
.64613 .51199 m
.64616 .51369 L
s
0 g
.43814 .411 m
.44674 .41254 L
s
0 1 0 r
.64616 .51369 m
.64619 .51539 L
s
0 g
.015 w
.28385 .50406 m
.28852 .50277 L
s
.47518 .54805 m
.47936 .5467 L
s
0 1 0 r
.5 Mabswid
.64619 .51539 m
.64623 .5171 L
s
0 g
.42953 .40945 m
.43814 .411 L
s
0 1 0 r
.43527 .41048 m
.43524 .41215 L
s
.64623 .5171 m
.64626 .5188 L
s
.43524 .41215 m
.43521 .41383 L
s
0 g
.42092 .40791 m
.42953 .40945 L
s
0 1 0 r
.64626 .5188 m
.64629 .52051 L
s
0 g
.015 w
.84563 .59393 m
.84928 .59998 L
s
0 1 0 r
.5 Mabswid
.43521 .41383 m
.43517 .4155 L
s
.64629 .52051 m
.64633 .52222 L
s
0 g
.41229 .40636 m
.42092 .40791 L
s
0 1 0 r
.43517 .4155 m
.43514 .41717 L
s
.64633 .52222 m
.64636 .52392 L
s
.43514 .41717 m
.43511 .41885 L
s
0 g
.015 w
.66266 .58514 m
.66641 .58621 L
s
0 1 0 r
.5 Mabswid
.64636 .52392 m
.6464 .52563 L
s
0 g
.40365 .40481 m
.41229 .40636 L
s
0 1 0 r
.43511 .41885 m
.43507 .42052 L
s
0 g
.015 w
.84194 .58717 m
.84563 .59393 L
s
0 1 0 r
.5 Mabswid
.6464 .52563 m
.64643 .52734 L
s
.43507 .42052 m
.43504 .4222 L
s
0 g
.39501 .40325 m
.40365 .40481 L
s
0 1 0 r
.64643 .52734 m
.64646 .52906 L
s
.43504 .4222 m
.435 .42388 L
s
0 g
.015 w
.27915 .50548 m
.28385 .50406 L
s
.47099 .54917 m
.47518 .54805 L
s
0 1 0 r
.5 Mabswid
.64646 .52906 m
.6465 .53077 L
s
0 g
.38635 .4017 m
.39501 .40325 L
s
0 1 0 r
.435 .42388 m
.43497 .42556 L
s
.6465 .53077 m
.64653 .53248 L
s
0 g
.015 w
.83821 .57976 m
.84194 .58717 L
s
0 1 0 r
.5 Mabswid
.43497 .42556 m
.43494 .42724 L
s
.64653 .53248 m
.64656 .5342 L
s
0 g
.37769 .40014 m
.38635 .4017 L
s
0 1 0 r
.43494 .42724 m
.4349 .42892 L
s
.64656 .5342 m
.6466 .53591 L
s
0 g
.015 w
.65888 .58342 m
.66266 .58514 L
s
.5 Mabswid
.36902 .39859 m
.37769 .40014 L
s
0 1 0 r
.4349 .42892 m
.43487 .4306 L
s
.6466 .53591 m
.64663 .53763 L
s
0 g
.015 w
.83444 .57173 m
.83821 .57976 L
s
0 1 0 r
.5 Mabswid
.43487 .4306 m
.43483 .43229 L
s
.64663 .53763 m
.64667 .53935 L
s
0 g
.36034 .39703 m
.36902 .39859 L
s
0 1 0 r
.43483 .43229 m
.4348 .43397 L
s
.64667 .53935 m
.6467 .54107 L
s
.4348 .43397 m
.43477 .43566 L
s
0 g
.015 w
.83063 .56317 m
.83444 .57173 L
s
.5 Mabswid
.35164 .39547 m
.36034 .39703 L
s
0 1 0 r
.6467 .54107 m
.64673 .54279 L
s
.43477 .43566 m
.43473 .43734 L
s
0 g
.015 w
.46678 .55 m
.47099 .54917 L
s
.27442 .50697 m
.27915 .50548 L
s
0 1 0 r
.5 Mabswid
.64673 .54279 m
.64677 .54451 L
s
0 g
.34294 .3939 m
.35164 .39547 L
s
0 1 0 r
.43473 .43734 m
.4347 .43903 L
s
.64677 .54451 m
.6468 .54623 L
s
0 g
.015 w
.82679 .55412 m
.83063 .56317 L
s
.65506 .58101 m
.65888 .58342 L
s
0 1 0 r
.5 Mabswid
.4347 .43903 m
.43466 .44072 L
s
.6468 .54623 m
.64684 .54796 L
s
0 g
.33423 .39234 m
.34294 .3939 L
s
0 1 0 r
.43466 .44072 m
.43463 .44241 L
s
.64684 .54796 m
.64687 .54968 L
s
0 g
.015 w
.82292 .54468 m
.82679 .55412 L
s
0 1 0 r
.5 Mabswid
.43463 .44241 m
.4346 .4441 L
s
0 g
.32552 .39078 m
.33423 .39234 L
s
0 1 0 r
.64687 .54968 m
.6469 .55141 L
s
.4346 .4441 m
.43456 .4458 L
s
0 g
.015 w
.81904 .53492 m
.82292 .54468 L
s
0 1 0 r
.5 Mabswid
.6469 .55141 m
.64694 .55313 L
s
0 g
.31679 .38921 m
.32552 .39078 L
s
0 1 0 r
.43456 .4458 m
.43453 .44749 L
s
.64694 .55313 m
.64697 .55486 L
s
0 g
.015 w
.81514 .52492 m
.81904 .53492 L
s
0 1 0 r
.5 Mabswid
.43453 .44749 m
.43449 .44918 L
s
.64697 .55486 m
.64701 .55659 L
s
0 g
.30805 .38764 m
.31679 .38921 L
s
.015 w
.65122 .57785 m
.65506 .58101 L
s
.46256 .55043 m
.46678 .55 L
s
0 1 0 r
.5 Mabswid
.43449 .44918 m
.43446 .45088 L
s
.64701 .55659 m
.64704 .55832 L
s
0 g
.015 w
.81123 .51475 m
.81514 .52492 L
s
.26966 .50845 m
.27442 .50697 L
s
0 1 0 r
.5 Mabswid
.43446 .45088 m
.43443 .45258 L
s
0 g
.2993 .38607 m
.30805 .38764 L
s
0 1 0 r
.64704 .55832 m
.64708 .56005 L
s
0 g
.015 w
.80731 .5045 m
.81123 .51475 L
s
0 1 0 r
.5 Mabswid
.43443 .45258 m
.43439 .45427 L
s
.64708 .56005 m
.64711 .56179 L
s
0 g
.29055 .3845 m
.2993 .38607 L
s
0 1 0 r
.43439 .45427 m
.43436 .45597 L
s
0 g
.015 w
.80338 .49423 m
.80731 .5045 L
s
0 1 0 r
.5 Mabswid
.64711 .56179 m
.64714 .56352 L
s
.43436 .45597 m
.43432 .45767 L
s
.64714 .56352 m
.64718 .56525 L
s
0 g
.28178 .38292 m
.29055 .3845 L
s
.015 w
.79946 .48402 m
.80338 .49423 L
s
0 1 0 r
.5 Mabswid
.43432 .45767 m
.43429 .45937 L
s
0 g
.015 w
.64735 .57394 m
.65122 .57785 L
s
0 1 0 r
.5 Mabswid
.64718 .56525 m
.64721 .56699 L
s
0 g
.015 w
.79554 .47391 m
.79946 .48402 L
s
0 1 0 r
.5 Mabswid
.43429 .45937 m
.43425 .46108 L
s
0 g
.27301 .38135 m
.28178 .38292 L
s
0 1 0 r
.64721 .56699 m
.64725 .56873 L
s
.43425 .46108 m
.43422 .46278 L
s
.64725 .56873 m
.64728 .57046 L
s
0 g
.015 w
.79162 .46397 m
.79554 .47391 L
s
.45832 .55041 m
.46256 .55043 L
s
.5 Mabswid
.26422 .37977 m
.27301 .38135 L
s
0 1 0 r
.43422 .46278 m
.43419 .46448 L
s
.64728 .57046 m
.64732 .5722 L
s
0 g
.015 w
.26489 .50987 m
.26966 .50845 L
s
0 1 0 r
.5 Mabswid
.43419 .46448 m
.43415 .46619 L
s
0 g
.015 w
.78771 .45423 m
.79162 .46397 L
s
0 1 0 r
.5 Mabswid
.64732 .5722 m
.64735 .57394 L
s
0 g
.25543 .37819 m
.26422 .37977 L
s
0 1 0 r
.43415 .46619 m
.43412 .4679 L
s
0 g
.015 w
.64345 .56927 m
.64735 .57394 L
s
.7838 .44474 m
.78771 .45423 L
s
0 1 0 r
.5 Mabswid
.43412 .4679 m
.43408 .4696 L
s
0 g
.24663 .37661 m
.25543 .37819 L
s
0 1 0 r
.43408 .4696 m
.43405 .47131 L
s
0 g
.015 w
.77991 .43552 m
.7838 .44474 L
s
.5 Mabswid
.23782 .37503 m
.24663 .37661 L
s
0 1 0 r
.43405 .47131 m
.43401 .47302 L
s
.43401 .47302 m
.43398 .47473 L
s
0 g
.229 .37344 m
.23782 .37503 L
s
.015 w
.77602 .42659 m
.77991 .43552 L
s
.45407 .54985 m
.45832 .55041 L
s
.63953 .56384 m
.64345 .56927 L
s
0 1 0 r
.5 Mabswid
.43398 .47473 m
.43394 .47645 L
s
.43394 .47645 m
.43391 .47816 L
s
0 g
.22016 .37186 m
.229 .37344 L
s
.015 w
.77214 .41797 m
.77602 .42659 L
s
.2601 .51115 m
.26489 .50987 L
s
0 1 0 r
.5 Mabswid
.43391 .47816 m
.43387 .47987 L
s
.22016 .37186 m
.22006 .37354 L
s
.43387 .47987 m
.43384 .48159 L
s
.22006 .37354 m
.21996 .37522 L
s
.43384 .48159 m
.43381 .4833 L
s
0 g
.015 w
.63558 .55766 m
.63953 .56384 L
s
.76827 .40966 m
.77214 .41797 L
s
0 1 0 r
.5 Mabswid
.21996 .37522 m
.21985 .3769 L
s
.43381 .4833 m
.43377 .48502 L
s
.21985 .3769 m
.21975 .37859 L
s
.43377 .48502 m
.43374 .48674 L
s
.21975 .37859 m
.21965 .38027 L
s
0 g
.015 w
.76441 .40166 m
.76827 .40966 L
s
.44981 .54869 m
.45407 .54985 L
s
0 1 0 r
.5 Mabswid
.43374 .48674 m
.4337 .48846 L
s
.21965 .38027 m
.21954 .38196 L
s
0 g
.015 w
.63162 .55078 m
.63558 .55766 L
s
0 1 0 r
.5 Mabswid
.4337 .48846 m
.43367 .49018 L
s
.21954 .38196 m
.21944 .38364 L
s
.43367 .49018 m
.43363 .4919 L
s
0 g
.015 w
.76055 .39396 m
.76441 .40166 L
s
0 1 0 r
.5 Mabswid
.21944 .38364 m
.21933 .38533 L
s
0 g
.015 w
.25529 .51219 m
.2601 .51115 L
s
0 1 0 r
.5 Mabswid
.43363 .4919 m
.4336 .49363 L
s
.21933 .38533 m
.21923 .38702 L
s
.4336 .49363 m
.43356 .49535 L
s
0 g
.015 w
.62763 .54323 m
.63162 .55078 L
s
0 1 0 r
.5 Mabswid
.21923 .38702 m
.21912 .38871 L
s
.43356 .49535 m
.43353 .49708 L
s
0 g
.015 w
.7567 .38657 m
.76055 .39396 L
s
0 1 0 r
.5 Mabswid
.21912 .38871 m
.21902 .3904 L
s
.43353 .49708 m
.43349 .4988 L
s
0 g
.015 w
.44554 .54688 m
.44981 .54869 L
s
0 1 0 r
.5 Mabswid
.21902 .3904 m
.21891 .39209 L
s
.43349 .4988 m
.43346 .50053 L
s
0 g
.015 w
.62363 .53507 m
.62763 .54323 L
s
0 1 0 r
.5 Mabswid
.21891 .39209 m
.21881 .39379 L
s
.43346 .50053 m
.43342 .50226 L
s
0 g
.015 w
.75285 .37946 m
.7567 .38657 L
s
0 1 0 r
.5 Mabswid
.21881 .39379 m
.21871 .39548 L
s
.43342 .50226 m
.43339 .50399 L
s
.21871 .39548 m
.2186 .39718 L
s
0 g
.015 w
.61961 .52636 m
.62363 .53507 L
s
0 1 0 r
.5 Mabswid
.43339 .50399 m
.43335 .50572 L
s
.2186 .39718 m
.2185 .39887 L
s
0 g
.015 w
.25048 .51293 m
.25529 .51219 L
s
0 1 0 r
.5 Mabswid
.43335 .50572 m
.43332 .50745 L
s
.2185 .39887 m
.21839 .40057 L
s
0 g
.015 w
.74901 .37261 m
.75285 .37946 L
s
0 1 0 r
.5 Mabswid
.43332 .50745 m
.43328 .50919 L
s
0 g
.015 w
.61558 .51717 m
.61961 .52636 L
s
.44127 .54436 m
.44554 .54688 L
s
0 1 0 r
.5 Mabswid
.21839 .40057 m
.21829 .40227 L
s
.43328 .50919 m
.43325 .51092 L
s
.21829 .40227 m
.21818 .40397 L
s
.43325 .51092 m
.43321 .51266 L
s
0 g
.015 w
.61154 .50758 m
.61558 .51717 L
s
0 1 0 r
.5 Mabswid
.21818 .40397 m
.21808 .40567 L
s
.43321 .51266 m
.43318 .51439 L
s
0 g
.015 w
.74517 .36602 m
.74901 .37261 L
s
0 1 0 r
.5 Mabswid
.21808 .40567 m
.21797 .40737 L
s
0 g
.015 w
.60749 .49767 m
.61154 .50758 L
s
0 1 0 r
.5 Mabswid
.43318 .51439 m
.43314 .51613 L
s
.21797 .40737 m
.21787 .40908 L
s
.43314 .51613 m
.43311 .51787 L
s
0 g
.015 w
.60343 .48752 m
.60749 .49767 L
s
0 1 0 r
.5 Mabswid
.21787 .40908 m
.21776 .41078 L
s
.43311 .51787 m
.43307 .51961 L
s
0 g
.015 w
.43699 .5411 m
.44127 .54436 L
s
.24566 .51328 m
.25048 .51293 L
s
0 1 0 r
.5 Mabswid
.21776 .41078 m
.21766 .41249 L
s
.43307 .51961 m
.43304 .52135 L
s
0 g
.015 w
.59937 .4772 m
.60343 .48752 L
s
.74132 .35966 m
.74517 .36602 L
s
0 1 0 r
.5 Mabswid
.21766 .41249 m
.21755 .41419 L
s
.43304 .52135 m
.433 .52309 L
s
0 g
.015 w
.5953 .46679 m
.59937 .4772 L
s
0 1 0 r
.5 Mabswid
.21755 .41419 m
.21744 .4159 L
s
.433 .52309 m
.43297 .52484 L
s
.21744 .4159 m
.21734 .41761 L
s
0 g
.015 w
.59123 .45637 m
.5953 .46679 L
s
0 1 0 r
.5 Mabswid
.43297 .52484 m
.43293 .52658 L
s
.21734 .41761 m
.21723 .41932 L
s
0 g
.015 w
.73748 .3535 m
.74132 .35966 L
s
0 1 0 r
.5 Mabswid
.43293 .52658 m
.4329 .52833 L
s
0 g
.015 w
.58716 .446 m
.59123 .45637 L
s
0 1 0 r
.5 Mabswid
.21723 .41932 m
.21713 .42103 L
s
0 g
.015 w
.43272 .53707 m
.43699 .5411 L
s
0 1 0 r
.5 Mabswid
.4329 .52833 m
.43286 .53008 L
s
0 g
.015 w
.58308 .43574 m
.58716 .446 L
s
0 1 0 r
.5 Mabswid
.21713 .42103 m
.21702 .42274 L
s
.43286 .53008 m
.43283 .53182 L
s
.21702 .42274 m
.21692 .42446 L
s
.43283 .53182 m
.43279 .53357 L
s
0 g
.015 w
.579 .42565 m
.58308 .43574 L
s
.24085 .51317 m
.24566 .51328 L
s
0 1 0 r
.5 Mabswid
.21692 .42446 m
.21681 .42617 L
s
0 g
.015 w
.73364 .34753 m
.73748 .3535 L
s
0 1 0 r
.5 Mabswid
.43279 .53357 m
.43276 .53532 L
s
.21681 .42617 m
.2167 .42789 L
s
0 g
.015 w
.57492 .41576 m
.579 .42565 L
s
0 1 0 r
.5 Mabswid
.43276 .53532 m
.43272 .53707 L
s
.2167 .42789 m
.2166 .42961 L
s
0 g
.015 w
.42845 .53228 m
.43272 .53707 L
s
.57083 .40612 m
.57492 .41576 L
s
0 1 0 r
.5 Mabswid
.2166 .42961 m
.21649 .43132 L
s
.21649 .43132 m
.21639 .43304 L
s
0 g
.015 w
.72979 .34173 m
.73364 .34753 L
s
.56674 .39675 m
.57083 .40612 L
s
0 1 0 r
.5 Mabswid
.21639 .43304 m
.21628 .43476 L
s
.21628 .43476 m
.21617 .43648 L
s
0 g
.015 w
.56265 .38768 m
.56674 .39675 L
s
.23604 .51252 m
.24085 .51317 L
s
.42418 .52673 m
.42845 .53228 L
s
0 1 0 r
.5 Mabswid
.21617 .43648 m
.21607 .43821 L
s
.21607 .43821 m
.21596 .43993 L
s
0 g
.015 w
.72594 .33608 m
.72979 .34173 L
s
.55855 .37891 m
.56265 .38768 L
s
0 1 0 r
.5 Mabswid
.21596 .43993 m
.21585 .44165 L
s
.21585 .44165 m
.21575 .44338 L
s
.21575 .44338 m
.21564 .44511 L
s
0 g
.015 w
.41992 .52042 m
.42418 .52673 L
s
.55445 .37045 m
.55855 .37891 L
s
0 1 0 r
.5 Mabswid
.21564 .44511 m
.21553 .44683 L
s
0 g
.015 w
.72208 .33055 m
.72594 .33608 L
s
0 1 0 r
.5 Mabswid
.21553 .44683 m
.21543 .44856 L
s
0 g
.015 w
.55034 .36231 m
.55445 .37045 L
s
.23125 .51126 m
.23604 .51252 L
s
0 1 0 r
.5 Mabswid
.21543 .44856 m
.21532 .45029 L
s
0 g
.015 w
.41566 .51341 m
.41992 .52042 L
s
0 1 0 r
.5 Mabswid
.21532 .45029 m
.21521 .45203 L
s
.21521 .45203 m
.21511 .45376 L
s
0 g
.015 w
.54622 .35448 m
.55034 .36231 L
s
.71821 .32513 m
.72208 .33055 L
s
0 1 0 r
.5 Mabswid
.21511 .45376 m
.215 .45549 L
s
.215 .45549 m
.21489 .45723 L
s
0 g
.015 w
.41141 .50572 m
.41566 .51341 L
s
0 1 0 r
.5 Mabswid
.21489 .45723 m
.21478 .45896 L
s
0 g
.015 w
.5421 .34694 m
.54622 .35448 L
s
0 1 0 r
.5 Mabswid
.21478 .45896 m
.21468 .4607 L
s
0 g
.015 w
.22648 .50935 m
.23125 .51126 L
s
0 1 0 r
.5 Mabswid
.21468 .4607 m
.21457 .46244 L
s
0 g
.015 w
.40717 .49741 m
.41141 .50572 L
s
.71434 .31981 m
.71821 .32513 L
s
0 1 0 r
.5 Mabswid
.21457 .46244 m
.21446 .46418 L
s
0 g
.015 w
.53796 .33969 m
.5421 .34694 L
s
0 1 0 r
.5 Mabswid
.21446 .46418 m
.21435 .46592 L
s
0 g
.015 w
.40293 .48856 m
.40717 .49741 L
s
0 1 0 r
.5 Mabswid
.21435 .46592 m
.21425 .46766 L
s
0 g
.70553 .31587 m
.71426 .31752 L
s
0 1 0 r
.21425 .46766 m
.21414 .4694 L
s
0 g
.015 w
.53382 .33271 m
.53796 .33969 L
s
0 1 0 r
.5 Mabswid
.21414 .4694 m
.21403 .47115 L
s
0 g
.015 w
.3987 .47922 m
.40293 .48856 L
s
.5 Mabswid
.69678 .31422 m
.70553 .31587 L
s
.015 w
.22172 .50672 m
.22648 .50935 L
s
0 1 0 r
.5 Mabswid
.21403 .47115 m
.21392 .47289 L
s
0 g
.68803 .31257 m
.69678 .31422 L
s
0 1 0 r
.21392 .47289 m
.21382 .47464 L
s
0 g
.015 w
.39447 .46948 m
.3987 .47922 L
s
0 1 0 r
.5 Mabswid
.21382 .47464 m
.21371 .47639 L
s
0 g
.67927 .31092 m
.68803 .31257 L
s
.015 w
.52967 .32598 m
.53382 .33271 L
s
.39025 .45942 m
.39447 .46948 L
s
0 1 0 r
.5 Mabswid
.21371 .47639 m
.2136 .47814 L
s
.2136 .47814 m
.21349 .47989 L
s
0 g
.6705 .30927 m
.67927 .31092 L
s
.015 w
.38603 .44911 m
.39025 .45942 L
s
0 1 0 r
.5 Mabswid
.21349 .47989 m
.21338 .48164 L
s
0 g
.015 w
.217 .50335 m
.22172 .50672 L
s
.5 Mabswid
.66172 .30761 m
.6705 .30927 L
s
0 1 0 r
.21338 .48164 m
.21328 .48339 L
s
0 g
.015 w
.38181 .43863 m
.38603 .44911 L
s
.5255 .31948 m
.52967 .32598 L
s
0 1 0 r
.5 Mabswid
.21328 .48339 m
.21317 .48514 L
s
0 g
.65293 .30596 m
.66172 .30761 L
s
.015 w
.37759 .42807 m
.38181 .43863 L
s
0 1 0 r
.5 Mabswid
.21317 .48514 m
.21306 .4869 L
s
0 g
.015 w
.37336 .41749 m
.37759 .42807 L
s
0 1 0 r
.5 Mabswid
.21306 .4869 m
.21295 .48865 L
s
0 g
.64413 .3043 m
.65293 .30596 L
s
.015 w
.52133 .31319 m
.5255 .31948 L
s
0 1 0 r
.5 Mabswid
.21295 .48865 m
.21284 .49041 L
s
0 g
.015 w
.36913 .40697 m
.37336 .41749 L
s
.5 Mabswid
.63532 .30264 m
.64413 .3043 L
s
.015 w
.2123 .49921 m
.217 .50335 L
s
0 1 0 r
.5 Mabswid
.21284 .49041 m
.21273 .49217 L
s
0 g
.015 w
.36489 .39655 m
.36913 .40697 L
s
0 1 0 r
.5 Mabswid
.21273 .49217 m
.21263 .49393 L
s
0 g
.6265 .30098 m
.63532 .30264 L
s
0 1 0 r
.21263 .49393 m
.21252 .49569 L
s
0 g
.015 w
.36064 .3863 m
.36489 .39655 L
s
.51714 .30708 m
.52133 .31319 L
s
0 1 0 r
.5 Mabswid
.21252 .49569 m
.21241 .49745 L
s
0 g
.61767 .29931 m
.6265 .30098 L
s
.015 w
.35638 .37625 m
.36064 .3863 L
s
0 1 0 r
.5 Mabswid
.21241 .49745 m
.2123 .49921 L
s
0 g
.60883 .29765 m
.61767 .29931 L
s
.015 w
.20763 .4943 m
.2123 .49921 L
s
.35211 .36646 m
.35638 .37625 L
s
.5 Mabswid
.59998 .29598 m
.60883 .29765 L
s
.015 w
.51294 .30115 m
.51714 .30708 L
s
.34782 .35694 m
.35211 .36646 L
s
.5 Mabswid
.59112 .29431 m
.59998 .29598 L
s
.015 w
.34351 .34771 m
.34782 .35694 L
s
.203 .48861 m
.20763 .4943 L
s
.5 Mabswid
.58226 .29264 m
.59112 .29431 L
s
.015 w
.50873 .29536 m
.51294 .30115 L
s
.5 Mabswid
.57338 .29096 m
.58226 .29264 L
s
.015 w
.33918 .33879 m
.34351 .34771 L
s
.5 Mabswid
.56449 .28929 m
.57338 .29096 L
s
.015 w
.19841 .48218 m
.203 .48861 L
s
.33483 .33018 m
.33918 .33879 L
s
.5 Mabswid
.5556 .28761 m
.56449 .28929 L
s
.015 w
.5045 .2897 m
.50873 .29536 L
s
.5 Mabswid
.54669 .28593 m
.5556 .28761 L
s
.015 w
.33046 .32189 m
.33483 .33018 L
s
.19384 .47502 m
.19841 .48218 L
s
.5 Mabswid
.53777 .28425 m
.54669 .28593 L
s
.015 w
.32607 .31391 m
.33046 .32189 L
s
.5 Mabswid
.52885 .28257 m
.53777 .28425 L
s
.015 w
.50026 .28415 m
.5045 .2897 L
s
.18932 .46719 m
.19384 .47502 L
s
.5 Mabswid
.51991 .28089 m
.52885 .28257 L
s
.015 w
.32166 .30623 m
.32607 .31391 L
s
.5 Mabswid
.51096 .2792 m
.51991 .28089 L
s
.015 w
.18482 .45874 m
.18932 .46719 L
s
.49601 .27869 m
.50026 .28415 L
s
.5 Mabswid
.50201 .27751 m
.51096 .2792 L
s
.015 w
.31723 .29884 m
.32166 .30623 L
s
.5 Mabswid
.49304 .27582 m
.50201 .27751 L
s
.015 w
.18035 .44973 m
.18482 .45874 L
s
.5 Mabswid
.48407 .27413 m
.49304 .27582 L
s
.015 w
.31277 .29172 m
.31723 .29884 L
s
.17591 .44025 m
.18035 .44973 L
s
.5 Mabswid
.47508 .27244 m
.48407 .27413 L
s
.015 w
.17149 .43035 m
.17591 .44025 L
s
.5 Mabswid
.46609 .27074 m
.47508 .27244 L
s
.015 w
.30829 .28484 m
.31277 .29172 L
s
.16709 .42013 m
.17149 .43035 L
s
.5 Mabswid
.45708 .26904 m
.46609 .27074 L
s
.015 w
.1627 .40965 m
.16709 .42013 L
s
.5 Mabswid
.44806 .26735 m
.45708 .26904 L
s
.015 w
.15831 .39902 m
.1627 .40965 L
s
.30378 .2782 m
.30829 .28484 L
s
.5 Mabswid
.43904 .26564 m
.44806 .26735 L
s
.015 w
.15393 .38829 m
.15831 .39902 L
s
.5 Mabswid
.43 .26394 m
.43904 .26564 L
s
.015 w
.14955 .37755 m
.15393 .38829 L
s
.5 Mabswid
.42096 .26224 m
.43 .26394 L
s
.015 w
.29926 .27177 m
.30378 .2782 L
s
.14515 .36686 m
.14955 .37755 L
s
.5 Mabswid
.4119 .26053 m
.42096 .26224 L
s
.015 w
.14074 .35628 m
.14515 .36686 L
s
.5 Mabswid
.40284 .25882 m
.4119 .26053 L
s
.015 w
.13632 .34587 m
.14074 .35628 L
s
.29471 .26553 m
.29926 .27177 L
s
.5 Mabswid
.39376 .25711 m
.40284 .25882 L
s
.015 w
.13187 .33567 m
.13632 .34587 L
s
.5 Mabswid
.38468 .2554 m
.39376 .25711 L
s
.015 w
.1274 .32571 m
.13187 .33567 L
s
.5 Mabswid
.37558 .25368 m
.38468 .2554 L
s
.015 w
.29014 .25945 m
.29471 .26553 L
s
.12289 .31603 m
.1274 .32571 L
s
.5 Mabswid
.36648 .25197 m
.37558 .25368 L
s
.015 w
.11836 .30664 m
.12289 .31603 L
s
.5 Mabswid
.35736 .25025 m
.36648 .25197 L
s
.015 w
.28555 .25352 m
.29014 .25945 L
s
.11379 .29757 m
.11836 .30664 L
s
.5 Mabswid
.34823 .24853 m
.35736 .25025 L
s
.3391 .24681 m
.34823 .24853 L
s
.015 w
.10919 .28881 m
.11379 .29757 L
s
.5 Mabswid
.32995 .24508 m
.3391 .24681 L
s
.015 w
.28094 .24773 m
.28555 .25352 L
s
.10454 .28037 m
.10919 .28881 L
s
.5 Mabswid
.32079 .24336 m
.32995 .24508 L
s
.31163 .24163 m
.32079 .24336 L
s
.015 w
.09987 .27224 m
.10454 .28037 L
s
.27631 .24204 m
.28094 .24773 L
s
.5 Mabswid
.30245 .2399 m
.31163 .24163 L
s
.29326 .23817 m
.30245 .2399 L
s
.015 w
.09515 .26441 m
.09987 .27224 L
s
.5 Mabswid
.28407 .23644 m
.29326 .23817 L
s
.015 w
.27166 .23644 m
.27631 .24204 L
s
.5 Mabswid
.27486 .2347 m
.28407 .23644 L
s
.015 w
.0904 .25686 m
.09515 .26441 L
s
.5 Mabswid
.26564 .23296 m
.27486 .2347 L
s
.25641 .23122 m
.26564 .23296 L
s
.015 w
.08561 .24959 m
.0904 .25686 L
s
.5 Mabswid
.24717 .22948 m
.25641 .23122 L
s
.23792 .22774 m
.24717 .22948 L
s
.015 w
.08079 .24257 m
.08561 .24959 L
s
.5 Mabswid
.22866 .22599 m
.23792 .22774 L
s
.21939 .22425 m
.22866 .22599 L
s
.015 w
.07593 .23578 m
.08079 .24257 L
s
.5 Mabswid
.21011 .2225 m
.21939 .22425 L
s
.20082 .22075 m
.21011 .2225 L
s
.015 w
.07104 .22921 m
.07593 .23578 L
s
.5 Mabswid
.19152 .21899 m
.20082 .22075 L
s
.18221 .21724 m
.19152 .21899 L
s
.17289 .21548 m
.18221 .21724 L
s
.015 w
.06611 .22282 m
.07104 .22921 L
s
.5 Mabswid
.16356 .21372 m
.17289 .21548 L
s
.15421 .21196 m
.16356 .21372 L
s
.015 w
.06116 .2166 m
.06611 .22282 L
s
.5 Mabswid
.14486 .2102 m
.15421 .21196 L
s
.1355 .20843 m
.14486 .2102 L
s
.12612 .20667 m
.1355 .20843 L
s
.015 w
.05617 .21052 m
.06116 .2166 L
s
.5 Mabswid
.11674 .2049 m
.12612 .20667 L
s
.10734 .20313 m
.11674 .2049 L
s
.015 w
.05115 .20458 m
.05617 .21052 L
s
.5 Mabswid
.09794 .20136 m
.10734 .20313 L
s
.08852 .19958 m
.09794 .20136 L
s
.07909 .1978 m
.08852 .19958 L
s
.015 w
.04611 .19875 m
.05115 .20458 L
s
.5 Mabswid
.06965 .19602 m
.07909 .1978 L
s
.0602 .19424 m
.06965 .19602 L
s
.05074 .19246 m
.0602 .19424 L
s
.015 w
.04104 .19301 m
.04611 .19875 L
s
.5 Mabswid
.04127 .19068 m
.05074 .19246 L
s
.25 Mabswid
.47602 0 m
.98951 .64108 L
s
.98951 .64108 m
1 .76863 L
s
1 .76863 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.01448 .17452 m
0 .31187 L
s
0 .31187 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.47602 0 m
.01448 .17452 L
s
.01448 .17452 m
.47602 0 L
s
gsave
.18494 .02919 -70.4794 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{383, 337.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007N0001YB000`400?l00000o`00003ooooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooolG
ooooo`;o0000a_ooool00:7ooooo00GoV9RHo`000?l0003oA4A4okZj^P1]ooooo`?o000000?ooooo
o`000?ooool0aOooool00:7ooooo00Go410@okZj^_o^k^koMgMgoa0@401Zooooo`?o00001?ooool2
o`000<Gooooo002Qooooo`03o`000?oooooooooo06[ooooo0_l00007ooooo`03o`000?oooooo0000
0<Cooooo002Qooooo`03o`000?oooooooooo06Oooooo0ol00009ooooo`04o`000?ooooooooooo`00
0<?ooooo002Qooooo`03o`000?oooooooooo06Cooooo0ol0000<ooooo`05o`000?oooooooooooooo
ool00000`_ooool009oooooo00?o410@o`000?l000000ol0001Qooooo`;o00003oooool01Ol0003o
oooooooooooooooo00000<;ooooo002Qooooo`03o`000?oooooooooo05oooooo0ol0000Aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0_oooool00:7ooooo00?o0000ooooooooool0
G?ooool3o`0001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2nooooo`00o_oo
ool2o`0001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2mooooo`00noooool3
o`0001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2looooo`00nOooool2o`00
01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2looooo`00m_ooool3o`0001ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2kooooo`00loooool3o`00027ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2jooooo`00lOooool2o`0002Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2iooooo`00k_ooool3o`0002Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2hooooo`00joooool3o`0002Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2hooooo`00jOooool2o`0002cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`2gooooo`00i_ooool3o`0002kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2fooooo`00hoooool3o`00037ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`2eooooo`00hOooool2o`0003Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2dooooo`00g_ooool3o`0003Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2dooooo`00foooool3o`0003Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2cooooo`00fOooool2o`0003cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`00e_ooool3o`0003kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`2aooooo`00doooool3o`00047ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2`
ooooo`00dOooool2o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2`oooo
o`00c_ooool3o`0004Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2_ooooo`00
boooool3o`0004Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2^ooooo`00bOoo
ool2o`0004_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2]ooooo`00a_ooool3
o`0004gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2/ooooo`00`oooool3o`00
053ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2/ooooo`00`Oooool2o`0005?o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2[ooooo`00__ooool3o`0005Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`2Zooooo`00_?ooool2o`0005Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Yooooo`00^Oooool3o`0005[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`2Xooooo`00]_ooool3o`0005gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2Xooooo`00]?ooool2o`00063ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`2Wooooo`00/Oooool3o`0006;ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`2Vooooo`00[_ooool3o`0006Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`2Uooooo`00[?ooool2o`0006Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2Tooooo`00ZOooool3o`0006[ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`2Tooooo`00Y_ooool3o`0006gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`2Sooooo`00Y?ooool2o`00073ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`2Rooooo`00XOooool3o`0007;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`2Qooooo`00W_ooool3o`0007Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2P
ooooo`00W?ooool2o`0007Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Poooo
o`00VOooool3o`0007[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Oooooo`00
U_ooool3o`0007gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Nooooo`00U?oo
ool2o`00083ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2Mooooo`00TOooool3
o`0008;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Looooo`00S_ooool3o`00
08Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Looooo`00S?ooool2o`0008So
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Kooooo`00ROooool3o`0008Wooooo
0_l0000Zooooo`03o`000?oooooooooo09[ooooo0026ooooo`?o0000ROooool3o`000003ooooool0
003ooooo02[ooooo00?o0000ooooooooool0VOooool008Cooooo0_l00029ooooo`?o00001Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09Sooooo0021ooooo`?o0000R?ooool3o`00
00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2Hooooo`00Ooooool2o`0008Wo
oooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Uoooool007cooooo
0ol00028ooooo`?o00004?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09Kooooo
001iooooo`?o0000R?ooool3o`0001Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`2Eooooo`00Moooool2o`0008Wooooo0_l0000Gooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0U?ooool007Cooooo0ol00028ooooo`?o00006_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo09Cooooo001aooooo`?o0000R?ooool3o`0001kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`2Cooooo`00Koooool2o`0008Sooooo0ol0000Rooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0T_ooool006cooooo0ol00028ooooo`;o00009_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo097ooooo001Yooooo`?o0000R?ooool3
o`0002Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Aooooo`00J?ooool00ol0
003oooooooooo`26ooooo`?o0000;?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
093ooooo001Xooooo`03o`000?oooooooooo08?ooooo0ol0000`ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0Soooool006Sooooo0_l00022ooooo`;o0000=?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo08kooooo001Xooooo`03o`000?oooooo000007kooooo0ol0
000gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0SOooool006Sooooo00Co0000
oooooooooooo0000N_ooool3o`0003_ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`2=ooooo`00Ioooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Go0000Kooo
ool2o`0003oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2<ooooo`00Ioooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go0000K?ooool3o`00047ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`2;ooooo`00Ioooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000Oo0000I_ooool3o`0004Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`2:ooooo`00Ioooool00ol0003oooooooooo`05ooooo`So000000?oooooo`000?l0
00000_l0001Oooooo`?o0000BOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Wo
oooo001Wooooo`03o`000?oooooooooo00Kooooo1ol00005ooooo`Oo0000E_ooool2o`0004gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`29ooooo`00Ioooool00ol0003ooooooooo
o`06ooooo`So00002oooool4o`0004oooooo0ol0001@ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0R?ooool006Oooooo00?o0000ooooooooool01oooool8o`0000kooooo1ol00015
ooooo`?o0000E?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08Oooooo001Woooo
o`03o`000?oooooooooo00Sooooo2?l0000Dooooo`?o0000?oooool3o`0005Oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`26ooooo`00Ioooool00ol0003oooooooooo`08ooooo`Wo
00005_ooool7o`0003Kooooo0_l0001Kooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0QOooool006Kooooo00?o0000ooooooooool02_ooool9o`0001cooooo1?l0000_ooooo`?o0000
G_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08Gooooo001Vooooo`03o`000?oo
oooooooo00_ooooo2?l0000Pooooo`Oo00009Oooool3o`0006;ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`24ooooo`00I_ooool00ol0003oooooooooo`0<ooooo`So00009_ooool4
o`0001oooooo0_l0001Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Poooool0
06Kooooo00?o0000ooooooooool03Oooool8o`0002Wooooo1ol0000Eooooo`?o0000JOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo08;ooooo001Vooooo`03o`000?oooooooooo00ko
oooo2?l0000_ooooo`?o00003oooool3o`0006cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`21ooooo`00I_ooool00ol0003oooooooooo`0>ooooo`Wo0000<Oooool7o`0000Gooooo
0ol0001`ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0POooool006Kooooo00?o
0000ooooooooool03oooool8o`0003Sooooo1Ol0001dooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0P?ooool006Kooooo00?o0000ooooooooool04?ooool8o`0003Oooooo0ol00000
0ooooooo0000o`000005o`0006oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1o
ooooo`00I_ooool00ol0003oooooooooo`0Aooooo`So0000<oooool3o`0000_ooooo0ol000000ooo
oooo0000o`000003o`0006Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1noooo
o`00IOooool00ol0003oooooooooo`0Cooooo`So0000;oooool3o`00017ooooo1ol0001Wooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0OOooool006Gooooo00?o0000ooooooooool0
4oooool9o`0002cooooo0_l0000Eooooo`[o0000Hoooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo07gooooo001Uooooo`03o`000?oooooooooo01Cooooo2?l0000Yooooo`?o00005ooo
ool8o`0000;ooooo1ol0001Mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0O?oo
ool006Gooooo00?o0000ooooooooool05Oooool8o`0002Gooooo0ol0000Jooooo`Wo00002?ooool3
o`0005_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1kooooo`00IOooool00ol0
003oooooooooo`0Fooooo`So00008_ooool2o`0001kooooo2?l0000;ooooo`Oo0000EOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo001Uooooo`03o`000?oooooooooo01Oo
oooo1ol0000Oooooo`?o00008Oooool8o`00017ooooo1ol0001?ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0NOooool006Gooooo00?o0000ooooooooool05oooool8o`0001_ooooo
0ol0000Uooooo`Oo00006?ooool4o`0004cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1iooooo`00IOooool00ol0003oooooooooo`0Hooooo`Oo00006?ooool3o`0002Wooooo1ol0
000Kooooo`Ko0000A_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Sooooo001U
ooooo`03o`000?oooooooooo01Wooooo1_l0000Fooooo`;o0000;?ooool8o`00023ooooo1?l00013
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Moooool006Cooooo00?o0000oooo
ooooool06_ooool7o`0001;ooooo0ol0000_ooooo`So00008oooool7o`0003gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1fooooo`00I?ooool00ol0003oooooooooo`0Kooooo`Oo
00003_ooool3o`0003;ooooo2Ol0000Yooooo`?o0000>oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo07Gooooo001Tooooo`03o`000?oooooooooo01_ooooo2?l0000:ooooo`?o0000
=_ooool9o`0002_ooooo1ol0000eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
MOooool000oooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`0Rooooo`03o`000?oo
oooooooo01_ooooo2Ol00007ooooo`;o0000>_ooool9o`00037ooooo1?l0000booooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0M?ooool000kooooo00?ogMgMoa0@4?o^k^h0;_ooool0
0oo^k^ko410@omgMg@0Rooooo`03o`000?oooooooooo01cooooo2Ol00003ooooo`?o0000?Oooool8
o`0003Gooooo1_l0000/ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Loooool0
00?ooooo00?o410@o`000?l000000_l000000ol@413oooooooooo`03ooooo`04oeEEEOnHV9Sooooo
ooooo`;o00000_ooool2o`0001;ooooo00GoIVIVo`000?l0003oA4A4olc<c00:ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00_ooool00on7QhOoIVIVooooo`0Qooooo`03o`000?oooooooooo01gooooo
2ol00011ooooo`So0000>_ooool4o`0002Wooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`1booooo`001Oooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMgA7ooooo00KoIVIVogMgMoooooooooooohN7Qol@410:ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41000_ooool00oo^k^ko0000ooooo`0Qooooo`03o`000?oooooooooo01ko
oooo1ol000000ooooooo0000ooooo`12ooooo`Oo0000?_ooool;o`0001oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1aooooo`001Oooool00ol0003oooooooooo`06ooooo`03oc8b
<_oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<0oooool6o`0000Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07oooool7o`000003ooooool0003ooooo04;ooooo1ol00013ooooo`Oo00007_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo077ooooo0005ooooo`03o`000?oooooooooo00Kooooo
00?o<S8booooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01go
oooo2Ol00002ooooo`03o`000?oooooooooo043ooooo2?l00012ooooo`_o00006oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo073ooooo0005ooooo`03o`000?oooooooooo00Kooooo
00?o0000onk^k_ooool00_ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`06ofIVI_mgMgOooooooooo
oon7QhOo00002_ooool00ol0003oooooooooo`04ooooo`03onk^k_l0003ooooo023ooooo00?o0000
ooooooooool06oooool3o`0000?ooooo1ol00002ooooo`03o`000?oooooooooo043ooooo1ol00012
ooooo`Oo00001?ooool7o`0001Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1_
ooooo`000oooool00ol@413o0000o`000003o`0000Gooooo00CoEEEEogMgMooooooooooo0_l00002
ooooo`;o00004Oooool01_o^k^koIVIVo`000?l0003oA4A4o`0000Sooooo00?o410@o`000?l00000
0ol00003ooooo`03ogMgMomEEEGooooo023ooooo00?o0000ooooooooool06Oooool2o`0000Kooooo
1ol00003ooooo`03o`000?oooooooooo03oooooo2?l00011ooooo`So00002_ooool3o`0001;ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1^ooooo`001Oooool00ol0003ooooooooo
o`06ooooo`03omgMgOl@413ok^k^02Sooooo00?o0000ooooooooool00oooool00oo^k^ko410@omgM
g@0Qooooo`03o`000?oooooooooo01Kooooo0ol00009ooooo`Ko00001?ooool00ol0003ooooooooo
o`0oooooo`So0000@Oooool8o`0000cooooo1ol0000<ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0KOooool000Gooooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0W
ooooo`03o`000?oooooooooo00?ooooo00?oIVIVogMgMoooool08Oooool00ol0003oooooooooo`0C
ooooo`?o00003?ooool7o`0000Cooooo00?o0000ooooooooool0?oooool7o`0004;ooooo2?l0000B
ooooo`?o00002_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06gooooo0005oooo
o`04okZj^_l@413o0000oa0@45[ooooo00?o0000ooooooooool04?ooool3o`00013ooooo1ol00004
ooooo`03o`000?oooooooooo03kooooo2?l00011ooooo`Wo00005?ooool7o`0000Cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1/ooooo`00Hoooool00ol0003oooooooooo`0>oooo
o`;o00004oooool7o`0000Gooooo00?o0000ooooooooool0?_ooool7o`0004;ooooo2Ol0000Joooo
o`Oo00009oooool00ol0003oooooooooo`1[ooooo`00Hoooool00ol0003oooooooooo`0;ooooo`?o
00005Oooool8o`0000Gooooo00?o0000ooooooooool0?_ooool7o`0004;ooooo2?l0000Pooooo`Co
00009Oooool00ol0003oooooooooo`1Zooooo`00Hoooool00ol0003oooooooooo`08ooooo`?o0000
6Oooool7o`0000Kooooo00?o0000ooooooooool0?Oooool8o`0004;ooooo2?l0000Oooooo`04o`00
0?ooooooooooooooo`Oo00007oooool00ol0003oooooooooo`1Yooooo`00Hoooool00ol0003ooooo
ooooo`06ooooo`;o00007Oooool7o`0000Kooooo00?o0000ooooooooool0?Oooool7o`0004?ooooo
1ol0000Pooooo`03o`000?oooooooooo00Oooooo0ol0000Looooo`03o`000?oooooooooo06Wooooo
001Rooooo`03o`000?oooooooooo00Cooooo0ol0000Oooooo`Oo00001oooool00ol0003ooooooooo
o`0looooo`So0000@oooool7o`00023ooooo00?o0000ooooooooool02Oooool7o`0001Kooooo00?o
0000ooooooooool0J?ooool006;ooooo00Co0000oooooooooooooooo0ol0000Sooooo`Oo00001ooo
ool00ol0003oooooooooo`0looooo`So0000@_ooool8o`00023ooooo00?o0000ooooooooool03ooo
ool3o`0001Cooooo00?o0000ooooooooool0Ioooool006;ooooo1?l0000Vooooo`So00001oooool0
0ol0003oooooooooo`0looooo`Oo0000@oooool7o`00027ooooo00?o0000ooooooooool04Oooool7
o`0000kooooo00?o0000ooooooooool0I_ooool006;ooooo0_l0000Yooooo`Oo00002?ooool00ol0
003oooooooooo`0kooooo`So0000@_ooool8o`00027ooooo00?o0000ooooooooool05oooool6o`00
00Wooooo00?o0000ooooooooool0IOooool006Cooooo00?o0000ooooooooool09_ooool7o`0000Wo
oooo00?o0000ooooooooool0>oooool7o`0004?ooooo1ol0000Qooooo`03o`000?oooooooooo01go
oooo1ol00002ooooo`03o`000?oooooooooo02[ooooo0_l00002ooooo`;o0000=Oooool006Gooooo
00?o0000ooooooooool09_ooool7o`0000Wooooo00?o0000ooooooooool0>oooool6o`0004Cooooo
1ol0000Qooooo`03o`000?oooooooooo01kooooo1Ol00003ooooo`03o`000?oooooooooo02Wooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdeooooo`00I_ooool00ol0003oooooooooo`0Vooooo`Ko
00002_ooool00ol0003oooooooooo`0jooooo`Oo0000@oooool8o`00027ooooo00?o0000oooooooo
ool07Oooool6o`0000?ooooo00?o0000ooooooooool0:Oooool01?oMgMgo0000oa0@4?o<c<`foooo
o`00Ioooool00ol0003oooooooooo`0Uooooo`Ko00002oooool00ol0003oooooooooo`0jooooo`Oo
0000@oooool7o`0002;ooooo00?o0000ooooooooool07?ooool7o`0000?ooooo00?o0000oooooooo
ool0:?ooool01?o^k^ko8B4Qoa0@4?o^k^hfooooo`00J?ooool00ol0003oooooooooo`0Tooooo`Oo
00002oooool00ol0003oooooooooo`0iooooo`Oo0000@oooool8o`0002;ooooo00?o0000oooooooo
ool06oooool8o`0000?ooooo00?o0000ooooooooool09oooool01?lQ8B7oMgMgogMgMolb<S8foooo
o`00JOooool00ol0003oooooooooo`0Tooooo`Ko00003?ooool00ol0003oooooooooo`0hooooo`So
0000@oooool7o`0002?ooooo00?o0000ooooooooool06_ooool8o`0000?ooooo00?o0000oooooooo
ool09_ooool2o`0000;ooooo0_l0000eooooo`00J_ooool00ol0003oooooooooo`0Sooooo`Oo0000
3?ooool00ol0003oooooooooo`0hooooo`Oo0000A?ooool7o`0002;ooooo00?o0000ooooooooool0
6oooool8o`0000?ooooo00?o0000ooooooooool0H?ooool006_ooooo00?o0000ooooooooool08_oo
ool7o`0000gooooo00?o0000ooooooooool0>?ooool7o`0004?ooooo2?l0000Rooooo`03o`000?oo
oooooooo01_ooooo2?l00003ooooo`03o`000?oooooooooo05oooooo001/ooooo`03o`000?oooooo
oooo02;ooooo1ol0000=ooooo`03o`000?oooooooooo03Oooooo1ol00014ooooo`Oo00008oooool0
0ol0003oooooooooo`0Kooooo`So00000oooool00ol0003oooooooooo`1Nooooo`00KOooool00ol0
003oooooooooo`0Qooooo`So00003Oooool00ol0003oooooooooo`0gooooo`Oo0000@oooool8o`00
02?ooooo00?o0000ooooooooool06_ooool8o`0000Cooooo00?o0000ooooooooool0GOooool006ko
oooo00?o0000ooooooooool08Oooool7o`0000kooooo00?o0000ooooooooool0=_ooool7o`0004Co
oooo2?l0000Sooooo`03o`000?oooooooooo01[ooooo2?l00003ooooo`03o`000?oooooooooo05go
oooo001_ooooo`03o`000?oooooooooo023ooooo1ol0000?ooooo`03o`000?oooooooooo03Kooooo
1_l00015ooooo`Oo00009?ooool00ol0003oooooooooo`0Jooooo`So00000oooool00ol0003ooooo
ooooo`1Looooo`00L?ooool00ol0003oooooooooo`0Pooooo`Oo00003oooool00ol0003ooooooooo
o`0eooooo`Oo0000A?ooool8o`0002?ooooo00?o0000ooooooooool06oooool8o`0000?ooooo00?o
0000ooooooooool0Foooool0077ooooo00?o0000ooooooooool08?ooool6o`00013ooooo00?o0000
ooooooooool0=Oooool6o`0004Gooooo1ol0000Tooooo`03o`000?oooooooooo01[ooooo2?l00004
ooooo`03o`000?oooooooooo05[ooooo001booooo`03o`000?oooooooooo01oooooo1_l0000Aoooo
o`03o`000?oooooooooo03Cooooo1ol00015ooooo`Ko00009Oooool00ol0003oooooooooo`0Joooo
o`So00001?ooool00ol0003oooooooooo`1Iooooo`00Loooool00ol0003oooooooooo`0Nooooo`Oo
00004Oooool00ol0003oooooooooo`0cooooo`Oo0000AOooool7o`0002Gooooo00?o0000oooooooo
ool06_ooool7o`0000Cooooo00?o0000ooooooooool0FOooool007Cooooo00?o0000ooooooooool0
7_ooool6o`0001;ooooo00?o0000ooooooooool0<oooool7o`0004Gooooo1ol0000Uooooo`03o`00
0?oooooooooo01[ooooo1ol00004ooooo`03o`000?oooooooooo05Sooooo001eooooo`03o`000?oo
oooooooo01gooooo1ol0000Booooo`03o`000?oooooooooo03;ooooo2?l00014ooooo`Oo00009_oo
ool00ol0003oooooooooo`0Iooooo`So00001?ooool00ol0003oooooooooo`1Gooooo`00M_ooool0
0ol0003oooooooooo`0Looooo`Oo00004oooool00ol0003oooooooooo`0booooo`Oo0000A?ooool8
o`0002Gooooo00?o0000ooooooooool06_ooool7o`0000Gooooo00?o0000ooooooooool0E_ooool0
07Oooooo00?o0000ooooooooool07?ooool7o`0001?ooooo00?o0000ooooooooool0<Oooool7o`00
04Gooooo1ol0000Vooooo`03o`000?oooooooooo01Wooooo2?l00005ooooo`03o`000?oooooooooo
05Gooooo001hooooo`;o00007?ooool7o`0001Cooooo00?o0000ooooooooool0<Oooool7o`0004Go
oooo1_l0000Wooooo`03o`000?oooooooooo01Wooooo1ol00005ooooo`03o`000?oooooooooo05Go
oooo001jooooo`03o`000?oooooooooo01[ooooo1ol0000Cooooo`03o`000?oooooooooo00;ooooo
00?o0?l0o`000?l00000;Oooool6o`0004Gooooo1ol0000Wooooo`03o`000?oooooooooo01Wooooo
1ol00005ooooo`03o`000?oooooooooo05Cooooo001kooooo`03o`000?oooooooooo01Wooooo1ol0
000Dooooo`05o`000?ooooooooooooooool0o`000_ooool6o`0002Oooooo1_l00016ooooo`Oo0000
9oooool00ol0003oooooooooo`0Hooooo`So00001Oooool00ol0003oooooooooo`1Cooooo`00O?oo
ool00ol0003oooooooooo`0Iooooo`Ko00005Oooool00ol0003oooooo`3o0009ooooo`Co00008ooo
ool7o`0004Gooooo1ol0000Xooooo`03o`000?oooooooooo01Sooooo1ol00006ooooo`03o`000?oo
oooooooo05;ooooo001mooooo`03o`000?oooooooooo01Sooooo1ol0000Eooooo`03o`000?l0o`3o
oooo00cooooo1_l0000Nooooo`Ko0000AOooool8o`0002Oooooo00?o0000ooooooooool06?ooool8
o`0000Kooooo00?o0000ooooooooool0DOooool007kooooo00?o0000ooooooooool06?ooool6o`00
01Kooooo00?o0?l0ooooooooool04Oooool7o`0001Oooooo1ol00015ooooo`Oo0000:?ooool00ol0
003oooooooooo`0Hooooo`Oo00001_ooool00ol0003oooooooooo`1Aooooo`00Ooooool00ol0003o
ooooooooo`0Gooooo`Ko00005_ooool00ol0o`3o0000ooooo`0Hooooo`?o00005?ooool7o`0004Ko
oooo1_l0000Yooooo`03o`000?oooooooooo01Sooooo1_l00007ooooo`03o`000?oooooooooo053o
oooo0020ooooo`03o`000?oooooooooo01Kooooo1ol0000Eooooo`03o`3o0?oooooo000001_ooooo
1ol0000>ooooo`Ko0000A_ooool7o`0002Wooooo00?o0000ooooooooool05oooool7o`0000Oooooo
00?o0000ooooooooool0Coooool0087ooooo00?o0000ooooooooool05_ooool6o`0001Gooooo00Co
0?l0oooooooooooo00008Oooool6o`0000Sooooo1ol00016ooooo`Ko0000:_ooool00ol0003ooooo
ooooo`0Gooooo`Ko00002?ooool00ol0003oooooooooo`1>ooooo`00P_ooool00ol0003ooooooooo
o`0Eooooo`Ko00005Oooool01Ol0o`3ooooooooooooooooo000002Kooooo1?l00005ooooo`Ko0000
A_ooool7o`0002[ooooo00?o0000ooooooooool05_ooool6o`0000Wooooo00?o0000ooooooooool0
COooool008?ooooo00?o0000ooooooooool05?ooool7o`0001Cooooo00?o0?l0ooooooooool00_oo
ool00ol0003oooooooooo`0Wooooo`_o0000A_ooool7o`0002[ooooo00?o0000ooooooooool05_oo
ool7o`0000Sooooo00?o0000ooooooooool0COooool008Cooooo00?o0000ooooooooool05?ooool6
o`0001Cooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`0[ooooo`So0000AOooool7
o`0002[ooooo00?o0000ooooooooool05_ooool7o`0000Sooooo00?o0000ooooooooool0C?ooool0
08Gooooo00?o0000ooooooooool04oooool7o`0001?ooooo00?o0?l0ooooooooool01?ooool00ol0
003oooooooooo`0[ooooo`Ko000000Coooooo`000?l0003o0000@_ooool8o`0002[ooooo00?o0000
ooooooooool05Oooool7o`0000Wooooo00?o0000ooooooooool0Boooool008Kooooo00?o0000oooo
ooooool04_ooool7o`0001?ooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`0Zoooo
o`Oo00000oooool7o`0003cooooo1ol0000[ooooo`03o`000?oooooooooo01Cooooo2?l00009oooo
o`03o`000?oooooooooo04[ooooo0027ooooo`03o`000?oooooooooo01;ooooo1ol0000Booooo`03
o`3o0?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool7o`0000[ooooo1_l0000fooooo`Oo
0000;?ooool00ol0003oooooooooo`0Dooooo`Oo00002_ooool00ol0003oooooooooo`19ooooo`00
R?ooool00ol0003oooooooooo`0Aooooo`Oo00004_ooool00ol0o`3oooooooooo`07ooooo`03o`00
0?oooooooooo02Wooooo1ol0000?ooooo`Co0000<oooool7o`0002cooooo00?o0000ooooooooool0
5?ooool6o`0000[ooooo00?o0000ooooooooool0BOooool008Wooooo00?o0000ooooooooool04Ooo
ool6o`0001;ooooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`Oo00004ooo
ool2o`000004o`3o0?l0003o0000o`0002kooooo1_l0000/ooooo`03o`000?oooooooooo01Cooooo
1ol0000:ooooo`03o`000?oooooooooo04Sooooo002:ooooo`03o`000?oooooooooo013ooooo1ol0
000Aooooo`03o`3o0?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool7o`0001Cooooo00Co
0?l0oooooooooooooooo1ol0000Wooooo`Ko0000;Oooool00ol0003oooooooooo`0Dooooo`Oo0000
2_ooool00ol0003oooooooooo`17ooooo`00Roooool00ol0003oooooooooo`0@ooooo`Ko00004Ooo
ool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo1ol0000Dooooo`03o`3o0?oo
oooooooo00Sooooo1_l0000Qooooo`Oo0000;Oooool00ol0003oooooooooo`0Cooooo`Oo00002ooo
ool00ol0003oooooooooo`16ooooo`00S?ooool00ol0003oooooooooo`0?ooooo`Ko00004?ooool0
0ol0o`3oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo1_l0000Dooooo`03o`3o0?oooooo
oooo00kooooo0ol0000Oooooo`Ko0000;_ooool00ol0003oooooooooo`0Booooo`So00002oooool0
0ol0003oooooooooo`15ooooo`00SOooool00ol0003oooooooooo`0>ooooo`Oo00003oooool00ol0
o`3oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo1ol0000Cooooo`03o`3o0?oooooooooo
017ooooo1ol0000Hooooo`Oo0000;_ooool00ol0003oooooooooo`0Booooo`Oo00002oooool00ol0
003oooooooooo`15ooooo`00S_ooool00ol0003oooooooooo`0>ooooo`Oo00003_ooool00ol0o`3o
ooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo1_l0000Cooooo`03o`3o0?oooooooooo01So
oooo1_l0000Booooo`Oo0000;oooool00ol0003oooooooooo`0Booooo`Ko00003?ooool00ol0003o
ooooooooo`14ooooo`00Soooool2o`0000kooooo1ol0000>ooooo`03o`3o0?oooooooooo00oooooo
00?o0000ooooooooool09Oooool6o`0001?ooooo00?o0?l0ooooooooool07_ooool4o`0000oooooo
1ol0000^ooooo`03o`000?oooooooooo01;ooooo1ol0000<ooooo`03o`000?oooooooooo04?ooooo
002Aooooo`03o`000?oooooooooo00_ooooo2?l0000=ooooo`03o`3o0?oooooooooo013ooooo00?o
0000ooooooooool09?ooool7o`0001;ooooo00?o0?l0ooooooooool08_ooool6o`0000Wooooo1ol0
000_ooooo`03o`000?oooooooooo01;ooooo1ol0000<ooooo`03o`000?oooooooooo04;ooooo002B
ooooo`03o`000?oooooooooo00_ooooo1ol0000=ooooo`03o`3o0?oooooooooo017ooooo00?o0000
ooooooooool09?ooool6o`0001;ooooo00?o0?l0ooooooooool0:?ooool7o`0000?ooooo1_l0000`
ooooo`03o`000?oooooooooo017ooooo1ol0000=ooooo`03o`000?oooooooooo047ooooo002Coooo
o`03o`000?oooooooooo00_ooooo1ol0000<ooooo`03o`3o0?oooooooooo01;ooooo00?o0000oooo
ooooool08oooool7o`00017ooooo00?o0?l0ooooooooool0;oooool:o`00033ooooo00?o0000oooo
ooooool04?ooool7o`0000gooooo00?o0000ooooooooool0@Oooool009Cooooo00?o0000oooooooo
ool02_ooool7o`0000cooooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`0Rooooo`Oo
00004Oooool00ol0o`3oooooooooo`0cooooo`Ko0000<Oooool00ol0003oooooooooo`0@ooooo`Oo
00003Oooool00ol0003oooooooooo`10ooooo`00UOooool00ol0003oooooooooo`0:ooooo`Ko0000
3?ooool00ol0o`3oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo1_l0000Aooooo`03o`3o
0?oooooooooo03?ooooo3?l0000/ooooo`03o`000?oooooooooo013ooooo1_l0000>ooooo`03o`00
0?oooooooooo03oooooo002Fooooo`03o`000?oooooooooo00Wooooo1ol0000;ooooo`03o`3o0?oo
oooooooo01Gooooo00?o0000ooooooooool08Oooool7o`00013ooooo00?o0?l0ooooooooool0<ooo
ool7o`0000Gooooo1_l0000Vooooo`03o`000?oooooooooo013ooooo1_l0000?ooooo`03o`000?oo
oooooooo03kooooo002Gooooo`03o`000?oooooooooo00Wooooo1_l0000;ooooo`03o`3o0?oooooo
oooo01Kooooo00?o0000ooooooooool08Oooool6o`00013ooooo00?o0?l0ooooooooool0=?ooool6
o`0000_ooooo1_l0000Qooooo`03o`000?oooooooooo00oooooo1ol0000?ooooo`03o`000?oooooo
oooo03gooooo002Hooooo`03o`000?oooooooooo00Sooooo1_l0000;ooooo`03o`3o0?oooooooooo
01Oooooo00?o0000ooooooooool08?ooool6o`00013ooooo00?o0?l0ooooooooool0=?ooool7o`00
013ooooo0_l000000ol0o`3o0000ooooo`0Mooooo`03o`000?oooooooooo00oooooo1ol0000>oooo
o`03o`000?oooooooooo03gooooo002Iooooo`03o`000?oooooooooo00Oooooo1ol0000:ooooo`03
o`3o0?oooooooooo01Sooooo00?o0000ooooooooool07oooool7o`0000oooooo00?o0?l0oooooooo
ool0=Oooool6o`0001;ooooo00?o0?l0ooooool000001Ol0000Iooooo`03o`000?oooooooooo00ko
oooo1ol0000?ooooo`03o`000?oooooooooo03cooooo002Jooooo`03o`000?oooooooooo00Oooooo
1ol00009ooooo`03o`3o0?oooooooooo01Wooooo00?o0000ooooooooool07oooool7o`0000kooooo
00?o0?l0ooooooooool0=Oooool6o`0001;ooooo00?o0?l0ooooooooool01Oooool6o`0001Cooooo
00?o0000ooooooooool03Oooool7o`00013ooooo00?o0000ooooooooool0>oooool009_ooooo00?o
0000ooooooooool01_ooool7o`0000Wooooo00?o0?l0ooooooooool06_ooool00ol0003ooooooooo
o`0Nooooo`Oo00003_ooool00ol0o`3oooooooooo`0eooooo`Oo00004Oooool00ol0o`3ooooooooo
o`0;ooooo`Oo00003_ooool00ol0003oooooooooo`0=ooooo`Oo00004?ooool00ol0003ooooooooo
o`0jooooo`00W?ooool00ol0003oooooooooo`05ooooo`So00002?ooool00ol0o`3oooooooooo`0K
ooooo`03o`000?oooooooooo01gooooo2?l0000=ooooo`03o`3o0?oooooooooo03Kooooo1_l0000A
ooooo`03o`3o0?oooooooooo01;ooooo0ol0000;ooooo`03o`000?oooooooooo00kooooo1_l0000A
ooooo`03o`000?oooooooooo03Wooooo002Mooooo`03o`000?oooooooooo00Gooooo2?l00006oooo
o`03o`3o0?oooooooooo01gooooo00?o0000ooooooooool07Oooool7o`0000gooooo00?o0?l0oooo
ooooool0=_ooool7o`00013ooooo00?o0?l0ooooooooool05Oooool6o`0000Kooooo00?o0000oooo
ooooool03Oooool6o`00017ooooo00?o0000ooooooooool0>Oooool009kooooo00?o0000oooooooo
ool01Oooool7o`0000Kooooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`Oo
00003?ooool00ol0o`3oooooooooo`0fooooo`Oo00004?ooool00ol0o`3oooooooooo`0Kooooo`Ko
000000?oooooo`000?ooool03Oooool7o`00017ooooo00?o0000ooooooooool0>?ooool009oooooo
00?o0000ooooooooool01?ooool8o`0000Gooooo00?o0?l0ooooooooool07oooool00ol0003ooooo
ooooo`0Looooo`Oo00003?ooool00ol0o`3oooooooooo`0gooooo`Ko00004?ooool00ol0o`3ooooo
ooooo`0Qooooo`Oo00002_ooool6o`0001;ooooo00?o0000ooooooooool0=oooool00:3ooooo00?o
0000ooooooooool01?ooool8o`0000Cooooo00?o0?l0ooooooooool08?ooool00ol0003ooooooooo
o`0Looooo`Ko00003?ooool00ol0o`3oooooooooo`0gooooo`Oo00003oooool00ol0o`3ooooooooo
o`0Tooooo`04o`000?ooooooooooooooo`Ko00001?ooool7o`0001;ooooo00?o0000ooooooooool0
=_ooool00:7ooooo00?o0000ooooooooool01?ooool7o`0000Cooooo00?o0?l0ooooooooool08Ooo
ool00ol0003oooooooooo`0Kooooo`Oo00002oooool00ol0o`3oooooooooo`0hooooo`Ko00003ooo
ool00ol0o`3oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo0ol000000ooooooo0000o`00
0005o`0001?ooooo00?o0000ooooooooool0=Oooool00:;ooooo00?o0000ooooooooool00oooool8
o`0000?ooooo00?o0?l0ooooooooool08_ooool00ol0003oooooooooo`0Kooooo`Ko00002oooool0
0ol0o`3oooooooooo`0hooooo`Ko00003oooool00ol0o`3oooooooooo`0Uooooo`03o`000?oooooo
oooo00Wooooo2?l0000Cooooo`03o`000?oooooooooo03Gooooo002Sooooo`03o`000?oooooooooo
00?ooooo1ol00003ooooo`03o`3o0?oooooooooo02?ooooo00?o0000ooooooooool06_ooool6o`00
00_ooooo00?o0?l0ooooooooool0>?ooool7o`0000kooooo00?o0?l0ooooooooool09_ooool00ol0
003oooooooooo`0:ooooo`_o00003oooool00ol0003oooooooooo`0dooooo`00Y?ooool00ol0003o
ooooooooo`03ooooo`Ko00000oooool00ol0o`3oooooooooo`0Tooooo`03o`000?oooooooooo01Wo
oooo1ol0000:ooooo`03o`3o0?oooooooooo03Wooooo1_l0000>ooooo`03o`3o0?oooooooooo02Oo
oooo00?o0000ooooooooool02_ooool6o`0000Cooooo1_l0000:ooooo`03o`000?oooooooooo03?o
oooo002Uooooo`;o00000oooool7o`0000;ooooo00?o0?l0ooooooooool09Oooool00ol0003ooooo
ooooo`0Iooooo`Ko00002_ooool00ol0o`3oooooooooo`0iooooo`Oo00003Oooool00ol0o`3ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Wooooo1_l0000:ooooo`?o00002?ooool00ol0003ooooo
ooooo`0booooo`00Yoooool01?l0003oooooooooooooool7o`000003ooooool0o`3ooooo02Oooooo
00?o0000ooooooooool06?ooool7o`0000Wooooo00?o0?l0ooooooooool0>Oooool7o`0000gooooo
00?o0?l0ooooooooool0:Oooool00ol0003oooooooooo`08ooooo`Oo00003?ooool4o`0000Cooooo
00?o0000ooooooooool0<_ooool00:Sooooo00?o0000ooooooooool02?l000000ol0o`3ooooooooo
o`0Wooooo`03o`000?oooooooooo01Oooooo1ol00009ooooo`03o`3o0?oooooooooo03[ooooo1_l0
000=ooooo`03o`3o0?oooooooooo02Wooooo00?o0000ooooooooool02Oooool6o`0000oooooo00?o
0?l0ooooooooool00oooool00ol0003oooooooooo`0aooooo`00ZOooool00ol0003oooooo`000008
o`0002[ooooo00?o0000ooooooooool05oooool7o`0000Sooooo00?o0?l0ooooooooool0>_ooool7
o`0000cooooo00?o0?l0ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`Oo00003_ooool0
0ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo033ooooo002Zooooo`03o`000?oooooo0000
00So0000:_ooool00ol0003oooooooooo`0Fooooo`Oo00001oooool00ol0o`3oooooooooo`0loooo
o`Ko00003?ooool00ol0o`3oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo1ol0000>oooo
o`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool00:_ooooo00?o0000ooooool0
00002?l0000Hoooooa?o00006?ooool6o`0000Oooooo00?o0?l0ooooooooool0??ooool6o`0000co
oooo00?o0?l0ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`Ko00003_ooool00ol0o`3o
ooooooooo`06ooooo`03o`000?oooooooooo02kooooo002/ooooo`03o`000?oooooo000000Wo0000
4ooooolIo`0001Gooooo1ol00006ooooo`03o`3o0?oooooooooo03cooooo1ol0000;ooooo`03o`3o
0?oooooooooo02gooooo00?o0000ooooooooool01_ooool7o`0000gooooo00?o0?l0ooooooooool0
1_ooool00ol0003oooooooooo`0^ooooo`00[Oooool00ol0003oooooo`00000:o`0000gooooo7ol0
000Dooooo`Oo00001Oooool00ol0o`3oooooooooo`0mooooo`Ko00002oooool00ol0o`3ooooooooo
o`0^ooooo`03o`000?oooooooooo00Kooooo1_l0000=ooooo`03o`3o0?oooooooooo00Oooooo00?o
0000ooooooooool0;Oooool00:kooooo00?o0000ooooool000002ol0000:ooooob7o00004oooool7
o`0000Gooooo00?o0?l0ooooooooool0?Oooool7o`0000[ooooo00?o0?l0ooooooooool0;_ooool0
0ol0003oooooooooo`06ooooo`Ko00003Oooool00ol0o`3oooooooooo`08ooooo`03o`000?oooooo
oooo02cooooo002_ooooo`03o`000?oooooo000000co00000_oooolYo`00017ooooo2?l00004oooo
o`03o`3o0?oooooooooo03gooooo1ol0000:ooooo`03o`3o0?oooooooooo02oooooo00?o0000oooo
ooooool01Oooool7o`0000cooooo0_l0o`0:ooooo`03o`000?oooooooooo02_ooooo002`ooooo`03
o`000?oooooo000001oo00002oooool>o`00013ooooo2?l00003ooooo`03o`3o0?oooooooooo03ko
oooo1ol00009ooooo`03o`3o0?oooooooooo033ooooo00?o0000ooooooooool01Oooool7o`0000co
oooo00?o0?l0ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`00/Oooool00ol0003ooooo
ooooo`0Ko`00017ooooo3?l0000@ooooo`Oo00000oooool00ol0o`3oooooooooo`0nooooo`Oo0000
2Oooool00ol0o`3oooooooooo`0aooooo`03o`000?oooooooooo00Cooooo1ol0000<ooooo`03o`3o
0?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool00;;ooooo00Co0000oooooooooooooooo
5Ol0000Gooooo`co00003_ooool8o`0000;ooooo00?o0?l0ooooooooool0?oooool6o`0000Wooooo
00?o0?l0ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`Oo00003?ooool00ol0o`3ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Wooooo002cooooo`03o`000?oooooooooo00;ooooo4_l0
000Iooooo`co00003_ooool7o`0000;ooooo00?o0?l0ooooooooool0?oooool7o`0000Sooooo00?o
0?l0ooooooooool0<oooool00ol0003oooooooooo`03ooooo`Oo00002oooool00ol0o`3ooooooooo
o`0;ooooo`03o`000?oooooooooo02Sooooo002dooooo`03o`000?oooooooooo00?ooooo2_l0000Q
ooooo`_o00003_ooool7o`000003ooooool0o`3ooooo047ooooo1_l00008ooooo`03o`3o0?oooooo
oooo03?ooooo00?o0000ooooooooool01?ooool6o`0000_ooooo00?o0?l0ooooooooool03?ooool0
0ol0003oooooooooo`0Wooooo`00]Oooool00ol0003oooooooooo`0_ooooo`[o00003Oooool8o`00
0003o`3o0?oooooooooo043ooooo1ol00007ooooo`03o`3o0?oooooooooo03Cooooo00?o0000oooo
ooooool00oooool6o`0000_ooooo00?o0?l0ooooooooool03Oooool00ol0003oooooooooo`0Voooo
o`00]_ooool00ol0003oooooooooo`0_ooooo`[o00003Oooool8o`0004;ooooo1ol00007ooooo`03
o`3o0?oooooooooo03Gooooo00?o0000ooooooooool00_ooool7o`0000[ooooo00?o0?l0oooooooo
ool03Oooool00ol0003oooooooooo`0Vooooo`00]oooool00ol0003oooooooooo`0`ooooo`[o0000
2oooool9o`0004;ooooo1ol00006ooooo`03o`3o0?oooooooooo03Kooooo00?o0000ooooooooool0
0_ooool6o`0000[ooooo00?o0?l0ooooooooool03_ooool00ol0003oooooooooo`0Uooooo`00^?oo
ool00ol0003oooooooooo`0`ooooo`[o00002oooool8o`0001_ooooo2Ol0000Nooooo`So00001Ooo
ool00ol0o`3oooooooooo`0gooooo`04o`000?ooooooooooooooo`Oo00002Oooool00ol0o`3ooooo
ooooo`0?ooooo`03o`000?oooooooooo02Cooooo002iooooo`03o`000?oooooooooo033ooooo2Ol0
000<ooooo`Wo00005OoooolBo`0001[ooooo1ol00005ooooo`03o`3o0?oooooooooo03Sooooo00?o
0000ooooooooool01ol00009ooooo`03o`3o0?oooooooooo013ooooo00?o0000ooooooooool08ooo
ool00;[ooooo00?o0000ooooooooool0<?ooool;o`0000[ooooo2Ol0000AoooooaKo00006Oooool8
o`0000Cooooo00?o0?l0ooooooooool0>?ooool01?l0003oooooooooooooool6o`0000Wooooo00?o
0?l0ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`00^oooool00ol0003oooooooooo`0`
ooooo`Oo00000oooool6o`0000Gooooo2?l0000=oooooago00005oooool7o`0000Cooooo00?o0?l0
ooooooooool0>Oooool00ol0003oooooooooo`07o`0000Sooooo00?o0?l0ooooooooool04Oooool0
0ol0003oooooooooo`0Rooooo`00_?ooool2o`0003;ooooo1Ol00009ooooo`oo00002_oooolOo`00
01Oooooo1_l00004ooooo`03o`3o0?oooooooooo03[ooooo00?o0000ooooooooool01_l00008oooo
o`03o`3o0?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00;kooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0?ooooo`co00000_oooolEo`000003ooooool0003o000000ko
00005Oooool7o`0000?ooooo00?o0?l0ooooooooool0>oooool00ol0003oooooo`000005o`0000So
oooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`0Pooooo`00_oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo013ooooo7Ol0000:ooooo`co00005Oooool7o`0000;ooooo
00?o0?l0ooooooooool0??ooool8o`0000Oooooo00?o0?l0ooooooooool05?ooool00ol0003ooooo
ooooo`0Oooooo`00`?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo6_l0
000>ooooo`go00004oooool7o`0000;ooooo00?o0?l0ooooooooool0?Oooool8o`0000Kooooo00?o
0?l0ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`00`Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00oooooo5ol0000Cooooo`_o00004_ooool8o`000003ooooool0o`3o
oooo03kooooo2?l00006ooooo`;o0?l05_ooool00ol0003oooooooooo`0Nooooo`00`_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo013ooooo4_l00003ooooo`Ko00003_ooool:o`00
01?ooooo1ol000000ooooooo0?l0ooooo`0oooooo`Oo00001oooool00ol0o`3oooooooooo`0Eoooo
o`03o`000?oooooooooo01gooooo0033ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04_ooool:o`0000kooooo0ol0000=ooooo`[o00004_ooool7o`000003o`3o0?oooooooooo03oo
oooo1ol00006ooooo`03o`3o0?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00<Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`Ko00002?ooool:o`00017ooooo
2?l00012ooooo`Ko00001_ooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo
0035ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool6o`0000Cooooo2Ol0
000Aooooo`Oo0000@_ooool6o`0000Kooooo00?o0?l0ooooooooool06?ooool00ol0003ooooooooo
o`0Jooooo`00a_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Oooooo3_l0000@
ooooo`So0000@Oooool7o`0000Gooooo00?o0?l0ooooooooool06?ooool00ol0003oooooooooo`0J
ooooo`00aoooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03_ooooo2Ol0000Aoooo
o`So00005?ooool>o`0001oooooo1_l00005ooooo`03o`3o0?oooooooooo01Wooooo00?o0000oooo
ooooool06Oooool00<Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0looooo`co
00003Oooool8o`00013ooooo4ol0000Mooooo`Ko00001Oooool00ol0o`3oooooooooo`0Jooooo`03
o`000?oooooooooo01Sooooo0039ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
??ooool6o`0000Gooooo1_l00007ooooo`Wo00003OoooolHo`0001[ooooo1ol00004ooooo`03o`3o
0?oooooooooo01_ooooo00?o0000ooooooooool05oooool00<[ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0looooo`Go00002oooool6o`0000;ooooo2?l0000;oooooa_o00006_oo
ool7o`0000?ooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`00boooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo057ooooo3Ol00006oooooako00006Oooool7
o`0000?ooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`00c?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05Cooooo7?l00006ooooo`go00005oooool8o`00
00;ooooo00?o0?l0ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`00cOooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo05Cooooo6?l0000;ooooo`co00005oooool7o`0000;o
oooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`00c_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo05?ooooo5_l0000@ooooo`[o00005oooool7o`000003oooo
ool0o`3ooooo023ooooo00?o0000ooooooooool04oooool00<oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1CoooooaGo00004Oooool:o`0001Kooooo2?l000000ol0o`3ooooooooo
o`0Pooooo`03o`000?oooooooooo01;ooooo003@ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0EOooool>o`0000Cooooo1_l0000<ooooo`[o00005_ooool7o`000003o`3o0?oooooo
oooo023ooooo00?o0000ooooooooool04_ooool00=7ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`1Fooooo`So00003_ooool6o`0000Sooooo2Ol0000Eooooo`So00008oooool00ol0
003oooooooooo`0Aooooo`00d_ooool2o`00037ooooo00?o0000ooooooooool0LOooool6o`0000?o
oooo2Ol0000Eooooo`Oo00009?ooool00ol0003oooooooooo`0@ooooo`00e?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo07Kooooo3Ol0000Eooooo`Ko000000?o0?l0ooooooooool0
8_ooool00ol0003oooooooooo`0?ooooo`00eOooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo07[ooooo2?l0000Eooooo`Oo00004_ooool=o`0000Kooooo00?o0000ooooooooool03_oo
ool00=Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1jooooo`co00004Oooool7
o`0000oooooo4?l00005ooooo`03o`000?oooooooooo00kooooo003Gooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0N_ooool6o`0000Gooooo1_l0000;ooooo`So00003?oooolEo`00
00?ooooo00?o0000ooooooooool03Oooool00=Sooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1jooooo`Go00002oooool6o`0000Gooooo2Ol00009oooooaSo00000oooool00ol0003o
ooooooooo`0<ooooo`00fOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08oooooo
4?l00005oooooa_o00000oooool00ol0003oooooooooo`0;ooooo`00f_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo09Cooooo2ol00002ooooo`ko00001Oooool;o`0000?ooooo00?o
0000ooooooooool02_ooool00=_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2E
oooooaOo00002?ooool;o`0000;ooooo00?o0000ooooooooool02_ooool00=cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2EoooooaCo00003Oooool9o`0000;ooooo00?o0000oooo
ooooool02Oooool00=gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Eoooooa?o
00003_ooool:o`000003ooooool0003ooooo00Wooooo003Nooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0U_ooool=o`0000Cooooo1_l00009ooooo`[o000000?oooooo`000?ooool0
2?ooool00=oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Fooooo`[o00003?oo
ool6o`0000Cooooo2_l000000ooooooo0000ooooo`07ooooo`00h?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool04oooool>o`000003ooooool0003o
oooo00Oooooo003Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Voooool00ol0
003oooooooooo`0Hooooo`Wo000000?oooooo`000?ooool01_ooool00>;ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01Wooooo1ol00002ooooo`03
o`000?oooooooooo00Cooooo003Sooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`0Iooooo`Ko00000oooool00ol0003oooooooooo`03ooooo`00i?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool06?oo
ool6o`0000;ooooo0ol00004ooooo`00iOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo09_ooooo00?o0000ooooooooool06?ooool7o`0000;ooooo00?o0000ooooooooool00_ooool0
0>Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
01Sooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo003Wooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0Dooooo`?o00002Oooool00ol0003o
ooooooooo`02ooooo`00j?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09[ooooo
00?o0000ooooooooool04?ooool3o`0000cooooo00?o0000ooooooooool00_ooool00>Wooooo0_l0
000`ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool4o`0000oooooo00?o
0000ooooooooool00_ooool00>_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00Oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo003/oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`02oooo
o`Co00005oooool00ol0003oooooooooo`01ooooo`00kOooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo09Wooooo00?o0000ooooool000000_l0000Kooooo`03o`000?oooooooooo007o
oooo003^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0U_ooool4o`0001kooooo
00?o0000ooooooooool00Oooool00>oooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`2Booooo`?o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo007ooooo003`
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0S_ooool3o`0000Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`01ooooo`00lOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo08Wooooo1?l0000<ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00Oooool00?;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`25ooooo`?o
00004Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo007ooooo003cooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0P?ooool4o`0001Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`01ooooo`00m?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo07cooooo0ol0000Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00Ooo
ool00?Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1gooooo`Co00007Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo003fooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0Loooool3o`0002;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`01ooooo`00moooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06oo
oooo0ol0000Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00Oooool00?Sooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Zooooo`Co0000:_ooool00ol0003ooooo
ooooo`0Dooooo`7o00000Oooool1ooooo`00nOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo06Kooooo0ol0000^ooooo`03o`000?oooooooooo01Cooooo0Ol00001ooooo`7ooooo003j
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0HOooool4o`0003;ooooo00?o0000
ooooooooool04oooool1o`00007ooooo0Oooool00?_ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1Mooooo`?o0000=oooool00ol0003oooooooooo`0Booooo`7o00000Oooool1oooo
o`00o?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Sooooo1?l0000kooooo`03
o`000?oooooooooo017ooooo0Ol00001ooooo`7ooooo003mooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0E?ooool3o`00043ooooo00?o0000ooooooooool04?ooool1o`00007ooooo
0Oooool00?kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1?ooooo`Co0000A?oo
ool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00ooooool2o`0002oooooo00?o0000
ooooooooool0Boooool3o`0004Sooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool0
0?oooooo0_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Oooooo0ol0001<oooo
o`03o`000?oooooooooo00kooooo0Ol00001ooooo`7ooooo003oooooo`?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`12ooooo`Co0000D?ooool00ol0003oooooooooo`0=ooooo`7o
00000Oooool1ooooo`00ooooool4ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
?_ooool3o`0005Gooooo00?o0000ooooooooool03?ooool1o`00007ooooo0Oooool00?oooooo1Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03Wooooo1?l0001Iooooo`03o`000?oo
oooooooo00_ooooo0Ol00001ooooo`7ooooo003oooooo`Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0eooooo`?o0000G_ooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1
ooooo`00ooooool7ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool4o`00
067ooooo00?o0000ooooooooool02oooool1o`00007ooooo003oooooo`Sooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0/ooooo`?o0000I_ooool00ol0003oooooooooo`0:ooooo`7o
00000Oooool00?oooooo2Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo
0ol0001Zooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`00ooooool:ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool08oooool4o`0006kooooo00?o0000ooooooooool02?oo
ool1o`00007ooooo003oooooo`_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0O
ooooo`?o0000Loooool00ol0003oooooooooo`07ooooo`7o00000Oooool00?oooooo3?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo01[ooooo1?l0001gooooo`03o`000?oooooooooo
00Kooooo0Ol00001ooooo`00ooooool=ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05_ooool3o`0007_ooooo00?o0000ooooooooool01_ooool1o`00007ooooo003oooooo`kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`Co0000Ooooool00ol0003ooooo
ooooo`05ooooo`7o00000Oooool00?oooooo3oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00gooooo0ol00024ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00ooooool@
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool3o`0008Sooooo00?o0000
ooooooooool00oooool1o`00007ooooo003ooooooa7ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`04ooooo`Co0000S?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool00?oo
oooo4_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?o0000TOooool01Ol0003o
oooooooooooooooo0000007ooooo003ooooooa?ooooo00?o0000ooooooooool0;Oooool2o`0009Co
oooo00?o0000ooooooooool00_ooool1o`000000oooooolDooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0U?ooool01?l0003oooooooooooooool1o`000000oooooolEooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`01o`000000oooo
oolFooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0U_ooool1o`00007ooooo0Ol0
00000?oooooo5oooool2o`0002[ooooo00?o0000ooooooooool0Uoooool2o`000000oooooolIoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0U_ooool3o`000000oooooolJooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0T_ooool4o`0000?ooooo003ooooooa_ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`2?ooooo`?o00001oooool00?oooooo7?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08_ooooo1?l0000:ooooo`00oooooolM
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Qoooool4o`0000kooooo003ooooo
oakooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`24ooooo`?o00004_ooool00?oo
oooo7oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo083ooooo1?l0000Eooooo`00
oooooolPooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0O?ooool4o`0001Wooooo
003oooooob7ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1iooooo`?o00007Ooo
ool00?oooooo8_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Gooooo1?l0000P
ooooo`00oooooolSooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0LOooool4o`00
02Cooooo003oooooobCooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1^ooooo`?o
0000:?ooool00?oooooo9Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06[ooooo
1?l0000[ooooo`00oooooolVooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0I_oo
ool4o`0002oooooo003oooooobOooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1S
ooooo`?o0000<oooool00?oooooo:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
05oooooo1?l0000fooooo`00oooooolYooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0Foooool4o`0003[ooooo003oooooob[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1Hooooo`?o0000?_ooool00?oooooo:oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo05Cooooo1?l00011ooooo`00ooooool/ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Coooool4o`0004Gooooo003oooooobgooooo0_l0000Eooooo`03o`000?oooooooooo
04cooooo0ol00019ooooo`00ooooool_ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0B?ooool4o`0004cooooo003ooooooc3ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`14ooooo`Co0000D?ooool00?oooooo<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo047ooooo0ol0001Dooooo`00oooooolbooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0?Oooool4o`0005Oooooo003ooooooc?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0iooooo`Co0000Foooool00?oooooo=?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03Kooooo0ol0001Oooooo`00ooooooleooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0<_ooool4o`0006;ooooo003oooooocKooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0^ooooo`Co0000I_ooool00?oooooo=oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02_ooooo0ol0001Zooooo`00oooooolhooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09oooool4o`0006gooooo003oooooocWooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Sooooo`Co0000LOooool00?oooooo>_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo023ooooo0ol0001eooooo`00oooooolkooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07?ooool4o`0007Sooooo003ooooooccooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`Co0000O?ooool00?oooooo?Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo0ol00020ooooo`00oooooolnooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool4o`0008?ooooo003oooooocoooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`Co0000Qoooool00?oooooo@?oo
ool01Ol0003ooooooooooooooooo000000cooooo0ol0002;ooooo`00oooooom1ooooo`04o`000?oo
ooooooooo`0000Sooooo1?l0002>ooooo`00oooooom2ooooo`03o`000?oooooo000000Cooooo1?l0
002Booooo`00oooooom3ooooo`;o000000Coooooo`000?l0003o0000U_ooool00?ooooooA?ooool2
o`0009Wooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo0000\
\>"],
  ImageRangeCache->{{{0, 477.75}, {420.438, 0}} -> {0, 0, 0, 0}}],

Cell[TextData[{
  "Fig. 7.1 The solution to Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = c\)]],
  ", at four times. Also shown are three characteristics. "
}], "Caption",
  CellTags->"Fig. 7.1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Example 2: ",
  Cell[BoxData[
      \(TraditionalForm\`s = a\ x\^n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = b\ x\)]],
  "."
}], "Section",
  CellTags->"c:7"],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  "  are now"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 
      a\ x\^n, \[IndentingNewLine]\[DifferentialD]x/\[DifferentialD]t\  = 
      b\ \(\(x\)\(.\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "The solution to  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = b\ x\)]],
  " with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " provides us with the characteristics:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_o) = 
        x\_o\ \[ExponentialE]\^\(\(\ \)\(b\ t\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.16)"],

Cell[TextData[{
  "These characteristics are shown in Fig. ",
  ButtonBox["7.2",
    ButtonData:>"Fig. 7.2",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9646 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.07848 -0.00533562 1.07848 [
[.21289 .03628 -9.3742 -12 ]
[.21289 .03628 .6258 0 ]
[.84871 .30553 0 -8.01227 ]
[.84871 .30553 10 3.98773 ]
[-0.06055 .34522 -40 -3.77786 ]
[-0.06055 .34522 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .9646 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.51756 0 m
.9781 .59953 L
s
gsave
.84871 .30553 -61 -12.0123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
gsave
-0.06055 .34522 -101 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
.55593 .72459 m
.02975 .1885 L
s
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.55593 .72459 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
0 0 m
1 0 L
1 .9646 L
0 .9646 L
closepath
clip
newpath
.5 Mabswid
.95043 .59464 m
.95906 .59668 L
s
.94182 .59264 m
.95043 .59464 L
s
.015 w
.95464 .59576 m
.95941 .6008 L
s
.5 Mabswid
.93324 .59069 m
.94182 .59264 L
s
.92468 .58878 m
.93324 .59069 L
s
.91615 .58692 m
.92468 .58878 L
s
.015 w
.94986 .59102 m
.95464 .59576 L
s
.5 Mabswid
.90764 .58511 m
.91615 .58692 L
s
.89916 .58334 m
.90764 .58511 L
s
.89071 .58162 m
.89916 .58334 L
s
.88228 .57994 m
.89071 .58162 L
s
.015 w
.94509 .58662 m
.94986 .59102 L
s
.5 Mabswid
.87387 .5783 m
.88228 .57994 L
s
.8655 .57671 m
.87387 .5783 L
s
.85715 .57516 m
.8655 .57671 L
s
.84882 .57365 m
.85715 .57516 L
s
.84052 .57218 m
.84882 .57365 L
s
.015 w
.94032 .58265 m
.94509 .58662 L
s
.5 Mabswid
.83224 .57076 m
.84052 .57218 L
s
.82399 .56937 m
.83224 .57076 L
s
.81577 .56803 m
.82399 .56937 L
s
.80757 .56673 m
.81577 .56803 L
s
.7994 .56546 m
.80757 .56673 L
s
.79125 .56424 m
.7994 .56546 L
s
.015 w
.93557 .57918 m
.94032 .58265 L
s
.5 Mabswid
.78313 .56305 m
.79125 .56424 L
s
.77503 .5619 m
.78313 .56305 L
s
.76696 .56079 m
.77503 .5619 L
s
.75892 .55972 m
.76696 .56079 L
s
.7509 .55868 m
.75892 .55972 L
s
.7429 .55769 m
.7509 .55868 L
s
.73494 .55672 m
.7429 .55769 L
s
.015 w
.93084 .57628 m
.93557 .57918 L
s
.5 Mabswid
.72699 .5558 m
.73494 .55672 L
s
.71907 .5549 m
.72699 .5558 L
s
.71118 .55405 m
.71907 .5549 L
s
.70331 .55323 m
.71118 .55405 L
s
.69547 .55244 m
.70331 .55323 L
s
.68765 .55168 m
.69547 .55244 L
s
.67985 .55096 m
.68765 .55168 L
s
.67208 .55028 m
.67985 .55096 L
s
.66434 .54962 m
.67208 .55028 L
s
.65662 .549 m
.66434 .54962 L
s
.64892 .54841 m
.65662 .549 L
s
.015 w
.92613 .57403 m
.93084 .57628 L
s
.5 Mabswid
.64125 .54785 m
.64892 .54841 L
s
.6336 .54732 m
.64125 .54785 L
s
.62598 .54682 m
.6336 .54732 L
s
.61838 .54635 m
.62598 .54682 L
s
.015 w
.65327 .55046 m
.65672 .55315 L
s
.5 Mabswid
.61081 .54591 m
.61838 .54635 L
s
.60326 .54551 m
.61081 .54591 L
s
.59573 .54513 m
.60326 .54551 L
s
.38744 .54524 m
.39432 .54492 L
s
.58823 .54478 m
.59573 .54513 L
s
.39432 .54492 m
.40121 .54463 L
s
.58075 .54445 m
.58823 .54478 L
s
.40121 .54463 m
.40813 .54435 L
s
.5733 .54416 m
.58075 .54445 L
s
.40813 .54435 m
.41507 .54409 L
s
.56587 .54389 m
.5733 .54416 L
s
.41507 .54409 m
.42203 .54385 L
s
.55846 .54365 m
.56587 .54389 L
s
.42203 .54385 m
.42901 .54364 L
s
.55107 .54344 m
.55846 .54365 L
s
.42901 .54364 m
.43601 .54344 L
s
.54371 .54326 m
.55107 .54344 L
s
.43601 .54344 m
.44304 .54327 L
s
.44304 .54327 m
.45008 .54311 L
s
.53637 .5431 m
.54371 .54326 L
s
.45008 .54311 m
.45715 .54298 L
s
.52906 .54296 m
.53637 .5431 L
s
.015 w
.38491 .54826 m
.38731 .5494 L
s
.5 Mabswid
.45715 .54298 m
.46424 .54288 L
s
.52177 .54286 m
.52906 .54296 L
s
.46424 .54288 m
.47136 .54279 L
s
.5145 .54277 m
.52177 .54286 L
s
.47136 .54279 m
.47849 .54273 L
s
.50725 .54272 m
.5145 .54277 L
s
.47849 .54273 m
.48565 .54269 L
s
.50003 .54268 m
.50725 .54272 L
s
.48565 .54269 m
.49282 .54267 L
s
.49282 .54267 m
.50003 .54268 L
s
.015 w
.64982 .54808 m
.65327 .55046 L
s
.92144 .57251 m
.92613 .57403 L
s
.3825 .54744 m
.38491 .54826 L
s
.64637 .54608 m
.64982 .54808 L
s
.38006 .547 m
.3825 .54744 L
s
.37761 .54701 m
.38006 .547 L
s
.64291 .54452 m
.64637 .54608 L
s
.91679 .57179 m
.92144 .57251 L
s
.37513 .54755 m
.37761 .54701 L
s
.63945 .54347 m
.64291 .54452 L
s
.37262 .54868 m
.37513 .54755 L
s
.63598 .54302 m
.63945 .54347 L
s
.91216 .57194 m
.91679 .57179 L
s
.37009 .55049 m
.37262 .54868 L
s
.36751 .55305 m
.37009 .55049 L
s
.63251 .54324 m
.63598 .54302 L
s
.3649 .55644 m
.36751 .55305 L
s
.90757 .573 m
.91216 .57194 L
s
.62904 .54421 m
.63251 .54324 L
s
.36224 .56072 m
.3649 .55644 L
s
.62557 .546 m
.62904 .54421 L
s
.90301 .57502 m
.90757 .573 L
s
.35954 .56593 m
.36224 .56072 L
s
.62209 .54868 m
.62557 .546 L
s
.35679 .57212 m
.35954 .56593 L
s
.89848 .57801 m
.90301 .57502 L
s
.6186 .5523 m
.62209 .54868 L
s
.35399 .57929 m
.35679 .57212 L
s
.61511 .55688 m
.6186 .5523 L
s
.35114 .58743 m
.35399 .57929 L
s
.89397 .58195 m
.89848 .57801 L
s
0 1 0 r
.5 Mabswid
.3158 .47203 m
.31565 .47514 L
s
0 g
.3158 .47203 m
.32186 .47067 L
s
.32186 .47067 m
.32793 .46932 L
s
0 1 0 r
.31565 .47514 m
.31551 .47825 L
s
0 g
.015 w
.61161 .56245 m
.61511 .55688 L
s
.34824 .59648 m
.35114 .58743 L
s
.5 Mabswid
.32793 .46932 m
.33402 .46797 L
s
0 1 0 r
.31551 .47825 m
.31537 .48137 L
s
0 g
.33402 .46797 m
.34012 .46663 L
s
0 1 0 r
.31537 .48137 m
.31522 .48448 L
s
0 g
.34012 .46663 m
.34623 .46529 L
s
.34623 .46529 m
.35235 .46396 L
s
0 1 0 r
.31522 .48448 m
.31508 .48761 L
s
0 g
.35235 .46396 m
.35849 .46263 L
s
.015 w
.88949 .5868 m
.89397 .58195 L
s
0 1 0 r
.5 Mabswid
.31508 .48761 m
.31493 .49073 L
s
0 g
.35849 .46263 m
.36464 .46131 L
s
0 1 0 r
.31493 .49073 m
.31479 .49386 L
s
0 g
.36464 .46131 m
.37081 .46 L
s
.015 w
.34528 .60636 m
.34824 .59648 L
s
.6081 .56898 m
.61161 .56245 L
s
.5 Mabswid
.37081 .46 m
.37699 .4587 L
s
0 1 0 r
.31479 .49386 m
.31464 .497 L
s
0 g
.37699 .4587 m
.38318 .4574 L
s
0 1 0 r
.31464 .497 m
.31449 .50013 L
s
0 g
.38318 .4574 m
.38939 .4561 L
s
0 1 0 r
.31449 .50013 m
.31435 .50328 L
s
0 g
.38939 .4561 m
.39561 .45482 L
s
.39561 .45482 m
.40184 .45354 L
s
0 1 0 r
.31435 .50328 m
.3142 .50642 L
s
0 g
.40184 .45354 m
.40809 .45227 L
s
0 1 0 r
.3142 .50642 m
.31406 .50957 L
s
0 g
.40809 .45227 m
.41435 .451 L
s
.015 w
.34228 .61696 m
.34528 .60636 L
s
0 1 0 r
.5 Mabswid
.31406 .50957 m
.31391 .51273 L
s
0 g
.41435 .451 m
.42062 .44975 L
s
.015 w
.88501 .59246 m
.88949 .5868 L
s
.60457 .57644 m
.6081 .56898 L
s
.5 Mabswid
.42062 .44975 m
.42691 .4485 L
s
0 1 0 r
.31391 .51273 m
.31376 .51589 L
s
0 g
.42691 .4485 m
.43322 .44726 L
s
0 1 0 r
.31376 .51589 m
.31362 .51905 L
s
0 g
.43322 .44726 m
.43953 .44603 L
s
.43953 .44603 m
.44586 .4448 L
s
0 1 0 r
.31362 .51905 m
.31347 .52222 L
s
0 g
.44586 .4448 m
.45221 .44358 L
s
0 1 0 r
.31347 .52222 m
.31332 .52539 L
s
0 g
.45221 .44358 m
.45857 .44238 L
s
.45857 .44238 m
.46494 .44118 L
s
0 1 0 r
.31332 .52539 m
.31318 .52856 L
s
0 g
.015 w
.33924 .62811 m
.34228 .61696 L
s
.5 Mabswid
.46494 .44118 m
.47133 .43998 L
s
0 1 0 r
.31318 .52856 m
.31303 .53174 L
s
0 g
.47133 .43998 m
.47774 .4388 L
s
.015 w
.60102 .58473 m
.60457 .57644 L
s
.5 Mabswid
.47774 .4388 m
.48416 .43763 L
s
0 1 0 r
.31303 .53174 m
.31288 .53493 L
s
0 g
.48416 .43763 m
.49059 .43646 L
s
0 1 0 r
.31288 .53493 m
.31273 .53811 L
s
0 g
.015 w
.88053 .59884 m
.88501 .59246 L
s
.5 Mabswid
.49059 .43646 m
.49704 .43531 L
s
.49704 .43531 m
.5035 .43416 L
s
0 1 0 r
.31273 .53811 m
.31259 .54131 L
s
0 g
.5035 .43416 m
.50998 .43303 L
s
0 1 0 r
.31259 .54131 m
.31244 .5445 L
s
0 g
.50998 .43303 m
.51647 .4319 L
s
.51647 .4319 m
.52298 .43079 L
s
.015 w
.33617 .63961 m
.33924 .62811 L
s
0 1 0 r
.5 Mabswid
.31244 .5445 m
.31229 .5477 L
s
0 g
.52298 .43079 m
.5295 .42968 L
s
0 1 0 r
.31229 .5477 m
.31214 .55091 L
s
0 g
.5295 .42968 m
.53604 .42858 L
s
.53604 .42858 m
.54259 .4275 L
s
.015 w
.59745 .59373 m
.60102 .58473 L
s
0 1 0 r
.5 Mabswid
.31214 .55091 m
.31199 .55412 L
s
0 g
.54259 .4275 m
.54916 .42642 L
s
.54916 .42642 m
.55574 .42536 L
s
0 1 0 r
.54916 .42642 m
.54917 .42955 L
s
.31199 .55412 m
.31184 .55733 L
s
0 g
.55574 .42536 m
.56234 .42431 L
s
0 1 0 r
.54917 .42955 m
.54917 .43269 L
s
.31184 .55733 m
.31169 .56055 L
s
0 g
.56234 .42431 m
.56896 .42327 L
s
.56896 .42327 m
.57559 .42224 L
s
0 1 0 r
.54917 .43269 m
.54918 .43582 L
s
.31169 .56055 m
.31154 .56377 L
s
0 g
.015 w
.87604 .60576 m
.88053 .59884 L
s
.5 Mabswid
.57559 .42224 m
.58224 .42122 L
s
.015 w
.33307 .65123 m
.33617 .63961 L
s
.5 Mabswid
.58224 .42122 m
.5889 .42021 L
s
0 1 0 r
.54918 .43582 m
.54919 .43897 L
s
.31154 .56377 m
.31139 .56699 L
s
0 g
.5889 .42021 m
.59558 .41922 L
s
0 1 0 r
.54919 .43897 m
.54919 .44211 L
s
0 g
.59558 .41922 m
.60227 .41824 L
s
0 1 0 r
.31139 .56699 m
.31124 .57022 L
s
0 g
.60227 .41824 m
.60898 .41727 L
s
0 1 0 r
.54919 .44211 m
.5492 .44526 L
s
.31124 .57022 m
.31109 .57346 L
s
0 g
.60898 .41727 m
.61571 .41631 L
s
.015 w
.59386 .60329 m
.59745 .59373 L
s
.5 Mabswid
.61571 .41631 m
.62245 .41537 L
s
0 1 0 r
.5492 .44526 m
.54921 .44841 L
s
.31109 .57346 m
.31094 .57669 L
s
0 g
.62245 .41537 m
.62921 .41444 L
s
.62921 .41444 m
.63598 .41352 L
s
0 1 0 r
.54921 .44841 m
.54921 .45157 L
s
.31094 .57669 m
.31079 .57994 L
s
0 g
.63598 .41352 m
.64277 .41261 L
s
.64277 .41261 m
.64958 .41172 L
s
0 1 0 r
.54921 .45157 m
.54922 .45473 L
s
.31079 .57994 m
.31064 .58318 L
s
0 g
.64958 .41172 m
.65641 .41085 L
s
.015 w
.32996 .66271 m
.33307 .65123 L
s
.5 Mabswid
.65641 .41085 m
.66325 .40999 L
s
0 1 0 r
.54922 .45473 m
.54923 .4579 L
s
.31064 .58318 m
.31049 .58644 L
s
0 g
.66325 .40999 m
.6701 .40914 L
s
.6701 .40914 m
.67698 .4083 L
s
0 1 0 r
.54923 .4579 m
.54923 .46107 L
s
.31049 .58644 m
.31034 .58969 L
s
0 g
.67698 .4083 m
.68387 .40749 L
s
.015 w
.87152 .61302 m
.87604 .60576 L
s
.5 Mabswid
.68387 .40749 m
.69078 .40668 L
s
.69078 .40668 m
.6977 .40589 L
s
0 1 0 r
.54923 .46107 m
.54924 .46425 L
s
.31034 .58969 m
.31019 .59295 L
s
0 g
.6977 .40589 m
.70464 .40512 L
s
.70464 .40512 m
.7116 .40437 L
s
.015 w
.59024 .6132 m
.59386 .60329 L
s
0 1 0 r
.5 Mabswid
.54924 .46425 m
.54924 .46742 L
s
.31019 .59295 m
.31004 .59621 L
s
0 g
.7116 .40437 m
.71858 .40362 L
s
.71858 .40362 m
.72557 .4029 L
s
0 1 0 r
.54924 .46742 m
.54925 .47061 L
s
.31004 .59621 m
.30989 .59948 L
s
0 g
.72557 .4029 m
.73258 .40219 L
s
.73258 .40219 m
.73961 .4015 L
s
.73961 .4015 m
.74665 .40083 L
s
0 1 0 r
.54925 .47061 m
.54926 .4738 L
s
.30989 .59948 m
.30974 .60276 L
s
0 g
.015 w
.32685 .67375 m
.32996 .66271 L
s
.5 Mabswid
.74665 .40083 m
.75372 .40017 L
s
.015 w
.25746 .43742 m
.25977 .44531 L
s
.25511 .43031 m
.25746 .43742 L
s
.5 Mabswid
.75372 .40017 m
.7608 .39953 L
s
.015 w
.25272 .42389 m
.25511 .43031 L
s
.25977 .44531 m
.26202 .45405 L
s
.25029 .4181 m
.25272 .42389 L
s
.5 Mabswid
.7608 .39953 m
.76789 .39891 L
s
0 1 0 r
.54926 .4738 m
.54926 .47699 L
s
.30974 .60276 m
.30958 .60603 L
s
0 g
.015 w
.26202 .45405 m
.26423 .46369 L
s
.5 Mabswid
.76789 .39891 m
.77501 .39831 L
s
.015 w
.24783 .41285 m
.25029 .4181 L
s
.5 Mabswid
.77501 .39831 m
.78214 .39772 L
s
.015 w
.26423 .46369 m
.26638 .47428 L
s
.5 Mabswid
.78214 .39772 m
.78929 .39716 L
s
.015 w
.24533 .40806 m
.24783 .41285 L
s
0 1 0 r
.5 Mabswid
.54926 .47699 m
.54927 .48018 L
s
.30958 .60603 m
.30943 .60931 L
s
0 g
.78929 .39716 m
.79646 .39661 L
s
.79646 .39661 m
.80365 .39608 L
s
.015 w
.24281 .40368 m
.24533 .40806 L
s
0 1 0 r
.5 Mabswid
.80365 .39608 m
.80383 .39923 L
s
0 g
.015 w
.26638 .47428 m
.26848 .48585 L
s
0 1 0 r
.5 Mabswid
.54927 .48018 m
.54928 .48338 L
s
.30943 .60931 m
.30928 .6126 L
s
0 g
.015 w
.24026 .39964 m
.24281 .40368 L
s
0 1 0 r
.5 Mabswid
.80383 .39923 m
.804 .40238 L
s
.54928 .48338 m
.54928 .48659 L
s
.30928 .6126 m
.30913 .61589 L
s
0 g
.015 w
.26848 .48585 m
.27053 .4984 L
s
.58659 .62324 m
.59024 .6132 L
s
.86695 .6204 m
.87152 .61302 L
s
.23769 .39587 m
.24026 .39964 L
s
0 1 0 r
.5 Mabswid
.804 .40238 m
.80418 .40553 L
s
.54928 .48659 m
.54929 .48979 L
s
.30913 .61589 m
.30897 .61918 L
s
0 g
.015 w
.32375 .68405 m
.32685 .67375 L
s
0 1 0 r
.5 Mabswid
.80418 .40553 m
.80435 .40868 L
s
0 g
.015 w
.27053 .4984 m
.27254 .5119 L
s
.2351 .39233 m
.23769 .39587 L
s
0 1 0 r
.5 Mabswid
.54929 .48979 m
.5493 .49301 L
s
.30897 .61918 m
.30882 .62248 L
s
.80435 .40868 m
.80453 .41185 L
s
.5493 .49301 m
.5493 .49622 L
s
.30882 .62248 m
.30867 .62579 L
s
0 g
.015 w
.2325 .38897 m
.2351 .39233 L
s
.27254 .5119 m
.27451 .5263 L
s
0 1 0 r
.5 Mabswid
.80453 .41185 m
.80471 .41501 L
s
.5493 .49622 m
.54931 .49945 L
s
.30867 .62579 m
.30851 .62909 L
s
0 g
.015 w
.22988 .38577 m
.2325 .38897 L
s
0 1 0 r
.5 Mabswid
.80471 .41501 m
.80488 .41818 L
s
.54931 .49945 m
.54932 .50267 L
s
.30851 .62909 m
.30836 .63241 L
s
0 g
.015 w
.22725 .38267 m
.22988 .38577 L
s
0 1 0 r
.5 Mabswid
.80488 .41818 m
.80506 .42135 L
s
0 g
.015 w
.27451 .5263 m
.27644 .5415 L
s
0 1 0 r
.5 Mabswid
.54932 .50267 m
.54932 .5059 L
s
.30836 .63241 m
.30821 .63572 L
s
.80506 .42135 m
.80524 .42453 L
s
0 g
.015 w
.32068 .6933 m
.32375 .68405 L
s
.2246 .37966 m
.22725 .38267 L
s
0 1 0 r
.5 Mabswid
.54932 .5059 m
.54933 .50914 L
s
.30821 .63572 m
.30805 .63904 L
s
0 g
.015 w
.5829 .63313 m
.58659 .62324 L
s
0 1 0 r
.5 Mabswid
.80524 .42453 m
.80541 .42771 L
s
.54933 .50914 m
.54934 .51237 L
s
.30805 .63904 m
.3079 .64237 L
s
0 g
.015 w
.27644 .5415 m
.27834 .55737 L
s
.22195 .37673 m
.2246 .37966 L
s
0 1 0 r
.5 Mabswid
.80541 .42771 m
.80559 .4309 L
s
0 g
.015 w
.86231 .62762 m
.86695 .6204 L
s
0 1 0 r
.5 Mabswid
.54934 .51237 m
.54935 .51562 L
s
.3079 .64237 m
.30774 .6457 L
s
0 g
.015 w
.21929 .37384 m
.22195 .37673 L
s
0 1 0 r
.5 Mabswid
.80559 .4309 m
.80577 .43409 L
s
.54935 .51562 m
.54935 .51886 L
s
.30774 .6457 m
.30759 .64903 L
s
.80577 .43409 m
.80595 .43728 L
s
0 g
.015 w
.27834 .55737 m
.28022 .57374 L
s
0 1 0 r
.5 Mabswid
.54935 .51886 m
.54936 .52212 L
s
.30759 .64903 m
.30743 .65237 L
s
0 g
.015 w
.21662 .37099 m
.21929 .37384 L
s
0 1 0 r
.5 Mabswid
.80595 .43728 m
.80613 .44048 L
s
0 g
.015 w
.31764 .7012 m
.32068 .6933 L
s
0 1 0 r
.5 Mabswid
.54936 .52212 m
.54937 .52537 L
s
.30743 .65237 m
.30728 .65571 L
s
0 g
.015 w
.21394 .36816 m
.21662 .37099 L
s
0 1 0 r
.5 Mabswid
.80613 .44048 m
.8063 .44368 L
s
.54937 .52537 m
.54937 .52863 L
s
.30728 .65571 m
.30712 .65906 L
s
0 g
.015 w
.28022 .57374 m
.28211 .59039 L
s
0 1 0 r
.5 Mabswid
.8063 .44368 m
.80648 .44689 L
s
0 g
.015 w
.57917 .64258 m
.5829 .63313 L
s
0 1 0 r
.5 Mabswid
.54937 .52863 m
.54938 .5319 L
s
.30712 .65906 m
.30697 .66241 L
s
0 g
.015 w
.21126 .36536 m
.21394 .36816 L
s
0 1 0 r
.5 Mabswid
.80648 .44689 m
.80666 .4501 L
s
.54938 .5319 m
.54939 .53516 L
s
.30697 .66241 m
.30681 .66577 L
s
0 g
.015 w
.20857 .36256 m
.21126 .36536 L
s
0 1 0 r
.5 Mabswid
.80666 .4501 m
.80684 .45332 L
s
.54939 .53516 m
.54939 .53844 L
s
.30681 .66577 m
.30666 .66913 L
s
0 g
.015 w
.31467 .70747 m
.31764 .7012 L
s
.28211 .59039 m
.284 .60709 L
s
0 1 0 r
.5 Mabswid
.80684 .45332 m
.80702 .45654 L
s
0 g
.015 w
.20587 .35978 m
.20857 .36256 L
s
0 1 0 r
.5 Mabswid
.54939 .53844 m
.5494 .54172 L
s
.30666 .66913 m
.3065 .6725 L
s
0 g
.015 w
.85759 .6344 m
.86231 .62762 L
s
0 1 0 r
.5 Mabswid
.80702 .45654 m
.8072 .45976 L
s
.5494 .54172 m
.54941 .545 L
s
.3065 .6725 m
.30634 .67587 L
s
0 g
.015 w
.20317 .35699 m
.20587 .35978 L
s
0 1 0 r
.5 Mabswid
.8072 .45976 m
.80738 .46299 L
s
.54941 .545 m
.54941 .54828 L
s
.30634 .67587 m
.30619 .67924 L
s
0 g
.015 w
.284 .60709 m
.28591 .62356 L
s
0 1 0 r
.5 Mabswid
.80738 .46299 m
.80756 .46622 L
s
0 g
.015 w
.20046 .35421 m
.20317 .35699 L
s
0 1 0 r
.5 Mabswid
.54941 .54828 m
.54942 .55158 L
s
.30619 .67924 m
.30603 .68262 L
s
0 g
.015 w
.57541 .65129 m
.57917 .64258 L
s
.31176 .71186 m
.31467 .70747 L
s
0 1 0 r
.5 Mabswid
.80756 .46622 m
.80774 .46946 L
s
.54942 .55158 m
.54943 .55487 L
s
.30603 .68262 m
.30587 .686 L
s
0 g
.20046 .35418 m
.20509 .35102 L
s
0 1 0 r
.80774 .46946 m
.80792 .4727 L
s
.54943 .55487 m
.54943 .55817 L
s
0 g
.015 w
.28591 .62356 m
.28785 .6395 L
s
0 1 0 r
.5 Mabswid
.30587 .686 m
.30572 .68939 L
s
.80792 .4727 m
.8081 .47595 L
s
.54943 .55817 m
.54944 .56147 L
s
.30572 .68939 m
.30556 .69278 L
s
0 g
.20509 .35102 m
.20972 .34784 L
s
0 1 0 r
.8081 .47595 m
.80829 .4792 L
s
0 g
.015 w
.30894 .71418 m
.31176 .71186 L
s
0 1 0 r
.5 Mabswid
.54944 .56147 m
.54945 .56478 L
s
.30556 .69278 m
.3054 .69618 L
s
0 g
.015 w
.28785 .6395 m
.28985 .65462 L
s
.5 Mabswid
.20972 .34784 m
.21434 .34464 L
s
0 1 0 r
.80829 .4792 m
.80847 .48245 L
s
.54945 .56478 m
.54945 .5681 L
s
.3054 .69618 m
.30524 .69958 L
s
0 g
.015 w
.85276 .64042 m
.85759 .6344 L
s
0 1 0 r
.5 Mabswid
.80847 .48245 m
.80865 .48571 L
s
.54945 .5681 m
.54946 .57141 L
s
.30524 .69958 m
.30509 .70299 L
s
0 g
.21434 .34464 m
.21895 .34141 L
s
.015 w
.57161 .65894 m
.57541 .65129 L
s
0 1 0 r
.5 Mabswid
.80865 .48571 m
.80883 .48898 L
s
0 g
.015 w
.3062 .71428 m
.30894 .71418 L
s
.28985 .65462 m
.29192 .66858 L
s
0 1 0 r
.5 Mabswid
.54946 .57141 m
.54947 .57474 L
s
.30509 .70299 m
.30493 .7064 L
s
.80883 .48898 m
.80901 .49225 L
s
.54947 .57474 m
.54948 .57806 L
s
.30493 .7064 m
.30477 .70982 L
s
0 g
.21895 .34141 m
.22357 .33816 L
s
.015 w
.29192 .66858 m
.29406 .68112 L
s
0 1 0 r
.5 Mabswid
.80901 .49225 m
.8092 .49552 L
s
.54948 .57806 m
.54948 .58139 L
s
0 g
.015 w
.30357 .71208 m
.3062 .71428 L
s
0 1 0 r
.5 Mabswid
.30477 .70982 m
.30461 .71324 L
s
.8092 .49552 m
.80938 .4988 L
s
0 g
.22357 .33816 m
.22817 .33488 L
s
0 1 0 r
.54948 .58139 m
.54949 .58473 L
s
0 g
.015 w
.29406 .68112 m
.29629 .69194 L
s
.30104 .70757 m
.30357 .71208 L
s
0 1 0 r
.5 Mabswid
.80938 .4988 m
.80956 .50208 L
s
.54949 .58473 m
.5495 .58807 L
s
0 g
.015 w
.29629 .69194 m
.29861 .70082 L
s
.29861 .70082 m
.30104 .70757 L
s
.5 Mabswid
.22817 .33488 m
.23277 .33158 L
s
0 1 0 r
.80956 .50208 m
.80974 .50536 L
s
.5495 .58807 m
.5495 .59141 L
s
0 g
.015 w
.56777 .66523 m
.57161 .65894 L
s
0 1 0 r
.5 Mabswid
.80974 .50536 m
.80993 .50865 L
s
.5495 .59141 m
.54951 .59476 L
s
0 g
.015 w
.84782 .64538 m
.85276 .64042 L
s
.5 Mabswid
.23277 .33158 m
.23737 .32826 L
s
0 1 0 r
.80993 .50865 m
.81011 .51195 L
s
.54951 .59476 m
.54952 .59812 L
s
.81011 .51195 m
.8103 .51525 L
s
.54952 .59812 m
.54952 .60148 L
s
0 g
.23737 .32826 m
.24196 .32491 L
s
0 1 0 r
.8103 .51525 m
.81048 .51855 L
s
.54952 .60148 m
.54953 .60484 L
s
0 g
.24196 .32491 m
.24654 .32154 L
s
0 1 0 r
.81048 .51855 m
.81066 .52186 L
s
.54953 .60484 m
.54954 .60821 L
s
.81066 .52186 m
.81085 .52517 L
s
.54954 .60821 m
.54954 .61158 L
s
0 g
.015 w
.56389 .66987 m
.56777 .66523 L
s
.5 Mabswid
.24654 .32154 m
.25112 .31814 L
s
0 1 0 r
.81085 .52517 m
.81103 .52849 L
s
.54954 .61158 m
.54955 .61495 L
s
.81103 .52849 m
.81122 .53181 L
s
.54955 .61495 m
.54956 .61834 L
s
0 g
.25112 .31814 m
.25569 .31471 L
s
.015 w
.84273 .64895 m
.84782 .64538 L
s
0 1 0 r
.5 Mabswid
.81122 .53181 m
.8114 .53514 L
s
.54956 .61834 m
.54957 .62172 L
s
.8114 .53514 m
.81159 .53847 L
s
.54957 .62172 m
.54957 .62511 L
s
0 g
.25569 .31471 m
.26026 .31126 L
s
.015 w
.47247 .38206 m
.47644 .39472 L
s
.46849 .37036 m
.47247 .38206 L
s
.47644 .39472 m
.4804 .40835 L
s
.46449 .35956 m
.46849 .37036 L
s
0 1 0 r
.5 Mabswid
.81159 .53847 m
.81178 .5418 L
s
0 g
.015 w
.4804 .40835 m
.48435 .42295 L
s
0 1 0 r
.5 Mabswid
.54957 .62511 m
.54958 .62851 L
s
0 g
.015 w
.55997 .67262 m
.56389 .66987 L
s
.46047 .3496 m
.46449 .35956 L
s
.48435 .42295 m
.48829 .43851 L
s
0 1 0 r
.5 Mabswid
.81178 .5418 m
.81196 .54514 L
s
0 g
.26026 .31126 m
.26482 .30778 L
s
.015 w
.45643 .34042 m
.46047 .3496 L
s
0 1 0 r
.5 Mabswid
.54958 .62851 m
.54959 .63191 L
s
0 g
.015 w
.48829 .43851 m
.49223 .45497 L
s
0 1 0 r
.5 Mabswid
.81196 .54514 m
.81215 .54849 L
s
0 g
.015 w
.45238 .33194 m
.45643 .34042 L
s
0 1 0 r
.5 Mabswid
.54959 .63191 m
.54959 .63531 L
s
0 g
.26482 .30778 m
.26938 .30428 L
s
.015 w
.49223 .45497 m
.49618 .47222 L
s
0 1 0 r
.5 Mabswid
.81215 .54849 m
.81234 .55184 L
s
.54959 .63531 m
.5496 .63872 L
s
0 g
.015 w
.4483 .32407 m
.45238 .33194 L
s
0 1 0 r
.5 Mabswid
.81234 .55184 m
.81252 .55519 L
s
.5496 .63872 m
.54961 .64213 L
s
0 g
.015 w
.49618 .47222 m
.50012 .49013 L
s
.5 Mabswid
.26938 .30428 m
.27392 .30074 L
s
.015 w
.55603 .67327 m
.55997 .67262 L
s
.44421 .31674 m
.4483 .32407 L
s
.8375 .65087 m
.84273 .64895 L
s
0 1 0 r
.5 Mabswid
.81252 .55519 m
.81271 .55855 L
s
.54961 .64213 m
.54962 .64555 L
s
0 g
.015 w
.50012 .49013 m
.50407 .50853 L
s
0 1 0 r
.5 Mabswid
.81271 .55855 m
.8129 .56191 L
s
.54962 .64555 m
.54962 .64898 L
s
0 g
.015 w
.4401 .30987 m
.44421 .31674 L
s
.5 Mabswid
.27392 .30074 m
.27846 .29718 L
s
0 1 0 r
.8129 .56191 m
.81309 .56528 L
s
.54962 .64898 m
.54963 .6524 L
s
0 g
.015 w
.50407 .50853 m
.50802 .5272 L
s
0 1 0 r
.5 Mabswid
.81309 .56528 m
.81327 .56865 L
s
0 g
.015 w
.43597 .30341 m
.4401 .30987 L
s
0 1 0 r
.5 Mabswid
.54963 .6524 m
.54964 .65584 L
s
0 g
.27846 .29718 m
.283 .29359 L
s
.015 w
.55206 .67168 m
.55603 .67327 L
s
0 1 0 r
.5 Mabswid
.81327 .56865 m
.81346 .57203 L
s
.54964 .65584 m
.54964 .65927 L
s
0 g
.015 w
.50802 .5272 m
.51199 .54591 L
s
.43182 .29727 m
.43597 .30341 L
s
0 1 0 r
.5 Mabswid
.81346 .57203 m
.81365 .57541 L
s
0 g
.283 .29359 m
.28753 .28997 L
s
0 1 0 r
.54964 .65927 m
.54965 .66272 L
s
.81365 .57541 m
.81384 .5788 L
s
.54965 .66272 m
.54966 .66616 L
s
0 g
.015 w
.8321 .65086 m
.8375 .65087 L
s
.51199 .54591 m
.51597 .56436 L
s
.54807 .66777 m
.55206 .67168 L
s
.5 Mabswid
.28753 .28997 m
.29204 .28632 L
s
.015 w
.42765 .2914 m
.43182 .29727 L
s
0 1 0 r
.5 Mabswid
.81384 .5788 m
.81403 .58219 L
s
.54966 .66616 m
.54967 .66961 L
s
.81403 .58219 m
.81422 .58558 L
s
0 g
.015 w
.51597 .56436 m
.51996 .58227 L
s
.5 Mabswid
.29204 .28632 m
.29656 .28264 L
s
0 1 0 r
.81422 .58558 m
.81441 .58898 L
s
0 g
.015 w
.42347 .28575 m
.42765 .2914 L
s
.54406 .66151 m
.54807 .66777 L
s
.51996 .58227 m
.52396 .59932 L
s
0 1 0 r
.5 Mabswid
.81441 .58898 m
.8146 .59239 L
s
0 g
.29656 .28264 m
.30106 .27894 L
s
.015 w
.54004 .65297 m
.54406 .66151 L
s
0 1 0 r
.5 Mabswid
.8146 .59239 m
.81479 .5958 L
s
0 g
.015 w
.52396 .59932 m
.52797 .6152 L
s
.41926 .28027 m
.42347 .28575 L
s
0 1 0 r
.5 Mabswid
.81479 .5958 m
.81498 .59921 L
s
0 g
.015 w
.52797 .6152 m
.53199 .62961 L
s
.53602 .64228 m
.54004 .65297 L
s
.82654 .64873 m
.8321 .65086 L
s
.5 Mabswid
.30106 .27894 m
.30556 .2752 L
s
.015 w
.53199 .62961 m
.53602 .64228 L
s
0 1 0 r
.5 Mabswid
.81498 .59921 m
.81517 .60263 L
s
0 g
.015 w
.41504 .27494 m
.41926 .28027 L
s
0 1 0 r
.5 Mabswid
.81517 .60263 m
.81536 .60605 L
s
0 g
.30556 .2752 m
.31005 .27142 L
s
0 1 0 r
.81536 .60605 m
.81555 .60948 L
s
0 g
.015 w
.4108 .26971 m
.41504 .27494 L
s
0 1 0 r
.5 Mabswid
.81555 .60948 m
.81574 .61292 L
s
0 g
.31005 .27142 m
.31453 .26762 L
s
0 1 0 r
.81574 .61292 m
.81593 .61635 L
s
0 g
.015 w
.8208 .64433 m
.82654 .64873 L
s
0 1 0 r
.5 Mabswid
.81593 .61635 m
.81613 .6198 L
s
0 g
.015 w
.40655 .26456 m
.4108 .26971 L
s
.5 Mabswid
.31453 .26762 m
.319 .26378 L
s
0 1 0 r
.81613 .6198 m
.81632 .62324 L
s
.81632 .62324 m
.81651 .6267 L
s
0 g
.319 .26378 m
.32346 .25992 L
s
.015 w
.40228 .25947 m
.40655 .26456 L
s
0 1 0 r
.5 Mabswid
.81651 .6267 m
.8167 .63015 L
s
.8167 .63015 m
.8169 .63362 L
s
0 g
.32346 .25992 m
.32792 .25601 L
s
.015 w
.8149 .63756 m
.8208 .64433 L
s
.398 .25441 m
.40228 .25947 L
s
0 1 0 r
.5 Mabswid
.8169 .63362 m
.81709 .63708 L
s
0 g
.32792 .25601 m
.33236 .25208 L
s
0 1 0 r
.81709 .63708 m
.81728 .64055 L
s
0 g
.015 w
.39369 .24939 m
.398 .25441 L
s
.5 Mabswid
.33236 .25208 m
.3368 .24811 L
s
.015 w
.80884 .62842 m
.8149 .63756 L
s
.38938 .24437 m
.39369 .24939 L
s
.5 Mabswid
.3368 .24811 m
.34122 .2441 L
s
.34122 .2441 m
.34564 .24006 L
s
.015 w
.38505 .23937 m
.38938 .24437 L
s
.80263 .61695 m
.80884 .62842 L
s
.5 Mabswid
.34564 .24006 m
.35005 .23598 L
s
.015 w
.3807 .23437 m
.38505 .23937 L
s
.79629 .60327 m
.80263 .61695 L
s
.5 Mabswid
.35005 .23598 m
.35444 .23186 L
s
.015 w
.37634 .22936 m
.3807 .23437 L
s
.78982 .58757 m
.79629 .60327 L
s
.5 Mabswid
.35444 .23186 m
.35883 .22771 L
s
.015 w
.78325 .57008 m
.78982 .58757 L
s
.37196 .22435 m
.37634 .22936 L
s
.72924 .40084 m
.73599 .42217 L
s
.7225 .38014 m
.72924 .40084 L
s
.73599 .42217 m
.74277 .44396 L
s
.7158 .36021 m
.7225 .38014 L
s
.77661 .55107 m
.78325 .57008 L
s
.74277 .44396 m
.74956 .46598 L
s
.70912 .34114 m
.7158 .36021 L
s
.74956 .46598 m
.75636 .48799 L
s
.5 Mabswid
.35883 .22771 m
.3632 .22352 L
s
.015 w
.76989 .53085 m
.77661 .55107 L
s
.75636 .48799 m
.76314 .50972 L
s
.76314 .50972 m
.76989 .53085 L
s
.70247 .323 m
.70912 .34114 L
s
.69584 .30582 m
.70247 .323 L
s
.36757 .21932 m
.37196 .22435 L
s
.5 Mabswid
.3632 .22352 m
.36757 .21929 L
s
.015 w
.68924 .28959 m
.69584 .30582 L
s
.68265 .27429 m
.68924 .28959 L
s
.5 Mabswid
.36757 .21929 m
.37192 .21502 L
s
.015 w
.67607 .25986 m
.68265 .27429 L
s
.5 Mabswid
.37192 .21502 m
.37626 .21071 L
s
.015 w
.6695 .24626 m
.67607 .25986 L
s
.5 Mabswid
.37626 .21071 m
.38059 .20636 L
s
.015 w
.66292 .23341 m
.6695 .24626 L
s
.5 Mabswid
.38059 .20636 m
.38491 .20197 L
s
.38491 .20197 m
.38922 .19754 L
s
.015 w
.65634 .22123 m
.66292 .23341 L
s
.5 Mabswid
.38922 .19754 m
.39351 .19306 L
s
.015 w
.64975 .20964 m
.65634 .22123 L
s
.5 Mabswid
.39351 .19306 m
.39779 .18854 L
s
.015 w
.64315 .19857 m
.64975 .20964 L
s
.5 Mabswid
.39779 .18854 m
.40206 .18398 L
s
.40206 .18398 m
.40632 .17937 L
s
.015 w
.63652 .18793 m
.64315 .19857 L
s
.5 Mabswid
.40632 .17937 m
.41056 .17471 L
s
.015 w
.62987 .17766 m
.63652 .18793 L
s
.5 Mabswid
.41056 .17471 m
.41478 .17001 L
s
.41478 .17001 m
.419 .16526 L
s
.015 w
.6232 .1677 m
.62987 .17766 L
s
.5 Mabswid
.419 .16526 m
.42319 .16046 L
s
.42319 .16046 m
.42738 .15562 L
s
.015 w
.61649 .15797 m
.6232 .1677 L
s
.5 Mabswid
.42738 .15562 m
.43155 .15072 L
s
.015 w
.60975 .14843 m
.61649 .15797 L
s
.5 Mabswid
.43155 .15072 m
.4357 .14577 L
s
.4357 .14577 m
.43984 .14077 L
s
.015 w
.60298 .13904 m
.60975 .14843 L
s
.5 Mabswid
.43984 .14077 m
.44396 .13572 L
s
.44396 .13572 m
.44806 .13061 L
s
.015 w
.59618 .12975 m
.60298 .13904 L
s
.5 Mabswid
.44806 .13061 m
.45215 .12545 L
s
.015 w
.58934 .12054 m
.59618 .12975 L
s
.5 Mabswid
.45215 .12545 m
.45622 .12023 L
s
.45622 .12023 m
.46028 .11496 L
s
.015 w
.58246 .11137 m
.58934 .12054 L
s
.5 Mabswid
.46028 .11496 m
.46431 .10963 L
s
.015 w
.57554 .10222 m
.58246 .11137 L
s
.5 Mabswid
.46431 .10963 m
.46833 .10424 L
s
.46833 .10424 m
.47233 .09879 L
s
.015 w
.56858 .09308 m
.57554 .10222 L
s
.5 Mabswid
.47233 .09879 m
.47631 .09328 L
s
.47631 .09328 m
.48027 .08771 L
s
.015 w
.56158 .08393 m
.56858 .09308 L
s
.5 Mabswid
.48027 .08771 m
.48421 .08207 L
s
.015 w
.55454 .07476 m
.56158 .08393 L
s
.5 Mabswid
.48421 .08207 m
.48813 .07637 L
s
.48813 .07637 m
.49203 .07061 L
s
.015 w
.54746 .06555 m
.55454 .07476 L
s
.5 Mabswid
.49203 .07061 m
.49591 .06478 L
s
.015 w
.54034 .05632 m
.54746 .06555 L
s
.5 Mabswid
.49591 .06478 m
.49976 .05887 L
s
.49976 .05887 m
.5036 .05291 L
s
.015 w
.53317 .04704 m
.54034 .05632 L
s
.5 Mabswid
.5036 .05291 m
.50741 .04687 L
s
.015 w
.52596 .03771 m
.53317 .04704 L
s
.5 Mabswid
.50741 .04687 m
.5112 .04075 L
s
.5112 .04075 m
.51497 .03457 L
s
.015 w
.51871 .02834 m
.52596 .03771 L
s
.5 Mabswid
.51497 .03457 m
.51871 .02831 L
s
.25 Mabswid
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 277.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Fb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00N_ooool0
1OnHV9So0000o`000?m4A4Co^[Zj05[ooooo0_l0002=ooooo`00N_ooool01Ol@413o^[Zjonk^k_mg
MgOo410@05Oooooo0ol000000ooooooo0000ooooo`2<ooooo`00N_ooool00ol0003oooooooooo`1G
ooooo`;o00001?ooool2o`0008cooooo001jooooo`03o`000?oooooooooo05Cooooo0ol00006oooo
o`03o`000?oooooo000008_ooooo001jooooo`03o`000?oooooooooo057ooooo0ol00009ooooo`04
o`000?ooooooooooo`0008[ooooo001hooooo`03oa0@4?l0003o000000?o0000C_ooool2o`0000co
oooo00Co0000oooooooooooo0000R_ooool007[ooooo00?o0000ooooooooool0C?ooool3o`0000ko
oooo00Go0000ooooooooooooooooo`000029ooooo`00N_ooool00ol0003oooooooooo`1:ooooo`;o
00003oooool4o`0000?ooooo00?o0000ooooooooool0Q_ooool00<Cooooo0ol0000Aooooo`Co0000
1?ooool00ol0003oooooooooo`25ooooo`00`Oooool3o`0001Cooooo1Ol00004ooooo`03o`000?oo
oooooooo08Cooooo002oooooo`;o00005oooool6o`0000?ooooo00?o0000ooooooooool0Q?ooool0
0;cooooo0ol0000Iooooo`Ko00001?ooool00ol0003oooooooooo`23ooooo`00^_ooool2o`0001co
oooo1ol00004ooooo`03o`000?oooooooooo08;ooooo002gooooo`?o00007_ooool00ol0003ooooo
o`000005o`0000Cooooo00?o0000ooooooooool0POooool00;Gooooo0_l0000Pooooo`03o`000?oo
oooooooo00Oo00000oooool00ol0003oooooooooo`21ooooo`00/_ooool3o`0002;ooooo00?o0000
ooooooooool02?l00003ooooo`03o`000?oooooooooo083ooooo002_ooooo`?o00009?ooool01_l0
003ooooooooooooooooo0000ooooo`Oo00000oooool00ol0003oooooooooo`1oooooo`00[Oooool2
o`0002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07o`0000?ooooo00?o0000
ooooooooool0O_ooool00:[ooooo0ol0000Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo1ol00002ooooo`03o`000?oooooooooo07kooooo002Xooooo`;o0000:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo1_l00003ooooo`03o`000?oooooooooo
07gooooo002Uooooo`?o0000;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo1_l00003ooooo`03o`000?oooooooooo07cooooo002Rooooo`?o0000;Oooool2o`0000Kooooo
00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool0Noooool00:3ooooo0_l0
000_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o
0000ooooooooool0Noooool009gooooo0ol0000aooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool6o`0000?ooooo00?o0000ooooooooool0N_ooool009_ooooo0_l0000coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool6o`0000?ooooo00?o0000oooo
ooooool0NOooool009Sooooo0ol0000eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool7o`0000?ooooo00?o0000ooooooooool0N?ooool009Kooooo0_l0000gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool7o`0000?ooooo00?o0000ooooooooool0
Moooool009?ooooo0ol0000hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool6o`0000?ooooo00?o0000ooooooooool0Moooool0093ooooo0ol0000kooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool6o`0000?ooooo00?o0000ooooooooool0M_ooool0
08kooooo0_l0000mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool6o`00
00?ooooo00?o0000ooooooooool0MOooool008_ooooo0ol0000nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o0000ooooooooool0M?ooool008Wooooo
0_l00010ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool6o`0000?ooooo
00?o0000ooooooooool0M?ooool008Kooooo0ol00011ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool6o`0000?ooooo00?o0000ooooooooool0Loooool008Cooooo0_l00014
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool7o`0000?ooooo00?o0000
ooooooooool0L_ooool0087ooooo0ol00015ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool7o`0000?ooooo00?o0000ooooooooool0LOooool007kooooo0ol00017ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool6o`0000?ooooo00?o0000oooooooo
ool0LOooool007cooooo0_l0001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool6o`0000?ooooo00?o0000ooooooooool0L?ooool007Wooooo0ol0001;ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool6o`0000?ooooo00?o0000ooooooooool0Kooo
ool007Oooooo0_l0001=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool6
o`0000Cooooo00?o0000ooooooooool0K_ooool007Cooooo0ol0001>ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04Oooool6o`0000?ooooo00?o0000ooooooooool0K_ooool0077o
oooo0ol0001@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool6o`0000?o
oooo00?o0000ooooooooool0KOooool006oooooo0_l0001Booooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool04_ooool7o`0000?ooooo00?o0000ooooooooool0K?ooool006cooooo0ol0
001Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool7o`0000?ooooo00?o
0000ooooooooool0Joooool006[ooooo0_l0001Fooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool6o`0000Cooooo00?o0000ooooooooool0J_ooool006Oooooo0ol0001Goooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool6o`0000?ooooo00?o0000oooo
ooooool0J_ooool006Gooooo0_l0001Iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05_ooool6o`0000?ooooo00?o0000ooooooooool0JOooool006;ooooo0ol0001Jooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05_ooool6o`0000Cooooo00?o0000ooooooooool0
J?ooool005oooooo0ol0001Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05ooo
ool6o`0000Cooooo00?o0000ooooooooool0Ioooool005gooooo0_l0001Nooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06?ooool6o`0000?ooooo00?o0000ooooooooool0Ioooool0
05[ooooo0ol0001Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool6o`00
00Cooooo00?o0000ooooooooool0I_ooool005Sooooo0_l0001Rooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06Oooool6o`0000Cooooo00?o0000ooooooooool0IOooool005Gooooo
0ol0001Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06_ooool6o`0000Cooooo
00?o0000ooooooooool0I?ooool005;ooooo0ol0001Uooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool06_ooool6o`0000Cooooo00?o0000ooooooooool0I?ooool0053ooooo0_l0001W
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06oooool6o`0000Cooooo00?o0000
ooooooooool0Hoooool004gooooo0ol0001Xooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07?ooool6o`0000Cooooo00?o0000ooooooooool0H_ooool004cooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo1_l00005ooooo`03
o`000?oooooooooo067ooooo001<ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Mooooo`Ko00001?ooool00ol0003oooooooooo`1Qooooo`00C?oo
ool2o`0006Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`Ko00001?oo
ool00ol0003oooooooooo`1Pooooo`00C?ooool00ol0003oooooo`00001Uooooo`;o00009?ooool0
0ol0003oooooooooo`0Nooooo`Ko00001Oooool00ol0003oooooooooo`1Oooooo`00C?ooool01?l0
003oooooooooool0001Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool6
o`0000Gooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08?ooool5o`00
00Kooooo00?o0000ooooooooool0GOooool004_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08?ooool5o`0000Ko
oooo00?o0000ooooooooool0GOooool004_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08Oooool5o`0000Kooooo
00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Fooooo`Go0000:Oooool00ol0003oooooooooo`0Qooooo`Go00001oooool00ol0003ooooooooo
o`1Kooooo`00Boooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Gooooo1_l0000X
ooooo`03o`000?oooooooooo027ooooo1_l00007ooooo`03o`000?oooooooooo05[ooooo001;oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool6o`0002Sooooo00?o0000oooo
ooooool08_ooool5o`0000Oooooo00?o0000ooooooooool0F_ooool004_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Cooooo`Oo00009oooool00ol0003oooooooooo`0Rooooo`Ko
00001oooool00ol0003oooooooooo`1Iooooo`00Boooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool01_l0000Vooooo`03o`000?oooooooooo02?ooooo
1_l00007ooooo`03o`000?oooooooooo05Sooooo001;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Coooool01?l0003oooooooooooooool6o`0002Kooooo00?o0000ooooooooool0
8oooool6o`0000Sooooo00?o0000ooooooooool0Eoooool004[ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00?ooooo1ol0000Tooooo`03o`000?oo
oooooooo02Cooooo1_l00007ooooo`03o`000?oooooooooo05Oooooo001:ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`05ooooo`Oo00008oooool0
0ol0003oooooooooo`0Uooooo`Go00002?ooool00ol0003oooooooooo`1Fooooo`00B_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`Oo00008oooool00ol0
003oooooooooo`0Uooooo`Ko00002?ooool00ol0003oooooooooo`1Eooooo`00B_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02Oooool7o`0002;o
oooo00?o0000ooooooooool09_ooool5o`0000Wooooo00?o0000ooooooooool0E?ooool004[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo
1_l0000Qooooo`03o`000?oooooooooo02Kooooo1_l00009ooooo`03o`000?oooooooooo05?ooooo
001:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0<ooooo`Ko00008Oooool00ol0003oooooooooo`0Wooooo`Go00002Oooool00ol0003ooooooooo
o`1Cooooo`00B_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo043ooooo0_l0000@
ooooo`Oo00007oooool00ol0003oooooooooo`0Wooooo`Ko00002Oooool00ol0003oooooooooo`1B
ooooo`00B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool04Oooool7o`0001kooooo00?o0000ooooooooool0:?ooool5o`0000[ooooo00?o0000oooo
ooooool0DOooool004Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo01;ooooo1ol0000Nooooo`03o`000?oooooooooo02Sooooo1_l0000:ooooo`03
o`000?oooooooooo053ooooo0019ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
>Oooool2o`0001Kooooo1ol0000Mooooo`03o`000?oooooooooo02Wooooo1Ol0000:ooooo`03o`00
0?oooooooooo053ooooo0019ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Hooooo`Ko00006oooool2o`0002_ooooo1_l0000:ooooo`03o`000?oo
oooooooo04oooooo0019ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Iooooo`Ko00006?ooool3o`000003ooooool0003ooooo02_ooooo1Ol0000;
ooooo`03o`000?oooooooooo04kooooo0019ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Kooooo`Oo00004oooool3o`0000Gooooo00?o0000oooo
ooooool0:Oooool6o`0000_ooooo00?o0000ooooooooool0COooool004Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01gooooo1ol0000?ooooo`?o
00002Oooool00ol0003oooooooooo`0Yooooo`Go00002oooool00ol0003oooooooooo`1=ooooo`00
BOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
7_ooool7o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo02Sooooo1_l0000;ooooo`03o`00
0?oooooooooo04cooooo0019ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Pooooo`Oo00002?ooool3o`00017ooooo00?o0000ooooooooool0:?oo
ool5o`0000cooooo00?o0000ooooooooool08Oooool2o`0000;ooooo0_l0000Tooooo`00BOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08oooool5
o`0000Gooooo0ol0000Eooooo`03o`000?oooooooooo02Oooooo1_l0000<ooooo`03o`000?oooooo
oooo023ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdTooooo`00B?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Sooooo0_l0000Vooooo`Ko00000_ooool2o`0001Sooooo00?o
0000ooooooooool0:?ooool5o`0000cooooo00?o0000ooooooooool08Oooool01?oMgMgo0000oa0@
4?o<c<`Uooooo`00B?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09oooool7o`0001_ooooo00?o0000ooooooooool09oooool5o`0000gooooo00?o
0000ooooooooool08?ooool01?o^k^ko8B4Qoa0@4?o^k^hUooooo`00B?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:?ooool6o`0001gooooo00?o
0000ooooooooool09oooool5o`0000gooooo00?o0000ooooooooool07oooool01?lQ8B7oMgMgogMg
Molb<S8Uooooo`00B?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo0_l0
000Yooooo`Wo00007Oooool00ol0003oooooooooo`0Vooooo`Go00003_ooool00ol0003ooooooooo
o`0Mooooo`;o00000_ooool2o`0002Cooooo0018ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Vooooo`?o00001?ooool6o`0001gooooo00?o0000
ooooooooool09Oooool6o`0000kooooo00?o0000ooooooooool0A_ooool004Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Cooooo0ol00007oooo
o`Oo00007Oooool00ol0003oooooooooo`0Uooooo`Go00003_ooool00ol0003oooooooooo`16oooo
o`00B?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo0_l0000Uooooo`;o
00002oooool6o`0001gooooo00?o0000ooooooooool09Oooool5o`0000oooooo00?o0000oooooooo
ool0AOooool004Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02;ooooo0ol0000>ooooo`Ko00007Oooool00ol0003oooooooooo`0Uooooo`Go0000
3oooool00ol0003oooooooooo`14ooooo`00Aoooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool08?ooool3o`0001;ooooo1Ol0000Nooooo`03o`000?oo
oooooooo02Cooooo1Ol0000@ooooo`03o`000?oooooooooo04?ooooo0017ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool04oooool2o`00023ooooo0ol0000Eooooo`Go00007oooool0
0ol0003oooooooooo`0Sooooo`Ko00003oooool00ol0003oooooooooo`13ooooo`00Aoooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool3o`00
01Wooooo1Ol0000Oooooo`03o`000?oooooooooo02?ooooo1Ol0000@ooooo`03o`000?oooooooooo
04;ooooo0017ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Kooooo`?o00007?ooool5o`00023ooooo00?o0000ooooooooool08_ooool5o`00017o
oooo00?o0000ooooooooool0@Oooool004Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0<ooooo`;o00006oooool3o`0001oooooo1_l0000Pooooo`03o`000?oooooooooo02;ooooo
1Ol0000Aooooo`03o`000?oooooooooo043ooooo000?ooooo`03ogMgMomVIVKooooo00Wooooo00?o
0000okZj^_ooool02oooool00omVIVKoMgMgooooo`0Kooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`;o00008oooool5o`00023ooooo00?o
0000ooooooooool08_ooool5o`00017ooooo00?o0000ooooooooool0@?ooool000kooooo00?ogMgM
oa0@4?o^k^h02_ooool2oc8b<Pcooooo00?ok^k^oa0@4?oMgMd06oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool3o`0002Gooooo1_l0000P
ooooo`03o`000?oooooooooo027ooooo1_l0000Aooooo`03o`000?oooooooooo03oooooo0003oooo
o`03oa0@4?l0003o000000;o000000?o410@ooooooooool00oooool01?mEEEGoV9RHooooooooool2
o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P03ooooo`03ohN7QomVIVKooooo01[ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`04ooooo`?o00005oooool3o`0002Wooooo1Ol0000Qooooo`03o`000?oooooooooo027ooooo1Ol0
000Booooo`03o`000?oooooooooo03kooooo0005ooooo`03o`000?oooooooooo00Kooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00oo^k^ko0000ooooo`0Jooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooool000000ol0000Gooooo`?o0000;?ooool5o`0002;ooooo00?o0000
ooooooooool08?ooool5o`0001?ooooo00?o0000ooooooooool0?Oooool000Gooooo00?o0000oooo
ooooool01_ooool00olb<S;oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo1Ol0000D
ooooo`?o0000<?ooool5o`0002;ooooo00?o0000ooooooooool08?ooool5o`0001;ooooo00?o0000
ooooooooool0?Oooool000Gooooo00?o0000ooooooooool01_ooool00olb<S;oooooooooo`02oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo03?ooooo1Ol0000@ooooo`?o0000<oooool5o`0002?ooooo00?o0000
ooooooooool07oooool5o`0001?ooooo00?o0000ooooooooool0??ooool000Gooooo00?o0000oooo
ooooool01_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000
ooooooooool01Oooool00oo^k^ko0000ooooo`0Iooooo`03o`000?oooooooooo03?ooooo1_l0000<
ooooo`?o0000=_ooool5o`0002?ooooo00?o0000ooooooooool07oooool5o`0001Cooooo00?o0000
ooooooooool0>oooool000?ooooo00?o410@o`000?l000000ol00005ooooo`04oeEEEOmgMgOooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03ogMgMomEEEGo
oooo01Wooooo00?o0000ooooooooool0<oooool7o`0000Wooooo0_l0000jooooo`Go00008oooool0
0ol0003oooooooooo`0Oooooo`Go00005?ooool00ol0003oooooooooo`0jooooo`001Oooool00ol0
003oooooooooo`06ooooo`03omgMgOl@413ok^k^017ooooo00?o0000ooooooooool01?ooool00oo^
k^ko410@omgMg@0Jooooo`03o`000?oooooooooo03Cooooo1ol00005ooooo`?o0000??ooool6o`00
02?ooooo00?o0000ooooooooool07_ooool5o`0001Gooooo00?o0000ooooooooool0>Oooool000Go
oooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?oIVIVogMgMoooool06_ooool00ol0003oooooooooo`0eooooo`Oo000000Coooooo`000?l0
003o0000?oooool6o`0002Cooooo00?o0000ooooooooool07Oooool5o`0001Gooooo00?o0000oooo
ooooool0>Oooool000Gooooo00Co^[Zjoa0@4?l0003o410@?Oooool00ol0003oooooooooo`0foooo
o`Oo0000@oooool6o`0002Cooooo00?o0000ooooooooool07Oooool5o`0001Gooooo00?o0000oooo
ooooool0>?ooool004Kooooo00?o0000ooooooooool0=oooool7o`0004?ooooo1Ol0000Uooooo`03
o`000?oooooooooo01cooooo1Ol0000Fooooo`03o`000?oooooooooo03Oooooo0016ooooo`03o`00
0?oooooooooo03Cooooo0ol000000ooooooo0000o`000005o`0004;ooooo1Ol0000Uooooo`03o`00
0?oooooooooo01cooooo1Ol0000Gooooo`03o`000?oooooooooo03Kooooo0015ooooo`03o`000?oo
oooooooo03?ooooo0_l00005ooooo`Oo0000@_ooool4o`0002Kooooo00?o0000ooooooooool07?oo
ool5o`0001Kooooo00?o0000ooooooooool0=_ooool004Gooooo00?o0000ooooooooool0<?ooool3
o`0000Sooooo1ol00011ooooo`Go00009_ooool00ol0003oooooooooo`0Kooooo`Go00005oooool0
0ol0003oooooooooo`0eooooo`00AOooool00ol0003oooooooooo`0]ooooo`?o00002oooool7o`00
047ooooo1Ol0000Wooooo`03o`000?oooooooooo01[ooooo1Ol0000Hooooo`03o`000?oooooooooo
03Cooooo0015ooooo`03o`000?oooooooooo02[ooooo0ol0000@ooooo`Go0000@Oooool5o`0002So
oooo00?o0000ooooooooool06_ooool5o`0001;ooooo00?o0000o`3o0?ooool00oooool00ol0003o
ooooooooo`0cooooo`00AOooool00ol0003oooooooooo`0Wooooo`?o00005?ooool5o`00047ooooo
1?l0000Yooooo`03o`000?oooooooooo01Wooooo1Ol00008ooooo`[o000000?oooooo`3o0?ooool0
0oooool00ol0003oooooooooo`0cooooo`00AOooool00ol0003oooooooooo`0Tooooo`?o00005ooo
ool6o`00043ooooo1Ol0000Xooooo`03o`000?oooooooooo01Wooooo3Ol0000;ooooo`03o`3o0?oo
oooooooo00?ooooo00?o0000ooooooooool0<_ooool004Gooooo00?o0000ooooooooool08Oooool3
o`0001[ooooo1ol0000oooooo`Go0000:Oooool00ol0003oooooooooo`0@ooooo`ko00004_ooool0
0ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo037ooooo0015ooooo`03o`000?oooooooooo
01oooooo0_l0000Nooooo`Ko0000?oooool5o`0002[ooooo00?o0000ooooooooool01oooool8o`00
00Wooooo1Ol0000Booooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool004Co
oooo00?o0000ooooooooool07Oooool3o`00027ooooo1Ol00010ooooo`Co0000:oooool9o`00017o
oooo1Ol0000Cooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool004Cooooo
00?o0000ooooooooool06_ooool3o`0002Gooooo1Ol0000oooooo`Go00009?ooool8o`0001Wooooo
1Ol0000Booooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool004Cooooo00?o
0000ooooooooool05oooool3o`0002Sooooo1Ol0000oooooo`Go00007_ooool6o`0000Sooooo00?o
0000ooooooooool05_ooool5o`0001;ooooo00?o0?l0ooooooooool01_ooool00ol0003ooooooooo
o`0^ooooo`00A?ooool00ol0003oooooooooo`0Dooooo`?o0000:oooool6o`0003kooooo1Ol0000F
ooooo`So00003oooool00ol0003oooooooooo`0Eooooo`Go00004_ooool00ol0o`3oooooooooo`07
ooooo`03o`000?oooooooooo02gooooo0014ooooo`03o`000?oooooooooo017ooooo0ol0000_oooo
o`Ko0000?_ooool4o`00013ooooo00?o0000o`3o0?l000000ol0000Gooooo`03o`000?oooooooooo
01Kooooo1Ol0000Aooooo`03o`3o0?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool004Co
oooo00?o0000ooooooooool03oooool2o`0003;ooooo1Ol000000ooooooo0000ooooo`0looooo`Go
00002_ooool5o`000003ooooool0o`3ooooo01_ooooo00?o0000ooooooooool05Oooool5o`00017o
oooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`00A?ooool00ol0003ooooo
ooooo`0<ooooo`?o0000=Oooool5o`000003ooooool0003ooooo03_ooooo1Ol00004ooooo`Ko0000
1_ooool00ol0o`3oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo1Ol0000Aooooo`03o`3o
0?oooooooooo00Wooooo00?o0000ooooooooool0:oooool004Cooooo00?o0000ooooooooool02Ooo
ool3o`0003Sooooo1Ol00002ooooo`03o`000?oooooooooo03Wooooo2Ol0000<ooooo`03o`3o0?oo
oooooooo01cooooo00?o0000ooooooooool05?ooool5o`00013ooooo00?o0?l0ooooooooool02_oo
ool00ol0003oooooooooo`0Zooooo`00A?ooool00ol0003oooooooooo`06ooooo`?o0000>oooool5
o`0000?ooooo00?o0000ooooooooool0=_ooool7o`00013ooooo00?o0?l0ooooooooool07Oooool0
0ol0003oooooooooo`0Cooooo`Go00004?ooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooo
oooo02Wooooo0013ooooo`03o`000?oooooooooo00Cooooo0ol0000oooooo`Go00000oooool00ol0
003oooooooooo`0_ooooo`Ko00000oooool5o`0000oooooo00?o0?l0ooooooooool07_ooool00ol0
003oooooooooo`0Booooo`Go00004?ooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooooooo
02Wooooo0013ooooo`04o`000?ooooooooooooooo`?o0000@_ooool5o`0000Cooooo00?o0000oooo
ooooool0:Oooool5o`0000Wooooo1Ol0000?ooooo`03o`3o0?oooooooooo01kooooo00?o0000oooo
ooooool04oooool4o`00013ooooo00?o0?l0ooooooooool03?ooool00ol0003oooooooooo`0Xoooo
o`00@oooool4o`0004Gooooo1Ol00005ooooo`03o`000?oooooooooo02;ooooo1_l0000>ooooo`Go
00003oooool00ol0o`3oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo1Ol0000?ooooo`03
o`3o0?oooooooooo00gooooo00?o0000ooooooooool09oooool004?ooooo0_l00018ooooo`Co0000
1_ooool00ol0003oooooooooo`0Mooooo`Co00005Oooool5o`0000kooooo00?o0?l0ooooooooool0
8?ooool00ol0003oooooooooo`0Aooooo`Go00003oooool00ol0o`3oooooooooo`0>ooooo`03o`00
0?oooooooooo02Kooooo0015ooooo`03o`000?oooooooooo04Gooooo1Ol00006ooooo`03o`000?oo
oooooooo01Oooooo1Ol0000Iooooo`Go00003_ooool00ol0o`3oooooooooo`0Qooooo`03o`000?oo
oooooooo013ooooo1Ol0000?ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool09_oo
ool004Kooooo00?o0000ooooooooool0A?ooool5o`0000Oooooo00?o0000ooooooooool04_ooool4
o`0001kooooo1Ol0000>ooooo`03o`3o0?oooooooooo02;ooooo00?o0000ooooooooool04?ooool5
o`0000kooooo00?o0?l0ooooooooool03oooool00ol0003oooooooooo`0Uooooo`00Aoooool00ol0
003oooooooooo`13ooooo`Go00002?ooool00ol0003oooooooooo`0<ooooo`Go00008oooool5o`00
00gooooo00?o0?l0ooooooooool08oooool00ol0003oooooooooo`0?ooooo`Go00003_ooool00ol0
o`3oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo0018ooooo`03o`000?oooooooooo04?o
oooo1Ol00008ooooo`03o`000?oooooooooo00Kooooo1Ol0000Xooooo`Go00003Oooool00ol0o`3o
ooooooooo`0Sooooo`03o`000?oooooooooo00oooooo1Ol0000>ooooo`03o`3o0?oooooooooo017o
oooo00?o0000ooooooooool08oooool004Wooooo00?o0000ooooooooool0@_ooool5o`0000Wooooo
00Co0000oooooooooooooooo1?l0000]ooooo`Go00003Oooool00ol0o`3oooooooooo`0Tooooo`03
o`000?oooooooooo00oooooo1Ol0000=ooooo`03o`3o0?oooooooooo01;ooooo00?o0000oooooooo
ool08_ooool004[ooooo00?o0000ooooooooool0@Oooool5o`0000[ooooo00?o0000ooooool00000
<_ooool4o`0000gooooo00?o0?l0ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`Go0000
3_ooool00ol0o`3oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo001;ooooo`03o`000?oo
oooooooo047ooooo1?l0000;ooooo`03o`000?l0o`3ooooo037ooooo1?l0000=ooooo`03o`3o0?oo
oooooooo02Kooooo00?o0000ooooooooool03Oooool5o`0000kooooo00?o0?l0ooooooooool04_oo
ool00ol0003oooooooooo`0Qooooo`00C?ooool00ol0003oooooooooo`10ooooo`Co00003?ooool0
0ol0o`3oooooooooo`0`ooooo`Go00003?ooool00ol0o`3oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo1Ol0000=ooooo`03o`3o0?oooooooooo01?ooooo00?o0000ooooooooool08?ooool0
04gooooo00?o0000ooooooooool0?oooool4o`0000cooooo00?o0?l0o`000?ooool0<?ooool5o`00
00cooooo00?o0?l0ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`Go00003Oooool00ol0
o`3oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo001>ooooo`03o`000?oooooooooo03ko
oooo1?l0000<ooooo`03o`3o0?oooooo0000033ooooo1Ol0000<ooooo`03o`3o0?oooooooooo02So
oooo00?o0000ooooooooool03?ooool5o`0000gooooo00?o0?l0ooooooooool05?ooool00ol0003o
ooooooooo`0Oooooo`00Coooool2o`0003kooooo1Ol0000;ooooo`04o`3o0?ooooooooooo`00033o
oooo1?l0000<ooooo`03o`3o0?oooooooooo02Wooooo00?o0000ooooooooool03?ooool4o`0000go
oooo00?o0?l0ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`00DOooool00ol0003ooooo
ooooo`0kooooo`Go00002oooool01Ol0o`3ooooooooooooooooo000002oooooo1?l0000<ooooo`03
o`3o0?oooooooooo02[ooooo00?o0000ooooooooool02oooool4o`0000gooooo00?o0?l0oooooooo
ool05_ooool00ol0003oooooooooo`0Mooooo`00D_ooool00ol0003oooooooooo`0jooooo`Go0000
2oooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo02cooooo1Ol0000;ooooo`03o`3o
0?oooooooooo02_ooooo00?o0000ooooooooool02_ooool5o`0000cooooo00?o0?l0ooooooooool0
5oooool00ol0003oooooooooo`0Looooo`00Doooool00ol0003oooooooooo`0jooooo`Co00002ooo
ool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo1Ol0000;ooooo`03o`3o0?oo
oooooooo02cooooo00?o0000ooooooooool02Oooool5o`0000cooooo00?o0?l0ooooooooool05ooo
ool00ol0003oooooooooo`0Looooo`00E?ooool00ol0003oooooooooo`0iooooo`Go00002_ooool0
0ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo1Ol0000;ooooo`03o`3o0?oooooo
oooo02gooooo00?o0000ooooooooool02?ooool5o`0000cooooo00?o0?l0ooooooooool06?ooool0
0ol0003oooooooooo`0Kooooo`00EOooool00ol0003oooooooooo`0hooooo`Go00002_ooool00ol0
o`3oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo1?l0000;ooooo`03o`3o0?oooooooooo
02gooooo00?o0000ooooooooool02Oooool4o`0000cooooo00?o0?l0ooooooooool06Oooool00ol0
003oooooooooo`0Jooooo`00E_ooool00ol0003oooooooooo`0gooooo`Go00002_ooool00ol0o`3o
ooooooooo`06ooooo`03o`000?oooooooooo02Wooooo1?l0000;ooooo`03o`3o0?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool4o`0000cooooo00?o0?l0ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`00Eoooool00ol0003oooooooooo`0gooooo`Co00002_ooool00ol0o`3ooooo
ooooo`07ooooo`03o`000?oooooooooo02Sooooo1?l0000;ooooo`03o`3o0?oooooooooo02oooooo
00?o0000ooooooooool01oooool5o`0000_ooooo00?o0?l0ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`00F?ooool00ol0003oooooooooo`0fooooo`Co00002_ooool00ol0o`3ooooooooo
o`08ooooo`03o`000?oooooooooo02Oooooo1Ol0000:ooooo`03o`3o0?oooooooooo033ooooo00?o
0000ooooooooool01_ooool5o`0000_ooooo00?o0?l0ooooooooool06oooool00ol0003ooooooooo
o`0Hooooo`00FOooool00ol0003oooooooooo`0eooooo`Co00002Oooool00ol0o`3oooooooooo`0:
ooooo`03o`000?oooooooooo02Kooooo1Ol0000:ooooo`03o`3o0?oooooooooo037ooooo00?o0000
ooooooooool01Oooool5o`0000_ooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`0G
ooooo`00F_ooool00ol0003oooooooooo`0dooooo`Co00002Oooool00ol0o`3oooooooooo`0;oooo
o`03o`000?oooooooooo02Gooooo1Ol0000:ooooo`03o`3o0?oooooooooo03;ooooo00?o0000oooo
ooooool01Oooool5o`0000[ooooo00?o0?l0ooooooooool07Oooool00ol0003oooooooooo`0Foooo
o`00Foooool00ol0003oooooooooo`0cooooo`Co00002Oooool00ol0o`3oooooooooo`0<ooooo`03
o`000?oooooooooo02Gooooo1?l0000:ooooo`03o`3o0?oooooooooo03?ooooo00?o0000oooooooo
ool01?ooool5o`0000[ooooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0Eooooo`00
G?ooool2o`0003?ooooo1Ol00008ooooo`03o`3o0?oooooooooo00gooooo00?o0000ooooooooool0
9?ooool4o`0000[ooooo00?o0?l0ooooooooool0<oooool00ol0003oooooooooo`04ooooo`Go0000
2_ooool00ol0o`3oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo001Nooooo`03o`000?oo
oooooooo033ooooo1Ol00008ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool08ooo
ool5o`0000Wooooo00?o0?l0ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`Go00002_oo
ool00ol0o`3oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo001Oooooo`03o`000?oooooo
oooo02oooooo1Ol00008ooooo`03o`3o0?oooooooooo00oooooo00?o0000ooooooooool08_ooool5
o`0000Wooooo00?o0?l0ooooooooool04oooool6o`0001cooooo00?o0000ooooooooool00oooool5
o`0000[ooooo00?o0?l0ooooooooool07oooool00ol0003oooooooooo`0Cooooo`00H?ooool00ol0
003oooooooooo`0_ooooo`Co00002?ooool00ol0o`3oooooooooo`0>ooooo`Go00002ooooolTo`00
0003o`3o0?l0003o000000;o00003oooool:o`0001_ooooo00?o0000ooooooooool00_ooool5o`00
00[ooooo00?o0?l0ooooooooool08?ooool00ol0003oooooooooo`0Booooo`00HOooool00ol0003o
ooooooooo`0^ooooo`Co00002?ooool00ol0o`3oooooooooo`0<oooooa;o00005oooool4o`0000Wo
oooo00?o0?l0ooooooooool00_oooolKo`0001[ooooo00?o0000ooooooooool00_ooool5o`0000Wo
oooo00?o0?l0ooooooooool08?ooool00ol0003oooooooooo`0Booooo`00H_ooool00ol0003ooooo
ooooo`0]ooooo`Co00002?ooool00ol0o`3oooooooooo`0;ooooo`[o00008?ooool4o`0000Wooooo
00?o0?l0ooooooooool03ooooolDo`0001Gooooo00Co0000oooooooooooooooo1Ol00009ooooo`03
o`3o0?oooooooooo027ooooo00?o0000ooooooooool04Oooool006?ooooo00?o0000ooooooooool0
;?ooool4o`0000Sooooo00?o0?l0ooooooooool02_ooool;o`00023ooooo1?l00009ooooo`03o`3o
0?oooooooooo00kooooo4?l00005ooooo`Wo00003?ooool01?l0003oooooooooooooool5o`0000Wo
oooo00?o0?l0ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`00I?ooool00ol0003ooooo
ooooo`0[ooooo`Co00002?ooool00ol0o`3oooooooooo`0:ooooo`_o00008?ooool5o`0000Sooooo
00?o0?l0ooooooooool03_ooool6o`0000Cooooo1_l0000>ooooo`[o00000oooool01?l0003ooooo
ooooooooool5o`0000Sooooo00?o0?l0ooooooooool08oooool00ol0003oooooooooo`0?ooooo`00
IOooool00ol0003oooooooooo`0Zooooo`Co00002?ooool00ol0o`3oooooooooo`0:ooooo`Go0000
1Oooool00ol0003oooooooooo`0Nooooo`Go00002?ooool00ol0o`3oooooooooo`0=ooooo`Ko0000
1oooool4o`0001Sooooo3?l00008ooooo`03o`3o0?oooooooooo02?ooooo00?o0000ooooooooool0
3oooool006Kooooo00?o0000ooooooooool0:Oooool5o`0000Oooooo00?o0?l0ooooooooool02Ooo
ool5o`0000Oooooo00?o0000ooooooooool07Oooool5o`0000Sooooo00?o0?l0ooooooooool03Ooo
ool5o`0002Wooooo00?o0000ooooool000002?l00004ooooo`03o`3o0?oooooooooo02Cooooo00?o
0000ooooooooool03_ooool006Oooooo00?o0000ooooooooool0:?ooool5o`0000Oooooo00?o0?l0
ooooooooool02Oooool5o`0000Sooooo00?o0000ooooooooool07Oooool4o`0000Sooooo00?o0?l0
ooooooooool03?ooool6o`0002[ooooo00?o0000ooooool000001?l00003ooooo`Co000000?o0?l0
ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`00J?ooool2o`0002Sooooo1Ol00007oooo
o`03o`3o0?oooooooooo00Sooooo1_l00009ooooo`03o`000?oooooooooo01cooooo1Ol00007oooo
o`03o`3o0?oooooooooo00cooooo1Ol0000/ooooo`Ko00001oooool00ol0o`3o0000o`000005o`00
017ooooo2_l00006ooooo`03o`000?oooooooooo00cooooo001Zooooo`03o`000?oooooooooo02Ko
oooo1?l00007ooooo`03o`3o0?oooooooooo00Sooooo1Ol0000;ooooo`03o`000?oooooooooo01_o
oooo1Ol00007ooooo`03o`3o0?oooooooooo00_ooooo1_l0000/ooooo`Oo00001_ooool00ol0o`3o
ooooooooo`05ooooo`Go00002oooool=o`0000Cooooo00?o0000ooooooooool03?ooool006_ooooo
00?o0000ooooooooool09Oooool4o`0000Oooooo00?o0?l0ooooooooool01oooool6o`0000cooooo
00?o0000ooooooooool06_ooool5o`0000Oooooo00?o0?l0ooooooooool02oooool5o`0002kooooo
1_l00006ooooo`03o`3o0?oooooooooo00[ooooo1Ol00005ooooo`oo00001?ooool00ol0003ooooo
ooooo`0;ooooo`00K?ooool00ol0003oooooooooo`0Tooooo`Co00001oooool00ol0o`3ooooooooo
o`07ooooo`Go00003_ooool00ol0003oooooooooo`0Jooooo`Go00001_ooool00ol0o`3ooooooooo
o`0:ooooo`Ko0000;oooool5o`0000Kooooo00?o0?l0ooooooooool03ooooolFo`0000?ooooo00?o
0000ooooooooool02_ooool006gooooo00?o0000ooooooooool08oooool4o`0000Oooooo00?o0?l0
ooooooooool01_ooool6o`0000oooooo00?o0000ooooooooool06Oooool5o`0000Kooooo00?o0?l0
ooooooooool02_ooool5o`00037ooooo1Ol00005ooooo`03o`3o0?oooooooooo017ooooo2?l00004
ooooo`Wo00000oooool00ol0003oooooooooo`09ooooo`00K_ooool00ol0003oooooooooo`0Roooo
o`Co00001oooool00ol0o`3oooooooooo`06ooooo`Go00004Oooool00ol0003oooooooooo`0Hoooo
o`Go00001_ooool00ol0o`3oooooooooo`09ooooo`Ko0000<Oooool5o`0000Gooooo00?o0?l0oooo
ooooool04Oooool7o`000003ooooool0003o000000?o000000?oooooo`000?l000001_l00003oooo
o`03o`000?oooooooooo00Sooooo001_ooooo`03o`000?oooooooooo027ooooo1?l00007ooooo`03
o`3o0?oooooooooo00Kooooo1Ol0000Booooo`03o`000?oooooooooo01Sooooo1Ol00005ooooo`03
o`3o0?oooooooooo00Wooooo1Ol0000booooo`Ko00001?ooool00ol0o`3oooooooooo`0@ooooo`Oo
00001oooool9o`0000?ooooo00?o0000ooooooooool02?ooool0073ooooo00?o0000ooooooooool0
8?ooool4o`0000Oooooo00?o0?l0ooooooooool01_ooool4o`0001Cooooo00?o0000ooooooooool0
5oooool5o`0000Gooooo00?o0?l0ooooooooool02Oooool5o`0003?ooooo1Ol00004ooooo`03o`3o
0?oooooooooo013ooooo1Ol0000=ooooo`Oo00000_ooool00ol0003oooooooooo`07ooooo`00LOoo
ool00ol0003oooooooooo`0Oooooo`Go00001Oooool00ol0o`3oooooooooo`07ooooo`Co00005Ooo
ool00ol0003oooooooooo`0Fooooo`Go00001Oooool00ol0o`3oooooooooo`08ooooo`Go0000=?oo
ool5o`0000Gooooo00?o0?l0ooooooooool03_ooool6o`0000kooooo1ol00002ooooo`03o`000?oo
oooooooo00Kooooo001booooo`03o`000?oooooooooo01kooooo1Ol00005ooooo`03o`3o0?oooooo
oooo00Kooooo1Ol0000Fooooo`03o`000?oooooooooo01Kooooo1?l00005ooooo`03o`3o0?oooooo
oooo00Sooooo1Ol0000eooooo`Go00001?ooool00ol0o`3oooooooooo`0=ooooo`Ko00003oooool7
o`000004ooooool0003o0000o`0000Oooooo001cooooo`03o`000?oooooooooo01gooooo1Ol00005
ooooo`03o`3o0?oooooooooo00Kooooo1Ol0000Gooooo`03o`000?oooooooooo01Gooooo1?l00005
ooooo`03o`3o0?oooooooooo00Sooooo1Ol0000eooooo`Go00001?ooool00ol0o`3oooooooooo`0<
ooooo`Oo00004?ooool7o`0000;ooooo00?o0000ooooooooool01Oooool007Cooooo00?o0000oooo
ooooool07Oooool4o`0000Gooooo00?o0?l0ooooooooool01_ooool5o`0001Sooooo00?o0000oooo
ooooool05?ooool5o`0000Cooooo00?o0?l0ooooooooool01oooool5o`0003Kooooo1_l00003oooo
o`03o`3o0?oooooooooo00cooooo1_l0000Aooooo`Ko00000oooool00ol0003oooooooooo`05oooo
o`00MOooool2o`0001gooooo1?l00005ooooo`03o`3o0?oooooooooo00Gooooo1Ol0000Jooooo`03
o`000?oooooooooo01?ooooo1Ol00004ooooo`03o`3o0?oooooooooo00Oooooo1Ol0000gooooo`Go
00000oooool00ol0o`3oooooooooo`0;ooooo`Ko00003oooool3o`0000Wooooo00?o0000oooooooo
ool01Oooool007Oooooo00?o0000ooooooooool06_ooool4o`0000Gooooo00?o0?l0ooooooooool0
1Oooool5o`0001_ooooo00?o0000ooooooooool04_ooool5o`0000Cooooo00?o0?l0ooooooooool0
1oooool5o`0003Oooooo1_l00002ooooo`03o`3o0?oooooooooo00_ooooo1Ol0000=ooooo`?o0000
3?ooool00ol0003oooooooooo`05ooooo`00N?ooool00ol0003oooooooooo`0Iooooo`Co00001Ooo
ool00ol0o`3oooooooooo`05ooooo`Go00007?ooool00ol0003oooooooooo`0Booooo`Co00001?oo
ool00ol0o`3oooooooooo`06ooooo`Go0000>Oooool5o`0000;ooooo00?o0?l0ooooooooool02_oo
ool6o`0000Wooooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo001iooooo`03o`000?oooooo
oooo01Sooooo1?l00005ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Nooooo`03o`000?oooooo
oooo017ooooo1Ol00003ooooo`03o`3o0?oooooooooo00Kooooo1Ol0000iooooo`Ko000000?ooooo
o`3o0?ooool02_ooool6o`0000Oooooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001joooo
o`03o`000?oooooooooo01Oooooo1?l00005ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Ooooo
o`03o`000?oooooooooo013ooooo1Ol00003ooooo`03o`3o0?oooooooooo00Kooooo1Ol0000joooo
o`Ko000000?o0?l0ooooooooool02?ooool7o`0000?ooooo1?l0000Gooooo`03o`000?oooooooooo
00Cooooo001kooooo`03o`000?oooooooooo01Kooooo1?l00005ooooo`03o`3o0?oooooooooo00Co
oooo1Ol0000Pooooo`03o`000?oooooooooo00oooooo1Ol00003ooooo`03o`3o0?oooooooooo00Go
oooo1Ol0000kooooo`Oo00002_ooool6o`000004ooooool0003o0000o`0001_ooooo00?o0000oooo
ooooool01?ooool007cooooo00?o0000ooooooooool05Oooool5o`0000Cooooo00?o0?l0oooooooo
ool00oooool5o`0002;ooooo00?o0000ooooooooool03oooool4o`0000?ooooo00?o0?l0oooooooo
ool01Oooool5o`0003cooooo1ol00008ooooo`So00007_ooool00ol0003oooooooooo`04ooooo`00
OOooool00ol0003oooooooooo`0Dooooo`Go00001?ooool00ol0o`3oooooooooo`03ooooo`Go0000
8oooool00ol0003oooooooooo`0>ooooo`Go00000_ooool00ol0o`3oooooooooo`05ooooo`Go0000
?Oooool7o`0000Oooooo1Ol0000Qooooo`03o`000?oooooooooo00Cooooo001nooooo`03o`000?oo
oooooooo01?ooooo1Ol00004ooooo`03o`3o0?oooooooooo00?ooooo1Ol0000Tooooo`03o`000?oo
oooooooo00gooooo1Ol00002ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000nooooo`Oo00001Ooo
ool7o`00027ooooo00?o0000ooooooooool01?ooool007oooooo00?o0000ooooooooool04oooool4
o`0000Cooooo00?o0?l0ooooooooool00oooool4o`0002Kooooo00?o0000ooooooooool03?ooool5
o`0000;ooooo00?o0?l0ooooooooool01?ooool5o`0003oooooo4Ol0000Rooooo`03o`000?oooooo
oooo00Cooooo0020ooooo`03o`000?oooooooooo01;ooooo1Ol00003ooooo`03o`3o0?oooooooooo
00;ooooo1Ol0000Wooooo`03o`000?oooooooooo00cooooo1Ol000000ooooooo0?l0ooooo`04oooo
o`Ko0000@?ooool@o`0002;ooooo00?o0000ooooooooool01?ooool0087ooooo0_l0000Booooo`Go
00000oooool00ol0o`3oooooooooo`02ooooo`Go0000:?ooool00ol0003oooooooooo`0;ooooo`Go
000000?oooooo`3o0?ooool01?ooool5o`00043ooooo4?l0000Sooooo`03o`000?oooooooooo00Co
oooo0023ooooo`03o`000?oooooooooo00oooooo1Ol00003ooooo`03o`3o0?oooooooooo00;ooooo
1Ol0000Yooooo`03o`000?oooooooooo00[ooooo1Ol000000ooooooo0?l0ooooo`04ooooo`Go0000
?Oooool3o`0000;ooooo3?l0000Uooooo`03o`000?oooooooooo00Cooooo0024ooooo`03o`000?oo
oooooooo00oooooo1?l00003ooooo`04o`3o0?ooooooooooooooo`Go0000:oooool00ol0003ooooo
ooooo`0:ooooo`Go000000?o0?l0ooooooooool00_ooool5o`0003_ooooo0ol00007ooooo`Wo0000
9oooool00ol0003oooooooooo`03ooooo`00QOooool00ol0003oooooooooo`0>ooooo`Co00000ooo
ool01?l0o`3oooooooooooooool5o`0002cooooo00?o0000ooooooooool02Oooool6o`0000Cooooo
1Ol0000gooooo`Co00003?ooool5o`0002Wooooo00?o0000ooooooooool00oooool008Kooooo00?o
0000ooooooooool03Oooool4o`0000?ooooo00Co0?l0oooooooooooooooo1Ol0000]ooooo`03o`00
0?oooooooooo00Sooooo1_l00002ooooo`Oo0000=?ooool3o`0001Gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`03ooooo`00Qoooool00ol0003oooooooooo`0<ooooo`Co00000ooo
ool00ol0o`3oooooooooo`05o`0002oooooo00?o0000ooooooooool02?ooool=o`00037ooooo1?l0
000Iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool008Sooooo00?o0000
ooooooooool02oooool4o`0000;ooooo00Co0?l0oooooooooooooooo1Ol0000`ooooo`03o`000?oo
oooooooo00Sooooo3?l0000^ooooo`?o00007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00?ooooo0029ooooo`03o`000?oooooooooo00[ooooo1?l00002ooooo`04o`3o0?oooooo
ooooooooo`Go0000<Oooool00ol0003oooooooooo`07ooooo`_o0000;?ooool3o`0002;ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`00R_ooool00ol0003oooooooooo`09
ooooo`Go000000Coooooo`3o0?oooooooooo1Ol0000cooooo`03o`000?oooooooooo00Oooooo2?l0
000Zooooo`Co00009_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo002;
ooooo`03o`000?oooooooooo00Sooooo1Ol000001?oooooo0?l0ooooooooool5o`0003Cooooo00?o
0000ooooooooool01oooool6o`0002Sooooo0ol0000Zooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool00oooool008cooooo00?o0000ooooooooool01oooool5o`000004ooooool0o`3o
ooooooooo`Go0000=Oooool00ol0003oooooooooo`0`ooooo`Co0000;_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00?ooooo002=ooooo`03o`000?oooooooooo00Oooooo1?l00000
1?oooooo0?l0ooooooooool4o`0003Oooooo00?o0000ooooooooool0;?ooool3o`0003?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00S_ooool2o`0000Oooooo1?l00000
1?oooooo0?l0ooooooooool4o`0003Sooooo00?o0000ooooooooool09oooool4o`0003Oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`00T?ooool00ol0003oooooooooo`04
ooooo`Co000000Coooooo`3o0?oooooooooo1?l0000iooooo`03o`000?oooooooooo02?ooooo0ol0
000looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool0097ooooo00?o0000
ooooooooool00oooool5o`000003o`3o0?oooooo000000Co0000>_ooool00ol0003oooooooooo`0O
ooooo`?o0000@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo002Boooo
o`03o`000?oooooooooo00;ooooo1Ol000000ol0o`3oooooo`000004o`0003_ooooo00?o0000oooo
ooooool06_ooool4o`0004?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`00Toooool01?l0003oooooooooooooool<o`0003cooooo00?o0000ooooooooool05_ooool3o`00
04Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00U?ooool01?l0003o
ooooooooooooool:o`0003kooooo00?o0000ooooooooool04Oooool4o`0004cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`02ooooo`00UOooool00ol0003oooooooooo`0:o`0003oo
oooo00?o0000ooooooooool03Oooool3o`00057ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`00U_ooool00ol0003oooooooooo`08o`00047ooooo00?o0000ooooooooool0
2Oooool3o`0005Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`00Uooo
ool00ol0003oooooo`000007o`0004;ooooo00?o0000ooooooooool01?ooool4o`0005Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00V?ooool00ol0003oooooo`000005
o`0004Cooooo00?o0000ooooooooool00ol0001Nooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool009Wooooo00?o0000ooooooooool0BOooool2o`00067ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`02ooooo`00V_ooool2o`0004Wooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo007ooooo002Looooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo007ooooo002Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo002Nooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo007ooooo002Oooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo007ooooo002Pooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo007o
oooo002Qooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo007ooooo002Rooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo007ooooo002S
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo007ooooo002Tooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo002Uooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0@ooooo`7o
00000Oooool1ooooo`00Y_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool04?ooool1o`00007ooooo0Oooool00:Oooooo0_l0000looooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool00:Wooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00kooooo0Ol00001
ooooo`7ooooo002Zooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0=ooooo`7o00000Oooool1ooooo`00Zoooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool03?ooool1o`00007ooooo0Oooool00:cooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo002]ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00[_ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
0:oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Wooooo0Ol00001ooooo`7ooooo002`ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00/Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool02?ooool1o`00007ooooo
002booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`07ooooo`7o00000Oooool00;?ooooo0_l0000`ooooo`03o`000?oooooooooo07Gooooo00?o0000
ooooooooool01_ooool1o`00007ooooo002eooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0MOooool00ol0003oooooooooo`06ooooo`7o00000Oooool00;Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00
]oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo002hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool00;Wooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00^_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo07[ooooo00Go0000ooooooooooooooooo`000001
ooooo`00^oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo00Go0000oooo
ooooooooooooo`000001ooooo`00_?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
07_ooooo00Co0000oooooooooooooooo0Ol000000;gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo007o0000002nooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0OOooool1o`00007ooooo0Ol000000;oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1nooooo`;o00000030ooooo`;o00008oooool00ol0003ooooooooo
o`1mooooo`?o00000032ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0NOooool4
o`0000?ooooo0033ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0MOooool4o`00
00Oooooo0034ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0L_ooool3o`0000_o
oooo0035ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0K_ooool4o`0000kooooo
0036ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0J_ooool4o`0001;ooooo0037
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0I_ooool4o`0001Kooooo0038oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0H_ooool4o`0001[ooooo0039ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0G_ooool4o`0001kooooo003:ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0Foooool3o`0002;ooooo003;ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0Eoooool4o`0002Gooooo003<ooooo`;o00005oooool0
0ol0003oooooooooo`1Cooooo`Co0000:Oooool00<kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1?ooooo`Co0000;Oooool00<oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1;ooooo`Co0000<Oooool00=3ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`18ooooo`?o0000=Oooool00=7ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`14ooooo`Co0000>?ooool00=;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`10
ooooo`Co0000??ooool00=?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0loooo
o`Co0000@?ooool00=Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0hooooo`Co
0000A?ooool00=Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0dooooo`Co0000
B?ooool00=Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`?o0000C?oo
ool00=Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0]ooooo`Co0000Coooool0
0=Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`Co0000Doooool00=Wo
oooo0_l0000:ooooo`03o`000?oooooooooo02Gooooo1?l0001Gooooo`00foooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo027ooooo1?l0001Kooooo`00g?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo1?l0001Oooooo`00gOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01[ooooo0ol0001Sooooo`00g_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Kooooo1?l0001Vooooo`00goooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01;ooooo1?l0001Zooooo`00h?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo1?l0001^ooooo`00hOooool01Ol0003ooooooooooooooooo000000cooooo
1?l0001booooo`00h_ooool01?l0003oooooooooool00009ooooo`?o0000M_ooool00>?ooooo00?o
0000ooooool000001Oooool4o`0007Wooooo003Tooooo`;o000000?oooooo`000?l000000_l0001m
ooooo`00iOooool2o`00087ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {346.188, 0}} -> {0, 0, 0, 0}}],

Cell[TextData[{
  "Fig. 7.2 The solution to Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = b\ x\)]],
  ", at three times. Also shown are three characteristics with initial \
conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(-2\), 1, 3\)]],
  ". "
}], "Caption",
  CellTags->"Fig. 7.2"],

Cell[TextData[{
  "\tThe characteristics must be used when solving ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = a\ x\^n\)]],
  ". The solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 
        a\ \(x\_o\^n\) \[ExponentialE]\^\(n\ b\ t\)\)]],
  "  is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        f(0) + \ \(\(\(a\ x\_o\^n\)\/\(n\ b\)\) \((\[ExponentialE]\^\(n\ b\ t\
\) - 1)\)\(\ \)\)\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(7.1.17)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(0) = \(f\_o\)(x\_o)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \(\(f(x, t)\)\( | \_\(x = x(t, x\_o)\)\)\)\)]],
  ". Finally, we must invert Eq. ",
  ButtonBox["(7.1.16)",
    ButtonData:>{"Chapter7.nb", "(7.1.16)"},
    ButtonStyle->"Hyperlink"],
  "  to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_o\)(x, t) = 
        x\ \[ExponentialE]\^\(\(-b\)\ t\)\)]],
  ". Substituting this result into  Eq. ",
  ButtonBox["(7.1.17)",
    ButtonData:>{"Chapter7.nb", "(7.1.17)"},
    ButtonStyle->"Hyperlink"],
  "  yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 
          t)\  = \ \(f\_o\)(
            x\ \[ExponentialE]\^\(\(-b\)\ t\))\  + \ \(\(a\ x\^n\ \(\(\
\[ExponentialE]\)\(\ \)\)\^\(\(-n\)\ b\ t\)\)\/\(n\ b\)\) \
\(\((\[ExponentialE]\^\(n\ b\ t\) - 1)\)\(\ \ \)\(.\)\)\)]],
  " "
}], "UNNEQ"],

Cell[TextData[{
  " An example of the resulting evolution is shown in Cell ",
  ButtonBox["7.2",
    ButtonData:>"Cell 7.2",
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0, b = 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(
          x)\  = \ \[ExponentialE]\^\(-\((x - 1)\)\^2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f0[x_]\  = \ Exp[\(-\((x - 1)\)\^2\)];\)\), "\n", 
    \(\(f[x_, t_]\  = \ f0[x\ Exp[\(-\ t\)]];\)\), "\n", 
    \(\(Table[
        Plot[f[x, t], {x, \(-10\), 20}, PlotRange \[Rule] {0, 1}], {t, 0, 
          4,  .2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.2"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.0766 0 L
.0774 0 L
.07809 0 L
.07885 0 L
.07956 0 L
.0802 0 L
.08095 0 L
.08166 0 L
.08291 0 L
.08362 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09016 0 L
.09148 0 L
.09214 0 L
.09285 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10086 0 L
.10201 0 L
.10333 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11491 0 L
.11554 0 L
.11624 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12081 0 L
.12194 0 L
.12323 0 L
.12446 0 L
.12562 0 L
.12668 0 L
.12789 0 L
.12903 0 L
.13009 0 L
.13107 0 L
.13214 0 L
.13327 0 L
.13441 0 L
.13564 0 L
.1368 0 L
.13785 0 L
.13909 0 L
.13979 0 L
.14043 0 L
.14162 0 L
.14288 0 L
.14402 0 L
.14526 0 L
.14656 0 L
.14777 0 L
.14891 0 L
.14994 0 L
.15113 0 L
.15226 0 L
.15348 0 L
.15478 0 L
.15589 0 L
.15711 0 L
.15842 0 L
.15915 0 L
.15982 0 L
.16113 0 L
.16236 0 L
.16352 0 L
.16456 0 L
.16577 0 L
.1669 0 L
.16796 0 L
.16893 0 L
.16999 0 L
.17111 0 L
.17225 0 L
.17347 0 L
.17462 0 L
Mistroke
.17566 0 L
.17689 0 L
.17758 0 L
.17823 0 L
.1794 0 L
.18065 0 L
.18185 0 L
.18316 0 L
.18441 0 L
.18556 0 L
.1867 0 L
.18773 0 L
.18893 0 L
.19005 0 L
.19128 0 L
.19258 0 L
.19369 0 L
.19491 0 L
.19623 0 L
.19696 0 L
.19763 0 L
.19894 0 L
.20017 0 L
.20122 0 L
.20238 0 L
.20359 0 L
.20472 0 L
.20578 0 L
.20675 0 L
.20781 0 L
.20894 0 L
.21008 0 L
.21129 0 L
.21244 0 L
.21349 0 L
.21472 0 L
.21541 0 L
.21605 0 L
.21723 0 L
.21847 0 L
.21968 0 L
.221 0 L
.22224 0 L
.2234 0 L
.22454 0 L
.22558 0 L
.22677 0 L
.2279 0 L
.22914 0 L
.23044 0 L
Mistroke
.23155 0 L
.23277 0 L
.23409 0 L
.23482 0 L
.2355 0 L
.2368 0 L
.23804 0 L
.23909 0 L
.24025 0 L
.24146 0 L
.2426 0 L
.24365 0 L
.24462 0 L
.24569 0 L
.24681 0 L
.24795 0 L
.24917 0 L
.25032 0 L
.25137 0 L
.2526 0 L
.25393 0 L
.25519 0 L
.25635 0 L
.2576 0 L
.25879 0 L
.25987 0 L
.26103 0 L
.2623 0 L
.26364 0 L
.26479 1e-05 L
.26606 1e-05 L
.26723 1e-05 L
.26831 1e-05 L
.26949 1e-05 L
.27074 2e-05 L
.27284 3e-05 L
.27403 4e-05 L
.27514 5e-05 L
.27643 6e-05 L
.27782 8e-05 L
.27914 .0001 L
.28036 .00012 L
.28267 .00019 L
.28383 .00023 L
.28512 .00029 L
.28777 .00046 L
.28926 .00059 L
.29063 .00073 L
.29189 .0009 L
.29327 .00112 L
Mistroke
.29579 .00166 L
.29712 .00204 L
.29834 .00244 L
.3011 .00365 L
.30354 .00514 L
.30611 .00728 L
.30842 .00983 L
.31057 .0129 L
.31293 .0172 L
.31547 .02311 L
.31817 .03123 L
.3211 .04262 L
.32369 .05528 L
.32644 .07181 L
.33164 .11301 L
.33644 .16389 L
.34604 .30019 L
.35614 .46591 L
.36031 .52658 L
.36477 .57768 L
.36608 .58926 L
.36733 .5985 L
.36854 .60586 L
.36965 .61114 L
.37071 .61479 L
.37184 .61718 L
.37296 .61803 L
.3742 .61718 L
.37549 .61428 L
.37672 .60968 L
.37782 .60404 L
.37902 .59631 L
.38171 .5734 L
.3842 .54591 L
.39355 .4067 L
.4043 .23402 L
.40957 .16414 L
.41441 .11288 L
.41922 .0743 L
.4243 .04547 L
.42694 .03453 L
.42939 .02638 L
.43209 .01937 L
.43498 .01369 L
.43738 .01013 L
.43999 .00721 L
.44245 .00517 L
.44473 .00376 L
.44677 .0028 L
.44903 .002 L
Mistroke
.45139 .00139 L
.4536 .00098 L
.45484 .0008 L
.45617 .00065 L
.45855 .00043 L
.46002 .00034 L
.46139 .00027 L
.46264 .00021 L
.46397 .00017 L
.46514 .00014 L
.46643 .00011 L
.4687 7e-05 L
.46998 5e-05 L
.47135 4e-05 L
.47264 3e-05 L
.47383 3e-05 L
.47496 2e-05 L
.47621 2e-05 L
.47746 1e-05 L
.4788 1e-05 L
.47997 1e-05 L
.48123 1e-05 L
.48242 0 L
.48351 0 L
.48557 0 L
.48673 0 L
.48781 0 L
.48896 0 L
.49001 0 L
.49121 0 L
.49235 0 L
.4935 0 L
.49473 0 L
.4959 0 L
.49697 0 L
.49822 0 L
.49958 0 L
.50086 0 L
.50206 0 L
.5034 0 L
.50467 0 L
.50581 0 L
.50704 0 L
.50838 0 L
.50906 0 L
.5098 0 L
.51112 0 L
.51234 0 L
.51349 0 L
.51474 0 L
Mistroke
.51591 0 L
.517 0 L
.51798 0 L
.51906 0 L
.52019 0 L
.52125 0 L
.52242 0 L
.52364 0 L
.52469 0 L
.52584 0 L
.52708 0 L
.52777 0 L
.5284 0 L
.52963 0 L
.53079 0 L
.53194 0 L
.53319 0 L
.53436 0 L
.53543 0 L
.53668 0 L
.53739 0 L
.53804 0 L
.53924 0 L
.54052 0 L
.54122 0 L
.54186 0 L
.54255 0 L
.54331 0 L
.54459 0 L
.54528 0 L
.54593 0 L
.54717 0 L
.54829 0 L
.54959 0 L
.55082 0 L
.55189 0 L
.55306 0 L
.55428 0 L
.55543 0 L
.55649 0 L
.55747 0 L
.5586 0 L
.55967 0 L
.56083 0 L
.56206 0 L
.56322 0 L
.56427 0 L
.56551 0 L
.56621 0 L
.56685 0 L
Mistroke
.56803 0 L
.56928 0 L
.5705 0 L
.57119 0 L
.57183 0 L
.573 0 L
.57424 0 L
.57535 0 L
.57639 0 L
.57753 0 L
.57876 0 L
.57999 0 L
.58069 0 L
.58134 0 L
.58265 0 L
.58339 0 L
.58406 0 L
.58526 0 L
.58656 0 L
.58778 0 L
.58892 0 L
.58997 0 L
.59111 0 L
.59218 0 L
.59316 0 L
.5943 0 L
.59555 0 L
.59673 0 L
.59782 0 L
.59906 0 L
.60022 0 L
.60126 0 L
.60239 0 L
.60362 0 L
.60492 0 L
.60603 0 L
.60725 0 L
.60856 0 L
.60977 0 L
.6104 0 L
.6111 0 L
.61182 0 L
.61251 0 L
.61376 0 L
.6149 0 L
.61616 0 L
.61748 0 L
.6186 0 L
.61979 0 L
.62091 0 L
Mistroke
.62193 0 L
.62313 0 L
.62443 0 L
.62566 0 L
.62679 0 L
.628 0 L
.6293 0 L
.63052 0 L
.63164 0 L
.63295 0 L
.63369 0 L
.63437 0 L
.63563 0 L
.63626 0 L
.63697 0 L
.63764 0 L
.63836 0 L
.63963 0 L
.64034 0 L
.64101 0 L
.64173 0 L
.64251 0 L
.64318 0 L
.64391 0 L
.6446 0 L
.64524 0 L
.64644 0 L
.64772 0 L
.64893 0 L
.65024 0 L
.65149 0 L
.65264 0 L
.65378 0 L
.65482 0 L
.65601 0 L
.65714 0 L
.65837 0 L
.65967 0 L
.66079 0 L
.66201 0 L
.66332 0 L
.66406 0 L
.66473 0 L
.66603 0 L
.66727 0 L
.66832 0 L
.66948 0 L
.67069 0 L
.67182 0 L
.67288 0 L
Mistroke
.67385 0 L
.67492 0 L
.67604 0 L
.67718 0 L
.6784 0 L
.67955 0 L
.68059 0 L
.68182 0 L
.68251 0 L
.68315 0 L
.68433 0 L
.68557 0 L
.68678 0 L
.6881 0 L
.68935 0 L
.69051 0 L
.69165 0 L
.69269 0 L
.69389 0 L
.69502 0 L
.69625 0 L
.69756 0 L
.69867 0 L
.69989 0 L
.70121 0 L
.70195 0 L
.70262 0 L
.70392 0 L
.70516 0 L
.70621 0 L
.70737 0 L
.70859 0 L
.70972 0 L
.71078 0 L
.71175 0 L
.71287 0 L
.71394 0 L
.71508 0 L
.7163 0 L
.71745 0 L
.7185 0 L
.71973 0 L
.72042 0 L
.72106 0 L
.72223 0 L
.72347 0 L
.72469 0 L
.72538 0 L
.72602 0 L
.72718 0 L
Mistroke
.72843 0 L
.72953 0 L
.73057 0 L
.73171 0 L
.73294 0 L
.73418 0 L
.73487 0 L
.73552 0 L
.73684 0 L
.73757 0 L
.73824 0 L
.73944 0 L
.74074 0 L
.74197 0 L
.7431 0 L
.74415 0 L
.74529 0 L
.74636 0 L
.74734 0 L
.74848 0 L
.74973 0 L
.75091 0 L
.752 0 L
.75323 0 L
.7544 0 L
.75544 0 L
.75657 0 L
.7578 0 L
.7591 0 L
.76021 0 L
.76143 0 L
.76274 0 L
.76395 0 L
.76458 0 L
.76527 0 L
.766 0 L
.76668 0 L
.76793 0 L
.76907 0 L
.77033 0 L
.77165 0 L
.77277 0 L
.77396 0 L
.77508 0 L
.7761 0 L
.7773 0 L
.7786 0 L
.77983 0 L
.78096 0 L
.78217 0 L
Mistroke
.78347 0 L
.78469 0 L
.78581 0 L
.78712 0 L
.78786 0 L
.78854 0 L
.7898 0 L
.79043 0 L
.79113 0 L
.79181 0 L
.79252 0 L
.7938 0 L
.79451 0 L
.79517 0 L
.7959 0 L
.79668 0 L
.79735 0 L
.79808 0 L
.79877 0 L
.79941 0 L
.80061 0 L
.80189 0 L
.80309 0 L
.80441 0 L
.80565 0 L
.8068 0 L
.80795 0 L
.80898 0 L
.81018 0 L
.8113 0 L
.81253 0 L
.81383 0 L
.81495 0 L
.81616 0 L
.81748 0 L
.81821 0 L
.81889 0 L
.82019 0 L
.82143 0 L
.82247 0 L
.82363 0 L
.82484 0 L
.82598 0 L
.82704 0 L
.82801 0 L
.82907 0 L
.83019 0 L
.83133 0 L
.83255 0 L
.8337 0 L
Mistroke
.83475 0 L
.83597 0 L
.83667 0 L
.83731 0 L
.83848 0 L
.83973 0 L
.84094 0 L
.84226 0 L
.8435 0 L
.84466 0 L
.8458 0 L
.84684 0 L
.84804 0 L
.84916 0 L
.8504 0 L
.8517 0 L
.85282 0 L
.85404 0 L
.85535 0 L
.85609 0 L
.85676 0 L
.85807 0 L
.8593 0 L
.86036 0 L
.86152 0 L
.86273 0 L
.86387 0 L
.86493 0 L
.8659 0 L
.86696 0 L
.86808 0 L
.86922 0 L
.87044 0 L
.87159 0 L
.87264 0 L
.87387 0 L
.87456 0 L
.8752 0 L
.87638 0 L
.87762 0 L
.87883 0 L
.87952 0 L
.88016 0 L
.88132 0 L
.88256 0 L
.88367 0 L
.88471 0 L
.88585 0 L
.88708 0 L
.88831 0 L
Mistroke
.88901 0 L
.88966 0 L
.89097 0 L
.89171 0 L
.89237 0 L
.89357 0 L
.89487 0 L
.8961 0 L
.89723 0 L
.89829 0 L
.89942 0 L
.90049 0 L
.90147 0 L
.90261 0 L
.90386 0 L
.90504 0 L
.90613 0 L
.90736 0 L
.90853 0 L
.90957 0 L
.9107 0 L
.91193 0 L
.91323 0 L
.91434 0 L
.91556 0 L
.91687 0 L
.91807 0 L
.9187 0 L
.9194 0 L
.92013 0 L
.92081 0 L
.92206 0 L
.9232 0 L
.92445 0 L
.92578 0 L
.92689 0 L
.92808 0 L
.9292 0 L
.93022 0 L
.93142 0 L
.93273 0 L
.93395 0 L
.93509 0 L
.93629 0 L
.93759 0 L
.93881 0 L
.93993 0 L
.94123 0 L
.94197 0 L
.94266 0 L
Mistroke
.94391 0 L
.94462 0 L
.94525 0 L
.94593 0 L
.94664 0 L
.94792 0 L
.94863 0 L
.94929 0 L
.95002 0 L
.95079 0 L
.95147 0 L
.9522 0 L
.95289 0 L
.95352 0 L
.95473 0 L
.95601 0 L
.95665 0 L
.95735 0 L
.95863 0 L
.95987 0 L
.96103 0 L
.96173 0 L
.9624 0 L
.96364 0 L
.96434 0 L
.96498 0 L
.96568 0 L
.96643 0 L
.96759 0 L
.96883 0 L
.97001 0 L
.97108 0 L
.97234 0 L
.97305 0 L
.9737 0 L
.97491 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`000004o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ooooool5o`000003ooooool0003ooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool001[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo0_l0
00000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0a?ooool007Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Gooooo001gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`35ooooo`00N?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool007Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`36ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0aoooool007[ooooo00?o0000ooooooooool01?ooool3o`0001[ooooo00?o0000oooo
ooooool0aoooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo0<Sooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`38ooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0b?ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<Wooooo001kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`39ooooo`00Noooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0bOooool007cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<Wooooo
001looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`39ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0bOooool007cooooo00?o0000ooooooooool00_ooool3o`0001Sooooo00?o0000oooo
ooooool0bOooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0<[ooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`3:ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0b_ooool007cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[ooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3:ooooo`00O?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0b_ooool007cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[ooooo
001mooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`3:ooooo`00OOoo
ool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool0boooool007gooooo00Co
0000oooooooooooooooo0ol0000Fooooo`03o`000?oooooooooo0<_ooooo001mooooo`05o`000?oo
ooooooooooooool000006?ooool00ol0003oooooooooo`3;ooooo`00OOooool01Ol0003ooooooooo
oooooooo000001Sooooo00?o0000ooooooooool0boooool007gooooo00Go0000oooooooooooooooo
o`00000Hooooo`03o`000?oooooooooo0<_ooooo001mooooo`05o`000?ooooooooooooooool00000
6?ooool00ol0003oooooooooo`3;ooooo`00O_ooool01?l0003oooooooooool0000Gooooo`03o`00
0?oooooooooo0<cooooo001nooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool0
c?ooool007kooooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`3<ooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000oooool01?l0003ooooo
ooooool0000Gooooo`03o`000?oooooooooo0<cooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`04o`000?oooooooooo
o`0001Oooooo00?o0000ooooooooool0c?ooool006Kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Co0000oooooooooooo00005oooool00ol0003ooooooooo
o`3<ooooo`00I_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00ooo
ool00ol0003oooooooooo`03o`0001Gooooo00?o0000ooooooooool0c?ooool006Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o0000ooooool000005_oo
ool00ol0003oooooooooo`3=ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo0<gooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooool000005_ooool00ol0003oooooooooo`3=ooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooo000001Ko
oooo00?o0000ooooooooool0cOooool007oooooo00?o0000ooooool000005_ooool00ol0003ooooo
ooooo`3=ooooo`00Ooooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo0<gooooo001o
ooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool0cOooool007oooooo00?o0000oooo
ool000005_ooool00ol0003oooooooooo`3=ooooo`00Ooooool00ol0003oooooo`00000Fooooo`03
o`000?oooooooooo0<gooooo0020ooooo`Co00004oooool00ol0003oooooooooo`3>ooooo`00P?oo
ool2o`0001Gooooo00?o0000ooooooooool0c_ooool0083ooooo0_l0000Eooooo`03o`000?oooooo
oooo0<kooooo0020ooooo`;o00005Oooool00ol0003oooooooooo`3>ooooo`00P?ooool2o`0001Go
oooo00?o0000ooooooooool0c_ooool0083ooooo0_l0000Eooooo`03o`000?oooooooooo0<kooooo
0020ooooo`;o00005Oooool00ol0003oooooooooo`3>ooooo`00P?ooool2o`0001Gooooo00?o0000
ooooooooool0c_ooool0083ooooo0_l0000Eooooo`03o`000?oooooooooo0<kooooo0020ooooo`;o
00005Oooool00ol0003oooooooooo`3>ooooo`00P?ooool4o`0001?ooooo00?o0000ooooooooool0
c_ooool0087ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3>ooooo`00POooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0c_ooool0087ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`3>ooooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<oooooo
0021ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0coooool0087ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0coooool0087ooooo0ol0000Booooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0coooool0087ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
0<oooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0coooool0087ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`3?ooooo`00POooool2o`0001?ooooo00?o
0000ooooooooool0coooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo0_l0000Cooooo`03o`000?oooooooooo0<oooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool2o`0001?ooooo00?o0000ooooooooool0coooool006Kooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool2o`0001?ooooo00?o0000ooooooooool0coooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000Booooo`03o`00
0?oooooooooo0<oooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`;o00004oooool00ol0003oooooooooo`3?ooooo`00I_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool2o`0001?ooooo00?o0000oooooooo
ool0coooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo0_l0000Booooo`03o`000?oooooooooo0=3ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`06ooooo`;o00004_ooool00ol0003oooooooooo`3@ooooo`00
POooool2o`0001;ooooo00?o0000ooooooooool0d?ooool0087ooooo0_l0000Booooo`03o`000?oo
oooooooo0=3ooooo0021ooooo`;o00004_ooool00ol0003oooooooooo`3@ooooo`00POooool2o`00
01;ooooo00?o0000ooooooooool0d?ooool0087ooooo0_l0000Booooo`03o`000?oooooooooo0=3o
oooo0021ooooo`?o00004Oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooo`00
000Aooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oooooo0000017ooooo00?o0000
ooooooooool0d?ooool0087ooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`3@oooo
o`00POooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`00
0?oooooo0000017ooooo00?o0000ooooooooool0d?ooool0087ooooo00?o0000ooooool000004Ooo
ool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooo`00000@ooooo`03o`000?oooooo
oooo0=7ooooo0021ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0dOooool0087o
oooo00?o0000ooooool000004?ooool00ol0003oooooooooo`3Aooooo`00POooool3o`00013ooooo
00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooool000004?ooool00ol0003ooooooooo
o`3Aooooo`00POooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo0=7ooooo0021oooo
o`03o`000?oooooo0000013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooool0
00004?ooool00ol0003oooooooooo`3Aooooo`00POooool00ol0003oooooo`00000@ooooo`03o`00
0?oooooooooo0=7ooooo0021ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0dOoo
ool0087ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`3Aooooo`00POooool0
1?l0003oooooooooool0000?ooooo`03o`000?oooooooooo0=7ooooo0021ooooo`04o`000?oooooo
ooooo`0000oooooo00?o0000ooooooooool0dOooool0087ooooo1?l0000?ooooo`03o`000?oooooo
oooo0=7ooooo0021ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0d_ooool0
087ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`3Booooo`00POooool01?l0
003oooooooooool0000>ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`04o`000?oooooooooo
o`0000kooooo00?o0000ooooooooool0d_ooool0087ooooo00Co0000oooooooooooo00003_ooool0
0ol0003oooooooooo`3Booooo`00POooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo0=;ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0
d_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`3Boooo
o`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0d_ooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool4o`0000kooooo
00?o0000ooooooooool0d_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo
0=;ooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0d_ooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00Co0000oooooooooooo00003_oo
ool00ol0003oooooooooo`3Booooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo0=;o
oooo0021ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`3Cooooo`00
POooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0doooool0087ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`3Cooooo`00POooool01Ol0003ooooo
oooooooooooo000000cooooo00?o0000ooooooooool0doooool0087ooooo0ol000000ooooooo0000
ooooo`0;ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`05o`000?ooooooooooooooool00000
3?ooool00ol0003oooooooooo`3Cooooo`00POooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool0doooool0087ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo0=?ooooo0021ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooo
ooooo`3Cooooo`00POooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0
doooool0087ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo0=?ooooo
0021ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`3Cooooo`00POoo
ool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0doooool0087ooooo00Go
0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`?o000000?o
ooooo`000?ooool02_ooool00ol0003oooooooooo`3Dooooo`00POooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool0e?ooool0087ooooo00Go0000ooooooooooooooooo`00
000;ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Dooooo`00POoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0e?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0=Cooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`3Dooooo`00POooool3o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`3Dooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0e?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0eOooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Eooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0eOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0=Gooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0=Gooooo001Vooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00002ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0eOooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0eOooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0eOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0eOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0eOooool0087ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Eooooo`00POooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0eOooool0087ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Gooooo0021
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3F
ooooo`00POooool3o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Foooo
o`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0e_ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0=Kooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3Fooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0e_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0=Kooooo0021ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Fooooo`00POooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0e_ooool0087ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Kooooo0021
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3F
ooooo`00POooool3o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Foooo
o`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0eoooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0=Oooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3Gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0eoooool0087ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0=Oooooo0021ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Gooooo`00POooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0eoooool0087ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=Oooooo0021
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3G
ooooo`00POooool3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Goooo
o`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0eoooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0=Oooooo0021ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`00003Iooooo`00POooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
fOooool0087ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0003Jooooo`00POoo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`000=[ooooo001gooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`000=[ooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool0003Jooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo0_l0
003Kooooo`00NOooool00ol0003oooooooooo`05ooooo`?o00001oooool2o`000=_ooooo001ioooo
o`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`00
0?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.0766 0 L
.0774 0 L
.07809 0 L
.07885 0 L
.07956 0 L
.0802 0 L
.08095 0 L
.08166 0 L
.08291 0 L
.08362 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09016 0 L
.09148 0 L
.09214 0 L
.09285 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10086 0 L
.10201 0 L
.10333 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11491 0 L
.11554 0 L
.11624 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12081 0 L
.12194 0 L
.12323 0 L
.12446 0 L
.12562 0 L
.12668 0 L
.12789 0 L
.12903 0 L
.13009 0 L
.13107 0 L
.13214 0 L
.13327 0 L
.13441 0 L
.13564 0 L
.1368 0 L
.13785 0 L
.13909 0 L
.13979 0 L
.14043 0 L
.14162 0 L
.14288 0 L
.14402 0 L
.14526 0 L
.14656 0 L
.14777 0 L
.14891 0 L
.14994 0 L
.15113 0 L
.15226 0 L
.15348 0 L
.15478 0 L
.15589 0 L
.15711 0 L
.15842 0 L
.15915 0 L
.15982 0 L
.16113 0 L
.16236 0 L
.16352 0 L
.16456 0 L
.16577 0 L
.1669 0 L
.16796 0 L
.16893 0 L
.16999 0 L
.17111 0 L
.17225 0 L
.17347 0 L
.17462 0 L
Mistroke
.17566 0 L
.17689 0 L
.17823 0 L
.17948 0 L
.18065 0 L
.18189 0 L
.18308 0 L
.18414 0 L
.1853 0 L
.18656 0 L
.1879 0 L
.18916 0 L
.19031 0 L
.19148 0 L
.19255 0 L
.19373 0 L
.19497 0 L
.19605 0 L
.19707 0 L
.19817 0 L
.19936 0 L
.20074 0 L
.20202 0 L
.20342 0 L
.2049 0 L
.20619 0 L
.2074 0 L
.20872 0 L
.21015 0 L
.21134 0 L
.21265 0 L
.21401 0 L
.21528 0 L
.21647 0 L
.21756 0 L
.21881 0 L
.21999 0 L
.22114 0 L
.22238 0 L
.22354 0 L
.22461 0 L
.22586 0 L
.22722 0 L
.22851 0 L
.2297 0 L
.23105 0 L
.23232 0 L
.23468 0 L
.23601 0 L
.23723 0 L
Mistroke
.23858 0 L
.23999 0 L
.24219 0 L
.24342 0 L
.24454 0 L
.24559 0 L
.24673 0 L
.24879 1e-05 L
.24995 1e-05 L
.25122 1e-05 L
.25247 1e-05 L
.25381 2e-05 L
.25505 2e-05 L
.2562 2e-05 L
.25844 3e-05 L
.25972 4e-05 L
.26093 5e-05 L
.26319 7e-05 L
.26563 .0001 L
.267 .00013 L
.26826 .00015 L
.27038 .00021 L
.2727 .00029 L
.27513 .00041 L
.27739 .00056 L
.28007 .0008 L
.28262 .00112 L
.2849 .0015 L
.28738 .00205 L
.29008 .00284 L
.29295 .00398 L
.2954 .00526 L
.2981 .0071 L
.30044 .00914 L
.30301 .01193 L
.3055 .01535 L
.30817 .01991 L
.31296 .03098 L
.31742 .04551 L
.32303 .07113 L
.32833 .10437 L
.3331 .14266 L
.33826 .19353 L
.35772 .44359 L
.36304 .50996 L
.36598 .54188 L
.36878 .56798 L
.37136 .58782 L
.37273 .59643 L
.37419 .60409 L
Mistroke
.37553 .60973 L
.37675 .6136 L
.37798 .61629 L
.37914 .6177 L
.38032 .618 L
.38142 .61726 L
.38263 .61529 L
.38393 .61187 L
.38529 .60684 L
.38657 .60076 L
.38899 .58603 L
.39333 .54962 L
.39805 .49821 L
.40777 .37069 L
.4185 .23118 L
.42341 .17697 L
.4287 .128 L
.43327 .09389 L
.43828 .06479 L
.44362 .04204 L
.44653 .03268 L
.44924 .02559 L
.4541 .01611 L
.45681 .01226 L
.45929 .00949 L
.46179 .00726 L
.46414 .0056 L
.46658 .00424 L
.46927 .0031 L
.47159 .00235 L
.47371 .00181 L
.47615 .00133 L
.47848 .00098 L
.48098 .00071 L
.48364 .00049 L
.48615 .00035 L
.48843 .00025 L
.49111 .00017 L
.49263 .00013 L
.49402 .00011 L
.49658 7e-05 L
.49786 6e-05 L
.49927 5e-05 L
.5018 3e-05 L
.50322 3e-05 L
.50453 2e-05 L
.50695 1e-05 L
.50817 1e-05 L
.50951 1e-05 L
.51183 1e-05 L
Mistroke
.51313 0 L
.51432 0 L
.51542 0 L
.51663 0 L
.51883 0 L
.52025 0 L
.52158 0 L
.5228 0 L
.52408 0 L
.52548 0 L
.52677 0 L
.52816 0 L
.52968 0 L
.53099 0 L
.53219 0 L
.53358 0 L
.53489 0 L
.5361 0 L
.53722 0 L
.53845 0 L
.53976 0 L
.54089 0 L
.54214 0 L
.54343 0 L
.54464 0 L
.54577 0 L
.5468 0 L
.54799 0 L
.54912 0 L
.55034 0 L
.55164 0 L
.55274 0 L
.55396 0 L
.55527 0 L
.55667 0 L
.558 0 L
.55921 0 L
.56034 0 L
.56154 0 L
.56267 0 L
.56369 0 L
.5649 0 L
.56621 0 L
.56745 0 L
.56858 0 L
.56965 0 L
.57065 0 L
.57174 0 L
.57291 0 L
.57414 0 L
Mistroke
.57531 0 L
.57635 0 L
.57748 0 L
.5787 0 L
.57982 0 L
.58105 0 L
.58234 0 L
.58347 0 L
.58452 0 L
.58567 0 L
.5869 0 L
.58824 0 L
.589 0 L
.5897 0 L
.59098 0 L
.59163 0 L
.59234 0 L
.59357 0 L
.59489 0 L
.59614 0 L
.59728 0 L
.59858 0 L
.5993 0 L
.59996 0 L
.60124 0 L
.60244 0 L
.60313 0 L
.60385 0 L
.60514 0 L
.60587 0 L
.60654 0 L
.60727 0 L
.60806 0 L
.60876 0 L
.60939 0 L
.61065 0 L
.61179 0 L
.61301 0 L
.61431 0 L
.61552 0 L
.61622 0 L
.61686 0 L
.61755 0 L
.61829 0 L
.61958 0 L
.62079 0 L
.62197 0 L
.62306 0 L
.62424 0 L
.62553 0 L
Mistroke
.62618 0 L
.62688 0 L
.62814 0 L
.62931 0 L
.63059 0 L
.6318 0 L
.63292 0 L
.63392 0 L
.63503 0 L
.63619 0 L
.63728 0 L
.63849 0 L
.63917 0 L
.63981 0 L
.6411 0 L
.64182 0 L
.64248 0 L
.64366 0 L
.64493 0 L
.64614 0 L
.64725 0 L
.64853 0 L
.64973 0 L
.65105 0 L
.65179 0 L
.65247 0 L
.65317 0 L
.65383 0 L
.65454 0 L
.65531 0 L
.65603 0 L
.65672 0 L
.658 0 L
.65916 0 L
.66041 0 L
.66159 0 L
.66267 0 L
.66393 0 L
.66464 0 L
.6653 0 L
.6665 0 L
.66779 0 L
.66901 0 L
.67032 0 L
.67156 0 L
.6727 0 L
.67396 0 L
.67467 0 L
.67534 0 L
.67604 0 L
Mistroke
.67668 0 L
.67742 0 L
.67811 0 L
.67918 0 L
.68036 0 L
.68159 0 L
.68273 0 L
.68381 0 L
.68479 0 L
.68592 0 L
.68699 0 L
.68814 0 L
.68938 0 L
.69043 0 L
.69159 0 L
.69283 0 L
.69353 0 L
.69417 0 L
.69535 0 L
.6966 0 L
.69783 0 L
.69852 0 L
.69916 0 L
.70034 0 L
.70159 0 L
.7027 0 L
.70375 0 L
.70489 0 L
.70612 0 L
.70743 0 L
.70817 0 L
.70885 0 L
.71011 0 L
.71081 0 L
.71144 0 L
.71265 0 L
.71395 0 L
.71518 0 L
.71631 0 L
.71737 0 L
.71851 0 L
.71959 0 L
.72057 0 L
.72172 0 L
.72297 0 L
.72415 0 L
.72524 0 L
.72636 0 L
.72741 0 L
.72857 0 L
Mistroke
.72981 0 L
.73105 0 L
.73235 0 L
.73345 0 L
.73467 0 L
.73599 0 L
.73721 0 L
.73784 0 L
.73854 0 L
.73927 0 L
.73996 0 L
.74122 0 L
.74237 0 L
.743 0 L
.74369 0 L
.74495 0 L
.74618 0 L
.7473 0 L
.74859 0 L
.7498 0 L
.75092 0 L
.75196 0 L
.75309 0 L
.75429 0 L
.7556 0 L
.75679 0 L
.75745 0 L
.75816 0 L
.75946 0 L
.76068 0 L
.76197 0 L
.76307 0 L
.76429 0 L
.76502 0 L
.76571 0 L
.76701 0 L
.76774 0 L
.76841 0 L
.76915 0 L
.76994 0 L
.77063 0 L
.77137 0 L
.77208 0 L
.77272 0 L
.77395 0 L
.77524 0 L
.77646 0 L
.77715 0 L
.77779 0 L
.77895 0 L
Mistroke
.7802 0 L
.7813 0 L
.78234 0 L
.78348 0 L
.78471 0 L
.78595 0 L
.78664 0 L
.78729 0 L
.78861 0 L
.78934 0 L
.79001 0 L
.79121 0 L
.79251 0 L
.79374 0 L
.79487 0 L
.79592 0 L
.79706 0 L
.79813 0 L
.79911 0 L
.80025 0 L
.8015 0 L
.80268 0 L
.80377 0 L
.805 0 L
.80617 0 L
.80721 0 L
.80834 0 L
.80957 0 L
.81087 0 L
.81198 0 L
.8132 0 L
.81451 0 L
.81572 0 L
.81635 0 L
.81704 0 L
.81777 0 L
.81845 0 L
.8197 0 L
.82084 0 L
.8221 0 L
.82342 0 L
.82454 0 L
.82573 0 L
.82685 0 L
.82787 0 L
.82907 0 L
.83037 0 L
.8316 0 L
.83273 0 L
.83394 0 L
Mistroke
.83524 0 L
.83646 0 L
.83758 0 L
.83889 0 L
.83963 0 L
.84031 0 L
.84157 0 L
.8422 0 L
.8429 0 L
.84358 0 L
.84429 0 L
.84557 0 L
.84628 0 L
.84694 0 L
.84767 0 L
.84845 0 L
.84912 0 L
.84985 0 L
.85054 0 L
.85118 0 L
.85238 0 L
.85366 0 L
.85486 0 L
.85618 0 L
.85742 0 L
.85857 0 L
.85972 0 L
.86075 0 L
.86195 0 L
.86307 0 L
.8643 0 L
.8656 0 L
.86672 0 L
.86793 0 L
.86925 0 L
.86998 0 L
.87066 0 L
.87196 0 L
.8732 0 L
.87424 0 L
.8754 0 L
.87661 0 L
.87775 0 L
.87881 0 L
.87978 0 L
.88084 0 L
.88196 0 L
.8831 0 L
.88432 0 L
.88547 0 L
Mistroke
.88652 0 L
.88774 0 L
.88844 0 L
.88908 0 L
.89025 0 L
.8915 0 L
.89271 0 L
.89403 0 L
.89527 0 L
.89643 0 L
.89757 0 L
.89861 0 L
.89981 0 L
.90093 0 L
.90217 0 L
.90347 0 L
.90459 0 L
.90581 0 L
.90712 0 L
.90786 0 L
.90853 0 L
.90984 0 L
.91107 0 L
.91213 0 L
.91329 0 L
.9145 0 L
.91564 0 L
.9167 0 L
.91767 0 L
.91873 0 L
.91985 0 L
.92099 0 L
.92221 0 L
.92336 0 L
.92441 0 L
.92564 0 L
.92633 0 L
.92697 0 L
.92815 0 L
.92939 0 L
.9306 0 L
.93129 0 L
.93193 0 L
.93309 0 L
.93433 0 L
.93544 0 L
.93648 0 L
.93762 0 L
.93885 0 L
.94008 0 L
Mistroke
.94078 0 L
.94143 0 L
.94274 0 L
.94348 0 L
.94414 0 L
.94534 0 L
.94664 0 L
.94787 0 L
.949 0 L
.95006 0 L
.95119 0 L
.95226 0 L
.95324 0 L
.95438 0 L
.95563 0 L
.95681 0 L
.9579 0 L
.95913 0 L
.9603 0 L
.96134 0 L
.96247 0 L
.9637 0 L
.965 0 L
.96611 0 L
.96733 0 L
.96848 0 L
.96957 0 L
.97054 0 L
.97161 0 L
.97276 0 L
.97399 0 L
.97504 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool7o`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`So00000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`006_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool2o`0000[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0
07?ooooo0_l0000<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0_Oooool007Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`;o0000_oooool007Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo
001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2oooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0_oooool007Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0<3ooooo001hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`31ooooo`00N?ooool00ol0003oooooooooo`06ooooo`?o0000
8?ooool00ol0003oooooooooo`31ooooo`00N?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0`_ooool007Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0<;ooooo001iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`33ooooo`00NOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0`oooool007[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0<?ooooo
001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`33ooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0`oooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo0<Cooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`34ooooo`00Noooool00ol0003oooooooooo`03ooooo`?o0000
7Oooool00ol0003oooooooooo`34ooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0a?ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0<Cooooo001kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`34ooooo`00Noooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool007_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Gooooo
001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`35ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0aOooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo0<Gooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`36ooooo`00O?ooool00ol0003oooooooooo`02ooooo`?o0000
6oooool00ol0003oooooooooo`36ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0a_ooool007gooooo00Go0000ooooooooooooooooo`00
000Mooooo`03o`000?oooooooooo0<Kooooo001mooooo`05o`000?ooooooooooooooool000007Ooo
ool00ol0003oooooooooo`36ooooo`00OOooool01Ol0003ooooooooooooooooo000001gooooo00?o
0000ooooooooool0a_ooool007gooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oo
oooooooo0<Kooooo001mooooo`05o`000?ooooooooooooooool000007Oooool00ol0003ooooooooo
o`36ooooo`00OOooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool0aooo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000?ooooo00Co
0000oooooooooooo00007?ooool00ol0003oooooooooo`37ooooo`00I_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo0<Oooooo001Vooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP04ooooo`04o`000?ooooooooooo`0001cooooo00?o0000
ooooooooool0aoooool006Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00?o0000ooooooooool00ol0000Jooooo`03o`000?oooooooooo0<Oooooo001Voooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`02ooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool0aoooool006Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0<Oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`37oooo
o`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0aoooool007oooooo00?o0000oooo
ool000007?ooool00ol0003oooooooooo`37ooooo`00Ooooool00ol0003oooooo`00000Kooooo`03
o`000?oooooooooo0<Sooooo001oooooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
b?ooool007oooooo00?o0000ooooool000006oooool00ol0003oooooooooo`38ooooo`00Ooooool0
0ol0003oooooo`00000Kooooo`03o`000?oooooooooo0<Sooooo001oooooo`03o`000?oooooo0000
00;o00006Oooool00ol0003oooooooooo`38ooooo`00Ooooool00ol0003oooooo`00000Kooooo`03
o`000?oooooooooo0<Sooooo001oooooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
b?ooool007oooooo00?o0000ooooool000006oooool00ol0003oooooooooo`38ooooo`00Ooooool0
0ol0003oooooo`00000Jooooo`03o`000?oooooooooo0<Wooooo0020ooooo`;o00006_ooool00ol0
003oooooooooo`39ooooo`00P?ooool2o`0001[ooooo00?o0000ooooooooool0bOooool0083ooooo
0_l0000Jooooo`03o`000?oooooooooo0<Wooooo0020ooooo`;o00006_ooool00ol0003ooooooooo
o`39ooooo`00P?ooool2o`0001[ooooo00?o0000ooooooooool0bOooool0083ooooo1?l0000Hoooo
o`03o`000?oooooooooo0<Wooooo0020ooooo`;o00006_ooool00ol0003oooooooooo`39ooooo`00
P?ooool2o`0001Wooooo00?o0000ooooooooool0b_ooool0083ooooo0_l0000Iooooo`03o`000?oo
oooooooo0<[ooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`3:ooooo`00P?ooool2o`00
01Wooooo00?o0000ooooooooool0b_ooool0083ooooo0_l0000Iooooo`03o`000?oooooooooo0<[o
oooo0020ooooo`;o00006Oooool00ol0003oooooooooo`3:ooooo`00P?ooool2o`0001Wooooo00?o
0000ooooooooool0b_ooool0087ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3:
ooooo`00POooool3o`0001Oooooo00?o0000ooooooooool0b_ooool0087ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0booo
ool0087ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3;ooooo`00POooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0boooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`3;ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3;ooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0boooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0000Fooooo`03o`000?oooooooooo0<_ooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`;o00005oooool0
0ol0003oooooooooo`3;ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool2o`0001Oooooo00?o0000ooooooooool0boooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo0_l0000Fooooo`03o`000?oooooo
oooo0<cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06
ooooo`;o00005_ooool00ol0003oooooooooo`3<ooooo`00POooool2o`0001Kooooo00?o0000oooo
ooooool0c?ooool0087ooooo0_l0000Fooooo`03o`000?oooooooooo0<cooooo0021ooooo`;o0000
5_ooool00ol0003oooooooooo`3<ooooo`00POooool2o`0001Kooooo00?o0000ooooooooool0c?oo
ool0087ooooo0_l0000Fooooo`03o`000?oooooooooo0<cooooo0021ooooo`?o00005Oooool00ol0
003oooooooooo`3<ooooo`00POooool2o`0001Kooooo00?o0000ooooooooool0c?ooool0087ooooo
00?o0000ooooool000005Oooool00ol0003oooooooooo`3<ooooo`00POooool00ol0003oooooo`00
000Eooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooo000001Gooooo00?o0000
ooooooooool0c?ooool0087ooooo00?o0000ooooool000005Oooool00ol0003oooooooooo`3<oooo
o`00POooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`00
0?oooooo000001Gooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000ooooool000005?oo
ool00ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooo`00000Dooooo`03o`000?oooooo
oooo0<gooooo0021ooooo`?o00005?ooool00ol0003oooooooooo`3=ooooo`00POooool00ol0003o
ooooo`00000Dooooo`03o`000?oooooooooo0<gooooo0021ooooo`03o`000?oooooo000001Cooooo
00?o0000ooooooooool0cOooool0087ooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`3=ooooo`00POooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo0<gooooo
0021ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0cOooool0087ooooo00Co
0000oooooooooooo00004oooool00ol0003oooooooooo`3=ooooo`00POooool01?l0003ooooooooo
ool0000Cooooo`03o`000?oooooooooo0<gooooo0021ooooo`04o`000?ooooooooooo`0001?ooooo
00?o0000ooooooooool0cOooool0087ooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`3=ooooo`00POooool4o`0001?ooooo00?o0000ooooooooool0cOooool0087ooooo00Co0000
oooooooooooo00004oooool00ol0003oooooooooo`3=ooooo`00POooool01?l0003oooooooooool0
000Cooooo`03o`000?oooooooooo0<gooooo0021ooooo`04o`000?ooooooooooo`0001;ooooo00?o
0000ooooooooool0c_ooool0087ooooo00Co0000oooooooooooo00004_ooool00ol0003ooooooooo
o`3>ooooo`00POooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0c_oo
ool0087ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo0<kooooo001V
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`3>ooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0c_ooool0
06Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0c_ooool006Kooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000003
ooooool0003ooooo013ooooo00?o0000ooooooooool0c_ooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool01Ol0003ooooooooooooooooo
0000017ooooo00?o0000ooooooooool0c_ooool006Kooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oo
oooooooo0<kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRH
V008ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`3>ooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool01Ol0003o
oooooooooooooooo0000017ooooo00?o0000ooooooooool0c_ooool0087ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`03o`000?oooooooooo0<kooooo0021ooooo`05o`000?oooooooooooooo
ool000004Oooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0c_ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3?ooooo`00POooool3
o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3?ooooo`00POooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0coooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<oo
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`3?ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0coooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0coooool0087ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3?ooooo`00POooool3
o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3?ooooo`00POooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0d?ooool0087o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=3o
oooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3@ooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3@ooooo`00POooool3
o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0d?ooool0087o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=3o
oooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3@ooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo0=7ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`3Aooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=7ooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=7ooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool006Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOoo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
dOooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0=7ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`3Booooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0d_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Booooo`00POooool3o`0000Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`3Booooo`00POooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0d_ooool0087ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Booooo`00
POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
d_ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0=?ooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3Cooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0doooool0087ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Cooooo`00POooool3o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3Cooooo`00POooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0doooool0087ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Cooooo`00
POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
e?ooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`00POooool3o`0000Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Eooooo`00
POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
eOooool0087ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo00000=Oooooo
0021ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00003Gooooo`00Mooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo00000=Oooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooo`00003Hooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooool00000f?ooool007Wooooo00?o0000ooooooooool01Oooool3o`00
00[ooooo00?o0000ooooooooool0eoooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo
00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Oooooo00?oEEEE
ofIVI_l00000k_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04726 0 L
.04797 0 L
.04925 0 L
.05041 0 L
.05166 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06451 0 L
.06529 0 L
.06659 0 L
.06731 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07583 0 L
.07659 0 L
.07728 0 L
.07809 0 L
.07885 0 L
.08011 0 L
.08077 0 L
.08149 0 L
.08224 0 L
.08294 0 L
.08427 0 L
.08544 0 L
.08673 0 L
.08807 0 L
.08933 0 L
.09051 0 L
.09158 0 L
.09276 0 L
.09401 0 L
.09527 0 L
.09663 0 L
.0979 0 L
.09906 0 L
.10042 0 L
.10119 0 L
.1019 0 L
.1032 0 L
.10458 0 L
.1058 0 L
.10712 0 L
.10837 0 L
.10953 0 L
.11057 0 L
.11172 0 L
.11291 0 L
.11404 0 L
.11528 0 L
.11659 0 L
.1177 0 L
.11892 0 L
.12024 0 L
.12165 0 L
.12298 0 L
.12419 0 L
.12533 0 L
.12654 0 L
.12758 0 L
.12871 0 L
Mistroke
.12993 0 L
.13125 0 L
.13248 0 L
.13362 0 L
.13475 0 L
.1358 0 L
.13695 0 L
.13818 0 L
.13935 0 L
.14046 0 L
.14252 0 L
.14368 0 L
.14493 0 L
.14611 0 L
.14718 0 L
.14844 0 L
.14981 0 L
.1511 0 L
.15229 0 L
.15352 0 L
.15467 0 L
.15594 0 L
.1573 0 L
.15865 0 L
.16007 0 L
.16129 0 L
.16261 0 L
.16386 0 L
.16504 0 L
.16724 0 L
.16848 0 L
.16962 0 L
.17086 0 L
.17219 0 L
.17324 0 L
.17438 0 L
.17643 0 L
.17768 0 L
.17886 0 L
.18109 0 L
.18234 0 L
.18369 0 L
.18488 0 L
.18614 0 L
.18728 0 L
.18852 0 L
.19071 0 L
.19205 0 L
.19327 0 L
.19459 0 L
Mistroke
.19601 0 L
.19733 0 L
.19855 0 L
.19971 0 L
.20095 0 L
.20314 0 L
.2052 0 L
.20645 0 L
.20765 0 L
.20988 0 L
.21102 0 L
.21223 0 L
.21441 0 L
.21575 0 L
.217 0 L
.21935 0 L
.22176 0 L
.22401 0 L
.22647 1e-05 L
.22785 1e-05 L
.22911 1e-05 L
.23165 1e-05 L
.23308 1e-05 L
.23441 2e-05 L
.23684 2e-05 L
.23942 3e-05 L
.2416 4e-05 L
.24395 5e-05 L
.24617 7e-05 L
.2482 9e-05 L
.25046 .00012 L
.25292 .00017 L
.2555 .00023 L
.25789 .0003 L
.26052 .00041 L
.26294 .00054 L
.2656 .00072 L
.26841 .00098 L
.27085 .00127 L
.27314 .00162 L
.27565 .00209 L
.27834 .00273 L
.28072 .00344 L
.28332 .0044 L
.28561 .00545 L
.28805 .0068 L
.29266 .01017 L
.29693 .01454 L
.3023 .02228 L
.30723 .03222 L
Mistroke
.31265 .04712 L
.31837 .06842 L
.32335 .09244 L
.32799 .11998 L
.33855 .20201 L
.35721 .39802 L
.36705 .5022 L
.37244 .54989 L
.3775 .58481 L
.38003 .59798 L
.38275 .60859 L
.38423 .61272 L
.38503 .61448 L
.38578 .6158 L
.38642 .61669 L
.3871 .61739 L
.38786 .61787 L
.38855 .61803 L
.38986 .61761 L
.39108 .61639 L
.39171 .61543 L
.3924 .61412 L
.39381 .61069 L
.39505 .6068 L
.39637 .60173 L
.39877 .59035 L
.40417 .55495 L
.40929 .51091 L
.4189 .41078 L
.43708 .21696 L
.44745 .13219 L
.45252 .10013 L
.45718 .07604 L
.46171 .05712 L
.46668 .04088 L
.47167 .02857 L
.47442 .02322 L
.47692 .01912 L
.48218 .01249 L
.48507 .00978 L
.48779 .00771 L
.49265 .00496 L
.49539 .00384 L
.49792 .00301 L
.50258 .00189 L
.5052 .00145 L
.50759 .00112 L
.50981 .00089 L
.51224 .00068 L
.51451 .00053 L
Mistroke
.51665 .00041 L
.51937 .0003 L
.52183 .00023 L
.52448 .00016 L
.52735 .00012 L
.52986 8e-05 L
.53252 6e-05 L
.53479 5e-05 L
.53728 3e-05 L
.53979 2e-05 L
.54252 2e-05 L
.5451 1e-05 L
.54749 1e-05 L
.54963 1e-05 L
.552 0 L
.55447 0 L
.55679 0 L
.55935 0 L
.56064 0 L
.56205 0 L
.56325 0 L
.56454 0 L
.56686 0 L
.56826 0 L
.56979 0 L
.57113 0 L
.57255 0 L
.57383 0 L
.57523 0 L
.57771 0 L
.57901 0 L
.58021 0 L
.58163 0 L
.58293 0 L
.58532 0 L
.58664 0 L
.58788 0 L
.58901 0 L
.5902 0 L
.59234 0 L
.59353 0 L
.59464 0 L
.59595 0 L
.59716 0 L
.59846 0 L
.59988 0 L
.60112 0 L
.60245 0 L
.60473 0 L
.60604 0 L
Mistroke
.60726 0 L
.60865 0 L
.60997 0 L
.61116 0 L
.61246 0 L
.61386 0 L
.61536 0 L
.61678 0 L
.61806 0 L
.61926 0 L
.62038 0 L
.62161 0 L
.62292 0 L
.62431 0 L
.62562 0 L
.62679 0 L
.62807 0 L
.62917 0 L
.63039 0 L
.63166 0 L
.63286 0 L
.63389 0 L
.63499 0 L
.63619 0 L
.63729 0 L
.63859 0 L
.63977 0 L
.64114 0 L
.64243 0 L
.64363 0 L
.64473 0 L
.64594 0 L
.64722 0 L
.64851 0 L
.6499 0 L
.65121 0 L
.6524 0 L
.6538 0 L
.65532 0 L
.65676 0 L
.6581 0 L
.65939 0 L
.66075 0 L
.66191 0 L
.66318 0 L
.66456 0 L
.66603 0 L
.66742 0 L
.66868 0 L
.66996 0 L
Mistroke
.67113 0 L
.67243 0 L
.6738 0 L
.67499 0 L
.6761 0 L
.67733 0 L
.67864 0 L
.67982 0 L
.6809 0 L
.6821 0 L
.68338 0 L
.68472 0 L
.68599 0 L
.68712 0 L
.68836 0 L
.68943 0 L
.69061 0 L
.69184 0 L
.69299 0 L
.69407 0 L
.69505 0 L
.69618 0 L
.69726 0 L
.69851 0 L
.69921 0 L
.69986 0 L
.70105 0 L
.70231 0 L
.70344 0 L
.70449 0 L
.70565 0 L
.70688 0 L
.7082 0 L
.70895 0 L
.70964 0 L
.7109 0 L
.71154 0 L
.71224 0 L
.71346 0 L
.71476 0 L
.716 0 L
.71712 0 L
.71826 0 L
.71946 0 L
.7206 0 L
.72163 0 L
.72285 0 L
.72417 0 L
.72541 0 L
.72656 0 L
Mistroke
.72763 0 L
.72864 0 L
.72974 0 L
.73092 0 L
.73216 0 L
.73333 0 L
.73438 0 L
.73553 0 L
.73675 0 L
.73786 0 L
.73909 0 L
.74038 0 L
.7415 0 L
.74255 0 L
.7437 0 L
.74493 0 L
.74562 0 L
.74627 0 L
.74696 0 L
.74772 0 L
.749 0 L
.74971 0 L
.75036 0 L
.75161 0 L
.75274 0 L
.75405 0 L
.7553 0 L
.75598 0 L
.75663 0 L
.75783 0 L
.75912 0 L
.75985 0 L
.76052 0 L
.76164 0 L
.76287 0 L
.76415 0 L
.76535 0 L
.76603 0 L
.76677 0 L
.76743 0 L
.76812 0 L
.76943 0 L
.77064 0 L
.77131 0 L
.77203 0 L
.77334 0 L
.77409 0 L
.77489 0 L
.77557 0 L
.77631 0 L
Mistroke
.77695 0 L
.77763 0 L
.77885 0 L
.78017 0 L
.78091 0 L
.78161 0 L
.78287 0 L
.78402 0 L
.78465 0 L
.78535 0 L
.78661 0 L
.78772 0 L
.78896 0 L
.79025 0 L
.79146 0 L
.79259 0 L
.79362 0 L
.79476 0 L
.79595 0 L
.79726 0 L
.79846 0 L
.79912 0 L
.79983 0 L
.80113 0 L
.80235 0 L
.80364 0 L
.80475 0 L
.80596 0 L
.80669 0 L
.80738 0 L
.80869 0 L
.80941 0 L
.81009 0 L
.81083 0 L
.81162 0 L
.8123 0 L
.81305 0 L
.81375 0 L
.8144 0 L
.81562 0 L
.81692 0 L
.81814 0 L
.81883 0 L
.81946 0 L
.82063 0 L
.82188 0 L
.82299 0 L
.82403 0 L
.82517 0 L
.8264 0 L
Mistroke
.82764 0 L
.82833 0 L
.82898 0 L
.8303 0 L
.83104 0 L
.8317 0 L
.8329 0 L
.83421 0 L
.83543 0 L
.83657 0 L
.83762 0 L
.83876 0 L
.83983 0 L
.84081 0 L
.84195 0 L
.8432 0 L
.84438 0 L
.84547 0 L
.84671 0 L
.84787 0 L
.84891 0 L
.85004 0 L
.85127 0 L
.85258 0 L
.85369 0 L
.8549 0 L
.85621 0 L
.85743 0 L
.85806 0 L
.85875 0 L
.85948 0 L
.86017 0 L
.86142 0 L
.86256 0 L
.86388 0 L
.86514 0 L
.86626 0 L
.86745 0 L
.86858 0 L
.8696 0 L
.8708 0 L
.8721 0 L
.87333 0 L
.87446 0 L
.87567 0 L
.87697 0 L
.87819 0 L
.87931 0 L
.88062 0 L
.88136 0 L
Mistroke
.88205 0 L
.8833 0 L
.88394 0 L
.88464 0 L
.88532 0 L
.88603 0 L
.88731 0 L
.88802 0 L
.88868 0 L
.88941 0 L
.89018 0 L
.89086 0 L
.89159 0 L
.89228 0 L
.89291 0 L
.89412 0 L
.89539 0 L
.8966 0 L
.89792 0 L
.89917 0 L
.90032 0 L
.90146 0 L
.9025 0 L
.9037 0 L
.90482 0 L
.90606 0 L
.90736 0 L
.90847 0 L
.90969 0 L
.91101 0 L
.91174 0 L
.91242 0 L
.91372 0 L
.91496 0 L
.91601 0 L
.91717 0 L
.91838 0 L
.91951 0 L
.92057 0 L
.92154 0 L
.92261 0 L
.92373 0 L
.92487 0 L
.92609 0 L
.92724 0 L
.92829 0 L
.92952 0 L
.93021 0 L
.93085 0 L
.93202 0 L
Mistroke
.93326 0 L
.93448 0 L
.9358 0 L
.93705 0 L
.93821 0 L
.93925 0 L
.94039 0 L
.94159 0 L
.94272 0 L
.94396 0 L
.94526 0 L
.94638 0 L
.9476 0 L
.94892 0 L
.94965 0 L
.95033 0 L
.95163 0 L
.95287 0 L
.95392 0 L
.95508 0 L
.9563 0 L
.95743 0 L
.95849 0 L
.95947 0 L
.96059 0 L
.96165 0 L
.9628 0 L
.96402 0 L
.96517 0 L
.96621 0 L
.96744 0 L
.96814 0 L
.96877 0 L
.96995 0 L
.97119 0 L
.97244 0 L
.97314 0 L
.97377 0 L
.97502 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ol0
0009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`Wo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05_ooool001[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`?o00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo001`ooooo`;o00003oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0;Cooooo001booooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0:oooool2o`000;Oooooo001cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`2fooooo`00Loooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0]oooool007Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;Sooooo001eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2ioooo
o`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0^Oooool007Kooooo00?o0000ooooooooool02?ooool3o`0002Sooooo00?o0000ooooooooool0
^Oooool007Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo0;Wooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`2jooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo0;_ooooo001gooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`2kooooo`00N?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0_?ooool007Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo001hoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2loooo
o`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0_Oooool007Wooooo00?o0000ooooooooool01Oooool3o`0002Cooooo00?o0000ooooooooool0
_Oooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo0;gooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`2mooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0__ooool007[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo001jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`2nooooo`00N_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0__ooool007_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo001koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2ooooo
o`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0_oooool007_ooooo00?o0000ooooooooool00oooool3o`0002;ooooo00?o0000ooooooooool0
_oooool007_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo0;oooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`30ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0`?ooool007cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo0<3ooooo001looooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`30ooooo`00O?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0`?ooool007cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0<3ooooo001Voooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00002ooooo`05o`000?oooooo
ooooooooool000008oooool00ol0003oooooooooo`30ooooo`00I_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01Ol0003ooooo
oooooooooooo000002;ooooo00?o0000ooooooooool0`Oooool006Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Roooo
o`03o`000?oooooooooo0<7ooooo001Vooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP02ooooo`04o`000?ooooooooooooooo`?o00008?ooool00ol0003oooooooooo`31
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000kooooo00GoMgMgofIVI_ooooooooooo`00
0003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0`Oooool006Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`31ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000oooo
ooooool0`Oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo0<7ooooo001n
ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool0`Oooool007kooooo00Co0000
oooooooooooo00008Oooool00ol0003oooooooooo`32ooooo`00O_ooool01?l0003oooooooooool0
000Qooooo`03o`000?oooooooooo0<;ooooo001nooooo`04o`000?ooooooooooo`00027ooooo00?o
0000ooooooooool0`_ooool007kooooo00Co0000oooooooooooo00008Oooool00ol0003ooooooooo
o`32ooooo`00O_ooool00ol0003oooooooooo`03o`0001oooooo00?o0000ooooooooool0`_ooool0
07kooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`32ooooo`00Ooooool00ol0
003oooooo`00000Qooooo`03o`000?oooooooooo0<;ooooo001oooooo`03o`000?oooooo0000023o
oooo00?o0000ooooooooool0`oooool007oooooo00?o0000ooooool000008?ooool00ol0003ooooo
ooooo`33ooooo`00Ooooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo0<?ooooo001o
ooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool0`oooool007oooooo00?o0000oooo
ool000008?ooool00ol0003oooooooooo`33ooooo`00Ooooool00ol0003oooooo`00000Pooooo`03
o`000?oooooooooo0<?ooooo001oooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool0
`oooool007oooooo00?o0000ooooool000000_l0000Mooooo`03o`000?oooooooooo0<Cooooo0020
ooooo`;o00007oooool00ol0003oooooooooo`34ooooo`00P?ooool2o`0001oooooo00?o0000oooo
ooooool0a?ooool0083ooooo0_l0000Oooooo`03o`000?oooooooooo0<Cooooo0020ooooo`;o0000
7oooool00ol0003oooooooooo`34ooooo`00P?ooool2o`0001oooooo00?o0000ooooooooool0a?oo
ool0083ooooo0_l0000Oooooo`03o`000?oooooooooo0<Cooooo0020ooooo`;o00007_ooool00ol0
003oooooooooo`35ooooo`00P?ooool2o`0001kooooo00?o0000ooooooooool0aOooool0083ooooo
0_l0000Nooooo`03o`000?oooooooooo0<Gooooo0020ooooo`Co00007?ooool00ol0003ooooooooo
o`35ooooo`00POooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Gooooo0021oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo0<Gooooo0021ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOoo
ool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo0<Kooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0000Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00I_ooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`0001_ooooo00?o
0000ooooooooool0a_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0000Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool2o`0001cooooo
00?o0000ooooooooool0a_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo0_l0000Looooo`03o`000?oooooooooo0<Kooooo001Vooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`;o00007?ooool00ol0003ooooo
ooooo`36ooooo`00POooool2o`0001cooooo00?o0000ooooooooool0a_ooool0087ooooo0_l0000L
ooooo`03o`000?oooooooooo0<Kooooo0021ooooo`;o00006oooool00ol0003oooooooooo`37oooo
o`00POooool2o`0001_ooooo00?o0000ooooooooool0aoooool0087ooooo0_l0000Kooooo`03o`00
0?oooooooooo0<Oooooo0021ooooo`?o00006_ooool00ol0003oooooooooo`37ooooo`00POooool2
o`0001_ooooo00?o0000ooooooooool0aoooool0087ooooo0_l0000Kooooo`03o`000?oooooooooo
0<Oooooo0021ooooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0aoooool0087ooooo
00?o0000ooooool000006_ooool00ol0003oooooooooo`37ooooo`00POooool00ol0003oooooo`00
000Jooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03o`000?oooooo000001[ooooo00?o0000
ooooooooool0aoooool0087ooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`38oooo
o`00POooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo0<Sooooo0021ooooo`03o`00
0?oooooo000001Wooooo00?o0000ooooooooool0b?ooool0087ooooo0ol0000Iooooo`03o`000?oo
oooooooo0<Sooooo0021ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool0b?ooool0
087ooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`38ooooo`00POooool01?l0003o
ooooooooool0000Hooooo`03o`000?oooooooooo0<Sooooo0021ooooo`04o`000?ooooooooooo`00
01Sooooo00?o0000ooooooooool0b?ooool0087ooooo00Co0000oooooooooooo00006?ooool00ol0
003oooooooooo`38ooooo`00POooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo
0<Sooooo0021ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0b?ooool0087o
oooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`39ooooo`00POooool01?l0003o
ooooooooool0000Gooooo`03o`000?oooooooooo0<Wooooo0021ooooo`Co00005oooool00ol0003o
ooooooooo`39ooooo`00POooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo0<Wo
oooo0021ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool0bOooool0087ooooo
00Co0000oooooooooooo00005oooool00ol0003oooooooooo`39ooooo`00POooool01Ol0003ooooo
oooooooooooo000001Kooooo00?o0000ooooooooool0bOooool0087ooooo00Go0000oooooooooooo
ooooo`00000Fooooo`03o`000?oooooooooo0<Wooooo0021ooooo`05o`000?ooooooooooooooool0
00005_ooool00ol0003oooooooooo`39ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool01Ol0003ooooooooooooooooo
000001Kooooo00?o0000ooooooooool0bOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo0<[ooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00000Eoooo
o`03o`000?oooooooooo0<[ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooo
oooo0<[ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo0<[ooooo
001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`05o`00
0?ooooooooooooooool000005Oooool00ol0003oooooooooo`3:ooooo`00I_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool0b_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oo
oooooooo0<[ooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3:ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0b_ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0<[ooooo0021ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`3:ooooo`00POooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0boooool0087ooooo0ol00002
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0boooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3;ooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
boooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo0<_ooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0boooool0087ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`3;ooooo`00POooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0c?ooool0087ooooo0ol00003
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0<cooooo0021ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3<ooooo`00
POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
c?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo0<cooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`3<ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3<ooooo`00POooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0c?ooool0087ooooo0ol00004
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0cOooool0087ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<gooooo0021ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3=ooooo`00
POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
cOooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0<gooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0cOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<gooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3=ooooo`00I_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3=ooooo`00I_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o
00001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0<gooooo001Vooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo001Voooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo001V
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo
0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`3>ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0c_ooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0c_ooool0087ooooo0ol00006ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0c_ooool0087ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0coooool0087ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<oooooo
0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3?ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0coooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0coooool0087ooooo0ol00007ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0coooool0087ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0d?ooool0087ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=3ooooo
0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3@ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0d?ooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0dOooool0087ooooo0ol00009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=7ooooo0021ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Aooooo`00POooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0dOooool0087ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=;ooooo
0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3Booooo`00POooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000e?oo
ool007Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo0000eOooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`04o`000?ooooooooooo`000=Gooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool4o`000=Gooooo001iooooo`03o`000?oooooooooo00Gooooo0ol0000<oooo
o`;o0000e_ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0
k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Oooooo00?oEEEEofIVI_l00000k_ooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04521 0 L
.04648 0 L
.04765 0 L
.04871 0 L
.04987 0 L
.05108 0 L
.05221 0 L
.05354 0 L
.0548 0 L
.05592 0 L
.05715 0 L
.05848 0 L
.0599 0 L
.06111 0 L
.06244 0 L
.06371 0 L
.0651 0 L
.06655 0 L
.0679 0 L
.06917 0 L
.07032 0 L
.07165 0 L
.0729 0 L
.07427 0 L
.07572 0 L
.07695 0 L
.07831 0 L
.07977 0 L
.08134 0 L
.08282 0 L
.08418 0 L
.08544 0 L
Mistroke
.08678 0 L
.08918 0 L
.09066 0 L
.09205 0 L
.0933 0 L
.09464 0 L
.09716 0 L
.09843 0 L
.09982 0 L
.10101 0 L
.10228 0 L
.10458 0 L
.1058 0 L
.10715 0 L
.10856 0 L
.10988 0 L
.11224 0 L
.11357 0 L
.11478 0 L
.11736 0 L
.11882 0 L
.12018 0 L
.12293 0 L
.12447 0 L
.12586 0 L
.12712 0 L
.12845 0 L
.13084 0 L
.13216 0 L
.1334 0 L
.13485 0 L
.13622 0 L
.1374 0 L
.13869 0 L
.14094 0 L
.14221 0 L
.14356 0 L
.14472 0 L
.14599 0 L
.14837 0 L
.14966 0 L
.15087 0 L
.15303 0 L
.15535 0 L
.15665 0 L
.15807 0 L
.16063 0 L
.16313 0 L
.16544 0 L
.16762 0 L
Mistroke
.16966 0 L
.1719 0 L
.17431 0 L
.17683 0 L
.17922 0 L
.18137 0 L
.18371 0 L
.18627 0 L
.18903 0 L
.19164 0 L
.19404 0 L
.19621 0 L
.19859 0 L
.20108 1e-05 L
.2034 1e-05 L
.20612 1e-05 L
.2087 1e-05 L
.21101 2e-05 L
.21353 2e-05 L
.21626 3e-05 L
.21916 4e-05 L
.22164 5e-05 L
.22438 7e-05 L
.22673 9e-05 L
.2293 .00011 L
.23198 .00015 L
.23448 .00019 L
.23896 .00029 L
.24146 .00037 L
.24374 .00045 L
.24889 .00073 L
.25179 .00094 L
.25447 .00119 L
.25939 .00181 L
.26187 .00222 L
.2646 .00277 L
.2671 .00338 L
.26982 .00418 L
.27477 .00609 L
.27959 .00865 L
.28406 .01183 L
.28938 .0169 L
.29419 .02301 L
.29974 .0323 L
.30496 .04369 L
.31476 .07369 L
.31969 .09381 L
.32509 .12018 L
.34358 .24589 L
.36478 .43454 L
Mistroke
.37481 .51805 L
.37922 .5491 L
.38408 .57766 L
.38874 .59847 L
.39129 .60684 L
.39368 .61261 L
.39503 .61496 L
.39631 .61658 L
.39746 .61753 L
.39871 .618 L
.39942 .61802 L
.40006 .61787 L
.40081 .6175 L
.40151 .61697 L
.40276 .61558 L
.40347 .61455 L
.40411 .61343 L
.40638 .60835 L
.4085 .60196 L
.41333 .58184 L
.41802 .55541 L
.42306 .52071 L
.44286 .34883 L
.45331 .25694 L
.46441 .17285 L
.47424 .11442 L
.47946 .08976 L
.4851 .06784 L
.49025 .05165 L
.49497 .03967 L
.49983 .02982 L
.50424 .02273 L
.50898 .01677 L
.51404 .01193 L
.51873 .00859 L
.52316 .00622 L
.52832 .00421 L
.53309 .00289 L
.53558 .00237 L
.53832 .00189 L
.54096 .00151 L
.54385 .00118 L
.54656 .00093 L
.54906 .00075 L
.55166 .00059 L
.55401 .00048 L
.5585 .00031 L
.56097 .00025 L
.56329 .0002 L
.56584 .00015 L
Mistroke
.56852 .00012 L
.57082 9e-05 L
.57333 7e-05 L
.57604 5e-05 L
.57895 4e-05 L
.58168 3e-05 L
.58418 2e-05 L
.58647 2e-05 L
.589 1e-05 L
.59164 1e-05 L
.59411 1e-05 L
.59642 1e-05 L
.59853 0 L
.60085 0 L
.60329 0 L
.60578 0 L
.60844 0 L
.61094 0 L
.61322 0 L
.6159 0 L
.61731 0 L
.6188 0 L
.62154 0 L
.62407 0 L
.6266 0 L
.62901 0 L
.63117 0 L
.63352 0 L
.63607 0 L
.63736 0 L
.63879 0 L
.64131 0 L
.64367 0 L
.64591 0 L
.64826 0 L
.65028 0 L
.65248 0 L
.65486 0 L
.65619 0 L
.65741 0 L
.65976 0 L
.66199 0 L
.66314 0 L
.66438 0 L
.66661 0 L
.66797 0 L
.66926 0 L
.67169 0 L
.67293 0 L
.67424 0 L
Mistroke
.67661 0 L
.67806 0 L
.67942 0 L
.68064 0 L
.68197 0 L
.68422 0 L
.68544 0 L
.68659 0 L
.68864 0 L
.68979 0 L
.69083 0 L
.69319 0 L
.69452 0 L
.69575 0 L
.69801 0 L
.69916 0 L
.70041 0 L
.70276 0 L
.7041 0 L
.70533 0 L
.70662 0 L
.70784 0 L
.70924 0 L
.71051 0 L
.71163 0 L
.71282 0 L
.71495 0 L
.71614 0 L
.71725 0 L
.71855 0 L
.71977 0 L
.72106 0 L
.72246 0 L
.7237 0 L
.72502 0 L
.72632 0 L
.72754 0 L
.72863 0 L
.72982 0 L
.73114 0 L
.73253 0 L
.73382 0 L
.73502 0 L
.73643 0 L
.73773 0 L
.73922 0 L
.74063 0 L
.74177 0 L
.743 0 L
.74407 0 L
Mistroke
.74523 0 L
.74659 0 L
.74788 0 L
.74914 0 L
.75031 0 L
.75165 0 L
.75291 0 L
.75405 0 L
.75528 0 L
.75662 0 L
.75804 0 L
.75925 0 L
.76058 0 L
.76181 0 L
.76298 0 L
.76404 0 L
.76518 0 L
.76642 0 L
.76774 0 L
.76887 0 L
.77011 0 L
.77126 0 L
.77232 0 L
.77348 0 L
.7747 0 L
.77577 0 L
.77676 0 L
.77785 0 L
.77901 0 L
.78024 0 L
.7816 0 L
.78301 0 L
.78434 0 L
.78557 0 L
.7867 0 L
.78801 0 L
.78924 0 L
.79058 0 L
.792 0 L
.79334 0 L
.79455 0 L
.79599 0 L
.79674 0 L
.79753 0 L
.799 0 L
.80034 0 L
.8016 0 L
.80274 0 L
.80406 0 L
.80531 0 L
Mistroke
.80647 0 L
.80753 0 L
.80871 0 L
.80995 0 L
.81119 0 L
.81253 0 L
.8138 0 L
.81496 0 L
.81625 0 L
.81765 0 L
.81836 0 L
.81912 0 L
.82049 0 L
.82172 0 L
.82308 0 L
.8245 0 L
.82583 0 L
.82707 0 L
.8282 0 L
.8295 0 L
.83074 0 L
.83208 0 L
.83283 0 L
.8335 0 L
.83482 0 L
.83606 0 L
.83677 0 L
.83751 0 L
.83885 0 L
.83959 0 L
.84028 0 L
.8411 0 L
.84186 0 L
.84311 0 L
.84448 0 L
.84568 0 L
.84695 0 L
.84809 0 L
.84916 0 L
.85033 0 L
.85159 0 L
.85293 0 L
.85368 0 L
.85438 0 L
.85567 0 L
.85638 0 L
.85703 0 L
.85827 0 L
.85891 0 L
.8596 0 L
Mistroke
.86086 0 L
.86201 0 L
.86323 0 L
.86388 0 L
.86456 0 L
.86581 0 L
.86697 0 L
.86808 0 L
.86912 0 L
.87026 0 L
.87149 0 L
.87272 0 L
.87342 0 L
.87407 0 L
.87538 0 L
.87612 0 L
.87679 0 L
.87799 0 L
.87929 0 L
.88052 0 L
.88165 0 L
.8827 0 L
.88384 0 L
.88491 0 L
.88589 0 L
.88703 0 L
.88828 0 L
.88946 0 L
.89055 0 L
.89179 0 L
.89295 0 L
.89399 0 L
.89512 0 L
.89635 0 L
.89765 0 L
.89876 0 L
.89998 0 L
.90129 0 L
.9025 0 L
.90313 0 L
.90383 0 L
.90456 0 L
.90524 0 L
.90647 0 L
.90712 0 L
.9078 0 L
.90895 0 L
.91021 0 L
.91143 0 L
.91255 0 L
Mistroke
.91383 0 L
.91504 0 L
.91616 0 L
.91719 0 L
.91833 0 L
.91953 0 L
.92083 0 L
.92201 0 L
.92267 0 L
.92338 0 L
.92468 0 L
.92589 0 L
.92718 0 L
.92828 0 L
.9295 0 L
.93019 0 L
.93091 0 L
.93221 0 L
.93294 0 L
.93361 0 L
.9344 0 L
.93514 0 L
.93579 0 L
.93649 0 L
.93771 0 L
.9384 0 L
.93914 0 L
.94045 0 L
.94159 0 L
.94283 0 L
.94401 0 L
.9451 0 L
.94618 0 L
.94715 0 L
.94828 0 L
.94935 0 L
.95051 0 L
.95174 0 L
.95279 0 L
.95394 0 L
.95518 0 L
.95588 0 L
.95651 0 L
.95774 0 L
.95891 0 L
.9599 0 L
.96099 0 L
.96214 0 L
.96321 0 L
.96421 0 L
Mistroke
.96512 0 L
.96613 0 L
.96719 0 L
.96826 0 L
.96942 0 L
.9705 0 L
.97149 0 L
.97265 0 L
.97391 0 L
.9751 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo2Ol00004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool;o`0000[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_oo
ool001[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`Go00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`Co00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo001]ooooo`;o00004_ooool00ol0003oooooooooo`0fooooo`;o0000[?ooool006oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:co
oooo001_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`2/ooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0[Oooool0077ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo0:kooooo001booooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`2_ooooo`00L_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0[oooool007?ooooo00?o0000ooooooooool0
2oooool3o`00037ooooo00?o0000ooooooooool0/?ooool007Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0;3ooooo001dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2aooooo`00MOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/_ooool007Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0;;o
oooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2booooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0/oooool007Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo0;?ooooo001gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`2cooooo`00Moooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0]?ooool007Sooooo00?o0000ooooooooool0
1_ooool3o`0002gooooo00?o0000ooooooooool0]?ooool007Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0;Cooooo001hooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2eooooo`00NOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0]Oooool007Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0;Go
oooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`2fooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0]_ooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0;Kooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`2fooooo`00N_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0]oooool007[ooooo00?o0000ooooooooool0
1?ooool3o`0002[ooooo00?o0000ooooooooool0]oooool007[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;Oooooo001jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2gooooo`00N_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0^?ooool007_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;So
oooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`2hooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0^?ooool007_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo0;Wooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0^Oooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1onHV9So8B4Qonk^k_ooooooA4A4ooooool000001?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo0;Wooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`2iooooo`00I_ooool01Ol0003ooooooooooooooooo000000gooooo00GoV9RHob4Q8Oo^k^ko
ooooo`000004ooooo`?o0000:?ooool00ol0003oooooooooo`2iooooo`00I_ooool01Ol0003ooooo
oooooooooooo000000kooooo00CoMgMgofIVI_oooooo00001?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo0;[ooooo001Vooooo`05oa0@4?ooooooooooooooool@41003oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0^_ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000_oo
ool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool0^_ooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool01Ol0003o
oooooooooooooooo000002Wooooo00?o0000ooooooooool0^_ooool007gooooo00Go0000oooooooo
ooooooooo`00000Yooooo`03o`000?oooooooooo0;[ooooo001mooooo`05o`000?oooooooooooooo
ool00000:Oooool00ol0003oooooooooo`2jooooo`00OOooool01Ol0003ooooooooooooooooo0000
02Sooooo00?o0000ooooooooool0^oooool007gooooo00Go0000ooooooooooooooooo`00000Xoooo
o`03o`000?oooooooooo0;_ooooo001nooooo`04o`000?ooooooooooo`0002Sooooo00?o0000oooo
ooooool0^oooool007kooooo00?o0000ooooooooool00ol0000Vooooo`03o`000?oooooooooo0;_o
oooo001nooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0^oooool007kooooo
00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`2kooooo`00O_ooool01?l0003ooooo
ooooool0000Wooooo`03o`000?oooooooooo0;cooooo001nooooo`04o`000?ooooooooooo`0002Oo
oooo00?o0000ooooooooool0_?ooool007kooooo00Co0000oooooooooooo00009oooool00ol0003o
ooooooooo`2looooo`00Ooooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo0;cooooo
001oooooo`03o`000?oooooo000002Oooooo00?o0000ooooooooool0_?ooool007oooooo00?o0000
ooooool000009oooool00ol0003oooooooooo`2looooo`00Ooooool00ol0003oooooo`00000Woooo
o`03o`000?oooooooooo0;cooooo001oooooo`03o`000?oooooo000000;o00009Oooool00ol0003o
ooooooooo`2looooo`00Ooooool00ol0003oooooo`00000Vooooo`03o`000?oooooooooo0;gooooo
001oooooo`03o`000?oooooo000002Kooooo00?o0000ooooooooool0_Oooool0083ooooo0_l0000V
ooooo`03o`000?oooooooooo0;gooooo0020ooooo`;o00009_ooool00ol0003oooooooooo`2moooo
o`00P?ooool2o`0002Kooooo00?o0000ooooooooool0_Oooool0083ooooo0_l0000Vooooo`03o`00
0?oooooooooo0;gooooo0020ooooo`;o00009_ooool00ol0003oooooooooo`2mooooo`00P?ooool2
o`0002Kooooo00?o0000ooooooooool0_Oooool0083ooooo0_l0000Vooooo`03o`000?oooooooooo
0;gooooo0021ooooo`?o00008oooool00ol0003oooooooooo`2nooooo`00POooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2n
ooooo`00POooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo0021ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`2nooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool2o`0002Cooooo00?o0000ooooooooool0
__ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`;o00009?ooool00ol0003oooooooooo`2nooooo`00I_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`;o00008oooool00ol0003oooooooooo`2oooooo`00I_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`0002;o
oooo00?o0000ooooooooool0_oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Oooooo0_l0000Sooooo`03o`000?oooooooooo0;oooooo001Vooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`;o00008oooool00ol0
003oooooooooo`2oooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000001oooool2o`0002?ooooo00?o0000ooooooooool0_oooool006Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooool000008_ooool00ol0
003oooooooooo`2oooooo`00POooool00ol0003oooooo`00000Rooooo`03o`000?oooooooooo0;oo
oooo0021ooooo`03o`000?oooooo000002;ooooo00?o0000ooooooooool0_oooool0087ooooo00?o
0000ooooool000008_ooool00ol0003oooooooooo`2oooooo`00POooool00ol0003oooooo`00000Q
ooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`000?oooooo0000027ooooo00?o0000oooo
ooooool0`?ooool0087ooooo0ol0000Qooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`00
0?oooooo0000027ooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooool000008Ooo
ool00ol0003oooooooooo`30ooooo`00POooool01?l0003oooooooooool0000Pooooo`03o`000?oo
oooooooo0<3ooooo0021ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool0`?oo
ool0087ooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`31ooooo`00POooool0
1?l0003oooooooooool0000Oooooo`03o`000?oooooooooo0<7ooooo0021ooooo`04o`000?oooooo
ooooo`0001oooooo00?o0000ooooooooool0`Oooool0087ooooo00Co0000oooooooooooo00007ooo
ool00ol0003oooooooooo`31ooooo`00POooool01?l0003oooooooooool0000Oooooo`03o`000?oo
oooooooo0<7ooooo0021ooooo`Co00007oooool00ol0003oooooooooo`31ooooo`00POooool01?l0
003oooooooooool0000Oooooo`03o`000?oooooooooo0<7ooooo0021ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`31ooooo`00POooool01Ol0003ooooooooooooooooo
000001gooooo00?o0000ooooooooool0`_ooool0087ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03o`000?oooooooooo0<;ooooo0021ooooo`05o`000?ooooooooooooooool000007Oooool0
0ol0003oooooooooo`32ooooo`00POooool01Ol0003ooooooooooooooooo000001gooooo00?o0000
ooooooooool0`_ooool0087ooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooo
oooo0<;ooooo0021ooooo`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`32
ooooo`00POooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool0`_ooool0
087ooooo0ol00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0`oooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<?o
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`33ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0`oooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo0<?ooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`33ooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0`oooool006Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<?ooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`33
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`34ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00000oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Cooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Co
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`34ooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0a?ooool006Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`34ooooo`00
POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
a?ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo0<Cooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0aOooool0087ooooo0ol00004ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0aOooool0087ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0<Gooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<Gooooo0021ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`35ooooo`00
POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
aOooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo0<Kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`36ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0a_ooool0087ooooo0ol00005ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0a_ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`36ooooo`00POooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0a_ooool0087ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`36ooooo`00
POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
aoooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo0<Oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`37ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0aoooool0087ooooo0ol00006ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0aoooool0087ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`37ooooo`00POooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0aoooool0087ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`38ooooo`00
POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
b?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0<Sooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`38ooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`38ooooo`00I_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00001oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Wooooo0021ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`39ooooo`00POooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0bOooool0087ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Wooooo
0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`39ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0bOooool0087ooooo0ol00008ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0bOooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0<Wooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3:ooooo`00POooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0b_ooool0087ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0<[ooooo0021ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3:ooooo`00POooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0b_ooool0087ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<[ooooo
0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3;ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0boooool0087ooooo0ol0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0boooool0087ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0boooool0087ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3<ooooo`00POooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0c?ooool0087ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<cooooo
0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3<ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0c?ooool0087ooooo0ol0000<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0c?ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0<gooooo0021ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0cOooool0087ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0c_ooool007Oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`00003Aooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo
00Go0000ooooooooooooooooo`00003Aooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooool00000d_ooool007Wooooo00?o0000ooooooooool01Ooo
ool3o`00013ooooo0_l0003Booooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0
003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00Moooool00omEEEGoIVIV
o`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02846 0 L
.03068 0 L
.03279 0 L
.03524 0 L
.0375 0 L
.03998 0 L
.04124 0 L
.04262 0 L
.04394 0 L
.04519 0 L
.04755 0 L
.04886 0 L
.05009 0 L
.05151 0 L
.05285 0 L
.05529 0 L
.0575 0 L
.05987 0 L
.06244 0 L
.06371 0 L
.06508 0 L
.06753 0 L
.06903 0 L
.07045 0 L
.07312 0 L
.07448 0 L
.07592 0 L
.07852 0 L
.07996 0 L
.08131 0 L
.08278 0 L
.08439 0 L
.08686 0 L
.08946 0 L
.09187 0 L
.09411 0 L
.09676 0 L
.09917 0 L
.10195 0 L
.10458 0 L
.10697 0 L
.10921 0 L
.11166 0 L
.1143 0 L
.11706 0 L
.11968 0 L
.12203 0 L
Mistroke
.12459 0 L
.12703 0 L
.12923 0 L
.13177 0 L
.13417 0 L
.13639 0 L
.13844 0 L
.14068 0 L
.14305 0 L
.1456 0 L
.14802 0 L
.15019 0 L
.15255 0 L
.15512 0 L
.15784 0 L
.16016 0 L
.16272 0 L
.16728 0 L
.16985 0 L
.17219 1e-05 L
.17652 1e-05 L
.17869 1e-05 L
.18107 1e-05 L
.18362 2e-05 L
.18637 2e-05 L
.1888 3e-05 L
.19137 4e-05 L
.19369 4e-05 L
.19624 6e-05 L
.20072 8e-05 L
.20345 .0001 L
.20595 .00013 L
.20863 .00016 L
.21156 .0002 L
.21426 .00025 L
.21675 .0003 L
.22168 .00044 L
.22631 .00062 L
.23129 .0009 L
.236 .00125 L
.24032 .00169 L
.24511 .00234 L
.25035 .00331 L
.25582 .00469 L
.26092 .00641 L
.26596 .00866 L
.27142 .01185 L
.27659 .01576 L
.28135 .02031 L
.29037 .03203 L
Mistroke
.29492 .03981 L
.29993 .0501 L
.31008 .07737 L
.31935 .11104 L
.33006 .16144 L
.34024 .22077 L
.37845 .49379 L
.38859 .55418 L
.39356 .57769 L
.39814 .59495 L
.40066 .60253 L
.40343 .60916 L
.40477 .61173 L
.40621 .614 L
.40773 .61586 L
.40846 .61655 L
.40914 .61708 L
.41043 .61776 L
.4111 .61795 L
.41182 .61803 L
.41303 .61788 L
.41372 .61764 L
.41436 .6173 L
.41556 .6164 L
.41665 .61527 L
.41912 .61166 L
.4216 .60654 L
.42386 .60063 L
.42893 .58324 L
.43805 .53901 L
.45876 .39824 L
.47958 .24704 L
.48872 .18964 L
.49876 .13643 L
.50778 .09808 L
.51746 .06636 L
.52281 .05264 L
.52769 .04217 L
.53725 .02658 L
.54204 .0208 L
.54713 .01587 L
.55153 .01245 L
.55629 .0095 L
.5619 .00682 L
.56717 .00494 L
.57231 .00357 L
.57703 .00263 L
.58175 .00191 L
.5868 .00135 L
.59157 .00096 L
Mistroke
.59591 .0007 L
.601 .00048 L
.60388 .00038 L
.60654 .00031 L
.61142 .00021 L
.61388 .00017 L
.61659 .00014 L
.61907 .00011 L
.62178 9e-05 L
.62417 7e-05 L
.62672 6e-05 L
.62924 5e-05 L
.63152 4e-05 L
.63599 3e-05 L
.63868 2e-05 L
.64115 2e-05 L
.64381 1e-05 L
.64674 1e-05 L
.64911 1e-05 L
.65166 1e-05 L
.65435 0 L
.65686 0 L
.65942 0 L
.66214 0 L
.66447 0 L
.66703 0 L
.66978 0 L
.67274 0 L
.67553 0 L
.67809 0 L
.68052 0 L
.68277 0 L
.68525 0 L
.68789 0 L
.69067 0 L
.6933 0 L
.69566 0 L
.69821 0 L
.70057 0 L
.7031 0 L
.70549 0 L
.70767 0 L
.71023 0 L
.71301 0 L
.71564 0 L
.71808 0 L
.72083 0 L
.72343 0 L
.72575 0 L
.72827 0 L
Mistroke
.73102 0 L
.7324 0 L
.73392 0 L
.73661 0 L
.73912 0 L
.74173 0 L
.74414 0 L
.74678 0 L
.74812 0 L
.74959 0 L
.75205 0 L
.75471 0 L
.75721 0 L
.7595 0 L
.76174 0 L
.76383 0 L
.76611 0 L
.76855 0 L
.76978 0 L
.77112 0 L
.77354 0 L
.7759 0 L
.77807 0 L
.78052 0 L
.78275 0 L
.78399 0 L
.78533 0 L
.78778 0 L
.79007 0 L
.79249 0 L
.79457 0 L
.79686 0 L
.79816 0 L
.79953 0 L
.80198 0 L
.80335 0 L
.80462 0 L
.8061 0 L
.80751 0 L
.80872 0 L
.81004 0 L
.81234 0 L
.81365 0 L
.81503 0 L
.81751 0 L
.81872 0 L
.82003 0 L
.82119 0 L
.82243 0 L
.82365 0 L
Mistroke
.82476 0 L
.82693 0 L
.82823 0 L
.82943 0 L
.83072 0 L
.83214 0 L
.83453 0 L
.83583 0 L
.83705 0 L
.83819 0 L
.83942 0 L
.84051 0 L
.84167 0 L
.84271 0 L
.84386 0 L
.84588 0 L
.84711 0 L
.84824 0 L
.84945 0 L
.85077 0 L
.853 0 L
.85422 0 L
.85535 0 L
.85663 0 L
.85798 0 L
.8604 0 L
.86175 0 L
.86301 0 L
.86439 0 L
.86588 0 L
.86715 0 L
.86854 0 L
.86977 0 L
.87107 0 L
.87236 0 L
.87353 0 L
.87582 0 L
.87698 0 L
.87822 0 L
.88042 0 L
.88165 0 L
.88279 0 L
.88413 0 L
.8854 0 L
.88649 0 L
.88767 0 L
.88975 0 L
.89092 0 L
.89217 0 L
.89441 0 L
Mistroke
.89561 0 L
.89692 0 L
.89808 0 L
.89931 0 L
.90053 0 L
.90164 0 L
.90381 0 L
.90511 0 L
.90631 0 L
.90762 0 L
.90901 0 L
.91022 0 L
.91135 0 L
.91259 0 L
.91392 0 L
.91514 0 L
.91627 0 L
.91751 0 L
.91883 0 L
.9199 0 L
.92105 0 L
.92231 0 L
.92349 0 L
.92571 0 L
.92682 0 L
.92804 0 L
.92909 0 L
.9302 0 L
.93222 0 L
.93345 0 L
.9348 0 L
.93621 0 L
.93754 0 L
.93877 0 L
.9399 0 L
.94121 0 L
.94245 0 L
.94378 0 L
.9452 0 L
.94654 0 L
.94775 0 L
.94919 0 L
.95074 0 L
.9522 0 L
.95354 0 L
.95471 0 L
.95596 0 L
.95714 0 L
.95822 0 L
.95948 0 L
Mistroke
.96085 0 L
.96215 0 L
.96334 0 L
.96457 0 L
.96573 0 L
.967 0 L
.96836 0 L
.96972 0 L
.97114 0 L
.97236 0 L
.97369 0 L
.9749 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`co00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool;o`0000Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000_l00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`Co00001ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`00Ioooool4o`0001Kooooo00?o0000ooooooooool0A?ooool2
o`0009kooooo001[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool3o`00
0:3ooooo001[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`2Pooooo`00K?ooool2o`0001?ooooo00?o0000ooooooooool0?oooool2o`000:?ooooo
001^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`2Sooooo`00K_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0Xoooool006oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo0:Cooooo001`ooooo`03o`000?oooooooooo00kooooo0ol0000mooooo`03
o`000?oooooooooo0:Cooooo001aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`2Uooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0Y_ooool007;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Kooooo001booooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Wooooo`00Loooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Yoooool007?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0:Sooooo
001dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`2Xooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0ZOooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo0:Wooooo001eooooo`03o`000?oooooooooo00Wooooo0ol0000gooooo`03
o`000?oooooooooo0:[ooooo001eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`2Zooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0Zoooool007Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:_ooooo001fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2[ooooo`00Moooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[?ooool007Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:cooooo
001gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`2/ooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0[Oooool007Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo0:gooooo001hooooo`03o`000?oooooooooo00Kooooo0ol0000dooooo`03
o`000?oooooooooo0:gooooo001hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`2^ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0[_ooool007Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:kooooo001iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2^ooooo`00N_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0[oooool007[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0:oooooo
001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`2_ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0:oooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00005ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0/?ooool006Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`05oiRHV?lQ8B7ok^k^ooooool000001Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo0;3ooooo001Vooooo`05o`000?ooooooooooooooool000003Oooool01?nH
V9So8B4Qonk^k_l00005ooooo`?o0000<Oooool00ol0003oooooooooo`2`ooooo`00I_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_l000001Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo0;3ooooo001Vooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0/?ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`07o`000?nj^[[ooooooiRHV?l@413ooooo
o`000004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0/Oooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`07oiRHV?l@413o0000ob4Q8Oo<c<coooooo`000004oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0/Oooool007cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0;7ooooo001looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2aooooo`00OOoo
ool01Ol0003ooooooooooooooooo000003;ooooo00?o0000ooooooooool0/Oooool007gooooo00Go
0000ooooooooooooooooo`00000aooooo`03o`000?oooooooooo0;;ooooo001mooooo`05o`000?oo
ooooooooooooool00000<Oooool00ol0003oooooooooo`2booooo`00OOooool01?l0003ooooooooo
ooooool3o`0002oooooo00?o0000ooooooooool0/_ooool007kooooo00Co0000oooooooooooo0000
<Oooool00ol0003oooooooooo`2booooo`00O_ooool01?l0003oooooooooool0000aooooo`03o`00
0?oooooooooo0;;ooooo001nooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0
/oooool007kooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`2cooooo`00O_oo
ool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo0;?ooooo001oooooo`03o`000?oo
oooo0000033ooooo00?o0000ooooooooool0/oooool007oooooo00?o0000ooooool00000<?ooool0
0ol0003oooooooooo`2cooooo`00Ooooool00ol0003oooooo`00000`ooooo`03o`000?oooooooooo
0;?ooooo001oooooo`03o`000?oooooo000002oooooo00?o0000ooooooooool0]?ooool007oooooo
00?o0000ooooool000000_l0000]ooooo`03o`000?oooooooooo0;Cooooo001oooooo`03o`000?oo
oooo000002oooooo00?o0000ooooooooool0]?ooool0083ooooo0_l0000_ooooo`03o`000?oooooo
oooo0;Cooooo0020ooooo`;o0000;oooool00ol0003oooooooooo`2dooooo`00P?ooool2o`0002oo
oooo00?o0000ooooooooool0]?ooool0083ooooo0_l0000^ooooo`03o`000?oooooooooo0;Gooooo
0020ooooo`;o0000;_ooool00ol0003oooooooooo`2eooooo`00P?ooool2o`0002kooooo00?o0000
ooooooooool0]Oooool0083ooooo0_l0000^ooooo`03o`000?oooooooooo0;Gooooo0021ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0]Oooool0087ooooo0ol0000/ooooo`03o`00
0?oooooooooo0;Gooooo0021ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0]_oo
ool0087ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2fooooo`00POooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`2fooooo`00POooool2o`0002cooooo00?o0000ooooooooool0]_ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo0_l0
000/ooooo`03o`000?oooooooooo0;Kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool2o`0002_ooooo00?o0000ooooooooool0]ooo
ool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool2o`0002_ooooo00?o
0000ooooooooool0]oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0000Zooooo`03o`000?oooooooooo0;Oooooo001Vooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`;o0000:oooool00ol0003o
ooooooooo`2gooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
00001oooool2o`0002_ooooo00?o0000ooooooooool0]oooool006Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooool00000:_ooool00ol0003o
ooooooooo`2gooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo0;Sooooo0021ooooo`03o`00
0?oooooo000002Wooooo00?o0000ooooooooool0^?ooool0087ooooo00?o0000ooooool00000:Ooo
ool00ol0003oooooooooo`2hooooo`00POooool00ol0003oooooo`00000Yooooo`03o`000?oooooo
oooo0;Sooooo0021ooooo`03o`000?oooooo000002Wooooo00?o0000ooooooooool0^?ooool0087o
oooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`2hooooo`00POooool3o`0002Wooooo
00?o0000ooooooooool0^?ooool0087ooooo00Co0000oooooooooooo00009oooool00ol0003ooooo
ooooo`2iooooo`00POooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo0;Wooooo
0021ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool0^Oooool0087ooooo00Co
0000oooooooooooo00009oooool00ol0003oooooooooo`2iooooo`00POooool01?l0003ooooooooo
ool0000Wooooo`03o`000?oooooooooo0;Wooooo0021ooooo`04o`000?ooooooooooo`0002Oooooo
00?o0000ooooooooool0^Oooool0087ooooo00Co0000oooooooooooo00009oooool00ol0003ooooo
ooooo`2iooooo`00POooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool0
^_ooool0087ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo0;[ooooo
0021ooooo`?o000000?oooooo`000?ooool09?ooool00ol0003oooooooooo`2jooooo`00POooool0
1Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool0^_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo0;[ooooo0021ooooo`05o`000?oooooo
ooooooooool000009Oooool00ol0003oooooooooo`2jooooo`00POooool01Ol0003ooooooooooooo
oooo000002Gooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;_ooooo0021ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2kooooo`00POooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^oooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;_ooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`2kooooo`00POooool3o`0000;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2k
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0^oooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0;cooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`2looooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0_?ooool0087ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;cooooo0021ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2looooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0_?ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo0;cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo0;gooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo0ol00004ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0_Oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0_Oooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0;gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2moooo
o`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0_Oooool0
087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0;gooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`2nooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`2nooooo`00POooool3o`0000Gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`2nooooo`00POooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2nooooo`00POooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0_oooool0
087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
0;oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`2oooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0_oooool0087ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0;oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`2oooooo`00POooool3o`0000Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2oooooo`00POooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`30ooooo`00POooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0`?ooool0
087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
0<3ooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`30ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`31ooooo`00POooool3o`0000Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`31ooooo`00POooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0`Oooool0087ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<7ooooo0021ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`31ooooo`00POooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0`Oooool0
087ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0<7ooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`32ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<;ooooo001Vooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<;ooooo001Vooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00009ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0`_ooool006Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0`oooool0087ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<?ooooo0021oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`33oooo
o`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0`oooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo0<?ooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`33ooooo`00POooool3o`0000_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`33ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0a?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`34ooooo`00POooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0a?ooool0087ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0<Cooooo0021oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`34oooo
o`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0aOooool0087ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0<Gooooo0021ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`35ooooo`00POooool3o`0000gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`36ooooo`00POooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0a_ooool0087ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<Kooooo0021oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`36oooo
o`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0aoooool0087ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`37ooooo`00POooool3o`0000oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`37ooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0b?ooool0087ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0<Sooooo0021ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`38ooooo`00POooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0bOooool0087ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Wooooo0021oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3:oooo
o`00Moooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0<[ooooo001iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<[ooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool2o`000003ooooool0
003o00000<gooooo001iooooo`03o`000?oooooooooo00Gooooo0ol0000Cooooo`?o0000c_ooool0
07Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo
00?o0000ooooooooool0k?ooool007Oooooo00?oEEEEofIVI_l00000k_ooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02605 0 L
.02846 0 L
.03072 0 L
.03279 0 L
.03521 0 L
.03784 0 L
.04032 0 L
.04262 0 L
.04498 0 L
.0472 0 L
.04963 0 L
.05224 0 L
.05497 0 L
.05757 0 L
.0599 0 L
.06244 0 L
.0653 0 L
.06799 0 L
.07041 0 L
.07302 0 L
.07588 0 L
.07889 0 L
.08147 0 L
.08429 0 L
.08694 0 L
.08936 0 L
.09196 0 L
.09479 0 L
.0974 0 L
.09982 0 L
.1023 0 L
.10458 0 L
.10921 0 L
.11165 0 L
.11421 0 L
.11852 0 L
.12097 0 L
.12324 0 L
.12593 0 L
.12846 0 L
.1332 1e-05 L
.13586 1e-05 L
.13831 1e-05 L
.1412 1e-05 L
.14385 1e-05 L
.14852 2e-05 L
.15354 3e-05 L
.15819 4e-05 L
.16261 5e-05 L
Mistroke
.16773 7e-05 L
.17248 .0001 L
.1777 .00014 L
.18325 .0002 L
.18862 .00029 L
.19356 .0004 L
.19898 .00055 L
.2047 .00078 L
.20968 .00105 L
.21433 .00138 L
.21943 .00184 L
.22488 .00248 L
.23018 .0033 L
.23508 .00427 L
.24046 .00561 L
.24616 .00745 L
.25574 .01173 L
.26119 .01502 L
.2663 .0188 L
.27615 .02845 L
.28652 .04274 L
.29537 .05913 L
.30504 .08231 L
.32469 .14919 L
.33568 .19888 L
.34565 .25101 L
.36649 .37453 L
.38568 .48834 L
.39536 .5377 L
.40441 .57509 L
.40934 .59107 L
.41384 .6026 L
.41623 .60747 L
.41884 .61175 L
.42027 .61363 L
.42159 .61508 L
.42286 .6162 L
.42356 .6167 L
.4242 .6171 L
.42535 .61763 L
.42661 .61796 L
.42768 .61803 L
.42883 .6179 L
.42947 .61773 L
.43017 .61747 L
.43144 .61679 L
.43267 .61587 L
.43381 .6148 L
.4359 .61229 L
.4382 .60872 L
Mistroke
.44284 .59896 L
.44797 .58443 L
.45348 .56474 L
.46344 .51996 L
.50468 .27809 L
.52529 .17142 L
.53532 .12998 L
.54441 .09881 L
.5533 .07397 L
.56291 .05281 L
.57306 .03601 L
.58262 .02448 L
.59214 .01627 L
.59754 .01277 L
.60258 .01011 L
.6078 .00788 L
.61275 .00618 L
.61845 .00463 L
.62365 .00354 L
.62863 .00271 L
.63331 .0021 L
.63819 .0016 L
.64357 .00117 L
.6482 .0009 L
.65244 .00069 L
.6571 .00052 L
.66199 .00039 L
.667 .00028 L
.67155 .00021 L
.6768 .00015 L
.68175 .00011 L
.68634 8e-05 L
.69057 6e-05 L
.69521 4e-05 L
.70012 3e-05 L
.70506 2e-05 L
.70957 1e-05 L
.71206 1e-05 L
.71477 1e-05 L
.71737 1e-05 L
.71971 1e-05 L
.72432 0 L
.72684 0 L
.72922 0 L
.73346 0 L
.73803 0 L
.74042 0 L
.74297 0 L
.74757 0 L
.75038 0 L
Mistroke
.75304 0 L
.75802 0 L
.76057 0 L
.76328 0 L
.76813 0 L
.77083 0 L
.77335 0 L
.77612 0 L
.77911 0 L
.78164 0 L
.78434 0 L
.78668 0 L
.7892 0 L
.79218 0 L
.79499 0 L
.79772 0 L
.80023 0 L
.80248 0 L
.80489 0 L
.80753 0 L
.81 0 L
.81277 0 L
.81539 0 L
.81775 0 L
.82032 0 L
.82265 0 L
.82516 0 L
.82753 0 L
.82971 0 L
.83212 0 L
.83476 0 L
.83752 0 L
.84008 0 L
.84282 0 L
.8454 0 L
.84772 0 L
.85024 0 L
.85298 0 L
.85588 0 L
.85836 0 L
.86109 0 L
.86358 0 L
.8663 0 L
.86886 0 L
.87124 0 L
.8736 0 L
.87574 0 L
.87821 0 L
.88053 0 L
.88307 0 L
Mistroke
.88576 0 L
.88805 0 L
.89057 0 L
.89328 0 L
.89618 0 L
.89892 0 L
.90142 0 L
.90371 0 L
.90623 0 L
.90887 0 L
.91135 0 L
.91366 0 L
.91577 0 L
.91809 0 L
.92053 0 L
.92302 0 L
.92567 0 L
.92818 0 L
.93045 0 L
.93313 0 L
.93464 0 L
.93604 0 L
.93859 0 L
.93988 0 L
.9413 0 L
.94346 0 L
.94582 0 L
.94804 0 L
.9501 0 L
.95195 0 L
.95399 0 L
.95612 0 L
.95813 0 L
.96033 0 L
.96266 0 L
.96464 0 L
.96682 0 L
.96916 0 L
.97045 0 L
.97167 0 L
.97404 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooo`00000>o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo3_l00007ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000J
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo1?l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool6o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0F
ooooo`00H_ooool3o`0001cooooo00?o0000ooooooooool0Doooool2o`0008oooooo001Uooooo`;o
00006_ooool00ol0003oooooooooo`1Aooooo`;o0000TOooool006Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo097ooooo001Xooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C_ooool2o`0009Cooooo001Yooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2Dooooo`00J_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0UOooool006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo09Ko
oooo001/ooooo`03o`000?oooooooooo01;ooooo0ol0001:ooooo`03o`000?oooooooooo09Oooooo
001]ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`2Hooooo`00K_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0VOooool006oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo09Wooooo001`ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`2Jooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0V_ooool0077ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09_ooooo001aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Kooooo`00LOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0W?ooool007;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo09co
oooo001booooo`03o`000?oooooooooo00cooooo0ol00014ooooo`03o`000?oooooooooo09gooooo
001booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`2Mooooo`00Loooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0W_ooool007?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo09kooooo001dooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`2Oooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0Woooool007Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0:3ooooo001fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2Pooooo`00M_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0X?ooool007Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0:7o
oooo001gooooo`03o`000?oooooooooo00Oooooo0ol00010ooooo`03o`000?oooooooooo0:7ooooo
001gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`2Qooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0X_ooool007Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo0:;ooooo001hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`2Rooooo`00N?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0Xoooool007Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:?ooooo001iooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2Sooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo0:Cooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko0000odA4A006ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0Y?ooool006Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7o000000Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2Tooooo`00I_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Ol000001_ooool3o`0003gooooo00?o
0000ooooooooool0Y?ooool006Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMol0
003ooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Uooooo`00I_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo0:Gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01_l0003o^[ZjoooooonHV9So410@o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`2Uooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00KoV9RHoa0@4?l0
003o8B4Qolc<c?l00005ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0YOooool0
07_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0:Kooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2Vooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0Y_ooool007cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0:Kooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`2Wooooo`00O?ooool00ol0003oooooooooo`02oooo
o`?o0000>_ooool00ol0003oooooooooo`2Wooooo`00O?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0Yoooool007gooooo00Go0000oooooooooooo
ooooo`00000looooo`03o`000?oooooooooo0:Oooooo001mooooo`05o`000?ooooooooooooooool0
0000??ooool00ol0003oooooooooo`2Wooooo`00OOooool01Ol0003ooooooooooooooooo000003_o
oooo00?o0000ooooooooool0Z?ooool007gooooo00Go0000ooooooooooooooooo`00000kooooo`03
o`000?oooooooooo0:Sooooo001mooooo`05o`000?ooooooooooooooool00000>oooool00ol0003o
ooooooooo`2Xooooo`00O_ooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo0:So
oooo001nooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0ZOooool007kooooo
00Co0000oooooooooooo0000>_ooool00ol0003oooooooooo`2Yooooo`00O_ooool00ol0003ooooo
ooooo`03o`0003Sooooo00?o0000ooooooooool0ZOooool007kooooo00Co0000oooooooooooo0000
>_ooool00ol0003oooooooooo`2Yooooo`00Ooooool00ol0003oooooo`00000jooooo`03o`000?oo
oooooooo0:Wooooo001oooooo`03o`000?oooooo000003Wooooo00?o0000ooooooooool0Z_ooool0
07oooooo00?o0000ooooool00000>Oooool00ol0003oooooooooo`2Zooooo`00Ooooool00ol0003o
ooooo`00000iooooo`03o`000?oooooooooo0:[ooooo001oooooo`03o`000?oooooo000003Wooooo
00?o0000ooooooooool0Z_ooool0083ooooo0_l0000iooooo`03o`000?oooooooooo0:[ooooo0020
ooooo`;o0000>?ooool00ol0003oooooooooo`2[ooooo`00P?ooool2o`0003Sooooo00?o0000oooo
ooooool0Zoooool0083ooooo1?l0000fooooo`03o`000?oooooooooo0:_ooooo0021ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0Zoooool0087ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2[ooooo`00POooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo0:cooooo0021ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[?ooool0087o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2/ooooo`00POooool2o`0003Kooooo
00?o0000ooooooooool0[?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo0_l0000fooooo`03o`000?oooooooooo0:cooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool2o`0003Gooooo00?o0000ooooooooool0[Oooool006Kooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool2o`0003Gooooo00?o0000ooooooooool0[Oooool006Kooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000dooooo`03
o`000?oooooooooo0:gooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooo000003Cooooo00?o0000ooooooooool0[Oooool006Ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ool00000=?ooool00ol0003oooooooooo`2]ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooo`00000cooooo`03o`000?oooooooooo
0:kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06oooo
o`03o`000?oooooo000003?ooooo00?o0000ooooooooool0[_ooool0087ooooo00Co0000oooooooo
oooo0000<_ooool00ol0003oooooooooo`2^ooooo`00POooool01?l0003oooooooooool0000boooo
o`03o`000?oooooooooo0:kooooo0021ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000oooo
ooooool0[_ooool0087ooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`2_oooo
o`00POooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo0:oooooo0021ooooo`Co
0000<Oooool00ol0003oooooooooo`2_ooooo`00POooool01?l0003oooooooooool0000aooooo`03
o`000?oooooooooo0:oooooo0021ooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003o
ooooooooo`2_ooooo`00POooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000oooooooo
ool0[oooool0087ooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo0;3o
oooo0021ooooo`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`2`ooooo`00
POooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooooooool0/?ooool0087ooooo
00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo0;3ooooo0021ooooo`05o`00
0?ooooooooooooooool00000;oooool00ol0003oooooooooo`2`ooooo`00POooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0/?ooool0087ooooo0ol0
0002ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0/Oooool0087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;7ooooo0021oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2aoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0/Oooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo0;7ooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`2aooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0/_ooool0087ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0;;ooooo0021ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2booooo`00POooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool0087ooooo0ol0
0003ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool0087ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;;ooooo0021oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2coooo
o`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0/oooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0;?ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2cooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0/oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;?ooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2dooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2dooooo`00
I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o00001Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;Cooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;Cooooo001Voooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2dooooo`00I_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0]?ooool006Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;Gooooo0021ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2eooooo`00POooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0]Oooool0087o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;Go
oooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`2eooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0]Oooool0087ooooo0ol00007ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0]_ooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2fooooo`00POooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2fooooo`00POooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0]oooool0087o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;Oo
oooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`2gooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0]oooool0087ooooo0ol00009ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0]oooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo0;Oooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`2hooooo`00POooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0^?ooool0087ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;Sooooo0021ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2hooooo`00POooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0^?ooool0087o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;So
oooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`2iooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0^Oooool0087ooooo0ol0000:ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0^Oooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo0;Wooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`2iooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0^Oooool0087ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2jooooo`00POooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0^_ooool006Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo0;[ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`2jooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`2jooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00003?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0;_ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo0;_ooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo0;_ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo0;_ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo0;_ooooo0021ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`2kooooo`00POooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0_?ooool0087ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;cooooo0021ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2looooo`00
POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
_?ooool0087ooooo0ol0000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0_?oo
ool0087ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0;gooooo0021ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2mooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0_Oooool0087ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo0;gooooo0021ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2mooooo`00POooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0__ooool0087ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;kooooo0021ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2nooooo`00
POooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
__ooool0087ooooo0ol0000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0__oo
ool0087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0;oooooo0021ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2oooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0_oooool0087ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo0;oooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`30ooooo`00POooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`31ooooo`00
POooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
`Oooool0087ooooo0ol0000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0`Ooo
ool0087ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo0<;ooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`32ooooo`00POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0`_ooool0087ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0<?ooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`33ooooo`00POooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0a?ooool007Oooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`34ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Ko
oooo0_l00004ooooo`03o`000?oooooooooo0<Gooooo001iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool2o`0000;ooooo00?o0000ooooooooool0a_ooool007Wooooo00?o
0000ooooooooool01Oooool3o`0001Sooooo0ol00039ooooo`00NOooool00ol0003oooooooooo`3/
ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00
Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 0 L
.03279 0 L
.03754 0 L
.04262 0 L
.04518 0 L
.04795 0 L
.053 0 L
.05791 0 L
.06244 0 L
.06747 0 L
.07218 0 L
.07734 0 L
.0829 0 L
.08567 0 L
.0887 1e-05 L
.09422 1e-05 L
.09959 1e-05 L
.10458 2e-05 L
.10966 2e-05 L
.11515 3e-05 L
.12033 4e-05 L
.1251 6e-05 L
.12942 7e-05 L
.13415 9e-05 L
.13909 .00012 L
.14371 .00016 L
.14872 .00021 L
.15416 .00028 L
.1593 .00037 L
.16406 .00047 L
.17306 .00073 L
.1776 .00091 L
.18262 .00116 L
.18753 .00147 L
.19271 .00186 L
.20196 .00282 L
.20712 .00353 L
.21193 .00433 L
.21715 .00539 L
.22282 .00679 L
.23334 .01028 L
.24328 .01492 L
.25295 .02108 L
.26187 .02857 L
.27156 .03911 L
.28063 .05167 L
.29122 .0702 L
.30127 .09216 L
.32156 .15103 L
Mistroke
.34009 .22232 L
.37834 .40596 L
.3997 .5067 L
.40978 .54676 L
.41904 .57698 L
.42367 .58928 L
.42874 .60041 L
.43384 .60895 L
.43663 .61245 L
.43922 .61496 L
.44041 .61586 L
.44169 .61666 L
.4429 .61725 L
.44403 .61765 L
.44503 .61789 L
.44615 .61802 L
.44731 .61801 L
.4484 .61787 L
.4496 .61756 L
.45087 .61706 L
.45195 .61649 L
.45313 .61572 L
.45577 .61345 L
.45822 .61066 L
.46328 .60287 L
.46877 .59146 L
.47872 .56347 L
.49732 .49062 L
.53829 .29033 L
.55868 .19976 L
.57774 .13165 L
.59604 .08294 L
.60631 .06233 L
.61568 .04724 L
.62492 .03539 L
.63474 .0256 L
.64552 .01759 L
.65549 .0122 L
.66485 .00851 L
.66976 .007 L
.67494 .00568 L
.67949 .0047 L
.68447 .00381 L
.69321 .0026 L
.69849 .00205 L
.70347 .00163 L
.7128 .00105 L
.71802 .00082 L
.72284 .00064 L
.72813 .00049 L
Mistroke
.73374 .00037 L
.73866 .00029 L
.74316 .00023 L
.74836 .00017 L
.75329 .00013 L
.75753 .0001 L
.76205 8e-05 L
.767 6e-05 L
.7716 5e-05 L
.77696 3e-05 L
.78189 3e-05 L
.78731 2e-05 L
.79302 1e-05 L
.798 1e-05 L
.80264 1e-05 L
.80774 0 L
.8132 0 L
.81849 0 L
.82338 0 L
.82875 0 L
.83146 0 L
.83445 0 L
.83945 0 L
.84226 0 L
.84484 0 L
.84958 0 L
.85458 0 L
.85716 0 L
.85959 0 L
.86413 0 L
.86903 0 L
.87179 0 L
.87434 0 L
.87859 0 L
.88326 0 L
.88562 0 L
.88814 0 L
.89271 0 L
.89526 0 L
.89797 0 L
.90285 0 L
.90584 0 L
.90865 0 L
.9112 0 L
.9139 0 L
.9163 0 L
.91894 0 L
.92357 0 L
.92618 0 L
.92897 0 L
Mistroke
.934 0 L
.93658 0 L
.93931 0 L
.94421 0 L
.94694 0 L
.94949 0 L
.95229 0 L
.9553 0 L
.95788 0 L
.96069 0 L
.96335 0 L
.96581 0 L
.97047 0 L
.97308 0 L
.97544 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo4_l00002ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooooa?o00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`Go00001oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo1Ol000000ooooooo0000ooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0F
ooooo`00Foooool3o`0002?ooooo00?o0000ooooooooool0IOooool4o`0007_ooooo001Nooooo`?o
00008?ooool00ol0003oooooooooo`1Rooooo`?o0000Ooooool0067ooooo0ol0000Mooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0P?ooool006Cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1Oooooo`;o0000Poooool006Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo08?ooooo001Vooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`24ooooo`00Ioooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0QOooool006Sooooo
00?o0000ooooooooool05_ooool3o`0005_ooooo00?o0000ooooooooool0Q_ooool006Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08Oooooo001Z
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`28
ooooo`00Joooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool0R?ooool006_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo08Wooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`2:ooooo`00KOooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool0Roooool006kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo08_ooooo001^ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2<ooooo`00Koooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0SOooool006oooooo
00?o0000ooooooooool03oooool3o`0005Cooooo00?o0000ooooooooool0SOooool0073ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo08kooooo001`
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2>
ooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0Soooool0077ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo08oooooo001booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`2@ooooo`00L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool0T?ooool007?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo097ooooo001cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`2Aooooo`00Loooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0T_ooool007Cooooo
00?o0000ooooooooool02_ooool3o`0004oooooo00?o0000ooooooooool0T_ooool007Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo09;ooooo001e
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2C
ooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0Toooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo09?ooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`2Dooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0U?ooool007Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Gooooo001Vooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0UOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So0000onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`2Eooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHo`000?o^k^h01ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo09Kooooo001Vooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003o8B4Qonk^kP06ooooo`?o0000Boooool00ol0003ooooooooo
o`2Fooooo`00I_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ogMgMomVIVH01_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo09Kooooo001Vooooo`05oa0@4?oooooo
ooooooooool@41003_ooool2o`0000Kooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`2Gooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo0000
oa0@4006ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Uoooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo09Oooooo001jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`2Hooooo`00N_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0V?ooool007[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo09Sooooo001koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2Ioooo
o`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0VOooool007_ooooo00?o0000ooooooooool00oooool3o`0004Sooooo00?o0000ooooooooool0
VOooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo09Wooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`2Jooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0V_ooool007cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo09[ooooo001mooooo`05o`000?ooooooooooooooool0
0000BOooool00ol0003oooooooooo`2Jooooo`00OOooool01Ol0003ooooooooooooooooo000004So
oooo00?o0000ooooooooool0Voooool007gooooo00Go0000ooooooooooooooooo`000018ooooo`03
o`000?oooooooooo09_ooooo001mooooo`05o`000?ooooooooooooooool00000B?ooool00ol0003o
ooooooooo`2Kooooo`00O_ooool01?l0003oooooooooool00017ooooo`03o`000?oooooooooo09co
oooo001nooooo`03o`000?oooooooooo00?o0000AOooool00ol0003oooooooooo`2Looooo`00O_oo
ool01?l0003oooooooooool00017ooooo`03o`000?oooooooooo09cooooo001nooooo`04o`000?oo
ooooooooo`0004Oooooo00?o0000ooooooooool0W?ooool007oooooo00?o0000ooooool00000A_oo
ool00ol0003oooooooooo`2Mooooo`00Ooooool00ol0003oooooo`000016ooooo`03o`000?oooooo
oooo09gooooo001oooooo`03o`000?oooooo000004Kooooo00?o0000ooooooooool0WOooool007oo
oooo00?o0000ooooool00000A_ooool00ol0003oooooooooo`2Mooooo`00P?ooool2o`0004Gooooo
00?o0000ooooooooool0W_ooool0083ooooo0_l00015ooooo`03o`000?oooooooooo09kooooo0020
ooooo`;o0000AOooool00ol0003oooooooooo`2Nooooo`00P?ooool4o`0004?ooooo00?o0000oooo
ooooool0W_ooool0087ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2Oooooo`00
POooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo09oooooo0021ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`2Oooooo`00POooool2o`0004?ooooo00?o0000ooooooooool0Woooool0087o
oooo0_l00012ooooo`03o`000?oooooooooo0:3ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`;o0000@_ooool00ol0003o
ooooooooo`2Pooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo0_l00012ooooo`03o`000?oooooooooo0:3ooooo001Vooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0_l00012ooooo`03o`000?oooooooooo0:3o
oooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000@?ooool00ol0003oooooooooo`2Qooooo`00I_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooo`000010ooooo`03o`000?oooooo
oooo0:7ooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooo0000043ooooo00?o0000ooooooooool0XOooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooool00000@?ooool0
0ol0003oooooooooo`2Qooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo0:;ooooo0021oooo
o`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0X_ooool0087ooooo00Co0000oooo
oooooooo0000?_ooool00ol0003oooooooooo`2Rooooo`00POooool01?l0003oooooooooool0000n
ooooo`03o`000?oooooooooo0:;ooooo0021ooooo`04o`000?ooooooooooo`0003kooooo00?o0000
ooooooooool0X_ooool0087ooooo00Co0000oooooooooooo0000?Oooool00ol0003oooooooooo`2S
ooooo`00POooool3o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool0Xoooool0087o
oooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo0:?ooooo0021ooooo`05
o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`2Sooooo`00POooool01Ol0003o
oooooooooooooooo000003_ooooo00?o0000ooooooooool0Y?ooool0087ooooo00Go0000oooooooo
ooooooooo`00000kooooo`03o`000?oooooooooo0:Cooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2Tooooo`00POooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Y?ooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Gooooo0021
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2U
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0YOooool0087ooooo0ol00003ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0YOooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo0:Gooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`2Vooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0Y_ooool0087ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo0:Kooooo0021ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Vooooo`00POooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Y_ooool0087ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:Oooooo0021
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2W
ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0Yoooool0087ooooo0ol00005ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0Yoooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo0:Oooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`2Xooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo0:Sooooo0021ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Xooooo`00POooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Z?ooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0:Wo
oooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`2Yooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`2Yooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo0:Wooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo0:Wooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`2Zooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
Z_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0:[o
oooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`2Zooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Z_ooool0087ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0:_ooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`2[ooooo`00POooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0Zoooool0087ooooo0ol00009ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0Zoooool0087ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0:_ooooo0021ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2/ooooo`00POooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0[?ooool0087o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:co
oooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`2/ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0[?ooool0087ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`2]ooooo`00POooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0[Oooool0087ooooo0ol0000;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2^ooooo`00POooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0[_ooool0087o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0:ko
oooo0021ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`2^ooooo`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0[_ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo0:oooooo0021ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2_ooooo`00POooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0[oooool0087ooooo0ol0000=ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0[oooool0087ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0:oooooo0021ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2`ooooo`00POooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0/?ooool0087o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3o
oooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`2`ooooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0/?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2aooooo`00I_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2aooooo`00I_ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00003oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;;ooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;;ooooo001Vooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;;ooooo0021ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2booooo`00
POooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
/oooool0087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo0;?ooooo0021ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2cooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0/oooool0087ooooo0ol0000Booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0]?ooool0087ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0;Cooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`2dooooo`00POooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0]Oooool0087ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;Gooooo0021ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2eooooo`00
POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
]Oooool0087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0;Kooooo0021ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`2fooooo`00POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0]_ooool0087ooooo0ol0000Eooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo0;Oooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2gooooo`00POooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0]oooool0087ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;Sooooo0021ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2hooooo`00
POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
^?ooool0087ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo0;Wooooo0021ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2iooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0^Oooool0087ooooo0ol0000Hooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0^oooool0087ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;_ooooo0021ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2looooo`00
POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_Oooool007Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2nooooo`00NOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2o
ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo0_l00002oooo
o`;o0000`Oooool007Wooooo00?o0000ooooooooool01Oooool3o`0001kooooo1?l00032ooooo`00
NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool0
0ol0003oooooooooo`3/ooooo`00Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 0 L
.03279 1e-05 L
.03754 1e-05 L
.04262 1e-05 L
.04795 1e-05 L
.053 2e-05 L
.05753 2e-05 L
.06244 3e-05 L
.06751 4e-05 L
.07308 5e-05 L
.0789 6e-05 L
.08435 8e-05 L
.0941 .00012 L
.09957 .00016 L
.10458 .0002 L
.10934 .00024 L
.11442 .0003 L
.12357 .00044 L
.12916 .00056 L
.13443 .00069 L
.13913 .00084 L
.14429 .00103 L
.15405 .0015 L
.15939 .00183 L
.16437 .0022 L
.17328 .00305 L
.18284 .00427 L
.19301 .00603 L
.20408 .00867 L
.21453 .01204 L
.2242 .01613 L
.23383 .02134 L
.24286 .02748 L
.2529 .03596 L
.26347 .04711 L
.28365 .07602 L
.30215 .1129 L
.3219 .1645 L
.34026 .22382 L
.37931 .37622 L
.39922 .45678 L
.42081 .53404 L
.43091 .56358 L
.44161 .58868 L
.45074 .60435 L
.45593 .61069 L
.45828 .61293 L
.46079 .61487 L
.46214 .61573 L
Mistroke
.46337 .61639 L
.46462 .61695 L
.46577 .61736 L
.46711 .61772 L
.46782 .61786 L
.46856 .61796 L
.46982 .61803 L
.47053 .61802 L
.47119 .61798 L
.47248 .61781 L
.47369 .61753 L
.47478 .61718 L
.47597 .61671 L
.47862 .61527 L
.48107 .61348 L
.48535 .60931 L
.49007 .6032 L
.49961 .5862 L
.50973 .5619 L
.519 .53471 L
.53987 .46038 L
.57954 .29964 L
.6177 .16572 L
.63735 .11406 L
.65832 .07274 L
.66859 .05723 L
.6797 .04352 L
.68931 .03394 L
.69987 .0255 L
.71016 .01904 L
.71978 .01433 L
.72994 .01048 L
.74084 .00739 L
.751 .00527 L
.76205 .0036 L
.7725 .00247 L
.78217 .00173 L
.79178 .0012 L
.80081 .00084 L
.81071 .00056 L
.81629 .00045 L
.8214 .00036 L
.82613 .00029 L
.83119 .00024 L
.8403 .00016 L
.84587 .00012 L
.85114 .0001 L
.85583 8e-05 L
.86099 6e-05 L
.8707 4e-05 L
Mistroke
.87601 3e-05 L
.88098 2e-05 L
.88987 1e-05 L
.89486 1e-05 L
.89943 1e-05 L
.9042 1e-05 L
.90928 1e-05 L
.91408 0 L
.91843 0 L
.92356 0 L
.9291 0 L
.93434 0 L
.93916 0 L
.94357 0 L
.94829 0 L
.95275 0 L
.95682 0 L
.96158 0 L
.96677 0 L
.97166 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`04oooooaWo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_oooolFo`0000Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`006_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo1_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool7
o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05_ooool005Cooooo1?l0000Yooooo`03o`000?oooooooooo
07gooooo1?l0001Sooooo`00F?ooool2o`0002Oooooo00?o0000ooooooooool0N_ooool3o`0006Oo
oooo001Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Moooool3o`0006[ooooo
001Kooooo`?o00008oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo06_ooooo001N
ooooo`;o00008Oooool00ol0003oooooooooo`1dooooo`;o0000K_ooool0063ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo06kooooo001Qooooo`;o
00007_ooool00ol0003oooooooooo`1aooooo`;o0000LOooool006?ooooo00?o0000ooooooooool0
6oooool3o`0006oooooo0_l0001cooooo`00I?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool0Loooool006Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo07?ooooo001Uooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1dooooo`00I_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0MOooool006Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo07Kooooo
001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`1gooooo`00J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool0N?ooool006Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo07Wooooo001Zooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`1jooooo`00Joooool00ol0003oooooooooo`0Cooooo`?o0000
Ioooool00ol0003oooooooooo`1jooooo`00K?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool0Noooool006cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo07cooooo001]ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1looooo`00K_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0OOooool006oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo07gooooo
001_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`1nooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool0O_ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo07oooooo001aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1oooooo`00LOooool00ol0003oooooooooo`0=ooooo`?o0000
HOooool00ol0003oooooooooo`20ooooo`00L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0POooool007;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo087ooooo001cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`22ooooo`00Loooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0P_ooool007Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo08?ooooo
001dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`23ooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0Q?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0oooool6
o`0000Kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`24ooooo`00I_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05o`000?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo08Gooooo001Vooooo`05oa0@4?oooooo
ooooooooool@41002oooool01?l0003oV9RHob4Q8Oo^k^h7ooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool0QOooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooV9RHob4Q8Oo^k^h01_ooool3o`0005cooooo00?o0000ooooooooool0QOooool006Kooooo
00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooMgMgofIVIPKooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`26ooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo08Kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`000003oooooonHV9So
410@00Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`26ooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool0Qoooool007Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08Oooooo001hooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`27ooooo`00NOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0R?ooool007Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo08Sooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`28ooooo`00N_ooool00ol0003oooooooooo`04ooooo`?o0000F?ooool00ol0003oooooooooo`29
ooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0ROooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo08Wooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`2:ooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool0R_ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo08[ooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`2;ooooo`00O?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Roooool007cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo08_ooooo
001mooooo`05o`000?ooooooooooooooool00000Eoooool00ol0003oooooooooo`2<ooooo`00OOoo
ool01?l0003oooooooooooooool3o`0005Gooooo00?o0000ooooooooool0S?ooool007gooooo00Go
0000ooooooooooooooooo`00001Gooooo`03o`000?oooooooooo08cooooo001nooooo`04o`000?oo
ooooooooo`0005Oooooo00?o0000ooooooooool0S?ooool007kooooo00Co0000oooooooooooo0000
E_ooool00ol0003oooooooooo`2=ooooo`00O_ooool01?l0003oooooooooool0001Fooooo`03o`00
0?oooooooooo08gooooo001oooooo`03o`000?oooooo000005Kooooo00?o0000ooooooooool0SOoo
ool007oooooo00?o0000ooooool00000E_ooool00ol0003oooooooooo`2=ooooo`00Ooooool00ol0
003oooooo`00001Eooooo`03o`000?oooooooooo08kooooo0020ooooo`;o0000EOooool00ol0003o
ooooooooo`2>ooooo`00P?ooool2o`0005Gooooo00?o0000ooooooooool0S_ooool0083ooooo1?l0
001Booooo`03o`000?oooooooooo08oooooo0021ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0Soooool0087ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`2?oooo
o`00POooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo08oooooo0021ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0T?ooool0087ooooo0_l0001Booooo`03o`000?oo
oooooooo093ooooo0021ooooo`;o0000D_ooool00ol0003oooooooooo`2@ooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool2
o`0005;ooooo00?o0000ooooooooool0T?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`;o0000DOooool00ol0003oooooooooo`2A
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooo
0000053ooooo00?o0000ooooooooool0TOooool006Kooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001@ooooo`03o`000?oooooooooo097ooooo001V
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`00
0?oooooo000004oooooo00?o0000ooooooooool0T_ooool006Kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00Co0000oooooooooooo0000C_ooool00ol0003o
ooooooooo`2Booooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool01?l0003oooooooooool0001>ooooo`03o`000?oooooooooo09;ooooo001Vooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`04o`000?oooooooooo
o`0004kooooo00?o0000ooooooooool0T_ooool0087ooooo00Co0000oooooooooooo0000COooool0
0ol0003oooooooooo`2Cooooo`00POooool01Ol0003ooooooooooooooooo000004cooooo00?o0000
ooooooooool0Toooool0087ooooo00Go0000ooooooooooooooooo`00001<ooooo`03o`000?oooooo
oooo09?ooooo0021ooooo`05o`000?ooooooooooooooool00000C?ooool00ol0003oooooooooo`2C
ooooo`00POooool01Ol0003ooooooooooooooooo000004_ooooo00?o0000ooooooooool0U?ooool0
087ooooo0ol00002ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0U?ooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo09Co
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`2Eooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0UOooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo09Gooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`2Eooooo`00POooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0U_ooool0087ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo09Kooooo0021ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Fooooo`00POooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0U_ooool0
087ooooo0ol00004ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Uoooool0087o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo09Oo
oooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`2Gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0Uoooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo09Sooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`2Hooooo`00POooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0V?ooool0087ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo09Sooooo0021ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Iooooo`00POooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0VOooool0
087ooooo0ol00007ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0VOooool0087o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo09Wo
oooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`2Jooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0V_ooool0087ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo09[ooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`2Jooooo`00POooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0Voooool006Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo09_ooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2K
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`2Kooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00002_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo09cooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo09co
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2Looooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0W?ooool006Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo09gooooo0021ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Mooooo`00
POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
WOooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo09gooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`2Nooooo`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0W_ooool0087ooooo0ol0000<ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0W_ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo09kooooo0021ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`2Oooooo`00POooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09oooooo0021ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Oooooo`00
POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
X?ooool0087ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo0:3ooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`2Pooooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0X?ooool0087ooooo0ol0000>ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0XOooool0087ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo0:7ooooo0021ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0XOooool0087ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0:;ooooo0021ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Rooooo`00
POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
X_ooool0087ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0:;ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`2Sooooo`00POooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0Xoooool0087ooooo0ol0000@ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0Xoooool0087ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo0:?ooooo0021ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2Tooooo`00POooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Y?ooool0087ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:Cooooo0021ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Uooooo`00
POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
YOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo0:Gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`2Uooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`2Vooooo`00I_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00004oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo0:Kooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo0:Kooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo0:Oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo0:Oooooo001Vooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0:Oooooo0021ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Xooooo`00POooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Z?ooool0087ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:Sooooo
0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`2Xooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0ZOooool0087ooooo0ol0000Fooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0ZOooool0087ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo0:Wooooo0021ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`2Zooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Z_ooool0087ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0:[ooooo0021ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2[ooooo`00POooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Zoooool0087ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0:_ooooo
0021ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`2/ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0[?ooool0087ooooo0ol0000Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0[?ooool0087ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`2]ooooo`00POooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0:kooooo0021ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`00POooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0[_ooool0087ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0:oooooo
0021ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`2_ooooo`00POooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0[oooool0087ooooo0ol0000Nooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0/?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo0;3ooooo0021ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`2aooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0/_ooool0087ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;;ooooo0021ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2cooooo`00POooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0]?ooool007Oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2eooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2fooooo`00NOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`;o0000^Oooool0
07Wooooo00?o0000ooooooooool01Oooool3o`0002Gooooo1Ol0002jooooo`00NOooool00ol0003o
ooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003ooooooooo
o`3/ooooo`00Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 7e-05 m
.03279 .0001 L
.04262 .00014 L
.05288 .0002 L
.06244 .00028 L
.0731 .00041 L
.0828 .00057 L
.094 .00083 L
.10458 .00116 L
.11428 .00158 L
.12455 .00216 L
.13333 .00281 L
.14299 .00372 L
.15313 .00496 L
.1624 .00641 L
.17311 .00853 L
.18328 .01111 L
.19287 .01413 L
.20309 .01811 L
.22147 .02773 L
.23176 .03476 L
.24289 .04398 L
.26306 .06565 L
.283 .09444 L
.30406 .13392 L
.34203 .22957 L
.38246 .35845 L
.42136 .48582 L
.44118 .54109 L
.45162 .56546 L
.46273 .58684 L
.47256 .60143 L
.47816 .60777 L
.48342 .61237 L
.48576 .61399 L
.48823 .6154 L
.49033 .61637 L
.49264 .61717 L
.49394 .61751 L
.49513 .61775 L
.49578 .61785 L
.49649 .61793 L
.49778 .61802 L
.49899 .61803 L
.50027 .61796 L
.50137 .61783 L
.50257 .61762 L
.50386 .61732 L
.50506 .61696 L
.50778 .61589 L
Mistroke
.51018 .61464 L
.51273 .613 L
.51761 .60898 L
.52202 .60437 L
.53278 .58936 L
.54291 .57067 L
.56303 .52227 L
.58151 .46772 L
.62105 .33669 L
.65908 .21784 L
.68026 .16246 L
.69955 .12051 L
.7198 .08527 L
.73851 .06014 L
.75764 .04088 L
.76836 .0325 L
.77841 .02599 L
.79711 .01678 L
.80704 .01315 L
.81773 .01002 L
.82814 .00763 L
.83781 .00587 L
.8479 .00443 L
.85892 .00323 L
.86947 .00236 L
.87942 .00175 L
.88835 .00132 L
.89802 .00097 L
.90751 .00071 L
.91793 .0005 L
.92882 .00035 L
.93899 .00024 L
.94898 .00017 L
.95844 .00012 L
.96694 9e-05 L
.97619 6e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000006Ol0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000007Ol00009ooooo`03o`000?oo
oooooooo01Kooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo1_l00007ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`Oo00002?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Fooooo`00Aoooool7o`0003?ooooo00?o0000ooooooooool0V_ooool3o`00
04Oooooo001>ooooo`?o0000<?ooool00ol0003oooooooooo`2Fooooo`Co0000B_ooool0057ooooo
0ol0000]ooooo`03o`000?oooooooooo09?ooooo0ol0001>ooooo`00E?ooool2o`0002_ooooo00?o
0000ooooooooool0T?ooool3o`00057ooooo001Fooooo`;o0000:Oooool00ol0003oooooooooo`2>
ooooo`;o0000E?ooool005Sooooo0_l0000Wooooo`03o`000?oooooooooo08cooooo0_l0001Foooo
o`00F_ooool2o`0002Gooooo00?o0000ooooooooool0R_ooool2o`0005Sooooo001Looooo`03o`00
0?oooooooooo02;ooooo0ol00029ooooo`03o`000?oooooooooo05Sooooo001Mooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Qoooool2o`0005_ooooo001Nooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1Kooooo`00Goooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0G?ooool0063o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo05go
oooo001Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`1Nooooo`00H_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0Goooool006?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo063ooooo001Tooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`1Qooooo`00IOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0H_ooool006Kooooo00?o0000ooooooooool0
6?ooool3o`0007kooooo00?o0000ooooooooool0Hoooool006Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo06?ooooo001Xooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1Tooooo`00J?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0IOooool006Wo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo06Ko
oooo001Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`1Vooooo`00J_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0Ioooool006_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo06Sooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`1Yooooo`00K?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0JOooool006gooooo00?o0000ooooooooool0
4Oooool3o`0007Oooooo00?o0000ooooooooool0J_ooool006kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo06[ooooo001^ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1[ooooo`00Koooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0K?ooool006oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo06co
oooo001`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`1]ooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool0KOooool0077ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo06kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo06oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09o`000?oo
oooooooooooooonHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1_ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00Sooooo00Oo0000oooo
oooooooooooooiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1`ooooo`00I_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000LOooool00ol0003oooooooooo`1`ooooo`00I_ooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool006Kooooo00Go410@
oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02_ooool2o`000004okZj^_ooooooV9RHoa0@40Kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1booooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo
00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool0L_ooool007Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo07?ooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1cooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool0Loooool007Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo07Cooooo001gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1dooooo`00N?ooool00ol0003o
ooooooooo`06ooooo`?o0000K?ooool00ol0003oooooooooo`1eooooo`00N?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0MOooool007Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo07Kooooo001i
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1f
ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0Moooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo07Oooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`1gooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0N?ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo07Sooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1iooooo`00O?ooool00ol0003o
ooooooooo`02ooooo`?o0000J?ooool00ol0003oooooooooo`1iooooo`00O?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0NOooool007gooooo00Go
0000ooooooooooooooooo`00001Yooooo`03o`000?oooooooooo07[ooooo001mooooo`05o`000?oo
ooooooooooooool00000JOooool00ol0003oooooooooo`1jooooo`00O_ooool01?l0003ooooooooo
ool0001Yooooo`03o`000?oooooooooo07[ooooo001nooooo`04o`000?ooooooooooo`0006Sooooo
00?o0000ooooooooool0Noooool007kooooo00Co0000oooooooooooo0000J?ooool00ol0003ooooo
ooooo`1kooooo`00Ooooool00ol0003oooooo`00001Wooooo`03o`000?oooooooooo07cooooo001o
ooooo`03o`000?oooooo000006Oooooo00?o0000ooooooooool0O?ooool0083ooooo0_l0001Woooo
o`03o`000?oooooooooo07cooooo0020ooooo`Co0000I?ooool00ol0003oooooooooo`1mooooo`00
POooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo07gooooo0021ooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0OOooool0087ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`1nooooo`00POooool2o`0006Cooooo00?o0000ooooooooool0O_ooool0087o
oooo0_l0001Tooooo`03o`000?oooooooooo07kooooo0021ooooo`;o0000Hoooool00ol0003ooooo
ooooo`1oooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooo`00001Rooooo`03o`000?oooooooooo07oooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`00001Rooooo`03o`000?oooooooooo07oooooo001Vooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooool00000HOooool00ol0003ooooo
ooooo`20ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool4o`00063ooooo00?o0000ooooooooool0P?ooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00Co0000oooooooooooo0000H?ooool0
0ol0003oooooooooo`20ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool01?l0003oooooooooool0001Oooooo`03o`000?oooooooooo087ooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`05o`000?oo
ooooooooooooool00000G_ooool00ol0003oooooooooo`21ooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool01Ol0003ooooooooooooooooo000005ko
oooo00?o0000ooooooooool0POooool0087ooooo00Go0000ooooooooooooooooo`00001Nooooo`03
o`000?oooooooooo087ooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`22ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool0P_ooool0087ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08;ooooo0021ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`23ooooo`00POooool3o`0000?o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`23ooooo`00POooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Poooool0087ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo08Cooooo0021
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`24
ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0Q?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo08Gooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`25ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0QOooool0087ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo08Gooooo0021ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`26ooooo`00POooool3o`0000Ko
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`26ooooo`00POooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Q_ooool0087ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo08Oooooo0021
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`27
ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool0Qoooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo08Sooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`28ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0R?ooool0087ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo08Wooooo0021ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`29ooooo`00POooool3o`0000Wo
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`29ooooo`00POooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0ROooool0087ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08[ooooo0021
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2:
ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool0R_ooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo08_ooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`2;ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0Roooool006Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo08cooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo08cooooo001Voooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
000<ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0S?ooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0SOooool006Kooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo08gooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2=ooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0SOooool0087ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo08kooooo0021ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2>ooooo`00POooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0S_ooool0
087ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
08oooooo0021ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`2?ooooo`00POooool3o`0000oooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`2?ooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0T?ooool0087ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo093ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`2@ooooo`00POooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0TOooool0087ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo097ooooo0021ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Aooooo`00POooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0T_ooool0
087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
09;ooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`2Booooo`00POooool3o`0001;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`2Booooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0Toooool0087ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo09?ooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`2Cooooo`00POooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0U?ooool0087ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo09Cooooo0021ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Dooooo`00POooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0UOooool0
087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
09Gooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`2Eooooo`00POooool3o`0001Gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`2Fooooo`00POooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0U_ooool0087ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo09Kooooo0021ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2Gooooo`00POooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0Uoooool0087ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Oooooo0021ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Hooooo`00I_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
V?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo09Sooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo09Wooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0000Hooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0VOooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0VOooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0V_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0V_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0V_ooool0087ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo09_ooooo0021ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Kooooo`00POooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Voooool0087ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0021oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Loooo
o`00POooool3o`0001cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Looooo`00
POooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
WOooool0087ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo09gooooo0021ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`2Mooooo`00POooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0W_ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo09kooooo0021ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Nooooo`00POooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo09oooooo0021oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Poooo
o`00POooool3o`00023ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Pooooo`00
POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
X?ooool0087ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo0:7ooooo0021ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0XOooool0087ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo0:;ooooo0021ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Rooooo`00POooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Xoooool0087ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:Cooooo0021oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Toooo
o`00POooool3o`0002Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Uooooo`00
POooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Y_ooool0087ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo0:Kooooo0021ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`2Wooooo`00POooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo0:Wooooo0021ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2Zooooo`00Moooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0:_ooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:cooooo001iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0;?ooool3o`0000Cooooo0_l0002_ooooo`00NOooool00ol0003o
ooooooooo`05ooooo`?o0000;_ooool5o`000;7ooooo001iooooo`03o`000?oooooooooo0>cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001goooo
o`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00054 m
.03279 .00069 L
.04262 .0009 L
.05288 .00118 L
.06244 .00151 L
.0731 .00198 L
.0828 .00252 L
.094 .0033 L
.10458 .00423 L
.11428 .00529 L
.12455 .00666 L
.14299 .00993 L
.1524 .01209 L
.16253 .01486 L
.18083 .02128 L
.20196 .03149 L
.22205 .04469 L
.24186 .06177 L
.26025 .08184 L
.29938 .14015 L
.34096 .22662 L
.38102 .32954 L
.41958 .43518 L
.43912 .48588 L
.46058 .53543 L
.48123 .5742 L
.49025 .58772 L
.50007 .59978 L
.50527 .60499 L
.51008 .60905 L
.51498 .61242 L
.51958 .61488 L
.52209 .61592 L
.5244 .6167 L
.52696 .61736 L
.5283 .61761 L
.52904 .61773 L
.52972 .61782 L
.53101 .61794 L
.53171 .61799 L
.53238 .61802 L
.53357 .61803 L
.53486 .61799 L
.53554 .61795 L
.53628 .61789 L
.53706 .6178 L
.53779 .6177 L
.5391 .61748 L
.54049 .61717 L
.54307 .61644 L
Mistroke
.54547 .61557 L
.5509 .61288 L
.55608 .60941 L
.56078 .60553 L
.57033 .59551 L
.57931 .58359 L
.59943 .54897 L
.61792 .50904 L
.65746 .40698 L
.69548 .30297 L
.73596 .20302 L
.77492 .12698 L
.7962 .09492 L
.81633 .07046 L
.83459 .05276 L
.85471 .03757 L
.87453 .02632 L
.89555 .01762 L
.91493 .01192 L
.92583 .00948 L
.9358 .00765 L
.95476 .00501 L
.9655 .00391 L
.97548 .00308 L
.97619 .00303 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Joooooa[o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0001Sooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`Oo00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`Wo000000?oooooo`000?ooool05oooool003_ooooo1?l00012oooo
o`03o`000?oooooooooo0;gooooo1?l0000Sooooo`00?oooool8o`0003[ooooo00?o0000oooooooo
ool0]_ooool7o`0002Oooooo0017ooooo`?o0000=oooool00ol0003oooooooooo`2cooooo`?o0000
;_ooool004[ooooo0ol0000dooooo`03o`000?oooooooooo0;3ooooo0ol0000aooooo`00COooool2
o`0003;ooooo00?o0000ooooooooool0[Oooool3o`0003Cooooo001?ooooo`;o0000<?ooool00ol0
003oooooooooo`2[ooooo`;o0000=oooool0057ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`2Yooooo`;o0000>Oooool005;ooooo0_l0000]ooooo`?o0000Z?ooool00ol0003ooooo
ooooo`0iooooo`00E?ooool2o`0002_ooooo00?o0000ooooooooool0Y_ooool2o`0003cooooo001F
ooooo`;o0000:Oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03cooooo001Hoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Xoooool2o`0003oooooo001Iooooo`;o
00009_ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03oooooo001Kooooo`;o0000
9?ooool00ol0003oooooooooo`2Pooooo`;o0000@_ooool005gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo04;ooooo001Nooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`13ooooo`00Goooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo09cooooo0_l00016ooooo`00H?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0A_ooool0067ooooo
00?o0000ooooooooool07Oooool3o`0009[ooooo00?o0000ooooooooool0Aoooool0067ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo04Sooooo001R
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`19
ooooo`00Hoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool0B_ooool006Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Gooooo`03
o`000?oooooooooo04[ooooo001Uooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
U_ooool00ol0003oooooooooo`1;ooooo`00I_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo09Gooooo00?o0000ooooooooool0C?ooool006Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`2Dooooo`03o`000?oooooooooo04gooooo001Wooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1=ooooo`00J?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0C_ooool006Wooooo
00?o0000ooooooooool05Oooool3o`0009;ooooo00?o0000ooooooooool0Coooool006Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo053ooooo001Z
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`1@
ooooo`00Joooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool0DOooool006_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo05;ooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Soooool00ol0003oooooooooo`1Booooo`00KOooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo08kooooo00?o0000ooooooooool0Doooool006kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`2=ooooo`03o`000?oooooooooo05Cooooo001Vooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01?l0003oooooob4Q8OlQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo05Cooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool00ol0003o8B4Qob4Q8@04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oooooooooo05Gooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
S?ooool00ol0003oooooooooo`1Eooooo`00I_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Roooool00ol0003ooooo
ooooo`1Fooooo`00I_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0
Eoooool006Kooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo05Oooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool02Ol0003ooooooooooooooooo0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0F?ooool0
06Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`08o`000?oooooooooooiRHV?l@413o0000
ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0F?ooool007Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo05Wooooo
001dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`1Iooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool0F_ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo05_ooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`1Kooooo`00M_ooool00ol0003oooooooooo`08ooooo`?o0000
QOooool00ol0003oooooooooo`1Looooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooooooool0G?ooool007Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`24ooooo`03o`000?oooooooooo05gooooo001gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`1Mooooo`00N?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0G_ooool007Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo05kooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`1Oooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0Goooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo063ooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`1Pooooo`00Noooool00ol0003oooooooooo`03ooooo`?o0000
P?ooool00ol0003oooooooooo`1Qooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0H_ooool007cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo06;ooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`1Sooooo`00OOooool01Ol0003o
oooooooooooooooo0000083ooooo00?o0000ooooooooool0Hoooool007gooooo00Go0000oooooooo
ooooooooo`00001oooooo`03o`000?oooooooooo06Cooooo001nooooo`04o`000?ooooooooooo`00
07oooooo00?o0000ooooooooool0I?ooool007kooooo00Co0000oooooooooooo0000O_ooool00ol0
003oooooooooo`1Uooooo`00O_ooool01?l0003oooooooooool0001nooooo`03o`000?oooooooooo
06Gooooo001oooooo`03o`000?oooooo000007kooooo00?o0000ooooooooool0IOooool007oooooo
00?o0000ooooool000000_l0001kooooo`03o`000?oooooooooo06Kooooo0020ooooo`;o0000OOoo
ool00ol0003oooooooooo`1Vooooo`00P?ooool2o`0007cooooo00?o0000ooooooooool0Ioooool0
087ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1Wooooo`00POooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo06Oooooo0021ooooo`;o0000N_ooool00ol0003ooooo
ooooo`1Xooooo`00POooool2o`0007[ooooo00?o0000ooooooooool0J?ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo0_l0
001iooooo`03o`000?oooooooooo06Wooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00001hooooo`03o`000?oo
oooooooo06Wooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o
0000ooooool00000N?ooool00ol0003oooooooooo`1Yooooo`00I_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool4o`0007Kooooo00?o0000ooooooooool0
J_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00Co0000oooooooooooo0000M_ooool00ol0003oooooooooo`1Zooooo`00I_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool01?l0003oooooooooool0001e
ooooo`03o`000?oooooooooo06_ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`05o`000?ooooooooooooooool00000M?ooool00ol0003ooooooooo
o`1[ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool01Ol0003ooooooooooooooooo000007Cooooo00?o0000ooooooooool0Joooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo06cooooo0021
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1/
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0K?ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo06gooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1]ooooo`00POooool3o`0000Cooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`1^ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool0K_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo06kooooo0021ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1_ooooo`00POooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Koooool0087ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo073ooooo0021
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1`
ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0L?ooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo077ooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`1aooooo`00POooool3o`0000Oooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`1booooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0L_ooool0087ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo07;ooooo0021ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1cooooo`00POooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Loooool0087ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo07?ooooo0021
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1d
ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0M?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo07Cooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`1eooooo`00POooool3o`0000_ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`1eooooo`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0M_ooool0087ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo07Kooooo0021ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1fooooo`00POooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Moooool0087ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo07Oooooo0021
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1g
ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0N?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo07Sooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo07Sooooo001Vooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000?ooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0NOooool006Kooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool0NOooool006Kooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo07[ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`1jooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0N_ooool0087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo07_ooooo0021ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1kooooo`00POooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool0Noooool0087ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo07cooooo0021ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1looooo`00POooool3
o`0001?ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1looooo`00POooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0OOooool0087o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07go
oooo0021ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1nooooo`00POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool0O_ooool0087ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo07kooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`1oooooo`00POooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0Ooooool0087ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07oooooo0021ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`20ooooo`00POooool3
o`0001Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`20ooooo`00POooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0POooool0087o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo087o
oooo0021ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`21ooooo`00POooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0P_ooool0087ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo08;ooooo0021ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`23ooooo`00POooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0Poooool0087ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo08?ooooo0021ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`24ooooo`00POooool3
o`0001[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`24ooooo`00POooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0087o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo08Go
oooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`25ooooo`00POooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0Q_ooool0087ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo08Kooooo0021ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`26ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Qoooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08Oooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08Sooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0000Nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0R?ooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0R?ooool006Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0ROooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0ROoo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
ROooool0087ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo08[ooooo0021ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2:ooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0Roooool0087ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo08_ooooo0021ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2<ooooo`00POooool3o`0002;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`2<ooooo`00POooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0SOooool0087ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo08gooooo0021ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2>ooooo`00
POooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
S_ooool0087ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo08oooooo0021ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`2?ooooo`00POooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0T?ooool0087ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo093ooooo0021ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Aooooo`00POooool3o`0002Sooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`2Aooooo`00POooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0T_ooool0087ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo09?ooooo0021ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Cooooo`00
POooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
U?ooool0087ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo09Cooooo0021ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2Eooooo`00POooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0U_ooool0087ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo09Kooooo0021ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Gooooo`00POooool3o`0002kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Gooooo`00POooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0V?ooool0087ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo09Sooooo0021ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05?ooool2o`0009_ooooo0021ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Kooooo`00POoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W?oo
ool0087ooooo00?o0000ooooooooool0<_ooool2o`00013ooooo00?o0000ooooooooool0WOooool0
07Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo0_l0000<oooo
o`;o0000X?ooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0X?ooool007Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0gooooo`?o00001Oooool2o`000:?ooooo001iooooo`03o`000?oo
oooooooo00Gooooo0ol0000jooooo`Go0000YOooool007Wooooo00?o0000ooooooooool0k?ooool0
07Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Oooooo
00?oEEEEofIVI_l00000k_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00243 m
.04262 .00352 L
.06244 .00514 L
.08255 .00742 L
.10458 .01092 L
.12415 .01516 L
.14509 .02121 L
.16639 .02936 L
.18653 .03933 L
.22495 .06595 L
.24479 .08433 L
.26581 .10774 L
.30365 .16079 L
.34394 .23256 L
.38271 .31377 L
.42393 .40633 L
.46364 .49164 L
.50184 .55948 L
.52151 .58575 L
.53243 .59722 L
.54248 .60566 L
.55277 .61208 L
.55818 .61454 L
.56093 .61554 L
.56389 .61643 L
.56649 .61705 L
.56887 .61749 L
.57001 .61765 L
.57125 .6178 L
.57242 .6179 L
.57351 .61797 L
.57476 .61802 L
.57594 .61803 L
.57723 .61801 L
.57796 .61798 L
.57863 .61795 L
.57989 .61785 L
.58127 .6177 L
.58272 .6175 L
.58406 .61728 L
.58911 .61606 L
.59196 .61512 L
.59459 .6141 L
.60452 .60887 L
.61355 .60227 L
.62311 .59344 L
.64268 .56984 L
.661 .54173 L
.69982 .46741 L
.7411 .37625 L
Mistroke
.78086 .28792 L
.8191 .21084 L
.8598 .14276 L
.89898 .09265 L
.919 .07271 L
.94062 .05506 L
.97619 .03357 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`Co00001oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05_ooool001[ooooo00Co0000oooooooooooooooo3Ol0
0004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool002_ooooo1ol0001?
ooooo`03o`000?oooooooooo0>Cooooo000booooo`Oo0000B?ooool00ol0003oooooooooo`3Toooo
o`00>Oooool5o`0004?ooooo00?o0000ooooooooool0i?ooool003kooooo0ol00010ooooo`03o`00
0?oooooooooo0>Cooooo0011ooooo`?o0000?Oooool00ol0003oooooooooo`3Tooooo`00A?ooool3
o`0003[ooooo00?o0000ooooooooool0i?ooool004Oooooo0_l0000hooooo`03o`000?oooooooooo
0>Cooooo0019ooooo`;o0000=_ooool3o`000>Cooooo001;ooooo`;o0000=?ooool00ol0003ooooo
ooooo`3:ooooo`;o00006?ooool004gooooo0_l0000booooo`03o`000?oooooooooo0<Wooooo00?o
0000ooooooooool06?ooool004oooooo0_l0000`ooooo`03o`000?oooooooooo0<Oooooo0_l0000K
ooooo`00DOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0<Gooooo0_l0000Moooo
o`00D_ooool2o`0002gooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`0Mooooo`00
E?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<;ooooo0_l0000Pooooo`00EOoo
ool2o`0002[ooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`0Pooooo`00Eoooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;oooooo0_l0000Sooooo`00F?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool08oooool005Wo
oooo0_l0000Vooooo`?o0000_Oooool00ol0003oooooooooo`0Tooooo`00Foooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool09Oooool005cooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo02Kooooo001M
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0W
ooooo`00G_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;Sooooo0_l0000Zoooo
o`00Goooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;Oooooo00?o0000oooooooo
ool0:_ooool0063ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2fooooo`03o`00
0?oooooooooo02_ooooo001Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0]Ooo
ool00ol0003oooooooooo`0/ooooo`00H_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo0;Cooooo00?o0000ooooooooool0;Oooool006?ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`2cooooo`03o`000?oooooooooo02kooooo001Tooooo`03o`000?oooooooooo01[o
oooo0ol0002booooo`03o`000?oooooooooo02oooooo001Uooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0_ooooo`00I_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0<?ooool006Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo037ooooo001Xoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0boooo
o`00JOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0:oooooo00?o0000oooooooo
ool0<_ooool006Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo03?ooooo001Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`0dooooo`00I_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo03Gooooo
001Vooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0=_ooool006Ko
oooo00Oo410@oooooooooooooooooa0@4?oooooo000000[ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`2[ooooo`03o`000?oooooooooo03Kooooo001Vooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002Z
ooooo`03o`000?oooooooooo03Oooooo001Vooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`09ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0ZOooool0
0ol0003oooooooooo`0hooooo`00I_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Sooooo00?o0000
ooooooooool0>Oooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0:Sooooo00?o
0000ooooooooool0>Oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooooooo00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:Oooooo
00?o0000ooooooooool0>_ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo03_ooooo001aooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0YOooool00ol0003oooooooooo`0looooo`00LOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0??ooool007;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo03gooooo001cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0mooooo`00Looo
ool00ol0003oooooooooo`0;ooooo`?o0000Xoooool00ol0003oooooooooo`0nooooo`00M?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0?oooool0
07Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
03oooooo001eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00ol0003o
ooooooooo`10ooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:7ooooo
00?o0000ooooooooool0@?ooool007Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo047ooooo001gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Woooool00ol0003oooooooooo`12ooooo`00N?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo09oooooo00?o0000ooooooooool0@_ooool007Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo04?ooooo001iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`13ooooo`00NOoo
ool00ol0003oooooooooo`05ooooo`?o0000WOooool00ol0003oooooooooo`14ooooo`00N_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0AOooool0
07[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
04Gooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`16ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool0A_ooool007cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Jooooo`03o`000?oooooooooo04Oooooo001mooooo`05o`000?ooooooooooooooool00000Vooo
ool00ol0003oooooooooo`18ooooo`00OOooool01Ol0003ooooooooooooooooo000009_ooooo00?o
0000ooooooooool0B?ooool007kooooo00Co0000oooooooooooo0000V_ooool00ol0003ooooooooo
o`19ooooo`00O_ooool01?l0003oooooooooool0002Jooooo`03o`000?oooooooooo04Wooooo001o
ooooo`03o`000?oooooo000000;o0000Uoooool00ol0003oooooooooo`1:ooooo`00Ooooool00ol0
003oooooo`00002Iooooo`03o`000?oooooooooo04[ooooo0020ooooo`;o0000V?ooool00ol0003o
ooooooooo`1;ooooo`00POooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo04_ooooo
0021ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0C?ooool0087ooooo0_l0002F
ooooo`03o`000?oooooooooo04cooooo0021ooooo`;o0000UOooool00ol0003oooooooooo`1=oooo
o`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooo`00002Dooooo`03o`000?oooooooooo04gooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`00002Cooooo`03o`000?oooooooooo04kooooo001Vooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000Kooooo00Co0000oooooooooooo0000T_ooool00ol0003oooooooooo`1>
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool4o`00097ooooo00?o0000ooooooooool0Coooool006Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00Go0000ooooooooooooooooo`00002@ooooo`03
o`000?oooooooooo04oooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`000007ooooo`05o`000?ooooooooooooooool00000T?ooool00ol0003oooooooooo`1?oooo
o`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0D?ooool006Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo053ooooo0021ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1Aooooo`00
POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0
DOooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`03o`000?oo
oooooooo05;ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`1Booooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08Kooooo00?o0000ooooooooool0Doooool0087ooooo0ol00005ooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool0Doooool0087ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo05Cooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`1Dooooo`00POooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0EOooool0087ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo05Gooooo0021ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1Fooooo`00
POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
E_ooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo05Oooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`1Gooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool0F?ooool0087ooooo0ol0000:ooooo`03o`000?oooooooooo07co
oooo00?o0000ooooooooool0F?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo05Sooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`1Iooooo`00POooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0FOooool0087ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo05[ooooo0021ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1Jooooo`00
POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
Foooool0087ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo05_ooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`1Looooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0G?ooool0087ooooo0ol0000?ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0GOooool0087ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo05gooooo0021ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1Nooooo`00POooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0G_ooool0087ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo05oooooo0021ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1Oooooo`00
POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
Goooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo063ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`1Pooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`1Qooooo`00I_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o00004oooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo067ooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo06;ooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
J?ooool00ol0003oooooooooo`1Rooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool0Hoooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo06?ooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`1Tooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0I?ooool0087ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo0021ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Uooooo`00POooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0IOooool0087ooooo
0ol0000Gooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0I_ooool0087ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06Kooooo0021
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1W
ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0Ioooool0087ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo06Oooooo0021ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`1Xooooo`00POooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool0J?ooool0087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo06Wooooo0021ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Yooooo`00POooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0J_ooool0087ooooo
0ol0000Looooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0J_ooool0087ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo06[ooooo0021
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1[
ooooo`00POooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0Joooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo06cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`1/ooooo`00POooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0KOooool0087ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo06gooooo0021ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1]ooooo`00POooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0K_ooool0087ooooo
0ol0000Qooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0K_ooool0087ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo0021
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1_
ooooo`00POooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0L?ooool0087ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo073ooooo0021ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`1aooooo`00POooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0LOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo07;ooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1cooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1coooo
o`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o00009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Cooooo001Voooo
o`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07Cooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Gooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07Go
oooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
07Kooooo0021ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1fooooo`00POooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0Moooool0087ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo07Oooooo0021ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`1hooooo`00POooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0N?ooool0087ooooo0ol0000[ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0NOooool0087ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07[ooooo0021ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1jooooo`00POooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Noooool0
087ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
07_ooooo0021ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`1looooo`00POooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0O?ooool0087ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo07gooooo0021ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`1nooooo`00POooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0O_ooool0087ooooo0ol0000`ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0Ooooool0087ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`20ooooo`00POooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0POooool0
087ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
08;ooooo0021ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`22ooooo`00POooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0Poooool0087ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo08Cooooo0021ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`25ooooo`00POooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0QOooool0087ooooo0ol0000hooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0Q_ooool0087ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo08Oooooo0021ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`28ooooo`00POooool0
0ol0003oooooooooo`0kooooo`;o00006oooool00ol0003oooooooooo`29ooooo`00POooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0R_ooool0087o
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Dooooo`;o0000SOooool0087ooooo
00?o0000ooooooooool0?oooool2o`0001?ooooo00?o0000ooooooooool0SOooool007Oooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03_oo
ool2o`00093ooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool2
o`0000cooooo0_l0002Booooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Cooooo0_l00007ooooo`?o0000U?ooool007Wooooo00?o0000ooooooooool01Oooool3o`0004Ko
oooo1ol0002Gooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003ooooooooo
o`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00Moooool00omEEEGoIVIVo`00003^oooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00726 m
.04262 .00954 L
.06244 .01259 L
.08255 .01653 L
.10458 .02202 L
.12579 .0287 L
.14509 .03617 L
.18408 .05616 L
.22401 .08482 L
.26243 .12156 L
.30329 .17138 L
.34264 .22955 L
.38048 .29339 L
.42077 .36668 L
.45954 .43778 L
.50076 .50776 L
.52135 .53838 L
.54047 .56323 L
.56014 .58453 L
.57866 .60014 L
.58852 .60654 L
.59919 .61191 L
.6039 .61376 L
.60888 .61535 L
.61313 .61642 L
.61779 .61728 L
.6203 .61761 L
.62172 .61776 L
.62303 .61786 L
.62418 .61794 L
.62544 .61799 L
.62676 .61803 L
.628 .61803 L
.62914 .61802 L
.63033 .61798 L
.63136 .61794 L
.63248 .61787 L
.63368 .61777 L
.63498 .61764 L
.6373 .61735 L
.64001 .61691 L
.64294 .61631 L
.64826 .61488 L
.65344 .6131 L
.65822 .6111 L
.67698 .60007 L
.68764 .59163 L
.69762 .58238 L
.73644 .53523 L
.77772 .46996 L
Mistroke
.81748 .39867 L
.85573 .32818 L
.89642 .25656 L
.93561 .19484 L
.97619 .14086 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo000Jooooo`Co0000Hoooool00ol0003oooooooooo`3Tooooo`007_ooool7o`0005co
oooo00?o0000ooooooooool0i?ooool002Gooooo1_l0001Fooooo`03o`000?oooooooooo0>Cooooo
000[ooooo`Go0000DOooool00ol0003oooooooooo`3Tooooo`00<?ooool4o`0004gooooo00?o0000
ooooooooool0i?ooool003Cooooo1?l00019ooooo`03o`000?oooooooooo0>Cooooo000hooooo`?o
0000A_ooool00ol0003oooooooooo`3Tooooo`00>oooool3o`0004?ooooo0ol0003Tooooo`00?_oo
ool3o`00043ooooo00?o0000ooooooooool0i?ooool0047ooooo0ol0000mooooo`03o`000?oooooo
oooo0>Cooooo0014ooooo`;o0000>oooool00ol0003oooooooooo`3Tooooo`00A_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo0>Cooooo0017ooooo`;o0000>?ooool00ol0003ooooo
ooooo`3Tooooo`00BOooool2o`0003Kooooo00?o0000ooooooooool0i?ooool004_ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`3Tooooo`00C?ooool2o`0003?ooooo00?o0000oooo
ooooool0i?ooool004kooooo0_l0000aooooo`03o`000?oooooooooo0>Cooooo001@ooooo`03o`00
0?oooooooooo02kooooo0ol0003Tooooo`00DOooool2o`0002kooooo00?o0000ooooooooool0i?oo
ool005?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3Tooooo`00E?ooool2o`00
02_ooooo00?o0000ooooooooool0i?ooool005Kooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`3Tooooo`00Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0>Cooooo
001Hooooo`;o00009oooool00ol0003oooooooooo`3Tooooo`00F_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo0>Cooooo001Kooooo`;o00009?ooool00ol0003oooooooooo`3Toooo
o`00GOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0>Cooooo001Nooooo`03o`00
0?oooooooooo023ooooo0ol0003Tooooo`00Goooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo0>Cooooo001Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0i?ooool0
067ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`3Tooooo`00H_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo0>Cooooo001Sooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0i?ooool006Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`3Tooooo`00IOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0>Cooooo001Voooo
o`05o`000?lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo0>Cooooo001Vooooo`05ogMgMol0003ooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05oa0@4?oooooo
0000ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0>Cooooo001V
ooooo`05o`000?oooooo0000ooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000i?oo
ool006Kooooo00?o0000ooooooooool00_l0000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0i?ooool006Kooooo00Go410@ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0i?ooool006Kooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0
000:ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Tooooo`00I_oo
ool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000002Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0i?ooool006cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo01Kooooo001]ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`00K_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool05oooool006oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo01Sooooo001`oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`0Ioooo
o`00LOooool00ol0003oooooooooo`0=ooooo`?o0000b?ooool00ol0003oooooooooo`0Iooooo`00
LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool0
6_ooool007;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`36ooooo`03o`000?oo
oooooooo01_ooooo001cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0a_ooool0
0ol0003oooooooooo`0Kooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
0<Gooooo00?o0000ooooooooool07?ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`34ooooo`03o`000?oooooooooo01gooooo001eooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0`oooool00ol0003oooooooooo`0Nooooo`00M_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool07_ooool007Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo01oooooo001goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`0Poooo
o`00N?ooool00ol0003oooooooooo`06ooooo`?o0000`Oooool00ol0003oooooooooo`0Pooooo`00
NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool0
8Oooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2oooooo`03o`000?oo
oooooooo02;ooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0__ooool0
0ol0003oooooooooo`0Sooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;kooooo00?o0000ooooooooool08oooool007cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2mooooo`03o`000?oooooooooo02Cooooo001looooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0Uooooo`00OOooool01Ol0003ooooooooo
oooooooo00000;kooooo00?o0000ooooooooool09Oooool007kooooo00Co0000oooooooooooo0000
_Oooool00ol0003oooooooooo`0Vooooo`00O_ooool01?l0003oooooooooool0002looooo`03o`00
0?oooooooooo02Oooooo001oooooo`03o`000?oooooo000000;o0000^_ooool00ol0003ooooooooo
o`0Wooooo`00P?ooool2o`000;_ooooo00?o0000ooooooooool0:?ooool0083ooooo0_l0002joooo
o`03o`000?oooooooooo02Wooooo0021ooooo`03o`000?oooooooooo0;Sooooo00?o0000oooooooo
ool0:Oooool0087ooooo0_l0002hooooo`03o`000?oooooooooo02[ooooo0021ooooo`;o0000^?oo
ool00ol0003oooooooooo`0Zooooo`00POooool00ol0003oooooo`00002fooooo`03o`000?oooooo
oooo02_ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooo00000;Gooooo00?o0000ooooooooool0;?ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`000;Cooooo00?o0000ooooooooool0;?ooool006Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool01Ol0003ooooooooooooooooo00000;;ooooo
00?o0000ooooooooool0;Oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol000000ooooooo0000ooooo`2`ooooo`03o`000?oooooooooo02ko
oooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`0^oooo
o`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0;oooool006Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo033ooooo001Vooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0`ooooo`00POooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0<Oooool0087ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo
0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Yoooool00ol0003ooooooooo
o`0booooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Gooooo00?o0000
ooooooooool0<oooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Uoooo
o`03o`000?oooooooooo03?ooooo0021ooooo`?o00001oooool00ol0003oooooooooo`2Sooooo`03
o`000?oooooooooo03Cooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Xoooool00ol0003oooooooooo`0dooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0:7ooooo00?o0000ooooooooool0=Oooool0087ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo03Gooooo0021ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0fooooo`00POooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0=oooool0087ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo03Oooooo
0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Voooool00ol0003ooooooooo
o`0hooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09_ooooo00?o0000
ooooooooool0>?ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Ioooo
o`03o`000?oooooooooo03Wooooo0021ooooo`?o00003Oooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo03Wooooo0021ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`0jooooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo09Kooooo00?o0000ooooooooool0>_ooool0087ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooooooo03_ooooo0021ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0looooo`00POooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0??ooool0087ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03gooooo
0021ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0mooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0?_ooool0087ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2>oooo
o`03o`000?oooooooooo03kooooo0021ooooo`?o00004_ooool00ol0003oooooooooo`2=ooooo`03
o`000?oooooooooo03oooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
S?ooool00ol0003oooooooooo`0oooooo`00POooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool0@?ooool0087ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`2:ooooo`03o`000?oooooooooo043ooooo0021ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`11ooooo`00POooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0@Oooool0087ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo04;ooooo
001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`12ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
08Cooooo00?o0000ooooooooool0@oooool006Kooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo08?ooooo00?o0000ooooooooool0A?ooool006Kooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0001Sooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`14ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
POooool00ol0003oooooooooo`15ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0AOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo04Kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`16ooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool0Aoooool0087ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo04Oooooo0021ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`18ooooo`00POooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0B?ooool0087ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo04Wooooo0021ooooo`?o0000
7_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo04Wooooo0021ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1:ooooo`00POooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0B_ooool0
087ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo
04_ooooo0021ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1<ooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0C?ooool0087ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo04gooooo0021ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`1=ooooo`00POooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0C_ooool0087ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo04kooooo0021ooooo`?o0000
8oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo04oooooo0021ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1@ooooo`00POooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0D?ooool0
087ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
057ooooo0021ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`1Aooooo`00POooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Kooooo
00?o0000ooooooooool0D_ooool0087ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo05;ooooo0021ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`1Cooooo`00POooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0Doooool0087ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo05Cooooo0021ooooo`?o0000
:Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo05Gooooo0021ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Eooooo`00POooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0E_ooool0
087ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
05Kooooo0021ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`1Gooooo`00POooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool0F?ooool0087ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo05Sooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Iooooo`00I_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F_ooool006Kooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0F_ooool006Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`0002kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Kooooo`00I_ooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Looooo`00I_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Looooo`00I_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Mooooo`00
I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1Noooo
o`00POooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool0G_ooool0087ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo05oooooo0021ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1Pooooo`00POooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0H?ooool0087ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo067ooooo0021ooooo`?o0000=Oooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo06;ooooo0021ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Rooooo`00POooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Hoooool0087ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06Cooooo0021oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Toooo
o`00POooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0IOooool0087ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo06Kooooo0021ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`1Wooooo`00POooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0J?ooool0087ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo06Sooooo0021ooooo`?o0000??ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo06Wooooo0021ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Zooooo`00POooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Joooool0087ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06cooooo0021oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1/oooo
o`00POooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0KOooool0087ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo06kooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1_ooooo`00POooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0L?ooool0087ooooo00?o0000ooooooooool0A?ooool2o`00
02[ooooo00?o0000ooooooooool0LOooool0087ooooo0ol00016ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0L_ooool0087ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Sooooo`;o0000MOooool0087ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo07Gooooo0021ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1fooooo`00POooool00ol0003oooooooooo`1:oooo
o`;o00007Oooool2o`0007Wooooo0021ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1iooooo`00POooool00ol0003oooooooooo`1=ooooo`;o0000
5oooool2o`0007cooooo001gooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`1?ooooo`;o00005?ooool00ol0003oooooooooo`1looooo`00NOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo057ooooo0ol0000>ooooo`?o0000Ooooool007Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Dooooo`?o00002?ooool3o`0008;ooooo001iooooo`03
o`000?oooooooooo00Gooooo0ol0001Gooooo`So0000QOooool007Wooooo00?o0000ooooooooool0
k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool0
07Oooooo00?oEEEEofIVI_l00000k_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01627 m
.06244 .02449 L
.10458 .0372 L
.14415 .05366 L
.18221 .0745 L
.22272 .10295 L
.26171 .13702 L
.30316 .1807 L
.34309 .22973 L
.3815 .28238 L
.42237 .34252 L
.46172 .402 L
.49955 .45787 L
.53984 .51257 L
.57861 .55725 L
.59832 .57599 L
.61984 .59285 L
.6298 .59929 L
.64043 .60515 L
.65038 .60968 L
.65954 .61299 L
.66983 .61573 L
.67524 .61675 L
.67796 .61715 L
.68096 .6175 L
.68359 .61774 L
.68599 .6179 L
.68732 .61796 L
.68807 .61798 L
.68876 .618 L
.69003 .61803 L
.69068 .61803 L
.69139 .61803 L
.69265 .61802 L
.6938 .618 L
.69507 .61796 L
.69641 .6179 L
.69866 .61775 L
.70113 .61754 L
.70366 .61725 L
.70641 .61687 L
.7114 .61598 L
.72074 .61365 L
.73164 .60984 L
.74169 .60531 L
.76045 .59431 L
.78109 .57858 L
.82143 .53812 L
.86025 .48941 L
.90153 .43066 L
Mistroke
.94129 .37087 L
.97619 .31842 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo000Jooooo`Co0000Hoooool00ol0003ooooooooo
o`3Tooooo`007_ooool7o`0005cooooo00?o0000ooooooooool0i?ooool002Gooooo1Ol0001Goooo
o`03o`000?oooooooooo0>Cooooo000Zooooo`?o0000E?ooool00ol0003oooooooooo`3Tooooo`00
;Oooool4o`00053ooooo0ol0003Tooooo`00<Oooool3o`0004gooooo00?o0000ooooooooool0i?oo
ool003Cooooo0ol0001:ooooo`03o`000?oooooooooo0>Cooooo000gooooo`;o0000B?ooool00ol0
003oooooooooo`3Tooooo`00>Oooool2o`0004Kooooo00?o0000ooooooooool0i?ooool003_ooooo
0_l00014ooooo`03o`000?oooooooooo0>Cooooo000mooooo`;o0000@_ooool00ol0003ooooooooo
o`3Tooooo`00?oooool2o`00043ooooo00?o0000ooooooooool0i?ooool0047ooooo0_l0000noooo
o`03o`000?oooooooooo0>Cooooo0013ooooo`;o0000??ooool00ol0003oooooooooo`3Tooooo`00
AOooool2o`0003[ooooo0ol0003Tooooo`00Aoooool2o`0003Sooooo00?o0000ooooooooool0i?oo
ool004Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3Tooooo`00B_ooool2o`00
03Gooooo00?o0000ooooooooool0i?ooool004cooooo0_l0000cooooo`03o`000?oooooooooo0>Co
oooo001>ooooo`;o0000<Oooool00ol0003oooooooooo`3Tooooo`00D?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo0>Cooooo001Aooooo`;o0000;_ooool00ol0003oooooooooo`3T
ooooo`00Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0>Cooooo001Dooooo`;o
0000:oooool00ol0003oooooooooo`3Tooooo`00E_ooool00ol0003oooooooooo`0Xooooo`?o0000
i?ooool005Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3Tooooo`00F?ooool2
o`0002Oooooo00?o0000ooooooooool0i?ooool005[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`3Tooooo`00Foooool2o`0002Cooooo00?o0000ooooooooool0i?ooool005gooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`3Tooooo`00G_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo0>Cooooo001Oooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0i?ooool0063ooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3Tooooo`00HOooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0>Cooooo001Rooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool0i?ooool006?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00I?ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3T
ooooo`00IOooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Ol0003oV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0>Cooooo001Voooo
o`05onk^k_l0003o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0i?ooool006Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3T
ooooo`00JOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>Cooooo001Zooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0i?ooool006_ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3Tooooo`00K?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo0>Cooooo001]ooooo`03o`000?oooooooooo017ooooo0ol0003Tooooo`00K_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo0>Cooooo001_ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0i?ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`3Tooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0>Cooooo001b
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0i?ooool007?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`3Tooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0>Cooooo001eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
i?ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Tooooo`00M_ooool0
0ol0003oooooooooo`08ooooo`?o0000i?ooool007Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3Tooooo`00N?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>Co
oooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3Tooooo`00N_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0>Cooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0i?ooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Tooooo`00
OOooool01Ol0003ooooooooooooooooo00000>Kooooo001nooooo`04o`000?ooooooooooo`000>Ko
oooo001nooooo`03o`000?oooooooooo00?o0000i?ooool007oooooo00?o0000ooooool00000i_oo
ool0083ooooo0_l0003Vooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool2o`000>Go
oooo0021ooooo`;o0000iOooool0087ooooo00?o0000ooooool00000i?ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00Co
0000oooooooooooo0000hoooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000>?ooooo001Vooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo00Go0000ooooooooooooooooo`00003Roooo
o`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3
o`0000;ooooo00?o0000ooooooooool0goooool006Kooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3Nooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=kooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0gOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Looooo`00POooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=cooooo0021ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0foooool0087ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3Jooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Wooooo
0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0fOooool0087ooooo0ol00009
ooooo`03o`000?oooooooooo0=Sooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0eoooool0087ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Gooooo`00
POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=Kooooo0021ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0eOooool0087ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`3Eooooo`00POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
0=Cooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0doooool0087ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`3Booooo`00POooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`?o00004?ooool00ol0003oooooooooo`3A
ooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo01Kooooo0021ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`0Fooooo`00POooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool05oooool0
087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
01Sooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0Hooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:oooooo
00?o0000ooooooooool06Oooool0087ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`2^ooooo`03o`000?oooooooooo01[ooooo0021ooooo`?o00005oooool00ol0003oooooooooo`2]
ooooo`03o`000?oooooooooo01[ooooo0021ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Zoooool00ol0003oooooooooo`0Kooooo`00POooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo0:[ooooo00?o0000ooooooooool07?ooool0087ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo01cooooo0021ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0Mooooo`00POooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool07Oooool0
087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo
01kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Y?ooool0
0ol0003oooooooooo`0Oooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo0:?ooooo00?o0000ooooooooool07oooool006Kooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo0:7ooooo00?o0000ooooooooool08?ooool006Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0001gooooo00?o0000oooooooo
ool0X?ooool00ol0003oooooooooo`0Qooooo`00I_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0Woooool00ol0003oooooooooo`0Qooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool08_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Loooo
o`03o`000?oooooooooo02?ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Voooool0
0ol0003oooooooooo`0Sooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
09Wooooo00?o0000ooooooooool09?ooool0087ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo02Gooooo0021ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Uooooo`00POooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool09_ooool0087ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo02Oooooo0021oooo
o`?o00009?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo02Sooooo0021ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Xooooo`00
POooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
:Oooool0087ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo02[ooooo0021ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0SOooool0
0ol0003oooooooooo`0Zooooo`00POooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool0:oooool0087ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo02cooooo0021ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`0/ooooo`00POooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0;Oooool0087ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02kooooo0021oooo
o`?o0000:oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02kooooo0021ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0_ooooo`00
POooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
<?ooool0087ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo033ooooo0021ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`0aooooo`00POooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool0<_ooool0087ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1mooooo`03o`000?oooooooooo03;ooooo0021ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`00POooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0=?ooool0087ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Gooooo0021oooo
o`?o0000<_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Gooooo0021ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0fooooo`00
POooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
=oooool0087ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo03Oooooo0021ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0hooooo`00POooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0>Oooool0087ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo03Wooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0jooooo`00I_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0>oooool0
06Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0>ooo
ool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`0003Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0looooo`00I_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0mooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0noooo
o`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0o
ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0oooooo`00POooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0@?ooool0087ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo047ooooo0021ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`12ooooo`00POooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0@oooool0087ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04Cooooo0021ooooo`?o0000@Oooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04Cooooo0021ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`15ooooo`00POooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0A_ooool0087ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04Oooooo
0021ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`18ooooo`00POooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0BOooool0087ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04[ooooo0021ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`1;ooooo`00POooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0C?ooool0087ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04gooooo0021ooooo`?o0000B_ooool2
o`0004Oooooo00?o0000ooooooooool0C_ooool0087ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04oooooo0021ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1@ooooo`00POooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0DOooool0087ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo05;ooooo0021
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1C
ooooo`00POooool00ol0003oooooooooo`1Aooooo`;o0000>_ooool00ol0003oooooooooo`1Doooo
o`00POooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03Gooooo0_l0001Gooooo`00
POooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
Eoooool0087ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0`ooooo`;o0000F_oo
ool0087ooooo0ol0001Fooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0F_ooool0
087ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
05_ooooo0021ooooo`03o`000?oooooooooo05Sooooo0_l0000Zooooo`;o0000G_ooool0087ooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo
0021ooooo`03o`000?oooooooooo05_ooooo0_l0000Tooooo`;o0000HOooool0087ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo067ooooo0021oooo
o`03o`000?oooooooooo05kooooo0ol0000Mooooo`;o0000I?ooool007Oooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo067ooooo1?l0000Eooooo`Co0000I_ooool007Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`?o00003oooool3o`0006[ooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0J?ooool3o`0000Wooooo0ol0
001]ooooo`00NOooool00ol0003oooooooooo`05ooooo`?o0000J_ooool:o`00073ooooo001ioooo
o`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`00
0?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02965 m
.06244 .0403 L
.10458 .05528 L
.14415 .07308 L
.18221 .09404 L
.22272 .12089 L
.26171 .15135 L
.30316 .18872 L
.34309 .2293 L
.3815 .27203 L
.42237 .32054 L
.46172 .36898 L
.49955 .41573 L
.53984 .46399 L
.57861 .50713 L
.61984 .54744 L
.65954 .57902 L
.67958 .59174 L
.69774 .60124 L
.71741 .6092 L
.72821 .61252 L
.73838 .61493 L
.74815 .61661 L
.75306 .61721 L
.75589 .61748 L
.75846 .61768 L
.76083 .61782 L
.76307 .61793 L
.7643 .61797 L
.76544 .618 L
.76669 .61802 L
.76732 .61803 L
.76801 .61803 L
.76917 .61803 L
.77023 .61803 L
.77139 .61801 L
.77261 .61798 L
.77368 .61795 L
.77468 .61791 L
.77693 .6178 L
.77956 .61763 L
.78198 .61744 L
.78746 .61684 L
.79228 .61615 L
.79739 .61525 L
.80624 .61328 L
.81598 .61052 L
.83543 .60315 L
.85632 .5926 L
.89759 .5643 L
Mistroke
.93736 .52891 L
.9756 .48892 L
.97619 .48827 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo000Jooooo`?o0000I?ooool3o`000>Cooooo000Mooooo`Go0000Gooo
ool00ol0003oooooooooo`3Tooooo`008_ooool4o`0005_ooooo00?o0000ooooooooool0i?ooool0
02Kooooo0ol0001Hooooo`03o`000?oooooooooo0>Cooooo000Yooooo`?o0000EOooool00ol0003o
ooooooooo`3Tooooo`00;?ooool3o`0005;ooooo00?o0000ooooooooool0i?ooool002oooooo0ol0
001?ooooo`03o`000?oooooooooo0>Cooooo000booooo`?o0000C?ooool00ol0003oooooooooo`3T
ooooo`00=Oooool2o`0004[ooooo00?o0000ooooooooool0i?ooool003Oooooo0_l00018ooooo`03
o`000?oooooooooo0>Cooooo000iooooo`;o0000A_ooool3o`000>Cooooo000kooooo`;o0000A?oo
ool00ol0003oooooooooo`3Tooooo`00?Oooool2o`0004;ooooo00?o0000ooooooooool0i?ooool0
03oooooo0_l00010ooooo`03o`000?oooooooooo0>Cooooo0011ooooo`;o0000?_ooool00ol0003o
ooooooooo`3Tooooo`00@oooool2o`0003cooooo00?o0000ooooooooool0i?ooool004Gooooo0_l0
000jooooo`03o`000?oooooooooo0>Cooooo0017ooooo`;o0000>?ooool00ol0003oooooooooo`3T
ooooo`00BOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0>Cooooo001:ooooo`;o
0000=Oooool00ol0003oooooooooo`3Tooooo`00C?ooool2o`0003?ooooo0ol0003Tooooo`00C_oo
ool2o`00037ooooo00?o0000ooooooooool0i?ooool0053ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`3Tooooo`00DOooool2o`0002kooooo00?o0000ooooooooool0i?ooool005?o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3Tooooo`00E?ooool2o`0002_ooooo
00?o0000ooooooooool0i?ooool005Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`3Tooooo`00Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0>Cooooo001Hoooo
o`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`3Tooooo`00F_ooool00ol0003oooooooooo`09ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo001Kooooo`;o00002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00GOooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000i?oo
ool005kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`3Tooooo`00Goooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0>Cooooo001Pooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Tooooo`00HOoo
ool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`3Tooooo`00Hoooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0>Cooooo001Tooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0i?oo
ool006Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3Tooooo`00I_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo0>Cooooo001Wooooo`;o00006?ooool00ol0003o
ooooooooo`3Tooooo`00JOooool00ol0003oooooooooo`0Eooooo`?o0000i?ooool006[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`3Tooooo`00Joooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0>Cooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0i?ooool006gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Tooooo`00
K_ooool2o`00017ooooo00?o0000ooooooooool0i?ooool0073ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`3Tooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0>Cooooo001booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0i?ooool007?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Tooooo`00M?ooool00ol0003ooooo
ooooo`0:ooooo`?o0000i?ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3Tooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>Cooooo001goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0i?ooool007Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0>Cooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?oo
ool007_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Tooooo`00O?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0>Cooooo001mooooo`05o`000?oooooooooooooo
ool00000i_ooool007kooooo00?o0000ooooooooool00ol0003Tooooo`00Ooooool00ol0003ooooo
o`00003Vooooo`00P?ooool2o`000>Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021oooo
o`;o0000iOooool0087ooooo0_l0003Uooooo`00POooool00ol0003oooooo`00003Tooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool01?l0003oooooooooool0003Sooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00003Roooo
o`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0goooool006Kooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol00003ooooo`03o`000?oooooooooo0=kooooo001Voooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0gOooool006Kooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3Mooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=cooooo001Vooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0foooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3J
ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Wooooo0021ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0f?ooool0087ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3Gooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0=Oooooo0021ooooo`?o00002oooool00ol0003oooooooooo`3Fooooo`00POooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`3Cooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0=;ooooo0021
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
c_ooool0087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3=ooooo`00POooool3
o`0001Gooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[o
oooo0021ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0bOooool0087ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`39ooooo`00POooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo0<Sooooo0021ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0aoooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00
POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0aOooool0087ooooo0ol0000Mooooo`03o`000?oooooo
oooo0<Cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0`oooool0087o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`33ooooo`00POooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0<;ooooo0021ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0`Oooool0087ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`30
ooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0<3ooooo001Vooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0_oooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`2nooooo`00I_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0_Oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool3o`0002Cooooo00?o0000ooooooooool0_Oooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo001Vooooo`05oa0@4?oooooooooooooo
ool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0^oooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2jooooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0^?ooool0087ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2gooooo`00
POooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`2eooooo`00POooool3o`0002gooooo00?o0000ooooooooool0]?ooool0087o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2cooooo`00POooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo0;;ooooo0021ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0/Oooool0087ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2`
ooooo`00POooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0;3ooooo0021ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0[oooool0087ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`2^ooooo`00POooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo0:gooooo0021ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[?ooool0
087ooooo0ol0000eooooo`03o`000?oooooooooo0:cooooo0021ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0Zoooool0087ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2Zooooo`00POooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0:Wooooo0021
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`2Wooooo`00POooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo0:Oooooo0021ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
Y_ooool0087ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Uooooo`00POooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo0:Cooooo0021ooooo`?o0000?_ooool00ol0
003oooooooooo`2Sooooo`00POooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:?o
oooo0021ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0X_ooool0087ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo0:3ooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0Woooool0087ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Nooooo`00
I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo09gooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0F
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Poooool00ol0003ooooooooo
o`0Fooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000A_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo01Oooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01So
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo
01Wooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo01[ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0B_ooool2o`0007[ooooo00?o0000ooooooooool06ooo
ool0087ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo01cooooo0021ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0Mooooo`00POooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool07_ooool0087ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01oooooo0021ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Pooooo`00POooool3o`00057ooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`0Qooooo`00POooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo06Wooooo0_l0000Tooooo`00POooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool09?ooool0087ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Gooooo0021ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`00POooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool0
087ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Nooooo`;o0000:_ooool0087o
oooo00?o0000ooooooooool0F?ooool2o`0005gooooo00?o0000ooooooooool0:_ooool0087ooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo
0021ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`0/ooooo`00POooool3o`0005cooooo0_l0001Fooooo`03o`000?oooooooooo02gooooo0021oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0^oooo
o`00POooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo04oooooo0_l0000aooooo`00
POooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
<Oooool0087ooooo00?o0000ooooooooool0HOooool2o`0004_ooooo0_l0000dooooo`00POooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0=?ooool0
087ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
03Gooooo0021ooooo`03o`000?oooooooooo06Gooooo0_l00013ooooo`;o0000>?ooool0087ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Sooooo
0021ooooo`03o`000?oooooooooo06Sooooo0_l0000mooooo`;o0000>oooool0087ooooo0ol0001Z
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>oooool0087ooooo00?o0000oooo
ooooool0Joooool2o`0003Sooooo00?o0000ooooooooool0??ooool0087ooooo00?o0000oooooooo
ool0KOooool2o`0003Cooooo0_l0000oooooo`00POooool00ol0003oooooooooo`1_ooooo`;o0000
<?ooool2o`00047ooooo0021ooooo`03o`000?oooooooooo077ooooo0_l0000/ooooo`;o0000@ooo
ool0087ooooo00?o0000ooooooooool0Loooool2o`0002Oooooo0ol00015ooooo`00POooool00ol0
003oooooooooo`1eooooo`;o00008_ooool3o`0004Sooooo001gooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`1gooooo`?o00007?ooool3o`0004_ooooo001iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0N_ooool4o`0001Gooooo0ol0001>ooooo`00NOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07kooooo1Ol0000:ooooo`Ko0000DOoo
ool007Wooooo00?o0000ooooooooool01Oooool3o`0008?ooooo2_l0001Gooooo`00NOooool00ol0
003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003ooooo
ooooo`3/ooooo`00Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04655 m
.06244 .05874 L
.10458 .07476 L
.14415 .09265 L
.18221 .11266 L
.22272 .13711 L
.26171 .16378 L
.30316 .19543 L
.34309 .22895 L
.3815 .26368 L
.42237 .30281 L
.46172 .34198 L
.49955 .38032 L
.53984 .42098 L
.57861 .45903 L
.61984 .49721 L
.65954 .53069 L
.69774 .55888 L
.73838 .58363 L
.77751 .60156 L
.79892 .6087 L
.80873 .61131 L
.81909 .61361 L
.82867 .61532 L
.83374 .61605 L
.83917 .61671 L
.84417 .6172 L
.84873 .61755 L
.85092 .61769 L
.85331 .61781 L
.85556 .6179 L
.85765 .61796 L
.85882 .61799 L
.86006 .61801 L
.86112 .61802 L
.86228 .61803 L
.86353 .61803 L
.86423 .61803 L
.86486 .61803 L
.8661 .61802 L
.86727 .618 L
.86837 .61798 L
.86953 .61795 L
.87161 .61788 L
.87385 .61778 L
.87631 .61765 L
.88144 .61729 L
.88695 .61677 L
.89691 .61548 L
.90704 .61371 L
Mistroke
.91809 .61127 L
.93819 .60545 L
.95659 .59862 L
.97619 .58981 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool001[ooooo0ol0
001Tooooo`03o`000?oooooooooo0>Cooooo000Mooooo`Go0000Goooool00ol0003oooooooooo`3T
ooooo`008_ooool4o`0005_ooooo00?o0000ooooooooool0i?ooool002Kooooo0ol0001Hooooo`03
o`000?oooooooooo0>Cooooo000Yooooo`?o0000EOooool3o`000>Cooooo000/ooooo`;o0000Dooo
ool00ol0003oooooooooo`3Tooooo`00;_ooool2o`00057ooooo00?o0000ooooooooool0i?ooool0
033ooooo0ol0001>ooooo`03o`000?oooooooooo0>Cooooo000cooooo`;o0000C?ooool00ol0003o
ooooooooo`3Tooooo`00=Oooool2o`0004[ooooo00?o0000ooooooooool0i?ooool003Oooooo0ol0
0017ooooo`03o`000?oooooooooo0>Cooooo000jooooo`;o0000AOooool00ol0003oooooooooo`3T
ooooo`00??ooool2o`0004?ooooo00?o0000ooooooooool0i?ooool003kooooo0ol00010ooooo`03
o`000?oooooooooo0>Cooooo0011ooooo`;o0000?_ooool3o`000>Cooooo0013ooooo`;o0000??oo
ool00ol0003oooooooooo`3Tooooo`00AOooool2o`0003[ooooo00?o0000ooooooooool0i?ooool0
04Oooooo0_l0000hooooo`03o`000?oooooooooo0>Cooooo0019ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0i?ooool004[ooooo0_l0000eooooo`03o`000?oooooooooo0>Cooooo
001<ooooo`;o0000<oooool00ol0003oooooooooo`3Tooooo`00C_ooool2o`00037ooooo00?o0000
ooooooooool0i?ooool0053ooooo00?o0000ooooooooool04oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3Tooooo`00DOooool2o`00
01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0i?ooool005?ooooo0_l0000Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0>Cooooo001E
ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003Tooooo`00E_ooool2o`0000kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0i?ooool005Sooooo0_l0000<
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0>Cooooo001Jooooo`03o`000?oooooooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Tooooo`00Fooo
ool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`3Tooooo`00GOooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo0>Cooooo001Nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0i?oo
ool005oooooo0_l0000Pooooo`03o`000?oooooooooo0>Cooooo001Qooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0i?ooool006;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`3Tooooo`00Hoooool2o`0001cooooo0ol0003Tooooo`00IOooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0>Cooooo001Vooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0i?ooool006Oooooo0_l0000Hooooo`03o`000?oooooooooo0>Cooooo001Yooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0i?ooool006[ooooo0_l0000Eooooo`03o`00
0?oooooooooo0>Cooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0i?oo
ool006gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Tooooo`00K_ooool2o`00
017ooooo00?o0000ooooooooool0i?ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`3Tooooo`00LOooool2o`0000kooooo0ol0003Tooooo`00Loooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0>Cooooo001dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0i?ooool007Gooooo0_l0000:ooooo`03o`000?oooooooooo0>Cooooo001gooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0i?ooool007Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0>Cooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?ooool0
07_ooooo0_l00004ooooo`03o`000?oooooooooo0>Cooooo001mooooo`05o`000?oooooooooooooo
ool00000i_ooool007kooooo00?o0000ooooooooool00ol0003Tooooo`00Ooooool00ol0003ooooo
o`00003Vooooo`00P?ooool2o`000>Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021oooo
o`?o0000i?ooool0087ooooo00Co0000oooooooooooo0000hoooool0087ooooo00Go0000oooooooo
ooooooooo`00003Rooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0=oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=kooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3Mooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001oooool3o`0000Gooooo00?o0000ooooooooool0g?ooool006Kooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3Kooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=[ooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0fOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3Hooooo`00POooool00ol0003oooooooooo`0:ooooo`;o0000f?ooool0087ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`3Eooooo`00POooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
doooool0087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3Booooo`00POooool3
o`00013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<oo
oooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0c_ooool0087ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0boooool0087ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3:ooooo`00
POooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<Wooooo0021ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0b?ooool0087ooooo0ol0000Jooooo`03o`000?oooooo
oooo0<Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0a_ooool0087o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`35ooooo`00POooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0`oooool0087ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`32
ooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0<7ooooo0021ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`2oooooo`00POooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo0;kooooo0021ooooo`?o00009?ooool00ol0003oooooooooo`2mooooo`00POooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo0021ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0^oooool0087ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`2jooooo`00POooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;Wooooo0021
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0^?ooool0087ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`2gooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0;Kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0]Oooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0;Cooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo0ol0000^ooooo`03o`000?oooooooooo0;?ooooo001Vooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`2booooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0/?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2_
ooooo`00POooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:kooooo0021ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`2/ooooo`00POooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo0:_ooooo0021ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Z_ooool0
087ooooo0ol0000hooooo`03o`000?oooooooooo0:Wooooo0021ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`2Wooooo`00POooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Kooooo0021
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0YOooool0087ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`2Tooooo`00POooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo0:?ooooo0021ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
X_ooool0087ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2Qooooo`00POooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo0:3ooooo0021ooooo`?o0000@_ooool00ol0
003oooooooooo`2Oooooo`00POooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo09ko
oooo0021ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0WOooool0087ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`2Looooo`00POooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo09_ooooo0021ooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool0V_ooool0087ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2Iooooo`00
POooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo09Sooooo0021ooooo`03o`000?oo
oooooooo04[ooooo0_l0002Hooooo`00POooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo09Gooooo0021ooooo`?o0000COooool00ol0003oooooooooo`2Dooooo`00POooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo09?ooooo0021ooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0T_ooool0087ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`2Aooooo`00POooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo093ooooo0021oooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Soooool0087ooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`2>ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo08gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0S?ooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo08_ooooo001V
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0001Gooooo`03o`000?oooooooooo08[ooooo001Vooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0F?ooool2o`0008[o
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`27ooooo`00I_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool0Q_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo08Gooooo0021ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0Q?ooool0
087ooooo00?o0000ooooooooool0G_ooool2o`0008Cooooo0021ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0POooool0087ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`20ooooo`00POooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo07oooooo0021
ooooo`?o0000Hoooool00ol0003oooooooooo`1nooooo`00POooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo07gooooo0021ooooo`03o`000?oooooooooo06Gooooo0_l0001mooooo`00
POooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo07[ooooo0021ooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool0NOooool0087ooooo00?o0000ooooooooool0JOooool2
o`0007Wooooo0021ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0M_ooool0087o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1eooooo`00POooool00ol0003ooooo
ooooo`1]ooooo`;o0000MOooool0087ooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1booooo`00POooool3o`00073ooooo00?o0000ooooooooool0LOooool0087ooooo00?o0000oooo
ooooool0LOooool2o`00077ooooo0021ooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool0K_ooool0087ooooo00?o0000ooooooooool0M?ooool2o`0006kooooo0021ooooo`03o`000?oo
oooooooo07Kooooo0_l0001/ooooo`00POooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo06Wooooo0021ooooo`03o`000?oooooooooo07Wooooo0_l0001Yooooo`00POooool00ol0003o
ooooooooo`1kooooo`;o0000Ioooool0087ooooo00?o0000ooooooooool0OOooool00ol0003ooooo
ooooo`1Tooooo`00POooool00ol0003oooooooooo`1nooooo`;o0000I?ooool0087ooooo0ol00020
ooooo`;o0000H_ooool0087ooooo00?o0000ooooooooool0P_ooool2o`0004Kooooo0_l0000Hoooo
o`00POooool00ol0003oooooooooo`24ooooo`?o0000@Oooool2o`0001[ooooo0021ooooo`03o`00
0?oooooooooo08Oooooo0_l0000mooooo`;o00007?ooool0087ooooo00?o0000ooooooooool0ROoo
ool2o`0003Wooooo0_l0000Nooooo`00POooool00ol0003oooooooooo`2;ooooo`?o0000<oooool3
o`00023ooooo0021ooooo`03o`000?oooooooooo08kooooo0ol0000/ooooo`Co00008oooool007Oo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo097ooooo1?l0000Uooooo`?o
00009oooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Eooooo`Ko0000
6?ooool7o`0002[ooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Vooo
ool5o`0000gooooo1_l0000aooooo`00NOooool00ol0003oooooooooo`05ooooo`?o0000X?ooool=
o`0003Oooooo001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>co
oooo001iooooo`03o`000?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .06556 m
.06244 .07832 L
.10458 .09429 L
.14415 .11135 L
.18221 .12972 L
.22272 .15143 L
.26171 .17441 L
.30316 .20102 L
.34309 .22866 L
.3815 .25692 L
.42237 .28851 L
.46172 .32011 L
.49955 .35121 L
.53984 .38467 L
.57861 .41673 L
.61984 .45008 L
.65954 .48091 L
.69774 .50882 L
.73838 .53606 L
.77751 .55936 L
.81909 .58041 L
.85916 .59662 L
.89771 .60809 L
.91765 .61236 L
.92782 .61408 L
.93871 .61558 L
.94885 .61666 L
.9581 .61738 L
.96255 .61763 L
.96489 .61774 L
.96739 .61783 L
.96956 .6179 L
.97196 .61796 L
.97301 .61798 L
.97414 .618 L
.97521 .61801 L
.97619 .61802 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`006_ooool3o`0006Cooooo00?o0000ooooooooool0i?ooool0
01gooooo0ol0001Qooooo`03o`000?oooooooooo0>Cooooo000Pooooo`?o0000G_ooool00ol0003o
ooooooooo`3Tooooo`008oooool3o`0005_ooooo00?o0000ooooooooool0i?ooool002Kooooo0ol0
001Hooooo`03o`000?oooooooooo0>Cooooo000Yooooo`?o0000EOooool00ol0003oooooooooo`3T
ooooo`00;?ooool3o`0005;ooooo00?o0000ooooooooool0i?ooool002oooooo0ol0001?ooooo`03
o`000?oooooooooo0>Cooooo000booooo`?o0000C?ooool3o`000>Cooooo000eooooo`;o0000B_oo
ool00ol0003oooooooooo`3Tooooo`00=oooool2o`0004Sooooo00?o0000ooooooooool0i?ooool0
03Wooooo0_l00016ooooo`03o`000?oooooooooo0>Cooooo000kooooo`;o0000A?ooool00ol0003o
ooooooooo`3Tooooo`00?Oooool2o`0004;ooooo00?o0000ooooooooool0i?ooool003oooooo0_l0
0010ooooo`03o`000?oooooooooo0>Cooooo0011ooooo`;o0000?_ooool00ol0003oooooooooo`3T
ooooo`00@oooool3o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0i?ooool004Kooooo0ol0000Mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo0019ooooo`;o00006oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00Boooool3o`0001Sooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00C_ooool2
o`0001Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool0053ooooo00?o0000ooooooooool04oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Tooooo`00DOooool2
o`0001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3Tooooo`00Doooool2o`00017ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00
EOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0>Cooooo001Fooooo`;o0000:Ooo
ool00ol0003oooooooooo`3Tooooo`00F?ooool2o`0002Oooooo00?o0000ooooooooool0i?ooool0
05[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`3Tooooo`00Foooool2o`0002Co
oooo00?o0000ooooooooool0i?ooool005gooooo0_l0000Rooooo`?o0000i?ooool005oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`3Tooooo`00H?ooool2o`0001oooooo00?o0000
ooooooooool0i?ooool006;ooooo0_l0000Mooooo`03o`000?oooooooooo0>Cooooo001Tooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0i?ooool006Gooooo0_l0000Jooooo`03o`00
0?oooooooooo0>Cooooo001Wooooo`;o00006?ooool00ol0003oooooooooo`3Tooooo`00JOooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>Cooooo001Zooooo`;o00005Oooool00ol0
003oooooooooo`3Tooooo`00K?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0>Co
oooo001]ooooo`;o00004_ooool3o`000>Cooooo001_ooooo`;o00004?ooool00ol0003ooooooooo
o`3Tooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0>Cooooo001boooo
o`;o00003Oooool00ol0003oooooooooo`3Tooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0>Cooooo001eooooo`;o00002_ooool00ol0003oooooooooo`3Tooooo`00Mooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>Cooooo001hooooo`;o00001oooool0
0ol0003oooooooooo`3Tooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0>Cooooo001kooooo`;o00001?ooool00ol0003oooooooooo`3Tooooo`00OOooool01?l0003ooooo
ooooooooool3o`000>Cooooo001nooooo`04o`000?ooooooooooo`000>Kooooo001oooooo`?o0000
i_ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool01?l0
003oooooooooool0003Sooooo`00POooool01Ol0003ooooooooooooooooo00000>;ooooo001Voooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0003Pooooo`00I_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3Mooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g?ooool006Kooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00006ooooo`;o0000g?oo
ool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Iooooo`00I_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0=Sooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo00[ooooo0_l0003Hooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0=Gooooo0021ooooo`03o`000?oooooooooo00gooooo0_l0003Eooooo`00POooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooooooool04Oooool2o`000=7o
oooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0c_ooool0087ooooo0ol0
000Dooooo`;o0000c_ooool0087ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3;
ooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[ooooo0021ooooo`03
o`000?oooooooooo01Sooooo0_l0003:ooooo`00POooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0a_oo
ool0087ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`35ooooo`00POooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03o`000?oooooooooo01ko
oooo0_l00034ooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0<7ooooo
0021ooooo`?o00008Oooool00ol0003oooooooooo`30ooooo`00POooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo0;oooooo0021ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0__ooool0087ooooo00?o0000ooooooooool09?ooool2o`000;kooooo0021ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0^oooool0087ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0Xooooo`;o0000^_ooool0
087ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2gooooo`00POooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0]Oooool0087ooooo0ol0000]ooooo`;o0000]Oooool0087ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`2booooo`00POooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo0;7ooooo0021ooooo`03o`000?oooooooooo037ooooo0_l0002aooooo`00
POooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:kooooo0021ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`2/ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo0:_ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Oooooo0_l0002[ooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0Z?ooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003[ooooo00?o0000oooo
ooooool0Yoooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Kooooo001Voooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0YOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2T
ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`0nooooo`;o0000Y?ooool0087ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
0:3ooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Woooool0087ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Nooooo`00POooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo09gooooo0021ooooo`?o0000AOooool00ol0003oooooooooo`2L
ooooo`00POooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09_ooooo0021ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0V_ooool0087ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`2Iooooo`00POooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo09Sooooo0021ooooo`03o`000?oooooooooo04[ooooo0_l0002Hooooo`00POooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo09Gooooo0021ooooo`03o`000?oooooooooo04go
oooo0_l0002Eooooo`00POooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo09;ooooo
0021ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0TOooool0087ooooo0ol0001A
ooooo`;o0000TOooool0087ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2>oooo
o`00POooool00ol0003oooooooooo`1Dooooo`;o0000S_ooool0087ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`2;ooooo`00POooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo08[ooooo0021ooooo`03o`000?oooooooooo05Sooooo0_l0002:ooooo`00POooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo08Oooooo0021ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0Q_ooool0087ooooo00?o0000ooooooooool0G?ooool2o`0008Kooooo
0021ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Poooool0087ooooo0ol0001O
ooooo`03o`000?oooooooooo08;ooooo0021ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0POooool0087ooooo00?o0000ooooooooool0HOooool2o`00087ooooo0021ooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0O_ooool0087ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`1mooooo`00POooool00ol0003oooooooooo`1Uooooo`;o0000OOooool0
087ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1jooooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo07Wooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo06Wooooo0_l0001iooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
M_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`0006cooooo00?o0000ooooooooool0MOooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1]oooo
o`;o0000MOooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07;ooooo001Voooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`00I_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo077ooooo
0_l0001aooooo`00POooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo06kooooo0021
ooooo`03o`000?oooooooooo07Cooooo0_l0001^ooooo`00POooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo06_ooooo0021ooooo`03o`000?oooooooooo07Oooooo0_l0001[ooooo`00
POooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo06Sooooo0021ooooo`?o0000N_oo
ool00ol0003oooooooooo`1Wooooo`00POooool00ol0003oooooooooo`1kooooo`;o0000Ioooool0
087ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1Tooooo`00POooool00ol0003o
ooooooooo`1nooooo`;o0000I?ooool0087ooooo00?o0000ooooooooool0P?ooool00ol0003ooooo
ooooo`1Qooooo`00POooool00ol0003oooooooooo`21ooooo`;o0000HOooool0087ooooo00?o0000
ooooooooool0Poooool2o`0005oooooo0021ooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0G?ooool0087ooooo00?o0000ooooooooool0Q_ooool2o`0005cooooo0021ooooo`03o`00
0?oooooooooo08Sooooo0_l0001Jooooo`00POooool3o`0008[ooooo00?o0000ooooooooool0Eooo
ool0087ooooo00?o0000ooooooooool0Roooool2o`0005Oooooo0021ooooo`03o`000?oooooooooo
08gooooo0_l0001Eooooo`00POooool00ol0003oooooooooo`2?ooooo`;o0000Doooool0087ooooo
00?o0000ooooooooool0TOooool2o`00057ooooo0021ooooo`03o`000?oooooooooo09?ooooo00?o
0000ooooooooool0C_ooool0087ooooo00?o0000ooooooooool0U?ooool2o`0004kooooo0021oooo
o`03o`000?oooooooooo09Kooooo0_l0001<ooooo`00POooool00ol0003oooooooooo`2Hooooo`;o
0000B_ooool0087ooooo00?o0000ooooooooool0V_ooool3o`0004Oooooo0021ooooo`?o0000WOoo
ool3o`0004Cooooo0021ooooo`03o`000?oooooooooo0:3ooooo0_l00012ooooo`00POooool00ol0
003oooooooooo`2Rooooo`?o0000?oooool0087ooooo00?o0000ooooooooool0YOooool3o`0003co
oooo0021ooooo`03o`000?oooooooooo0:Sooooo0ol0000iooooo`00POooool00ol0003ooooooooo
o`2[ooooo`?o0000=_ooool0087ooooo00?o0000ooooooooool0[_ooool3o`0003?ooooo001goooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2aooooo`Go0000;_ooool007Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2fooooo`Go0000:Oooool007Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`[o00007oooool007Wooooo00?o
0000ooooooooool01Oooool3o`000<Gooooo1ol0000Hooooo`00NOooool00ol0003oooooooooo`3/
ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00
Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08521 m
.06244 .09774 L
.10458 .11288 L
.14415 .12855 L
.18221 .14495 L
.22272 .16385 L
.26171 .18342 L
.30316 .20567 L
.34309 .22842 L
.3815 .25144 L
.42237 .27698 L
.46172 .30246 L
.49955 .32757 L
.53984 .35477 L
.57861 .38114 L
.61984 .4091 L
.65954 .43566 L
.69774 .46057 L
.73838 .48606 L
.77751 .50931 L
.81909 .53229 L
.85916 .55242 L
.89771 .56965 L
.93871 .58541 L
.97619 .59729 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`006_ooool3o`0006Cooooo00?o0000ooooooooool0i?ooool001gooooo0ol0001Qooooo`03
o`000?oooooooooo0>Cooooo000Pooooo`?o0000G_ooool3o`000>Cooooo000Sooooo`?o0000Fooo
ool00ol0003oooooooooo`3Tooooo`009_ooool3o`0005Sooooo00?o0000ooooooooool0i?ooool0
02Wooooo0ol0001Eooooo`03o`000?oooooooooo0>Cooooo000/ooooo`?o0000D_ooool00ol0003o
ooooooooo`3Tooooo`00;oooool3o`0004oooooo00?o0000ooooooooool0i?ooool003;ooooo0ol0
001<ooooo`03o`000?oooooooooo0>Cooooo000eooooo`;o0000B_ooool00ol0003oooooooooo`3T
ooooo`00=oooool3o`0002cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0i?ooool003[ooooo0_l0000Zooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo000looooo`;o0000:?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00?_ooool3o`0002Gooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00@Oooool2
o`0002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool004?ooooo0ol0000Pooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Cooooo0016ooooo`?o00007Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0>Cooooo0019ooooo`;o00006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo001;ooooo`?o0000
<oooool00ol0003oooooooooo`3Tooooo`00C_ooool2o`00037ooooo00?o0000ooooooooool0i?oo
ool0053ooooo0_l0000_ooooo`03o`000?oooooooooo0>Cooooo001Booooo`;o0000;Oooool00ol0
003oooooooooo`3Tooooo`00E?ooool2o`0002_ooooo00?o0000ooooooooool0i?ooool005Kooooo
00?o0000ooooooooool0:?ooool3o`000>Cooooo001Gooooo`;o0000:?ooool00ol0003ooooooooo
o`3Tooooo`00FOooool2o`0002Kooooo00?o0000ooooooooool0i?ooool005_ooooo0_l0000Toooo
o`03o`000?oooooooooo0>Cooooo001Mooooo`;o00008_ooool00ol0003oooooooooo`3Tooooo`00
Goooool2o`00023ooooo00?o0000ooooooooool0i?ooool0067ooooo0_l0000Nooooo`03o`000?oo
oooooooo0>Cooooo001Sooooo`;o00007?ooool00ol0003oooooooooo`3Tooooo`00IOooool2o`00
01[ooooo00?o0000ooooooooool0i?ooool006Oooooo0_l0000Hooooo`03o`000?oooooooooo0>Co
oooo001Yooooo`;o00005_ooool3o`000>Cooooo001[ooooo`;o00005?ooool00ol0003ooooooooo
o`3Tooooo`00KOooool2o`0001;ooooo00?o0000ooooooooool0i?ooool006oooooo0_l0000@oooo
o`03o`000?oooooooooo0>Cooooo001aooooo`;o00003_ooool00ol0003oooooooooo`3Tooooo`00
Loooool2o`0000cooooo00?o0000ooooooooool0i?ooool007Gooooo0_l0000:ooooo`03o`000?oo
oooooooo0>Cooooo001gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0i?ooool0
07Sooooo0_l00007ooooo`03o`000?oooooooooo0>Cooooo001jooooo`;o00001Oooool00ol0003o
ooooooooo`3Tooooo`00O?ooool00ol0003oooooooooo`02ooooo`?o0000i?ooool007gooooo0_l0
0002ooooo`03o`000?oooooooooo0>Cooooo001oooooo`?o0000i_ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`02o`000>;ooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0goooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool00oooool2o`000=oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000gOoo
ool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0=[ooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`?o00002?ooool2o`000=[ooooo001Vooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00[o
oooo0_l0003Hooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`0<ooooo`;o0000e_ooool006Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`3Cooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`0?ooooo`;o0000doooool0087ooooo00?o0000ooooooooool0
4Oooool2o`000=7ooooo0021ooooo`03o`000?oooooooooo01?ooooo0_l0003?ooooo`00POooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooooooo
01Kooooo0_l0003<ooooo`00POooool00ol0003oooooooooo`0Hooooo`;o0000b_ooool0087ooooo
0ol0000Jooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0a_ooool0087ooooo00?o0000ooooooooool07?ooool2o`000<Kooooo0021oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0`oooool0087ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`32ooooo`00POooool00ol0003oooooooooo`0Pooooo`;o0000
`_ooool0087ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2oooooo`00POooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oooooooooo
02Cooooo0_l0002nooooo`00POooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;_o
oooo0021ooooo`?o00009oooool2o`000;_ooooo0021ooooo`03o`000?oooooooooo02Wooooo0_l0
002iooooo`00POooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021oooo
o`03o`000?oooooooooo02cooooo0_l0002fooooo`00POooool00ol0003oooooooooo`0^ooooo`;o
0000]?ooool0087ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2aooooo`00POoo
ool00ol0003oooooooooo`0aooooo`;o0000/Oooool0087ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2^ooooo`00POooool00ol0003oooooooooo`0dooooo`;o0000[_ooool0087o
oooo00?o0000ooooooooool0=_ooool2o`000:cooooo0021ooooo`?o0000>?ooool00ol0003ooooo
ooooo`2Yooooo`00POooool00ol0003oooooooooo`0iooooo`;o0000ZOooool0087ooooo00?o0000
ooooooooool0>oooool2o`000:Oooooo0021ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0Y?ooool0087ooooo00?o0000ooooooooool0?_ooool2o`000:Cooooo0021ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0XOooool0087ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`2Pooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`12ooooo`;o0000
X?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Mooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0W?ooool006Kooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0004Kooooo0_l0002L
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0VOooool006Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`2Hooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1:ooooo`;o0000V?ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`2Eooooo`00POooool00ol0003oooooooooo`1=ooooo`;o0000UOoo
ool0087ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2Booooo`00POooool00ol0
003oooooooooo`1@ooooo`;o0000T_ooool0087ooooo00?o0000ooooooooool0D_ooool2o`00093o
oooo0021ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0SOooool0087ooooo0ol0
001Eooooo`;o0000SOooool0087ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2:
ooooo`00POooool00ol0003oooooooooo`1Hooooo`;o0000R_ooool0087ooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`27ooooo`00POooool00ol0003oooooooooo`1Kooooo`;o0000
Qoooool0087ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`24ooooo`00POooool0
0ol0003oooooooooo`1Nooooo`;o0000Q?ooool0087ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`21ooooo`00POooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo083o
oooo0021ooooo`03o`000?oooooooooo06;ooooo0_l00020ooooo`00POooool3o`0006Cooooo00?o
0000ooooooooool0OOooool0087ooooo00?o0000ooooooooool0IOooool2o`0007gooooo0021oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0N_ooool0087ooooo00?o0000oooooooo
ool0J?ooool2o`0007[ooooo0021ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
Moooool0087ooooo00?o0000ooooooooool0Joooool2o`0007Oooooo0021ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool0M?ooool0087ooooo00?o0000ooooooooool0K_ooool2o`00
07Cooooo0021ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool0087ooooo
00?o0000ooooooooool0LOooool2o`00077ooooo0021ooooo`?o0000Loooool00ol0003ooooooooo
o`1^ooooo`00POooool00ol0003oooooooooo`1dooooo`;o0000K_ooool0087ooooo00?o0000oooo
ooooool0M_ooool2o`0006cooooo0021ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0JOooool0087ooooo00?o0000ooooooooool0NOooool2o`0006Wooooo0021ooooo`03o`000?oo
oooooooo07_ooooo0_l0001Wooooo`00POooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo06Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07kooooo0_l0001Tooooo`00I_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo067ooooo001Vooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0POooool2o`00067ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol00023ooooo`;o0000Goooool006Kooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo05cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Q_ooool2o`0005cooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0R?ooool2o`0005[ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0R_ooool00ol0003o
ooooooooo`1Gooooo`00POooool00ol0003oooooooooo`2;ooooo`;o0000Eoooool0087ooooo00?o
0000ooooooooool0SOooool2o`0005Gooooo0021ooooo`03o`000?oooooooooo08oooooo0_l0001C
ooooo`00POooool00ol0003oooooooooo`2Aooooo`;o0000DOooool0087ooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`1>ooooo`00POooool3o`0009Cooooo0_l0001>ooooo`00POoo
ool00ol0003oooooooooo`2Fooooo`;o0000C?ooool0087ooooo00?o0000ooooooooool0V?ooool2
o`0004[ooooo0021ooooo`03o`000?oooooooooo09[ooooo0_l00018ooooo`00POooool00ol0003o
ooooooooo`2Looooo`;o0000A_ooool0087ooooo00?o0000ooooooooool0W_ooool2o`0004Cooooo
0021ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0@Oooool0087ooooo00?o0000
ooooooooool0XOooool2o`00047ooooo0021ooooo`03o`000?oooooooooo0:?ooooo0_l0000ooooo
o`00POooool00ol0003oooooooooo`2Uooooo`;o0000?Oooool0087ooooo0ol0002Wooooo`?o0000
>_ooool0087ooooo00?o0000ooooooooool0Z_ooool3o`0003Oooooo0021ooooo`03o`000?oooooo
oooo0:gooooo0_l0000eooooo`00POooool00ol0003oooooooooo`2_ooooo`?o0000<_ooool0087o
oooo00?o0000ooooooooool0/_ooool2o`00033ooooo0021ooooo`03o`000?oooooooooo0;Cooooo
0ol0000]ooooo`00POooool00ol0003oooooooooo`2gooooo`?o0000:_ooool0087ooooo00?o0000
ooooooooool0^_ooool2o`0002Sooooo0021ooooo`03o`000?oooooooooo0;cooooo0ol0000Uoooo
o`00POooool00ol0003oooooooooo`2oooooo`?o00008_ooool0087ooooo0ol00032ooooo`?o0000
7oooool0087ooooo00?o0000ooooooooool0aOooool3o`0001cooooo0021ooooo`03o`000?oooooo
oooo0<Sooooo0ol0000Iooooo`00POooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo
0021ooooo`03o`000?oooooooooo0>Cooooo001gooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0>Cooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wooooo
00?o0000ooooooooool01Oooool3o`000>Cooooo001iooooo`03o`000?oooooooooo0>cooooo001i
ooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001gooooo`03
oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10434 m
.06244 .11609 L
.10458 .12993 L
.14415 .14391 L
.18221 .15825 L
.22272 .17447 L
.26171 .191 L
.30316 .20952 L
.34309 .22823 L
.3815 .24699 L
.42237 .26768 L
.46172 .28823 L
.49955 .30848 L
.53984 .33045 L
.57861 .35188 L
.61984 .37483 L
.65954 .39693 L
.69774 .41805 L
.73838 .44019 L
.77751 .46102 L
.81909 .48244 L
.85916 .5022 L
.89771 .52024 L
.93871 .53819 L
.97619 .55334 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo000Jooooo`?o0000I?ooool00ol0003o
ooooooooo`3Tooooo`007Oooool3o`00067ooooo00?o0000ooooooooool0i?ooool0023ooooo0ol0
001Nooooo`03o`000?oooooooooo0>Cooooo000Sooooo`?o0000Foooool00ol0003oooooooooo`3T
ooooo`009_ooool3o`0003gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0i?ooool002Wooooo0ol0000jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo000/ooooo`?o0000=oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00;oooool3o`0003Cooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00<_ooool3
o`00037ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool003Gooooo0ol0000^ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Cooooo000hooooo`?o0000:oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0>Cooooo000kooooo`?o0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo000nooooo`?o0000
@?ooool00ol0003oooooooooo`3Tooooo`00@Oooool2o`0003kooooo00?o0000ooooooooool0i?oo
ool004?ooooo0ol0000kooooo`03o`000?oooooooooo0>Cooooo0016ooooo`?o0000>?ooool00ol0
003oooooooooo`3Tooooo`00BOooool2o`0003Kooooo00?o0000ooooooooool0i?ooool004_ooooo
0ol0000cooooo`?o0000i?ooool004kooooo0_l0000aooooo`03o`000?oooooooooo0>Cooooo001@
ooooo`?o0000;_ooool00ol0003oooooooooo`3Tooooo`00Doooool3o`0002_ooooo00?o0000oooo
ooooool0i?ooool005Kooooo0_l0000Yooooo`03o`000?oooooooooo0>Cooooo001Hooooo`?o0000
9_ooool00ol0003oooooooooo`3Tooooo`00Foooool2o`0002Cooooo00?o0000ooooooooool0i?oo
ool005gooooo0ol0000Qooooo`03o`000?oooooooooo0>Cooooo001Pooooo`;o00007oooool00ol0
003oooooooooo`3Tooooo`00H_ooool2o`0001gooooo00?o0000ooooooooool0i?ooool006Cooooo
0ol0000Jooooo`?o0000i?ooool006Oooooo0_l0000Hooooo`03o`000?oooooooooo0>Cooooo001Y
ooooo`?o00005Oooool00ol0003oooooooooo`3Tooooo`00K?ooool2o`0001?ooooo00?o0000oooo
ooooool0i?ooool006kooooo0_l0000Aooooo`03o`000?oooooooooo0>Cooooo001`ooooo`?o0000
3_ooool00ol0003oooooooooo`3Tooooo`00Loooool2o`0000cooooo00?o0000ooooooooool0i?oo
ool007Gooooo0_l0000:ooooo`03o`000?oooooooooo0>Cooooo001gooooo`;o00002?ooool00ol0
003oooooooooo`3Tooooo`00NOooool2o`0000Kooooo00?o0000ooooooooool0i?ooool007_ooooo
0ol00003ooooo`?o0000i?ooool007kooooo0_l000000ooooooo0000ooooo`3Uooooo`00P?ooool2
o`000>Kooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool00_l0003Rooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=oooooo0021ooooo`03o`000?oo
oooooooo00?ooooo0_l0003Oooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o0000gOoo
ool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0f_ooool006Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`;o0000f_oo
ool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo
0ol0000:ooooo`;o0000f?ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool03?ooool3o`000=Gooooo001Vooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00oo
oooo0_l0003Cooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0Aooooo`;o0000dOooool006Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool04oooool3o`000<ko
oooo0021ooooo`03o`000?oooooooooo01Kooooo0_l0003<ooooo`00POooool00ol0003ooooooooo
o`0Hooooo`;o0000b_ooool0087ooooo00?o0000ooooooooool06_ooool2o`000<Sooooo0021oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000oooooooo
ool07Oooool2o`000<Gooooo0021ooooo`?o00007oooool2o`000<?ooooo0021ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool08_ooool2
o`000<3ooooo0021ooooo`03o`000?oooooooooo02Cooooo0_l0002nooooo`00POooool00ol0003o
ooooooooo`0Vooooo`;o0000_?ooool0087ooooo00?o0000ooooooooool0:?ooool2o`000;[ooooo
0021ooooo`03o`000?oooooooooo02[ooooo0ol0002gooooo`00POooool00ol0003oooooooooo`0]
ooooo`;o0000]Oooool0087ooooo00?o0000ooooooooool0;oooool2o`000;?ooooo0021ooooo`03
o`000?oooooooooo037ooooo0_l0002aooooo`00POooool3o`0003?ooooo00?o0000ooooooooool0
[_ooool0087ooooo00?o0000ooooooooool0=?ooool2o`000:kooooo0021ooooo`03o`000?oooooo
oooo03Kooooo0_l0002/ooooo`00POooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
0:Wooooo0021ooooo`03o`000?oooooooooo03Wooooo0_l0002Yooooo`00POooool00ol0003ooooo
ooooo`0kooooo`;o0000Yoooool0087ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`2Tooooo`00POooool00ol0003oooooooooo`0nooooo`;o0000Y?ooool0087ooooo00?o0000oooo
ooooool0@?ooool2o`000:;ooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0Woooool0087ooooo0ol00013ooooo`;o0000Woooool0087ooooo00?o0000ooooooooool0AOoo
ool2o`0009gooooo0021ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0V_ooool0
087ooooo00?o0000ooooooooool0B?ooool2o`0009[ooooo0021ooooo`03o`000?oooooooooo04[o
oooo0_l0002Hooooo`00POooool00ol0003oooooooooo`1<ooooo`;o0000U_ooool0087ooooo00?o
0000ooooooooool0C_ooool2o`0009Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo053ooooo
0_l0002Booooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Booooo`;o0000T?ooool006Kooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1Dooooo`;o0000S_ooool006Kooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0005Kooooo0_l0002<ooooo`00I_ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo05Sooooo0_l0002:ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Jooooo`;o0000R?ooool006Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0G?oo
ool2o`0008Kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo05kooooo0_l00024ooooo`00POooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo087ooooo0021ooooo`03o`000?oooooooooo067ooooo0_l00021
ooooo`00POooool00ol0003oooooooooo`1Sooooo`;o0000Ooooool0087ooooo00?o0000oooooooo
ool0IOooool2o`0007gooooo0021ooooo`03o`000?oooooooooo06Oooooo0_l0001kooooo`00POoo
ool3o`0006Wooooo00?o0000ooooooooool0N?ooool0087ooooo00?o0000ooooooooool0J_ooool2
o`0007Sooooo0021ooooo`03o`000?oooooooooo06cooooo0_l0001fooooo`00POooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo07?ooooo0021ooooo`03o`000?oooooooooo06oooooo
0_l0001cooooo`00POooool00ol0003oooooooooo`1aooooo`;o0000LOooool0087ooooo00?o0000
ooooooooool0Loooool2o`0006oooooo0021ooooo`03o`000?oooooooooo07Gooooo0_l0001]oooo
o`00POooool00ol0003oooooooooo`1gooooo`;o0000Joooool0087ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1Xooooo`00POooool3o`0007[ooooo0_l0001Xooooo`00POooool0
0ol0003oooooooooo`1looooo`;o0000I_ooool0087ooooo00?o0000ooooooooool0O_ooool2o`00
06Cooooo0021ooooo`03o`000?oooooooooo083ooooo0_l0001Rooooo`00POooool00ol0003ooooo
ooooo`22ooooo`;o0000H?ooool0087ooooo00?o0000ooooooooool0Q?ooool2o`0005kooooo0021
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Foooool0087ooooo00?o0000oooo
ooooool0Qoooool2o`0005_ooooo0021ooooo`03o`000?oooooooooo08Wooooo0_l0001Iooooo`00
POooool00ol0003oooooooooo`2;ooooo`;o0000Eoooool0087ooooo0ol0002=ooooo`;o0000EOoo
ool0087ooooo00?o0000ooooooooool0Soooool2o`0005?ooooo0021ooooo`03o`000?oooooooooo
097ooooo0_l0001Aooooo`00POooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo04ko
oooo0021ooooo`03o`000?oooooooooo09Cooooo0_l0001>ooooo`00POooool00ol0003ooooooooo
o`2Fooooo`;o0000C?ooool0087ooooo00?o0000ooooooooool0V?ooool2o`0004[ooooo001Voooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo09[ooooo0_l00018ooooo`00I_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2Looooo`;o0000A_ooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`2Nooooo`?o0000@oooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0:7ooooo0_l00011ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo0:?ooooo0_l0000oooooo`00I_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oo
oooooooo0:Gooooo0_l0000mooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0:Oooooo0_l0000kooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0:Wooooo0_l0000iooooo`00POooool00ol0003oooooooooo`2[ooooo`?o0000
=_ooool0087ooooo00?o0000ooooooooool0[_ooool2o`0003Cooooo0021ooooo`03o`000?oooooo
oooo0;3ooooo0_l0000booooo`00POooool00ol0003oooooooooo`2booooo`;o0000<?ooool0087o
oooo00?o0000ooooooooool0]?ooool2o`0002kooooo0021ooooo`?o0000]_ooool2o`0002cooooo
0021ooooo`03o`000?oooooooooo0;Sooooo0ol0000Yooooo`00POooool00ol0003oooooooooo`2k
ooooo`;o00009oooool0087ooooo00?o0000ooooooooool0_Oooool2o`0002Gooooo0021ooooo`03
o`000?oooooooooo0;oooooo0_l0000Sooooo`00POooool00ol0003oooooooooo`31ooooo`?o0000
8?ooool0087ooooo00?o0000ooooooooool0a?ooool2o`0001kooooo0021ooooo`03o`000?oooooo
oooo0<Kooooo0_l0000Looooo`00POooool00ol0003oooooooooo`38ooooo`?o00006Oooool0087o
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`00POooool3o`000>Cooooo
0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021oooo
o`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000
ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooooooo
ool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool007Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0>Cooooo001ioooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`?o0000
i?ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool0
07Wooooo00?o0000ooooooooool0k?ooool007Oooooo00?oEEEEofIVI_l00000k_ooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12217 m
.06244 .13282 L
.10458 .14513 L
.14415 .15735 L
.18221 .16969 L
.22272 .18347 L
.26171 .19733 L
.30316 .21269 L
.34309 .22807 L
.3815 .24337 L
.42237 .26015 L
.46172 .27675 L
.49955 .29308 L
.53984 .3108 L
.57861 .32812 L
.61984 .34674 L
.65954 .36481 L
.69774 .38223 L
.73838 .40074 L
.77751 .41843 L
.81909 .437 L
.85916 .45457 L
.89771 .47108 L
.93871 .48812 L
.97619 .50313 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo000Jooooo`?o0000BOooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`007Oooool3o`0004Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`008?ooool3
o`0004?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool002?ooooo0ol00010ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Cooooo000Vooooo`Co0000??ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0>Cooooo000Zooooo`Go0000=oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo000_ooooo`Go0000
COooool00ol0003oooooooooo`3Tooooo`00=?ooool4o`0004Wooooo00?o0000ooooooooool0i?oo
ool003Sooooo0ol00016ooooo`03o`000?oooooooooo0>Cooooo000kooooo`?o0000@oooool00ol0
003oooooooooo`3Tooooo`00?_ooool3o`00043ooooo00?o0000ooooooooool0i?ooool0047ooooo
0ol0000mooooo`?o0000i?ooool004Cooooo0ol0000jooooo`03o`000?oooooooooo0>Cooooo0017
ooooo`?o0000=oooool00ol0003oooooooooo`3Tooooo`00B_ooool3o`0003Cooooo00?o0000oooo
ooooool0i?ooool004gooooo0ol0000aooooo`03o`000?oooooooooo0>Cooooo001@ooooo`?o0000
;_ooool00ol0003oooooooooo`3Tooooo`00Doooool3o`0002_ooooo00?o0000ooooooooool0i?oo
ool005Kooooo0_l0000Yooooo`03o`000?oooooooooo0>Cooooo001Hooooo`?o00009_ooool00ol0
003oooooooooo`3Tooooo`00Foooool3o`0002?ooooo00?o0000ooooooooool0i?ooool005kooooo
0ol0000Pooooo`?o0000i?ooool0067ooooo0ol0000Mooooo`03o`000?oooooooooo0>Cooooo001T
ooooo`?o00006_ooool00ol0003oooooooooo`3Tooooo`00Ioooool2o`0001Sooooo00?o0000oooo
ooooool0i?ooool006Wooooo0ol0000Eooooo`03o`000?oooooooooo0>Cooooo001/ooooo`?o0000
4_ooool00ol0003oooooooooo`3Tooooo`00Koooool3o`0000oooooo00?o0000ooooooooool0i?oo
ool007;ooooo0ol0000<ooooo`03o`000?oooooooooo0>Cooooo001eooooo`;o00002_ooool00ol0
003oooooooooo`3Tooooo`00Moooool3o`0000Oooooo00?o0000ooooooooool0i?ooool007[ooooo
0ol00004ooooo`?o0000i?ooool007gooooo0_l00002ooooo`03o`000?oooooooooo0>Cooooo001o
ooooo`?o0000i_ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`03o`000>7o
oooo0021ooooo`03o`000?oooooooooo00?ooooo0_l0003Oooooo`00POooool00ol0003ooooooooo
o`05ooooo`;o0000gOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01oooool3o`000=[ooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`;o0000f?ooool006Kooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool00ol0003oooooooooo`0<ooooo`?o0000eOooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000?ooooo`;o0000
doooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool04Oooool2o`000=7ooooo001Vooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo01?ooooo0ol0003>ooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`0Fooooo`;o0000c?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool06?ooool2o`000<[ooooo0021ooooo`03o`00
0?oooooooooo01[ooooo0ol00037ooooo`00POooool00ol0003oooooooooo`0Mooooo`;o0000aOoo
ool0087ooooo00?o0000ooooooooool07oooool2o`000<?ooooo0021ooooo`03o`000?oooooooooo
027ooooo0ol00030ooooo`00POooool00ol0003oooooooooo`0Tooooo`;o0000__ooool0087ooooo
0ol0000Vooooo`?o0000^oooool0087ooooo00?o0000ooooooooool0:Oooool3o`000;Sooooo0021
ooooo`03o`000?oooooooooo02cooooo0_l0002fooooo`00POooool00ol0003oooooooooo`0^oooo
o`?o0000/oooool0087ooooo00?o0000ooooooooool0<Oooool2o`000;7ooooo0021ooooo`03o`00
0?oooooooooo03?ooooo0_l0002_ooooo`00POooool00ol0003oooooooooo`0eooooo`;o0000[Ooo
ool0087ooooo00?o0000ooooooooool0=oooool3o`000:[ooooo0021ooooo`03o`000?oooooooooo
03[ooooo0_l0002Xooooo`00POooool00ol0003oooooooooo`0looooo`;o0000Y_ooool0087ooooo
0ol0000nooooo`;o0000Y?ooool0087ooooo00?o0000ooooooooool0@?ooool2o`000:;ooooo0021
ooooo`03o`000?oooooooooo04;ooooo0_l0002Pooooo`00POooool00ol0003oooooooooo`14oooo
o`;o0000W_ooool0087ooooo00?o0000ooooooooool0A_ooool2o`0009cooooo0021ooooo`03o`00
0?oooooooooo04Sooooo0_l0002Jooooo`00POooool00ol0003oooooooooo`1:ooooo`;o0000V?oo
ool0087ooooo00?o0000ooooooooool0C?ooool3o`0009Gooooo0021ooooo`03o`000?oooooooooo
04oooooo0_l0002Cooooo`00POooool00ol0003oooooooooo`1Aooooo`;o0000TOooool0087ooooo
0ol0001Cooooo`?o0000S_ooool0087ooooo00?o0000ooooooooool0E_ooool2o`0008cooooo0021
ooooo`03o`000?oooooooooo05Sooooo0_l0002:ooooo`00POooool00ol0003oooooooooo`1Joooo
o`;o0000R?ooool0087ooooo00?o0000ooooooooool0G?ooool2o`0008Kooooo0021ooooo`03o`00
0?oooooooooo05kooooo0ol00023ooooo`00POooool00ol0003oooooooooo`1Qooooo`;o0000POoo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0Hoooool2o`0007oooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo06Gooooo0_l0001mooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Oooooo0ol0001joooo
o`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000J_ooool2o`0007Sooooo001Vooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0K?ooool2o`0007Kooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo06kooooo0ol0001cooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1aooooo`;o0000LOooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
Loooool2o`0006oooooo0021ooooo`03o`000?oooooooooo07Gooooo0_l0001]ooooo`00POooool0
0ol0003oooooooooo`1gooooo`?o0000J_ooool0087ooooo00?o0000ooooooooool0N_ooool2o`00
06Sooooo0021ooooo`03o`000?oooooooooo07cooooo0_l0001Vooooo`00POooool00ol0003ooooo
ooooo`1nooooo`;o0000I?ooool0087ooooo0ol00020ooooo`;o0000H_ooool0087ooooo00?o0000
ooooooooool0P_ooool2o`00063ooooo0021ooooo`03o`000?oooooooooo08Cooooo0ol0001Moooo
o`00POooool00ol0003oooooooooo`27ooooo`;o0000Foooool0087ooooo00?o0000ooooooooool0
ROooool2o`0005Wooooo0021ooooo`03o`000?oooooooooo08_ooooo0_l0001Gooooo`00POooool0
0ol0003oooooooooo`2=ooooo`;o0000EOooool0087ooooo00?o0000ooooooooool0Soooool2o`00
05?ooooo0021ooooo`03o`000?oooooooooo097ooooo0ol0001@ooooo`00POooool00ol0003ooooo
ooooo`2Dooooo`;o0000C_ooool0087ooooo0ol0002Fooooo`;o0000C?ooool0087ooooo00?o0000
ooooooooool0V?ooool2o`0004[ooooo0021ooooo`03o`000?oooooooooo09[ooooo0_l00018oooo
o`00POooool00ol0003oooooooooo`2Looooo`;o0000A_ooool0087ooooo00?o0000ooooooooool0
W_ooool3o`0004?ooooo0021ooooo`03o`000?oooooooooo0:7ooooo0_l00011ooooo`00POooool0
0ol0003oooooooooo`2Sooooo`;o0000?oooool0087ooooo00?o0000ooooooooool0YOooool2o`00
03gooooo0021ooooo`03o`000?oooooooooo0:Oooooo0ol0000jooooo`00POooool00ol0003ooooo
ooooo`2Zooooo`?o0000=oooool0087ooooo0ol0002]ooooo`;o0000=Oooool0087ooooo00?o0000
ooooooooool0[oooool3o`0003;ooooo0021ooooo`03o`000?oooooooooo0;;ooooo0_l0000`oooo
o`00POooool00ol0003oooooooooo`2dooooo`;o0000;_ooool0087ooooo00?o0000ooooooooool0
]_ooool2o`0002cooooo0021ooooo`03o`000?oooooooooo0;Sooooo0ol0000Yooooo`00POooool0
0ol0003oooooooooo`2kooooo`;o00009oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0_Ooo
ool2o`0002Gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;oooooo0_l0000Sooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo0<7ooooo0ol0000Pooooo`00I_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000a?ooool2o`0001kooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0a_ooool2o`0001cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0b?ooool3o`0001Wooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo001g
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0>Cooooo001iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0i?ooool007Wooooo00?o0000ooooooooool01Oooool3o`000>Cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001ioooo
o`03o`000?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .13825 m
.06244 .14767 L
.10458 .1584 L
.14415 .16892 L
.18221 .17943 L
.22272 .19104 L
.26171 .20261 L
.30316 .21532 L
.34309 .22794 L
.3815 .24043 L
.42237 .25406 L
.46172 .26749 L
.49955 .28067 L
.53984 .29495 L
.57861 .30892 L
.61984 .32396 L
.65954 .33859 L
.69774 .35278 L
.73838 .36794 L
.77751 .38255 L
.81909 .39806 L
.85916 .41292 L
.89771 .4271 L
.93871 .442 L
.97619 .45541 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000i?ooool006Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0i?ooool006Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?oo
ool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3Tooooo`006_ooool3o`0004Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00
7Oooool5o`0005oooooo00?o0000ooooooooool0i?ooool002;ooooo1?l0001Kooooo`03o`000?oo
oooooooo0>Cooooo000Vooooo`Co0000Eoooool00ol0003oooooooooo`3Tooooo`00:_ooool3o`00
05Cooooo00?o0000ooooooooool0i?ooool002gooooo1?l0001@ooooo`03o`000?oooooooooo0>Co
oooo000aooooo`?o0000COooool3o`000>Cooooo000dooooo`Co0000BOooool00ol0003ooooooooo
o`3Tooooo`00>?ooool4o`0004Gooooo00?o0000ooooooooool0i?ooool003cooooo1?l00011oooo
o`03o`000?oooooooooo0>Cooooo0010ooooo`Co0000?Oooool00ol0003oooooooooo`3Tooooo`00
A?ooool3o`0003[ooooo00?o0000ooooooooool0i?ooool004Oooooo0ol0000gooooo`03o`000?oo
oooooooo0>Cooooo001:ooooo`?o0000=?ooool00ol0003oooooooooo`3Tooooo`00COooool4o`00
033ooooo00?o0000ooooooooool0i?ooool0057ooooo1Ol0000[ooooo`03o`000?oooooooooo0>Co
oooo001Fooooo`Co00009oooool3o`000>Cooooo001Jooooo`Co00008oooool00ol0003ooooooooo
o`3Tooooo`00G_ooool3o`00023ooooo00?o0000ooooooooool0i?ooool0067ooooo0ol0000Moooo
o`03o`000?oooooooooo0>Cooooo001Tooooo`?o00006_ooool00ol0003oooooooooo`3Tooooo`00
Ioooool3o`0001Oooooo00?o0000ooooooooool0i?ooool006[ooooo0ol0000Dooooo`03o`000?oo
oooooooo0>Cooooo001]ooooo`Co00004?ooool00ol0003oooooooooo`3Tooooo`00LOooool3o`00
00gooooo00?o0000ooooooooool0i?ooool007Cooooo1?l00009ooooo`03o`000?oooooooooo0>Co
oooo001hooooo`?o00001_ooool3o`000>Cooooo001kooooo`?o00000oooool00ol0003ooooooooo
o`3Tooooo`00O_ooool4o`000>Kooooo0021ooooo`Co0000hoooool0087ooooo00Co0000oooooooo
oooooooo0ol0003Pooooo`00POooool00ol0003oooooooooo`04ooooo`?o0000gOooool0087ooooo
00?o0000ooooooooool01oooool3o`000=[ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
0_l0003Hooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool3o`000=Gooooo001Vooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool03oooool3o`000=;ooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o
00004_ooool3o`000<oooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo01Gooooo0ol0003<ooooo`00I_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Hoooo
o`?o0000bOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool06oooool3o`000<Kooooo001Vooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo01kooooo0ol00033oooo
o`00POooool00ol0003oooooooooo`0Qooooo`?o0000`?ooool0087ooooo00?o0000ooooooooool0
9?ooool3o`000;gooooo0021ooooo`03o`000?oooooooooo02Oooooo0ol0002jooooo`00POooool0
0ol0003oooooooooo`0Zooooo`?o0000]oooool0087ooooo00?o0000ooooooooool0;Oooool3o`00
0;Cooooo0021ooooo`?o0000<?ooool3o`000;7ooooo0021ooooo`03o`000?oooooooooo03?ooooo
0ol0002^ooooo`00POooool00ol0003oooooooooo`0fooooo`?o0000Zoooool0087ooooo00?o0000
ooooooooool0>Oooool2o`000:Wooooo0021ooooo`03o`000?oooooooooo03_ooooo0ol0002Voooo
o`00POooool00ol0003oooooooooo`0nooooo`;o0000Y?ooool0087ooooo00?o0000ooooooooool0
@?ooool3o`000:7ooooo0021ooooo`03o`000?oooooooooo04?ooooo0_l0002Oooooo`00POooool0
0ol0003oooooooooo`15ooooo`;o0000WOooool0087ooooo00?o0000ooooooooool0Aoooool3o`00
09[ooooo0021ooooo`?o0000B_ooool3o`0009Oooooo0021ooooo`03o`000?oooooooooo04gooooo
0ol0002Dooooo`00POooool00ol0003oooooooooo`1@ooooo`Co0000T?ooool0087ooooo00?o0000
ooooooooool0E?ooool3o`0008gooooo0021ooooo`03o`000?oooooooooo05Oooooo0ol0002:oooo
o`00POooool00ol0003oooooooooo`1Jooooo`?o0000Qoooool0087ooooo00?o0000ooooooooool0
GOooool3o`0008Cooooo0021ooooo`03o`000?oooooooooo063ooooo0_l00022ooooo`00POooool0
0ol0003oooooooooo`1Rooooo`?o0000Ooooool0087ooooo00?o0000ooooooooool0IOooool2o`00
07gooooo0021ooooo`?o0000Ioooool3o`0007[ooooo0021ooooo`03o`000?oooooooooo06[ooooo
0_l0001hooooo`00POooool00ol0003oooooooooo`1/ooooo`;o0000M_ooool0087ooooo00?o0000
ooooooooool0K_ooool3o`0007?ooooo0021ooooo`03o`000?oooooooooo077ooooo0_l0001aoooo
o`00POooool00ol0003oooooooooo`1cooooo`?o0000K_ooool0087ooooo00?o0000ooooooooool0
M_ooool3o`0006_ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo07Wooooo0_l0001Yooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1kooooo`?o0000I_ooool006Kooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1n
ooooo`?o0000Hoooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`00087ooooo0ol0001Pooooo`00I_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo08Cooooo
0ol0001Mooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`27ooooo`?o0000F_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0R_ooool3o`0005Oooooo
001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo08gooooo0_l0001Eooooo`00POooool00ol0003oooooooooo`2?ooooo`;o0000
Doooool0087ooooo00?o0000ooooooooool0TOooool3o`00053ooooo0021ooooo`03o`000?oooooo
oooo09Cooooo0_l0001>ooooo`00POooool00ol0003oooooooooo`2Fooooo`;o0000C?ooool0087o
oooo00?o0000ooooooooool0V?ooool3o`0004Wooooo0021ooooo`?o0000Voooool3o`0004Kooooo
0021ooooo`03o`000?oooooooooo09kooooo0ol00013ooooo`00POooool00ol0003oooooooooo`2Q
ooooo`?o0000@?ooool0087ooooo00?o0000ooooooooool0Y?ooool3o`0003gooooo0021ooooo`03
o`000?oooooooooo0:Oooooo0ol0000jooooo`00POooool00ol0003oooooooooo`2Zooooo`?o0000
=oooool0087ooooo00?o0000ooooooooool0[Oooool2o`0003Gooooo0021ooooo`03o`000?oooooo
oooo0:oooooo0ol0000booooo`00POooool00ol0003oooooooooo`2booooo`;o0000<?ooool0087o
oooo00?o0000ooooooooool0]?ooool3o`0002gooooo0021ooooo`?o0000]oooool3o`0002[ooooo
0021ooooo`03o`000?oooooooooo0;[ooooo0_l0000Xooooo`00POooool00ol0003oooooooooo`2l
ooooo`?o00009Oooool0087ooooo00?o0000ooooooooool0_oooool3o`0002;ooooo0021ooooo`03
o`000?oooooooooo0<;ooooo0ol0000Oooooo`00POooool00ol0003oooooooooo`35ooooo`?o0000
7?ooool0087ooooo00?o0000ooooooooool0b?ooool3o`0001Wooooo0021ooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool05_ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003ooooooooo
o`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Toooo
o`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00I_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003T
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0i?ooool006Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`?o
0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool3o`000>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo001gooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0>Cooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wo
oooo00?o0000ooooooooool01Oooool3o`000>Cooooo001iooooo`03o`000?oooooooooo0>cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001goooo
o`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15243 m
.06244 .1606 L
.10458 .16983 L
.14415 .17878 L
.18221 .18765 L
.22272 .19737 L
.26171 .20698 L
.30316 .21747 L
.34309 .22784 L
.3815 .23804 L
.42237 .24912 L
.46172 .26 L
.49955 .27065 L
.53984 .28218 L
.57861 .29344 L
.61984 .30556 L
.65954 .31737 L
.69774 .32884 L
.73838 .34113 L
.77751 .35304 L
.81909 .36573 L
.85916 .37798 L
.89771 .38977 L
.93871 .40227 L
.97619 .41363 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000i?ooool006Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0i?ooool006Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?oo
ool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo000Jooooo`?o0000I?ooool00ol0003o
ooooooooo`3Tooooo`007Oooool5o`0005oooooo0ol0003Tooooo`008_ooool4o`0005_ooooo00?o
0000ooooooooool0i?ooool002Kooooo1?l0001Gooooo`03o`000?oooooooooo0>Cooooo000Zoooo
o`Go0000D_ooool00ol0003oooooooooo`3Tooooo`00;oooool5o`0004gooooo00?o0000oooooooo
ool0i?ooool003Cooooo1Ol00018ooooo`03o`000?oooooooooo0>Cooooo000iooooo`Ko0000@_oo
ool00ol0003oooooooooo`3Tooooo`00?oooool5o`0003gooooo00?o0000ooooooooool0i?ooool0
04Cooooo1Ol0000hooooo`03o`000?oooooooooo0>Cooooo0019ooooo`Co0000=?ooool00ol0003o
ooooooooo`3Tooooo`00COooool4o`00033ooooo0ol0003Tooooo`00DOooool5o`0002_ooooo00?o
0000ooooooooool0i?ooool005Kooooo1?l0000Wooooo`03o`000?oooooooooo0>Cooooo001Joooo
o`Co00008oooool00ol0003oooooooooo`3Tooooo`00G_ooool3o`00023ooooo00?o0000oooooooo
ool0i?ooool0067ooooo0ol0000Mooooo`03o`000?oooooooooo0>Cooooo001Tooooo`?o00006_oo
ool00ol0003oooooooooo`3Tooooo`00Ioooool3o`0001Oooooo00?o0000ooooooooool0i?ooool0
06[ooooo1Ol0000Booooo`03o`000?oooooooooo0>Cooooo001_ooooo`Go00003Oooool00ol0003o
ooooooooo`3Tooooo`00M?ooool4o`0000Wooooo0ol0003Tooooo`00N?ooool5o`0000Cooooo00?o
0000ooooooooool0i?ooool007gooooo1Ol0003Vooooo`00POooool4o`000>?ooooo0021ooooo`04
o`000?ooooooooooooooo`?o0000h?ooool0087ooooo00?o0000ooooooooool01?ooool3o`000=go
oooo0021ooooo`03o`000?oooooooooo00Oooooo0ol0003Jooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`?o0000eoooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo1Ol0003Booooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo
1Ol0003=ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool3o`0001Oooooo1?l00039ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Kooooo`?o0000a_ooool006Ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool07_ooool3o`000<?ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo027ooooo0ol00030ooooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0Toooo
o`?o0000_Oooool0087ooooo00?o0000ooooooooool09oooool5o`000;Sooooo0021ooooo`03o`00
0?oooooooooo02cooooo1?l0002dooooo`00POooool00ol0003oooooooooo`0`ooooo`Co0000/?oo
ool0087ooooo00?o0000ooooooooool0=?ooool3o`000:gooooo0021ooooo`03o`000?oooooooooo
03Oooooo0ol0002Zooooo`00POooool3o`0003[ooooo0ol0002Wooooo`00POooool00ol0003ooooo
ooooo`0mooooo`Co0000Xoooool0087ooooo00?o0000ooooooooool0@Oooool3o`000:3ooooo0021
ooooo`03o`000?oooooooooo04Cooooo0ol0002Mooooo`00POooool00ol0003oooooooooo`17oooo
o`?o0000V_ooool0087ooooo00?o0000ooooooooool0B_ooool3o`0009Oooooo0021ooooo`03o`00
0?oooooooooo04gooooo0ol0002Dooooo`00POooool00ol0003oooooooooo`1@ooooo`Co0000T?oo
ool0087ooooo00?o0000ooooooooool0E?ooool3o`0008gooooo0021ooooo`03o`000?oooooooooo
05Oooooo1?l00029ooooo`00POooool3o`0005_ooooo1Ol00024ooooo`00POooool00ol0003ooooo
ooooo`1Pooooo`Co0000P?ooool0087ooooo00?o0000ooooooooool0I?ooool4o`0007cooooo0021
ooooo`03o`000?oooooooooo06Sooooo0ol0001iooooo`00POooool00ol0003oooooooooo`1[oooo
o`?o0000M_ooool0087ooooo00?o0000ooooooooool0K_ooool3o`0007?ooooo0021ooooo`03o`00
0?oooooooooo077ooooo0ol0001`ooooo`00POooool00ol0003oooooooooo`1dooooo`?o0000KOoo
ool0087ooooo00?o0000ooooooooool0Moooool3o`0006[ooooo0021ooooo`03o`000?oooooooooo
07[ooooo0ol0001Wooooo`00POooool3o`0007gooooo1?l0001Sooooo`00POooool00ol0003ooooo
ooooo`21ooooo`?o0000H?ooool0087ooooo00?o0000ooooooooool0Q?ooool3o`0005gooooo0021
ooooo`03o`000?oooooooooo08Oooooo0ol0001Jooooo`00POooool00ol0003oooooooooo`2:oooo
o`Co0000E_ooool0087ooooo00?o0000ooooooooool0S_ooool3o`0005?ooooo0021ooooo`03o`00
0?oooooooooo097ooooo0ol0001@ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Dooooo`?o
0000COooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Uoooool4o`0004Wooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0Voooool3o`0004Kooooo001Vooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002Nooooo`?o0000@oooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2Qooooo`?o0000@?ooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0Y?ooool4o`0003cooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0:Sooooo
0ol0000iooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`2[ooooo`?o0000=_ooool0087ooooo00?o0000ooooooooool0
[_ooool3o`0003?ooooo0021ooooo`03o`000?oooooooooo0;7ooooo1?l0000_ooooo`00POooool0
0ol0003oooooooooo`2eooooo`?o0000;?ooool0087ooooo00?o0000ooooooooool0^?ooool3o`00
02Wooooo0021ooooo`03o`000?oooooooooo0;_ooooo0ol0000Vooooo`00POooool3o`000;kooooo
1?l0000Rooooo`00POooool00ol0003oooooooooo`32ooooo`?o00007oooool0087ooooo00?o0000
ooooooooool0aOooool3o`0001cooooo0021ooooo`03o`000?oooooooooo0<Sooooo0ol0000Ioooo
o`00POooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Kooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000
ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooooooo
ool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003ooooooooo
o`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Toooo
o`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00I_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003T
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0i?ooool006Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`?o
0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool3o`000>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo001gooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0>Cooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wo
oooo00?o0000ooooooooool01Oooool3o`000>Cooooo001iooooo`03o`000?oooooooooo0>cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001goooo
o`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Although ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is constant along each characteristic (",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  "), the spreading of the characteristics results in a change in shape of \
the solution over time. The reader is invited to vary the parameters of the \
problem so as to investigate other solutions. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3: Mixing Dye ", "Section",
  CellTags->"c:8"],

Cell[TextData[{
  "Next, we consider a generalization of Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  to two  spatial dimensions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \(\(v\_x\)(x, y, 
              t)\) \[PartialD]f\/\[PartialD]x + \(\(v\_y\)(x, y, 
              t)\) \[PartialD]f\/\[PartialD]y = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->{"i:4", "(7.1.18)"}],

Cell[TextData[{
  "Here, the functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_y\)]],
  " provide the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " components of the velocity. Equation ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  describes the behavior of dye placed in a fluid that moves with flow \
velocity ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((v\_x, \ v\_y)\)}], 
        TraditionalForm]]],
  ". The density of the dye, ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y, t)\)]],
  ", is carried along with the fluid, and so follows "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.19)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  is merely an expression for this total time derivative, analogous to the \
one-dimensional total time derivative of Eq. ",
  ButtonBox["(7.1.7)",
    ButtonData:>{"Chapter7.nb", "(7.1.7)"},
    ButtonStyle->"Hyperlink"],
  " .  Equation ",
  ButtonBox["(7.1.19)",
    ButtonData:>{"Chapter7.nb", "(7.1.19)"},
    ButtonStyle->"Hyperlink"],
  "  implies that ",
  Cell[BoxData[
      \(TraditionalForm\`f = constant\)]],
  " along the characteristics.  This means that elements of the dye are \
carried along by the fluid without change in their density."
}], "Text"],

Cell[TextData[{
  "\t The characteristics for Eq. ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  are the coupled first-order ODEs, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ \(v\_x\)(
          x, y, t)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]y/\[DifferentialD]t\  = \ \(v\_y\
\)(x, y, t)\)\(,\)\)\)]]
}], "NumberedEquation",
  CellTags->"(7.1.20)"],

Cell[TextData[{
  "with initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`y = y\_o\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". For general functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_x\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_y\)]],
  ", these ODEs need not have an analytic solution and can even display \
chaotic behavior.  That is, the dye can be mixed chaotically if the fluid \
flow is sufficiently complex.  Thus, even though Eq. ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  is linear, it is not always be possible to find a closed-form analytic \
solution. "
}], "Text"],

Cell[TextData[{
  "\tBelow, we show some characteristics for  a fluid flow with\n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`v\_x\  = \ y\  + x\)]],
  ", \n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`v\_y = \ \(-y\)\  - \ \((x\^3 - 1)\)\ \((1 + 
                Cos\ t)\)\)]],
  "."
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  "Note that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\(\(\[CenterDot]\)\((v\_x, v\_y)\)\) = 0\)]],
  ",",
  "  so this flow is incompressible [see Eq. ",
  ButtonBox["(1.2.12)",
    ButtonData:>{"Chapter1.nb", "(1.2.12)"},
    ButtonStyle->"Hyperlink"],
  " ]. Therefore, the area of a patch of dye carried along by this particular \
flow will not change over time.  "
}], "Text"],

Cell[TextData[{
  "\tThe characteristics for the flow can be computed using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", for given initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_o, y\_o)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(c[x0_, 
          y0_]\  := \ \(c[x0, 
            y0]\  = {x[t], 
              y[t]} /. \(NDSolve[{\(x'\)[
                      t]\  \[Equal] \((y[t] + x[t])\), \ \(y'\)[
                      t]\  \[Equal] \ \(-y[
                          t]\) - \((x[t]^3 - 1)\) \((1 + \ Cos[t])\), 
                  x[0] \[Equal] x0, y[0] \[Equal] y0}, {x, y}, {t, 0, 
                  10}]\)[\([1]\)]\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.3"],

Cell[TextData[{
  "The characteristics can then be plotted in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane using ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", as shown in Cell ",
  ButtonBox["7.4",
    ButtonData:>"Cell 7.4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Table[
        ParametricPlot[Evaluate[c[x0, y0]], {t, 0, 10}, 
          DisplayFunction \[Rule] Identity], {x0, \(-2\), 2}, {y0, \(-2\), 
          2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[%, DisplayFunction -> $DisplayFunction, 
        PlotRange \[Rule] {{\(-30\), 30}, {\(-30\), 30}}, 
        AspectRatio \[Rule] 1];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0166667 0.5 0.0166667 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.16667 .4875 -9 -9 ]
[.16667 .4875 9 0 ]
[.33333 .4875 -9 -9 ]
[.33333 .4875 9 0 ]
[.66667 .4875 -6 -9 ]
[.66667 .4875 6 0 ]
[.83333 .4875 -6 -9 ]
[.83333 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -18 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -18 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -12 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -12 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-30)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-20)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-10)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(10)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(20)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(30)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-30)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-20)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-10)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(10)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(20)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(30)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.46667 .46667 m
.46517 .47487 L
.46376 .48439 L
.46271 .49316 L
.46178 .50316 L
.46131 .50945 L
.46096 .51535 L
.46069 .52104 L
.46048 .5271 L
.46036 .5325 L
.46031 .53753 L
.46032 .54299 L
.4604 .54876 L
.46057 .55457 L
.4608 .55981 L
.46113 .56535 L
.46157 .57096 L
.46208 .57602 L
.46263 .58049 L
.46383 .58803 L
.46521 .59438 L
.46665 .59924 L
.46839 .60351 L
.46931 .60525 L
.47037 .60686 L
.47148 .60819 L
.47208 .60878 L
.47273 .60931 L
.47331 .60971 L
.47395 .61007 L
.47509 .61053 L
.47622 .61079 L
.47686 .61085 L
.47745 .61086 L
.47856 .61076 L
.47973 .61052 L
.4804 .61033 L
.48102 .61012 L
.4824 .60955 L
.48492 .60822 L
.49075 .6043 L
.50147 .59654 L
.51168 .58962 L
.51684 .58568 L
.5217 .58102 L
.52673 .57447 L
.52936 .57006 L
.53212 .56443 L
.53477 .55779 L
.53751 .54931 L
Mistroke
.53976 .54071 L
.54196 .53042 L
.54388 .51918 L
.54538 .50821 L
.54664 .49662 L
.54756 .48537 L
.54793 .47964 L
.54826 .4735 L
.54849 .46772 L
.54865 .46251 L
.54876 .45646 L
.54878 .4531 L
.54878 .45003 L
.54873 .44451 L
.5486 .43883 L
.54841 .43362 L
.54812 .42825 L
.54778 .42344 L
.54741 .41926 L
.54635 .41047 L
.54571 .40656 L
.54495 .40267 L
.54352 .3971 L
.54208 .39304 L
.54123 .39118 L
.54027 .38947 L
.53942 .38825 L
.53845 .38715 L
.53753 .38636 L
.53665 .3858 L
.53571 .3854 L
.53468 .38516 L
.53371 .38511 L
.53278 .3852 L
.53193 .38539 L
.53101 .3857 L
.52994 .38619 L
.52896 .38674 L
.52673 .38832 L
.52266 .39207 L
.51344 .40274 L
.49535 .42374 L
.46156 .45691 L
.44457 .47457 L
.43717 .48124 L
.43322 .48421 L
.42897 .48684 L
.42675 .48797 L
.42428 .48904 L
.4198 .49047 L
Mistroke
.41755 .49097 L
.41508 .4914 L
.41269 .4917 L
.41046 .49192 L
.40506 .49237 L
.40354 .49252 L
.40189 .49272 L
.39887 .49324 L
.39736 .4936 L
.39571 .49409 L
.39425 .49463 L
.39269 .49532 L
.3897 .49707 L
.38693 .49929 L
.38388 .5026 L
.38102 .50675 L
.37849 .51151 L
.37581 .51797 L
.37303 .52677 L
.37029 .53844 L
.36818 .55053 L
.36715 .55791 L
.36617 .56637 L
.36541 .57427 L
.36468 .58354 L
.36411 .59266 L
.36368 .60143 L
.3633 .61243 L
.36305 .62487 L
.36297 .63702 L
.36304 .649 L
.36324 .66066 L
.36361 .67339 L
.36405 .68456 L
.36466 .69709 L
.36659 .72574 L
.3691 .7529 L
.37289 .78399 L
.37724 .81152 L
.38293 .8393 L
.38995 .865 L
.39349 .8752 L
.3975 .88498 L
.40121 .89248 L
.40526 .89924 L
.40905 .90433 L
.41332 .90879 L
.4173 .91185 L
.42109 .91388 L
.42518 .9152 L
Mistroke
.4297 .91571 L
.43402 .91537 L
.43806 .9144 L
.44172 .91304 L
.44577 .91105 L
.45404 .90571 L
.47281 .88929 L
.49044 .87171 L
.5093 .85326 L
.52994 .83317 L
.53936 .82261 L
.54935 .80885 L
.55863 .79195 L
.56682 .77182 L
.57507 .744 L
.58214 .71104 L
.58909 .66554 L
.59219 .63871 L
.59522 .60624 L
.59749 .57577 L
.59931 .54497 L
.60098 .50746 L
.60208 .47171 L
.60272 .43708 L
.60297 .40453 L
.60285 .36863 L
.60227 .33079 L
.60124 .29469 L
.59963 .2567 L
.5974 .21935 L
.59485 .18723 L
.58925 .13718 L
.58559 .11383 L
.58198 .09562 L
.57744 .07789 L
.573 .06496 L
.5679 .05431 L
.56525 .05026 L
.56229 .04675 L
.55721 .04291 L
.55165 .04131 L
.54633 .04181 L
.54141 .04368 L
.53649 .04661 L
.53123 .05063 L
.52174 .05943 L
.50026 .08191 L
.48128 .10167 L
.47093 .11346 L
.46134 .12679 L
Mistroke
.45038 .14773 L
.44472 .16237 L
.43883 .18168 L
.43365 .20321 L
.42898 .22747 L
.42106 .28428 L
.41715 .32373 L
.41358 .37103 L
.41109 .41543 L
.40998 .44064 L
.40899 .468 L
.40814 .49869 L
.40756 .52738 L
.40718 .55868 L
.40703 .59308 L
.40714 .62288 L
.40751 .65435 L
.40808 .68352 L
.40879 .70935 L
.41069 .75767 L
.41189 .78058 L
.4134 .80449 L
.4165 .84316 L
.41986 .87477 L
.42434 .90614 L
.42884 .92918 L
.43147 .93969 L
.43443 .94943 L
.4373 .95702 L
.44006 .96287 L
.44509 .97045 L
.45081 .97516 L
.4565 .97668 L
.45973 .97644 L
.46272 .97564 L
.46778 .97327 L
.47334 .96954 L
.4846 .9599 L
.50924 .93677 L
.52138 .92512 L
.53258 .91217 L
.54266 .89596 L
.54767 .88519 L
.5531 .87062 L
.55839 .85257 L
.56388 .82861 L
.56879 .80106 L
.573 .77126 L
.57742 .73135 L
.58156 .68209 L
Mistroke
.58482 .62965 L
.58717 .57775 L
.58829 .54418 L
.58911 .51243 L
.58976 .47688 L
.59014 .43887 L
.5901 .37491 L
.58969 .33921 L
.58906 .30666 L
.58827 .2775 L
.58718 .24698 L
.58464 .19538 L
.58151 .15079 L
.5781 .11505 L
.57394 .08273 L
.56885 .05452 L
.56613 .04318 L
.5631 .03296 L
.55737 .01934 L
.55169 .01151 L
.5464 .00805 L
.54019 .00756 L
.53425 .00973 L
.52872 .0134 L
.52361 .01777 L
.51205 .02949 L
.48809 .05514 L
.47543 .06953 L
.46848 .07897 L
.46194 .08985 L
.45575 .10284 L
.44914 .12086 L
.44331 .14169 L
.43813 .16555 L
.43304 .19549 L
.42876 .22761 L
.42427 .27085 L
.42058 .3175 L
.4173 .37327 L
.41593 .40336 L
.41467 .43764 L
.41308 .50089 L
.41237 .56144 L
.41231 .59832 L
.41251 .63285 L
.41357 .69561 L
.41453 .72907 L
.41565 .75862 L
.41712 .78928 L
.41895 .81957 L
Mistroke
.42225 .86127 L
.42646 .89955 L
.43093 .92866 L
.43544 .94978 L
.44018 .96547 L
.44466 .97567 L
.45002 .98329 L
.45519 .98703 L
.46095 .98805 L
.46711 .98645 L
.47241 .98352 L
.47825 .97918 L
.50358 .95606 L
.52564 .93461 L
.53198 .92675 L
.53796 .91765 L
.54335 .90745 L
.549 .89395 L
.55381 .87952 L
.55897 .86008 L
.56756 .8152 L
.57199 .78333 L
.57636 .74326 L
.58003 .70003 L
.58294 .65603 L
.58578 .59868 L
.58777 .54073 L
.58893 .48663 L
.58949 .42703 L
.58928 .36268 L
.58885 .33104 L
.58812 .29721 L
.58622 .2408 L
.58378 .19288 L
.58073 .1504 L
.57735 .11565 L
.57395 .08924 L
.56991 .06552 L
.56522 .04553 L
.55991 .03022 L
.55468 .02076 L
.54981 .01577 L
.54382 .01348 L
.54078 .01359 L
.53741 .0145 L
.53142 .01775 L
.5258 .02217 L
.49953 .04933 L
.48756 .062 L
.47488 .07629 L
Mistroke
.46412 .09142 L
.45806 .10239 L
.45246 .11494 L
.44175 .14833 L
.43604 .17342 L
.43108 .20109 L
.42637 .23431 L
.42169 .27656 L
.41744 .32711 L
.41417 .37944 L
.41172 .43363 L
.41007 .4873 L
.40917 .53664 L
.40882 .59025 L
.4092 .64758 L
.40969 .67556 L
.41045 .70534 L
.41234 .75488 L
.4147 .79688 L
.41749 .83306 L
.42104 .86705 L
.42481 .89385 L
.42862 .91417 L
.43265 .93027 L
.43647 .94159 L
.44107 .9512 L
.44553 .95723 L
.45054 .961 L
.45593 .96228 L
.46059 .96162 L
.46574 .95946 L
.47132 .95587 L
.47732 .95106 L
.48816 .94109 L
.51053 .91988 L
.5228 .908 L
.53429 .89486 L
.54656 .87552 L
.55296 .86175 L
.55969 .84328 L
.56561 .82254 L
.57101 .79886 L
.57604 .77142 L
.5803 .74286 L
.58777 .67537 L
.59117 .63285 L
.59385 .58984 L
.59584 .54791 L
.59724 .50813 L
.59827 .4638 L
Mistroke
.59878 .41698 L
.59868 .37058 L
.59836 .34528 L
.5979 .32281 L
.59658 .2812 L
.59483 .24472 L
.59223 .20646 L
.58932 .17539 L
.58565 .14628 L
.58125 .12107 L
.57758 .10551 L
.57333 .0921 L
.56866 .08178 L
.56415 .07519 L
.5598 .07131 L
.55577 .06947 L
.55106 .06906 L
.54655 .07005 L
.5416 .07238 L
.53633 .07594 L
.52685 .08421 L
.50541 .10631 L
.48545 .12673 L
.46652 .14691 L
.44969 .16998 L
.44034 .18719 L
.4319 .20694 L
.42302 .23359 L
.41542 .26281 L
.40736 .3028 L
.40062 .34632 L
.39448 .39864 L
.38998 .45036 L
.3881 .47827 L
.38642 .50913 L
.38574 .52468 L
.38512 .54125 L
.3843 .57076 L
.3839 .59784 L
.38382 .62205 L
.38407 .64753 L
.38469 .67309 L
.38552 .69385 L
.38652 .71206 L
.38786 .73056 L
.38957 .7487 L
.39316 .77597 L
.39523 .78752 L
.39765 .79855 L
.39987 .80673 L
Mistroke
.40235 .81421 L
.40476 .82009 L
.40708 .82468 L
.41015 .82937 L
.41195 .83152 L
.41362 .83314 L
.41527 .83444 L
.4171 .83556 L
.41904 .83641 L
.42091 .83693 L
.42429 .83721 L
.42792 .83672 L
.43106 .83572 L
.43455 .8341 L
.43862 .83164 L
.44237 .82893 L
.45087 .82163 L
.46628 .8061 L
.52374 .7483 L
.58316 .69885 L
.61326 .67885 L
.6279 .66968 L
.64164 .65995 L
.65604 .64626 L
.6636 .6364 L
.67152 .62294 L
.67822 .60798 L
.68429 .5905 L
.6906 .56662 L
.69685 .53444 L
.6999 .51395 L
.70251 .49279 L
.70528 .46478 L
.70744 .43665 L
.70915 .40729 L
.71041 .37743 L
.71135 .34363 L
.71168 .3236 L
.71185 .30458 L
.71184 .26994 L
.71146 .23625 L
.71059 .19802 L
.70912 .1559 L
.70696 .11088 L
.70432 .06794 L
Mfstroke
.70432 .06794 m
.69873 0 L
s
.46667 .48333 m
.46556 .49103 L
.46457 .49974 L
.46381 .50832 L
.46329 .51632 L
.46305 .52126 L
.46288 .52583 L
.46276 .53084 L
.46273 .53336 L
.46271 .53611 L
.46272 .54067 L
.4628 .5455 L
.46294 .54995 L
.46311 .55391 L
.46336 .55815 L
.46368 .5625 L
.46442 .56979 L
.46497 .5739 L
.46556 .57749 L
.46679 .58346 L
.46815 .58824 L
.46952 .59185 L
.47116 .59494 L
.47203 .59618 L
.47301 .59729 L
.47402 .59818 L
.47457 .59856 L
.47515 .5989 L
.47567 .59914 L
.47624 .59935 L
.47727 .59959 L
.47829 .59968 L
.47886 .59967 L
.47939 .59962 L
.48038 .59946 L
.48143 .59918 L
.48257 .59878 L
.48381 .59824 L
.48606 .59704 L
.49126 .59364 L
.51002 .58112 L
.51482 .57778 L
.51997 .57336 L
.52267 .57045 L
.52561 .5666 L
.52829 .56233 L
.53068 .55771 L
.53517 .54632 L
.53746 .53866 L
.53948 .53046 L
Mistroke
.54258 .51389 L
.54402 .50355 L
.54513 .49353 L
.54562 .48811 L
.54607 .48236 L
.54639 .47736 L
.54667 .47202 L
.5468 .46903 L
.5469 .46631 L
.54704 .46106 L
.54709 .45815 L
.54712 .45503 L
.54713 .45213 L
.54711 .44948 L
.54704 .44491 L
.54692 .44076 L
.54673 .43636 L
.54647 .43184 L
.54614 .42758 L
.54572 .42337 L
.54483 .41656 L
.54385 .41119 L
.54265 .40636 L
.54138 .40264 L
.54014 .39994 L
.53934 .3986 L
.53858 .39755 L
.53772 .39662 L
.53679 .39586 L
.53596 .39538 L
.53517 .39507 L
.53429 .39488 L
.53333 .39484 L
.53241 .39495 L
.53188 .39507 L
.53138 .39522 L
.53037 .39562 L
.52927 .39619 L
.52726 .39755 L
.52542 .3991 L
.51668 .40872 L
.5013 .42738 L
.4716 .45543 L
.45603 .46795 L
.44899 .47276 L
.44107 .47705 L
.43649 .47892 L
.43213 .48031 L
.4278 .48138 L
.42304 .48233 L
Mistroke
.41817 .48326 L
.4154 .48388 L
.41271 .4846 L
.40948 .48573 L
.40648 .48713 L
.40363 .48888 L
.4005 .49144 L
.3976 .49455 L
.39448 .49893 L
.39159 .50424 L
.38901 .51034 L
.38676 .51702 L
.38443 .52577 L
.3822 .53668 L
.38034 .54865 L
.37941 .55617 L
.37851 .56503 L
.37782 .57343 L
.3772 .58297 L
.37676 .59206 L
.3764 .60268 L
.3762 .61283 L
.37612 .62277 L
.37614 .62855 L
.37619 .63501 L
.3763 .64188 L
.37646 .64839 L
.37685 .66033 L
.37745 .67339 L
.37839 .68905 L
.37952 .70402 L
.3823 .73204 L
.38553 .75648 L
.38917 .7782 L
.39383 .80011 L
.39958 .82072 L
.40272 .82971 L
.40633 .83841 L
.40966 .84509 L
.41334 .85115 L
.41712 .85608 L
.42064 .85964 L
.42427 .86235 L
.42775 .86415 L
.43107 .8652 L
.43476 .86567 L
.43866 .86545 L
.44234 .86466 L
.44581 .86343 L
.449 .86194 L
Mistroke
.4562 .8575 L
.47251 .84367 L
.48797 .82839 L
.5202 .79727 L
.52872 .78878 L
.53787 .77839 L
.54629 .76655 L
.55418 .75215 L
.56111 .73543 L
.56837 .71193 L
.57454 .68479 L
.57977 .65398 L
.58275 .63178 L
.5853 .60876 L
.58933 .56051 L
.59112 .53073 L
.59242 .50185 L
.59346 .46885 L
.59382 .45183 L
.59408 .43293 L
.59421 .39731 L
.59389 .36439 L
.59356 .3474 L
.59306 .32888 L
.59239 .30991 L
.59163 .29252 L
.5899 .26203 L
.58796 .23586 L
.58544 .20946 L
.5824 .18457 L
.57956 .1661 L
.57625 .14896 L
.5732 .13632 L
.56971 .12485 L
.56541 .11423 L
.56117 .10687 L
.55692 .10197 L
.5529 .09925 L
.54846 .09801 L
.54363 .09838 L
.53902 .10008 L
.53478 .10255 L
.5298 .1063 L
.52435 .11119 L
.51443 .12127 L
.49328 .14372 L
.48293 .15459 L
.47344 .16542 L
.46431 .17805 L
.45483 .19578 L
Mistroke
.45001 .20765 L
.44562 .22084 L
.44067 .23928 L
.43619 .26019 L
.43267 .28036 L
.42909 .30537 L
.42359 .35705 L
.42097 .39069 L
.41865 .4295 L
.41708 .46482 L
.41582 .50558 L
.41537 .52729 L
.41504 .55128 L
.41488 .57646 L
.4149 .59986 L
.41535 .64134 L
.41641 .68417 L
.41727 .70738 L
.41841 .73149 L
.42099 .77197 L
.42408 .80677 L
.4274 .83437 L
.43091 .85648 L
.43446 .87356 L
.43862 .88845 L
.44106 .89515 L
.44334 .90028 L
.44805 .90797 L
.45078 .91092 L
.45335 .91284 L
.45813 .91457 L
.46329 .9143 L
.4678 .91267 L
.47277 .90977 L
.48285 .90171 L
.50094 .88493 L
.52074 .86644 L
.52644 .86026 L
.53182 .85346 L
.53668 .8461 L
.54179 .83662 L
.54622 .82648 L
.551 .81291 L
.55908 .78144 L
.56334 .75875 L
.56763 .72987 L
.57104 .70099 L
.57438 .6653 L
.57723 .6261 L
.57944 .58644 L
Mistroke
.58111 .54607 L
.58239 .50103 L
.58312 .45551 L
.58331 .41229 L
.58307 .37385 L
.58238 .33333 L
.58097 .28725 L
.57915 .24825 L
.57648 .2076 L
.57344 .17401 L
.57022 .14752 L
.56696 .12692 L
.56309 .10856 L
.55871 .09365 L
.55412 .08308 L
.55145 .07885 L
.54897 .07595 L
.54431 .07278 L
.53932 .07204 L
.53664 .07254 L
.53376 .07365 L
.52855 .07685 L
.52233 .08212 L
.51668 .08775 L
.49512 .11109 L
.48381 .12336 L
.47189 .13816 L
.4616 .15567 L
.45586 .16897 L
.45062 .18446 L
.44187 .22074 L
.43731 .2471 L
.43345 .27537 L
.42969 .31006 L
.42658 .34688 L
.42417 .38319 L
.42203 .42542 L
.42028 .47447 L
.41964 .49997 L
.41915 .52829 L
.41878 .5788 L
.41904 .62533 L
.41989 .67081 L
.42121 .71151 L
.42281 .74555 L
.42496 .77935 L
.42774 .81196 L
.43115 .8415 L
.43439 .86254 L
.43825 .88139 L
Mistroke
.4405 .88995 L
.44304 .89786 L
.44785 .90871 L
.45271 .91536 L
.45735 .91863 L
.46023 .91947 L
.46296 .91957 L
.46812 .91829 L
.47103 .91689 L
.47372 .91527 L
.47981 .91072 L
.49972 .89269 L
.51072 .88268 L
.52117 .87268 L
.53122 .86084 L
.53687 .85221 L
.54204 .84236 L
.55096 .81898 L
.55531 .80352 L
.55994 .78304 L
.56762 .73616 L
.57148 .70372 L
.57465 .6701 L
.57732 .63477 L
.57944 .59931 L
.58125 .56009 L
.58274 .51517 L
.58373 .46463 L
.58399 .4359 L
.58404 .40951 L
.58364 .36192 L
.58256 .31376 L
.58103 .27354 L
.57914 .23896 L
.57661 .20494 L
.57341 .1733 L
.56954 .14555 L
.56716 .13246 L
.56485 .12194 L
.56038 .10653 L
.55778 .09996 L
.55536 .09515 L
.55065 .08878 L
.54794 .08659 L
.54542 .08536 L
.54072 .0848 L
.53571 .08618 L
.53084 .08898 L
.52553 .09319 L
.51585 .10268 L
Mistroke
.49776 .12213 L
.47811 .14337 L
.46741 .15733 L
.45751 .17474 L
.44922 .19518 L
.44068 .22503 L
.43632 .24524 L
.43199 .26993 L
.4285 .29421 L
.42507 .32314 L
.4222 .35263 L
.41989 .38147 L
.41785 .4126 L
.41626 .44263 L
.41478 .479 L
.41366 .51937 L
.4131 .55525 L
.41294 .59294 L
.41327 .6318 L
.41418 .67226 L
.41556 .70802 L
.41726 .73856 L
.41932 .76607 L
.42147 .7884 L
.42428 .81103 L
.42719 .82923 L
.43066 .84585 L
.43457 .85973 L
.43809 .86885 L
.4421 .8762 L
.44657 .88141 L
.44913 .88323 L
.45149 .88429 L
.45613 .88491 L
.46057 .88403 L
.4644 .88238 L
.46865 .8798 L
.47727 .87295 L
.4928 .85827 L
.50962 .8423 L
.52804 .82423 L
.53797 .81219 L
.54711 .79793 L
.55567 .78023 L
.56446 .75558 L
.57259 .72441 L
.5796 .68812 L
.5852 .6498 L
.59036 .60278 L
.59479 .54583 L
Mistroke
.59666 .5119 L
.59797 .47974 L
.5985 .46228 L
.59888 .44579 L
.59928 .41528 L
.59932 .39855 L
.59925 .38335 L
.59906 .36705 L
.59871 .35022 L
.59792 .32574 L
.59673 .30105 L
.59529 .27955 L
.59373 .26148 L
.59174 .24336 L
.58929 .22588 L
.58644 .21023 L
.58356 .19799 L
.58055 .18804 L
.57718 .17962 L
.57418 .17403 L
.57078 .16943 L
.56882 .1675 L
.56701 .16611 L
.56489 .16494 L
.56285 .16421 L
.5592 .16377 L
.55711 .16395 L
.55516 .16436 L
.55131 .16579 L
.54766 .16777 L
.54081 .17275 L
.52537 .18746 L
.46948 .24397 L
.44011 .27594 L
.40996 .32037 L
.36212 .41537 L
.35097 .436 L
.34078 .45138 L
.33523 .45796 L
.32921 .46353 L
.32654 .46549 L
.3237 .46725 L
.31856 .46966 L
.31595 .47055 L
.31313 .4713 L
.31045 .47186 L
.308 .47226 L
.30253 .47297 L
.29936 .47338 L
.29641 .47385 L
Mistroke
.29386 .47438 L
.29114 .47513 L
.28839 .47614 L
.28534 .47765 L
.28269 .47936 L
.27984 .4817 L
.2747 .48758 L
.2717 .49225 L
.26846 .49856 L
.26565 .50533 L
.26272 .51396 L
.26017 .52308 L
.25744 .53486 L
.25297 .5605 L
.25052 .57944 L
.24848 .59927 L
.24653 .6239 L
.24566 .63765 L
.24484 .65327 L
.24371 .68183 L
.243 .71092 L
.24273 .72989 L
.24261 .74863 L
.24273 .78579 L
.24324 .81998 L
.24425 .85969 L
.24586 .90319 L
.2479 .94551 L
Mfstroke
.2479 .94551 m
.25138 1 L
s
.46667 .5 m
.46596 .5072 L
.46563 .51125 L
.46537 .51512 L
.46517 .51874 L
.46499 .5227 L
.46487 .52629 L
.4648 .52959 L
.46475 .53348 L
.46475 .53708 L
.4648 .54097 L
.46491 .54507 L
.46498 .54708 L
.46508 .54924 L
.4653 .55308 L
.46557 .55668 L
.46586 .55988 L
.46667 .56651 L
.4676 .57204 L
.46858 .57639 L
.46976 .5804 L
.4712 .58398 L
.47197 .58546 L
.47285 .58686 L
.47363 .58787 L
.47449 .58877 L
.47532 .58946 L
.47609 .58995 L
.47696 .59035 L
.47746 .59052 L
.47794 .59064 L
.47844 .59073 L
.47891 .59078 L
.47942 .5908 L
.47997 .59079 L
.48089 .59068 L
.48176 .5905 L
.48272 .59022 L
.48375 .58984 L
.48839 .58741 L
.4927 .58461 L
.50152 .57883 L
.50999 .57369 L
.51831 .56766 L
.52255 .56332 L
.52717 .55683 L
.53163 .54792 L
.534 .54169 L
.53605 .53518 L
.53784 .52843 L
Mistroke
.53962 .52033 L
.54236 .50389 L
.5435 .49463 L
.54447 .48432 L
.54483 .47954 L
.54514 .47449 L
.54535 .47016 L
.54552 .46555 L
.54564 .46113 L
.54569 .45716 L
.5457 .45326 L
.54567 .44965 L
.54559 .44557 L
.54546 .44192 L
.54527 .43806 L
.54501 .43416 L
.5447 .43052 L
.54437 .42737 L
.54347 .42095 L
.54252 .4161 L
.54137 .41183 L
.5407 .4099 L
.53996 .40809 L
.53852 .4055 L
.53759 .4043 L
.53668 .40343 L
.53585 .40284 L
.53537 .4026 L
.53492 .40241 L
.53409 .4022 L
.53328 .40212 L
.53255 .40216 L
.53175 .40231 L
.53087 .40258 L
.52993 .40299 L
.52821 .404 L
.52513 .40653 L
.52171 .41006 L
.50726 .42791 L
.49323 .44344 L
.48034 .45493 L
.46641 .46545 L
.4593 .46998 L
.45257 .47354 L
.44528 .47651 L
.43697 .47893 L
.43226 .48008 L
.42705 .48144 L
.42243 .48301 L
.41974 .48421 L
Mistroke
.41719 .48563 L
.41466 .48739 L
.41223 .48947 L
.40769 .49482 L
.40519 .49884 L
.40291 .50337 L
.40051 .50933 L
.39803 .51715 L
.39571 .5267 L
.39373 .53737 L
.39206 .54944 L
.39079 .56207 L
.3902 .56981 L
.38974 .57746 L
.38934 .5863 L
.38917 .59147 L
.38905 .59629 L
.38896 .60147 L
.38891 .60636 L
.3889 .61185 L
.38893 .6178 L
.38909 .62804 L
.38924 .63401 L
.38943 .63969 L
.38985 .64968 L
.39045 .66052 L
.39191 .68032 L
.39432 .70381 L
.39715 .72455 L
.40074 .74501 L
.40534 .76506 L
.41032 .78142 L
.4154 .79391 L
.42044 .80301 L
.42542 .80941 L
.42838 .81217 L
.43115 .81412 L
.4344 .81571 L
.43755 .8166 L
.44062 .81692 L
.44394 .8167 L
.4471 .81602 L
.44999 .81502 L
.45342 .81343 L
.45715 .81127 L
.46396 .80637 L
.52105 .75219 L
.53498 .73723 L
.54273 .7264 L
.54966 .71383 L
Mistroke
.55761 .69416 L
.5647 .66927 L
.57067 .6398 L
.57373 .62009 L
.57631 .59984 L
.57849 .5791 L
.58033 .55785 L
.58179 .53734 L
.5831 .51433 L
.58421 .48831 L
.58494 .46333 L
.58524 .44774 L
.58542 .43292 L
.58548 .40506 L
.58522 .38047 L
.58464 .35487 L
.5839 .33355 L
.58282 .31095 L
.58135 .28782 L
.57946 .26467 L
.57524 .228 L
.57223 .20932 L
.56919 .19454 L
.56559 .18111 L
.56151 .16995 L
.55781 .16274 L
.55421 .15789 L
.55211 .15588 L
.55015 .15451 L
.54798 .15347 L
.54567 .15287 L
.54192 .15287 L
.53788 .15401 L
.53403 .15598 L
.53051 .15838 L
.51368 .17451 L
.49785 .19162 L
.48115 .2095 L
.467 .228 L
.4591 .24257 L
.45193 .26083 L
.44811 .2734 L
.4441 .28953 L
.44072 .30606 L
.43734 .32624 L
.43424 .34897 L
.43167 .37195 L
.42949 .39581 L
.42747 .42303 L
.42552 .45741 L
Mistroke
.42417 .49087 L
.4236 .5101 L
.4232 .52831 L
.42291 .54848 L
.42276 .57019 L
.42278 .58891 L
.42295 .60909 L
.42325 .62791 L
.42365 .64498 L
.42473 .67621 L
.42631 .70732 L
.42807 .73289 L
.43036 .75818 L
.43312 .78138 L
.43599 .79987 L
.43891 .81455 L
.44174 .82565 L
.44518 .83595 L
.44856 .84334 L
.45239 .84909 L
.45656 .85283 L
.46019 .85438 L
.46425 .85462 L
.46866 .85349 L
.47115 .85235 L
.47344 .85104 L
.48212 .84453 L
.49757 .83054 L
.51447 .8153 L
.52223 .80769 L
.53047 .79772 L
.53744 .78641 L
.54497 .76919 L
.54892 .75719 L
.55249 .74395 L
.55657 .72529 L
.56008 .70531 L
.5665 .6549 L
.56948 .62173 L
.57186 .58707 L
.57356 .55494 L
.57494 .51905 L
.57578 .48734 L
.57631 .45176 L
.57643 .41346 L
.57601 .37297 L
.57512 .3362 L
.57389 .30441 L
.57201 .27051 L
.56949 .23828 L
Mistroke
.56669 .21193 L
.56382 .19162 L
.56011 .17204 L
.55787 .16304 L
.55574 .15599 L
.55166 .14593 L
.54954 .14217 L
.54716 .13898 L
.5449 .1368 L
.54273 .1354 L
.53861 .13431 L
.53411 .13502 L
.53155 .13613 L
.52917 .13752 L
.52082 .14444 L
.51195 .15373 L
.49596 .1714 L
.47921 .19021 L
.47051 .20224 L
.46596 .21005 L
.46116 .22001 L
.45681 .23108 L
.45295 .24303 L
.44578 .27264 L
.44249 .29059 L
.43922 .31226 L
.43401 .35817 L
.43155 .38749 L
.42957 .41713 L
.4278 .45176 L
.42699 .47184 L
.42638 .49085 L
.42559 .52538 L
.42519 .56339 L
.42525 .59664 L
.42574 .63116 L
.42662 .6637 L
.42782 .69257 L
.42917 .71675 L
.43092 .74077 L
.43335 .76633 L
.43587 .78653 L
.4391 .80616 L
.44241 .82117 L
.44567 .83213 L
.44882 .83994 L
.45241 .8462 L
.45633 .85049 L
.46035 .85272 L
.46265 .8532 L
Mistroke
.46476 .85321 L
.4689 .85225 L
.47287 .85036 L
.47749 .8473 L
.48179 .84389 L
.49159 .83515 L
.50965 .81878 L
.51854 .81053 L
.52674 .80173 L
.53614 .78829 L
.54102 .77895 L
.54608 .76675 L
.55397 .74064 L
.5582 .72167 L
.56193 .70093 L
.56528 .67811 L
.56853 .65075 L
.57105 .6246 L
.57343 .59402 L
.57554 .55895 L
.5771 .52424 L
.57779 .50357 L
.57836 .48152 L
.57871 .46256 L
.57894 .4418 L
.57897 .40444 L
.57855 .3714 L
.57815 .35369 L
.57757 .33506 L
.57616 .30311 L
.57445 .27571 L
.57225 .24968 L
.57008 .23007 L
.56743 .21135 L
.56443 .19515 L
.56136 .18262 L
.55846 .17361 L
.55515 .16602 L
.55144 .1602 L
.54931 .15793 L
.54736 .15643 L
.5435 .15484 L
.5398 .15476 L
.53628 .15573 L
.53254 .15765 L
.52933 .15986 L
.52581 .16276 L
.51056 .17829 L
.49489 .19517 L
.47792 .21344 L
Mistroke
.47018 .22304 L
.46204 .2354 L
.45522 .24868 L
.44791 .26729 L
.44004 .29479 L
.4359 .31364 L
.43233 .33318 L
.42644 .37489 L
.42387 .39848 L
.42141 .42601 L
.41951 .4523 L
.41803 .47798 L
.41735 .49246 L
.41672 .50829 L
.41589 .53609 L
.41545 .56258 L
.41534 .59015 L
.41553 .61303 L
.41605 .63722 L
.41695 .66184 L
.41809 .68313 L
.41965 .70461 L
.42165 .72514 L
.42386 .74241 L
.42617 .75652 L
.42845 .7676 L
.43102 .77751 L
.43351 .78511 L
.43637 .79185 L
.43907 .79664 L
.44165 .80005 L
.44479 .80289 L
.4477 .80447 L
.45113 .80525 L
.45441 .80508 L
.4577 .80419 L
.45959 .8034 L
.46136 .8025 L
.46883 .7974 L
.48232 .78512 L
.5129 .75551 L
.52691 .74216 L
.54218 .72527 L
.5564 .70437 L
.56911 .67848 L
.58084 .64559 L
.59041 .60966 L
.59981 .56266 L
.60676 .51581 L
.61174 .46974 L
Mistroke
.61369 .44525 L
.61495 .42403 L
.61543 .41331 L
.61574 .4037 L
.61593 .39556 L
.61602 .38722 L
.61603 .38313 L
.61601 .3788 L
.61595 .37447 L
.61587 .37059 L
.61565 .3641 L
.61549 .36069 L
.61532 .35773 L
.61499 .35305 L
.61457 .3485 L
.61368 .34146 L
.61305 .33784 L
.61241 .33489 L
.6111 .33049 L
.61039 .32876 L
.60959 .3273 L
.6089 .32633 L
.60811 .32554 L
.60724 .32499 L
.6063 .32473 L
.60539 .32477 L
.60455 .32503 L
.60359 .32555 L
.60269 .32624 L
.60099 .32801 L
.59918 .33047 L
.59724 .33365 L
.59091 .34694 L
.58492 .3619 L
.57936 .37574 L
.57712 .38067 L
.57484 .38488 L
.57377 .38652 L
.57276 .38783 L
.57187 .3888 L
.57089 .38967 L
.56985 .39036 L
.56927 .39064 L
.56873 .39084 L
.56821 .39099 L
.56774 .39107 L
.56721 .39113 L
.56665 .39114 L
.56608 .3911 L
.56575 .39106 L
Mistroke
.56545 .39101 L
.56486 .39089 L
.56429 .39074 L
.56299 .3903 L
.56151 .38968 L
Mfstroke
.46667 .51667 m
.46648 .52017 L
.46635 .52336 L
.46624 .52704 L
.46618 .5305 L
.46616 .53368 L
.46617 .53657 L
.46622 .53971 L
.46631 .54297 L
.46645 .54617 L
.46664 .54951 L
.46709 .55526 L
.46744 .55855 L
.46783 .56152 L
.46866 .56664 L
.46961 .57098 L
.47076 .57493 L
.47196 .57801 L
.47314 .58028 L
.47463 .58233 L
.4755 .58322 L
.47633 .58386 L
.47707 .58431 L
.47791 .58467 L
.47833 .58481 L
.47879 .58492 L
.47963 .58504 L
.48007 .58506 L
.48056 .58506 L
.48108 .58502 L
.48157 .58496 L
.48245 .58479 L
.48295 .58466 L
.48341 .58452 L
.48548 .5837 L
.48769 .58258 L
.49578 .57753 L
.5034 .57288 L
.51191 .5679 L
.51641 .56476 L
.52071 .56089 L
.52456 .55624 L
.52865 .54951 L
.53235 .54113 L
.53596 .5299 L
.53868 .51841 L
.54116 .50401 L
.54225 .49565 L
.54321 .48625 L
.54357 .48189 L
Mistroke
.5439 .47725 L
.54415 .47291 L
.54433 .46895 L
.54447 .4648 L
.54457 .46038 L
.54461 .45657 L
.54459 .45263 L
.54454 .44919 L
.54446 .44607 L
.54433 .44276 L
.54414 .43934 L
.54387 .43552 L
.54357 .43218 L
.54318 .42881 L
.5427 .42537 L
.54175 .42025 L
.54058 .41574 L
.53938 .41247 L
.53866 .41097 L
.53798 .40979 L
.53665 .40809 L
.53596 .40746 L
.53518 .40694 L
.53479 .40673 L
.53437 .40656 L
.53361 .40636 L
.53277 .40627 L
.53229 .40629 L
.53184 .40634 L
.53102 .40653 L
.53026 .40679 L
.52938 .40719 L
.52854 .40767 L
.52552 .40998 L
.52222 .41329 L
.50836 .43054 L
.49618 .44455 L
.48279 .45682 L
.46949 .46674 L
.45643 .47423 L
.44938 .47708 L
.44144 .47944 L
.43273 .4817 L
.4301 .48251 L
.42756 .48342 L
.42521 .48444 L
.42269 .48578 L
.42043 .48726 L
.41793 .48928 L
.41351 .49415 L
Mistroke
.41105 .49782 L
.40845 .50272 L
.40627 .50786 L
.40399 .51459 L
.40189 .5225 L
.40009 .53109 L
.39855 .54052 L
.39713 .55194 L
.39655 .55784 L
.396 .56459 L
.39558 .57085 L
.39522 .57778 L
.39496 .58432 L
.39476 .59178 L
.39465 .59881 L
.39461 .60557 L
.39468 .61469 L
.39476 .61941 L
.39488 .62469 L
.3952 .63419 L
.39562 .64326 L
.39626 .65408 L
.39699 .66407 L
.39917 .68659 L
.40149 .70456 L
.40459 .72327 L
.40843 .74123 L
.41252 .75605 L
.41702 .76858 L
.42165 .77825 L
.42607 .78506 L
.42867 .78812 L
.43113 .79043 L
.43382 .79239 L
.43639 .79375 L
.43925 .79473 L
.44238 .7952 L
.4457 .7951 L
.44889 .79449 L
.45178 .79354 L
.45495 .79211 L
.46164 .78801 L
.46893 .78225 L
.4822 .76982 L
.50702 .7457 L
.52118 .73247 L
.52892 .72456 L
.53611 .71592 L
.54272 .70606 L
.54863 .69481 L
Mistroke
.555 .67889 L
.56146 .65677 L
.56651 .63317 L
.57147 .60138 L
.57368 .58302 L
.5758 .56154 L
.57739 .5416 L
.57886 .51852 L
.58002 .49459 L
.58081 .47154 L
.5813 .44897 L
.58153 .42456 L
.58145 .40051 L
.58111 .37804 L
.58057 .35821 L
.57975 .33734 L
.57845 .31347 L
.57693 .29249 L
.57494 .27119 L
.57247 .25061 L
.56952 .23177 L
.56643 .21662 L
.56344 .20526 L
.55998 .19527 L
.55686 .18857 L
.55327 .18308 L
.55143 .18103 L
.54941 .17932 L
.5457 .17743 L
.54213 .17692 L
.53833 .17753 L
.53506 .17885 L
.53146 .18099 L
.52378 .18729 L
.51545 .19574 L
.50036 .2122 L
.48697 .22653 L
.47231 .24399 L
.46423 .25692 L
.45685 .27307 L
.45289 .28431 L
.44939 .29635 L
.44546 .31284 L
.44202 .3307 L
.43654 .36875 L
.43402 .39227 L
.43167 .41981 L
.42979 .44829 L
.42837 .47676 L
.4274 .50341 L
Mistroke
.42671 .53302 L
.42638 .56396 L
.42643 .59211 L
.42691 .62402 L
.42777 .65315 L
.4289 .67872 L
.43023 .70093 L
.43198 .72347 L
.43415 .74504 L
.43661 .76407 L
.43956 .78157 L
.44258 .79525 L
.44553 .80544 L
.44898 .81426 L
.451 .81818 L
.45292 .82117 L
.45498 .82369 L
.45689 .82544 L
.45911 .82689 L
.46124 .82772 L
.46496 .82811 L
.4671 .82781 L
.46911 .82724 L
.47319 .82536 L
.4776 .8225 L
.49295 .80934 L
.51106 .79315 L
.51906 .78572 L
.5279 .7758 L
.53178 .77035 L
.53594 .76338 L
.54333 .74684 L
.54732 .73484 L
.55139 .71958 L
.55817 .68453 L
.5614 .66169 L
.56453 .63381 L
.56712 .60433 L
.56913 .57506 L
.57103 .5381 L
.57186 .51626 L
.57247 .49563 L
.57288 .47733 L
.57318 .45701 L
.57333 .43573 L
.57332 .41587 L
.57295 .38118 L
.57254 .36207 L
.57204 .3448 L
.5708 .31464 L
Mistroke
.56905 .28499 L
.56695 .25877 L
.56464 .237 L
.56233 .21996 L
.5596 .20424 L
.55636 .19014 L
.55257 .17832 L
.55058 .17371 L
.54839 .16971 L
.54629 .16676 L
.54434 .16472 L
.54055 .16237 L
.53837 .16185 L
.53634 .16183 L
.53259 .16276 L
.52858 .16489 L
.52491 .16763 L
.52089 .17125 L
.51278 .17972 L
.49835 .19582 L
.4827 .21321 L
.47416 .22417 L
.46619 .23734 L
.45889 .25396 L
.45489 .26584 L
.45132 .27872 L
.44535 .30674 L
.44252 .32385 L
.43968 .34446 L
.43723 .36601 L
.43519 .38744 L
.43186 .4338 L
.43042 .46182 L
.42922 .49363 L
.42846 .52445 L
.42809 .5533 L
.42807 .58756 L
.42823 .60451 L
.42855 .62274 L
.42944 .65383 L
.43065 .68102 L
.43155 .69655 L
.43251 .71047 L
.43459 .73439 L
.43719 .75683 L
.4404 .77717 L
.44323 .79058 L
.44658 .80237 L
.44833 .80718 L
.45027 .81158 L
Mistroke
.45389 .81761 L
.45759 .82143 L
.4612 .82332 L
.46449 .82381 L
.46813 .82326 L
.472 .8217 L
.47568 .81953 L
.48258 .81422 L
.49815 .80017 L
.51271 .78714 L
.52636 .77336 L
.53339 .76386 L
.54083 .75032 L
.54498 .74048 L
.54883 .72941 L
.55571 .70331 L
.55901 .68699 L
.56231 .66726 L
.5676 .62563 L
.5701 .59927 L
.57215 .57261 L
.574 .54161 L
.5748 .52486 L
.57552 .50662 L
.57636 .47818 L
.57683 .45152 L
.577 .42002 L
.57679 .392 L
.5762 .3638 L
.57516 .33489 L
.57381 .30956 L
.57225 .28816 L
.5706 .27035 L
.56886 .25531 L
.56658 .23952 L
.56431 .22708 L
.56194 .21674 L
.55921 .20741 L
.55618 .19963 L
.55319 .19407 L
.55145 .19165 L
.54959 .18963 L
.5462 .18724 L
.54248 .18622 L
.54034 .18627 L
.53833 .18667 L
.53466 .18814 L
.53129 .19019 L
.52369 .19653 L
.49626 .22564 L
Mistroke
.4812 .24153 L
.47329 .25062 L
.46495 .26192 L
.45778 .27406 L
.45007 .29099 L
.44335 .31047 L
.43742 .33287 L
.43181 .36035 L
.42715 .38994 L
.42278 .42645 L
.41911 .46911 L
.41769 .49162 L
.41648 .51637 L
.41605 .52776 L
.41568 .53979 L
.41523 .56118 L
.41505 .58133 L
.41512 .59965 L
.41544 .61902 L
.41574 .6295 L
.41607 .63878 L
.41683 .6547 L
.41785 .67054 L
.41901 .68438 L
.42021 .69592 L
.4218 .70833 L
.4237 .72023 L
.4255 .72927 L
.42761 .73787 L
.42958 .74435 L
.43179 .75021 L
.43423 .75526 L
.43658 .75897 L
.439 .7618 L
.44134 .76374 L
.44347 .76493 L
.44583 .76566 L
.44858 .76588 L
.45111 .76556 L
.45407 .76466 L
.45691 .76334 L
.46198 .76011 L
.46755 .75562 L
.49196 .73157 L
.54154 .68403 L
.58708 .62367 L
.6103 .58385 L
.63013 .5531 L
.6397 .5422 L
.64452 .53801 L
Mistroke
.64984 .53441 L
.65525 .53177 L
.65832 .53067 L
.66115 .52987 L
.66675 .52874 L
.67217 .52794 L
.67734 .52712 L
.67999 .52657 L
.68295 .52576 L
.68549 .52486 L
.68824 .52359 L
.69085 .52204 L
.69326 .52027 L
.69875 .51464 L
.70184 .51023 L
.7047 .50516 L
.71034 .49149 L
.71338 .48148 L
.71604 .47067 L
.71973 .45137 L
.72335 .42496 L
.72496 .40942 L
.7265 .39093 L
.72776 .37172 L
.72871 .35263 L
.72946 .33229 L
.72996 .31213 L
.73029 .28858 L
.73035 .2619 L
.73012 .23497 L
.72963 .20839 L
.72895 .18358 L
.72795 .15586 L
.72458 .09003 L
.72197 .05147 L
.71905 .01516 L
Mfstroke
.71905 .01516 m
.71753 0 L
s
.46667 .53333 m
.46669 .5366 L
.46674 .53953 L
.46684 .54285 L
.46698 .54591 L
.46715 .54866 L
.46732 .55114 L
.46783 .55645 L
.46848 .56138 L
.46934 .56624 L
.47039 .57065 L
.4715 .57414 L
.47279 .57713 L
.47411 .57937 L
.47537 .5809 L
.47611 .58158 L
.47681 .58209 L
.47765 .58256 L
.47846 .58288 L
.47919 .58307 L
.48 .58319 L
.48043 .58321 L
.4809 .5832 L
.4814 .58317 L
.48186 .58311 L
.4827 .58295 L
.48361 .58271 L
.48559 .58196 L
.48745 .58106 L
.49175 .57855 L
.49984 .57354 L
.50801 .56892 L
.51216 .56648 L
.51603 .56382 L
.51972 .56065 L
.5236 .55625 L
.52743 .55035 L
.53145 .54175 L
.53523 .53037 L
.53713 .52283 L
.53871 .51528 L
.54002 .50772 L
.54125 .49904 L
.54221 .49048 L
.54291 .48249 L
.54345 .47427 L
.54366 .46976 L
.54381 .46553 L
.5439 .46168 L
.54394 .45818 L
Mistroke
.54394 .4544 L
.5439 .45049 L
.54385 .4483 L
.54379 .44632 L
.5436 .442 L
.54338 .43837 L
.54309 .43474 L
.54246 .42892 L
.54203 .42593 L
.54159 .42333 L
.5405 .41835 L
.53931 .41451 L
.53813 .41178 L
.53743 .41052 L
.53676 .40954 L
.53607 .40872 L
.5353 .40801 L
.53486 .40769 L
.53444 .40744 L
.53401 .40723 L
.53361 .40707 L
.53279 .40688 L
.53236 .40683 L
.53188 .40682 L
.53138 .40686 L
.53091 .40694 L
.53048 .40705 L
.53001 .40719 L
.52919 .40752 L
.52844 .40791 L
.52674 .40902 L
.52363 .41174 L
.5166 .41986 L
.50298 .43707 L
.4901 .45066 L
.47805 .46103 L
.4651 .47055 L
.45844 .47462 L
.45206 .47779 L
.44526 .48032 L
.44151 .48138 L
.43741 .48235 L
.42868 .48429 L
.42603 .48503 L
.42348 .4859 L
.42112 .48689 L
.41858 .48823 L
.41628 .48975 L
.41373 .49186 L
.40924 .49704 L
Mistroke
.40674 .501 L
.40412 .50629 L
.40173 .51245 L
.39965 .51921 L
.39785 .52649 L
.39609 .53547 L
.39439 .54687 L
.39306 .55898 L
.39251 .56547 L
.392 .5729 L
.39161 .5803 L
.39133 .58742 L
.39114 .59412 L
.39101 .60174 L
.39098 .60998 L
.39103 .61792 L
.39122 .6277 L
.39136 .63274 L
.39156 .63838 L
.39202 .64849 L
.39258 .65812 L
.3943 .68006 L
.39689 .70356 L
.39985 .72376 L
.40362 .74363 L
.40735 .759 L
.41193 .77373 L
.4169 .78582 L
.42178 .79454 L
.42461 .79842 L
.42776 .80185 L
.43083 .80438 L
.43371 .8061 L
.43643 .80719 L
.439 .8078 L
.44186 .80802 L
.44497 .80777 L
.44826 .80702 L
.45141 .80586 L
.45426 .80451 L
.45738 .80271 L
.47206 .7911 L
.48594 .77765 L
.5119 .75262 L
.52557 .73955 L
.53994 .72227 L
.54734 .70979 L
.55521 .69162 L
.56201 .66958 L
.56787 .64322 L
Mistroke
.5706 .62753 L
.57329 .60906 L
.5775 .57117 L
.57945 .54759 L
.58098 .52402 L
.58231 .49674 L
.5829 .48087 L
.58332 .46607 L
.5838 .4393 L
.58393 .41414 L
.58371 .38657 L
.58343 .3713 L
.58307 .35762 L
.58217 .3331 L
.58084 .30772 L
.57925 .28516 L
.57753 .26581 L
.57565 .24875 L
.57341 .23214 L
.56883 .20681 L
.56574 .19435 L
.56262 .18463 L
.5597 .17757 L
.5564 .17158 L
.55309 .16734 L
.54935 .16432 L
.54535 .16282 L
.54153 .16275 L
.53794 .16368 L
.53462 .16524 L
.53096 .1676 L
.52709 .17067 L
.49684 .20225 L
.48031 .22008 L
.47223 .23009 L
.46485 .24145 L
.45801 .25524 L
.451 .27455 L
.44436 .30033 L
.44083 .31837 L
.43773 .3377 L
.43516 .35699 L
.43292 .37711 L
.4293 .41944 L
.42766 .44546 L
.4264 .47087 L
.42534 .49992 L
.42458 .53179 L
.42422 .5649 L
.42421 .58371 L
Mistroke
.42432 .60115 L
.42458 .61937 L
.42493 .6357 L
.42547 .65413 L
.42611 .67107 L
.42756 .69966 L
.42924 .72413 L
.43142 .74852 L
.4341 .77131 L
.4371 .79068 L
.44065 .80784 L
.44425 .8206 L
.44774 .82955 L
.44982 .8336 L
.45179 .83668 L
.45398 .83936 L
.45637 .84148 L
.45891 .84294 L
.46134 .84368 L
.46354 .84387 L
.46594 .84363 L
.47004 .8423 L
.47391 .84023 L
.48276 .83356 L
.50074 .8173 L
.51756 .8021 L
.52498 .79435 L
.5292 .7891 L
.53314 .78336 L
.5411 .76812 L
.54508 .75793 L
.54927 .74465 L
.55344 .72805 L
.55761 .70699 L
.56099 .6856 L
.56432 .65931 L
.56715 .63101 L
.56942 .60262 L
.57136 .57177 L
.57285 .54079 L
.57414 .50294 L
.57489 .46693 L
.57519 .42699 L
.57514 .40695 L
.57492 .38515 L
.57416 .34906 L
.573 .31653 L
.57162 .28923 L
.56976 .26187 L
.56736 .23543 L
Mistroke
.56442 .21118 L
.56132 .1921 L
.55827 .17796 L
.55498 .16652 L
.55181 .15845 L
.54819 .15206 L
.54426 .14782 L
.54076 .14594 L
.53744 .14549 L
.53376 .1462 L
.52979 .14811 L
.52566 .15105 L
.52109 .15511 L
.51184 .16479 L
.49528 .18314 L
.47735 .20364 L
.47247 .21039 L
.46738 .21869 L
.46303 .22724 L
.45847 .23817 L
.45423 .25066 L
.45051 .26411 L
.44365 .29709 L
.44014 .31985 L
.43667 .34815 L
.43376 .37829 L
.43146 .40882 L
.42967 .43901 L
.42833 .46872 L
.42725 .50251 L
.42654 .53959 L
.42638 .55824 L
.42634 .57849 L
.42665 .61473 L
.42741 .64867 L
.42852 .67843 L
.4302 .70936 L
.43242 .73866 L
.43467 .76069 L
.43744 .78153 L
.44077 .80012 L
.44273 .80866 L
.44465 .81569 L
.4465 .82134 L
.44856 .82657 L
.45229 .83356 L
.45593 .83793 L
.46005 .84058 L
.46215 .84117 L
.46444 .84132 L
Mistroke
.4686 .84052 L
.47278 .83863 L
.47677 .83607 L
.48431 .83 L
.51381 .80333 L
.52194 .79544 L
.53059 .78513 L
.53867 .77196 L
.54583 .75556 L
.55299 .73236 L
.55686 .71584 L
.56029 .69798 L
.56656 .65447 L
.56961 .6257 L
.57204 .59693 L
.57385 .57033 L
.57544 .54059 L
.57678 .50666 L
.57763 .47451 L
.57806 .44451 L
.57815 .41653 L
.57791 .38645 L
.57725 .3552 L
.57609 .32368 L
.57463 .29653 L
.57262 .26956 L
.57004 .2443 L
.56691 .22191 L
.56361 .20468 L
.56041 .19235 L
.55853 .18667 L
.55672 .18211 L
.55337 .17564 L
.54956 .17085 L
.54575 .16823 L
.54357 .16753 L
.54156 .16732 L
.53796 .16785 L
.53399 .16952 L
.53022 .17192 L
.52672 .17471 L
.49358 .20933 L
.47742 .22673 L
.47037 .23544 L
.4627 .24682 L
.4559 .25955 L
.44971 .27427 L
.44343 .29349 L
.43709 .31891 L
.43079 .35293 L
Mistroke
.42562 .39105 L
.42176 .42963 L
.41995 .45299 L
.41854 .47511 L
.41739 .49754 L
.41647 .52141 L
.41583 .54541 L
.41547 .57139 L
.41545 .59347 L
.41571 .61631 L
.41622 .63696 L
.41691 .65482 L
.41807 .6762 L
.41942 .69433 L
.42117 .71239 L
.42332 .72929 L
.42541 .74211 L
.42753 .75255 L
.43002 .76232 L
.43286 .77093 L
.43593 .77788 L
.4389 .78275 L
.44066 .78493 L
.44227 .78653 L
.44416 .78796 L
.44596 .78894 L
.44758 .78953 L
.4493 .78988 L
.45241 .78989 L
.45416 .78958 L
.4558 .78912 L
.45761 .78843 L
.45955 .7875 L
.46659 .78286 L
.47329 .77716 L
.48587 .76494 L
.53414 .7182 L
.54737 .70291 L
.56136 .68218 L
.57407 .65731 L
.58499 .62977 L
.59539 .59681 L
.60531 .55787 L
.61902 .48838 L
.62832 .42876 L
.63101 .4112 L
.6329 .401 L
.63371 .39787 L
.6341 .39673 L
.63452 .39578 L
Mistroke
.63494 .39514 L
.63517 .39491 L
.63538 .39477 L
.6358 .3947 L
.6362 .39486 L
.63658 .39518 L
.63699 .39569 L
.63777 .39698 L
.63974 .4012 L
.64197 .40597 L
.64329 .40832 L
.64478 .4104 L
.64561 .41127 L
.64606 .41164 L
.64655 .41195 L
.647 .41217 L
.64742 .4123 L
.64825 .41235 L
.64909 .4121 L
.64957 .41181 L
.65001 .41144 L
.65082 .41049 L
.65122 .40986 L
.65167 .40906 L
.65312 .40543 L
.65391 .40267 L
.65461 .3996 L
.65581 .39262 L
.65642 .3879 L
.65692 .38308 L
.65733 .37816 L
.6577 .37246 L
.65804 .36559 L
.65828 .35869 L
.65842 .35174 L
.65849 .34482 L
.65849 .33672 L
.65837 .32749 L
.6581 .31616 L
.65771 .30503 L
.6571 .29213 L
.65625 .27773 L
.65429 .25209 L
.65131 .22228 L
.64791 .19511 L
.64341 .16596 L
.63306 .11653 L
Mfstroke
.48333 .46667 m
.48096 .47181 L
.47888 .47714 L
.47663 .48427 L
.47484 .49154 L
.47327 .49991 L
.47214 .50836 L
.47167 .51313 L
.47135 .51756 L
.47122 .51987 L
.47111 .52241 L
.47107 .52368 L
.47103 .52504 L
.47101 .52631 L
.47099 .52747 L
.47098 .52873 L
.47099 .52992 L
.47101 .5321 L
.47104 .5333 L
.47107 .5344 L
.47117 .53682 L
.47128 .53871 L
.47143 .54072 L
.47181 .54456 L
.47208 .54663 L
.47236 .54842 L
.47309 .55208 L
.47389 .55502 L
.47474 .55738 L
.47561 .55922 L
.4766 .5608 L
.47751 .56186 L
.47856 .56274 L
.47917 .5631 L
.47974 .56336 L
.48038 .56357 L
.4807 .56365 L
.48106 .56371 L
.48168 .56376 L
.48202 .56377 L
.48234 .56376 L
.48297 .5637 L
.48356 .5636 L
.48414 .56347 L
.48476 .56329 L
.4859 .56289 L
.48855 .56164 L
.49409 .55835 L
.50466 .5522 L
.51086 .54881 L
Mistroke
.51425 .54675 L
.51793 .54413 L
.52152 .541 L
.52477 .53748 L
.53096 .52822 L
.53393 .52222 L
.53686 .51493 L
.5414 .49992 L
.54344 .49091 L
.545 .48245 L
.54631 .47346 L
.54682 .46903 L
.54724 .46456 L
.54751 .46091 L
.54761 .45907 L
.5477 .45717 L
.54775 .45551 L
.54779 .45406 L
.5478 .45272 L
.5478 .45139 L
.54779 .45065 L
.54778 .45 L
.54776 .44928 L
.54773 .44861 L
.54768 .44749 L
.5476 .44635 L
.5475 .44518 L
.54737 .44406 L
.54723 .4431 L
.54709 .44231 L
.54681 .44107 L
.54665 .44052 L
.54646 .44 L
.54628 .43958 L
.54611 .43925 L
.54594 .43897 L
.54575 .43873 L
.54554 .43851 L
.54534 .43836 L
.54523 .4383 L
.5451 .43824 L
.54488 .43818 L
.54476 .43817 L
.54464 .43817 L
.54441 .43821 L
.54427 .43826 L
.54414 .43831 L
.54389 .43845 L
.54344 .4388 L
.54303 .43923 L
Mistroke
.54209 .44057 L
.5412 .44223 L
.54031 .44431 L
.53889 .44852 L
.53786 .45258 L
.53742 .45477 L
.53706 .45706 L
.53692 .45815 L
.53681 .45915 L
.53673 .46003 L
.53666 .46097 L
.53663 .4615 L
.53661 .46199 L
.5366 .4625 L
.53659 .46278 L
.53659 .46303 L
.53659 .46348 L
.53659 .46396 L
.5366 .46441 L
.53661 .46481 L
.53664 .46527 L
.53666 .46569 L
.53675 .46661 L
.53685 .46746 L
.537 .46833 L
.53714 .46901 L
.53732 .46968 L
.5377 .47075 L
.53796 .47132 L
.53823 .47178 L
.53849 .47213 L
.53879 .47243 L
.53893 .47255 L
.53909 .47266 L
.53919 .47271 L
.53927 .47275 L
.53936 .47278 L
.53944 .47281 L
.53954 .47283 L
.53962 .47285 L
.53973 .47286 L
.53982 .47286 L
.53991 .47285 L
.54001 .47283 L
.54011 .47281 L
.54019 .47279 L
.54036 .47272 L
.54052 .47263 L
.54087 .47236 L
.54122 .47199 L
Mistroke
.54159 .47145 L
.54194 .47081 L
.5423 .46999 L
.5429 .4681 L
.54321 .46682 L
.54346 .46547 L
.5437 .46382 L
.54382 .46283 L
.54391 .46185 L
.54399 .4609 L
.54405 .46 L
.5441 .45897 L
.54412 .45839 L
.54414 .45783 L
.54416 .45679 L
.54416 .4558 L
.54415 .45469 L
.54414 .45412 L
.54413 .45348 L
.54409 .45236 L
.54404 .45131 L
.54388 .44889 L
.54367 .4466 L
.54341 .4444 L
.54269 .43992 L
.54161 .43511 L
.54015 .43051 L
.53937 .42862 L
.53848 .4268 L
.53765 .42539 L
.53668 .42404 L
.53574 .42299 L
.53485 .4222 L
.53375 .42147 L
.53312 .42117 L
.53252 .42095 L
.53196 .42081 L
.53143 .42072 L
.53084 .42068 L
.53021 .42069 L
.52958 .42076 L
.52889 .42091 L
.52823 .4211 L
.52761 .42133 L
.52644 .42191 L
.52517 .42269 L
.52224 .42511 L
.51958 .42792 L
.5098 .44155 L
.49979 .45752 L
Mistroke
.49166 .47032 L
.48467 .48297 L
.48167 .4905 L
.4802 .4953 L
.479 .50015 L
.47801 .50532 L
.47758 .50815 L
.4772 .51121 L
.47693 .51391 L
.47682 .51534 L
.47671 .51689 L
.47664 .51831 L
.47658 .5196 L
.47654 .52083 L
.47652 .52211 L
.47651 .52336 L
.47651 .52449 L
.47653 .52578 L
.47657 .52697 L
.47662 .52807 L
.47667 .52906 L
.47683 .53123 L
.47705 .53333 L
.47735 .53551 L
.47773 .53762 L
.47815 .53945 L
.47918 .54271 L
.47987 .54424 L
.48055 .54546 L
.48125 .54643 L
.48194 .54718 L
.4827 .54782 L
.48312 .5481 L
.48358 .54836 L
.48435 .54869 L
.48479 .54883 L
.4852 .54892 L
.48558 .54899 L
.48594 .54903 L
.48636 .54906 L
.48676 .54907 L
.48721 .54906 L
.48768 .54903 L
.48809 .54898 L
.48854 .54892 L
.48957 .54872 L
.49055 .54847 L
.49867 .54574 L
.50882 .54244 L
.51173 .54129 L
Mistroke
.51492 .53967 L
.51801 .53754 L
.52084 .53493 L
.52374 .53136 L
.5268 .52631 L
.52955 .52026 L
.53189 .51357 L
.534 .50581 L
.53592 .49655 L
.53735 .48722 L
.53785 .48301 L
.53829 .47853 L
.5385 .47603 L
.53869 .47329 L
.53884 .4708 L
.53894 .46855 L
.53903 .46595 L
.53906 .46461 L
.53909 .46322 L
.5391 .46092 L
.5391 .45965 L
.53908 .45848 L
.53904 .45628 L
.53896 .45427 L
.53887 .45254 L
.53875 .45073 L
.53859 .44885 L
.53839 .44697 L
.53796 .44388 L
.53744 .44113 L
.53686 .43888 L
.53629 .43717 L
.5356 .43561 L
.5348 .43429 L
.53433 .43371 L
.53389 .43328 L
.53347 .43295 L
.53301 .43267 L
.53256 .43249 L
.53214 .43238 L
.53174 .43232 L
.53131 .43232 L
.5309 .43236 L
.53052 .43244 L
.53007 .43257 L
.52958 .43277 L
.52868 .43325 L
.52773 .4339 L
.52671 .43475 L
.52488 .43659 L
Mistroke
.51058 .45642 L
.50357 .46555 L
.49739 .47207 L
.49093 .47738 L
.48442 .48146 L
.4693 .48934 L
.46734 .49073 L
Mfstroke
.48333 .48333 m
.48177 .48754 L
.48044 .49174 L
.47904 .49708 L
.47796 .50222 L
.47706 .50786 L
.47673 .51049 L
.47644 .5133 L
.4762 .51628 L
.47612 .5176 L
.47604 .51901 L
.47599 .5205 L
.47595 .52189 L
.47594 .52273 L
.47593 .52351 L
.47593 .52422 L
.47593 .52498 L
.47594 .52575 L
.47596 .52645 L
.47598 .52721 L
.47601 .52801 L
.47607 .52932 L
.47616 .53072 L
.47638 .53319 L
.47666 .53534 L
.47706 .53766 L
.47749 .53958 L
.47807 .54154 L
.47869 .54314 L
.47927 .54433 L
.47994 .5454 L
.48055 .54617 L
.48125 .54685 L
.48204 .54741 L
.48251 .54765 L
.48294 .54782 L
.48333 .54794 L
.48376 .54804 L
.48398 .54808 L
.48422 .54811 L
.48465 .54814 L
.48508 .54814 L
.48532 .54813 L
.48555 .54811 L
.48602 .54806 L
.48629 .54802 L
.48653 .54797 L
.48746 .54775 L
.48835 .54748 L
.49267 .5456 L
Mistroke
.50121 .54136 L
.51072 .53696 L
.51518 .5345 L
.52019 .53093 L
.52566 .5255 L
.53071 .51856 L
.53613 .50844 L
.5405 .49768 L
.54708 .47602 L
.54917 .46782 L
.55059 .46249 L
.55118 .46064 L
.55147 .45988 L
.55176 .45923 L
.55202 .45878 L
.55215 .45859 L
.55229 .45842 L
.55242 .45829 L
.55254 .4582 L
.55266 .45814 L
.55278 .4581 L
.55292 .45808 L
.55305 .45808 L
.5532 .45812 L
.55335 .45819 L
.55349 .45827 L
.55361 .45836 L
.55392 .45864 L
.55462 .45952 L
.55545 .46078 L
.55729 .46368 L
.55984 .46719 L
.56132 .46883 L
.56287 .47022 L
.56438 .47124 L
.56528 .47169 L
.56569 .47185 L
.56615 .47199 L
.56662 .47211 L
.56713 .47218 L
.5676 .47222 L
.56805 .47221 L
.56859 .47215 L
.56908 .47205 L
.56936 .47197 L
.56966 .47187 L
.57021 .47162 L
.57121 .47099 L
.57172 .47058 L
.57228 .47003 L
Mistroke
.57327 .46885 L
.5742 .46743 L
.57536 .46517 L
.57638 .46261 L
.57743 .45928 L
.57849 .45489 L
.57932 .4504 L
.58008 .44488 L
.58041 .44193 L
.58067 .43897 L
.5809 .43593 L
.58108 .43301 L
.58123 .42975 L
.58135 .4261 L
.58142 .42257 L
.58145 .41911 L
.58143 .41494 L
.58136 .41096 L
.58122 .40646 L
.58113 .40414 L
.58101 .40154 L
.58041 .39205 L
.57995 .38657 L
.57944 .38151 L
.57823 .37152 L
.57683 .36232 L
.57365 .3466 L
.57163 .33894 L
.56922 .33145 L
.56642 .32448 L
.56355 .31888 L
.5608 .31474 L
.55766 .31123 L
.55594 .30981 L
.55433 .30875 L
.55244 .30784 L
.55062 .30726 L
.54891 .30696 L
.5473 .30689 L
.54552 .30702 L
.54361 .3074 L
.5425 .30773 L
.54147 .30809 L
.53915 .30912 L
.53491 .31168 L
.52689 .31836 L
.49298 .35517 L
.47849 .37092 L
.47047 .38169 L
.46338 .39469 L
Mistroke
.45952 .40412 L
.45554 .41654 L
.45205 .43069 L
.44913 .44603 L
.44676 .46217 L
.44456 .48208 L
.44364 .49286 L
.44281 .50496 L
.44217 .5168 L
.44173 .5279 L
.4414 .54013 L
.44124 .55177 L
.44122 .56225 L
.44133 .57352 L
.44161 .58567 L
.44182 .5917 L
.4421 .59821 L
.44271 .60943 L
.44342 .61949 L
.44519 .63777 L
.44721 .65248 L
.44847 .65971 L
.44997 .66681 L
.45296 .67764 L
.45476 .68249 L
.45653 .68632 L
.45854 .68974 L
.45961 .69118 L
.46079 .69254 L
.4619 .69358 L
.46309 .69449 L
.46437 .69523 L
.46558 .69573 L
.46679 .69606 L
.46795 .69621 L
.47014 .69615 L
.47226 .6957 L
.47452 .69486 L
.47647 .69389 L
.47863 .69261 L
.48801 .68537 L
.50629 .66987 L
.51542 .66231 L
.52393 .65371 L
.52863 .64737 L
.53356 .63861 L
.53885 .62557 L
.54337 .60994 L
.54717 .59199 L
.55081 .56835 L
Mistroke
.55227 .55603 L
.55366 .54208 L
.55569 .51498 L
.5565 .49976 L
.55686 .49154 L
.55718 .4827 L
.5576 .46629 L
.5578 .45101 L
.55781 .43644 L
.55768 .42294 L
.55736 .40845 L
.55681 .39338 L
.55607 .37897 L
.55503 .36421 L
.55372 .35009 L
.5523 .33825 L
.54934 .32034 L
.54746 .31225 L
.54565 .30608 L
.54383 .30118 L
.54181 .29705 L
.54004 .29432 L
.53803 .29212 L
.53583 .29061 L
.53341 .28987 L
.53109 .28991 L
.52896 .29049 L
.5268 .29152 L
.52479 .29283 L
.52021 .29673 L
.5119 .30585 L
.49491 .3261 L
.48609 .33646 L
.47692 .34891 L
.47213 .35723 L
.46704 .36855 L
.46261 .38153 L
.45873 .39639 L
.45508 .41483 L
.45214 .43446 L
.4507 .44646 L
.4493 .46032 L
.44814 .4742 L
.44724 .48741 L
.44654 .50019 L
.44594 .51442 L
.4455 .52965 L
.44527 .54416 L
.44523 .55757 L
.44536 .57162 L
Mistroke
.44564 .58451 L
.44604 .59581 L
.44635 .60263 L
.44673 .60962 L
.44754 .62155 L
.44859 .63345 L
.44995 .64529 L
.45128 .65444 L
.45285 .6631 L
.45434 .6697 L
.45603 .67573 L
.45803 .68132 L
.45997 .68545 L
.46215 .68886 L
.46343 .69035 L
.46464 .69147 L
.46572 .69225 L
.46687 .69288 L
.46896 .69354 L
.47014 .69367 L
.47124 .69366 L
.47246 .69351 L
.47377 .6932 L
.47605 .69236 L
.47855 .69106 L
.48311 .68797 L
.49173 .68086 L
.5105 .66515 L
.51979 .65691 L
.52828 .64695 L
.53282 .63976 L
.53703 .63127 L
.54134 .62018 L
.54579 .60521 L
.54998 .58648 L
.55391 .5627 L
.55699 .53696 L
.5582 .52397 L
.55917 .51144 L
.56 .49853 L
.56062 .48659 L
.56115 .47322 L
.56153 .4589 L
.56171 .44527 L
.56174 .43768 L
.56171 .43076 L
.56153 .41834 L
.56117 .40566 L
.56073 .39542 L
.56012 .38496 L
Mistroke
.55942 .37566 L
.55868 .36769 L
.5577 .35905 L
.5565 .35049 L
.554 .33727 L
.55232 .33083 L
.55065 .32572 L
.54906 .32191 L
.54727 .31856 L
.54525 .31577 L
.5442 .31468 L
.54304 .31373 L
.54203 .31309 L
.54094 .31259 L
.53893 .31211 L
.5369 .31214 L
.53574 .31236 L
.53466 .31267 L
.53267 .31352 L
.53054 .31476 L
.52683 .31755 L
.52272 .32135 L
.48877 .35826 L
.47406 .37395 L
.46636 .38362 L
.45829 .39602 L
.45066 .41098 L
.44414 .42722 L
.43309 .46554 L
.42835 .48848 L
.42429 .51352 L
.42154 .53595 L
.4199 .55458 L
.41935 .56336 L
.41916 .56725 L
.41903 .57069 L
.41892 .57443 L
.41888 .57632 L
.41885 .57826 L
.41884 .58168 L
.41886 .58456 L
.41892 .58727 L
.419 .58958 L
.41913 .59193 L
.41929 .5942 L
.41945 .59599 L
.41963 .59753 L
.42008 .60052 L
.42037 .6019 L
.42071 .60317 L
Mistroke
.42105 .60417 L
.42138 .60493 L
.42169 .60548 L
.42204 .60595 L
.42241 .60629 L
.42277 .60649 L
.42318 .60656 L
.42338 .60655 L
.42361 .6065 L
.42401 .60632 L
.42439 .60606 L
.42484 .60563 L
.42525 .60514 L
.42615 .60375 L
.42764 .6006 L
.4291 .59655 L
.4313 .58839 L
.43298 .57972 L
.43362 .57531 L
.43402 .57173 L
.43426 .56896 L
.43433 .5677 L
.43436 .56718 L
.43438 .56675 L
.43439 .56638 L
.4344 .56605 L
.4344 .56579 L
.4344 .5656 L
.4344 .56545 L
.4344 .56534 L
.4344 .56531 L
.43439 .56529 L
.43439 .56532 L
.43439 .5654 L
.43438 .56554 L
.43438 .56576 L
.43439 .56589 L
.43439 .56606 L
.4344 .56639 L
.43441 .56681 L
.43445 .56776 L
.43452 .56899 L
.43462 .5704 L
.43492 .57366 L
.43502 .57463 L
Mfstroke
.48333 .5 m
.48258 .50329 L
.482 .5064 L
.48149 .50984 L
.48127 .51175 L
.48111 .51348 L
.48105 .51435 L
.48099 .51527 L
.48095 .51605 L
.48092 .51689 L
.48089 .51778 L
.48088 .5186 L
.48088 .51909 L
.48088 .51955 L
.48089 .51997 L
.48089 .52042 L
.48092 .52122 L
.48095 .52194 L
.48099 .52275 L
.48105 .5235 L
.48117 .52479 L
.48134 .52611 L
.48157 .52747 L
.48182 .52864 L
.48217 .52993 L
.48252 .53099 L
.48337 .53283 L
.48391 .53365 L
.48445 .53431 L
.48494 .53479 L
.48549 .5352 L
.48598 .5355 L
.48654 .53575 L
.48686 .53586 L
.48716 .53594 L
.4875 .53602 L
.48767 .53605 L
.48786 .53608 L
.48817 .53611 L
.48848 .53613 L
.48866 .53614 L
.48884 .53614 L
.48917 .53614 L
.48948 .53612 L
.48982 .5361 L
.49014 .53606 L
.49043 .53602 L
.49188 .53575 L
.49344 .53534 L
.49498 .53488 L
Mistroke
.50117 .53287 L
.505 .53163 L
.50887 .53029 L
.51288 .52861 L
.51676 .52651 L
.52113 .52334 L
.52593 .51857 L
.53063 .51228 L
.53531 .50418 L
.54759 .47491 L
.54869 .47243 L
.54982 .47025 L
.55084 .46869 L
.55133 .46811 L
.55178 .46767 L
.55229 .46728 L
.55257 .46712 L
.55287 .46698 L
.55317 .46688 L
.55332 .46685 L
.55349 .46682 L
.55364 .4668 L
.55379 .46679 L
.55407 .4668 L
.55436 .46683 L
.55452 .46686 L
.55467 .46689 L
.55495 .46697 L
.55526 .46708 L
.5558 .46733 L
.55641 .46768 L
.55944 .46997 L
.56295 .47282 L
.5647 .47406 L
.56671 .47524 L
.56783 .47575 L
.56843 .47598 L
.5691 .47619 L
.56973 .47635 L
.57031 .47645 L
.57087 .47652 L
.57147 .47655 L
.57211 .47654 L
.57271 .47647 L
.57326 .47636 L
.57387 .4762 L
.57453 .47595 L
.57524 .47561 L
.57651 .47475 L
.5777 .47366 L
Mistroke
.57881 .47233 L
.58001 .47051 L
.58129 .46806 L
.58261 .46481 L
.58399 .46045 L
.58519 .45546 L
.58619 .45003 L
.58706 .44383 L
.58772 .43749 L
.58803 .43368 L
.5883 .42931 L
.58851 .42497 L
.58865 .42078 L
.58875 .41603 L
.58878 .41134 L
.58875 .40699 L
.58867 .40212 L
.58851 .39666 L
.5884 .39384 L
.58826 .3907 L
.58757 .37965 L
.58666 .36907 L
.58537 .35756 L
.58219 .33712 L
.57988 .32612 L
.57697 .315 L
.57351 .30471 L
.56994 .29659 L
.56629 .29039 L
.56277 .28603 L
.56075 .28415 L
.5585 .28254 L
.55632 .28142 L
.55428 .28073 L
.55209 .28034 L
.54998 .28028 L
.54806 .28048 L
.54596 .28095 L
.54365 .28175 L
.54118 .28289 L
.53669 .28565 L
.52776 .29313 L
.51965 .30139 L
.49954 .3234 L
.48121 .34265 L
.47225 .3533 L
.46404 .36598 L
.46001 .37406 L
.45583 .38442 L
.45141 .39844 L
Mistroke
.44766 .41388 L
.444 .43376 L
.44107 .45514 L
.43845 .48181 L
.4374 .49639 L
.43648 .51318 L
.43589 .52836 L
.43552 .54253 L
.4354 .55043 L
.43532 .55909 L
.43535 .57486 L
.43558 .58942 L
.43603 .60465 L
.43666 .61861 L
.43738 .63081 L
.43936 .65429 L
.44075 .66635 L
.44221 .67669 L
.4456 .69457 L
.44772 .70281 L
.44979 .70919 L
.45166 .71386 L
.45373 .71799 L
.45608 .72157 L
.45832 .72405 L
.46045 .72569 L
.46249 .72669 L
.46475 .72726 L
.46723 .72729 L
.46992 .72676 L
.47244 .72581 L
.47524 .72436 L
.47823 .72241 L
.49004 .71263 L
.51136 .69411 L
.52212 .68406 L
.52753 .67755 L
.53343 .66826 L
.53645 .66219 L
.53964 .65449 L
.54252 .64611 L
.54517 .63689 L
.54766 .62656 L
.55024 .61375 L
.55433 .58717 L
.55626 .57071 L
.55788 .55389 L
.55916 .53758 L
.56031 .51944 L
.56081 .50966 L
Mistroke
.5613 .49872 L
.56196 .47906 L
.56222 .46781 L
.56241 .45568 L
.5625 .44422 L
.56251 .43381 L
.56233 .41396 L
.56194 .39606 L
.56125 .37713 L
.56081 .36793 L
.56025 .35813 L
.55914 .34258 L
.55772 .32717 L
.55463 .30322 L
.55266 .29227 L
.55074 .28375 L
.54837 .27559 L
.54601 .26946 L
.54373 .26506 L
.54157 .26203 L
.53913 .25973 L
.53649 .25837 L
.53379 .25798 L
.53226 .25814 L
.53085 .2585 L
.5281 .2597 L
.52548 .26138 L
.51959 .26653 L
.51317 .27346 L
.4909 .29923 L
.47921 .31349 L
.47273 .32347 L
.46692 .33515 L
.4621 .34796 L
.45709 .36575 L
.45232 .38927 L
.44842 .41608 L
.44673 .43104 L
.44531 .44615 L
.44312 .47667 L
.44219 .49477 L
.44154 .51192 L
.44105 .53104 L
.4409 .54073 L
.4408 .55139 L
.44078 .56161 L
.44084 .57267 L
.44098 .58297 L
.44117 .59238 L
.44171 .60962 L
Mistroke
.44253 .62707 L
.4431 .63645 L
.4438 .64614 L
.44529 .66241 L
.44698 .67652 L
.44873 .68792 L
.45042 .69676 L
.45237 .7049 L
.45465 .71229 L
.45688 .71781 L
.45813 .72025 L
.45951 .72252 L
.46075 .7242 L
.46209 .72568 L
.46467 .72765 L
.4671 .72863 L
.46946 .7289 L
.47207 .72857 L
.47482 .72764 L
.4774 .72634 L
.48205 .72325 L
.48706 .71925 L
.5091 .70042 L
.51998 .69067 L
.52533 .68474 L
.53023 .67798 L
.53464 .6703 L
.5392 .66014 L
.54362 .64737 L
.54822 .62986 L
.55266 .60712 L
.55479 .59328 L
.55687 .57719 L
.55867 .56049 L
.5601 .54443 L
.56136 .5273 L
.56233 .51099 L
.5631 .49457 L
.56371 .47699 L
.56411 .45923 L
.5643 .43988 L
.56425 .4234 L
.56398 .40622 L
.56353 .39062 L
.56296 .37704 L
.56202 .361 L
.56078 .34533 L
.55954 .33317 L
.55799 .32112 L
.55613 .30982 L
Mistroke
.55392 .29955 L
.55167 .2916 L
.54949 .28575 L
.54721 .28118 L
.54501 .27801 L
.54254 .2756 L
.54112 .2747 L
.53983 .27414 L
.53742 .27369 L
.53604 .27374 L
.53477 .27396 L
.53241 .27475 L
.52991 .27607 L
.52742 .27777 L
.52471 .27998 L
.51977 .28473 L
.51051 .29487 L
.48989 .31759 L
.48072 .32759 L
.4709 .33992 L
.46183 .35494 L
.45387 .3733 L
.45 .38488 L
.44598 .39937 L
.43883 .43444 L
.43562 .45626 L
.43279 .48129 L
.43166 .49388 L
.43074 .50593 L
.42999 .51764 L
.42942 .5286 L
.42896 .54004 L
.42877 .54606 L
.42861 .55247 L
.42849 .55909 L
.42842 .56529 L
.42841 .57665 L
.42854 .58687 L
.42878 .59597 L
.42916 .60552 L
.4297 .61511 L
.43045 .62487 L
.43142 .63453 L
.4325 .64278 L
.43361 .64961 L
.436 .6606 L
.43733 .66518 L
.43887 .66949 L
.44029 .67268 L
.44186 .6755 L
Mistroke
.44364 .67797 L
.44534 .67971 L
.44696 .68089 L
.44851 .68164 L
.45024 .68211 L
.45123 .68222 L
.45214 .68224 L
.45373 .68206 L
.45523 .6817 L
.45688 .68111 L
.45866 .68026 L
.46233 .67797 L
.46568 .67536 L
.4967 .64404 L
.52769 .61583 L
.55714 .59229 L
.58752 .57399 L
.60417 .56674 L
.60872 .56463 L
.61374 .56197 L
.62303 .55536 L
.62785 .55052 L
.63297 .5438 L
.63772 .53552 L
.64192 .52599 L
.64592 .51425 L
.64998 .49853 L
.65349 .48036 L
.65635 .46049 L
.65761 .44954 L
.65882 .43693 L
.65976 .42526 L
.66064 .41179 L
.66149 .39489 L
.66209 .37786 L
.66247 .36032 L
.66263 .34334 L
.6626 .32471 L
.66235 .30661 L
.66185 .28611 L
.66102 .26343 L
.65982 .23922 L
.65836 .21588 L
.65473 .17196 L
.65431 .16768 L
Mfstroke
.48333 .51667 m
.48334 .51728 L
.48335 .51783 L
.48337 .51846 L
.48339 .51904 L
.48342 .51957 L
.48346 .52006 L
.48355 .52112 L
.48368 .52215 L
.48385 .52323 L
.48406 .52431 L
.48429 .52524 L
.48484 .52695 L
.4852 .52778 L
.48556 .5285 L
.48629 .52961 L
.48717 .53057 L
.48772 .53101 L
.48826 .53136 L
.48877 .53162 L
.48934 .53185 L
.48998 .53204 L
.49059 .53217 L
.49094 .53223 L
.49127 .53227 L
.49163 .5323 L
.49184 .53232 L
.49204 .53233 L
.49236 .53234 L
.49253 .53234 L
.49271 .53234 L
.49304 .53234 L
.49335 .53233 L
.49353 .53232 L
.49372 .53231 L
.49406 .53229 L
.49485 .53223 L
.49622 .53208 L
.49779 .53188 L
.50447 .53082 L
.50661 .5304 L
.50873 .52991 L
.51069 .52934 L
.51292 .52852 L
.51514 .52749 L
.51727 .52625 L
.51955 .52457 L
.52203 .52227 L
.52432 .51963 L
.52647 .51662 L
Mistroke
.53033 .50965 L
.5341 .50027 L
.53738 .48902 L
.53963 .47833 L
.54033 .47399 L
.54093 .46958 L
.54137 .46535 L
.54153 .46327 L
.54159 .46235 L
.54163 .46151 L
.54167 .46077 L
.54169 .46 L
.54171 .45933 L
.54172 .45875 L
.54172 .45815 L
.54171 .45753 L
.5417 .45692 L
.54168 .45639 L
.54165 .45588 L
.54161 .45537 L
.54156 .45489 L
.54151 .45448 L
.5414 .45386 L
.54134 .45356 L
.54127 .45333 L
.5412 .45311 L
.54111 .45292 L
.54107 .45284 L
.54102 .45276 L
.54097 .4527 L
.54092 .45265 L
.54083 .45258 L
.54078 .45256 L
.54074 .45255 L
.54065 .45254 L
.54056 .45257 L
.54047 .45262 L
.54039 .45269 L
.5403 .45279 L
.5402 .45292 L
.54005 .45319 L
.53988 .45355 L
.53971 .45403 L
.53953 .45462 L
.53925 .45586 L
.53912 .45661 L
.539 .45748 L
.53891 .45834 L
.53887 .45877 L
.53884 .45917 L
Mistroke
.53882 .45957 L
.5388 .45993 L
.53879 .46034 L
.53878 .46079 L
.53878 .46122 L
.53878 .46146 L
.53878 .46169 L
.53879 .46211 L
.5388 .46256 L
.53882 .46299 L
.53885 .46347 L
.53894 .46443 L
.53904 .46531 L
.53916 .46614 L
.53952 .46796 L
.54004 .46984 L
.54067 .47149 L
.54139 .47293 L
.54212 .47408 L
.54255 .47462 L
.54303 .47515 L
.54353 .4756 L
.544 .47595 L
.54448 .47623 L
.54499 .47645 L
.54527 .47654 L
.54543 .47657 L
.54558 .4766 L
.54588 .47664 L
.54615 .47665 L
.5463 .47665 L
.54647 .47663 L
.54678 .47659 L
.54695 .47655 L
.54711 .4765 L
.54748 .47637 L
.5478 .47621 L
.54816 .476 L
.54882 .47548 L
.54946 .47481 L
.55005 .47402 L
.55135 .47161 L
.55205 .46984 L
.55264 .46796 L
.55363 .46375 L
.55405 .46125 L
.55445 .45821 L
.55472 .45536 L
.55485 .45367 L
.55495 .45207 L
Mistroke
.55502 .45053 L
.55508 .44881 L
.55511 .44713 L
.55513 .44554 L
.55513 .44367 L
.5551 .44161 L
.55504 .43962 L
.55497 .43776 L
.55485 .43556 L
.55469 .43312 L
.55429 .4286 L
.55373 .42385 L
.55297 .41881 L
.55116 .41011 L
.55003 .40605 L
.54868 .40208 L
.5459 .39604 L
.54417 .39338 L
.54244 .39138 L
.5414 .39045 L
.54043 .38976 L
.53988 .38943 L
.53928 .38912 L
.53875 .38889 L
.53817 .38869 L
.5372 .38845 L
.53628 .38833 L
.53575 .38831 L
.53518 .38832 L
.53415 .38843 L
.53362 .38852 L
.53305 .38866 L
.53203 .38899 L
.5308 .3895 L
.52967 .39008 L
.52543 .3931 L
.5214 .39694 L
.48995 .43609 L
.4821 .44652 L
.4784 .45262 L
.47515 .45925 L
.47195 .46767 L
.46887 .47871 L
.46745 .48535 L
.46609 .49328 L
.465 .50137 L
.46418 .50931 L
.46385 .51342 L
.46355 .51782 L
.46335 .52167 L
Mistroke
.46317 .52583 L
.4631 .52818 L
.46305 .53032 L
.46299 .53452 L
.46298 .53685 L
.46299 .53938 L
.46301 .54175 L
.46306 .54393 L
.46317 .54773 L
.46332 .55123 L
.46353 .55498 L
.46381 .5589 L
.46457 .56642 L
.46546 .57268 L
.46643 .57782 L
.46746 .58203 L
.46872 .58601 L
.47019 .58952 L
.47098 .591 L
.47186 .59239 L
.47267 .59344 L
.47355 .59437 L
.47436 .59506 L
.47527 .59567 L
.47612 .59609 L
.47692 .59637 L
.4779 .59658 L
.4784 .59663 L
.47895 .59665 L
.47994 .59661 L
.48088 .59647 L
.48142 .59635 L
.48199 .59619 L
.48302 .59585 L
.48538 .59482 L
.49389 .58962 L
.51077 .5794 L
.51545 .57625 L
.51992 .5723 L
.52239 .56945 L
.52506 .56565 L
.52724 .56181 L
.52958 .55674 L
.53361 .5449 L
.53562 .53688 L
.53735 .52836 L
.53995 .51085 L
.54111 .49994 L
.54194 .48946 L
.54232 .48312 L
Mistroke
.54261 .47709 L
.5428 .47165 L
.54295 .46578 L
.54302 .45941 L
.54303 .45624 L
.54301 .45279 L
.54291 .44678 L
.54275 .44133 L
.54252 .43601 L
.54224 .43116 L
.54155 .42264 L
.54107 .41823 L
.54058 .41441 L
.5393 .40668 L
.5378 .40031 L
.53621 .39556 L
.53524 .39338 L
.53432 .39171 L
.53326 .39022 L
.53267 .38955 L
.53212 .38903 L
.53105 .38826 L
.53045 .38795 L
.52988 .38774 L
.52885 .38754 L
.52772 .38756 L
.52713 .38766 L
.52646 .38783 L
.52577 .38809 L
.52511 .38839 L
.52267 .38996 L
.52029 .39206 L
.51809 .39438 L
.51313 .40047 L
.50432 .41237 L
.48855 .43226 L
.47987 .44367 L
.47576 .45021 L
.47212 .45712 L
.46588 .47295 L
.46303 .48279 L
.46043 .49413 L
.45831 .50614 L
.45684 .51724 L
.45623 .5233 L
.45597 .52644 L
.45573 .52972 L
.45556 .53253 L
.45541 .53556 L
.45531 .53824 L
Mistroke
.45525 .5407 L
.45522 .54304 L
.45521 .54553 L
.45523 .54779 L
.45528 .54982 L
.45535 .55176 L
.45543 .55346 L
.45555 .55533 L
.45568 .55702 L
.45604 .56055 L
.45646 .56344 L
.45701 .56622 L
.45767 .56873 L
.45841 .5708 L
.45918 .57238 L
.45992 .57349 L
.46077 .5744 L
.46122 .57474 L
.46174 .57504 L
.462 .57516 L
.46228 .57526 L
.46281 .57538 L
.46331 .57542 L
.46384 .5754 L
.4643 .57533 L
.46481 .57519 L
.46533 .57501 L
.46583 .57479 L
.46677 .57426 L
.4689 .57264 L
.47275 .56864 L
.48846 .54787 L
.49571 .53908 L
.50349 .53122 L
.51105 .52531 L
.5186 .52078 L
.51921 .52044 L
Mfstroke
.48333 .53333 m
.4842 .5348 L
.48511 .53589 L
.48568 .5364 L
.48621 .53679 L
.48686 .53716 L
.48749 .53744 L
.48813 .53765 L
.48846 .53774 L
.48883 .53781 L
.48915 .53787 L
.4895 .53791 L
.48983 .53794 L
.49014 .53796 L
.49053 .53797 L
.4909 .53798 L
.49111 .53797 L
.49131 .53797 L
.49154 .53796 L
.49175 .53795 L
.49215 .53792 L
.49251 .53789 L
.49336 .5378 L
.4967 .53729 L
.50071 .53659 L
.50537 .53578 L
.50755 .53533 L
.51002 .5347 L
.51251 .53386 L
.51489 .53277 L
.51721 .53135 L
.51972 .52931 L
.52236 .52646 L
.52481 .523 L
.5274 .51822 L
.53002 .51188 L
.5321 .50539 L
.53379 .49865 L
.53535 .49069 L
.53662 .48187 L
.53709 .47742 L
.53729 .4751 L
.53747 .47268 L
.5376 .4706 L
.53771 .46835 L
.53775 .46738 L
.53778 .46636 L
.53782 .46453 L
.53784 .4627 L
.53784 .46168 L
Mistroke
.53784 .46076 L
.53781 .45911 L
.53775 .45742 L
.53768 .45582 L
.53758 .45439 L
.53736 .45188 L
.53722 .45068 L
.53705 .44947 L
.5367 .44747 L
.53622 .4454 L
.53572 .44381 L
.53515 .44244 L
.53483 .44184 L
.53447 .44128 L
.53415 .44087 L
.53379 .44048 L
.53347 .44021 L
.53312 .43998 L
.53279 .43981 L
.53243 .43969 L
.53209 .43962 L
.53178 .4396 L
.5314 .43961 L
.53105 .43967 L
.53064 .43978 L
.53026 .43993 L
.52955 .44029 L
.5289 .44072 L
.52741 .442 L
.52431 .44566 L
.5215 .44971 L
.51564 .45915 L
.50646 .47312 L
.50233 .47818 L
.49795 .48263 L
.48952 .48923 L
.48507 .49243 L
.48262 .49446 L
.47994 .49718 L
.47745 .50058 L
.4764 .50241 L
.4753 .5047 L
.47351 .50975 L
.47268 .513 L
.47204 .51634 L
.47176 .51819 L
.47151 .52023 L
.4714 .52132 L
.4713 .52254 L
.47122 .52368 L
Mistroke
.47115 .52474 L
.47111 .52581 L
.47107 .52685 L
.47105 .52794 L
.47105 .52857 L
.47105 .52914 L
.47106 .53021 L
.47108 .53117 L
.47112 .53228 L
.47116 .53332 L
.4713 .53528 L
.47149 .53731 L
.4717 .53901 L
.47197 .54082 L
.47233 .54271 L
.47277 .54463 L
.47372 .54779 L
.47433 .54934 L
.47504 .55082 L
.47646 .55302 L
.47733 .55398 L
.47819 .55472 L
.47918 .55534 L
.47975 .55561 L
.48029 .5558 L
.48074 .55593 L
.48123 .55603 L
.48169 .55609 L
.48212 .55612 L
.48263 .55613 L
.48293 .55613 L
.4832 .55611 L
.4837 .55607 L
.48423 .55599 L
.48475 .55589 L
.48532 .55576 L
.48635 .55547 L
.48877 .55458 L
.4983 .55032 L
.50381 .54829 L
.50701 .54725 L
.51013 .54616 L
.51326 .54482 L
.51494 .54391 L
.51673 .54273 L
.51826 .54152 L
.51994 .53991 L
.52288 .53618 L
.52579 .53094 L
.52736 .52726 L
Mistroke
.52873 .52339 L
.53117 .51443 L
.53314 .50423 L
.53401 .49822 L
.5347 .49228 L
.53532 .48549 L
.53559 .48162 L
.53579 .47799 L
.53596 .47421 L
.53603 .47221 L
.53608 .47009 L
.53612 .46807 L
.53614 .46618 L
.53615 .46267 L
.53611 .45926 L
.53604 .45619 L
.53592 .45289 L
.53574 .44952 L
.53554 .44668 L
.53533 .44418 L
.53475 .43892 L
.53409 .43454 L
.53336 .43087 L
.5324 .42721 L
.53142 .42442 L
.53024 .42202 L
.52961 .42106 L
.5289 .42019 L
.52824 .41958 L
.52761 .41914 L
.52691 .41881 L
.52651 .41869 L
.52615 .41862 L
.5254 .41858 L
.52498 .41861 L
.52458 .41868 L
.52385 .4189 L
.52307 .41924 L
.52169 .42012 L
.52038 .4212 L
.51741 .42441 L
.50529 .44276 L
.48619 .47104 L
.48177 .47796 L
.47731 .48635 L
.4736 .49525 L
.47074 .50412 L
.46835 .51388 L
.46748 .51843 L
.46686 .52234 L
Mistroke
.46644 .52557 L
.46611 .52876 L
.466 .53027 L
.46593 .53157 L
.4659 .53225 L
.46588 .53283 L
.46587 .53348 L
.46586 .53407 L
.46586 .53457 L
.46587 .53509 L
.46589 .53555 L
.46591 .53594 L
.46593 .53636 L
.46597 .53678 L
.46601 .53719 L
.46605 .53754 L
.46611 .53788 L
.46616 .53817 L
.46628 .53863 L
.46635 .53885 L
.46641 .53903 L
.46649 .53919 L
.46658 .53934 L
.46665 .53943 L
.46672 .53949 L
.46679 .53955 L
.46686 .53958 L
.46694 .5396 L
.46701 .5396 L
.46709 .53959 L
.46718 .53955 L
.46726 .53951 L
.46735 .53944 L
.4675 .53927 L
.46769 .53901 L
.46785 .53871 L
.46817 .53798 L
.46848 .53701 L
.46873 .53596 L
.46893 .53491 L
.46902 .53429 L
.4691 .5336 L
.46914 .53324 L
.46917 .53283 L
.4692 .53246 L
.46922 .53211 L
.46924 .53176 L
.46925 .53142 L
.46925 .53106 L
.46926 .53086 L
Mistroke
.46926 .53067 L
.46925 .53033 L
.46925 .53001 L
.46923 .52965 L
.46922 .52931 L
.46917 .52864 L
.46911 .52801 L
.46903 .52733 L
.46891 .52661 L
.46861 .52516 L
.46825 .5239 L
.46784 .52279 L
.46731 .52166 L
.46673 .52068 L
.46612 .51986 L
.46551 .5192 L
.46478 .5186 L
.46436 .51833 L
.46391 .5181 L
.4635 .51795 L
.46327 .51788 L
.46305 .51783 L
.46281 .5178 L
.46256 .51777 L
.46231 .51777 L
.46208 .51778 L
.46187 .5178 L
.46163 .51784 L
.46138 .5179 L
.46115 .51797 L
.46062 .5182 L
.46012 .51849 L
.45954 .51893 L
.459 .51946 L
Mfstroke
.5 .46667 m
.49403 .47867 L
.48896 .48973 L
.48695 .49497 L
.48518 .50055 L
.48436 .50373 L
.48375 .50658 L
.48328 .50921 L
.48308 .51061 L
.48292 .5119 L
.4828 .51307 L
.48271 .51411 L
.48264 .51523 L
.48261 .51583 L
.48259 .51639 L
.48258 .51684 L
.48258 .51732 L
.48258 .51776 L
.48259 .51816 L
.4826 .51861 L
.48262 .51909 L
.48264 .51953 L
.48267 .51992 L
.48275 .52076 L
.48285 .5215 L
.48298 .52225 L
.48314 .52299 L
.48334 .52369 L
.48355 .52429 L
.48378 .52481 L
.48401 .52524 L
.48448 .5259 L
.48475 .52617 L
.48506 .52642 L
.48538 .52662 L
.48556 .5267 L
.48574 .52677 L
.4859 .52682 L
.48605 .52685 L
.48622 .52688 L
.48631 .5269 L
.4864 .52691 L
.48655 .52692 L
.48672 .52692 L
.48689 .52692 L
.48706 .5269 L
.48722 .52689 L
.48736 .52686 L
.48769 .5268 L
.48806 .5267 L
Mistroke
.48846 .52657 L
.4892 .52626 L
.49093 .52532 L
.49255 .52425 L
.49638 .52149 L
.50438 .51595 L
.50846 .51352 L
.51337 .51106 L
.51883 .50897 L
.52549 .50714 L
.52907 .50622 L
.53272 .50504 L
.53483 .50412 L
.5372 .50278 L
.53939 .50112 L
.54143 .49908 L
.5434 .49651 L
.54546 .49294 L
.54731 .48866 L
.54887 .48383 L
.5504 .47736 L
.55115 .47316 L
.55174 .4689 L
.55226 .46403 L
.55263 .45931 L
.55278 .45658 L
.55284 .45511 L
.5529 .45354 L
.55294 .45214 L
.55297 .4506 L
.553 .44783 L
.55299 .44495 L
.55295 .44225 L
.55286 .43926 L
.5528 .43774 L
.55272 .43605 L
.55256 .43324 L
.55234 .4302 L
.55182 .42474 L
.55117 .41948 L
.55032 .41414 L
.5484 .40534 L
.54712 .40096 L
.54558 .39681 L
.54399 .39345 L
.54243 .39091 L
.54048 .38856 L
.53933 .38755 L
.53824 .38681 L
.53727 .38632 L
Mistroke
.53671 .3861 L
.53617 .38594 L
.53509 .38574 L
.53447 .38569 L
.5339 .38569 L
.53281 .38579 L
.53177 .38601 L
.53082 .38631 L
.52979 .38673 L
.52746 .38804 L
.52529 .38962 L
.5171 .39796 L
.49915 .421 L
.49099 .43112 L
.48247 .44239 L
.47849 .44893 L
.47489 .45639 L
.47185 .46449 L
.46887 .47513 L
.46641 .48728 L
.46524 .49501 L
.46431 .50276 L
.46353 .5113 L
.46301 .51941 L
.46281 .52373 L
.46271 .52622 L
.46265 .52848 L
.46259 .53088 L
.46255 .53345 L
.46253 .53804 L
.46256 .54203 L
.46265 .5462 L
.46276 .5497 L
.46293 .55347 L
.46317 .55743 L
.46348 .56154 L
.4642 .56853 L
.46511 .57495 L
.46613 .58038 L
.46718 .58466 L
.46844 .58868 L
.47006 .5925 L
.47103 .59425 L
.47195 .59562 L
.47286 .59671 L
.47373 .59755 L
.47466 .59825 L
.47516 .59855 L
.47571 .59883 L
.47667 .59919 L
Mistroke
.47759 .5994 L
.47851 .59949 L
.47936 .59948 L
.48029 .59938 L
.48133 .59917 L
.48242 .59884 L
.48345 .59846 L
.48806 .59607 L
.49237 .5933 L
.50235 .58689 L
.51113 .58167 L
.51608 .57821 L
.5208 .57379 L
.52348 .57047 L
.52634 .56599 L
.53116 .55538 L
.5334 .54859 L
.53561 .54018 L
.53907 .52196 L
.54057 .51074 L
.54174 .49932 L
.54256 .48857 L
.54293 .48236 L
.54319 .47657 L
.54341 .47037 L
.54354 .46456 L
.5436 .45825 L
.5436 .45473 L
.54358 .45154 L
.54348 .4456 L
.54339 .4423 L
.54328 .43928 L
.543 .43336 L
.54261 .42732 L
.54218 .42225 L
.54173 .41783 L
.5405 .40884 L
.5392 .40215 L
.53762 .39636 L
.53607 .39229 L
.53451 .38942 L
.53358 .38815 L
.5327 .38723 L
.53167 .38642 L
.53067 .3859 L
.52957 .3856 L
.52894 .38553 L
.52835 .38553 L
.52727 .3857 L
.52612 .38607 L
Mistroke
.52508 .38656 L
.5241 .38714 L
.52187 .38884 L
.51724 .39361 L
.51231 .39976 L
.49585 .42128 L
.48757 .43126 L
.47898 .44251 L
.47466 .44943 L
.4701 .45841 L
.4662 .46813 L
.46296 .47831 L
.46019 .48927 L
.45775 .50159 L
.45586 .51431 L
.45505 .52147 L
.45447 .52796 L
.45426 .53082 L
.45408 .53386 L
.45395 .53647 L
.45384 .53917 L
.45377 .54155 L
.45373 .54408 L
.45372 .54631 L
.45373 .54833 L
.45377 .55078 L
.45385 .55299 L
.45394 .5549 L
.45406 .55688 L
.45423 .55892 L
.45443 .56095 L
.45488 .56428 L
.4554 .56704 L
.45603 .56953 L
.45663 .57131 L
.45735 .57292 L
.45818 .57428 L
.45867 .57487 L
.45913 .57531 L
.45957 .57565 L
.46006 .57592 L
.46053 .57611 L
.46097 .57622 L
.46138 .57627 L
.46183 .57627 L
.46226 .57622 L
.46265 .57614 L
.46312 .576 L
.46363 .5758 L
.46457 .57531 L
Mistroke
.46557 .57464 L
.46663 .57377 L
.46855 .5719 L
.48504 .54935 L
.49228 .53969 L
.49862 .53246 L
.51137 .52212 L
Mfstroke
.5 .48333 m
.49857 .48783 L
.49734 .49228 L
.49639 .49649 L
.49608 .49818 L
.49582 .49991 L
.49571 .50085 L
.49562 .5017 L
.49556 .50248 L
.49554 .50287 L
.49552 .50328 L
.49551 .50351 L
.4955 .50372 L
.4955 .50391 L
.4955 .50411 L
.49549 .50432 L
.49549 .50455 L
.49549 .50477 L
.4955 .50496 L
.4955 .50515 L
.49551 .50533 L
.49552 .50572 L
.49554 .50605 L
.49557 .5064 L
.49563 .50701 L
.49571 .50763 L
.4959 .50869 L
.49605 .5093 L
.49621 .50985 L
.49657 .5108 L
.49695 .51159 L
.49744 .51238 L
.49803 .51312 L
.49864 .51374 L
.49989 .51467 L
.50069 .51509 L
.50147 .51543 L
.50234 .51572 L
.50284 .51586 L
.50333 .51598 L
.50381 .51607 L
.50433 .51615 L
.50482 .51622 L
.50529 .51626 L
.50556 .51628 L
.50586 .5163 L
.50603 .51631 L
.5062 .51632 L
.50651 .51632 L
.50667 .51633 L
Mistroke
.50684 .51633 L
.50715 .51632 L
.50735 .51632 L
.50753 .51631 L
.5077 .51631 L
.50788 .5163 L
.50852 .51625 L
.50886 .51622 L
.50922 .51618 L
.51052 .51599 L
.51123 .51586 L
.51202 .51568 L
.51349 .51526 L
.5164 .51416 L
.51999 .51228 L
.52346 .50993 L
.5307 .50369 L
.5376 .49713 L
.54086 .49437 L
.54436 .49198 L
.54624 .491 L
.54726 .49057 L
.54837 .49017 L
.54941 .48988 L
.55037 .48966 L
.55084 .48957 L
.55136 .48949 L
.55184 .48943 L
.5523 .48938 L
.55285 .48934 L
.55335 .48932 L
.5539 .48931 L
.55421 .4893 L
.55451 .48931 L
.55499 .48932 L
.55554 .48934 L
.55612 .48938 L
.55667 .48943 L
.55795 .48957 L
.55917 .48974 L
.56204 .49023 L
.56505 .49075 L
.56659 .49098 L
.56804 .49114 L
.56884 .49121 L
.56961 .49125 L
.57043 .49127 L
.5709 .49127 L
.57133 .49126 L
.5722 .49121 L
Mistroke
.57269 .49116 L
.57316 .4911 L
.57411 .49094 L
.57514 .4907 L
.57607 .49042 L
.57692 .49009 L
.57884 .48912 L
.58063 .48784 L
.58233 .48624 L
.58432 .4838 L
.58612 .48091 L
.58805 .47693 L
.59002 .47166 L
.59152 .46645 L
.59302 .45988 L
.59429 .45265 L
.5953 .44514 L
.59628 .43518 L
.59672 .429 L
.59704 .42294 L
.59726 .41737 L
.59742 .41095 L
.59746 .40761 L
.59749 .40394 L
.59746 .3971 L
.59734 .39012 L
.59715 .3836 L
.59683 .37589 L
.59642 .36847 L
.59544 .35499 L
.59398 .34024 L
.5919 .32411 L
.58915 .30768 L
.58635 .29454 L
.58283 .2814 L
.57868 .2695 L
.5745 .26051 L
.57205 .25637 L
.56927 .25257 L
.56656 .24964 L
.56397 .24751 L
.5627 .24668 L
.5613 .24592 L
.55873 .24492 L
.55619 .24439 L
.55382 .24428 L
.55122 .24455 L
.54973 .24487 L
.54833 .24527 L
.54549 .24637 L
Mistroke
.54243 .24796 L
.53674 .25181 L
.53066 .25696 L
.51972 .26791 L
.49511 .29426 L
.4737 .31698 L
.46758 .32488 L
.46183 .33384 L
.45671 .34376 L
.45142 .35681 L
.44644 .37281 L
.44223 .39049 L
.43837 .41164 L
.43516 .43481 L
.43355 .44937 L
.43204 .4658 L
.43091 .4808 L
.42988 .49762 L
.42901 .51643 L
.42842 .53453 L
.42817 .54576 L
.42802 .55649 L
.42794 .57671 L
.42808 .59269 L
.42845 .61014 L
.42905 .62795 L
.42983 .64415 L
.43074 .65863 L
.43172 .67131 L
.43442 .69742 L
.43609 .7096 L
.4378 .71991 L
.43999 .73083 L
.44213 .73947 L
.44435 .74677 L
.44688 .7534 L
.44967 .75899 L
.4524 .76302 L
.45523 .76593 L
.45786 .76768 L
.46097 .76873 L
.46396 .76889 L
.46675 .7684 L
.46936 .76748 L
.47224 .76603 L
.47533 .76408 L
.50171 .74106 L
.51626 .72817 L
.52342 .72102 L
.52999 .71291 L
Mistroke
.53591 .70332 L
.54202 .68987 L
.54791 .67175 L
.55108 .65898 L
.5539 .64526 L
.55647 .63025 L
.55899 .61237 L
.56293 .57529 L
.56472 .55212 L
.56612 .52895 L
.56731 .5022 L
.56781 .48671 L
.56817 .47231 L
.56853 .44775 L
.56858 .42489 L
.56834 .40009 L
.56773 .37437 L
.56728 .36179 L
.5667 .34856 L
.56538 .32581 L
.5638 .30544 L
.56209 .28842 L
.56032 .27428 L
.55823 .26088 L
.55627 .2508 L
.55401 .24139 L
.55121 .23239 L
.54842 .22577 L
.54559 .22099 L
.5429 .21791 L
.54003 .21592 L
.53728 .21508 L
.53423 .21515 L
.53089 .21621 L
.52757 .2181 L
.52405 .22078 L
.51773 .22681 L
.49234 .25528 L
.4857 .26276 L
.47852 .27157 L
.47237 .28056 L
.46571 .29309 L
.45968 .30852 L
.45361 .33016 L
.44845 .35607 L
.44416 .38602 L
.44224 .40327 L
.44059 .42092 L
.43801 .45702 L
.43689 .47859 L
Mistroke
.43607 .49929 L
.43543 .52253 L
.43505 .54758 L
.43499 .57304 L
.4351 .58731 L
.4353 .60044 L
.43561 .61404 L
.43598 .62614 L
.43652 .63986 L
.43712 .6521 L
.43839 .67258 L
.44009 .69289 L
.44182 .70893 L
.44389 .72397 L
.44632 .73766 L
.44916 .74978 L
.45204 .75882 L
.45481 .7652 L
.45646 .76809 L
.45801 .77032 L
.45975 .77227 L
.46163 .77384 L
.46364 .77495 L
.46556 .77555 L
.4673 .77574 L
.4692 .77563 L
.47244 .77478 L
.4755 .77335 L
.47887 .77126 L
.48251 .76856 L
.4968 .75619 L
.50929 .74539 L
.52267 .7328 L
.53005 .72339 L
.53664 .71179 L
.54308 .69582 L
.54884 .67566 L
.55194 .66157 L
.55503 .64449 L
.55995 .6081 L
.5623 .5847 L
.56419 .56107 L
.5659 .53343 L
.56663 .5185 L
.56727 .50234 L
.5677 .48917 L
.56807 .47453 L
.56846 .44863 L
.56853 .43413 L
.56849 .41867 L
Mistroke
.56834 .40429 L
.56811 .39137 L
.56741 .36737 L
.56688 .35438 L
.56629 .34276 L
.565 .32274 L
.56334 .30334 L
.56148 .28669 L
.55921 .27104 L
.55684 .25855 L
.5545 .24897 L
.55227 .24185 L
.54971 .2356 L
.54693 .23071 L
.54425 .22752 L
.5412 .22536 L
.53964 .22476 L
.53789 .22446 L
.53478 .22472 L
.53183 .22577 L
.53014 .22666 L
.52835 .2278 L
.52513 .23026 L
.51787 .23721 L
.49257 .26513 L
.4817 .27711 L
.47018 .29222 L
.46368 .30348 L
.45792 .31629 L
.45234 .33232 L
.44736 .35091 L
.44253 .37442 L
.43848 .40019 L
.43469 .43241 L
.43148 .47083 L
.43026 .49111 L
.42973 .502 L
.42924 .5137 L
.42885 .52499 L
.42857 .53522 L
.42822 .5551 L
.42813 .574 L
.4283 .59389 L
.42871 .61196 L
.4293 .6278 L
.43002 .64186 L
.43098 .65601 L
.43314 .67888 L
.43472 .69107 L
.43637 .70134 L
Mistroke
.43984 .71725 L
.44178 .72376 L
.44394 .72953 L
.44586 .73357 L
.44805 .73715 L
.45047 .74004 L
.45315 .74215 L
.45573 .7433 L
.45813 .7437 L
.46086 .74352 L
.46347 .74282 L
.46583 .74181 L
.46839 .74037 L
.47958 .73148 L
.49985 .71202 L
.52188 .69164 L
.5336 .67941 L
.54605 .66251 L
.55756 .64052 L
.56738 .61427 L
.57621 .58188 L
.5833 .54666 L
.58654 .52644 L
.58947 .50458 L
.59157 .48577 L
.59337 .46594 L
.59424 .45414 L
.59489 .44366 L
.59537 .43419 L
.59557 .42934 L
.59575 .42427 L
.59597 .41577 L
.59607 .40825 L
.59609 .40401 L
.59607 .40013 L
.59597 .39321 L
.59581 .38738 L
.59555 .38153 L
.59524 .37641 L
.59489 .37207 L
.59443 .3674 L
.59384 .3628 L
.59261 .3557 L
.59184 .35249 L
.5911 .34997 L
.59027 .34766 L
.58931 .34558 L
.58839 .34404 L
.58751 .34293 L
.58664 .34212 L
Mistroke
.58571 .34152 L
.58483 .34118 L
.58401 .34104 L
.58305 .34107 L
.58214 .34128 L
.58128 .3416 L
.58049 .34201 L
.57868 .34329 L
.57686 .34499 L
.57485 .34727 L
.57082 .35281 L
.54323 .4017 L
.52445 .43033 L
Mfstroke
.5 .5 m
.5 .50041 L
.50001 .50078 L
.50002 .5012 L
.50004 .50159 L
.50006 .50194 L
.50008 .50227 L
.50015 .503 L
.50023 .50371 L
.50035 .50447 L
.50065 .50595 L
.50104 .50731 L
.50156 .50869 L
.50276 .51094 L
.50359 .51208 L
.50463 .5132 L
.50565 .51409 L
.50686 .51492 L
.50817 .51559 L
.50945 .51606 L
.5101 .51624 L
.51046 .51631 L
.51083 .51637 L
.51117 .51642 L
.51154 .51646 L
.51189 .51648 L
.51221 .51649 L
.5126 .51648 L
.51279 .51648 L
.51301 .51646 L
.51339 .51643 L
.51376 .51638 L
.5142 .5163 L
.5146 .51621 L
.51552 .51594 L
.51629 .51564 L
.51714 .51523 L
.51888 .51409 L
.5205 .51266 L
.52222 .51068 L
.52524 .50587 L
.52693 .50224 L
.52838 .49844 L
.52979 .49394 L
.53112 .48864 L
.53201 .48421 L
.53277 .47947 L
.53309 .47691 L
.53334 .47464 L
.53353 .47238 L
Mistroke
.53365 .47043 L
.5337 .46949 L
.53373 .46851 L
.53376 .46761 L
.53377 .4668 L
.53377 .46598 L
.53376 .4651 L
.53375 .46467 L
.53374 .46423 L
.5337 .46345 L
.53367 .46275 L
.53361 .46203 L
.53349 .46081 L
.53334 .45975 L
.53317 .45888 L
.53295 .45798 L
.53272 .45726 L
.53244 .45661 L
.53229 .45633 L
.53211 .45607 L
.53195 .45586 L
.53177 .45568 L
.53157 .45553 L
.53138 .45543 L
.53129 .45539 L
.53119 .45536 L
.531 .45533 L
.53082 .45532 L
.53065 .45534 L
.53046 .45538 L
.53029 .45545 L
.53012 .45552 L
.52995 .45562 L
.52955 .4559 L
.52918 .45624 L
.5278 .45801 L
.52637 .46061 L
.52501 .46375 L
.52399 .46661 L
.52311 .46964 L
.52249 .47237 L
.52226 .47362 L
.52211 .47472 L
.52197 .47592 L
.52195 .47623 L
.52192 .47656 L
.52191 .47685 L
.52189 .47716 L
.52188 .47744 L
.52188 .4777 L
Mistroke
.52187 .47797 L
.52187 .47826 L
.52188 .47853 L
.52188 .47877 L
.52189 .479 L
.5219 .47923 L
.52192 .47954 L
.52194 .47982 L
.522 .48034 L
.52207 .48088 L
.52217 .48144 L
.5224 .48242 L
.52267 .48326 L
.52299 .48404 L
.52339 .48481 L
.52379 .48542 L
.52427 .48602 L
.52491 .48663 L
.52523 .48687 L
.52558 .48709 L
.52591 .48727 L
.52629 .48743 L
.52646 .48749 L
.52665 .48755 L
.52682 .48759 L
.52699 .48763 L
.52719 .48766 L
.52737 .48768 L
.52756 .48769 L
.52768 .48769 L
.52778 .48769 L
.52795 .48768 L
.52815 .48766 L
.52835 .48763 L
.52855 .48759 L
.52878 .48753 L
.529 .48745 L
.52942 .48728 L
.52988 .48702 L
.53038 .48667 L
.53133 .48575 L
.53186 .48509 L
.53234 .48438 L
.53323 .48268 L
.53403 .48069 L
.53471 .4784 L
.53536 .47546 L
.53563 .4738 L
.53589 .47191 L
.53608 .47001 L
Mistroke
.53614 .46914 L
.53621 .46819 L
.53625 .46731 L
.53629 .46632 L
.53632 .4654 L
.53633 .46453 L
.53634 .46349 L
.53633 .46253 L
.53631 .46141 L
.53627 .46034 L
.53623 .45941 L
.53617 .45842 L
.53603 .45663 L
.53581 .45452 L
.53556 .45263 L
.53483 .44867 L
.53438 .44681 L
.53381 .44489 L
.53327 .44338 L
.53264 .44191 L
.53137 .43967 L
.53053 .43862 L
.53006 .43816 L
.52955 .43773 L
.5291 .43743 L
.52859 .43716 L
.52811 .43697 L
.52765 .43684 L
.5272 .43677 L
.52671 .43675 L
.52629 .43677 L
.52582 .43683 L
.52531 .43695 L
.52503 .43704 L
.52476 .43713 L
.52376 .43761 L
.52282 .4382 L
.52178 .43901 L
.51967 .44111 L
.51592 .44605 L
.50823 .45978 L
.50196 .47331 L
.49759 .48388 L
.49432 .49325 L
.49319 .49732 L
.49243 .50076 L
.49215 .50239 L
.49191 .50408 L
.49181 .50499 L
.49174 .50579 L
Mistroke
.49169 .50655 L
.49167 .50692 L
.49165 .50733 L
.49165 .50753 L
.49164 .50776 L
.49164 .50816 L
.49164 .50855 L
.49164 .5089 L
.49165 .50928 L
.49166 .50949 L
.49167 .50969 L
.49169 .51008 L
.49172 .51049 L
.49179 .51117 L
.49188 .51187 L
.49211 .51304 L
.49226 .51363 L
.49242 .51417 L
.49276 .51511 L
.4932 .51603 L
.49376 .51692 L
.49431 .51762 L
.49496 .51828 L
.49629 .51926 L
.49713 .51971 L
.49796 .52008 L
.49891 .52041 L
.50002 .52071 L
.50112 .52094 L
.50162 .52103 L
.5022 .52111 L
.50271 .52117 L
.50328 .52123 L
.5036 .52126 L
.5039 .52128 L
.50418 .52129 L
.50449 .52131 L
.50484 .52132 L
.50517 .52133 L
.5055 .52133 L
.50581 .52133 L
.50614 .52133 L
.50652 .52131 L
.50671 .52131 L
.50691 .5213 L
.50729 .52128 L
.50803 .52122 L
.50875 .52114 L
.51014 .52093 L
.51096 .52076 L
Mistroke
.51185 .52055 L
.5135 .52004 L
.51553 .51923 L
.51743 .51824 L
.52125 .51555 L
.52483 .51205 L
.5287 .50706 L
.53259 .50066 L
.54325 .47722 L
.54425 .47515 L
.54529 .47328 L
.54618 .47198 L
.54711 .47095 L
.54762 .47053 L
.54789 .47036 L
.54819 .4702 L
.54847 .47009 L
.54872 .47001 L
.54896 .46996 L
.54923 .46993 L
.54947 .46992 L
.54973 .46993 L
.54998 .46995 L
.55021 .47 L
.55048 .47006 L
.55079 .47016 L
.55135 .47039 L
.55252 .47103 L
.55369 .47183 L
.55677 .47418 L
.55853 .47549 L
.56065 .47689 L
.56169 .47748 L
.56284 .47806 L
.56396 .47851 L
.56503 .47885 L
.56563 .47899 L
.56627 .4791 L
.56661 .47914 L
.56692 .47917 L
.56727 .47919 L
.56765 .47919 L
.56798 .47918 L
.56834 .47915 L
.569 .47906 L
.56964 .47891 L
.57025 .47872 L
.57084 .47848 L
.5714 .4782 L
.57269 .47735 L
Mistroke
.57394 .47621 L
.5753 .47459 L
.57653 .47267 L
.57785 .47006 L
.57898 .46727 L
.58014 .46373 L
.58121 .4596 L
.58211 .45529 L
.58287 .45072 L
.5836 .44519 L
.58429 .43797 L
Mfstroke
.5 .51667 m
.50172 .51816 L
.50396 .51961 L
.50524 .52025 L
.50672 .52084 L
.50748 .52109 L
.50822 .52129 L
.50891 .52143 L
.50967 .52156 L
.51009 .52161 L
.51032 .52163 L
.51054 .52165 L
.51098 .52167 L
.51138 .52167 L
.51161 .52167 L
.51186 .52166 L
.51232 .52163 L
.5126 .5216 L
.51287 .52157 L
.51337 .52149 L
.51387 .52138 L
.51441 .52124 L
.51539 .52091 L
.51647 .52041 L
.51766 .5197 L
.51965 .51805 L
.52179 .51555 L
.52377 .51241 L
.52549 .50883 L
.52716 .50442 L
.52875 .49899 L
.52994 .49383 L
.53101 .48773 L
.53147 .48444 L
.53187 .48095 L
.53221 .47714 L
.53232 .47546 L
.53242 .4737 L
.53249 .47204 L
.53254 .47056 L
.53257 .46909 L
.53258 .46774 L
.53258 .4662 L
.53255 .46481 L
.53253 .46411 L
.5325 .46334 L
.53243 .46184 L
.53234 .46051 L
.53225 .45933 L
.53197 .45683 L
Mistroke
.53165 .45486 L
.53126 .453 L
.53082 .45142 L
.53036 .45016 L
.52991 .44921 L
.52939 .44838 L
.52878 .44768 L
.52842 .44739 L
.52808 .44718 L
.52789 .44708 L
.52771 .44701 L
.52736 .44692 L
.52717 .44689 L
.52699 .44688 L
.52678 .44688 L
.52657 .44689 L
.52624 .44695 L
.52588 .44705 L
.52554 .44718 L
.52522 .44733 L
.52448 .44779 L
.52369 .4484 L
.52089 .45148 L
.51799 .45567 L
.51322 .46373 L
.50875 .4715 L
.50457 .47807 L
.50121 .48244 L
.49764 .48606 L
.49416 .48871 L
.4902 .49099 L
.48578 .49308 L
.48126 .49531 L
.47886 .49682 L
.47618 .49904 L
.47494 .50036 L
.47363 .50202 L
.47137 .50584 L
.47024 .50843 L
.46928 .51117 L
.46833 .51461 L
.46749 .51873 L
.46719 .52062 L
.46692 .52272 L
.46671 .52462 L
.46654 .52674 L
.46645 .52806 L
.46639 .52931 L
.46634 .53051 L
.46631 .5318 L
Mistroke
.46629 .53297 L
.46629 .53407 L
.4663 .53528 L
.46633 .53659 L
.46635 .53732 L
.46638 .538 L
.46645 .53929 L
.46653 .54067 L
.46665 .54215 L
.46693 .5448 L
.46725 .54718 L
.46823 .55236 L
.46886 .55475 L
.46965 .55716 L
.47119 .56068 L
.47217 .5623 L
.47313 .56354 L
.47408 .56451 L
.47515 .56533 L
.47566 .56564 L
.47622 .56591 L
.47674 .56612 L
.47724 .56627 L
.47776 .56639 L
.47834 .56648 L
.47892 .56652 L
.47954 .56653 L
.48013 .56649 L
.48069 .56642 L
.4812 .56633 L
.48176 .56621 L
.48306 .56582 L
.48446 .56528 L
.48702 .56404 L
.49723 .55814 L
.5033 .55512 L
.50939 .55246 L
.51215 .55114 L
.51515 .54942 L
.51849 .54688 L
.52161 .5436 L
.52333 .54124 L
.52517 .53818 L
.52675 .53499 L
.52837 .53107 L
.52977 .52699 L
.53123 .52191 L
.53352 .51145 L
.53472 .50405 L
.53566 .49678 L
Mistroke
.5361 .49256 L
.53652 .48785 L
.53682 .4837 L
.53709 .47907 L
.53729 .47475 L
.53742 .4707 L
.5375 .46643 L
.53752 .46404 L
.53753 .46187 L
.53749 .45806 L
.53741 .45397 L
.53727 .4502 L
.5371 .4468 L
.53686 .44308 L
.53654 .43932 L
.53583 .43308 L
.53488 .42716 L
.53426 .4242 L
.53364 .42171 L
.53239 .41788 L
.53115 .41515 L
.53042 .41395 L
.5296 .41288 L
.5288 .4121 L
.52805 .41156 L
.52737 .41122 L
.52662 .411 L
.52591 .41092 L
.52525 .41096 L
.5245 .4111 L
.52369 .41138 L
.52283 .41181 L
.52202 .41231 L
.51881 .41517 L
.5154 .41932 L
.50244 .43916 L
.48993 .45771 L
.48453 .46603 L
.47922 .47604 L
.47521 .48626 L
.47323 .49281 L
.47162 .49937 L
.47025 .50637 L
.46965 .51012 L
.4691 .51412 L
.46868 .51793 L
.46837 .52132 L
.46826 .52293 L
.46815 .52464 L
.46807 .52622 L
Mistroke
.46801 .52766 L
.46797 .52904 L
.46794 .53049 L
.46793 .53206 L
.46794 .53344 L
.46796 .53485 L
.46799 .53562 L
.46801 .53632 L
.46808 .53757 L
.46816 .53885 L
.46835 .54097 L
.46857 .54281 L
.46886 .54465 L
.46923 .54642 L
.46965 .54797 L
.47015 .5494 L
.47067 .55053 L
.47118 .55138 L
.47181 .55218 L
.47218 .55253 L
.47254 .5528 L
.47285 .553 L
.47321 .55317 L
.47339 .55323 L
.47358 .55329 L
.47394 .55337 L
.47414 .55339 L
.47435 .55341 L
.47473 .5534 L
.47495 .55338 L
.47515 .55335 L
.47537 .55331 L
.47562 .55325 L
.47603 .55312 L
.47647 .55294 L
.47727 .55254 L
.47879 .55153 L
.48048 .55012 L
.49328 .53595 L
.50519 .52439 L
.51201 .51953 L
.51899 .5158 L
.53315 .50917 L
Mfstroke
.5 .53333 m
.50041 .53333 L
.5008 .53333 L
.50124 .53333 L
.50167 .53333 L
.50207 .53333 L
.50244 .53333 L
.50285 .53333 L
.50329 .53333 L
.50374 .53332 L
.50423 .53331 L
.5047 .5333 L
.50514 .53329 L
.50565 .53328 L
.50622 .53325 L
.50727 .53319 L
.50785 .53314 L
.50839 .53309 L
.50944 .53296 L
.51058 .53277 L
.51185 .53248 L
.51299 .53214 L
.51421 .53168 L
.51644 .53052 L
.51774 .52963 L
.51893 .52863 L
.52161 .52566 L
.52406 .52186 L
.52627 .51718 L
.52866 .51035 L
.53059 .50274 L
.53232 .49317 L
.53301 .48799 L
.53361 .48212 L
.53394 .47764 L
.53409 .47511 L
.53419 .47278 L
.53427 .47032 L
.53432 .46813 L
.53433 .46692 L
.53433 .46563 L
.53432 .46333 L
.53428 .46141 L
.53421 .45934 L
.53411 .45726 L
.53399 .45538 L
.53371 .45219 L
.53333 .44906 L
.53278 .44581 L
.53206 .44278 L
Mistroke
.53129 .44042 L
.53049 .43866 L
.53006 .43792 L
.52965 .43732 L
.52883 .43645 L
.52835 .43608 L
.52791 .43583 L
.52741 .43564 L
.52716 .43558 L
.52687 .43553 L
.52635 .43551 L
.52587 .43556 L
.52561 .43561 L
.52532 .43569 L
.52474 .4359 L
.52423 .43615 L
.52368 .43648 L
.52267 .43722 L
.52061 .43919 L
.51874 .44141 L
.5104 .4539 L
.50315 .46512 L
.49701 .47319 L
.49128 .47916 L
.48506 .48414 L
.48167 .48631 L
.47784 .48835 L
.47433 .48986 L
.47021 .49122 L
.46587 .49225 L
.46146 .49301 L
.45893 .49339 L
.45604 .49386 L
.45317 .49444 L
.45041 .4952 L
.4477 .49624 L
.44612 .49704 L
.44461 .49795 L
.44155 .50041 L
.43983 .50226 L
.43825 .50431 L
.43568 .50861 L
.433 .51487 L
.43173 .51874 L
.43045 .52348 L
.42842 .53369 L
.42747 .54044 L
.42702 .54444 L
.42665 .54839 L
.42612 .55582 L
Mistroke
.42591 .55999 L
.42582 .56222 L
.42574 .56464 L
.42568 .56728 L
.42564 .56978 L
.42561 .5728 L
.42561 .57558 L
.42563 .57826 L
.42567 .58119 L
.42573 .58399 L
.42581 .58659 L
.426 .59152 L
.42629 .597 L
.42712 .60817 L
.42826 .61896 L
.42959 .62858 L
.43146 .6392 L
.43357 .64857 L
.43563 .65594 L
.43806 .66292 L
.44098 .66947 L
.4439 .67439 L
.44695 .67813 L
.44855 .6796 L
.45033 .68089 L
.4519 .68175 L
.4536 .68242 L
.45523 .68281 L
.45673 .68298 L
.45864 .68295 L
.46043 .6827 L
.46242 .68218 L
.46343 .68184 L
.46454 .68139 L
.46845 .67935 L
.47215 .67688 L
.50108 .65069 L
.5178 .63617 L
.5261 .62776 L
.53012 .62267 L
.53372 .61717 L
.5404 .60347 L
.54388 .59364 L
.547 .58259 L
.55016 .5683 L
.55278 .55302 L
.55529 .53387 L
.55639 .52328 L
.55743 .51117 L
.55831 .49856 L
Mistroke
.55897 .48649 L
.55946 .47464 L
.55982 .46182 L
.56001 .45025 L
.56006 .43937 L
.55999 .42747 L
.55974 .41483 L
.5593 .40177 L
.55897 .39457 L
.55861 .38802 L
.55775 .37552 L
.55681 .36483 L
.55462 .34642 L
.5532 .33756 L
.55175 .33006 L
.54881 .31857 L
.5472 .31387 L
.54536 .30955 L
.54373 .30652 L
.54193 .30392 L
.54018 .30205 L
.53855 .30082 L
.53648 .29987 L
.53453 .29951 L
.53236 .29966 L
.53003 .30036 L
.52799 .30136 L
.52608 .30258 L
.52168 .30621 L
.50401 .32618 L
.48573 .34749 L
.47829 .35726 L
.47053 .37072 L
.46623 .38086 L
.46249 .39215 L
.45896 .40587 L
.45589 .42123 L
.453 .4401 L
.45069 .46016 L
.44868 .48452 L
.44781 .49907 L
.44719 .51278 L
.44674 .52731 L
.44649 .54089 L
.44643 .54872 L
.44642 .55578 L
.44647 .56387 L
.44657 .57141 L
.4469 .58487 L
.44736 .59682 L
Mistroke
.44803 .60937 L
.44893 .62182 L
.4508 .64028 L
.45205 .64939 L
.4533 .65689 L
.45455 .66316 L
.456 .66921 L
.45885 .67816 L
.46055 .68207 L
.46249 .68553 L
.4635 .68695 L
.4646 .68825 L
.46663 .69004 L
.46859 .69112 L
.47069 .69168 L
.4725 .69176 L
.47451 .69146 L
.47563 .69115 L
.47683 .69071 L
.47898 .6897 L
.48389 .68658 L
.49288 .6794 L
.50994 .66567 L
.51886 .65797 L
.52388 .6525 L
.52843 .64617 L
.5337 .63632 L
.53853 .62383 L
.54272 .60903 L
.5469 .58881 L
.55001 .56836 L
.55146 .5564 L
.55284 .54295 L
.55391 .53049 L
.55493 .51624 L
.55569 .50294 L
.55627 .49007 L
.55656 .48204 L
.55682 .47328 L
.55711 .45791 L
.55719 .44923 L
.5572 .44009 L
.55716 .43237 L
.55705 .42397 L
.5567 .40939 L
.55643 .40146 L
.55612 .3944 L
.55538 .38128 L
.55452 .36963 L
.55338 .35758 L
Mistroke
.55219 .34768 L
.55075 .33814 L
.54904 .32917 L
.54733 .32209 L
.54565 .31662 L
.54396 .31229 L
.54211 .30862 L
.54003 .30563 L
.53883 .30437 L
.53773 .30347 L
.53554 .30234 L
.53344 .30195 L
.53224 .30199 L
.53096 .30223 L
.52863 .30309 L
.52734 .30378 L
.52612 .30455 L
.52333 .30669 L
.51493 .31522 L
.50581 .32594 L
.48768 .34674 L
.47965 .35641 L
.47122 .36899 L
.46723 .37659 L
.46356 .38499 L
.45708 .40458 L
.45373 .41813 L
.45085 .43251 L
.44803 .45012 L
.44545 .47092 L
.44436 .48194 L
.44333 .4943 L
.44257 .50542 L
.44191 .5174 L
.44164 .52354 L
.44142 .52931 L
.44112 .54005 L
.44095 .55002 L
.4409 .56059 L
.44098 .57029 L
.44116 .57907 L
.44147 .58836 L
.44193 .59784 L
.44256 .60722 L
.44327 .61551 L
.44403 .62253 L
.44492 .6294 L
.44679 .64037 L
.44877 .64874 L
.45112 .65591 L
Mistroke
.45255 .65918 L
.45394 .66173 L
.45548 .66395 L
.45717 .66577 L
.4588 .66701 L
.46031 .66778 L
.46125 .66808 L
.46213 .66827 L
.4631 .66836 L
.46413 .66835 L
.46588 .66808 L
.46688 .66781 L
.46782 .66748 L
.46964 .66667 L
.47138 .6657 L
.47466 .66346 L
.4821 .65711 L
.5093 .63163 L
.52365 .61885 L
.53897 .6024 L
.55172 .58348 L
.56479 .55652 L
.57658 .52407 L
.58535 .49495 L
.59329 .46765 L
.59648 .4582 L
.59777 .45494 L
.59913 .452 L
.60042 .4497 L
.6016 .44806 L
.60273 .44692 L
.60329 .4465 L
.60392 .44614 L
.60459 .44588 L
.60521 .44574 L
.60555 .44571 L
.60593 .4457 L
.60663 .44577 L
.60728 .44593 L
.608 .44618 L
.60931 .44683 L
.61255 .44907 L
.61632 .45189 L
.61799 .45296 L
.61985 .45391 L
.62041 .45414 L
.62095 .45432 L
.62196 .45459 L
.62294 .45472 L
.62401 .45472 L
Mistroke
.62503 .45456 L
.62562 .45439 L
.62618 .45417 L
.6273 .45357 L
.62793 .45311 L
.62851 .45262 L
.63057 .45022 L
.63159 .44859 L
.6327 .44644 L
.63497 .44052 L
.63618 .43627 L
.63724 .43178 L
.63817 .42699 L
.63912 .42113 L
.63993 .41496 L
.64062 .40858 L
.64123 .4015 L
.64172 .39448 L
.64215 .38605 L
.64235 .38111 L
.64249 .37624 L
.64261 .37136 L
.64269 .36599 L
.64274 .35585 L
.6427 .34934 L
.64262 .34302 L
.6425 .33718 L
.64233 .33072 L
.64192 .31944 L
.64131 .3066 L
.63951 .27942 L
.63711 .25322 L
.63421 .22847 L
.63191 .21202 L
Mfstroke
.51667 .46667 m
.51518 .47006 L
.51379 .47412 L
.51266 .47845 L
.51226 .48035 L
.51192 .48237 L
.51177 .48349 L
.51165 .4845 L
.51156 .48543 L
.51152 .48592 L
.51149 .48643 L
.51146 .48689 L
.51144 .4873 L
.51143 .48771 L
.51142 .48809 L
.51142 .48851 L
.51142 .4889 L
.51143 .48932 L
.51143 .48955 L
.51144 .48976 L
.51146 .49019 L
.51149 .49064 L
.51156 .49143 L
.51166 .49223 L
.5118 .49308 L
.51195 .49377 L
.51213 .49447 L
.51253 .49563 L
.51302 .49668 L
.51355 .4975 L
.51422 .49824 L
.51458 .49854 L
.515 .49882 L
.51539 .49901 L
.51576 .49914 L
.51596 .4992 L
.51618 .49924 L
.51629 .49926 L
.51641 .49928 L
.51652 .49929 L
.51663 .4993 L
.51684 .4993 L
.51704 .4993 L
.51726 .49928 L
.51737 .49927 L
.51749 .49925 L
.5177 .49921 L
.51792 .49916 L
.51834 .49903 L
.51881 .49884 L
Mistroke
.51931 .49858 L
.52024 .49798 L
.52135 .49703 L
.52236 .49596 L
.52433 .49333 L
.52608 .49036 L
.53135 .47828 L
.53232 .4761 L
.53276 .4753 L
.53314 .47473 L
.53354 .47429 L
.53376 .47411 L
.53397 .47399 L
.53409 .47395 L
.53415 .47393 L
.53421 .47391 L
.53431 .47389 L
.53436 .47389 L
.53442 .47388 L
.53449 .47388 L
.53455 .47388 L
.53462 .47389 L
.53469 .4739 L
.53475 .47391 L
.53481 .47392 L
.53494 .47396 L
.53516 .47405 L
.53541 .47418 L
.53595 .47455 L
.53707 .47553 L
.54052 .4789 L
.54277 .48084 L
.54534 .48264 L
.54694 .48353 L
.54785 .48394 L
.54885 .48432 L
.54972 .48458 L
.55019 .48469 L
.55071 .48479 L
.5512 .48486 L
.55165 .4849 L
.55209 .48491 L
.55255 .48491 L
.55304 .48488 L
.55332 .48485 L
.55357 .48481 L
.55405 .48472 L
.55456 .4846 L
.55546 .48428 L
.55646 .48379 L
Mistroke
.55753 .48307 L
.5587 .48203 L
.5598 .48078 L
.56079 .47938 L
.56266 .47588 L
.56367 .47337 L
.56457 .47067 L
.56608 .46469 L
.56682 .46073 L
.56741 .45674 L
.56796 .45209 L
.56843 .44649 L
.56861 .44348 L
.56869 .44176 L
.56876 .44011 L
.56886 .43681 L
.56891 .4337 L
.56892 .43069 L
.5689 .42742 L
.56884 .42457 L
.56875 .42136 L
.5686 .41787 L
.56839 .41404 L
.56787 .407 L
.56709 .39928 L
.56598 .39089 L
.56452 .38238 L
.56289 .37487 L
.55935 .36285 L
.55703 .3572 L
.55474 .35284 L
.55242 .34947 L
.54973 .34662 L
.54832 .34553 L
.54677 .34462 L
.54528 .344 L
.54389 .34363 L
.54249 .34345 L
.54118 .34344 L
.53973 .3436 L
.53816 .34396 L
.53666 .34448 L
.53523 .3451 L
.53254 .34662 L
.52587 .3519 L
.51973 .35814 L
.50599 .37403 L
.48252 .40051 L
.47621 .40877 L
.4728 .41414 L
Mistroke
.46965 .42003 L
.46679 .4264 L
.46381 .43447 L
.45903 .45206 L
.45694 .46253 L
.45494 .47516 L
.45334 .48833 L
.45213 .50133 L
.45154 .50957 L
.45109 .51744 L
.4507 .52625 L
.45054 .53123 L
.45042 .53578 L
.4503 .54417 L
.45027 .54889 L
.45028 .55323 L
.45038 .56116 L
.45059 .56942 L
.45092 .57778 L
.45133 .58519 L
.45192 .59341 L
.4526 .60082 L
.45406 .61292 L
.45602 .62435 L
.45717 .62954 L
.45855 .63463 L
.45998 .63893 L
.46161 .64285 L
.46321 .64585 L
.46473 .64808 L
.46622 .64976 L
.46785 .65108 L
.4694 .65194 L
.47029 .65227 L
.47112 .65248 L
.47266 .65264 L
.47431 .65254 L
.47581 .65223 L
.47722 .65178 L
.47878 .65111 L
.48047 .65024 L
.48785 .64514 L
.49468 .63966 L
.50735 .62994 L
.51443 .62453 L
.52115 .61827 L
.52478 .61387 L
.52867 .60787 L
.53213 .60095 L
.53522 .59308 L
Mistroke
.53801 .5841 L
.54089 .57233 L
.54364 .55779 L
.5459 .54214 L
.54703 .53238 L
.54813 .52114 L
.54896 .51074 L
.54971 .49928 L
.55026 .48868 L
.55071 .47676 L
.55099 .4658 L
.55112 .45551 L
.55113 .44341 L
.55107 .4374 L
.55096 .43092 L
.55064 .4197 L
.5502 .40966 L
.54952 .39836 L
.54875 .38875 L
.54769 .37854 L
.54654 .36985 L
.54548 .36335 L
.54424 .35713 L
.54177 .34789 L
.54014 .34348 L
.53852 .34012 L
.53701 .33776 L
.53532 .33585 L
.53364 .33461 L
.53266 .33415 L
.53173 .33387 L
.53075 .33373 L
.52985 .33373 L
.52885 .33387 L
.52779 .33415 L
.526 .33492 L
.52434 .33592 L
.52052 .33904 L
.51364 .34656 L
.50744 .35429 L
.49376 .37123 L
.48073 .38783 L
.47435 .39844 L
.46767 .41404 L
.46442 .42438 L
.46119 .43748 L
.45845 .45179 L
.45625 .46649 L
.45444 .48219 L
.45364 .49092 L
Mistroke
.4529 .50049 L
.45231 .50986 L
.45189 .51846 L
.45156 .52715 L
.45136 .53532 L
.45125 .54362 L
.45124 .55239 L
.45133 .56048 L
.45151 .56767 L
.45181 .57581 L
.45204 .58025 L
.45228 .58425 L
.45282 .59174 L
.45343 .59834 L
.45489 .61008 L
.4558 .61558 L
.45686 .62091 L
.45801 .62559 L
.4593 .62986 L
.46058 .63328 L
.4618 .63591 L
.4629 .63786 L
.46414 .63961 L
.46548 .64108 L
.46677 .64213 L
.46801 .64283 L
.46935 .64331 L
.47051 .64352 L
.47179 .64356 L
.47332 .64336 L
.47474 .64298 L
.47552 .64269 L
.47638 .64233 L
.47795 .64153 L
.48386 .63749 L
.50938 .61605 L
.51642 .61024 L
.52391 .6031 L
.53028 .59535 L
.5371 .58414 L
.54368 .56897 L
.54926 .55101 L
.55444 .52768 L
.55685 .51321 L
.5587 .49947 L
.56004 .48717 L
.56115 .47412 L
.5616 .4674 L
.56199 .4601 L
.56213 .45695 L
Mistroke
.56226 .4536 L
.56243 .44767 L
.56252 .4419 L
.56254 .43871 L
.56254 .43582 L
.56249 .43066 L
.56236 .4254 L
.56216 .42049 L
.56192 .41609 L
.56165 .41235 L
.5613 .40852 L
.56045 .40145 L
.55989 .39792 L
.55933 .39497 L
.55813 .38999 L
.55685 .38613 L
.55608 .38432 L
.55523 .38267 L
.55446 .38145 L
.55361 .38035 L
.55267 .37941 L
.55177 .37874 L
.55124 .37843 L
.55067 .37818 L
.55018 .37801 L
.54964 .37788 L
.54912 .37781 L
.54855 .37778 L
.54801 .37781 L
.54751 .37787 L
.54655 .37808 L
.54552 .37843 L
.54441 .37895 L
.54337 .37955 L
.54096 .38129 L
.53266 .38979 L
.50247 .42584 L
.48648 .44063 L
.4707 .45208 L
.44355 .47637 L
Mfstroke
.51667 .48333 m
.51667 .48354 L
.51667 .48372 L
.51668 .48393 L
.51669 .48413 L
.5167 .4843 L
.51671 .48446 L
.51674 .48482 L
.51678 .48516 L
.51684 .48553 L
.51691 .48589 L
.51699 .4862 L
.51717 .48677 L
.51729 .48705 L
.51741 .48728 L
.51765 .48763 L
.5178 .48779 L
.51794 .4879 L
.51811 .488 L
.51821 .48804 L
.51825 .48806 L
.5183 .48807 L
.51838 .48809 L
.51847 .4881 L
.51856 .48811 L
.51861 .48811 L
.51866 .4881 L
.51875 .48809 L
.51883 .48807 L
.51892 .48805 L
.51902 .48801 L
.51918 .48793 L
.51937 .48781 L
.51978 .48746 L
.52022 .48694 L
.52099 .48566 L
.52162 .48421 L
.52219 .48245 L
.52265 .48062 L
.52293 .47906 L
.52302 .47838 L
.52305 .47806 L
.52308 .47774 L
.5231 .47749 L
.52311 .47736 L
.52311 .47723 L
.52312 .47712 L
.52312 .47702 L
.52312 .47693 L
.52312 .47685 L
Mistroke
.52312 .47677 L
.52312 .4767 L
.52311 .47662 L
.52311 .47656 L
.52311 .47651 L
.5231 .47646 L
.52309 .47637 L
.52308 .47633 L
.52308 .47629 L
.52307 .47626 L
.52306 .47623 L
.52305 .47621 L
.52304 .4762 L
.52303 .47619 L
.52303 .47618 L
.52302 .47618 L
.52301 .47618 L
.523 .47619 L
.52299 .47619 L
.52298 .47621 L
.52297 .47623 L
.52296 .47625 L
.52294 .47631 L
.52292 .47639 L
.5229 .47648 L
.52289 .47658 L
.52288 .47669 L
.52288 .47676 L
.52287 .47683 L
.52287 .47691 L
.52287 .47696 L
.52287 .477 L
.52286 .47704 L
.52286 .47709 L
.52286 .47714 L
.52286 .47719 L
.52287 .47728 L
.52287 .47734 L
.52287 .47739 L
.52287 .47748 L
.52288 .47758 L
.52289 .47776 L
.52291 .47797 L
.52294 .47821 L
.52302 .4787 L
.52312 .47919 L
.52341 .48016 L
.52387 .48126 L
.52456 .48248 L
.52535 .48357 L
Mistroke
.52645 .48478 L
.5279 .48608 L
.52952 .48728 L
.5313 .48839 L
.53357 .48956 L
.53498 .49014 L
.53639 .49061 L
.53784 .49098 L
.53827 .49106 L
.53868 .49113 L
.53906 .49118 L
.53948 .49123 L
.53989 .49126 L
.54026 .49128 L
.54065 .49129 L
.54102 .49128 L
.54145 .49126 L
.54186 .49123 L
.54231 .49118 L
.5428 .4911 L
.54323 .491 L
.54371 .49088 L
.54458 .49059 L
.54563 .49011 L
.5466 .48952 L
.54824 .4882 L
.55004 .48614 L
.55188 .48316 L
.55351 .47949 L
.55518 .47423 L
.55602 .47067 L
.55671 .46698 L
.55725 .46343 L
.55775 .45917 L
.55796 .45689 L
.55816 .45434 L
.55831 .45186 L
.55843 .44949 L
.55851 .44712 L
.55857 .44453 L
.55858 .44301 L
.55859 .44157 L
.55857 .43884 L
.55852 .43617 L
.55845 .43368 L
.55833 .43091 L
.55817 .42796 L
.55779 .42278 L
.55731 .41795 L
.55666 .41268 L
Mistroke
.55581 .40716 L
.55471 .40146 L
.55336 .39578 L
.55043 .38685 L
.54855 .38276 L
.54664 .37956 L
.54439 .3768 L
.54307 .37561 L
.54183 .37474 L
.54073 .37417 L
.53954 .37373 L
.5384 .37347 L
.53734 .37337 L
.53669 .37336 L
.53608 .3734 L
.53542 .37349 L
.53471 .37362 L
.5335 .37396 L
.53217 .37448 L
.52975 .37577 L
.52713 .3776 L
.52237 .38189 L
.5028 .40532 L
.49284 .41723 L
.48247 .42989 L
.47816 .43624 L
.47367 .44457 L
.47121 .45029 L
.46906 .4563 L
.46699 .46325 L
.46521 .47053 L
.46247 .48527 L
.46127 .49403 L
.46021 .50405 L
.45976 .50932 L
.45935 .51517 L
.45904 .52079 L
.45882 .52605 L
.45867 .53082 L
.45857 .53608 L
.45854 .54157 L
.45857 .54668 L
.45868 .5521 L
.45877 .55509 L
.45887 .55776 L
.45912 .56289 L
.45942 .56757 L
.46031 .57751 L
.46094 .58268 L
.46159 .58714 L
Mistroke
.46286 .59399 L
.46447 .6004 L
.46636 .60583 L
.46727 .60784 L
.46829 .60974 L
.46934 .61133 L
.47033 .61255 L
.47128 .6135 L
.47236 .61434 L
.47334 .6149 L
.47427 .61529 L
.47527 .61556 L
.47637 .61569 L
.4775 .61568 L
.47875 .61551 L
.47939 .61537 L
.48008 .61517 L
.48132 .61473 L
.48376 .61358 L
.486 .61228 L
.50645 .59827 L
.5123 .59441 L
.51553 .59201 L
.51858 .58937 L
.52396 .58321 L
.52677 .57882 L
.52973 .57299 L
.53243 .5662 L
.53517 .55744 L
.53734 .5486 L
.53954 .53735 L
.54159 .52363 L
.54252 .51579 L
.54339 .50711 L
.54405 .49919 L
.54464 .49026 L
.54508 .48197 L
.54538 .47415 L
.54559 .4662 L
.54566 .46172 L
.54569 .4576 L
.54569 .4501 L
.54558 .44231 L
.54539 .43553 L
.54514 .42937 L
.54479 .42286 L
.54431 .41619 L
.54371 .40955 L
.54294 .40284 L
.54217 .39743 L
Mistroke
.54126 .39221 L
.54028 .38759 L
.53932 .3839 L
.53829 .38064 L
.53729 .37802 L
.53618 .37568 L
.53514 .37391 L
.53395 .37235 L
.53263 .37111 L
.53133 .37031 L
.53059 .37003 L
.5299 .36986 L
.52861 .36978 L
.52722 .37 L
.52604 .3704 L
.52476 .37104 L
.52243 .37264 L
.51965 .37517 L
.51709 .37792 L
.49482 .40643 L
.48543 .41807 L
.47574 .4327 L
.47049 .4438 L
.4661 .45636 L
.46222 .47158 L
.46056 .47991 L
.45918 .48816 L
.45698 .50545 L
.45612 .51492 L
.45545 .52512 L
.45522 .53018 L
.45512 .53282 L
.45504 .53561 L
.45498 .53827 L
.45494 .54065 L
.45491 .54522 L
.45494 .54951 L
.45503 .55401 L
.45518 .5581 L
.45536 .56172 L
.45557 .56498 L
.45584 .56832 L
.45643 .57393 L
.45731 .57987 L
.45825 .58456 L
.45936 .58872 L
.46071 .59242 L
.4621 .59515 L
.46347 .59705 L
.46427 .59788 L
Mistroke
.46505 .59851 L
.46576 .59896 L
.46656 .59932 L
.46744 .59958 L
.46793 .59966 L
.46839 .5997 L
.46928 .59969 L
.47013 .59958 L
.47094 .59939 L
.4718 .5991 L
.47336 .59841 L
.47506 .59742 L
.47694 .5961 L
.49292 .58107 L
.52511 .55391 L
.54091 .54189 L
.54958 .53589 L
.55916 .53041 L
.56416 .52818 L
.56988 .52615 L
.58057 .52339 L
.58613 .52202 L
.58914 .52112 L
.59236 .51992 L
.59524 .51857 L
.59844 .51664 L
.60136 .51435 L
.6041 .51165 L
.60907 .50482 L
.61182 .49962 L
.61429 .49378 L
.61857 .47993 L
.62056 .47118 L
.62256 .46002 L
.62417 .44845 L
.62545 .43659 L
.62606 .4295 L
.62665 .42132 L
.62714 .41308 L
.6275 .40525 L
.62778 .39701 L
.62798 .38894 L
.6281 .38012 L
.62814 .37024 L
.62808 .3613 L
.62793 .3516 L
.62772 .34313 L
.6274 .33366 L
Mfstroke
.51667 .5 m
.51687 .49999 L
.51706 .49997 L
.51729 .49993 L
.5175 .49988 L
.51788 .49974 L
.5183 .49953 L
.51877 .49922 L
.51926 .4988 L
.52016 .49781 L
.52107 .49645 L
.52189 .49487 L
.52274 .4928 L
.52357 .49021 L
.52429 .48731 L
.52462 .48568 L
.52493 .48389 L
.52517 .48214 L
.52536 .48054 L
.5255 .47893 L
.52555 .47822 L
.5256 .47744 L
.52563 .47669 L
.52566 .47601 L
.52568 .47529 L
.52568 .4749 L
.52568 .47454 L
.52568 .47391 L
.52567 .47324 L
.52566 .47262 L
.52563 .47206 L
.5256 .47144 L
.52556 .47087 L
.5255 .47021 L
.52544 .46964 L
.52529 .46854 L
.52509 .46747 L
.52488 .46663 L
.52467 .46596 L
.5244 .46529 L
.52412 .46476 L
.52385 .46437 L
.52358 .46408 L
.52344 .46397 L
.52328 .46386 L
.52311 .46377 L
.52294 .46371 L
.52276 .46367 L
.52266 .46366 L
.52256 .46365 L
Mistroke
.52238 .46366 L
.52219 .4637 L
.522 .46376 L
.52181 .46383 L
.52147 .46402 L
.52106 .46432 L
.52068 .46467 L
.51983 .46568 L
.51838 .46799 L
.51714 .47054 L
.51587 .47371 L
.51487 .47669 L
.51411 .47943 L
.51379 .48079 L
.51351 .48216 L
.51332 .48325 L
.51316 .48438 L
.51311 .48485 L
.51306 .48535 L
.51303 .4858 L
.51301 .4862 L
.513 .48644 L
.513 .48667 L
.51299 .48686 L
.51299 .48708 L
.513 .4873 L
.513 .48741 L
.513 .48754 L
.51301 .48775 L
.51302 .48795 L
.51305 .48832 L
.51308 .48865 L
.51313 .48901 L
.51319 .48935 L
.51335 .49005 L
.51354 .49064 L
.51379 .49124 L
.51411 .49182 L
.51477 .49268 L
.51521 .49311 L
.51565 .49346 L
.51657 .49406 L
.5177 .49461 L
.51902 .49512 L
.52064 .49561 L
.52239 .49603 L
.52418 .49636 L
.52525 .49651 L
.52582 .49657 L
.52615 .4966 L
Mistroke
.52646 .49662 L
.52673 .49664 L
.52702 .49665 L
.52734 .49667 L
.52764 .49667 L
.52793 .49668 L
.52824 .49668 L
.52853 .49667 L
.5288 .49666 L
.52915 .49664 L
.52953 .49661 L
.52985 .49658 L
.53021 .49654 L
.53103 .49641 L
.53181 .49623 L
.53257 .49601 L
.53327 .49577 L
.53489 .49499 L
.53641 .49396 L
.53805 .49243 L
.53944 .4907 L
.54094 .48825 L
.54247 .48489 L
.54323 .48278 L
.54399 .48029 L
.5446 .47786 L
.54522 .47494 L
.54571 .47203 L
.54612 .46915 L
.54648 .46576 L
.54664 .46392 L
.54678 .46184 L
.54689 .45998 L
.54696 .4582 L
.54702 .45629 L
.54704 .45519 L
.54705 .45419 L
.54705 .45228 L
.54703 .45049 L
.54699 .4485 L
.54691 .44637 L
.54681 .44432 L
.54669 .44239 L
.5464 .43878 L
.54594 .43456 L
.54532 .43021 L
.54385 .42292 L
.54285 .41925 L
.5418 .41615 L
.54052 .41314 L
Mistroke
.53903 .41043 L
.53761 .40852 L
.5368 .40766 L
.53602 .40698 L
.53529 .40646 L
.5346 .40607 L
.53382 .40574 L
.53338 .4056 L
.53297 .40549 L
.53251 .40541 L
.5321 .40537 L
.53162 .40534 L
.53116 .40535 L
.53034 .40544 L
.52987 .40554 L
.52944 .40564 L
.52852 .40595 L
.52751 .4064 L
.52543 .40764 L
.52188 .41063 L
.51806 .41477 L
.5113 .42364 L
.49836 .44205 L
.49195 .45081 L
.48544 .46021 L
.48003 .47011 L
.47722 .47704 L
.47483 .48468 L
.47294 .49271 L
.4715 .50091 L
.47088 .50549 L
.47031 .51067 L
.47007 .51335 L
.46986 .51623 L
.46969 .51894 L
.46956 .52148 L
.46946 .52412 L
.46942 .52552 L
.46939 .52702 L
.46937 .52858 L
.46936 .53006 L
.46937 .53281 L
.46941 .53534 L
.46948 .53765 L
.46959 .54014 L
.46975 .54273 L
.46996 .54547 L
.47024 .54831 L
.47087 .55313 L
.47164 .55735 L
Mistroke
.47246 .56078 L
.47335 .56365 L
.47427 .56594 L
.47536 .56804 L
.47661 .56982 L
.47727 .57053 L
.47801 .57118 L
.47872 .57168 L
.4794 .57205 L
.48002 .5723 L
.48071 .57251 L
.48145 .57264 L
.48215 .57269 L
.48284 .57268 L
.48358 .57261 L
.48428 .5725 L
.48493 .57235 L
.48654 .57185 L
.48808 .57124 L
.49471 .56784 L
.50747 .56153 L
.51117 .5597 L
.51471 .55762 L
.51846 .55472 L
.52059 .55262 L
.5226 .55021 L
.52612 .54474 L
.52921 .53816 L
.53232 .52913 L
.53381 .52357 L
.5353 .51694 L
.53661 .50989 L
.53767 .50297 L
.5386 .49557 L
.53931 .48844 L
.53992 .48044 L
.54016 .47618 L
.54037 .47164 L
.54045 .46936 L
.54051 .4669 L
.54056 .46459 L
.54059 .46248 L
.5406 .45854 L
.54056 .45445 L
.54047 .4505 L
.54033 .447 L
.54012 .44312 L
.53986 .43959 L
.53929 .43379 L
.53889 .43078 L
Mistroke
.53849 .42817 L
.53741 .42287 L
.53629 .41892 L
.53561 .41709 L
.53484 .41538 L
.53407 .41402 L
.53334 .413 L
.53269 .41226 L
.53197 .41163 L
.53118 .41113 L
.53043 .41082 L
.52971 .41065 L
.52893 .41061 L
.52826 .41067 L
.52752 .41083 L
.52709 .41097 L
.52664 .41115 L
.52583 .41154 L
.52398 .41276 L
.52061 .41589 L
.50695 .43359 L
.48414 .45981 L
.46051 .48529 L
.44994 .4965 L
.44705 .49897 L
.44394 .50117 L
.44124 .50269 L
.43819 .50393 L
.43649 .50443 L
.43489 .50477 L
.434 .50491 L
.43301 .50503 L
.43256 .50507 L
.43207 .50511 L
.43164 .50514 L
.43118 .50516 L
.43071 .50518 L
.43027 .50519 L
.4298 .50519 L
.42929 .50519 L
.42883 .50519 L
.42834 .50518 L
.42745 .50515 L
.42651 .5051 L
.42561 .50505 L
.42389 .50494 L
.42204 .50481 L
.42101 .50476 L
.42003 .50471 L
.41918 .50469 L
Mistroke
.41826 .50468 L
.41723 .50469 L
.41627 .50473 L
.41573 .50477 L
.41516 .50482 L
.41411 .50495 L
.41347 .50506 L
.41285 .50518 L
.4117 .50546 L
.41058 .50581 L
.40954 .50621 L
.40717 .50743 L
.4052 .50885 L
.40339 .51053 L
.4013 .51302 L
.39935 .516 L
.39595 .5231 L
.39412 .52831 L
.39251 .53402 L
.39098 .5407 L
.38947 .54904 L
.38802 .55966 L
.38689 .57109 L
.38642 .57743 L
.38598 .5848 L
.38563 .59296 L
.38541 .60098 L
.38529 .60887 L
.38526 .61633 L
.38534 .62526 L
.38552 .63398 L
Mfstroke
.51667 .51667 m
.51746 .51622 L
.51831 .51562 L
.51986 .51418 L
.52168 .51179 L
.5233 .5089 L
.5249 .5051 L
.52648 .50009 L
.52777 .49455 L
.52875 .48889 L
.52916 .48577 L
.52953 .48234 L
.52979 .47906 L
.52989 .47761 L
.52997 .47606 L
.53001 .47512 L
.53004 .47426 L
.53009 .4726 L
.53011 .47168 L
.53012 .4707 L
.53012 .46977 L
.53012 .46893 L
.5301 .46743 L
.53007 .46659 L
.53005 .46581 L
.52998 .46428 L
.52989 .4627 L
.52976 .46111 L
.52962 .4597 L
.52923 .45675 L
.52879 .45446 L
.52825 .45236 L
.52771 .45078 L
.52715 .44956 L
.52649 .44851 L
.52609 .44804 L
.52572 .4477 L
.52536 .44744 L
.52502 .44725 L
.5247 .44713 L
.52435 .44705 L
.52396 .44703 L
.52376 .44703 L
.52354 .44706 L
.52316 .44714 L
.52279 .44726 L
.52242 .44743 L
.52206 .44762 L
.52139 .44808 L
.51987 .44949 L
Mistroke
.51823 .4515 L
.51673 .45369 L
.5135 .45926 L
.50436 .47804 L
.50103 .48468 L
.49805 .48976 L
.49678 .49154 L
.49548 .49308 L
.49427 .49424 L
.49315 .4951 L
.49196 .49583 L
.49062 .49644 L
.48929 .4969 L
.48796 .49724 L
.48639 .49753 L
.48457 .49779 L
.48085 .49822 L
.47869 .49853 L
.4774 .49876 L
.47617 .49903 L
.47377 .49977 L
.4725 .5003 L
.47109 .50105 L
.46952 .50211 L
.46803 .50342 L
.46668 .5049 L
.46524 .5069 L
.46372 .50965 L
.46221 .51328 L
.46104 .51704 L
.46048 .51929 L
.45993 .52194 L
.45945 .52478 L
.45906 .5276 L
.45876 .53046 L
.45863 .53198 L
.45851 .53366 L
.45842 .5352 L
.45835 .53663 L
.45831 .53803 L
.45827 .53953 L
.45825 .54119 L
.45826 .54276 L
.45828 .5445 L
.45833 .54638 L
.45837 .54735 L
.45842 .54839 L
.45852 .55026 L
.45886 .55447 L
.45927 .55808 L
Mistroke
.45985 .56195 L
.46046 .56527 L
.46124 .56866 L
.46294 .57417 L
.46398 .5767 L
.46518 .57907 L
.46631 .58083 L
.4676 .58242 L
.46843 .58323 L
.46921 .58386 L
.46997 .58437 L
.47081 .58481 L
.47159 .58512 L
.47233 .58533 L
.47313 .58548 L
.47358 .58553 L
.47399 .58555 L
.47477 .58554 L
.47517 .58551 L
.47562 .58546 L
.47641 .58533 L
.47716 .58515 L
.47887 .58457 L
.48074 .58372 L
.48749 .5794 L
.50169 .5693 L
.50961 .56463 L
.51412 .56184 L
.51845 .55851 L
.52262 .55408 L
.52496 .55079 L
.52707 .54711 L
.53067 .53874 L
.53237 .5335 L
.53412 .52688 L
.5369 .51258 L
.53818 .50332 L
.53914 .4942 L
.53983 .48528 L
.54014 .48009 L
.54036 .47523 L
.54052 .47051 L
.54062 .46623 L
.54068 .4613 L
.54067 .4567 L
.54061 .45197 L
.54048 .44699 L
.54029 .44241 L
.54007 .43835 L
.53976 .43375 L
Mistroke
.53934 .42899 L
.53839 .42103 L
.53783 .41743 L
.53716 .41378 L
.53645 .41054 L
.53562 .40742 L
.5348 .40486 L
.534 .4028 L
.53322 .4011 L
.53235 .39957 L
.53145 .39831 L
.53062 .39739 L
.52976 .39668 L
.52893 .39619 L
.52795 .39583 L
.52703 .39569 L
.52601 .39574 L
.52492 .396 L
.52403 .39636 L
.52306 .39687 L
.52131 .39812 L
.51732 .40212 L
.50011 .42661 L
.49276 .43701 L
.4853 .44791 L
.4789 .45967 L
.47556 .46796 L
.47272 .4771 L
.47046 .48665 L
.46872 .49631 L
.46725 .50768 L
.4667 .51356 L
.46644 .51693 L
.46625 .52004 L
.46609 .52307 L
.46596 .52639 L
.46591 .5281 L
.46588 .52969 L
.46585 .53135 L
.46584 .53312 L
.46584 .53466 L
.46585 .53631 L
.46589 .53926 L
.46598 .54205 L
.46609 .54457 L
.46625 .54717 L
.46642 .54952 L
.46684 .55368 L
.46739 .55777 L
.46811 .56171 L
Mistroke
.46897 .56518 L
.47002 .56836 L
.4706 .56973 L
.47125 .57101 L
.47184 .57198 L
.4725 .57289 L
.47318 .57365 L
.47382 .57423 L
.47446 .57468 L
.47514 .57505 L
.47576 .5753 L
.47636 .57545 L
.47702 .57555 L
.47774 .57557 L
.47845 .57552 L
.47911 .5754 L
.47987 .57521 L
.48059 .57497 L
.48189 .57441 L
.48332 .57365 L
.4897 .56913 L
.50306 .55884 L
.51615 .5497 L
.52338 .54381 L
.53121 .53559 L
.53856 .52547 L
.54488 .5146 L
.55564 .49235 L
.56005 .48325 L
.56434 .47602 L
.5665 .47342 L
.56772 .47231 L
.56888 .4715 L
.56939 .47122 L
.56994 .47097 L
.57042 .47079 L
.57094 .47064 L
.5715 .47052 L
.57203 .47045 L
.57235 .47042 L
.57267 .47041 L
.57325 .47042 L
.57378 .47047 L
.57436 .47055 L
.57491 .47066 L
.57543 .47079 L
.57798 .47168 L
.58065 .47288 L
.58379 .47434 L
.58526 .47496 L
Mistroke
.58689 .47553 L
.58771 .47577 L
.58848 .47596 L
.58919 .4761 L
.58997 .47621 L
.59073 .47628 L
.59157 .47629 L
.59246 .47623 L
.5933 .4761 L
.5941 .47591 L
.59483 .47567 L
.59568 .4753 L
.59649 .47486 L
.59812 .47367 L
.59966 .47213 L
.60134 .46989 L
.60313 .46673 L
.60485 .46273 L
.6066 .45746 L
.608 .452 L
.60941 .44492 L
.6106 .43709 L
.61153 .42895 L
.61198 .42402 L
.61241 .41832 L
.61274 .4126 L
.61299 .40704 L
.61317 .40166 L
.61329 .39641 L
.61336 .39043 L
.61337 .38375 L
.61329 .3765 L
.61313 .36937 L
.61292 .36279 L
.61262 .35543 L
Mfstroke
.51667 .53333 m
.51912 .53136 L
.52141 .52877 L
.52389 .52491 L
.52642 .5194 L
.52885 .51191 L
.53084 .50325 L
.53229 .49433 L
.53294 .48893 L
.53343 .48379 L
.5338 .47842 L
.53396 .47539 L
.53406 .47263 L
.53413 .47009 L
.53417 .46733 L
.53417 .46477 L
.53414 .46244 L
.53411 .46103 L
.53407 .45954 L
.53396 .45689 L
.53382 .45439 L
.53366 .45218 L
.53319 .44748 L
.53289 .4453 L
.53253 .44306 L
.53174 .43929 L
.5309 .43642 L
.5304 .43507 L
.52982 .43379 L
.5293 .43284 L
.5287 .43196 L
.52813 .43131 L
.52757 .43082 L
.52698 .43043 L
.52664 .43027 L
.52632 .43015 L
.52578 .43003 L
.52518 .43 L
.52488 .43002 L
.52455 .43007 L
.52396 .43023 L
.52336 .43047 L
.5227 .43081 L
.52136 .43176 L
.51893 .43416 L
.51356 .44156 L
.50468 .45624 L
.48981 .47769 L
.47707 .49287 L
.47096 .50012 L
Mistroke
.46781 .50356 L
.46447 .50668 L
.46277 .50797 L
.46114 .50899 L
.45964 .50974 L
.45886 .51005 L
.45798 .51035 L
.45719 .51056 L
.45634 .51074 L
.45585 .51082 L
.45541 .51088 L
.45496 .51092 L
.45452 .51095 L
.45412 .51097 L
.45369 .51099 L
.45331 .51099 L
.4529 .51098 L
.45244 .51096 L
.45195 .51093 L
.45148 .51089 L
.45104 .51085 L
.44908 .51058 L
.44686 .51016 L
.44249 .50927 L
.44111 .50903 L
.44037 .50891 L
.43956 .50881 L
.43885 .50873 L
.43847 .5087 L
.43805 .50867 L
.43732 .50864 L
.43662 .50863 L
.43589 .50864 L
.43547 .50867 L
.43508 .5087 L
.43436 .50878 L
.43358 .5089 L
.43288 .50905 L
.43222 .50922 L
.43069 .50977 L
.42916 .51053 L
.42772 .51149 L
.42614 .51287 L
.42444 .51477 L
.42268 .51733 L
.42104 .52036 L
.41959 .5237 L
.41811 .52792 L
.4169 .53221 L
.41566 .53765 L
Mistroke
.41462 .54336 L
.41378 .54922 L
.41293 .5569 L
.41254 .5615 L
.41223 .56612 L
.41199 .57057 L
.41182 .57487 L
.41168 .57978 L
.41161 .5852 L
.4116 .59079 L
.41163 .59404 L
.41168 .59713 L
.41176 .60043 L
.41185 .60349 L
.41213 .61048 L
.41246 .61655 L
.41291 .62326 L
.41399 .63559 L
.41569 .65 L
.41801 .66489 L
.42042 .67693 L
.42351 .68913 L
.42679 .69919 L
.4301 .70712 L
.43405 .71423 L
.43614 .71716 L
.43851 .71984 L
.44063 .72174 L
.44268 .72317 L
.44383 .7238 L
.44509 .72438 L
.44732 .72508 L
.44949 .72543 L
.45182 .72545 L
.45383 .7252 L
.45606 .72467 L
.45853 .7238 L
.46084 .72273 L
.46612 .71954 L
.47583 .71167 L
.49416 .69403 L
.51553 .67445 L
.52608 .6642 L
.53069 .65883 L
.53572 .65184 L
.54026 .64401 L
.54501 .63366 L
.54983 .61996 L
.55405 .60413 L
.55856 .58128 L
Mistroke
.56225 .55517 L
.56495 .5281 L
.56619 .51146 L
.56712 .49534 L
.56775 .48133 L
.56825 .46588 L
.56856 .45105 L
.5687 .43736 L
.56867 .42135 L
.56842 .40401 L
.56797 .38794 L
.56737 .37342 L
.56648 .35769 L
.56545 .34362 L
.56303 .31963 L
.56141 .3077 L
.55978 .29776 L
.55772 .28755 L
.55562 .27919 L
.55352 .2725 L
.55113 .26648 L
.54886 .2621 L
.54669 .25893 L
.54429 .25641 L
.54158 .25463 L
.5402 .2541 L
.53869 .25378 L
.53593 .25381 L
.53349 .25442 L
.53079 .25563 L
.52796 .2574 L
.52532 .25944 L
.51548 .26914 L
.49162 .29596 L
.48002 .30936 L
.47497 .3162 L
.46948 .32516 L
.46425 .33607 L
.45951 .34891 L
.45476 .36593 L
.45008 .38885 L
.44786 .40288 L
.44564 .41983 L
.44389 .43615 L
.44225 .45488 L
.44089 .47465 L
.43989 .49344 L
.43914 .51297 L
.43865 .53175 L
.43841 .54902 L
Mistroke
.43837 .56794 L
.43858 .58744 L
.43901 .60518 L
.43961 .62123 L
.44031 .63525 L
.44131 .65058 L
.44243 .66414 L
.44383 .6777 L
.44551 .69068 L
.44896 .71019 L
.45109 .71891 L
.45322 .72574 L
.45566 .73181 L
.45706 .73456 L
.45841 .73678 L
.46103 .74005 L
.46347 .74203 L
.46616 .74324 L
.46769 .74354 L
.46911 .7436 L
.47152 .74329 L
.47418 .74243 L
.47698 .74106 L
.47961 .73942 L
.50397 .71916 L
.51626 .70868 L
.52234 .70259 L
.52796 .69554 L
.53432 .68472 L
.53761 .6774 L
.54103 .66808 L
.5463 .64913 L
.54912 .6359 L
.55162 .62173 L
.55368 .6078 L
.55571 .59142 L
.55886 .55825 L
.56041 .53594 L
.56158 .51371 L
.56239 .49304 L
.56298 .47013 L
.56327 .44758 L
.5633 .4348 L
.56324 .42294 L
.5631 .41061 L
.56288 .39952 L
.56254 .387 L
.56213 .37544 L
.56119 .35598 L
.56009 .33915 L
Mistroke
.55864 .32222 L
.55684 .30609 L
.55494 .2929 L
.55303 .28241 L
.55076 .2727 L
.54821 .26442 L
.54588 .25879 L
.54362 .25476 L
.54107 .25159 L
.53826 .24952 L
.53572 .24868 L
.53292 .2487 L
.53024 .24948 L
.52774 .25076 L
.52549 .25228 L
.523 .25429 L
.51795 .25918 L
.49602 .2841 L
.48419 .29753 L
.47331 .31222 L
.4677 .32224 L
.46188 .33583 L
.45575 .35551 L
.45063 .37844 L
.44647 .40387 L
.44452 .419 L
.44266 .43624 L
.44123 .45226 L
.43987 .47075 L
.4389 .48712 L
.43808 .50497 L
.43743 .52459 L
.43707 .54287 L
.43696 .55402 L
.43693 .56442 L
.43708 .58351 L
.43746 .60123 L
.43802 .61681 L
.43886 .63299 L
.43997 .64886 L
.44108 .66112 L
.44244 .67311 L
.44528 .69162 L
.44724 .70095 L
.44922 .70841 L
.4511 .71403 L
.45324 .71903 L
.45562 .72321 L
.45794 .72609 L
.45929 .72733 L
Mistroke
.46054 .72821 L
.462 .72897 L
.46341 .72943 L
.46477 .72966 L
.46624 .7297 L
.4689 .72927 L
.47055 .72873 L
.4721 .72805 L
.47503 .72643 L
.48529 .71838 L
.49647 .70816 L
.50718 .69863 L
.51873 .6883 L
.52435 .68264 L
.52966 .67642 L
.53948 .66111 L
.54467 .65 L
.5493 .6375 L
.55412 .62105 L
.55886 .60023 L
.5631 .57597 L
.56652 .55039 L
.56954 .51986 L
.57087 .50192 L
.57185 .4852 L
.57252 .47029 L
.57298 .45628 L
.57324 .44384 L
.57337 .43059 L
.57333 .41655 L
.57323 .40965 L
.57308 .40223 L
.57267 .38959 L
.57213 .37837 L
.57145 .36777 L
.57067 .35834 L
.56891 .34244 L
.56776 .33462 L
.56661 .32804 L
.56367 .31553 L
.56197 .31022 L
.56004 .30545 L
.55812 .30181 L
.5563 .29916 L
.5546 .2973 L
.55269 .2958 L
.55066 .2948 L
.54873 .29433 L
.54763 .29425 L
.54643 .2943 L
Mistroke
.54422 .29473 L
.54205 .29553 L
.54003 .29655 L
.53542 .2997 L
.53048 .30399 L
.46532 .36999 L
.42921 .40916 L
.41373 .42692 L
.40561 .43537 L
.39693 .44314 L
.38827 .44924 L
.38024 .45334 L
.37629 .45487 L
.37194 .45625 L
.36384 .45831 L
.35895 .4595 L
.35428 .46083 L
.34933 .4627 L
.34667 .464 L
.3438 .46572 L
.34135 .4675 L
.33867 .46984 L
.33381 .47541 L
.32911 .4829 L
.32485 .49213 L
.32049 .50488 L
.3167 .51978 L
.31287 .54022 L
.31112 .5523 L
.30935 .56702 L
.30682 .59561 L
.30567 .61376 L
.30483 .63163 L
.30423 .64946 L
.3038 .67007 L
.30363 .69071 L
.30367 .71072 L
.30391 .73062 L
.30439 .75284 L
.30507 .77452 L
.30589 .79488 L
.30874 .84622 L
.31258 .89617 L
.31774 .94731 L
.32363 .99324 L
Mfstroke
.32363 .99324 m
.32472 1 L
s
.53333 .46667 m
.53332 .46421 L
.53328 .46202 L
.5332 .45953 L
.5331 .45724 L
.53297 .45517 L
.53284 .45331 L
.53246 .44933 L
.53198 .44565 L
.53133 .44202 L
.53054 .43874 L
.52971 .43618 L
.52926 .43509 L
.52875 .43403 L
.52828 .43322 L
.52777 .43248 L
.52724 .43187 L
.52675 .43142 L
.52625 .43106 L
.52577 .43081 L
.52519 .43062 L
.52458 .43054 L
.52404 .43055 L
.52345 .43066 L
.52311 .43076 L
.5228 .43087 L
.52211 .43121 L
.52084 .43207 L
.51954 .43323 L
.51817 .43474 L
.51572 .43798 L
.51043 .44663 L
.50196 .46217 L
.48963 .48313 L
.47972 .50098 L
.47369 .51555 L
.47261 .51815 L
.47172 .5199 L
.4713 .52054 L
.47085 .52104 L
.4706 .52125 L
.47047 .52133 L
.47036 .52139 L
.47025 .52144 L
.47014 .52148 L
.47002 .52151 L
.46996 .52152 L
.46989 .52153 L
.46978 .52154 L
.46972 .52154 L
Mistroke
.46966 .52154 L
.46954 .52153 L
.46943 .52151 L
.46937 .5215 L
.4693 .52148 L
.46918 .52145 L
.4689 .52134 L
.4684 .52107 L
.4678 .52066 L
.4651 .51841 L
.46101 .51531 L
.45955 .51444 L
.45803 .51368 L
.45656 .51311 L
.45568 .51286 L
.45527 .51276 L
.45484 .51267 L
.45444 .5126 L
.454 .51255 L
.4536 .51251 L
.45321 .51249 L
.45275 .51249 L
.45233 .51251 L
.45209 .51253 L
.45184 .51255 L
.45136 .51262 L
.45095 .5127 L
.45049 .51282 L
.44955 .51315 L
.44866 .51357 L
.44783 .51408 L
.44676 .51492 L
.44574 .51592 L
.44384 .51847 L
.4428 .52032 L
.44186 .52234 L
.4408 .52515 L
.43988 .52816 L
.43843 .53444 L
.43778 .53832 L
.43719 .54283 L
.43677 .54714 L
.43646 .55145 L
.43632 .55405 L
.43623 .5565 L
.43615 .55941 L
.43611 .56224 L
.43611 .56515 L
.43615 .56843 L
.43619 .57011 L
Mistroke
.43624 .57194 L
.43637 .57529 L
.43655 .57867 L
.43677 .58191 L
.43729 .58807 L
.43811 .59532 L
.43908 .60197 L
.44047 .60957 L
.44199 .61618 L
.44549 .62728 L
.44763 .63216 L
.4501 .63647 L
.4524 .63948 L
.45467 .64164 L
.45601 .6426 L
.45727 .6433 L
.45797 .64361 L
.45875 .64389 L
.46017 .64426 L
.46144 .64443 L
.46265 .64446 L
.46399 .64435 L
.46545 .64409 L
.46691 .64368 L
.46847 .6431 L
.47127 .64172 L
.47638 .63833 L
.48204 .63369 L
.50817 .61075 L
.5143 .60583 L
.52085 .60002 L
.52644 .59374 L
.53249 .58428 L
.5354 .57816 L
.53841 .57025 L
.54089 .56214 L
.54343 .55183 L
.54607 .53793 L
.54824 .52274 L
.54913 .51494 L
.54997 .50622 L
.5512 .48963 L
.55169 .48034 L
.55204 .47163 L
.5523 .46194 L
.55238 .45703 L
.55243 .45165 L
.55242 .44259 L
.55229 .43298 L
.55204 .42408 L
Mistroke
.55172 .41616 L
.55127 .40818 L
.55078 .40107 L
.55015 .39376 L
.54935 .38615 L
.54776 .37455 L
.54577 .36403 L
.54451 .3589 L
.54326 .35472 L
.54169 .35046 L
.5402 .34727 L
.53872 .34479 L
.53729 .34296 L
.53573 .34151 L
.53483 .3409 L
.534 .34048 L
.53252 .34001 L
.53113 .33988 L
.52958 .34004 L
.5279 .34055 L
.52612 .3414 L
.52443 .34248 L
.52125 .34509 L
.5073 .36127 L
.4925 .37962 L
.48005 .39602 L
.47673 .40155 L
.47323 .4085 L
.46723 .42463 L
.46444 .435 L
.46164 .44825 L
.45909 .46426 L
.45711 .48102 L
.45631 .48968 L
.45566 .49814 L
.45516 .50602 L
.45473 .51453 L
.45437 .52391 L
.45415 .53262 L
.45403 .54197 L
.45402 .54725 L
.45405 .55215 L
.45419 .56098 L
.45432 .56582 L
.45447 .57012 L
.45484 .57829 L
.45529 .58566 L
.45594 .59384 L
.45665 .60088 L
.45759 .60848 L
Mistroke
.45859 .61492 L
.4605 .62431 L
.46161 .62852 L
.46288 .63246 L
.46428 .63597 L
.46567 .63873 L
.46696 .64076 L
.4684 .64251 L
.46975 .64373 L
.47105 .64456 L
.47249 .64515 L
.47408 .64546 L
.47567 .64546 L
.47648 .64536 L
.47737 .64517 L
.47896 .64468 L
.48044 .64405 L
.48341 .64241 L
.48613 .6406 L
.49228 .63594 L
.505 .62625 L
.51208 .62103 L
.51878 .61537 L
.52603 .60688 L
.52982 .6007 L
.53378 .59227 L
.53724 .58265 L
.54034 .57161 L
.54291 .56001 L
.54544 .54557 L
.54751 .53043 L
.54935 .51261 L
.55006 .504 L
.55069 .4947 L
.55119 .48586 L
.55155 .47773 L
.55187 .46799 L
.55199 .46265 L
.55207 .45762 L
.55213 .44876 L
.55208 .43932 L
.55201 .43446 L
.55189 .42922 L
.55172 .42386 L
.55152 .41895 L
.55107 .41052 L
.55046 .40197 L
.5497 .39375 L
.54888 .38672 L
.54776 .37917 L
Mistroke
.54664 .37311 L
.5443 .36383 L
.54289 .35981 L
.54149 .35668 L
.54016 .35437 L
.53871 .35245 L
.53744 .35122 L
.53601 .35026 L
.53444 .34967 L
.53355 .34951 L
.53273 .34948 L
.53112 .34968 L
.52958 .35016 L
.52814 .35084 L
.52657 .35179 L
.52372 .35399 L
.51721 .36058 L
.50418 .3761 L
.48132 .40178 L
.46972 .41732 L
.46342 .42871 L
.45789 .44163 L
.45254 .45791 L
.44829 .47481 L
.44425 .49607 L
.44267 .50677 L
.44143 .51678 L
.44047 .52611 L
.43979 .53441 L
.43923 .54328 L
.43901 .54798 L
.43887 .55229 L
.43878 .55629 L
.43874 .56039 L
.43875 .56409 L
.4388 .56729 L
.43885 .56919 L
.43891 .57089 L
.43909 .57454 L
.43929 .57755 L
.43955 .58052 L
.44007 .58494 L
.44075 .58903 L
.4415 .59229 L
.44225 .59478 L
.44321 .59713 L
.4438 .5982 L
.44435 .59904 L
.44489 .59971 L
.44542 .60022 L
Mistroke
.44597 .60064 L
.4466 .60098 L
.44723 .6012 L
.44758 .60128 L
.4479 .60131 L
.44854 .60131 L
.44915 .60122 L
.4495 .60114 L
.44987 .60102 L
.45054 .60075 L
.45127 .60036 L
.45207 .59985 L
.45486 .59741 L
.45747 .59445 L
.46718 .58029 L
.48445 .55364 L
.49997 .53536 L
Mfstroke
.53333 .48333 m
.53352 .48065 L
.53367 .47818 L
.5338 .47553 L
.5339 .47264 L
.53397 .46997 L
.534 .46753 L
.534 .46522 L
.53398 .4628 L
.53392 .46024 L
.53383 .45755 L
.5337 .45508 L
.53356 .45288 L
.53337 .4504 L
.53311 .44782 L
.53254 .44346 L
.53182 .43946 L
.53106 .43633 L
.53006 .43334 L
.52957 .4322 L
.52903 .43114 L
.52854 .43035 L
.528 .42962 L
.52748 .42906 L
.52699 .42865 L
.52641 .42827 L
.52609 .42811 L
.52577 .428 L
.52521 .42787 L
.52459 .42784 L
.52396 .42791 L
.52361 .42799 L
.52328 .42809 L
.52267 .42835 L
.52202 .4287 L
.52064 .42971 L
.51912 .43117 L
.51333 .43905 L
.50393 .45532 L
.48882 .47986 L
.483 .48929 L
.47762 .49991 L
.47333 .51093 L
.47063 .51933 L
.46966 .52233 L
.46892 .52425 L
.46858 .52489 L
.4684 .52516 L
.46823 .52536 L
.46814 .52544 L
Mistroke
.46805 .52551 L
.468 .52554 L
.46795 .52557 L
.4679 .52559 L
.46785 .52561 L
.4678 .52562 L
.46776 .52563 L
.46771 .52563 L
.46766 .52564 L
.46761 .52564 L
.46756 .52563 L
.46747 .52562 L
.46738 .52559 L
.46728 .52555 L
.46707 .52543 L
.46687 .52527 L
.46667 .5251 L
.46558 .52388 L
.46274 .52052 L
.46082 .51862 L
.45959 .51761 L
.45834 .51672 L
.45708 .51597 L
.45585 .51538 L
.45516 .51512 L
.45438 .51489 L
.45395 .51479 L
.45354 .51471 L
.45315 .51466 L
.45272 .51462 L
.4523 .5146 L
.45206 .51459 L
.45184 .5146 L
.45143 .51463 L
.45098 .51468 L
.45058 .51475 L
.4502 .51484 L
.44932 .51513 L
.44886 .51533 L
.44837 .51558 L
.44748 .51615 L
.44651 .51694 L
.44546 .51805 L
.44371 .52055 L
.44276 .52235 L
.44192 .52428 L
.44037 .52886 L
.43908 .53431 L
.43844 .53785 L
.43792 .54151 L
Mistroke
.43744 .54589 L
.43722 .54853 L
.43705 .55105 L
.4369 .55376 L
.4368 .55638 L
.43675 .55793 L
.43672 .55935 L
.4367 .56102 L
.43669 .56262 L
.4367 .56559 L
.43674 .56839 L
.43683 .57153 L
.43689 .57313 L
.43698 .5749 L
.43736 .58111 L
.43786 .58686 L
.43861 .59353 L
.43951 .59978 L
.44156 .61046 L
.44296 .61608 L
.44442 .62092 L
.4479 .62964 L
.45011 .63359 L
.45228 .63656 L
.45429 .63865 L
.45658 .64034 L
.45778 .64097 L
.45908 .64148 L
.46032 .6418 L
.46147 .64197 L
.46288 .64202 L
.46359 .64198 L
.46439 .6419 L
.4658 .64163 L
.46714 .64125 L
.46873 .64066 L
.47019 .63998 L
.47352 .63807 L
.48538 .62847 L
.51035 .60687 L
.51676 .60164 L
.52282 .59586 L
.52825 .58911 L
.53101 .58474 L
.53397 .57902 L
.53935 .56479 L
.54207 .55482 L
.5444 .54399 L
.54634 .53265 L
.54796 .52075 L
Mistroke
.54952 .50572 L
.55064 .491 L
.55109 .48303 L
.55148 .47407 L
.55177 .46456 L
.55192 .45557 L
.55196 .44718 L
.55191 .43954 L
.55174 .43082 L
.55148 .42269 L
.55109 .41419 L
.55055 .40547 L
.54926 .39085 L
.54828 .38272 L
.54723 .3757 L
.54619 .36993 L
.54498 .36436 L
.54375 .35965 L
.54255 .35589 L
.54005 .34995 L
.53858 .34742 L
.53778 .34631 L
.53691 .3453 L
.5353 .34385 L
.53377 .34297 L
.53218 .34249 L
.53044 .34241 L
.52878 .34271 L
.52724 .34327 L
.52552 .34418 L
.52363 .34548 L
.51981 .34887 L
.49482 .37933 L
.48846 .38711 L
.48167 .3962 L
.47541 .40672 L
.46992 .41948 L
.46705 .42833 L
.4641 .43979 L
.46133 .45381 L
.45907 .46885 L
.45735 .48419 L
.4561 .49926 L
.45556 .50791 L
.4551 .51752 L
.45478 .5267 L
.4546 .53525 L
.45452 .54432 L
.45453 .54884 L
.45458 .55376 L
Mistroke
.45474 .56233 L
.455 .57009 L
.45521 .57469 L
.45544 .57893 L
.45595 .5866 L
.45662 .59438 L
.45748 .60224 L
.45924 .61397 L
.46025 .6191 L
.46147 .62412 L
.46257 .62786 L
.46381 .63137 L
.46504 .63417 L
.46622 .63637 L
.46752 .6383 L
.46873 .63971 L
.47011 .64092 L
.47162 .64183 L
.47309 .64235 L
.47394 .64251 L
.47472 .64258 L
.47618 .64252 L
.47774 .64221 L
.47907 .64179 L
.48052 .64118 L
.48315 .63977 L
.48921 .63555 L
.50267 .62523 L
.50992 .61996 L
.51774 .61367 L
.52458 .60621 L
.52844 .60046 L
.53199 .59366 L
.53791 .5777 L
.54097 .56608 L
.54355 .55365 L
.54592 .5391 L
.54779 .52447 L
.54868 .51588 L
.54954 .50622 L
.55017 .49765 L
.55076 .48803 L
.55119 .47904 L
.55149 .47059 L
.55171 .46168 L
.55183 .45218 L
.55182 .44352 L
.55172 .43548 L
.55155 .42845 L
.55128 .42102 L
Mistroke
.55106 .41657 L
.5508 .41189 L
.55022 .4038 L
.54954 .39645 L
.54883 .39018 L
.5469 .37774 L
.54578 .37247 L
.54445 .36746 L
.54323 .36379 L
.54203 .36084 L
.54057 .35804 L
.5392 .35604 L
.53786 .35459 L
.5366 .3536 L
.53519 .35289 L
.53366 .35253 L
.53229 .35251 L
.53077 .35278 L
.52918 .35336 L
.52768 .35413 L
.52498 .35601 L
.52208 .35855 L
.50948 .37283 L
.48725 .39819 L
.47501 .4125 L
.46871 .42167 L
.46229 .43347 L
.457 .44593 L
.4517 .46199 L
.44748 .47847 L
.44417 .49499 L
.44138 .51301 L
.44024 .52241 L
.43927 .53212 L
.43857 .54105 L
.43815 .54869 L
.438 .5522 L
.4379 .55586 L
.43784 .55918 L
.43782 .5621 L
.43784 .56483 L
.43789 .56761 L
.43796 .57012 L
.43806 .57229 L
.4382 .5747 L
.43839 .57716 L
.43882 .58118 L
.43907 .58298 L
.43938 .58479 L
.44008 .58797 L
Mistroke
.44081 .59035 L
.44156 .59211 L
.44201 .5929 L
.4425 .59361 L
.44299 .59416 L
.44343 .59454 L
.44369 .59472 L
.44397 .59488 L
.44428 .59502 L
.44457 .59511 L
.4451 .5952 L
.4454 .59521 L
.44568 .59519 L
.44623 .59508 L
.44676 .5949 L
.44724 .59468 L
.44776 .59438 L
.44894 .59348 L
.45003 .59243 L
.45399 .58722 L
.45799 .58042 L
.47051 .55468 L
.47907 .53738 L
.47938 .53682 L
Mfstroke
.53333 .5 m
.53406 .49435 L
.53471 .48803 L
.53518 .48186 L
.53535 .4791 L
.53549 .47616 L
.53562 .47267 L
.53571 .46945 L
.53575 .46601 L
.53576 .46407 L
.53575 .46227 L
.53571 .45906 L
.53563 .45619 L
.5355 .45295 L
.53533 .44997 L
.53512 .44699 L
.53489 .4444 L
.53425 .43901 L
.53353 .43457 L
.53274 .43093 L
.53168 .42735 L
.53061 .42472 L
.53002 .42359 L
.52934 .42254 L
.5286 .42166 L
.5279 .42103 L
.52754 .42078 L
.52716 .42056 L
.52646 .42028 L
.52607 .42019 L
.5257 .42014 L
.52529 .42012 L
.52484 .42016 L
.52408 .42032 L
.52369 .42044 L
.52327 .42062 L
.5218 .42147 L
.52035 .42265 L
.5188 .42422 L
.51601 .42764 L
.50387 .44675 L
.49414 .46178 L
.48464 .47572 L
.48058 .48262 L
.47666 .49071 L
.47349 .49904 L
.47111 .50698 L
.46924 .51502 L
.46852 .5189 L
.46792 .52285 L
Mistroke
.46752 .52614 L
.46738 .5276 L
.46728 .52885 L
.4672 .53005 L
.46718 .53058 L
.46715 .53111 L
.46714 .53166 L
.46713 .53214 L
.46712 .53263 L
.46712 .53315 L
.46713 .53366 L
.46714 .53411 L
.46715 .53433 L
.46716 .53456 L
.46719 .53502 L
.46722 .53538 L
.46726 .53575 L
.4673 .53604 L
.46734 .53633 L
.46744 .53681 L
.4675 .53702 L
.46756 .53721 L
.46762 .53737 L
.46768 .5375 L
.46774 .5376 L
.4678 .5377 L
.46788 .53779 L
.46792 .53782 L
.46796 .53785 L
.46804 .53789 L
.46812 .53791 L
.46816 .53791 L
.46821 .53791 L
.46826 .5379 L
.46831 .53788 L
.46839 .53783 L
.46848 .53776 L
.46864 .53759 L
.4688 .53737 L
.46913 .53669 L
.46941 .53591 L
.46967 .53491 L
.46979 .53435 L
.46991 .53373 L
.46999 .53316 L
.47007 .53253 L
.47013 .53189 L
.47016 .5316 L
.47018 .53128 L
.47019 .531 L
Mistroke
.4702 .53069 L
.47021 .53036 L
.47022 .53006 L
.47022 .52976 L
.47022 .52943 L
.47021 .52913 L
.4702 .52884 L
.47019 .52856 L
.47018 .5283 L
.47014 .52772 L
.47007 .52711 L
.46999 .52643 L
.46975 .52509 L
.46946 .52389 L
.46911 .5228 L
.46862 .52158 L
.46809 .52053 L
.46737 .51944 L
.4666 .51853 L
.46585 .51786 L
.46538 .51754 L
.46494 .51729 L
.46446 .51708 L
.46419 .51699 L
.46391 .51692 L
.46366 .51687 L
.46343 .51683 L
.46317 .51681 L
.46302 .51681 L
.46288 .51681 L
.46264 .51683 L
.46237 .51687 L
.46215 .51691 L
.46189 .51698 L
.46162 .51707 L
.46132 .51719 L
.46078 .51748 L
.46023 .51787 L
.45971 .51834 L
.45873 .51948 L
.45759 .52136 L
.4566 .5236 L
.45609 .52509 L
.45557 .52691 L
.45515 .52866 L
.45473 .53078 L
.4544 .53278 L
.45411 .5351 L
.45396 .53646 L
.45385 .53774 L
Mistroke
.45375 .53908 L
.45367 .54036 L
.45361 .54158 L
.45356 .5429 L
.45353 .54425 L
.45351 .54578 L
.45351 .54713 L
.45352 .5486 L
.45355 .55001 L
.4536 .55132 L
.45368 .55304 L
.45377 .55469 L
.45401 .5578 L
.45436 .56118 L
.45485 .56484 L
.45603 .57127 L
.45744 .57682 L
.45935 .58222 L
.4606 .58488 L
.46186 .58707 L
.46327 .58899 L
.46468 .59049 L
.46549 .59117 L
.46639 .5918 L
.46724 .59228 L
.46803 .59262 L
.46876 .59287 L
.46954 .59305 L
.47033 .59317 L
.47122 .59321 L
.47199 .59319 L
.47283 .5931 L
.47363 .59295 L
.47436 .59277 L
.47618 .59215 L
.47819 .59121 L
.4819 .58895 L
.49793 .57652 L
.51368 .56608 L
.51818 .56262 L
.52068 .56026 L
.52305 .55756 L
.52523 .55457 L
.52757 .55064 L
.53152 .54168 L
.53352 .53556 L
.53528 .52889 L
.53817 .51402 L
.53951 .50436 L
.54052 .49476 L
Mistroke
.54136 .48359 L
.54167 .47778 L
.54181 .4747 L
.54193 .47133 L
.54207 .46571 L
.54213 .46038 L
.54213 .45523 L
.54207 .45052 L
.54195 .44551 L
.54174 .44011 L
.54144 .43465 L
.54109 .42972 L
.54028 .42133 L
.53934 .4144 L
.53812 .40772 L
.53664 .40183 L
.53582 .39928 L
.53488 .39688 L
.53401 .39506 L
.53307 .39344 L
.53218 .39223 L
.53118 .39117 L
.53025 .39045 L
.52937 .38998 L
.52824 .38963 L
.52715 .38955 L
.52616 .38966 L
.52508 .38998 L
.52451 .39021 L
.52388 .39052 L
.52261 .3913 L
.52031 .39318 L
.51617 .39767 L
.51176 .40349 L
.50399 .41469 L
.48793 .43724 L
.48377 .44364 L
.47949 .45148 L
.47569 .46039 L
.47254 .47016 L
.46972 .48202 L
.4676 .49451 L
.4667 .50151 L
.4659 .50949 L
.46558 .51357 L
.46529 .51799 L
.46508 .52217 L
.46493 .52597 L
.46484 .52953 L
.46479 .53327 L
Mistroke
.46479 .53675 L
.46482 .53984 L
.46491 .54342 L
.46498 .54539 L
.46506 .54717 L
.46524 .55036 L
.46547 .55361 L
.46601 .5591 L
.46664 .56376 L
.46746 .56834 L
.46848 .57257 L
.46965 .57614 L
.47103 .57918 L
.47229 .58117 L
.47305 .58207 L
.47378 .58277 L
.47459 .58338 L
.47504 .58365 L
.47547 .58386 L
.47623 .58414 L
.47664 .58425 L
.47709 .58433 L
.47757 .58439 L
.47809 .58441 L
.47859 .58439 L
.47906 .58435 L
.47948 .58429 L
.47995 .58419 L
.4809 .58393 L
.48182 .5836 L
.4827 .58322 L
.48437 .58235 L
.48818 .5799 L
.49522 .57468 L
.51043 .56418 L
.51737 .55916 L
.52499 .55187 L
.52923 .54637 L
.53304 .54017 L
.53999 .52451 L
.54313 .51486 L
.54615 .50331 L
.54876 .49067 L
.55064 .47889 L
.55195 .46801 L
.55246 .46225 L
.55265 .45963 L
.5528 .45726 L
.55291 .45509 L
.553 .45318 L
Mistroke
.55306 .45114 L
.55311 .44903 L
.55312 .44711 L
.55312 .44607 L
.55311 .44512 L
.55308 .44346 L
.55302 .44179 L
.55294 .44026 L
.55285 .43894 L
.55273 .43758 L
.55258 .43626 L
.55229 .43428 L
.55191 .43245 L
.55153 .43111 L
.5513 .43049 L
.55108 .42997 L
.55086 .42955 L
.55062 .42916 L
.55041 .42888 L
.55018 .42863 L
.5499 .4284 L
.54965 .42825 L
.54937 .42815 L
.54906 .4281 L
.54878 .4281 L
.54848 .42816 L
.5482 .42827 L
.54794 .4284 L
.5473 .42886 L
.54661 .42955 L
.54536 .43126 L
.54408 .43352 L
.5428 .43627 L
.54076 .44167 L
.53919 .44683 L
.53792 .45212 L
.53746 .45453 L
.53711 .45669 L
.53687 .45851 L
.53669 .46037 L
.53663 .46131 L
.5366 .46182 L
.53658 .46228 L
.53657 .46267 L
.53657 .46309 L
.53656 .46351 L
.53657 .4639 L
.53658 .46426 L
.53659 .4646 L
.5366 .46489 L
Mistroke
.53662 .4652 L
.53667 .46585 L
.53674 .46641 L
.53683 .46696 L
.53692 .46742 L
.53704 .46788 L
.53719 .46829 L
.53735 .46863 L
.53744 .46879 L
.53753 .46891 L
.53761 .469 L
.53769 .46907 L
.53778 .46913 L
.53783 .46915 L
.53788 .46917 L
Mfstroke
.53333 .51667 m
.53445 .51051 L
.53551 .5034 L
.5363 .49685 L
.537 .48942 L
.53736 .48475 L
.53762 .48038 L
.53783 .47617 L
.53799 .4717 L
.53808 .4677 L
.53813 .46399 L
.53813 .45995 L
.53807 .45568 L
.53796 .45137 L
.53779 .44748 L
.53755 .44336 L
.53723 .43917 L
.53687 .43538 L
.53647 .43202 L
.53559 .42632 L
.53457 .42147 L
.5335 .41774 L
.53222 .41444 L
.53153 .4131 L
.53075 .41185 L
.52992 .41083 L
.52947 .41039 L
.52899 .40999 L
.52856 .4097 L
.52809 .40945 L
.52724 .40915 L
.5264 .40903 L
.52592 .40904 L
.52548 .40908 L
.52466 .40928 L
.5238 .40961 L
.52285 .41012 L
.52183 .41082 L
.51999 .4124 L
.51583 .41719 L
.50219 .43739 L
.49011 .45438 L
.48413 .46287 L
.47817 .47308 L
.4734 .48409 L
.47103 .49124 L
.46908 .49841 L
.46759 .50514 L
.46643 .51162 L
.4654 .51899 L
Mistroke
.46506 .52214 L
.46477 .52545 L
.46464 .52721 L
.46455 .5288 L
.46448 .53025 L
.46441 .53181 L
.46438 .53317 L
.46436 .5344 L
.46435 .53566 L
.46436 .53697 L
.46439 .53835 L
.46441 .5391 L
.46444 .53977 L
.4645 .54097 L
.46459 .54218 L
.46478 .54413 L
.46491 .54515 L
.46505 .54605 L
.46533 .54756 L
.46568 .54894 L
.466 .54997 L
.46639 .55093 L
.46684 .55179 L
.4671 .55218 L
.46736 .55251 L
.4676 .55277 L
.46787 .55301 L
.46812 .55318 L
.46836 .55332 L
.46864 .55344 L
.46891 .55352 L
.4692 .55356 L
.46936 .55358 L
.46951 .55358 L
.46977 .55356 L
.47006 .55351 L
.47036 .55343 L
.47065 .55333 L
.47131 .55301 L
.47193 .55262 L
.47333 .55143 L
.47598 .54838 L
.47869 .54453 L
.48688 .5309 L
.49349 .52025 L
.49609 .51679 L
.49882 .51401 L
.50033 .51289 L
.50101 .51248 L
.50178 .51209 L
Mistroke
.50325 .51153 L
.5041 .5113 L
.50492 .51113 L
.50578 .51101 L
.50628 .51095 L
.50676 .51091 L
.50767 .51085 L
.5082 .51083 L
.50869 .51081 L
.50966 .51078 L
.51062 .51075 L
.51112 .51073 L
.51166 .5107 L
.51228 .51065 L
.51286 .5106 L
.51347 .51053 L
.51416 .51042 L
.51477 .5103 L
.51544 .51014 L
.51675 .50973 L
.518 .50917 L
.51948 .50827 L
.52088 .50711 L
.52243 .50541 L
.52406 .50296 L
.52544 .50022 L
.52664 .49712 L
.52783 .49309 L
.52891 .48809 L
.52936 .48531 L
.52978 .48214 L
.53009 .47903 L
.53021 .47751 L
.5303 .47608 L
.53037 .47467 L
.53042 .47339 L
.53046 .47195 L
.53048 .47116 L
.53049 .47041 L
.53049 .46892 L
.53047 .46755 L
.53043 .46606 L
.5304 .46524 L
.53037 .4645 L
.53021 .46194 L
.53009 .46053 L
.52996 .45925 L
.52964 .45679 L
.52922 .45435 L
.52876 .45229 L
Mistroke
.52826 .45055 L
.52778 .44918 L
.5272 .44788 L
.52651 .44671 L
.52614 .44622 L
.52573 .44577 L
.52534 .44542 L
.52497 .44516 L
.5246 .44496 L
.52423 .44482 L
.52381 .44472 L
.52357 .44469 L
.52334 .44469 L
.52291 .44472 L
.5225 .44481 L
.52226 .44489 L
.52201 .44498 L
.52155 .4452 L
.52052 .44588 L
.51962 .44667 L
.51877 .44758 L
.51718 .44963 L
.51375 .45538 L
.50842 .46729 L
.50446 .47843 L
.50282 .484 L
.50165 .48869 L
.50085 .49277 L
.50054 .49486 L
.50043 .4958 L
.50035 .49665 L
.50028 .49747 L
.50025 .49788 L
.50023 .49832 L
.50022 .49856 L
.50021 .49879 L
.50021 .499 L
.5002 .49923 L
.5002 .49961 L
.5002 .50002 L
.5002 .50024 L
.5002 .50044 L
.50021 .50083 L
.50022 .50103 L
.50023 .50123 L
.50026 .50166 L
.50032 .50235 L
.50041 .50307 L
.50051 .50374 L
.50065 .50441 L
Mistroke
.50095 .50554 L
.50135 .50666 L
.50189 .50776 L
.50244 .50862 L
.50311 .50944 L
.50376 .51007 L
.50453 .51067 L
.50541 .51121 L
.5063 .51162 L
.50733 .51196 L
.50795 .51212 L
.50855 .51223 L
.5091 .5123 L
.50938 .51233 L
.50954 .51234 L
.50969 .51235 L
.50996 .51237 L
.51025 .51238 L
.51053 .51238 L
.51079 .51237 L
.5111 .51236 L
.51126 .51236 L
.51143 .51234 L
.51174 .51232 L
.51204 .51229 L
.51272 .5122 L
.51346 .51206 L
.5149 .5117 L
.51629 .51124 L
.51959 .50968 L
.52265 .50773 L
.52599 .50509 L
.53246 .499 L
.53845 .49338 L
.54162 .49097 L
.54328 .48996 L
.54509 .48909 L
.54607 .48871 L
.54697 .48843 L
.54789 .4882 L
.54879 .48803 L
.5493 .48795 L
.54985 .48789 L
.55033 .48785 L
.55086 .48783 L
.55116 .48782 L
.55143 .48781 L
.55176 .48782 L
.55206 .48782 L
.55262 .48784 L
Mistroke
.55293 .48786 L
.55323 .48788 L
.55766 .48853 L
.56021 .48906 L
.56309 .48966 L
.56437 .48989 L
.56578 .49009 L
.56661 .49018 L
.56737 .49025 L
.56815 .49029 L
.5689 .4903 L
.56959 .49028 L
.57033 .49024 L
.57096 .49018 L
.57167 .49008 L
.57244 .48993 L
.57327 .48971 L
.5748 .48917 L
.57622 .48848 L
.57754 .48762 L
.57901 .48642 L
.58058 .48479 L
.58222 .48262 L
.58375 .48009 L
.58511 .47733 L
.58652 .47387 L
.5877 .47037 L
.58893 .46596 L
.59091 .45662 L
.59188 .4504 L
.59279 .44292 L
.5935 .43508 L
.594 .42726 L
Mfstroke
.53333 .53333 m
.53485 .52668 L
.53632 .51875 L
.53745 .51127 L
.53851 .50256 L
.53907 .49699 L
.53952 .49169 L
.53988 .48663 L
.54021 .48098 L
.54044 .47586 L
.5406 .47106 L
.54072 .46599 L
.54077 .46057 L
.54075 .45494 L
.54066 .44982 L
.54058 .44693 L
.54048 .44434 L
.54021 .43872 L
.5399 .43402 L
.5395 .42918 L
.53909 .42523 L
.53857 .42115 L
.53746 .41432 L
.53607 .40828 L
.53463 .40381 L
.53315 .40059 L
.53219 .39904 L
.53127 .3979 L
.53023 .39696 L
.52969 .3966 L
.52909 .39629 L
.52808 .39597 L
.5275 .39589 L
.52696 .39588 L
.52597 .39601 L
.52491 .39633 L
.52395 .39678 L
.52291 .3974 L
.52104 .39885 L
.51678 .40334 L
.49925 .4277 L
.48448 .44739 L
.48064 .45326 L
.47672 .46034 L
.47351 .4674 L
.47034 .47613 L
.46762 .48562 L
.46549 .49512 L
.46375 .50525 L
.46249 .51511 L
Mistroke
.46196 .52062 L
.46173 .52361 L
.46155 .52639 L
.46141 .52895 L
.46129 .53167 L
.46122 .53409 L
.46118 .53627 L
.46116 .53881 L
.46118 .54111 L
.4612 .54239 L
.46122 .54354 L
.46127 .54484 L
.46132 .54605 L
.46144 .54838 L
.46159 .55043 L
.46179 .55256 L
.46203 .5547 L
.4625 .5578 L
.46308 .56066 L
.46365 .56279 L
.46433 .56478 L
.46514 .56656 L
.46561 .56737 L
.46608 .56804 L
.46652 .56857 L
.46702 .56906 L
.46748 .56942 L
.46792 .5697 L
.46834 .56991 L
.4688 .57007 L
.46932 .57019 L
.46981 .57024 L
.47032 .57024 L
.47088 .57017 L
.47141 .57006 L
.47191 .56991 L
.47281 .56954 L
.4738 .56901 L
.47585 .56758 L
.48047 .56327 L
.4847 .55864 L
.49406 .54821 L
.50315 .53929 L
.5118 .53228 L
.52059 .52662 L
.53085 .52157 L
.53665 .51896 L
.53984 .51735 L
.54332 .51527 L
.54641 .51294 L
Mistroke
.54983 .50954 L
.55292 .5054 L
.55574 .50032 L
.55856 .49331 L
.56004 .4885 L
.56132 .48342 L
.56243 .47806 L
.56336 .47249 L
.56428 .46544 L
.56496 .45847 L
.56544 .45152 L
.56562 .44787 L
.56577 .44374 L
.56585 .44013 L
.5659 .43618 L
.5659 .43238 L
.56587 .42888 L
.56577 .42442 L
.56563 .42026 L
.56541 .41567 L
.56511 .41077 L
.56445 .40258 L
.56347 .3937 L
.5623 .3855 L
.56075 .37702 L
.55885 .3689 L
.55684 .36216 L
.55475 .35665 L
.5527 .35239 L
.55016 .3484 L
.54762 .34556 L
.54625 .34445 L
.54471 .3435 L
.54393 .34313 L
.54307 .34281 L
.54151 .34244 L
.53993 .34232 L
.53841 .34242 L
.53703 .34269 L
.53551 .34315 L
.53368 .34394 L
.53201 .34485 L
.52824 .34749 L
.52141 .35382 L
.49442 .38479 L
.48286 .39788 L
.47682 .40583 L
.47356 .41095 L
.47053 .41652 L
.46767 .42275 L
Mistroke
.46469 .43065 L
.45987 .44785 L
.45775 .45811 L
.45573 .47031 L
.45423 .48179 L
.45284 .49546 L
.45218 .5038 L
.45165 .51197 L
.45126 .51947 L
.45093 .52779 L
.45079 .53256 L
.4507 .53691 L
.45062 .54194 L
.45058 .54668 L
.4506 .5551 L
.45066 .55981 L
.45075 .56411 L
.45097 .57177 L
.45127 .57877 L
.45169 .58623 L
.45225 .59393 L
.45295 .6016 L
.45372 .60844 L
.45542 .62006 L
.45744 .62999 L
.4596 .63763 L
.46221 .64413 L
.46377 .64696 L
.46525 .64905 L
.46676 .65067 L
.46819 .6518 L
.4698 .65266 L
.47071 .65298 L
.47155 .65318 L
.47326 .65332 L
.47423 .65326 L
.47514 .65312 L
.47682 .65268 L
.47861 .65198 L
.48162 .65038 L
.48489 .64821 L
.49085 .64364 L
.50462 .63289 L
.51174 .62759 L
.51942 .621 L
.52385 .61602 L
.52782 .61022 L
.53174 .6027 L
.53531 .59367 L
.53854 .583 L
Mistroke
.5417 .56928 L
.54414 .55547 L
.54649 .53813 L
.54855 .51712 L
.54947 .50447 L
.55015 .49253 L
.55063 .48114 L
.55084 .47463 L
.551 .46859 L
.55117 .45749 L
.55121 .44578 L
.55111 .43533 L
.55086 .42418 L
.55044 .41295 L
.5499 .40299 L
.54928 .3941 L
.54862 .38649 L
.54683 .37118 L
.54565 .36373 L
.54447 .35763 L
.54309 .35189 L
.54148 .34656 L
.53999 .34273 L
.53855 .3398 L
.53697 .33737 L
.53522 .33545 L
.53354 .33428 L
.53196 .33367 L
.5302 .33348 L
.5283 .33377 L
.52664 .33439 L
.52508 .33524 L
.52148 .33797 L
.51529 .34443 L
.50865 .35256 L
.49375 .37099 L
.48021 .38825 L
.4736 .39943 L
.46689 .41553 L
.46335 .4273 L
.46027 .4404 L
.45779 .45384 L
.45545 .47012 L
.45377 .48535 L
.453 .49413 L
.45237 .50268 L
.45187 .51072 L
.45144 .51959 L
.45114 .52768 L
.45095 .53517 L
Mistroke
.45087 .5398 L
.45082 .54478 L
.45082 .55368 L
.45093 .56214 L
.45114 .56969 L
.45146 .57758 L
.45194 .58582 L
.45257 .59391 L
.45328 .60094 L
.45407 .60731 L
.45504 .61364 L
.45599 .61867 L
.45707 .62345 L
.45811 .62725 L
.45933 .63092 L
.46163 .63609 L
.4631 .63845 L
.4645 .64015 L
.46608 .64154 L
.46689 .64206 L
.46779 .6425 L
.46933 .64297 L
.47021 .64308 L
.47101 .6431 L
.47258 .64294 L
.47409 .64256 L
.4755 .64202 L
.47704 .64128 L
.47983 .63958 L
.48626 .63459 L
.49942 .62309 L
.51184 .61288 L
.52354 .60236 L
.53001 .5948 L
.53677 .58435 L
.54392 .56899 L
.54984 .55122 L
.55474 .53117 L
.55697 .5196 L
.55904 .50687 L
.56059 .49541 L
.562 .48277 L
.563 .47138 L
.5637 .46101 L
.56399 .45533 L
.56423 .44946 L
.56436 .44459 L
.56445 .4394 L
.56447 .43657 L
.56447 .43404 L
Mistroke
.56444 .43119 L
.5644 .42855 L
.56428 .42404 L
.56418 .42159 L
.56407 .41939 L
.56382 .41528 L
.56352 .41164 L
.56284 .40548 L
.56239 .40238 L
.56194 .39977 L
.56078 .39465 L
.55968 .39118 L
.55857 .38859 L
.55726 .3864 L
.5565 .38546 L
.55578 .38477 L
.55501 .38421 L
.55428 .38383 L
.55347 .38356 L
.55259 .38343 L
.55182 .38344 L
.55109 .38354 L
.55028 .38375 L
.5494 .38409 L
.54772 .38501 L
.54591 .38633 L
.54262 .38942 L
.53522 .39837 L
.5211 .41769 L
.49562 .44677 L
.47406 .46417 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00X_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP2iooooo`00X_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`2iooooo`00V_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo0;Oooooo002Uooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000@?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06Kooooo002Tooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Vooooo`00YOooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`0:ooooo`?o0000<oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06Kooooo002Rooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo002Rooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooooooool4o`00037ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Vooooo`00]Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
00000oooool2o`00033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`00
]Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000ooooool0
0000;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo002eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool000002?ooool2o`00033ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Vooooo`00]Oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000;oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06Kooooo002eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
2_ooool2o`0002oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Vooooo`00]Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I_ooool00;Gooooo0_l0
0002ooooo`03o`000?oooooo000000gooooo0_l0000^ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0I_ooool00;Gooooo00Ko0000oooooooooooo0000ooooool0000?ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`00]Ooo
ool01Ol0003oooooo`000?oooooo0000013ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06Gooooo002eooooo`;o000000?oooooo`000?ooool02_oo
ool5o`000003ooooool0003o000002gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Uooooo`00]Oooool00ol0003oooooo`00000:ooooo`;o00001Oooool00ol0003oooooo`00000]
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00;Cooooo0ol0000:oooo
o`03o`000?oooooooooo00Kooooo0_l0000]ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0IOooool00;?ooooo00?o0000ooooool000002Oooool2o`0000[ooooo0_l0000/ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00;;ooooo00Co0000ooooool0003o
00002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Uooooo`00/Oooool01Ol0003oooooo`000?oooooo000000Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0IOooool00;7ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03Oooool2o`0002cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Uooooo`00/?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Uooooo`00[oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?
ooooo`;o0000:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo002^oooo
o`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0000[oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool00:gooooo0_l00006ooooo`05
o`000?ooooooooooooooool000002?ooool4o`0000;ooooo0ol00002ooooo`;o0000:oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo002/ooooo`;o00001oooool01?l0003o
ooooooooool00007ooooo`Ko00001Oooool01Ol0003oooooo`000?oooooo000002[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00Zoooool2o`0000Sooooo00?o0000oooo
ool000001_ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000002o`0002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Toooo
o`00Z_ooool00ol0003oooooo`000008ooooo`;o00001_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00?ooooo00Co0000ooooool0003o0000:_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06Cooooo002Zooooo`;o00002Oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oo
oooo000002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00ZOooool2
o`0000Wooooo0_l00006ooooo`04o`000?oooooo0000ooooo`Ko000000?oooooo`000?ooool00ooo
ool01Ol0003oooooo`000?oooooo000002Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Tooooo`00Z?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo000000Gooooo00Go
0000ooooool0003oooooo`000006ooooo`03o`000?oooooo000000Cooooo0_l000000ooooooo0000
ooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool00:Sooooo0_l0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`05ooooo`;o00001Oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00:Oooooo00?o0000ooooool000001oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000ooooool0003ooooo0_l00009ooooo`;o00001?ooool01?l0
003oooooooooool0000Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool0
0:Oooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00So0000oooooooooooo0000ooooool0
003oooooo`0000Kooooo1?l000000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`0002Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Tooooo`00Yoooool2o`0000Kooooo
00?o0000ooooooooool00oooool3o`000004ooooool0003oooooo`0000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000004ooooo`;o000000?oooooo`000?ooool0:?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Vooooo`;o00001_ooool00ol0003ooooo
ooooo`04ooooo`;o000000Coooooo`000?oooooo00001Oooool2o`0000Kooooo0ol00004ooooo`03
o`000?oooooo000002Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Tooooo`00
Y_ooool2o`0000Gooooo00?o0000ooooooooool01Oooool01Ol0003oooooo`000?oooooo000000Go
oooo00?o0000ooooooooool01oooool2o`0000Cooooo00Co0000oooooooooooo0000:?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Uooooo`;o00001Oooool00ol0003o
ooooooooo`05ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`08ooooo`;o
00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0I?ooool00:Gooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooool0
003oooooo`000005ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o000000?oooooo`00
0?ooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Uooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000002o`0000Go
oooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`0Wooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00:Cooooo0_l00004ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooool0003oooooo`000005ooooo`03o`000?oooooooooo00co
oooo0_l00003ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00:Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000ooooo`;o00001?ooool00ol0003o
ooooooooo`0>ooooo`;o00000_ooool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Tooooo`00Y?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool2o`0000Co
oooo00?o0000ooooooooool03_ooool3o`000003ooooool0003ooooo00;o00003oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00:Cooooo
00Go0000ooooooooooooooooo`000006ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00oooooo0ol000000ooooooo0000o`000002o`00013ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo002Sooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Aooooo`;o000000Koooooo`000?l0003o0000ooooool0000?
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1S
ooooo`00Xoooool01Ol0003ooooooooooooooooo000000Gooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`?o00005?ooool00ol0003oooooo`000003o`000003ooooool0003ooooo00kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo002S
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0000Wooooo1Ol00007ooooo`06o`000?oooooo0000ooooool0003ooooo0_l0000?ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00
X_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool3o`000003
ooooool0003ooooo00;o00004?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0Hoooool00:;ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo0_l000000ooooooo0000ooooo`02o`00013ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo002Rooooo`04o`000?ooooooooooo`00
00Cooooo00Co0000oooooooooooo00001?ooool2o`000003ooooool0003ooooo00Gooooo00?o0000
ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004
o`00013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06?ooooo002Qooooo`;o000000?oooooo`000?ooool00oooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o000000?oooooo`000?ooool01Oooool00ol0003oooooo`000004o`00013ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo002Q
ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001?l0000Aooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00XOooool00ol0003ooooo
o`000004ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooooooool7o`0000Gooooo00?o0000oooo
ool000000ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Sooooo`00X?ooool2o`000003ooooool0003ooooo00;o
oooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooooooo`Wo00001?ooool00ol0003oooooo`000003
o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06?ooooo002Pooooo`Wo000000Koooooo`000?lb<S;o0000oc8b<_l0
0006ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l00005ooooo`?o
00001?ooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo002Pooooo`06o`00
0?oooooo0000ob4Q8Oo^k^kooooo0_l000001ooooooo0000ogMgMonHV9Soooooo`000?mgMgL01_oo
ool00ol0003oooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo1_l000001?oooooo
0000ooooool00004ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool04?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool009[o
oooo1ol000001Ooooooo0000oiRHV?lQ8B7ok^k^00?o000000Kooooooa0@4?oooooo0000ooooool@
4106ooooo`;o00000_ooool01?l0003oooooooooooooool6o`000003ooooool0003ooooo00Oo0000
00?oooooo`000?ooool00_l000000ooooooo0000o`00000Aooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00X?ooool01Ol0003oooooo`00
0?ooooooV9RH00;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000Kooooo1?l00003
ooooo`;o000000?oooooo`000?ooool01Ol000000ooooooo0000o`000002o`000005ooooool0003o
ooooo`000?ooool00_l000000ooooooo0000o`00000Aooooo`04o`000?ooooooooooo`0001;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00Woooool3o`0000;ooooo00Co
0000ogMgMol0003o00000_ooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`000003oooo
ool0003ooooo00;ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o000000Coooooo`000?l0
003o00000_ooool2o`000004ooooool0003o0000ooooo`;o00004Oooool01Ol0003ooooooooooooo
oooo0000017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`00Woooool0
0ol0003oooooo`000002ooooo`?o00000oooool01Ol0003ooooooooooooooooo410@00Gooooo0ol0
0003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooo`000?ooool0
0ol00003ooooo`03o`000?oooooo000000Co00004Oooool01Ol0003ooooooooooooooooo0000017o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`00Woooool00ol0003ooooo
o`000002o`000003ooooool0003o000000;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL4oooo
o`03o`000?oooooo000000?ooooo0_l00002ooooo`;o00000oooool6o`000004ooooool0003ooooo
o`0000;ooooo00?o0000ooooooooool01?l0000Aooooo`05o`000?ooooooooooooooool000004Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo002Oooooo`;o000000?ooooo
oiRHV?l000000ol00002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01?l0003ooooo
o`000?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`000006ooooool0003o0000o`000?oooooo00004?ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W_oo
ool3o`000003ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`06ooooo`0:o`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`0000Kooooo1Ol00002
ooooo`;o000000Koooooo`000?l0003o0000ooooool0000Aooooo`04o`000?ooooooooooo`0001;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W_ooool3o`000003oooo
ool0003ooooo00;o00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooo`000?oo
ool00_l000000ooooooo0000ooooo`02o`0000;ooooo0_l00002ooooo`?o00000_ooool00ol0003o
ooooo`000002o`0000;ooooo00?o0000ooooool000000ol000000ooooooo0000ooooo`0@ooooo`04
o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Roooo
o`00W_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?ooool01_ooool01?l0
003oooooooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003o0000
0_ooool01?l0003oooooooooooooool2o`000003ooooool0003o000000?o000000?oooooo`000?oo
ool01?l000000ooooooo0000ooooo`0@ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Rooooo`00W_ooool2o`000005ooooool0003ooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00005ooooo`03o`000?oooooo000000Co000000?o
ooooo`000?l000001?l000000ooooooo0000ooooo`0@ooooo`04o`000?ooooooooooo`0001;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W_ooool3o`0000;ooooo0_l0
00000ooooooo0000ooooo`06ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0003ooooo
0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Kooooo1_l00002ooooo`05o`00
0?oooooo0000o`000?ooool00_l0000Aooooo`05o`000?ooooooooooooooool000004Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Mooooo`Co00000_ooool2o`000003
ooooool0003ooooo00Gooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003o`0000;o
oooo00Co0000oooooooooooo00002Oooool6o`0000;ooooo00Go0000ooooool0003o0000ooooo`02
o`00017ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0H_ooool009gooooo0ol00003ooooo`?o00001_ooool00ol0003oooooo`000002
ooooo`04o`000?oooooo0000ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000[ooooo
1Ol00002ooooo`05o`000?oooooo0000o`000?ooool00_l0000Aooooo`05o`000?oooooooooooooo
ool000004Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Mooooo`?o
00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0
003ooooo0_l00002ooooo`05o`000?ooooooooooooooool000002oooool6o`000003ooooool0003o
oooo00;o000000?oooooo`000?l000004Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00WOooool2o`0000?ooooo0_l00000
0ooooooo0000ooooo`03ooooo`09o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo00?o
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`Go000000?oooooo`000?oo
ool00_l000001?oooooo0000ooooool0000@ooooo`05o`000?ooooooooooooooool000004Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Mooooo`;o00000oooool3o`00
00Cooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo00cooooo1Ol000000ooooooo0000ooooo`02o`000004oooo
ool0003oooooo`00013ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0H_ooool009gooooo0_l00003ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01?l000000ooooooo0000o`000002ooooo`05o`000?oooooooooooooo
ool000003oooool5o`000003ooooool0003ooooo00;o000000Coooooo`000?oooooo00002oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`00WOooool2o`0000?ooooo0_l00005ooooo`06o`000?oooooo
0000ooooool0003ooooo0ol00002ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`Co0000
1oooool4o`000003ooooool0003ooooo00;o000000Coooooo`000?oooooo00002oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Rooooo`00WOooool01?l0003oooooooooooooool3o`0000Cooooo00Ko0000oooo
ool0003oooooo`000?ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool4o`000003ooooool0003ooooo00;o0000
00Coooooo`000?oooooo00002oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W?ooool2o`0000?o
oooo0_l00005ooooo`04o`000?oooooo0000ooooo`Co00000_ooool00ol0003oooooooooo`02o`00
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Ko00000_ooool3o`00
0003ooooool0003ooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000A
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009cooooo0_l00003oooo
o`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Cooooo1ol00000
1_oooooo0000o`000?l0003oooooo`0000cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009cooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool00ol0003ooooo
ooooo`03o`0000Gooooo00?o0000ooooooooool00ol00002ooooo`?o00001?ooool7o`000004oooo
ool0003o0000ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Voooool3o`0000?o
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_l000001Ooo
oooo0000oooooooooooo000000Gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02
ooooo`Go000000?oooooo`000?ooool00_l000000ooooooo0000o`00000<ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06;ooooo002Kooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooool000001?l00000
1Ooooooo0000o`000?oooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Oooooo
0_l00004ooooo`Co000000?oooooo`000?ooool00_l000000ooooooo0000o`00000<ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo002Kooooo`?o00000_ooool2o`0000Cooooo0ol000001?oooooo0000
o`000?ooool2o`000003ooooool0003ooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool4o`000003ooooool0003ooooo
00;o000000?oooooo`000?l000003?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`00017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Voooool3o`00
00;ooooo0_l00003ooooo`03o`000?oooooo000000Ko000000?oooooo`000?ooool01?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`Ko000000?ooooo
o`000?l000000ol0000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Jooooo`03o`000?oooooo
000000;ooooo0ol00003ooooo`04o`000?oooooo0000ooooo`Co000000?oooooo`000?ooool01Ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo
1_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
H_ooool009[ooooo00?o0000ooooool000000_ooool3o`0000?ooooo1ol00002ooooo`03o`000?oo
oooooooo00Cooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo1Ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000;o000000?oooooo`000?ooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Rooooo`00V_ooool3o`0000;ooooo0_l00004ooooo`Co000000Goooooo`000?l0003oooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000002o`000003ooooool0003ooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0H_ooool009Wooooo00Co0000ooooool0003o00000_ooool2o`0000Cooooo
0_l000001_oooooo0000o`000?l0003oooooo`0000Oooooo0_l000000ooooooo0000ooooo`05oooo
o`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Go000000?oooooo`000?l000000_l000000ooo
oooo0000ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000004Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Iooooo`04o`000?oooooo0000o`00
00;ooooo0_l00003ooooo`Go000000Coooooo`000?oooooo00001_ooool01?l0003oooooo`000?l0
0006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool5o`000003ooooool0
003o000000;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00VOoo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo1?l000001?oooooo0000
ooooool00006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000ooooool0003o00000oooool2
o`0000?ooooo00Co0000oooooooooooooooo1Ol000001ooooooo0000o`000?oooooo0000ooooool0
00003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Rooooo`00V?ooool00ol0003oooooooooo`02o`000003
ooooool0003o000000Cooooo1?l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00;o
00001Oooool00ol0003oooooo`000005o`000003ooooool0003o000000;ooooo0_l00002ooooo`Go
000000Ooooooo`000?l0003oooooo`000?oooooo000000cooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_oo
ool009Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00
0006ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool2o`000003ooooool0003ooooo00?o
oooo0_l000000ooooooo0000ooooo`02o`0000;ooooo1Ol000001ooooooo0000o`000?oooooo0000
ooooool000003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00V?ooool01?l0003oooooooooool0
0002ooooo`;o00000oooool4o`000003ooooool0003o000000Kooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool01Oooool3o`000003ooooool0
003o000000;ooooo1Ol000001?oooooo0000o`000?ooool3o`0000cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0H_ooool009Sooooo00Co0000ooooool0003o00000_ooool2o`0000?ooooo1_l00006ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00002ooooo`Co00001oooool3o`0000;ooooo00?o0000oooo
ooooool01Ol000001?oooooo0000o`000?ooool3o`0000cooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`00000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool0
09Oooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooooooo`Co000000?ooooo
o`000?l000001Oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooo`000?ooool0
0_l00009ooooo`;o00000_ooool00ol0003oooooooooo`05o`0000;ooooo00?o0000ooooool00000
0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06;ooooo002Gooooo`03o`000?oooooooooo00;o00000_oo
ool00ol0003oooooooooo`07o`0000Gooooo00Co0000oooooooooooo00001?ooool01?l0003ooooo
o`000?ooool2o`0000Gooooo1?l000001_oooooo0000o`000?l0003oooooo`0000;ooooo1Ol00002
ooooo`03o`000?oooooo000000;o00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Uoooool00ol0
003oooooooooo`02o`0000;ooooo00Co0000ooooool0003ooooo1_l00004ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooool000000_l00004ooooo`;o00000oooool5o`000004ooooool0
003oooooooooo`?o000000Koooooo`000?ooooooooooo`000?ooool3o`0000cooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0H_ooool009Oooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oooooo0000oooo
o`?o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo000000Gooooo1?l00004
ooooo`03o`000?oooooooooo00Cooooo1ol000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000000ol0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Gooooo`03o`000?oooooo
oooo00;o00000_ooool2o`000003ooooool0003o000000Co00001?ooool01?l0003oooooooooool0
0006ooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`Wo000000?oooooo`000?l000001?l0
00000ooooooo0000o`000003o`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009Kooooo00Co0000
oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`Go00001?ooool01?l0003ooooooooo
ool00005ooooo`Co00001?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`000004oooo
ool0003o0000ooooo`Ko000000?oooooo`000?l000000ol0000<ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;o
oooo002Fooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool3o`000003
ooooool0003ooooo00?ooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`000004ooooool0003o0000
ooooo`Ko000000?oooooo`000?l000000ol0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Foooo
o`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo1_l00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool00_ooool5o`0000?ooooo3ol0
00000ooooooo0000o`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Fooooo`04o`000?oooooo
ooooooooo`Co00000_ooool5o`0000Cooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`03o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo2?l000000ooooooo0000o`00
0007o`000003ooooool0003o000000gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009Kooooo00Ko0000
ooooooooooooooooo`000?ooool2o`0000;ooooo1Ol00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`02o`000005ooooool0003oooooooooool000000oooool2o`0000Cooooo0_l00003ooooo`Co
000000?oooooo`000?l000001ol000000ooooooo0000o`00000=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;o
oooo002Eooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool5o`0000?o
oooo00?o0000ooooool000001?ooool01?l0003oooooo`000?l00002ooooo`?o00000oooool2o`00
0003ooooool0003o000000?o000000Coooooo`000?oooooooooo3_l000000ooooooo0000o`00000=
ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0H_ooool009Gooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002
ooooo`Co00001?ooool2o`0000Cooooo00?o0000ooooool000000_l00002ooooo`;o00000oooool0
0ol0003oooooo`000008o`0000;ooooo1Ol000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`;o00003Oooool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06;ooooo002Eooooo`04o`000?ooooooooooooooo`;o000000Co
ooooo`000?l0003ooooo1Ol00004ooooo`;o00000oooool00ol0003oooooo`000002o`0000?ooooo
00Ko0000ooooooooooooooooo`000?ooool3o`000006ooooool0003oooooooooool0003ooooo2?l0
00000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00003Oooool00ol0003ooooo
ooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo
002Eooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o
00001?ooool4o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool3o`00
00;ooooo0_l000001?oooooo0000o`000?ooool5o`000004ooooool0003o0000ooooo`;o00003Ooo
ool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06;ooooo002Eooooo`03o`000?oooooooooo00?o000000Coooooo`000?l0003ooooo1?l0
0004ooooo`;o00000oooool4o`0000?ooooo00?o0000ooooool000000_ooool2o`000004ooooool0
003oooooo`0000;ooooo1_l00002ooooo`Co000000?oooooo`000?l000000ol000001?oooooo0000
o`000?ooool2o`0000gooooo00?o0000ooooooooool00oooool2o`00013ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Rooooo`00UOooool00ol0003oooooooooo`03o`000004oooo
ool0003o0000ooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool01Ol0003o
ooooooooool0003ooooo00;o000000Coooooo`000?oooooo00000_ooool2o`0000?ooooo0_l00002
ooooo`05o`000?oooooo0000o`000?ooool01Ol000001ooooooo0000o`000?oooooo0000ooooool0
00003?ooool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo002Dooooo`05o`000?ooooooooooo`000?ooool00ol000000ooooooo
0000ooooo`04o`0000?ooooo0_l00003ooooo`;o000000Goooooo`000?ooooooooooo`000003oooo
o`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`03ooooo`?o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000003o`000007ooooool0003o0000ooooool0003ooooo
o`00000<ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0H_ooool009Cooooo00?o0000ooooool000000_ooool5o`000003ooooool0
003o000000;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o0000
00?oooooo`000?ooool02oooool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06;ooooo002Dooooo`03o`000?oooooo000000;ooooo1Ol0
00001?oooooo0000o`000?l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003o
ooooooooo`02ooooo`;o000000Coooooo`000?l0003o00000oooool00ol0003oooooooooo`05oooo
o`;o00000_ooool9o`000003ooooool0003o000000;o000000?oooooo`000?l000002oooool00ol0
003oooooooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
06;ooooo002Dooooo`;o00000oooool9o`000003ooooool0003o000000;o000000So410@oooooooo
oooo0000oc8b<_l0003o<S8bo`0000Cooooo00?o0000ooooool000000ol00003ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02Ol000000ooooooo0000o`000004o`000003ooooool0
003ooooo00Wooooo00?o0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`00U?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002
o`0000?ooooo00Co0000oooooooooooooooo0ol000000oooooooV9RHo`000003ooooo`03o`000?oo
oooooooo00?o00000oooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l000001ol0
00000ooooooo0000o`000004o`000003ooooool0003o000000Wooooo00?o0000ooooooooool00ooo
ool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00U?ooool0
0ol0003oooooooooo`02ooooo`Wo00000oooool00ol0003oooooooooo`02o`000005oa0@4?l0003o
ooooo`000?l@41000_ooool01?l0003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000;o0000
00Goooooo`000?ooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00
U?ooool00ol0003oooooooooo`02ooooo`Co000000?oooooo`000?l000000_l00003ooooo`03o`00
0?oooooooooo00?o000000Koooooo`000?oooooo0000ooooool00003ooooo`;o00000oooool01?l0
003oooooooooooooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000ooooo`07
o`000003ooooool0003ooooo00;o000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`00Toooool00ol0003oooooooooo`02ooooo`Go000000?ooooo
o`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000ooooo`03
o`0000;ooooo0ol00002ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo0_l0
00000ooooooo0000ooooo`07o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooooooo
o`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`00013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Toooool00ol0003ooooooooo
o`02ooooo`?o000000?oooooo`000?ooool00ol00003ooooo`;o000000Koooooo`000?l0003o0000
oa0@4?l00002ooooo`;o00000_ooool2o`000004ooooool0003oooooo`0000?ooooo2Ol00002oooo
o`;o000000?oooooo`000?l000002Ol000001Ooooooo0000o`000?oooooo000000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0H_ooool009;ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000000ol00003ooooo`Ko000000GoMgMgo`000?ooooooV9RHo`000002ooooo`;o00000_oo
ool2o`0000?ooooo3?l000000ooooooo0000ooooo`09o`000003ooooool0003ooooo00;o000000?o
ooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00T_oo
ool2o`0000Cooooo1_l000000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?lb<S800ol0
00000ooooooo0000o`000003ooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0003o
0000ooooool0003ooooo00;o00000_oooolAo`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0H_ooool0097ooooo00?o0000ooooool000001?ooool9o`00
00;ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000007o`0000;ooooo4Ol000000ooooooo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`;o00004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Aooooo`03o`000?oooooo
000000Cooooo2Ol00002ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool00_l00000
0ooooooo0000o`000003ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool02Ol0
0002oooooa3o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Rooooo`00T?ooool01?l0003oooooooooool00004ooooo`Wo00000_ooool2o`000004oooo
ool0003o0000o`0000;ooooo00Co0000ooooool0003o00000oooool01Ol0003oooooooooool0003o
oooo00?o000000Coooooo`000?l0003o00001?ooool3o`0000;ooooo4?l000001?oooooo0000oooo
ooooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o0000
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002@ooooo`04o`000?oo
ooooooooo`0000Cooooo2Ol000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000Kooooo0_l00002
oooooa3o000000Coooooo`000?oooooooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Rooooo`00Soooool01?l0003oooooooooool00004ooooo`[o000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo1?l00002ooooo`;o00000oooool3o`000003ooooool0003o000000;o0000
1_ooool2o`0000;ooooo4_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo0_l0000?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
H_ooool008oooooo00Co0000oooooooooooo00001?ooool:o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_l00002ooooo`;o00001?ooool00ol0003oooooo`000004o`0000Sooooo
00?o0000ooooooooool04_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Hoooool008kooooo00Go0000ooooooooooooooooo`000004ooooo`[o000000Coooooo`000?l0003o
oooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool7o`0000Wooooo00?o0000oooooooo
ool04_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008kooooo
00Go0000ooooooooooooooooo`000004ooooo`_o000000?oooooo`000?ooool00_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Cooooo00?o0000ooooool000001?l00003ooooo`Co
00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002ol00002ooooo`;o
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l0000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`go000000Goooooo`000?l0003o0000ooooo`04o`000003
ooooool0003ooooo00?ooooo0ol000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00Ko
000000?oooooo`000?l000000_l000000ooooooo0000o`00000;o`0000;ooooo0_l00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Sooooo`00SOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo5Ol000000ooooooo0000ooooo`03ooooo`Oo00000_ooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000;o`0000;o
oooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00S?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo2Ol000001?oooooo0000o`000?ooool2o`000003
ooooool0003ooooo00;o000000?oooooo`000?ooool00oooool3o`000004ooooool0003o0000o`00
00?ooooo00?o0000ooooool000001?ooool00ol0003oooooo`00000Do`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`Wo000000Coooooo`000?l0003ooooo0ol000001Ooo
oooo0000o`000?oooooo000000Cooooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooo
000000Gooooo0_l000000ooooooo0000o`00000Bo`0000;ooooo0_l00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Hoooool008_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`Wo000000Coooooo`000?l0003ooooo0ol000001Ooooooo0000o`000?oo
oooo000000?ooooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooooooo00Oo000000?o
ooooo`000?l000001ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Hoooool008_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`co000000Soooooo`000?l0003o0000ooooool0003oooooo`0000?o
oooo00?o0000ooooool000001Ol00002ooooo`03o`000?oooooooooo00Wo000000?oooooo`000?l0
00004_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?o
oooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`000003oooo
ool0003o000000[o000000Coooooo`000?l0003o00001?ooool00ol0003oooooo`000003o`000004
ooooool0003oooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`03o`000003ooooool0003o
oooo00;o000000?oooooo`000?l000003ol00002ooooo`;o00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000003oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06?ooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool2o`000003ooooool0003o000000[o000000?oooooo`000?l000001?ooool00ol0
003oooooo`000003o`0000;ooooo00Ko0000ooooool0003oooooo`000?oooolBo`000003ooooool0
003o000000Wo00000_ooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`03
o`000?oooooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00
ROooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000
o`000006o`000003ooooool0003o000000;ooooo0_l00003ooooo`Ko00000oooool2o`0000;ooooo
4_l000000ooooooo0000ooooo`0;o`0000;ooooo0_l00003ooooo`03o`000?oooooo000000?o0000
0oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Hoooool008Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`ko0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o00001?ooool2o`000003oooo
ool0003o000000Go000000?oooooo`000?l000002ol000000ooooooo0000o`000009o`0000;ooooo
0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool01?l0003oooooooooool0000?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`ko000000?oooooo`000?l000000oooool5o`0000Co
oooo0_l000000ooooooo0000ooooo`03o`000003ooooool0003o000000ko000000?oooooo`000?l0
00002Ol00002ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000oooo
oooooooo00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Cooooo0028oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooooolAo`0000?ooooo00?o0000oooo
ool000000_l00003ooooo`05o`000?oooooo0000o`000?ooool03ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Wo00000_ooool2o`0000?ooooo00?o0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Cooooo0027ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00ooooolAo`0000?ooooo1?l00004ooooo`04o`000?oooooo0000ooooo`Wo000000?o
ooooo`000?l000001?l000000ooooooo0000o`000003o`000003ooooool0003o000000Wo00000_oo
ool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool008Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`So000000?oooooo`000?l000000ol00000
0ooooooo0000o`000002ooooo`Co00001?ooool00ol0003oooooo`000006o`000003ooooool0003o
000000Wo000000?oooooo`000?l000000ol000000ooooooo0000o`000009o`0000;ooooo0_l00003
ooooo`;o00000oooool4o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Cooooo0026ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool8o`000003ooooool0003o000000Go00000oooool3o`0000Cooooo00Co0000oooo
ool0003ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00ko000000?oooooo`000?l000002Ol0
0002ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool008Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`go000000?oooooo`000?l000000oooool3
o`0000?ooooo00Co0000ooooool0003ooooo0ol000000ooooooo0000o`000005o`000003ooooool0
003o000000_o000000?oooooo`000?l000002Ol00002ooooo`;o00000oooool2o`0000;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0I?ooool008Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`go000000?oooooo`000?l000000_ooool3o`0000Cooooo00?o0000ooooool000006_l00000
0ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1T
ooooo`00QOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo3Ol000000ooo
oooo0000o`000002ooooo`?o00000oooool01?l0003oooooo`000?ooool;o`000003ooooool0003o
000000co000000?oooooo`000?l000002Ol00002ooooo`;o00000oooool2o`0000;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0I?ooool008Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`Wo000000?oooooo`000?l000001?l000001?oooooo0000o`000?l00003ooooo`04o`000?oooooo
0000ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`00000;o`000003ooooool0
003o000000Wo00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo0023
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooooolAo`000004ooooool0003o
0000o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?o
ooooo`000?l000003ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`;o00000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Tooooo`00Poooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo4?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000_o000000?ooooo
o`000?l000003Ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`;o00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Tooooo`00P_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo4Ol000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooool000001?l000001Ooo
oooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000003_l000000ooooooo0000o`000009
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool008;ooooo00?o0000oooo
ooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Go000000?oooooo`000?l000002?l0
00001?oooooo0000o`000?l00002ooooo`Oo00000_ooool2o`000005ooooool0003o0000o`000?oo
ool04Ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Gooooo0021ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002oooo
o`Go000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol00000
0ooooooo0000ooooo`09o`000003ooooool0003o000000go000000?oooooo`000?l000002Ol00002
ooooo`;o00000oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00P?ooool00ol0003oooooooooo`0<
ooooo`04o`000?oooooo0000o`0000?ooooo1Ol000000ooooooo0000o`000008o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`000006o`000005ooooool0003o0000o`000?oo
ool01?l000000ooooooo0000o`00000;o`000003ooooool0003o000000Wo000000Coooooo`000?oo
oooo00000_ooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0IOooool0083ooooo00?o0000oooooooo
ool03?ooool2o`0000Gooooo1Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000co
000000?oooooo`000?l000004Ol000000ooooooo0000o`00000;o`000004ooooool0003ooooooooo
o`;o000000?oooooo`000?ooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0IOooool007oooooo00?o0000ooooooooool03?ooool2o`0000Ko
oooo1Ol000000ooooooo0000o`00000;o`000003ooooool0003o000000So000000?oooooo`000?l0
00001_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Wo000000Coooooo`000?l0
003o00000_ooool4o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo06Gooooo001oooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo
0000ooooo`05ooooo`Go000000?oooooo`000?l000005_l000000ooooooo0000o`000003o`000004
ooooool0003o0000ooooo`oo000000?oooooo`000?l000002Ol000000ooooooo0000ooooo`06o`00
00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Gooooo001nooooo`03o`000?oooooooooo00Oooooo1?l00003ooooo`03o`000?oooooooooo00Co
oooo1Ol000000ooooooo0000o`000008o`000003ooooool0003o000000[o000000?oooooo`000?l0
00001_l00003ooooo`ko000000?oooooo`000?l000001ol000001ooooooo0000ooooool0003ooooo
o`000?ooool00_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Uooooo`00OOooool00ol0003oooooooooo`04ooooo`Co00001oooool00ol0
003oooooooooo`04ooooo`Go000000?oooooo`000?l000005?l000000ooooooo0000o`000007o`00
00;ooooo3ol000000ooooooo0000o`000007o`000005ooooool0003o0000ooooool000000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00
001Xooooo`002?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0[ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02gooooo1?l000001?l@413o
ooooooooooo^k^h2o`000003oc8b<_o^k^kooooo00Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`000002o`000003ooooool0003o000001Co000000?oooooo`000?ooool01_l00002oooo
oa3o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
oooo00;ooooo00?o0000ooooooooool01_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h7ooooo`05o`000?ooooooooooooooool000007oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo0008ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0;Oooool3o`0000?ooooo0_l000001?nHV9SooooooiRHV?mgMgL9ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000000_l000000ooooooo0000o`00000Co`000003ooooool0
003o000000Ko00000_ooool2o`000003ooooool0003o000000co000000?oooooo`000?l000001ol0
00001Ooooooo0000o`000?oooooo000000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool01Ol0003ooooooooooooooooo0000
01oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00
1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Qooooo`Ko
00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41009?ooool6o`00
0003ooooool0003o000000;ooooo00Ko0000oooooooooooo0000ooooool@4103ooooo`03oa0@4?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000002o`000003ooooool0
003o000001co000000Goooooo`000?oooooo0000ooooo`0>o`000003ooooool0003o000000Oo0000
00Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo00Co0000oooooooooooo00008Oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100<?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool00Oooool000_ooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000002gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000002Oooooo1?l00004ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo0000o`00000Ho`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000006_l00002ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00008_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool00000;oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
00[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000002kooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000002;ooooo1_l00007ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool5o`000003oooo
ool0003o000001_o000000?oooooo`000?ooool04Ol000000ooooooo0000o`000009o`0000;ooooo
00Co0000oooooooooooo00002_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0002?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000002kooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo
000;ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400_ooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Mooooo`?o00003Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003oooooooooo`04oooo
ob;o00000_ooool00ol0003oooooo`00000:o`000003ooooool0003o000000go000000Koooooo`00
0?ooooooooooo`000?ooool2o`0000[ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@4100
1oooool01?l0003oooooooooool0000Tooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0]ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`002?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0[ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02Oooool00ol0003oooooooooo`04ooooo`ko000000?oooooo`000?l000002Ol000001Ooo
oooo0000o`000?l0003ooooo00;o00000_ooool2o`000003ooooool0003o000001Wo000000Kooooo
o`000?ooooooooooo`000?ooool2o`0000[ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01oooool00ol0003oooooo`00000Qooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg02cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool000Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Mooooo`03o`000?oooooooooo00gooooo00?oEEEEo`000?l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool01?ooool>o`000003ooooool0
003o000000_o000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo000001_o000000Oo
ooooo`000?ooooooooooo`000?oooooo000000[ooooo00?oEEEEo`000?l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo00008Oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo001Yooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`_o000000Coooooo`000?l0
003ooooo3_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo000001_o000000Cooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00Co
0000oooooooooooo0000J_ooool006Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00;ooooo4?l000000ooooooo0000o`000007o`000003ooooool0
003o000000Go00000oooool00ol0003oooooo`00000?o`000003ooooool0003o000000Oo000000Oo
ooooo`000?oooooo0000ooooool0003ooooo00;o00002oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooo000006_ooooo001Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4oooool01?l0003ooooooooooooooolAo`000003ooooool0003o000000oo00000oooool2o`0000;o
oooo2_l000000ooooooo0000o`00000;o`000003ooooool0003o000000;ooooo00Co0000ooooool0
003o00002_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000006_ooooo001Wooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool5o`000003ooooool0003o000001[o
00000_ooool3o`0000?ooooo3_l000001Ooooooo0000o`000?l0003ooooo00Wo000000?oooooo`00
0?l000000_ooool01?l0003oooooo`000?l0000:ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool00000Joooool006Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Boooo
o`;o00000_ooool00ol0003oooooooooo`0Fo`000003ooooool0003ooooo00So00000oooool2o`00
0003ooooool0003o000000go000000?oooooo`000?l000001ol000000ooooooo0000o`000002oooo
o`04o`000?oooooo0000o`0000[ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00001[
ooooo`002oooooooo`0005Ko00002?ooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooooooo4Ol00000
0ooooooo0000o`00000:o`000005ooooool0003o0000ooooool000001oooool:o`000005ooooool0
003o0000o`000?ooool01_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`?o
00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01_ooool000_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000?ooooo`05o`000?oooooo0000oooo
ool000000oooool00ol0003oooooo`00000;o`000003ooooool0003o000000Wo000000Coooooo`00
0?oooooooooo1?l00006oooooaKo000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`00
0?oooooo000000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000002[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`06ooooo`00IOoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Co0000ooooool0003o0000
0ooooolKo`000004ooooool0003oooooooooo`Go00000oooool=o`000003ooooool0003o000000So
000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000oooooooooooo000000[ooooo00?o0000
ooooooooool03oooool2o`0006gooooo001Tooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool01?l0003oooooo`000?l00003ooooo`_o000000?oooooo`000?l000003Ol00000
1_oooooo0000oooooooooooo0000oooooa?o000000?oooooo`000?l000002?l000001?oooooo0000
o`000?ooool4o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`;o
0000KOooool006Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`04o`00
0?oooooo0000o`0000;ooooo7_l00002ooooo`_o000000?oooooo`000?l000001ol000000ooooooo
0000o`000008o`000004ooooool0003o0000ooooo`;o000000Goooooo`000?ooooooooooo`00000:
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0K?ooool006Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000?ooooo2?l00000
0ooooooo0000o`00000Co`0000?ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o
000000Oo000000?oooooo`000?l000003_l000001?oooooo0000ooooool0000;ooooo`03o`000?oo
oooooooo00kooooo0_l0001^ooooo`00Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00Co0000oooooooooooo00000oooool2o`000003ooooool0003o000001Go000000Co
ooooo`000?l0003o00000oooool9o`000003ooooool0003o000001Ko000000Ooooooo`000?l0003o
ooooo`000?oooooo000000[ooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003ooooo
06gooooo001Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000ooooool0003ooooo2Ol000000ooooooo0000o`00000;
o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000ooooo`04o`000003ooooool0
003o000000So000000?oooooo`000?l000003?l000001ooooooo0000o`000?oooooo0000ooooool0
00002_ooool00ol0003oooooooooo`0;ooooo`;o00000oooool00ol0003oooooooooo`1/ooooo`00
Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00Go0000oooooooooooo
ooooo`000002ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000o`00000;o`000003
ooooool0003ooooo00Co00000_ooool?o`000003ooooool0003ooooo00ko000000Ooooooo`000?l0
003oooooo`000?oooooo000000Wooooo00?o0000ooooooooool02?ooool4o`0000Cooooo00?o0000
ooooooooool0KOooool006?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`05o`000?ooooooooooooooool000000_ooool3o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000002ol000000ooooooo0000ooooo`03o`0000?ooooo3ol000000ooooooo0000ooooo`05
o`000003ooooool0003o000000[o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo1Ol00008ooooo`03o`000?oooooooooo06gooooo001Rooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02o`0000;ooooo0ol000000ooo
oooo0000o`000007o`000003ooooool0003o000000_o000000?oooooo`000?ooool05Ol000000ooo
oooo0000ooooo`05o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo
06gooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooooooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001ol000000ooo
oooo0000o`00000;o`000004ooooool0003oooooooooo`_o000000?oooooo`000?l000001_l00000
0ooooooo0000o`000005o`000003ooooool0003o000000Oo000000Goooooo`000?l0003oooooo`00
0009ooooo`03o`000?oooooooooo00;o00003oooool00ol0003oooooooooo`1]ooooo`00H_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooooooo0_l0
00001?oooooo0000o`000?l00002ooooo`Wo000000?oooooo`000?l000002ol000000ooooooo0000
o`00000=o`000003ooooool0003ooooo00Co000000Coooooo`000?l0003ooooo0ol000000ooooooo
0000o`000005o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000ooooo`08oooo
o`?o00004Oooool00ol0003oooooooooo`1]ooooo`00H_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?l00002
ooooo`Wo000000?oooooo`000?l000002ol000001Ooooooo0000o`000?l0003ooooo00Wo000000?o
ooooo`000?l000003Ol000000ooooooo0000o`000005o`000005ooooool0003o0000o`000?ooool0
0_l000000ooooooo0000ooooo`07ooooo`;o00004oooool00ol0003oooooooooo`1]ooooo`00H_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Oo0000oooooooooooo0000
ooooool0003ooooo00?o00000_ooool9o`000003ooooool0003o000000ko000000?oooooo`000?oo
ool01Ol00002ooooo`Ko000000Goooooo`000?l0003o0000ooooo`0>o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooo000001?ooooo00?o0000
ooooooooool0KOooool006;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`06o`000?ooooooooooooooool0003ooooo1Ol00002ooooo`Wo000000?oooooo`000?l000006?l0
00000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000003?l000001Ooooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00000Cooooo`03o`00
0?oooooooooo06kooooo001Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?oo
ool01_l0003ooooooooooooooooo0000ooooo`Go00000_ooool9o`000003ooooool0003o000000co
000000?oooooo`000?ooool00_l000001?oooooo0000o`000?l00002ooooo`?o00000_ooool6o`00
0003ooooool0003ooooo00co000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003o
oooo00Cooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`1^ooooo`00HOooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00Ko0000ooooooooooooooooo`000?oo
ool5o`0000;ooooo2Ol000000ooooooo0000o`00000>o`000004ooooool0003oooooo`0000;ooooo
1?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Oo
000000Soooooo`000?oooooo0000ooooool0003oooooo`0000Kooooo0_l0000Eooooo`03o`000?oo
oooooooo06kooooo001Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool0
1_l0003ooooooooooooooooo0000ooooo`?o000000Coooooo`000?oooooooooo2Ol000000ooooooo
0000o`00000Ao`0000;ooooo1?l00003ooooo`Oo000000?oooooo`000?l000000ol000000ooooooo
0000o`000007o`000008ooooool0003oooooo`000?oooooo0000ooooool00004ooooo`;o000000?o
ooooo`000?ooool05?ooool00ol0003oooooooooo`1^ooooo`00HOooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo013ooooo00Ko0000ooooooooooooooooo`000?ooool3o`000004oooo
ool0003oooooooooo`Wo000000?oooooo`000?l000004?l000000ooooooo0000o`000003o`000003
ooooool0003o000000;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00Go000000?ooooo
o`000?l000001ol000002?oooooo0000ooooool0003oooooo`000?oooooo00000oooool01?l0003o
ooooooooool0000Fooooo`03o`000?oooooooooo06kooooo001Qooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool01_l0003ooooooooooooooooo0000ooooo`?o000000Cooooo
o`000?oooooooooo1Ol000001Ooooooo0000o`000?l0003ooooo01Co000000?oooooo`000?l00000
0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go000000?oooooo`000?l00000
1ol000000ooooooo0000ooooo`03o`000003ooooool0003ooooo00;o00000_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06oooooo001Qooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?o00000ooo
ool5o`000005ooooool0003o0000o`000?ooool03?l000000ooooooo0000o`000003o`0000;ooooo
0ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000Goooooo`000?l0003o
0000ooooo`0<o`000003ooooool0003ooooo00?o000000?oooooo`000?l000001?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06oooooo001Qooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`;o
00000oooool5o`000005ooooool0003o0000o`000?ooool04Ol00002ooooo`;o000000?oooooo`00
0?l000001Ol000001_oooooo0000o`000?oooooo0000ooooo`?o000000?oooooo`000?l000002_l0
00000ooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1_ooooo`00HOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?oooooo0000o`0000?ooooo1Ol000000ooooooo0000
o`00000Bo`000003ooooool0003o000000;ooooo1?l000001?oooooo0000ooooooooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000002_l000000ooooooo0000o`000004o`0000Co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1_ooooo`00H?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?oooooo0000o`0000?ooooo1Ol000000ooooooo0000o`00000@o`000004ooooool0003o0000
o`0000;ooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`ko000000Go
ooooo`000?l0003oooooo`000004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Koooool0063ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`05o`000?oo
ooooooooooooool000000_ooool4o`0000?ooooo1Ol000000ooooooo0000o`000008o`000003oooo
ool0003o000000Oo00000oooool5o`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o
0000ooooo`06o`000003ooooool0003o000000[o00001?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool01Ol0003ooooooooooooooooo000000;ooooo1?l00003ooooo`Go000000?oooooo`000?l0
00004?l00003ooooo`Ko00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Co000000?oooooo`000?l000002_l00004ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0L?ooool0063ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000000_ooool4o`0000?ooooo1Ol000000ooooooo
0000o`00000Go`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo0ol00002ooooo`Ko
000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0000?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00Ko0000ooooooooooooooooo`000?ooool5o`0000?ooooo1Ol000000ooo
oooo0000o`00000Fo`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo1?l00002oooo
o`co000000?oooooo`000?l000000ol00003ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0L?ooool0063ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`06
o`000?ooooooooooooooool0003ooooo1Ol00003ooooo`Go000000?oooooo`000?l000004?l00000
0ooooooo0000o`000007o`000005ooooool0003o0000ooooool000000_ooool00ol0003oooooo`00
0002o`0000;ooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o00000ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo077ooooo001Oooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool01_l0003ooooooooooooooooo0000ooooo`Go0000
0oooool5o`000003ooooool0003o000000oo000000Ooooooo`000?l0003o0000ooooool0003ooooo
00?o000000Goooooo`000?ooooooooooo`000003ooooo`Co00000_ooool7o`000003ooooool0003o
000000?o000000?oooooo`000?l000000ol00002ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0LOooool005oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`06o`000?ooooooooooooooool0003ooooo1Ol00003ooooo`Go000000Goooooo`000?l0003o0000
ooooo`08o`000003ooooool0003o000000?o000000?oooooo`000?ooool00ol00002ooooo`;o0000
00?oooooo`000?l000000oooool5o`0000;ooooo1ol000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo077ooooo
001Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool01_l0003ooooooooo
oooooooo0000ooooo`Go00000oooool9o`000003ooooool0003o000000?o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000005o`0000;ooooo1?l00005ooooo`03o`000?oooooo0000
00;o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000?o000000?ooooo
o`000?l000000_l00002ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0L_ooool0
05oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001?l00003ooooo`Wo000000?oooooo`000?l000001_l00002oooo
o`Oo00000oooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000;o00000_ooool3
o`000004ooooool0003o0000o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1booooo`00Goooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004
o`0000?ooooo2Ol000001ooooooo0000o`000?l0003oooooo`000?ooool00_l00002ooooo`;o0000
1oooool4o`0000Cooooo1ol000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?oo
oooooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003ooooo01[ooooo00?o0000oooo
ooooool0L_ooool005oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003ooooo`Wo000000Ooooooo`000?l0
003o0000ooooool0003ooooo00;o00000_ooool3o`0000Gooooo0_l00002ooooo`03o`000?oooooo
oooo00[o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000ooooooooool5o`000003oooo
ool0003ooooo00?o00006oooool00ol0003oooooooooo`1cooooo`00Goooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0004o`0000?ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?ooool0
0_l00003ooooo`?o000000?oooooo`000?l000000_l00003ooooo`04o`000?oooooo0000ooooo`?o
000000?oooooo`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool5o`00
0003ooooool0003ooooo00?o00006oooool00ol0003oooooooooo`1cooooo`00Goooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000004o`0000?ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Go000000Coooooo`00
0?l0003o00000_ooool5o`000003ooooool0003ooooo00?ooooo1_l000000ooooooo0000ooooo`02
o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l00002ooooo`Go000000?ooooo
o`000?ooool00_l0000Looooo`03o`000?oooooooooo07?ooooo001Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Co00000oooool5o`000005ooooool0003o0000o`000?ooool01Ol000001?oooooo0000o`000?l0
0003ooooo`Go00001Oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`Co00000_ooool5o`000003ooooool0003o000000;o00006oooool00ol0003ooooo
ooooo`1dooooo`00Goooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000004o`0000?ooooo1Ol000001Ooooooo0000o`00
0?l0003ooooo00Wo00003?ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool01?l0003o
ooooo`000?l00002ooooo`;o000000Coooooo`000?oooooooooo1Ol000000ooooooo0000o`000002
o`0001[ooooo00?o0000ooooooooool0MOooool005oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003oooo
o`Go000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0003o000000_ooooo1?l00000
1?oooooo0000o`000?ooool2o`0000?ooooo00Co0000ooooool0003o00000_ooool2o`000003oooo
ool0003ooooo00Go00000_ooool4o`0001[ooooo00?o0000ooooooooool0MOooool005oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`06o`000004oooo
ool0003o0000o`0000Wooooo00Go0000ooooool0003o0000ooooo`05o`0000?ooooo00?o0000oooo
ooooool00_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000_l0000Jooooo`03o`000?oooooooooo07Kooooo001Oooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Co
00000oooool5o`000005ooooool0003o0000o`000?ooool01_l000001?oooooo0000o`000?l00008
ooooo`04o`000?oooooo0000ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000;ooooo
2ol000000ooooooo0000o`000002o`0001[ooooo00?o0000ooooooooool0M_ooool005oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`06o`000004oooo
ool0003o0000o`0000Kooooo0_l000000ooooooo0000o`000002o`000004ooooool0003oooooo`00
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`Co000000?oooooo`000?l000001?l00000
0ooooooo0000o`000002o`0001Wooooo00?o0000ooooooooool0Moooool005kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000001?l00003ooooo`Go000000?oooooo`000?l000002?l000000ooooooo0000o`000002o`00
00Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool01?l000000ooooooo0000ooooo`04
o`0001Wooooo00?o0000ooooooooool0Moooool005kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003oooo
o`Go000000?oooooo`000?l000002Ol000001?oooooo0000o`000?l00003ooooo`Ko00000_ooool3
o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`?o000000?o
ooooo`000?l000001?l0000Hooooo`03o`000?oooooooooo07Sooooo001Nooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
0000ooooo`?o00000oooool5o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l0
00000ooooooo0000o`000004o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooooooo1_l000001Ooooooo0000o`000?l0003ooooo00Ko00006?ooool00ol0003o
ooooooooo`1hooooo`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool3o`0000?ooooo1Ol000000ooooooo
0000o`00000Do`000003ooooool0003o000000;o00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;o000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003ooooo
00;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`1iooooo`00G_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooo`000?ooool3o`0000?ooooo1Ol000000ooooooo0000o`000008o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000001?l000000ooooooo0000ooooo`06ooooo`04o`000?oooooooooo
ooooo`?o000000?oooooo`000?l000000_ooool8o`000003ooooool0003ooooo01Gooooo00?o0000
ooooooooool0N_ooool005kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0ol00003ooooo`Go000000?ooooo
o`000?l000002Ol00002ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001ooo
ool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`So000000?oooooo`000?ooool04ooo
ool2o`0007gooooo001Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?oooooooooo
4Ol00003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool01?l0003o
ooooooooooooool4o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?ooool04_ooool0
0ol0003oooooooooo`1mooooo`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool2o`000004ooooool0003o
oooooooooa7o00001?ooool5o`000007ooooool0003o0000ooooool0003oooooo`000007ooooo`04
o`000?ooooooooooooooo`Ko000000?oooooo`000?ooool00ol000000ooooooo0000o`000005o`00
01;ooooo00?o0000ooooooooool0O_ooool005kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0_l000001?oo
oooo0000oooooooooolAo`0000Wooooo0_l000001Ooooooo0000oooooooooooo000000Gooooo0_l0
0003ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000_ooool3o`000003ooooool0
003o000000Co00004_ooool00ol0003oooooooooo`1oooooo`00G_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo2Ol000000ooooooo0000o`000006o`000007oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<P02o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo00?o0000ooooooooool00ol000000ooooooo0000o`000002ooooo`?o0000
00?oooooo`000?l000001?l0000@ooooo`;o0000P_ooool005kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00So0000oooooooooooo0000
ooooool0003oooooo`0000;ooooo2Ol000000ooooooo0000o`000003o`000003ooooool0003ooooo
00?ooooo00?oMgMgoiRHV?ooool00_l000000ooooooo0000ooooo`03ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool01Ol0003oooooo`000?l0003ooooo00Co000000?oooooo`000?l000000_l0
00000ooooooo0000ooooo`02o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0P_oo
ool005kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo2Ol00002ooooo`?o
000000Coooooo`000?l0003o00000oooool01_l@413o0000o`000?l0003o410@o`0000Gooooo00?o
0000ooooool000000_l00003ooooo`;o00000_ooool3o`000005ooooool0003o0000o`000?ooool0
1ol000001?oooooo0000ooooool0000>ooooo`03o`000?oooooooooo08?ooooo001Nooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool00002ooooo`[o000000Goooooo`000?l0003o0000oooo
o`02o`000003ooooool0003o000000Co000000?oooooo`000?ooool01Oooool4o`0000?ooooo00Co
0000oooooooooooooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000
00Soooooo`000?l0003o0000ooooool0003oooooo`0000gooooo00?o0000ooooooooool0Q?ooool0
05kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo00Go0000oooooooooooo0000ooooo`03o`0000?ooooo2Ol000001?oooooo0000o`000?oo
ool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`?o00000oooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?ooool00ol000000ooooooo0000o`000005o`000004ooooool0
003oooooo`0000_ooooo0_l00027ooooo`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00?o0000
0oooool9o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool01Ol0003ooooo
o`000?oooooo410@00Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`;o
00000_ooool7o`000004ooooool0003oooooo`0000Wooooo0_l00029ooooo`00G_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01Ol0003o
ooooooooool0003ooooo00;o000000Coooooo`000?oooooooooo2Ol000000ooooooo0000o`000002
o`00000;ooooool0003o0000o`000?oooooo0000ogMgMol0003ooooooiRHV?mgMgL01?ooool3o`00
00?ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`00
0008ooooool0003o0000o`000?oooooo0000ooooool00008ooooo`03o`000?oooooooooo08Wooooo
001Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooo`000?ooool00_l000001?oooooo0000ooooooooool9o`000003
ooooool0003o000000;o000000?oIVIVo`000?l000000_l000001_oooooo0000oc8b<_l0003o<S8b
onk^kP;ooooo0ol000001Ooooooo0000oooooooooooo000000Gooooo0ol000000ooooooo0000oooo
o`02o`0000;ooooo1Ol000000ooooooo0000ooooo`04o`0000Kooooo0_l0002<ooooo`00G_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool9o`000003ooooool0003o000000So
00001_ooool3o`0000;ooooo00?o0000ooooool000001Oooool3o`000004ooooool0003ooooooooo
o`;o00000_ooool5o`000003ooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`2<oooo
o`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool>o`0000;ooooo0ol0
0006ooooo`?o00000oooool2o`0000Gooooo0ol00002ooooo`Go000000?oooooo`000?ooool00ol0
00001?oooooo0000o`000?ooool4o`0000?ooooo0_l0002?ooooo`00G_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`00
0?oooooo0000o`000?oooooo00000_ooool8o`000004ooooool0003o0000ooooo`;o00000_ooool0
1?l0003oooooo`000?l00005ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000?ooooo00Oo0000ooooool0003o0000ooooool0003ooooo00Co000000Coooooo`000?l0
003ooooo1?l00002ooooo`03o`000?oooooooooo08oooooo001Nooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooo
ool0003o0000ooooool00002ooooo`_o000000?oooooo`000?l000000oooool9o`0000Cooooo0_l0
0004ooooo`?o00000oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00?o00000_oo
ool2o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooooooool0T?ooool005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`03o`0000;ooooo2ol000001?oooooo0000ooooool00003ooooo`Oo
00001?ooool00ol0003oooooo`000002ooooo`Co00000oooool01?l0003oooooooooooooool3o`00
0003ooooool0003o000000;o00000_ooool00ol0003oooooooooo`05o`0009?ooooo001Nooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000;ooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol000001?oooooo
0000o`000?l00004ooooo`?o00001_ooool01Ol0003oooooooooool0003ooooo00Co00000oooool0
1_l0003ooooooooooooooooo0000ooooo`;o000000?oooooo`000?l000000_l00002ooooo`06o`00
0?ooooooooooo`000?oooooo0000UOooool005gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool3o`0000;o
oooo1Ol000000ooooooo0000o`000003o`0000;ooooo0_l0000<ooooo`04o`000?oooooooooooooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`Go00000_ooool0
0ol0003oooooo`000003o`0009Gooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo0ol00002oooo
o`Go000000?oooooo`000?l000000_l000001_oooooo0000ooooool0003oooooo`0000[ooooo00Co
0000oooooooooooooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001ol00002ooooo`03o`000?oooooo000000?o0000UOooool005gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0
003ooooo00?o00002Oooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`000003o`0000;ooooo1_l0002Eoooo
o`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000002ooooo`?o00000_ooool5o`000003ooooool0003o000000;o
000000Coooooo`000?oooooooooo0_l00008ooooo`04o`000?ooooooooooooooo`Go00000oooool0
0ol0003oooooooooo`03ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`04o`000004oooo
ool0003o0000ooooo`Co0000UOooool005gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool3o`0000;ooooo
1Ol000000ooooooo0000o`000004o`0000;ooooo0_l00006ooooo`;o00000oooool3o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l00002ooooo`Go
000000Goooooo`000?l0003o0000ooooo`03o`0009Kooooo001Mooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?o
oooo0_l00002ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000001?l00002ooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?l000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000001?l000001?oooooo
0000o`000?ooool3o`0009Kooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo0ol000000ooooooo
0000ooooo`09o`000003ooooool0003ooooo00?o00000oooool00ol0003oooooooooo`02ooooo`?o
000000Koooooo`000?oooooo0000ooooool00006ooooo`07o`000?oooooo0000o`000?oooooo0000
ooooo`02o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00002Fooooo`00GOoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0ol000000ooooooo0000ooooo`07o`000005ooooool0003o0000o`000?ooool0
1?l000000ooooooo0000ooooo`03ooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000Ko
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000004o`000006ooooool0003o0000
ooooool0003ooooo0_l0002Fooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002ooooo`?o000000?ooooo
o`000?ooool01ol000001?oooooo0000o`000?l00002ooooo`Co00000oooool4o`000004ooooool0
003oooooooooo`;o00001_ooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo0000oooo
o`Co000000Coooooo`000?l0003ooooo1?l0002Fooooo`00GOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002oooo
o`?o000000?oooooo`000?ooool03_l000000ooooooo0000o`000005o`0000;ooooo00?o0000oooo
ooooool00ol00005ooooo`03o`000?oooooo000000;o00000_ooool2o`000003ooooool0003o0000
00?o000000Coooooo`000?l0003ooooo1?l0002Fooooo`00GOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002oooo
o`;o000000Coooooo`000?l0003ooooo2Ol000001_oooooo0000oooooooooooo0000ooooo`Go0000
0oooool00ol0003oooooo`000002o`000003ooooool0003ooooo00;ooooo0_l000001?oooooo0000
o`000?l00002ooooo`Go000000?oooooo`000?l000000_ooool2o`000005ooooool0003o0000oooo
ool00000U_ooool005gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool2o`000003ooooool0003o000000[o
000000?oooooo`000?l000000_ooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?oo
oooo00000_ooool2o`000004ooooool0003oooooooooo`?o00000_ooool4o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool00_l000001?oooooo0000ooooool0002Fooooo`00GOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000003ooooo`Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooo000000;ooooo0_l00004ooooo`?o00000_ooool01ol0003oooooo`000?l0003oooooo`00
0?ooool00_l000000ooooooo0000o`00002Gooooo`00GOooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`000004ooooool0003oooooo`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Cooooo0_l00002
ooooo`;o00001?ooool3o`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l00000Uoooool0
05gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000000oooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000ol000000ooooooo0000ooooo`03o`0000;ooooo0ol000001Ooooooo0000o`000?oooooo
000000Cooooo0_l00002ooooo`;o00000oooool4o`0000?ooooo1?l000000ooooooo0000ooooo`02
o`000004ooooool0003o0000o`0009Oooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo1_l00002
ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`Co00001?oo
ool01ol0003oooooo`000?l0003oooooo`000?ooool00_l000001?oooooo0000o`000?l0002Goooo
o`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00;o
000000Koooooo`000?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00ol00003ooooo`Co00001?ooool6o`0000;ooooo0_l000001?oooooo0000o`000?l0
002Gooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000;o000000Koooooo`000?oooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooooooo0_l00003ooooo`Co00001Oooool6o`0000;ooooo0_l000001?oooooo
0000o`000?l0002Gooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool2o`0000Cooooo1_l000000ooooooo0000o`000004o`0000;o
oooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002oooo
o`Go00001_ooool00ol0003oooooo`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`00
09Oooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool=o`0000;ooooo00?o0000ooooool000000oooool2o`0000Co
oooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`02o`0000Oooooo1_l00002oooo
o`;o000000Goooooo`000?l0003oooooo`00002Gooooo`00GOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003oooo
o`go00000oooool2o`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2
o`000004ooooool0003o0000ooooo`;o00001oooool2o`000004ooooool0003oooooo`0000?ooooo
0_l000001?oooooo0000o`000?l0002Hooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`co0000
1?ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003o
ooooo`000?l00008ooooo`Co000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03o`00
09Sooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000Cooooo1ol000000ooooooo0000o`000008o`0000Go
oooo00Co0000oooooooooooooooo0_l00002ooooo`Co00002?ooool2o`000003ooooool0003ooooo
00;o00000oooool00ol0003oooooooooo`03o`0009Sooooo001Mooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Co
oooo1ol000001_oooooo0000o`000?l0003oooooo`0000Cooooo1_l00003ooooo`;o00000_ooool0
1?l0003oooooo`000?l00009ooooo`;o000000Coooooo`000?oooooo00001?ooool01?l0003ooooo
o`000?ooool2o`0009Sooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`03ooooo`;o00001?ooool7o`000006ooooool0003o0000o`000?oo
oooo00001Oooool00ol0003oooooooooo`04ooooo`;o00000_ooool01?l0003oooooo`000?l00009
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?ooool00_l0002H
ooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Co000000?oooooo`00
0?l000000ol00005ooooo`;o00000_ooool3o`0000?ooooo00?o0000ooooool000000_l00008oooo
o`;o00000_ooool00ol0003oooooo`000004ooooo`;o000000?oooooo`000?ooool00_l0002Hoooo
o`00GOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000004ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`00
00Oooooo0_l000000ooooooo0000ooooo`02ooooo`06o`000?oooooo0000o`000?oooooo00001ooo
ool2o`0000;ooooo1?l00004ooooo`04o`000?oooooo0000ooooo`?o0000V?ooool005gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?ooool6o`000003ooooool0003o000000?o00002Oooool01_l0003ooooooooo
oooooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`;o00000oooool3o`0000Co
oooo0_l000000ooooooo0000ooooo`02o`0009Wooooo001Mooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo
1_l00002ooooo`Co00001oooool2o`0000?ooooo00Co0000ooooool0003o00000oooool00ol0003o
ooooooooo`03ooooo`;o00000oooool2o`000003ooooool0003ooooo00?ooooo0ol00002ooooo`;o
0000VOooool005gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001?ooool7o`000003ooooool0003o000000?o0000
1Oooool2o`0000?ooooo1?l00004ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o0000
00?oooooo`000?ooool00oooool01?l0003oooooo`000?l00002ooooo`;o0000VOooool005gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000ooooo`02ooooo`?o0000
0oooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00_l000000ooooooo0000
ooooo`02ooooo`04o`000?oooooo0000o`0000Cooooo00Co0000ooooool0003o00000_ooool2o`00
09Wooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool5o`000003ooooool0003o000000So00000oooool3o`000003
ooooool0003ooooo00Gooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00003ooooo`;o0000VOooool0
05gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`Go00000oooool6o`0000Cooooo00Go0000ooooool0003oooooo`000007
ooooo`;o000000?oooooo`000?l000000oooool01?l0003oooooooooool00005ooooo`04o`000?oo
oooo0000o`0000;ooooo0_l0002Jooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo1_l00002ooooo`Co00001Ooo
ool01Ol0003oooooo`000?oooooo000000Sooooo00?o0000ooooool000001?ooool2o`000003oooo
ool0003ooooo00Cooooo00Co0000oooooooooooo00000oooool2o`0009[ooooo001Mooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool6o`0000;ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oooooo0000ooooool0
00002?ooool3o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0
003o00000oooool2o`0009[ooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool6o`0000;ooooo1Ol00002ooooo`?o
000000?oooooo`000?ooool01oooool3o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_l00003ooooo`;o0000V_ooool005kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
0oooool3o`000003ooooool0003o000000Wo00000_ooool2o`0000Sooooo0_l000001?oooooo0000
ooooooooool2o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`00
00?ooooo0_l0002Jooooo`00G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01?ooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`Go
00000oooool2o`0000Sooooo0_l00002ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool0VOooool005ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool000000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Sooooo0_l00003ooooo`?o00000_ooool2o`0000Kooooo00Co0000
oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo09Wooooo001Nooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000;ooooo0ol000000ooooooo0000o`000006o`000004ooooool0003o0000o`0000Sooooo0_l0
0004ooooo`;o00000_ooool2o`0000Kooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`00
0?oooooooooo09Wooooo001Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`05ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo
1_l00008ooooo`;o00001?ooool2o`0000;ooooo00?o0000ooooooooool01Oooool01ol0003ooooo
oooooooooooo0000ooooool000001?ooool2o`0009_ooooo001Nooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool01?l0003o
ooooo`000?ooool2o`0000?ooooo2?l00003ooooo`Co00001?ooool3o`000003ooooool0003ooooo
00Kooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Cooooo0_l0002Kooooo`00G_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`?o0000
0_ooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000Oooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001?ooool2o`0009_o
oooo001Nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool7o`0000;ooooo
0ol000001?lb<S;ok^k^ooooooooool2o`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Joooo
o`00G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01Oooool01?l0003oooooo`000?ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooodA4
A?ooool00ol000001?nHV9SooooooiRHV?mgMgL3o`0000;ooooo0_l00006ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09[ooooo001N
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?o00000_ooool2o`0000;ooooo00Ko0000ooooool0003o0000ob4Q
8Ol00004ooooo`04oa0@4?ooooooooooooooo`?o00000_ooool00ol0003oooooo`000002o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l0002Loooo
o`00G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02o`0000;ooooo1?l00002ooooo`05o`000?oooooo0000o`00
0?o^k^h00oooool00ol0003oooooooooo`03o`0000;ooooo00Co0000oooooooooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool2o`0009cooooo001N
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Ko00001?ooool5o`0000?ooooo1Ol00002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo0_l00005ooooo`;o0000
W?ooool005kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_l00002ooooo`;o00001Oooool00ol0003ooooooooo
o`08o`000003oa0@4?oooooo000000Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0002Mooooo`00G_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00
0002o`000003ooooool0003o000000Cooooo0ol000000onHV9So410@o`000002o`000004ogMgMol0
003o0000oiRHV0;o00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo
0_l00005ooooo`;o0000WOooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_l00002ooooo`03o`000?oo
oooooooo00;ooooo00GoV9RHoa0@4?l0003o0000olc<c003ooooo`05o`000?lb<S;o0000o`000?o^
k^h01_ooool2o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0002Mooooo`00
G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1_ooool4o`0000;ooooo0_l00006ooooo`;o00000_ooool01?l0003oooooo`000?l00008ooooo`05
o`000?ooooooooooooooool000001oooool2o`0000Gooooo0ol0002Mooooo`00G_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooo`000002ooooo`;o00001oooool6o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`?o0000WOooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o00002?ooool3o`0000Wooooo
00Go0000ooooool0003oooooo`000008ooooo`;o00001_ooool2o`0009kooooo001Nooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`;o0000
0_ooool00ol0003oooooo`000005ooooo`;o00002oooool00ol0003oooooooooo`02o`0000Sooooo
0_l00006ooooo`?o0000W_ooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo0ol00002ooooo`;o00000oooool2o`0000cooooo00Go
0000ooooooooooooooooo`000008ooooo`;o00001oooool3o`0009kooooo001Nooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`;o000000?o
ooooo`000?l000001Ol0000=ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003ooooo
o`000007ooooo`?o0000W_ooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`?o00003_ooool01_l0003ooooooooo
oooooooo0000ooooo`;o00001?ooool2o`000003ooooool0003ooooo00Kooooo0ol0002Oooooo`00
G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008ooooo`?o0000Woooool005ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oo
oooo0_l00003ooooo`?o00002_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000Wooooo0ol0002Oooooo`00G_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0ol00009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Oooooo0ol0002Pooooo`00G_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l000000ooo
oooo0000ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000002ooooo`03o`000?oooooooooo00Sooooo0ol0002Pooooo`00G_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool2o`0000Co
oooo00?o0000ooooooooool00_l00003ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`;o
00000_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo0000o`000:3ooooo001Nooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`;o
00001?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool0000:ooooo`05o`000?oooooo0000ooooool00000X?ooool005kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo0_l00004
ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooooooo0000ooooo`0:ooooo`04o`000?oooooo
0000o`000:7ooooo001Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool01_ooool0
1?l0003oooooo`000?l0000;ooooo`05o`000?oooooo0000ooooool00000XOooool005kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo0_l0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooo`00
0?l0000;ooooo`06o`000?ooooooooooo`000?oooooo0000XOooool005kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01Ol0003oooooo`000?oooooo0000
00_ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`2Oooooo`00G_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000_ooool2o`0000Wo
oooo00Ko0000oooooooooooo0000ooooool0002Rooooo`00G_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool2o`0000Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0X?ooool005kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`Co00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`2Pooooo`00G_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01oooooo0_l00002ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l0
0003ooooo`04o`000?ooooooooooo`000:?ooooo001Nooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool08?ooool00ol0003oooooo`000002o`0000Cooooo00?o0000ooooool000000_l0
0002ooooo`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000Xoooool005kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Qooooo`So00000oooool01?l0003oooooo`000?l00003ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`000:Cooooo001Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
8oooool2o`0000Sooooo00?o0000ooooooooool00ol00009ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool0002Uooooo`00G_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02?ooooo0_l00009ooooo`;o00003?ooool01?l0003oooooooooool00005oooo
o`05o`000?ooooooooooooooool00000YOooool005kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Sooooo`?o00005_ooool00ol0003oooooo`000005ooooo`05o`000?oooooooooo
ooooool00000Y_ooool005oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Toooo
o`;o00005_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`00002Wooooo`00Goooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02Cooooo0_l0000Fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Uooooo`00Goooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Cooooo0_l0000Eooooo`?o00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0:Kooooo001Oooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool09?ooool2o`0001Cooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooooooool2o`000:Wooooo001Oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
9?ooool2o`0001;ooooo00Go0000oooooooooooo0000ooooo`02o`0000?ooooo00?o0000oooooooo
ool0ZOooool005oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Tooooo`;o0000
4?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0:[ooooo001Oooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool09?ooool2o`0000oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo001Oooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool09Oooool2o`0000gooooo00?o0000ooooooooool00oooool2
o`0000?ooooo00?o0000ooooooooool0[?ooool005oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Uooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool0[Oooool005oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00oooool01_l0003o
ooooooooool0003oooooo`000;3ooooo001Oooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool09_ooool2o`0000Sooooo0_l00005ooooo`04o`000?ooooooooooooooo`;o0000/Oooool0
05oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`04o`000?oooooo0000
o`0000Cooooo0_l00006ooooo`04o`000?ooooooooooooooo`;o0000/_ooool005oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooooooo`Co00001ooo
ool01ol0003ooooooooooooooooo0000ooooool00000/_ooool005oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Uooooo`;o00003?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0/?ooool005oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`;o
0000/Oooool005oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Vooooo`;o0000
2?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2`ooooo`00Gooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo001Pooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool09oooool00ol0003oooooo`000004o`0000Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;3ooooo001Pooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/?ooool0063ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00H?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo1Ol0000:ooooo`03o`000?oo
oooooooo0;3ooooo001Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02Kooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02Kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02[ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo
0ol0002`ooooo`00YOooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
^Oooool00:Cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo00000;Wooooo
002Uooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00X_oo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00
X_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2ioooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-31, -31, 0, 0}}]
}, Open  ]],

Cell["\<\
Even this smooth flow produces a complex pattern of \
characteristics. By computing the Lyapunov exponent for these trajectories, \
one can show that in fact the trajectories are chaotic, exhibiting sensitive \
dependence on the initial conditions.\
\>", "Text"],

Cell[TextData[{
  "\tThe behavior of a patch of dye in this flow can be followed by computing \
the positions of the edge of the patch as a function of time. We do so in \
Cell ",
  ButtonBox["7.5",
    ButtonData:>"Cell 7.5",
    ButtonStyle->"Hyperlink"],
  " for a patch that is initially circular, following 100 points from the \
patch edge."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(patchedge[t1_]\  := 
        Table[c[Sin[\[Theta]], Cos[\[Theta]]], {\[Theta], 0, 
              2  Pi,  .02  Pi}] /. t \[Rule] t1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Evaluate[patchedge[t1]], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{\(-10\), 10}, {\(-10\), 10}}, 
          AspectRatio \[Rule] 1], {t1, 0, 5,  .2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.5"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.5 .55 m
.50314 .5499 L
.50627 .54961 L
.50937 .54911 L
.51243 .54843 L
.51545 .54755 L
.51841 .54649 L
.52129 .54524 L
.52409 .54382 L
.52679 .54222 L
.52939 .54045 L
.53187 .53853 L
.53423 .53645 L
.53645 .53423 L
.53853 .53187 L
.54045 .52939 L
.54222 .52679 L
.54382 .52409 L
.54524 .52129 L
.54649 .51841 L
.54755 .51545 L
.54843 .51243 L
.54911 .50937 L
.54961 .50627 L
.5499 .50314 L
.55 .5 L
.5499 .49686 L
.54961 .49373 L
.54911 .49063 L
.54843 .48757 L
.54755 .48455 L
.54649 .48159 L
.54524 .47871 L
.54382 .47591 L
.54222 .47321 L
.54045 .47061 L
.53853 .46813 L
.53645 .46577 L
.53423 .46355 L
.53187 .46147 L
.52939 .45955 L
.52679 .45778 L
.52409 .45618 L
.52129 .45476 L
.51841 .45351 L
.51545 .45245 L
.51243 .45157 L
.50937 .45089 L
.50627 .45039 L
.50314 .4501 L
Mistroke
.5 .45 L
.49686 .4501 L
.49373 .45039 L
.49063 .45089 L
.48757 .45157 L
.48455 .45245 L
.48159 .45351 L
.47871 .45476 L
.47591 .45618 L
.47321 .45778 L
.47061 .45955 L
.46813 .46147 L
.46577 .46355 L
.46355 .46577 L
.46147 .46813 L
.45955 .47061 L
.45778 .47321 L
.45618 .47591 L
.45476 .47871 L
.45351 .48159 L
.45245 .48455 L
.45157 .48757 L
.45089 .49063 L
.45039 .49373 L
.4501 .49686 L
.45 .5 L
.4501 .50314 L
.45039 .50627 L
.45089 .50937 L
.45157 .51243 L
.45245 .51545 L
.45351 .51841 L
.45476 .52129 L
.45618 .52409 L
.45778 .52679 L
.45955 .52939 L
.46147 .53187 L
.46355 .53423 L
.46577 .53645 L
.46813 .53853 L
.47061 .54045 L
.47321 .54222 L
.47591 .54382 L
.47871 .54524 L
.48159 .54649 L
.48455 .54755 L
.48757 .54843 L
.49063 .54911 L
.49373 .54961 L
.49686 .5499 L
Mistroke
.5 .55 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
/_ooool7o`000:oooooo002_ooooo`?o00000oooool01?l0003oooooooooooooool3o`000:cooooo
002]ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000Z_ooool00:_ooooo0_l00008
ooooo`03o`000?oooooooooo00Kooooo0_l0002Xooooo`002Oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hKooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo1Ol00005oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo1Ol00005ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`002oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01_ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`;o00002oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oEEEEojVYZOoo
ool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool000Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41004Oooool6o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0
003oooooooooo`0Cooooo`Ko00001oooool00ol0003oooooooooo`0Booooo`Ko00000oooool00onH
V9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?oZJVYoeEEEOooool04?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Oooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?oV9RHob4Q8Oo^k^h03oooool0
0omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool0
0omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?oo
ool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<01oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00kooooo00?o0000ooooooooool02oooool2o`0000cooooo00?o0000ooooooooool04Oooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`05oa0@4?oooooooooo
oooooolb<S803?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00Go0000okZj^_ooooooV9RH
oa0@400<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413ooooo
oooooooooooo<S8b00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00<ooooo`Co00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
000Oooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0X?ooool00:Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:3ooooo002Tooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`00Y?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Woooool00:Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo
000;oooooooo0000E_l00008ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00:Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oo
oooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2Pooooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0X?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0:3ooooo002Uooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`2Qooooo`00Y_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0XOooool00:Oooooo00?o0000ooooooooool0
2oooool2o`0000cooooo00?o0000ooooooooool0X_ooool00:Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:;ooooo002Xooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Sooooo`00Z?ooool2o`00
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`00Z_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0YOooool00:_ooooo
0_l00008ooooo`03o`000?oooooooooo00Kooooo0_l0002Xooooo`00[Oooool2o`0000Kooooo00?o
0000ooooooooool01?ooool2o`000:[ooooo002_ooooo`?o00000oooool01?l0003ooooooooooooo
ool3o`000:cooooo002booooo`Oo0000[oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Q
onk^kP0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?o
V9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMg
ofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4
o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b
<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
0ol0002`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo
002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.57139 .53707 m
.57589 .52609 L
.57971 .51413 L
.58284 .50156 L
.5853 .48879 L
.58713 .47619 L
.5884 .46408 L
.58917 .45272 L
.5895 .44229 L
.58947 .43292 L
.58914 .42465 L
.58856 .41752 L
.58781 .41149 L
.58691 .40653 L
.58592 .40257 L
.58488 .39954 L
.58382 .39738 L
.58276 .39602 L
.58173 .39538 L
.58074 .39543 L
.57981 .3961 L
.57894 .39737 L
.57815 .3992 L
.57743 .40156 L
.57678 .40445 L
.57619 .40786 L
.57564 .41178 L
.57512 .41621 L
.57461 .42116 L
.57407 .42663 L
.57347 .43262 L
.57277 .43911 L
.57193 .44608 L
.57089 .4535 L
.5696 .46129 L
.568 .46938 L
.56603 .47764 L
.56363 .48591 L
.56073 .49401 L
.55729 .5017 L
.55327 .50877 L
.54864 .51499 L
.5434 .52017 L
.53758 .52418 L
.53124 .52698 L
.52446 .52865 L
.51736 .5294 L
.51008 .52951 L
.50278 .52936 L
.49561 .52935 L
Mistroke
.48873 .52983 L
.48228 .5311 L
.47638 .53333 L
.47109 .53657 L
.46647 .54079 L
.46254 .54583 L
.45929 .55151 L
.4567 .55761 L
.45472 .5639 L
.4533 .57018 L
.45237 .57628 L
.45187 .58206 L
.45175 .58741 L
.45193 .59227 L
.45237 .59659 L
.45302 .60035 L
.45383 .60353 L
.45476 .60614 L
.45579 .60819 L
.45687 .6097 L
.458 .61067 L
.45916 .61113 L
.46033 .61111 L
.46152 .61061 L
.46272 .60966 L
.46395 .60828 L
.46523 .60651 L
.46656 .60438 L
.46798 .60192 L
.46952 .59918 L
.47122 .59621 L
.47313 .5931 L
.47529 .58991 L
.47775 .58673 L
.48056 .58368 L
.48377 .58084 L
.48744 .57833 L
.49158 .57623 L
.49624 .57461 L
.5014 .57348 L
.50707 .57279 L
.5132 .57242 L
.51972 .57216 L
.52654 .57171 L
.53353 .57074 L
.54057 .56886 L
.5475 .56574 L
.55417 .56109 L
.56045 .55475 L
.56622 .5467 L
Mistroke
.57139 .53707 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo01Sooooo0_l0002Fooooo`00]Oooool00ol0003oooooooooo`0Hooooo`;o0000U_ooool0
0;Gooooo0_l0000Hooooo`04o`000?ooooooooooo`0009Gooooo002eooooo`03o`000?oooooooooo
01Oooooo00Co0000oooooooooooo0000UOooool00;Gooooo00?o0000ooooooooool05oooool01?l0
003oooooooooool0002Eooooo`00]Oooool00ol0003oooooooooo`0Gooooo`04o`000?oooooooooo
o`0009Gooooo002eooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00002D
ooooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0T_ooool00;Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Booooo`00]Oooool2o`0001Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09;ooooo002e
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2B
ooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0T_ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo09;ooooo002eooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo09;ooooo0009ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo1_l00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`03o`000?o^k^kooooo00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0P
ooooo`03ogMgMolb<S;ooooo01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool01_l0003oV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023o
oooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Aoooo
o`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01?ooooo1_l00007oooo
o`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
oonHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool0
0onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?oo
ool00omgMgOo<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooV9RH
ob4Q8Oo^k^h?ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07_ooool00olQ8B7o
ooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00N
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07?ooool2o`0001Gooooo00?o0000ooooooooool01?ooool01_l0003ooooo
ooooooooooooMgMgofIVIPcooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`07oooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
7?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oZJVYogMgMooo
ool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Go410@oooo
oooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Gooooo0_l000001?nj^[[ooooooiRHV?l@410<ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo<S8b00co
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`Co00007Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00Ko0000
oiRHV?l@413o0000ob4Q8Oo<c<`<ooooo`Co00007oooool4o`0001gooooo1Ol0000<ooooo`Co0000
6oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00;Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo
002eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2Cooooo`00]Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Toooool00;Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo09?ooooo002eooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2Dooooo`002oooooooo`0005Ko00002?ooool000_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`002oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo002eooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Dooooo`00]Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0UOooool00;Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09Gooooo002eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Eooooo`00]Ooo
ool00ol0003oooooooooo`0;ooooo`;o00002oooool00ol0003oooooooooo`2Eooooo`00]Oooool0
0ol0003oooooooooo`09ooooo`;o00003?ooool00ol0003oooooooooo`2Fooooo`00]Oooool2o`00
00Sooooo0_l0000>ooooo`03o`000?oooooooooo09Kooooo002`ooooo`oo00004?ooool00ol0003o
ooooooooo`2Fooooo`00[?ooool4o`0000Gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`2Gooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Uoooool00:[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo09Sooooo002Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`2Hooooo`00ZOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0VOooool00:Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09[ooooo002Xooooo`03o`000?oo
oooooooo00[ooooo0_l0000Dooooo`03o`000?oooooooooo09[ooooo002Wooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Kooooo`00Yoooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W?ooool00:Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09go
oooo002Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool2o`000:3ooooo
002Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`000:;ooooo002U
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000:Cooooo002Uoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool5o`000:Kooooo002Uooooo`03
o`000?oooooooooo00_ooooo2_l0002[ooooo`00YOooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;o0000/Oooool00:Gooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o
0000ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000
ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l0002aooooo`00YOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/?ooool00:Gooooo
00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0;3ooooo002Vooooo`04o`00
0?oooooo0000o`0000_ooooo00?o0000ooooooooool0/?ooool00:Oooooo0_l0000<ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00[ooo
ool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03ojVYZOmE
EEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00WOooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<ooooo`Co00001_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0002`ooooo`00YOooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.53241 .40393 m
.52782 .41064 L
.52396 .41677 L
.52078 .42235 L
.51823 .42743 L
.51625 .43206 L
.51481 .43629 L
.51384 .44016 L
.51331 .44371 L
.51317 .44696 L
.51339 .44994 L
.51391 .45266 L
.51472 .45513 L
.51576 .45737 L
.51702 .45938 L
.51847 .46115 L
.52008 .46269 L
.52183 .46399 L
.52372 .46504 L
.52571 .46583 L
.5278 .46635 L
.52997 .46658 L
.53221 .4665 L
.53449 .46609 L
.53679 .46534 L
.53909 .46423 L
.54136 .46274 L
.54358 .46087 L
.54574 .45859 L
.54781 .45592 L
.54979 .45286 L
.55169 .4494 L
.55352 .44555 L
.55533 .44131 L
.55715 .4367 L
.55905 .43171 L
.56112 .42636 L
.56347 .42065 L
.5662 .41461 L
.56945 .40833 L
.57335 .40196 L
.57804 .3958 L
.58361 .39039 L
.59005 .38671 L
.59715 .38637 L
.60429 .39174 L
.61019 .40569 L
.61272 .43005 L
.6093 .46274 L
.59838 .49602 L
Mistroke
.58135 .52089 L
.5625 .53455 L
.54635 .54076 L
.53531 .54405 L
.52958 .54663 L
.52828 .54904 L
.53029 .55123 L
.53462 .55302 L
.54051 .55429 L
.54741 .55487 L
.55487 .55462 L
.56255 .55341 L
.57018 .55114 L
.57755 .54778 L
.58447 .54337 L
.59083 .53803 L
.59654 .53197 L
.60155 .52544 L
.60584 .5187 L
.60943 .51203 L
.61237 .50569 L
.61469 .49989 L
.61647 .49478 L
.61776 .49045 L
.61864 .48691 L
.61916 .48414 L
.6194 .48202 L
.61942 .48038 L
.61932 .47899 L
.61917 .47755 L
.61908 .47572 L
.61916 .47308 L
.6195 .46916 L
.62016 .46343 L
.62111 .45536 L
.6222 .44449 L
.62305 .43067 L
.62312 .41428 L
.62179 .39654 L
.6185 .37945 L
.61304 .3653 L
.60559 .35587 L
.5967 .35178 L
.58704 .35257 L
.57726 .35706 L
.56783 .36391 L
.55905 .37197 L
.55109 .38041 L
.544 .38872 L
.53779 .39661 L
Mistroke
.53241 .40393 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo01Wooooo2?l0002?
ooooo`00]Oooool00ol0003oooooooooo`0Gooooo`;o00002?ooool00ol0003oooooooooo`2<oooo
o`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0S?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08_ooooo002eooooo`03o`000?oooooooooo01?ooooo0_l0000>ooooo`03o`000?oo
oooooooo08[ooooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2:ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo08Wooooo002Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo0ol0000@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0ROooool0
09cooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`29ooooo`00WOooool00omgMgOo
IVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0R?ooool009kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`28ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo1?l00006ooooo`03o`000?oooooooooo08Sooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00
]Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo002eooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Qoooool00;Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`27ooooo`00]Oooool2o`0000[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Qoooool00;Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`27ooooo`00]Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000008Wooooo002eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Q_ooool00;Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`26ooooo`00]Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo002eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Q_ooool00;Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000028oooo
o`00]Oooool2o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool00000R?ooool00;Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000028oooo
o`00]Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool01Ol0003ooooooooooooooooo000008Sooooo002eooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooooooo
ool00000R?ooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000028ooooo`00]Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool00029ooooo`00]Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04?ooool01?l0003oooooooooool00029ooooo`00]Oooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00029
ooooo`00]Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool04?ooool0
1Ol0003ooooooooooooooooo000008Wooooo002eooooo`;o00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`000029ooooo`00]Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool0
1Ol0003ooooooooooooooooo000008Wooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000ROoo
ool00;Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`000029ooooo`002Oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^hKooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo1Ol00005
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo00?o0000ooooooooool00ooo
ool2o`0000Kooooo0_l0000?ooooo`Go000000?oooooo`000?ooool00_ooool00ol0003o8B4Qoooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01ko
oooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Joooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooooooo
ool01?ooool3o`0000;ooooo0_l0000Aooooo`07oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000003
ooooo`03o`000?lQ8B7ooooo00Oooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0M
ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmE
EEGooooo013ooooo00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_oo
ool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Kooooo0ol0000Dooooo`05oiRHV?lQ8B7ok^k^ooooool000001?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEE
ooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo
<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06oooool00ol0003o
ooooooooo`0Nooooo`04oiRHV?lQ8B7ok^k^o`0000Cooooo00?o0000ooooooooool01oooool00omg
MgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool00omg
MgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01co
oooo0_l0000Pooooo`03ogMgMomVIVKo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03oeEEEOo<c<co
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`002oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wo
oooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Looooo`05o`000?nj^[[ooooooiRHV?l000001?ooool2o`0000Kooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo1?l0000Mooooo`03o`000?oooooooooo01cooooo00GoV9RHoa0@4?l0003o8B4Qo`000005
ooooo`03o`000?oooooooooo00Cooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo1?l0000K
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00]Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool0
0;Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
08Sooooo002eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`28ooooo`00]Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0R?ooool00;Gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo08Sooooo000;oooooooo0000E_l00008ooooo`002oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01_ooool00;Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08[ooooo002eooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2;ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Roooool00;Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooo
oooo01Sooooo0_l00007ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=ooooo`00]Oooool2o`0001Ko
oooo0_l00008ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Soooool00;Gooooo00?o0000
ooooooooool04Oooool2o`0000[ooooo00?o0000ooooooooool0T?ooool00;Gooooo00?o0000oooo
ooooool03_ooool3o`0000_ooooo00?o0000ooooooooool0TOooool00;Gooooo00?o0000oooooooo
ool02oooool3o`0000gooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool0
2?ooool3o`0000kooooo0_l0002Eooooo`00]Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00cooooo0ol0002Gooooo`00]Oooool2o`0000Oooooo0ol0000;ooooo`;o0000V_ooool0
0;Gooooo00?o0000ooooooooool02Oooool4o`0000Cooooo0ol0002Looooo`00]Oooool00ol0003o
ooooooooo`0=ooooo`Co0000Woooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Q
onk^kP0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?o
V9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMg
ofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4
o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b
<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
0ol0002`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo
002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.49033 .46037 m
.48628 .46352 L
.48324 .46635 L
.48119 .4689 L
.48005 .4712 L
.47979 .4733 L
.48034 .47521 L
.48163 .47695 L
.4836 .47854 L
.48618 .48 L
.4893 .48133 L
.49288 .48255 L
.49686 .48365 L
.50115 .48464 L
.50571 .48552 L
.51046 .48628 L
.51535 .48692 L
.52033 .48742 L
.52535 .48777 L
.53035 .48797 L
.53529 .48801 L
.54011 .48786 L
.54476 .48753 L
.54916 .487 L
.55327 .48626 L
.55701 .48533 L
.56033 .4842 L
.56317 .48288 L
.5655 .48139 L
.56729 .47973 L
.56853 .47793 L
.56926 .47598 L
.56952 .4739 L
.56938 .47168 L
.56893 .4693 L
.56831 .46674 L
.56766 .46396 L
.56719 .46092 L
.5671 .45756 L
.56765 .45383 L
.56915 .44965 L
.57195 .44498 L
.57645 .43975 L
.58313 .43401 L
.59249 .42793 L
.60502 .42207 L
.62089 .4177 L
.63941 .41732 L
.65783 .42469 L
.67031 .44265 L
Mistroke
.66986 .46827 L
.65513 .4921 L
.63404 .50737 L
.61664 .51503 L
.60773 .51851 L
.60718 .51985 L
.61293 .51971 L
.62268 .5181 L
.63452 .51487 L
.64689 .50988 L
.65866 .50313 L
.66902 .49484 L
.67748 .48537 L
.68384 .47524 L
.68814 .46497 L
.69056 .45504 L
.69141 .44583 L
.69103 .43759 L
.68977 .43046 L
.68795 .42448 L
.68583 .41961 L
.68365 .41577 L
.68156 .41286 L
.67967 .41076 L
.67803 .40936 L
.67668 .40854 L
.67556 .4082 L
.67463 .40821 L
.67377 .40844 L
.67287 .40874 L
.67176 .40894 L
.67025 .40886 L
.66811 .40834 L
.66506 .40726 L
.66075 .40564 L
.65479 .40369 L
.64683 .40186 L
.63667 .40077 L
.62439 .40107 L
.61041 .40317 L
.59544 .4071 L
.58025 .41249 L
.56552 .41877 L
.55171 .42536 L
.5391 .43184 L
.52781 .43792 L
.51784 .44347 L
.50916 .44845 L
.50172 .45289 L
.49546 .45685 L
Mistroke
.49033 .46037 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o00009_ooool9o`00
08;ooooo002eooooo`03o`000?oooooooooo023ooooo1Ol00009ooooo`Ko0000O?ooool00;Gooooo
00?o0000ooooooooool07?ooool4o`0001Cooooo0_l0001jooooo`00]Oooool00ol0003ooooooooo
o`0Iooooo`?o00006_ooool4o`0007Kooooo002eooooo`03o`000?oooooooooo01Oooooo0_l0000Q
ooooo`;o0000M?ooool00;Gooooo00?o0000ooooooooool05?ooool3o`0002Cooooo00?o0000oooo
ooooool0L_ooool00;Gooooo00?o0000ooooooooool04_ooool2o`00013ooooo2ol0000<ooooo`03
o`000?oooooooooo07;ooooo002eooooo`03o`000?oooooooooo013ooooo0_l0000>ooooo`Co0000
2oooool3o`0000[ooooo00?o0000ooooooooool0LOooool00;Gooooo0_l0000@ooooo`03o`000?oo
oooooooo00_ooooo0ol0000Booooo`;o00002Oooool00ol0003oooooooooo`1`ooooo`00]Oooool0
0ol0003oooooooooo`0=ooooo`;o00003Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0L?ooool00;Gooooo00?o0000ooooooooool02oooool2o`00
00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
073ooooo002eooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`00]Oooool00ol0003ooooo
ooooo`07ooooo`;o00003oooool2o`0001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1_ooooo`00]Oooool00ol0003oooooooooo`05ooooo`;o00004?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Koooool00;Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`00]Oooool00ol0003oooooooooo`02oooo
o`;o00004Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Koooool00;Gooooo00?o0000ooooool000000_l0000Cooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`00]Oooool2o`0001Gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oooooo
002dooooo`;o00005_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Koooool00;?ooooo00?o0000ooooool000005_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Koooool00;?ooooo00?o0000oooo
ool000005_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Koooool000Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6ooo
ool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Hooooo`;o00000_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Gooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_oo
ool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01[ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool000_ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEEojVYZOooool01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Kooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Cooooo`03ogMgMolb<S;ooooo01gooooo00?oEEEEojVYZOooool0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool000Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41004Oooool6o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003o
ooooooooo`0Cooooo`Ko00001oooool00ol0003oooooooooo`0Booooo`Ko00000oooool00onHV9So
8B4Qonk^kP0Aooooo`03o`000?oooooooooo01?ooooo0_l00005ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01co
oooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007?ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
023ooooo00?oMgMgoc8b<_ooool07Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Oooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05?ooool00omgMgOo<S8booooo`0Nooooo`03ob4Q8Ooooooooooo
00kooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001cooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Eooooo`03o`000?oooooooooo00Cooooo0_l0000Fooooo`03o`000?oooooooooo00Oo
oooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01cooooo00?oZJVYogMgMoooool02oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Gooooo`;o00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wo
oooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool06?ooool2
o`0000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo1?l0000Iooooo`Go00005?ooool2o`0000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`Co00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo1?l0000M
ooooo`Go00003?ooool4o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo002eooooo`Go00003Oooool3o`0002;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1dooooo`00]Oooool00ol0003oooooooooo`02ooooo`go00009?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo07Gooooo002eooooo`03o`000?oooooooooo037o
oooo0_l00004ooooo`03o`000?oooooooooo07Kooooo002eooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1gooooo`00]Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N?ooool000_oooooool0001F
o`0000Sooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_l0
003ooooooooooooooooo0000ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool0
1Ol0003ooooooooooooooooo000000Cooooo0_l0000Pooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`00]Oooool00ol0003oooooooooo`0Y
ooooo`;o00000oooool2o`00083ooooo002eooooo`03o`000?oooooooooo02Kooooo0ol00003oooo
o`;o0000P_ooool00;Gooooo00?o0000ooooooooool09?ooool2o`0000?ooooo0ol00024ooooo`00
]Oooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l000000_l00027ooooo`00]Ooo
ool00ol0003oooooooooo`0Qooooo`Co0000Roooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_o
oooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3o
oooo002Looooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo
002Mooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool00:oooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?oo
ool009cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00W?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0/?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo
<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
oooooooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`Go00003?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3o
oooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`?o0000/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo00000;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100^Oooool00:Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wo
oooo002Sooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.4439 .48588 m
.43777 .48796 L
.43361 .48978 L
.43134 .49127 L
.43088 .49239 L
.43214 .49317 L
.435 .49365 L
.43935 .49391 L
.44508 .49403 L
.45204 .49412 L
.4601 .49424 L
.46911 .49445 L
.47891 .49474 L
.48934 .49511 L
.50026 .49549 L
.51151 .49581 L
.52294 .49598 L
.53442 .49588 L
.54581 .49542 L
.55697 .49453 L
.56778 .49313 L
.57811 .49122 L
.58781 .48882 L
.59676 .48599 L
.60483 .48285 L
.6119 .47957 L
.61786 .47631 L
.62264 .47328 L
.62619 .47064 L
.62848 .46853 L
.62954 .46702 L
.62942 .46614 L
.62822 .46582 L
.62608 .46596 L
.62319 .46639 L
.61977 .46693 L
.61612 .46739 L
.61258 .46756 L
.60957 .46727 L
.60758 .46632 L
.6072 .46448 L
.60909 .46144 L
.61406 .45668 L
.62301 .44927 L
.63695 .43749 L
.65684 .41817 L
.68323 .38579 L
.71522 .33279 L
.74901 .25557 L
.77705 .1724 L
Mistroke
.79078 .1339 L
.78578 .17522 L
.76638 .25879 L
.74522 .32537 L
.73328 .35605 L
.73331 .3568 L
.74249 .3352 L
.75652 .29659 L
.77165 .24631 L
.78535 .19091 L
.79623 .13745 L
.80384 .09208 L
.8083 .05882 L
.81 .03921 L
.80945 .03257 L
.80712 .03679 L
.80348 .04905 L
.79895 .06646 L
.79388 .08645 L
.78864 .107 L
.78349 .12662 L
.7787 .14434 L
.77442 .15965 L
.77078 .17233 L
.76783 .18244 L
.76554 .19021 L
.76384 .19604 L
.76258 .20049 L
.76156 .20422 L
.7605 .20806 L
.75909 .21296 L
.75695 .22 L
.75361 .23031 L
.74854 .24502 L
.74113 .26496 L
.73071 .29039 L
.71669 .32046 L
.69875 .35301 L
.67703 .38478 L
.65232 .41257 L
.62585 .43438 L
.59904 .44992 L
.5731 .4602 L
.54887 .46675 L
.52682 .47103 L
.50715 .47408 L
.4899 .4766 L
.47502 .47895 L
.46245 .48129 L
.4521 .48362 L
Mistroke
.4439 .48588 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`17ooooo`00]Oooool00ol0003oooooooooo`1Uooooo`;o
0000BOooool00;Gooooo00?o0000ooooooooool0IOooool2o`0004Wooooo002eooooo`03o`000?oo
oooooooo06Gooooo0_l00019ooooo`00]Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
000004Wooooo002eooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool00000BOooool00;Go
oooo0_l0001Uooooo`03o`000?oooooo000004Wooooo002eooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooool00000BOooool00;Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooo`00
0019ooooo`00]Oooool00ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`0004Wooooo002e
ooooo`03o`000?oooooooooo06?ooooo00Co0000oooooooooooo0000BOooool00;Gooooo00?o0000
ooooooooool0Hoooool01?l0003oooooooooool00019ooooo`00]Oooool00ol0003oooooooooo`1S
ooooo`04o`000?ooooooooooo`0004Wooooo002eooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooool00000B_ooool00;Gooooo0_l0001Sooooo`04o`000?ooooooooooo`0004[ooooo002eoooo
o`03o`000?oooooooooo06;ooooo00Co0000oooooooooooo0000B_ooool00;Gooooo00?o0000oooo
ooooool0H_ooool01?l0003oooooooooool0001:ooooo`00]Oooool00ol0003oooooooooo`1Qoooo
o`05o`000?ooooooooooooooool00000B_ooool00;Gooooo00?o0000ooooooooool0HOooool01?l0
003oooooooooool0001;ooooo`00]Oooool00ol0003oooooooooo`1Qooooo`04o`000?oooooooooo
o`0004_ooooo002eooooo`03o`000?oooooooooo067ooooo00Co0000oooooooooooo0000Boooool0
0;Gooooo00?o0000ooooooooool0H?ooool01Ol0003ooooooooooooooooo000004_ooooo002eoooo
o`03o`000?oooooooooo063ooooo00Go0000ooooooooooooooooo`00001;ooooo`00]Oooool2o`00
067ooooo00Go0000ooooooooooooooooo`00001;ooooo`00]Oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool00;Gooooo00?o0000oooooooo
ool0Goooool01Ol0003ooooooooooooooooo000004cooooo002eooooo`03o`000?oooooooooo05oo
oooo00Go0000ooooooooooooooooo`00001<ooooo`00]Oooool00ol0003oooooooooo`1Oooooo`05
o`000?ooooooooooooooool00000C?ooool00;Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04[ooooo002Looooo`03o`000?o^k^kooooo00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0B_ooool009cooooo00?oEEEEojVYZOooool0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0B_ooool009;ooooo1_l00004ooooo`03ojVYZOmE
EEGooooo013ooooo00?o0000ooooooooool00oooool3o`0005gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1:ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04[ooooo002Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;
ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0GOooool01_l0003oooooooooool0003oooooo`0004gooooo002Jooooo`05oa0@4?oooooo
oooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo00Ko
0000oooooooooooo0000ooooool0001=ooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`1<ooooo`00]Ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool0C?oo
ool00;Gooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo04_ooooo002eooooo`03o`000?oooooooooo05cooooo00Ko0000ooooool0003o0000oooo
ool0001>ooooo`00]Oooool2o`0005cooooo00?o0000ooooooooool00_l000000ooooooo0000oooo
o`1=ooooo`00]Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00;o000000?ooooo
o`000?ooool0COooool00;Gooooo00?o0000ooooooooool0Foooool01ol0003oooooo`000?oooooo
0000ooooool00000C_ooool00;Gooooo00?o0000ooooooooool0F_ooool02?l0003oooooooooool0
003oooooo`000?oooooo0000C_ooool00;Gooooo00?o0000ooooooooool0F_ooool01Ol0003ooooo
ooooool0003ooooo00;o0000Coooool00;Gooooo00?o0000ooooooooool0F_ooool01ol0003ooooo
o`000?oooooo0000ooooool00000Coooool00;Gooooo00?o0000ooooooooool0FOooool02?l0003o
ooooooooool0003oooooo`000?oooooo0000Coooool00;Gooooo00?o0000ooooooooool0FOooool0
2?l0003oooooooooool0003oooooo`000?oooooo0000Coooool00;Gooooo0_l0001Jooooo`03o`00
0?oooooo000000;ooooo0_l0001@ooooo`00]Oooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooo000000;ooooo0_l0001@ooooo`00]Oooool00ol0003oooooooooo`1Hooooo`04o`000?oooooo
ooooo`0000;ooooo0_l0001@ooooo`00]Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
000000;ooooo00?o0000ooooool00000D?ooool00;Gooooo00?o0000ooooooooool0F?ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo0000053ooooo002eooooo`03o`000?oooooooooo05Oo
oooo00Co0000oooooooooooo00000_ooool2o`00057ooooo002eooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooool000000oooool2o`00057ooooo002eooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooool000000oooool2o`00057ooooo002eooooo`03o`000?oooooooooo05Oooooo00?o
0000ooooool000000_ooool00ol0003oooooo`00001Aooooo`00]Oooool2o`0005Oooooo00?o0000
ooooool000000oooool2o`0005;ooooo002eooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ool000000oooool2o`0005;ooooo002eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooool0
00000oooool2o`0005;ooooo002eooooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o0000
D_ooool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooo`000003ooooo`;o0000Dooo
ool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooo`000003ooooo`;o0000Doooool0
0;Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooo`000004ooooo`;o0000Doooool00;Go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo05;o
oooo002eooooo`;o0000EOooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo05;ooooo
002eooooo`03o`000?oooooooooo05?ooooo00?o0000ooooool000001?ooool2o`0005Cooooo002e
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooool000001?ooool2o`0005Cooooo002eoooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`1Coooo
o`00]Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool0Doooool00;Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo05?ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooo000000Cooooo0_l0001Eooooo`00[_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`1Dooooo`00X_ooool6o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0E?ooool00:kooooo00?oMgMgoc8b
<_ooool01?ooool3o`00057ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1Doooo
o`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0D?ooool00ol0
003oooooo`000006ooooo`03o`000?oooooooooo05Cooooo002[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0D?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo05Go
oooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo05Gooooo002[ooooo`Co00001_ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0EOooool00;Gooooo00?o0000
ooooooooool0Coooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo05Kooooo002eoooo
o`03o`000?oooooooooo04oooooo0_l00006ooooo`03o`000?oooooooooo05Kooooo002eooooo`03
o`000?oooooooooo04kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`1Fooooo`00
]Oooool2o`0004oooooo0_l00006ooooo`03o`000?oooooooooo05Oooooo002eooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`1Gooooo`00]Oooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0Eoooool0
0;Gooooo00?o0000ooooooooool0COooool2o`0000Kooooo0_l0001Iooooo`00]Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0F?ooool00;Gooooo
00?o0000ooooooooool0C?ooool2o`0000Oooooo00?o0000ooooooooool0F?ooool00;Gooooo00?o
0000ooooooooool0Boooool00ol0003oooooo`000006ooooo`;o0000F_ooool00;Gooooo00?o0000
ooooooooool0Boooool2o`0000Oooooo00?o0000ooooooooool0FOooool00;Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo05Wooooo002eooooo`;o
0000Boooool2o`0000Oooooo0_l0001Kooooo`00]Oooool00ol0003oooooooooo`1:ooooo`;o0000
1oooool00ol0003oooooooooo`1Jooooo`00]Oooool00ol0003oooooooooo`19ooooo`;o00002?oo
ool00ol0003oooooooooo`1Jooooo`00]Oooool00ol0003oooooooooo`19ooooo`;o00001oooool2
o`0005cooooo002eooooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`03o`000?oooooooooo
05_ooooo002eooooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`03o`000?oooooooooo05_o
oooo002eooooo`03o`000?oooooooooo04Sooooo0_l00007ooooo`03o`000?oooooooooo05cooooo
002eooooo`03o`000?oooooooooo04Oooooo0_l00008ooooo`03o`000?oooooooooo05cooooo002e
ooooo`;o0000B?ooool2o`0000Sooooo00?o0000ooooooooool0G?ooool00;Gooooo00?o0000oooo
ooooool0A_ooool2o`0000Sooooo00?o0000ooooooooool0GOooool00;Gooooo00?o0000oooooooo
ool0A_ooool2o`0000Sooooo00?o0000ooooooooool0GOooool00;Gooooo00?o0000ooooooooool0
AOooool2o`0000Sooooo0_l0001Oooooo`00]Oooool00ol0003oooooooooo`15ooooo`;o00002?oo
ool00ol0003oooooooooo`1Nooooo`00]Oooool00ol0003oooooooooo`14ooooo`;o00002Oooool0
0ol0003oooooooooo`1Nooooo`00]Oooool00ol0003oooooooooo`13ooooo`;o00002Oooool00ol0
003oooooooooo`1Oooooo`00]Oooool00ol0003oooooooooo`13ooooo`;o00002Oooool00ol0003o
ooooooooo`1Oooooo`00]Oooool00ol0003oooooooooo`12ooooo`;o00002Oooool00ol0003ooooo
ooooo`1Pooooo`00]Oooool2o`0004?ooooo0_l00009ooooo`03o`000?oooooooooo063ooooo002e
ooooo`03o`000?oooooooooo047ooooo0_l0000:ooooo`03o`000?oooooooooo063ooooo002eoooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Qoooo
o`00]Oooool00ol0003oooooooooo`10ooooo`;o0000K_ooool00;Gooooo00?o0000ooooooooool0
?oooool2o`0006oooooo002eooooo`03o`000?oooooooooo03kooooo00?o0000ooooool00000Kooo
ool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0?_ooool2o`00073ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0mooooo`;o0000LOoo
ool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3
o`0003cooooo00?o0000ooooool00000LOooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03cooooo0_l0001booooo`00WOooool00omgMgOo
IVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooo000007;ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo000007?ooooo002Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooool00000M?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co
00001_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo000007Cooooo002eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooool00000MOooool00;Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooo`00001fooooo`00]Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
000007Oooooo002eooooo`;o0000=_ooool00ol0003oooooo`00001hooooo`00]Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooo000007Wooooo002eooooo`03o`000?oooooooooo03?ooooo
00Co0000oooooooooooo0000NOooool00;Gooooo00?o0000ooooooooool0<_ooool01?l0003ooooo
ooooool0001jooooo`00]Oooool00ol0003oooooooooo`0`ooooo`;o00000_ooool00ol0003ooooo
ooooo`1iooooo`00]Oooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool00000
O?ooool00;Gooooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo000007gooooo
002eooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00001nooooo`00]Ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00001oooooo`00]Oooool00ol0003ooooooooo
o`0[ooooo`05o`000?ooooooooooooooool00000P?ooool00;Gooooo00?o0000ooooooooool0:_oo
ool01Ol0003ooooooooooooooooo0000087ooooo002eooooo`03o`000?oooooooooo02Wooooo00Go
0000ooooooooooooooooo`000022ooooo`00]Oooool00ol0003oooooooooo`0Wooooo`;o00000ooo
ool00ol0003oooooooooo`21ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool0
0ol0003oooooooooo`22ooooo`00]Oooool00ol0003oooooooooo`0Sooooo`;o00001Oooool00ol0
003oooooooooo`23ooooo`00]Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Q?ooool00;Gooooo00?o0000ooooooooool08?ooool2o`0000Kooooo
00?o0000ooooooooool0QOooool00;Gooooo0_l0000Oooooo`;o00001_ooool2o`0008Sooooo002e
ooooo`03o`000?oooooooooo01_ooooo0ol00007ooooo`03o`000?oooooooooo08Sooooo002eoooo
o`03o`000?oooooooooo01Sooooo0ol00009ooooo`03o`000?oooooooooo08Wooooo002eooooo`03
o`000?oooooooooo01Gooooo0ol0000;ooooo`03o`000?oooooooooo08[ooooo0009ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd0
7?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003o
ooooooooo`0Booooo`?o00001oooool5o`000003ooooool0003ooooo00;ooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o0000
onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool03oooool3
o`0000[ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00004ooooo`;o8B4Q0_l00006ooooo`03ogMg
Molb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Aooooo`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01?o
oooo1_l00007ooooo`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`Go00003_ooool01?nHV9So
8B4Qonk^k_ooool7o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Qooooooooool03_ooool0
0omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RHob4Q8Oo^k^h03oooool0
0omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00?ooooo1ol0000Dooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool01Oooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;o
oooo01kooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo00?oMgMgofIVI_oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01_ooooo1ol0000Looooo`03ogMgMomVIVKooooo
00Cooooo0_l00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06?ooool5o`000003ooooool0003ooooo027ooooo00Co0000oooooooo
oooooooo0_l00007ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00onY
ZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Iooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01kooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`00
0?oooooooooo01?ooooo1Ol00006ooooo`03o`000?oooooooooo01cooooo00Ko0000okZj^_oooooo
V9RHoa0@4?ooool2o`0000Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Noooo
o`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`Ko00002oooool00ol0003ooooo
ooooo`0Looooo`04oiRHV?l@413o0000ob4Q8@;o00002oooool4o`0001oooooo1?l0000Mooooo`Go
00003?ooool4o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo002Qooooo`?o00004Oooool00ol0003oooooooooo`0Mooooo`?o0000T?ooool009oooooo
0_l0000Dooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00WOooool2o`0001Kooooo00?o
0000ooooooooool05_ooool3o`0009Oooooo002Noooooa[o00002oooool;o`0009[ooooo002eoooo
o`03o`000?oooooooooo00_o0000YOooool000_oooooool0001Fo`0000Sooooo000;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool000_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Kooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2`ooooo`00W?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00W_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002_oooo
o`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002[ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l00006
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009cooooo00?oZJVYoeEE
EOooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03
ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03oeEE
EOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3o
oooo002Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^1_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000;3ooooo002Uooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00YOooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@0;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00Xoooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0^Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.39895 .60797 m
.39496 .62953 L
.39298 .64411 L
.39227 .65153 L
.39248 .65202 L
.39353 .646 L
.39559 .63402 L
.39903 .61688 L
.40438 .59581 L
.41228 .57274 L
.42338 .55037 L
.4382 .53176 L
.45687 .5195 L
.47898 .51424 L
.50338 .51362 L
.52843 .5125 L
.55221 .50496 L
.57305 .48701 L
.58983 .4582 L
.60217 .42129 L
.61027 .38056 L
.61474 .34018 L
.61634 .30317 L
.61587 .27122 L
.61407 .24492 L
.61155 .22413 L
.60881 .20836 L
.60625 .197 L
.60415 .18946 L
.60268 .18525 L
.60193 .18401 L
.60191 .18547 L
.60255 .18943 L
.60369 .19574 L
.60516 .20419 L
.60673 .21447 L
.60818 .22601 L
.60932 .23794 L
.61002 .24897 L
.61022 .25741 L
.60989 .26126 L
.60892 .25842 L
.60689 .24709 L
.60276 .22654 L
.59455 .19826 L
.57937 .16646 L
.55368 .13527 L
.51406 .10217 L
.46003 .06114 L
.40342 .03033 L
Mistroke
.37304 .02512 L
.38752 .01351 L
.43043 .01579 L
.46933 .03306 L
.48859 .04337 L
.48853 .04281 L
.4739 .034 L
.44954 .02087 L
.42003 .00946 L
.38988 .00731 L
.36309 .01859 L
.34241 .03996 L
.32895 .06237 L
.32259 .0773 L
.32242 .08113 L
.32731 .07548 L
.33601 .06477 L
.34728 .05353 L
.35991 .04478 L
.37286 .03967 L
.38528 .03795 L
.39657 .0387 L
.40635 .04086 L
.41446 .04356 L
.42091 .04617 L
.42581 .04838 L
.42943 .05006 L
.43209 .05129 L
.43426 .05226 L
.43648 .05326 L
.43939 .0547 L
.44372 .05709 L
.45026 .06108 L
.45982 .06745 L
.47308 .07699 L
.49038 .09017 L
.51146 .10681 L
.53521 .12648 L
.55968 .15039 L
.58217 .18387 L
.59916 .23568 L
.60619 .31036 L
.59878 .39631 L
.57521 .46555 L
.53938 .4981 L
.4997 .504 L
.46421 .50816 L
.43693 .52424 L
.41811 .55075 L
.40611 .58064 L
Mistroke
.39895 .60797 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002>ooooo`So00003oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`2`ooooo`00S?ooool2
o`0000Sooooo1_l00009ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo0;3ooooo0029ooooo`?o00000_ooool9o`0000Gooooo0ol00004
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo0027ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`[o00005?ooool0
0ol0003oooooooooo`2`ooooo`00Q_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
013ooooo1Ol0000Aooooo`03o`000?oooooooooo0;3ooooo0025ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool2o`000003ooooool0003o000000oooooo00?o0000oooooooo
ool0/?ooool008Cooooo00?o0000ooooooooool00oooool4o`0001Gooooo1Ol0000=ooooo`;o0000
/Oooool008?ooooo00?o0000ooooooooool02?ooool5o`0001?ooooo1?l0000;ooooo`03o`000?oo
oooooooo0;3ooooo0022ooooo`03o`000?oooooooooo00kooooo0ol0000Booooo`Co00002Oooool0
0ol0003oooooooooo`2`ooooo`00POooool00ol0003oooooooooo`0Booooo`;o00004_ooool4o`00
00Oooooo00?o0000ooooooooool0/?ooool0083ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Aooooo`Co00001Oooool00ol0003oooooooooo`2`ooooo`00Ooooool00ol0003ooooo
ooooo`07ooooo`co00001?ooool2o`0001?ooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`2`ooooo`00Ooooool00ol0003oooooooooo`04ooooo`?o00003?ooool3o`0000?ooooo0_l0
000Booooo`?o00000oooool00ol0003oooooooooo`2`ooooo`00O_ooool00ol0003oooooooooo`03
ooooo`;o00004_ooool2o`0000?ooooo0_l0000Booooo`05o`000?ooooooooooooooool00000/_oo
ool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`?o00000_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;3ooooo001mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000001?ooooo0_l0002aoooo
o`00OOooool01Ol0003ooooooooooooooooo000001gooooo1Ol0000Aooooo`03o`000?oooooooooo
0;3ooooo001looooo`05o`000?ooooooooooooooool000008Oooool00ol0003oooooo`00000@oooo
o`03o`000?oooooooooo0;3ooooo001looooo`04o`000?ooooooooooo`0002?ooooo00Co0000oooo
ool0003o00003_ooool00ol0003oooooooooo`2`ooooo`00Noooool01?l0003oooooooooool0000U
ooooo`;o000000?oooooo`000?l000003?ooool00ol0003oooooooooo`2`ooooo`00Noooool00ol0
003oooooo`00000Xooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0/?ooool0
07[ooooo00Co0000oooooooooooo0000:Oooool2o`000003ooooool0003ooooo00Wooooo00?o0000
ooooooooool0/?ooool007[ooooo00?o0000ooooool00000;?ooool4o`0000Sooooo00?o0000oooo
ooooool0/?ooool007[ooooo0_l0000_ooooo`03o`000?oooooo000000Oooooo0_l0002aooooo`00
NOooool2o`00037ooooo0ol00006ooooo`03o`000?oooooooooo0;3ooooo001hooooo`03o`000?oo
oooooooo03?ooooo0ol00004ooooo`03o`000?oooooooooo0;3ooooo002_ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool0/?ooool00;3ooooo00Ko0000ooooool0003o0000ooooool0
002booooo`00/Oooool00ol0003oooooooooo`02o`000;;ooooo002booooo`;o000000?oooooo`00
0?ooool0/Oooool00;Cooooo1?l0002`ooooo`00]Oooool2o`000003ooooool0003ooooo0:kooooo
002eooooo`?o000000?oooooo`000?ooool0[Oooool00;Gooooo00Go0000oooooooooooo0000oooo
o`02o`000:cooooo002eooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool0Z_oo
ool00;Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00002Zooooo`00]Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooo00000:Wooooo002eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooool00000Z?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0
003o0000Y_ooool009cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`000:Gooooo002Booooo`Ko
00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`04
o`000?ooooooooooo`000:Cooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`000:?ooooo002Mooooo`03
oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooo0000X_ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000XOooool0
09[ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03?ooool01?l0003oooooooooool0002Pooooo`00V_ooool5o`0000cooooo1?l00006
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000X?ooool00;Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooo`00002Oooooo`00]Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooo000009kooooo002eooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000
WOooool00;Gooooo0_l0000Booooo`03o`000?oooooo000009cooooo002eooooo`03o`000?oooooo
oooo017ooooo00Co0000oooooooooooo0000Voooool00;Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooo`00002Kooooo`00]Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo0000
09[ooooo002eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool00000VOooool00;Gooooo
00?o0000ooooooooool05?ooool01?l0003oooooooooool0002Hooooo`00]Oooool00ol0003ooooo
ooooo`0Eooooo`04o`000?ooooooooooo`0009Oooooo002eooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooool00000Uoooool00;Gooooo0_l0000Gooooo`04o`000?ooooooooooo`0009Kooooo
002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool00000U_ooool00;Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`00002Eooooo`00]Oooool00ol0003oooooooooo`0Ioooo
o`;o00001Oooool00ol0003oooooooooo`2=ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool0SOooool00;Gooooo00?o0000ooooooooool0
6_ooool2o`0000Cooooo00?o0000ooooooooool0SOooool00;Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo08gooooo002eooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooool000000oooool2o`0008kooooo002eooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooool000000_ooool2o`0008kooooo002eooooo`;o00007?ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`2<ooooo`00]Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000000;ooooo0_l0002=ooooo`00]Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooo000000;ooooo0_l0002=ooooo`00]Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo000000;ooooo0_l0002=ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`04
o`000?oooooo0000ooooo`;o0000SOooool00;Gooooo00?o0000ooooooooool07Oooool01ol0003o
ooooo`000?oooooo0000ooooool00000S?ooool00;Gooooo00?o0000ooooooooool07Oooool01ol0
003oooooo`000?oooooo0000ooooool00000S?ooool00;Gooooo0_l0000Oooooo`04o`000?oooooo
0000ooooo`;o0000S?ooool00;Gooooo00?o0000ooooooooool07_ooool01?l0003oooooo`000?oo
ool2o`0008cooooo002eooooo`03o`000?oooooooooo01kooooo00Co0000ooooool0003ooooo0_l0
002<ooooo`00]Oooool00ol0003oooooooooo`0Oooooo`;o000000?oooooo`000?l00000S?ooool0
0;Gooooo00?o0000ooooooooool07oooool2o`000004ooooool0003oooooo`0008_ooooo002eoooo
o`03o`000?oooooooooo01oooooo00Ko0000ooooool0003o0000ooooool0002;ooooo`00Zoooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool01_l0003oooooo`00
0?l0003oooooo`0008_ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
7oooool01_l0003oooooo`000?l0003oooooo`0008_ooooo002Rooooo`Ko00001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01oooooo00Ko0000ooooool0003o0000ooooool0002;
ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`?o00007oooool01_l0003oooooo`000?l0003o
ooooo`0008_ooooo002[ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Oooooo`06o`000?oooooo0000o`000?oooooo0000Roooool00:_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooo0000ooooool00000Roooool00:_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooo0000ooooool0
0000Roooool00:_ooooo1?l00006ooooo`03o`000?oooooooooo023ooooo00Go0000ooooool0003o
ooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool0
0000Roooool00;Gooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000008_o
oooo002eooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002;ooooo`00
]Oooool2o`00027ooooo00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000008_ooooo002eooooo`03o`000?oooooooooo023ooooo
00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Pooooo`05o`00
0?ooooooooooooooool00000Roooool00;Gooooo00?o0000ooooooooool08?ooool01Ol0003ooooo
oooooooooooo000008_ooooo002eooooo`03o`000?oooooooooo023ooooo00Go0000oooooooooooo
ooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0008_o
oooo002eooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000Roooool00;Gooooo
0_l0000Rooooo`04o`000?ooooooooooo`0008_ooooo002eooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo0000Roooool00;Gooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooool0002;ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0008_o
oooo002eooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000Roooool00;Gooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool0002;ooooo`00]Oooool00ol0003ooooo
ooooo`0Qooooo`04o`000?ooooooooooo`0008_ooooo002eooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo0000Roooool00;Gooooo0_l0000Rooooo`04o`000?ooooooooooo`0008_o
oooo002eooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002;ooooo`00
]Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo
00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000008_ooooo002eooooo`03o`00
0?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000008_ooooo002eooooo`03o`000?oooooooooo023ooooo
00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Pooooo`05o`00
0?ooooooooooooooool00000Roooool00;Gooooo0_l0000Qooooo`05o`000?ooooooooooooooool0
0000Roooool00;Gooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0002<ooooo`00
]Oooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000S?ooool00;Gooooo
00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000008cooooo002eooooo`03o`00
0?oooooooooo01oooooo00Go0000ooooooooooooooooo`00002<ooooo`00]Oooool00ol0003ooooo
ooooo`0Oooooo`05o`000?ooooooooooooooool00000S?ooool009[ooooo1Ol00005ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool01Ol0003o
oooooooooooooooo000008cooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Oooooo`05o`000?oooooooooo
ooooool00000S?ooool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool00oooool3o`0001oooooo00Co0000oooooooooooo0000SOooool009cooooo00?oV9RHob4Q
8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooo0000SOooool009gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0002=ooooo`00W_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool0
1?l0003oooooooooool0002=ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool00000
SOooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003ooooo
ooooo`0Nooooo`05o`000?ooooooooooooooool00000SOooool00;Gooooo00?o0000ooooooooool0
7_ooool01?l0003oooooooooool0002>ooooo`00]Oooool00ol0003oooooooooo`0Nooooo`04o`00
0?ooooooooooo`0008kooooo002eooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo
0000S_ooool00;Gooooo0_l0000Oooooo`04o`000?ooooooooooo`0008kooooo002eooooo`03o`00
0?oooooooooo01gooooo00Go0000ooooooooooooooooo`00002>ooooo`00]Oooool00ol0003ooooo
ooooo`0Mooooo`05o`000?ooooooooooooooool00000S_ooool00;Gooooo00?o0000ooooooooool0
7Oooool01Ol0003ooooooooooooooooo000008kooooo002eooooo`03o`000?oooooooooo01cooooo
00Go0000ooooooooooooooooo`00002?ooooo`00]Oooool00ol0003oooooooooo`0Looooo`05o`00
0?ooooooooooooooool00000Soooool00;Gooooo00?o0000ooooooooool07?ooool01Ol0003ooooo
oooooooooooo000008oooooo002eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2=ooooo`00]Oooool2o`0001cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2=ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`05o`000?oooooo
ooooooooool00000T?ooool00;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool00000TOooool00;Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo01Wooooo
00Go0000ooooooooooooooooo`00002Booooo`00]Oooool00ol0003oooooooooo`0Iooooo`05o`00
0?ooooooooooooooool00000T_ooool00;Gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo093ooooo002eooooo`;o00006Oooool01Ol0003ooooooooo
oooooooo000009?ooooo002eooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00002Cooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0TOooool00;Gooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooo
oooo000009Cooooo0009ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ_o
oooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Noooo
o`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooooooo`Ko0000
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b
<_oMgMd07_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool000_ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEEojVYZOoo
ool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Kooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0
003oooooooooo`0Eooooo`;o00000oooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnY
ZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo
00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00oooool01_l0003ooooooooooonHV9So8B4Qonk^kQ7ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
00_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Q
ooooooooool03_ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RH
ob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMg
oc8b<_ooool08?ooool00omgMgOo<S8booooo`0Nooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMg
oc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o
EEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Oooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Loooo
o`;o00004oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?oMgMgofIV
I_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo027ooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01Oooool02Ol0003ooooooooooooooooo0000okZj^_ooooooV9RHoa0@400<oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`Co00007Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Oooooo`Co
00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`00]Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0U_ooool00;Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`05ooooo`;o0000VOooool00;Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo09Wooooo002eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Jooooo`00]Oooool00ol0003oooooooooo`07oooo
o`Co00001oooool00ol0003oooooooooo`2Kooooo`002oooooooo`0005Ko00002?ooool000_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01oooooo1_l0
0003ooooo`03o`000?oooooooooo00gooooo0ol0000Gooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002X
ooooo`Co00002Oooool00ol0003oooooooooo`09ooooo`Co0000Xoooool00:Kooooo0_l0000=oooo
o`03o`000?oooooooooo00?ooooo1_l0002Wooooo`00Y?ooool2o`0000Kooooo3ol0002]ooooo`00
X_ooool2o`0000Cooooo1?l00009ooooo`03o`000?oooooooooo0;3ooooo002Pooooo`;o00000ooo
ool3o`0000gooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo
00;o00004Oooool2o`000;7ooooo002Nooooo`04o`000?ooooooooooo`0001?ooooo00?o0000oooo
ooooool0/?ooool009gooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`2`oooo
o`00WOooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo0;3ooooo002Looooo`04
o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0/?ooool009_ooooo00Co0000oooooooo
oooo00005_ooool00ol0003oooooooooo`2`ooooo`00Voooool00ol0003oooooo`00000Gooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool0
/?ooool009Wooooo00?o0000ooooool000006Oooool2o`000;7ooooo002Iooooo`03o`000?oooooo
000001Wooooo00?o0000ooooooooool0/?ooool009Sooooo00?o0000ooooool000006_ooool00ol0
003oooooooooo`2`ooooo`00V?ooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo0;3o
oooo002Hooooo`;o00006oooool00ol0003oooooooooo`2`ooooo`00Uoooool00ol0003oooooo`00
000Kooooo`03o`000?oooooooooo0;3ooooo002Gooooo`;o00007?ooool00ol0003oooooooooo`2`
ooooo`00U_ooool00ol0003oooooo`00000Looooo`03o`000?oooooooooo0;3ooooo002Fooooo`;o
00007Oooool00ol0003oooooooooo`2`ooooo`00U_ooool2o`0001gooooo0_l0002aooooo`00UOoo
ool2o`0001kooooo00?o0000ooooooooool0/?ooool009Gooooo0_l0000Nooooo`03o`000?oooooo
oooo0;3ooooo002Eooooo`;o00007_ooool00ol0003oooooooooo`2`ooooo`00U?ooool2o`0001oo
oooo00?o0000ooooooooool0/?ooool009Cooooo0_l0000Oooooo`03o`000?oooooooooo0;3ooooo
002Dooooo`;o00007oooool00ol0003oooooooooo`2`ooooo`00Toooool2o`00023ooooo00?o0000
ooooooooool0/?ooool009?ooooo0_l0000Pooooo`;o0000/Oooool009?ooooo0_l0000Pooooo`03
o`000?oooooooooo0;3ooooo002Booooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool0
/?ooool009;ooooo0_l0000Qooooo`03o`000?oooooooooo0;3ooooo002Booooo`;o00008Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool2o`00027ooooo00?o0000ooooooooool0/?ooool009;o
oooo0_l00006ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;3ooooo002Aooooo`03o`000?oooooo000000Kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Aooooo`;o00002?ooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/?ooool0097ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Aooooo`;o00002_ooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00TOoo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00TOooool00ol0003oooooooooo`06ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002@
ooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03o`000?oo
oooooooo0;3ooooo002@ooooo`;o00008oooool00ol0003oooooooooo`2`ooooo`00T?ooool2o`00
02?ooooo00?o0000ooooooooool0/?ooool0093ooooo0_l0000Sooooo`03o`000?oooooooooo0;3o
oooo002@ooooo`;o00008oooool2o`000;7ooooo002@ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
0:oooooo00?o0000ooooooooool00oooool3o`000;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool00:_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00Zoooool4
o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009cooooo00?oEEEEojVYZOooool01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00W?ooool00onY
ZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009go
oooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo
00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0/?ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00003?ooool4o`0000Kooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000/?ooool00:Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00YOooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100^Oooool00:Gooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo002Sooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell["\<\
Although the patch area remains constant, the dye patch is \
stretched and folded by the flow in a very complex manner due to the chaotic \
nature of the characteristics. Ultimately, the filaments of dye become so \
thin that they are indistinguishable, and the dye becomes thoroughly mixed \
through the background fluid. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4: The Collisionless Boltzmann Equation", "Section",
  CellTags->"c:9"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  can also be interpreted in a different manner. Rather than thinking of \
",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as the density of dye placed in a fluid, we can instead think of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as the density in phase space ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, \ p)\)\)]],
  " of a one-dimensional gas of atoms of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p = m\ \[DifferentialD]x/\[DifferentialD]t\)]],
  " is the particle momentum. Now ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x, p, t)\)]],
  ", and Eq. ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  is written as"
}], "Text",
  CellTags->"i:20"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \(p\/m\) \[PartialD]f\/\
\[PartialD]x + \ \(F(x, p, t)\) \[PartialD]f\/\[PartialD]p = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.21)"],

Cell[TextData[{
  "The physical interpretation of the function ",
  Cell[BoxData[
      \(TraditionalForm\`F(x, p, t)\)]],
  " becomes clear when we write out the characteristic equations:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = 
        p/m, \[IndentingNewLine]\[DifferentialD]p\/\[DifferentialD]t = 
        F(x, p, t)\)]],
  "."
}], "UNNEQ",
  CellTags->"i:19"],

Cell[TextData[{
  "These are Newton's equations for the motion of particles in a prescribed \
external force ",
  Cell[BoxData[
      \(TraditionalForm\`F(x, p, t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Equation ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  "  is called the collisionless Boltzmann ( or Vlasov)  equation. The number \
of particles in the element ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\ \[DifferentialD]p\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`f\ \[DifferentialD]x\ \[DifferentialD]p\)]],
  ". According to our understanding of convective derivatives, Eq. ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  "  is equivalent to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " along the characteristics. This means that the particle density in phase \
space remains constant along the phase-space flow: particles are neither \
created nor destroyed, but are simply carried through phase space by their  \
dynamics."
}], "Text",
  CellTags->"i:6"],

Cell[TextData[{
  "\tInteractions between the particles are neglected in this description of \
the gas, since the only force acting on the particles is the external force \
",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ". ",
  Cell[BoxData[
      FormBox[Cell[TextData[StyleBox["", "Input"]]], TraditionalForm]]],
  " Therefore, Eq. ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  "  describes the evolution of an ",
  StyleBox["ideal gas",
    FontSlant->"Italic"],
  " of ",
  StyleBox["noninteracting",
    FontSlant->"Italic"],
  " ",
  StyleBox["particles",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:7"],

Cell[TextData[{
  "\t For example, consider the behavior of a gas of particles falling in \
gravity.  If the particles are confined in an evacuated container, the force \
law could be given by something like ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(-m\)\ g\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(-m\)\ g\  - \ k\ x, \ x < 0\)]],
  ", where the term ",
  Cell[BoxData[
      \(TraditionalForm\`k\ x\)]],
  " describes an elastic collision of the atoms with the bottom of the \
container at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ". A few characteristics for this flow in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " plane are shown in Cell ",
  ButtonBox["7.6",
    ButtonData:>"Cell 7.6",
    ButtonStyle->"Hyperlink"],
  " for a range of initial conditions, taking ",
  Cell[BoxData[
      \(TraditionalForm\`k = 20, m = \(g = 1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear[c];\)\(\n\)
    \)\), "\n", 
    \(m = \(g = 1\); k = 20;\), "\n", 
    \(F[x_]\  := \ \(-m\)\ g\  /; \ x > 0\), "\n", 
    \(F[x_]\  := \ \(-m\)\ g\  - \ k\ x\  /; \ x \[LessEqual] \ 0\), "\n", 
    \(\(\(c[x0_, 
          p0_]\  := \ \(c[x0, 
            p0]\  = \ {x[t], 
              p[t]} /. \(NDSolve[{\(x'\)[t]\  \[Equal] \ 
                    p[t]/m, \(p'\)[t]\  \[Equal] \ F[x[t]], x[0] \[Equal] x0, 
                  p[0] \[Equal] p0}, {x, p}, {t, 0, 50}, 
                MaxSteps \[Rule] 4000]\)[\([1]\)]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ParametricPlot[Evaluate[c[x0, p0]], {t, 0, 20}, 
          DisplayFunction \[Rule] Identity], {x0, 0, 2}, {p0, \(-1\), 
          1}];\)\), "\n", 
    \(\(Show[%, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<x\>", "\<p\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.196186 0.312003 0.309018 0.130964 [
[.04018 .29652 -12 -9 ]
[.04018 .29652 12 0 ]
[.35219 .29652 -9 -9 ]
[.35219 .29652 9 0 ]
[.50819 .29652 -3 -9 ]
[.50819 .29652 3 0 ]
[.66419 .29652 -9 -9 ]
[.66419 .29652 9 0 ]
[.82019 .29652 -3 -9 ]
[.82019 .29652 3 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.18369 .04709 -12 -4.5 ]
[.18369 .04709 0 4.5 ]
[.18369 .17805 -12 -4.5 ]
[.18369 .17805 0 4.5 ]
[.18369 .43998 -6 -4.5 ]
[.18369 .43998 0 4.5 ]
[.18369 .57095 -6 -4.5 ]
[.18369 .57095 0 4.5 ]
[.19619 .64303 -5 0 ]
[.19619 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04018 .30902 m
.04018 .31527 L
s
[(-0.5)] .04018 .29652 0 1 Mshowa
.35219 .30902 m
.35219 .31527 L
s
[(0.5)] .35219 .29652 0 1 Mshowa
.50819 .30902 m
.50819 .31527 L
s
[(1)] .50819 .29652 0 1 Mshowa
.66419 .30902 m
.66419 .31527 L
s
[(1.5)] .66419 .29652 0 1 Mshowa
.82019 .30902 m
.82019 .31527 L
s
[(2)] .82019 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07139 .30902 m
.07139 .31277 L
s
.10259 .30902 m
.10259 .31277 L
s
.13379 .30902 m
.13379 .31277 L
s
.16499 .30902 m
.16499 .31277 L
s
.22739 .30902 m
.22739 .31277 L
s
.25859 .30902 m
.25859 .31277 L
s
.28979 .30902 m
.28979 .31277 L
s
.32099 .30902 m
.32099 .31277 L
s
.38339 .30902 m
.38339 .31277 L
s
.41459 .30902 m
.41459 .31277 L
s
.44579 .30902 m
.44579 .31277 L
s
.47699 .30902 m
.47699 .31277 L
s
.53939 .30902 m
.53939 .31277 L
s
.57059 .30902 m
.57059 .31277 L
s
.60179 .30902 m
.60179 .31277 L
s
.63299 .30902 m
.63299 .31277 L
s
.69539 .30902 m
.69539 .31277 L
s
.72659 .30902 m
.72659 .31277 L
s
.75779 .30902 m
.75779 .31277 L
s
.78899 .30902 m
.78899 .31277 L
s
.85139 .30902 m
.85139 .31277 L
s
.88259 .30902 m
.88259 .31277 L
s
.91379 .30902 m
.91379 .31277 L
s
.94499 .30902 m
.94499 .31277 L
s
.00898 .30902 m
.00898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19619 .04709 m
.20244 .04709 L
s
[(-2)] .18369 .04709 1 0 Mshowa
.19619 .17805 m
.20244 .17805 L
s
[(-1)] .18369 .17805 1 0 Mshowa
.19619 .43998 m
.20244 .43998 L
s
[(1)] .18369 .43998 1 0 Mshowa
.19619 .57095 m
.20244 .57095 L
s
[(2)] .18369 .57095 1 0 Mshowa
.125 Mabswid
.19619 .07328 m
.19994 .07328 L
s
.19619 .09948 m
.19994 .09948 L
s
.19619 .12567 m
.19994 .12567 L
s
.19619 .15186 m
.19994 .15186 L
s
.19619 .20425 m
.19994 .20425 L
s
.19619 .23044 m
.19994 .23044 L
s
.19619 .25663 m
.19994 .25663 L
s
.19619 .28283 m
.19994 .28283 L
s
.19619 .33521 m
.19994 .33521 L
s
.19619 .3614 m
.19994 .3614 L
s
.19619 .3876 m
.19994 .3876 L
s
.19619 .41379 m
.19994 .41379 L
s
.19619 .46617 m
.19994 .46617 L
s
.19619 .49237 m
.19994 .49237 L
s
.19619 .51856 m
.19994 .51856 L
s
.19619 .54475 m
.19994 .54475 L
s
.19619 .0209 m
.19994 .0209 L
s
.19619 .59714 m
.19994 .59714 L
s
.25 Mabswid
.19619 0 m
.19619 .61803 L
s
gsave
.19619 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.19619 .17805 m
.1884 .17563 L
.18124 .17483 L
.17296 .17559 L
.16523 .17795 L
.15825 .18154 L
.152 .18602 L
.14543 .19217 L
.13887 .20003 L
.13279 .20922 L
.12688 .22044 L
.12237 .23112 L
.11814 .24369 L
.11594 .25171 L
.11417 .25939 L
.11142 .27508 L
.10983 .28979 L
.10912 .30574 L
.10915 .31395 L
.10946 .3226 L
.11078 .33793 L
.11191 .3463 L
.11323 .35399 L
.11712 .3708 L
.1215 .38457 L
.12624 .39619 L
.1325 .40831 L
.13913 .41835 L
.14557 .42602 L
.15286 .43271 L
.15936 .43716 L
.16677 .44069 L
.17487 .44279 L
.18369 .44309 L
.19198 .4415 L
.19944 .43861 L
.2606 .40937 L
.30353 .38216 L
.32007 .36844 L
.33397 .35378 L
.34014 .34541 L
.3448 .33751 L
.34802 .33042 L
.34943 .32642 L
.35048 .32273 L
.35123 .31928 L
.35174 .31601 L
.35204 .31308 L
.35218 .30987 L
.35212 .3064 L
Mistroke
.352 .30447 L
.35182 .30271 L
.35132 .29929 L
.35066 .29607 L
.34883 .28982 L
.34653 .28408 L
.34331 .27777 L
.33912 .27112 L
.32768 .25711 L
.31379 .24404 L
.27069 .21436 L
.24517 .20055 L
.23032 .19327 L
.21351 .18554 L
.19796 .1788 L
.19355 .17705 L
.18875 .1757 L
.17999 .17483 L
.17188 .17582 L
.16347 .17872 L
.15649 .18268 L
.14914 .1885 L
.1418 .19629 L
.13537 .20507 L
.12491 .22484 L
.12007 .23758 L
.11634 .25017 L
.1131 .26476 L
.11182 .27236 L
.11069 .28086 L
.10947 .29537 L
.1091 .30876 L
.10956 .32421 L
.11086 .33867 L
.11281 .3517 L
.11522 .36338 L
.11853 .37564 L
.12276 .38792 L
.13349 .40998 L
.13981 .41924 L
.14731 .42779 L
.15414 .43369 L
.16176 .43848 L
.16917 .44149 L
.17603 .44294 L
.18472 .44299 L
.19268 .44128 L
.20125 .43784 L
.21007 .43402 L
.23907 .42053 L
Mistroke
.28605 .39429 L
.31805 .37028 L
.33125 .357 L
.34082 .34437 L
.34483 .33746 L
.34777 .33105 L
.35014 .32401 L
.35107 .32008 L
.35167 .31652 L
.35201 .31336 L
.35218 .31003 L
.35215 .30718 L
.35196 .30406 L
.35155 .30069 L
.35089 .29709 L
.35005 .29369 L
.34909 .29059 L
.34675 .28458 L
.34346 .27805 L
.33549 .26617 L
.32346 .25282 L
.30923 .2403 L
.26613 .21175 L
.24047 .19819 L
.20987 .18393 L
.20153 .18032 L
.19684 .17833 L
.19236 .17665 L
.18699 .17536 L
.18208 .17485 L
.17747 .17495 L
.17249 .17568 L
.16378 .17858 L
.15949 .1808 L
.15485 .18382 L
.14697 .19058 L
.14005 .19848 L
.13341 .20819 L
.12707 .22004 L
.12185 .23251 L
.11784 .24472 L
.11402 .26009 L
.11233 .2691 L
.11109 .27755 L
.10958 .29343 L
.10921 .30153 L
.1091 .31043 L
.10972 .32669 L
.11119 .34126 L
.11237 .34917 L
Mistroke
.11394 .35759 L
.11754 .3723 L
.12175 .38524 L
.12702 .39789 L
.13266 .4086 L
.13836 .4173 L
.14423 .42457 L
.15105 .43123 L
.15862 .43672 L
.16609 .44043 L
.17319 .44249 L
.18084 .44321 L
.18806 .44248 L
.19455 .44063 L
.20268 .43723 L
.20998 .43406 L
.22578 .42691 L
.25206 .41394 L
.29405 .38897 L
.31233 .37522 L
.32647 .36219 L
.3331 .35483 L
.33919 .34682 L
.34336 .34016 L
.34704 .33281 L
.34959 .3259 L
.35063 .32211 L
.35136 .31856 L
.35183 .31525 L
.35209 .31221 L
.35218 .30888 L
.35206 .30537 L
.35173 .30198 L
.35146 .30007 L
.35114 .2983 L
.35041 .29506 L
.34943 .29163 L
.34723 .28568 L
.34406 .27914 L
.33428 .26465 L
.32168 .2511 L
.29064 .22676 L
.24526 .2006 L
.21701 .18711 L
.20901 .18356 L
.20011 .17971 L
.19146 .17638 L
.18336 .17492 L
.17868 .17487 L
.17356 .17547 L
Mistroke
.16825 .17684 L
.16336 .17878 L
.15494 .18375 L
.15039 .18738 L
.14637 .19119 L
.13894 .19995 L
.13157 .21133 L
.12542 .22367 L
.12051 .23629 L
.11667 .24889 L
.11338 .26325 L
.11111 .27738 L
.10977 .29066 L
.10912 .30561 L
.10943 .32199 L
.10999 .3302 L
.11089 .33888 L
.11326 .35415 L
.11498 .36232 L
.11681 .36966 L
.12179 .38536 L
.12709 .39804 L
.13353 .41005 L
.13996 .41943 L
.14643 .42691 L
.15398 .43358 L
.15839 .43658 L
.16249 .43884 L
.17021 .44179 L
.17758 .4431 L
.1857 .44287 L
.19438 .44069 L
.20279 .43718 L
.21141 .43343 L
.22619 .42672 L
.27436 .40152 L
.31344 .37428 L
.32961 .35884 L
.33588 .35136 L
.34076 .34446 L
.34462 .33787 L
.34795 .33061 L
.34921 .32709 L
.35033 .32331 L
.35083 .32123 L
.35122 .31932 L
.35153 .31751 L
.35179 .31558 L
.3521 .31211 L
.35219 .30889 L
Mistroke
.35215 .30692 L
.35204 .30506 L
.35168 .30159 L
.35113 .29826 L
.35045 .2952 L
.34828 .28829 L
.34563 .28216 L
.34253 .27644 L
.33329 .26344 L
.32133 .25077 L
.30527 .2372 L
.26157 .20921 L
.23279 .19444 L
.21534 .18636 L
.20636 .1824 L
.19787 .17877 L
.19019 .17604 L
.18199 .17485 L
.17373 .17544 L
.16909 .17657 L
.16481 .17813 L
.16017 .18041 L
.15587 .18309 L
.14811 .18946 L
.14027 .1982 L
.13251 .20969 L
.12703 .22013 L
.12174 .23283 L
.11712 .24726 L
.1137 .26165 L
.11134 .27569 L
.10991 .28886 L
.10914 .30432 L
.1093 .31905 L
.11041 .33466 L
.11147 .3433 L
.11271 .35111 L
.11563 .36507 L
.1196 .37902 L
.12388 .39074 L
.12845 .40084 L
.134 .41081 L
.14064 .42031 L
.14834 .42878 L
.15608 .43508 L
.16395 .43953 L
.17142 .44211 L
.17959 .4432 L
.18426 .44304 L
.18861 .44237 L
Mistroke
.19728 .43952 L
.20636 .43564 L
.26053 .4094 L
.29964 .38503 L
.31783 .37047 L
.33101 .35727 L
.34192 .3426 L
.34626 .33455 L
.34782 .33093 L
.34926 .32696 L
.35022 .32372 L
.35104 .32024 L
.3514 .31832 L
.35166 .31657 L
.35203 .31314 L
.35217 .31002 L
.35213 .30662 L
.3519 .3034 L
.35151 .30043 L
.35087 .29702 L
.35008 .29382 L
.34758 .28651 L
.3442 .2794 L
.33953 .27172 L
.3286 .2581 L
.3154 .24543 L
.27459 .21665 L
.22032 .18861 L
.21171 .18474 L
.20205 .18054 L
.19751 .17861 L
.19264 .17674 L
.18843 .17563 L
.18376 .17495 L
.17509 .17522 L
.17025 .17623 L
.16587 .1777 L
.15754 .18198 L
.14994 .18778 L
.14261 .19533 L
.13527 .20523 L
.129 .21611 L
.12388 .22729 L
.11953 .23923 L
.1161 .25109 L
.11322 .26409 L
.11092 .27892 L
.11009 .28678 L
.10947 .29541 L
.10911 .31122 L
Mistroke
.10971 .32658 L
.1111 .34059 L
.11348 .35529 L
.11523 .3634 L
.11712 .3708 L
.12165 .38496 L
.12752 .39893 L
.13866 .41771 L
.14582 .42628 L
.15293 .43276 L
.16082 .43798 L
.16823 .44119 L
.17695 .44304 L
.18522 .44293 L
.19234 .44139 L
.19974 .43848 L
.21257 .43291 L
.23948 .42033 L
.28596 .39434 L
.30632 .38003 L
.32219 .36644 L
.33391 .35384 L
.33893 .34718 L
.34339 .34011 L
.34671 .33355 L
.34904 .32762 L
.34993 .32476 L
.35073 .32166 L
.35132 .31874 L
.35173 .31606 L
.35207 .31256 L
.35218 .30926 L
.35212 .30629 L
.35186 .30307 L
.35137 .29956 L
.35104 .29779 L
.35061 .29585 L
.3486 .28918 L
.346 .28295 L
.34241 .27624 L
.33386 .26413 L
.31931 .2489 L
.30157 .23442 L
.25796 .20724 L
.23116 .19367 L
.20284 .18088 L
.19471 .17747 L
.18592 .1752 L
.18129 .17483 L
.17619 .17508 L
Mistroke
.17158 .17589 L
.16731 .17716 L
.15932 .18089 L
.15228 .18579 L
.14455 .19312 L
.13771 .20163 L
.12681 .2206 L
.12216 .23168 L
.11778 .24491 L
.11473 .25683 L
.11215 .27025 L
.11042 .28332 L
.10946 .29554 L
.1091 .31007 L
.10952 .32357 L
.11081 .33822 L
.11313 .35347 L
.11467 .36094 L
.11659 .36884 L
.12077 .3825 L
.12562 .39482 L
.13073 .4052 L
.13709 .41552 L
.14368 .42395 L
.14999 .43031 L
.15722 .43585 L
.16537 .44014 L
.17003 .44174 L
.17428 .44269 L
.18263 .44316 L
.19046 .44193 L
.19774 .43933 L
.20525 .43612 L
.21822 .43038 L
.24529 .41743 L
.29202 .39035 L
.3126 .37499 L
.32792 .36067 L
.33916 .34686 L
.34397 .33906 L
.34744 .33185 L
.34969 .32556 L
.35065 .32198 L
.35134 .31863 L
.35185 .3151 L
.35211 .31187 L
.35218 .30832 L
.35213 .30654 L
.35201 .30459 L
.35162 .30114 L
Mistroke
.35105 .29788 L
.35038 .29495 L
.34948 .29179 L
.34679 .28467 L
.3435 .27812 L
.33548 .26617 L
.32418 .25353 L
.29176 .22751 L
.24328 .1996 L
.21469 .18607 L
.20738 .18284 L
.1994 .17941 L
.19241 .17667 L
.18457 .17503 L
.1776 .17494 L
.17012 .17627 L
.16316 .17887 L
.15692 .18239 L
.15034 .18743 L
.14347 .19432 L
.13678 .20297 L
.13105 .21226 L
.12614 .22206 L
.12143 .23368 L
.11785 .24467 L
.1147 .25696 L
.11244 .2685 L
.11061 .28159 L
.10956 .29373 L
.10913 .30523 L
Mfstroke
.19619 .30902 m
.19609 .30579 L
.19584 .30289 L
.19536 .29962 L
.19472 .29664 L
.19398 .29402 L
.19318 .29173 L
.19096 .28715 L
.18962 .28514 L
.18826 .28352 L
.18668 .28206 L
.18489 .28087 L
.18397 .28043 L
.18295 .28007 L
.18108 .27975 L
.17924 .27984 L
.17755 .28029 L
.17579 .28115 L
.17482 .2818 L
.17396 .28251 L
.17243 .28406 L
.17092 .28603 L
.16864 .29019 L
.16756 .29291 L
.16671 .29565 L
.16631 .29723 L
.16593 .29899 L
.1654 .3023 L
.16509 .30561 L
.16499 .30872 L
.16507 .31207 L
.16521 .31396 L
.1654 .31572 L
.16595 .31917 L
.16636 .32105 L
.1668 .32272 L
.16776 .32569 L
.16883 .32827 L
.17025 .33095 L
.17169 .33307 L
.17316 .33477 L
.1746 .33606 L
.17624 .33715 L
.17805 .33791 L
.1799 .33827 L
.18095 .3383 L
.1819 .3382 L
.18374 .3377 L
.18544 .33685 L
.18637 .33622 L
Mistroke
.18733 .33542 L
.18899 .3337 L
.19079 .33117 L
.19224 .32848 L
.19346 .32554 L
.19453 .32215 L
.19524 .31907 L
.19556 .31726 L
.19579 .31554 L
.196 .31351 L
.19613 .31157 L
.19618 .30982 L
.19617 .30791 L
.19609 .30584 L
.19592 .30367 L
.19571 .30183 L
.1954 .29985 L
.19466 .29638 L
.19378 .29339 L
.1926 .29035 L
.19116 .28748 L
.18973 .2853 L
.1883 .28356 L
.18661 .28201 L
.18563 .28131 L
.18472 .28078 L
.18301 .28009 L
.18138 .27977 L
.17958 .2798 L
.17766 .28025 L
.17672 .28065 L
.17571 .2812 L
.17393 .28254 L
.17229 .28422 L
.17088 .28609 L
.16866 .29015 L
.16759 .29281 L
.16675 .2955 L
.16603 .29848 L
.16553 .30134 L
.16517 .30457 L
.165 .30803 L
.16505 .3116 L
.1653 .31482 L
.16552 .31658 L
.16582 .31845 L
.16653 .32174 L
.16739 .32464 L
.16849 .32751 L
.17088 .33194 L
Mistroke
.17242 .33397 L
.17422 .33575 L
.17601 .33701 L
.17771 .3378 L
.17876 .3381 L
.17974 .33826 L
.18082 .3383 L
.18197 .33819 L
.18306 .33793 L
.18408 .33756 L
.18593 .33653 L
.1875 .33527 L
.18909 .33357 L
.19048 .33166 L
.19164 .32968 L
.19286 .32709 L
.19399 .32399 L
.19486 .32083 L
.19547 .31776 L
.19591 .31449 L
.19614 .31135 L
.19617 .30788 L
.1961 .30593 L
.19597 .30415 L
.19556 .30084 L
.19525 .29901 L
.19489 .29734 L
.19401 .29412 L
.19285 .29092 L
.19164 .28836 L
.1904 .28625 L
.1889 .28424 L
.18719 .28248 L
.18561 .2813 L
.18409 .28048 L
.18238 .27993 L
.18051 .27974 L
.17886 .27991 L
.17709 .28048 L
.17545 .28137 L
.17399 .28248 L
.17261 .28385 L
.17143 .28531 L
.16907 .28927 L
.16795 .29185 L
.16705 .29445 L
.16625 .29749 L
.1656 .30092 L
.16536 .30269 L
.16516 .30465 L
Mistroke
.16499 .30824 L
.16505 .31176 L
.16531 .31497 L
.16572 .3179 L
.16625 .32056 L
.16698 .32335 L
.16794 .32617 L
.16912 .32888 L
.1704 .33119 L
.17175 .33315 L
.17313 .33474 L
.17487 .33626 L
.17652 .33729 L
.17836 .338 L
.17941 .33822 L
.18038 .3383 L
.182 .33818 L
.18377 .33768 L
.18557 .33677 L
.18719 .33555 L
.189 .33368 L
.19057 .33151 L
.19186 .32926 L
.19309 .32652 L
.19422 .32325 L
.19473 .32135 L
.19515 .3195 L
.19572 .31614 L
.19593 .3143 L
.19609 .3123 L
.19619 .30885 L
.19609 .30572 L
.19575 .30216 L
.19522 .29889 L
.19456 .29599 L
.1938 .29344 L
.19281 .29083 L
.19161 .2883 L
.19025 .28603 L
.18865 .28395 L
.18701 .28234 L
.18544 .28119 L
.18446 .28065 L
.18354 .28026 L
.18251 .27996 L
.18141 .27978 L
.18035 .27974 L
.17935 .27983 L
.17751 .28031 L
.17578 .28116 L
Mistroke
.17482 .28181 L
.17395 .28252 L
.17226 .28425 L
.1706 .28652 L
.16921 .28898 L
.16805 .29159 L
.16715 .29413 L
.16634 .29707 L
.16567 .30045 L
.16539 .30244 L
.16519 .30433 L
.16505 .30634 L
.16499 .30819 L
.165 .31023 L
.16509 .31236 L
.16542 .31589 L
.16594 .31908 L
.16632 .32085 L
.16672 .32242 L
.16779 .32576 L
.16887 .32835 L
.17002 .33055 L
.17153 .33286 L
.17303 .33464 L
.17471 .33615 L
.17639 .33722 L
.17821 .33796 L
.17926 .33819 L
.18023 .33829 L
.18183 .33821 L
.18332 .33785 L
.18493 .33714 L
.18661 .33603 L
.1882 .33458 L
.18976 .3327 L
.19223 .32851 L
.19341 .3257 L
.19431 .32293 L
.19474 .32132 L
.19515 .31952 L
.19572 .31613 L
.19605 .31287 L
.19618 .30936 L
.19612 .30635 L
.19586 .30307 L
.19561 .30114 L
.19531 .29933 L
.19457 .29606 L
.19355 .29275 L
.19219 .28945 L
Mistroke
.19081 .28691 L
.18917 .28457 L
.18748 .28275 L
.18586 .28146 L
.18417 .28052 L
.18256 .27997 L
.18076 .27974 L
.17883 .27992 L
.17787 .28018 L
.17683 .2806 L
.175 .28168 L
.1733 .28313 L
.17182 .2848 L
.16943 .28854 L
.16827 .29105 L
.16732 .29362 L
.16649 .2965 L
.16588 .29928 L
.16539 .30245 L
.16508 .30587 L
.16499 .30946 L
.16511 .31271 L
.16526 .31449 L
.16549 .3164 L
.16608 .31978 L
.16682 .3228 L
.1678 .3258 L
.16879 .32818 L
.17002 .33055 L
.17163 .33299 L
.17325 .33485 L
.17418 .33572 L
.17524 .33653 L
.17628 .33716 L
.17723 .33762 L
.17914 .33818 L
.1802 .33829 L
.1812 .33828 L
.18297 .33796 L
.18485 .33718 L
.18658 .33605 L
.18808 .3347 L
.1897 .33278 L
.19111 .33063 L
.19325 .32611 L
.19423 .32322 L
.19496 .32038 L
.19557 .31715 L
.19596 .31403 L
.19616 .31053 L
Mistroke
.19618 .30855 L
.19614 .30674 L
.19587 .30316 L
.19561 .30116 L
.19531 .29934 L
.19459 .29613 L
.19361 .2929 L
.19235 .28979 L
.191 .28722 L
.18935 .28479 L
.18742 .2827 L
.18563 .28131 L
.18389 .2804 L
.18287 .28005 L
.18193 .27985 L
.18084 .27974 L
.1798 .27977 L
.17804 .28013 L
.17621 .28091 L
.17469 .28191 L
.17309 .28334 L
.17149 .28524 L
.16991 .28768 L
.16858 .29032 L
.16753 .293 L
.1666 .29604 L
.16591 .29909 L
.16545 .30193 L
.16513 .30509 L
.16499 .30859 L
.165 .31037 L
.16509 .31231 L
.1654 .31571 L
.16588 .3188 L
.16655 .32179 L
.16734 .32448 L
.16921 .32905 L
.17045 .33127 L
.17171 .33309 L
.1732 .33481 L
.17489 .33627 L
.17582 .3369 L
.17684 .33744 L
.17869 .33808 L
.17974 .33826 L
.18072 .3383 L
.18179 .33821 L
.18293 .33797 L
.18391 .33763 L
.18496 .33713 L
Mistroke
.1868 .33588 L
.1885 .33425 L
.18997 .33241 L
.19239 .32816 L
.19354 .32533 L
.19444 .32247 L
.1952 .31927 L
.19571 .31621 L
.19606 .31276 L
.19615 .311 L
.19618 .30906 L
.19607 .30543 L
.19575 .30214 L
.1955 .30045 L
.19517 .29863 L
.19431 .29509 L
.19335 .29218 L
.19212 .28931 L
.1908 .28689 L
.18947 .28495 L
.18798 .28324 L
.18652 .28194 L
.18485 .28085 L
.18301 .28009 L
.18121 .27976 L
.17952 .27981 L
.17801 .28014 L
.17641 .28081 L
.17459 .28199 L
.17298 .28346 L
.17132 .28546 L
.16972 .28801 L
.16825 .29111 L
.16708 .29436 L
.16624 .29751 L
.16586 .29936 L
.16557 .30111 L
.16519 .30432 L
.16501 .30739 L
.16502 .31077 L
.16511 .31266 L
.16525 .31437 L
.1657 .31775 L
.16604 .31961 L
.16642 .32129 L
.16726 .32424 L
.16835 .32717 L
.16956 .32972 L
.17105 .3322 L
.17278 .33437 L
Mistroke
.17452 .336 L
.17624 .33714 L
.17786 .33785 L
.17976 .33826 L
.18158 .33824 L
.18251 .33808 L
.18353 .33777 L
.18458 .33732 L
.18555 .33678 L
.18722 .33552 L
.18893 .33376 L
.19066 .33137 L
.19228 .32839 L
.19347 .32551 L
.19455 .32208 L
.19495 .32045 L
.19532 .31863 L
.19583 .31523 L
.19611 .31183 L
.19618 .30867 L
.19605 .30524 L
.19589 .30332 L
.19567 .30154 L
.19537 .2997 L
.19505 .29805 L
.19413 .2945 L
.19314 .29165 L
.19207 .28921 L
.19075 .2868 L
.18918 .28458 L
.18756 .28282 L
.18594 .28151 L
.18442 .28064 L
.18275 .28002 L
.18093 .27974 L
.17927 .27984 L
.17737 .28037 L
.17562 .28126 L
.17406 .28242 L
.17269 .28377 L
.17127 .28554 L
.16989 .28771 L
.16864 .29018 L
.16749 .29312 L
.16658 .29612 L
.16592 .29903 L
.16539 .30239 L
.16519 .30434 L
.16506 .30617 L
.165 .30812 L
Mistroke
.16499 .3099 L
.16507 .31195 L
.1652 .31386 L
.1656 .31713 L
.16591 .31894 L
.16626 .3206 L
.16712 .3238 L
.16827 .32699 L
.16953 .32968 L
.17088 .33194 L
.17219 .3337 L
.17374 .33533 L
.17553 .33672 L
.17654 .3373 L
.17751 .33772 L
.17927 .33819 L
.18119 .33828 L
.1822 .33814 L
.1833 .33785 L
.18443 .3374 L
.18547 .33683 L
.18726 .33548 L
.18907 .33359 L
.19052 .3316 L
.19196 .32905 L
.19327 .32605 L
.1943 .32297 L
.19507 .3199 L
.1956 .31696 L
.196 .31346 L
.19617 .31007 L
.19618 .30815 L
.19612 .30641 L
.19599 .30441 L
.1958 .30255 L
.1953 .29931 L
.19494 .29754 L
.19455 .29596 L
.19356 .29277 L
.19224 .28956 L
.19063 .28662 L
.18893 .28429 L
.18733 .28262 L
.18645 .28188 L
.18548 .28122 L
.18366 .28031 L
.18194 .27985 L
.18028 .27974 L
.17872 .27995 L
.17703 .28051 L
Mistroke
.17526 .2815 L
.17356 .28288 L
.17182 .28481 L
.17015 .28726 L
.16878 .28989 L
.16765 .29265 L
.16679 .29536 L
.16638 .29692 L
.16599 .29867 L
.16545 .30195 L
.16512 .30528 L
.16499 .30837 L
.16507 .31194 L
.16535 .31529 L
.16579 .3183 L
.16635 .321 L
.16713 .32383 L
.16813 .32664 L
.16942 .32946 L
.17102 .33214 L
.17269 .33427 L
.17435 .33585 L
.17592 .33696 L
.17771 .3378 L
.17962 .33824 L
.18141 .33826 L
.18332 .33784 L
.18438 .33742 L
.18534 .3369 L
.18706 .33566 L
.18878 .33393 L
.19021 .33206 L
.19144 .33005 L
.19264 .3276 L
.19378 .32464 L
.19476 .32126 L
.19513 .31962 L
.19546 .31784 L
.19592 .31437 L
.19614 .31109 L
.19618 .30908 L
.19614 .3069 L
.19603 .30486 L
.19585 .303 L
.19534 .29954 L
.19501 .29785 L
.19457 .29605 L
.19362 .29294 L
.19257 .29028 L
.19124 .28764 L
Mistroke
.18965 .28519 L
.18815 .28341 L
.18664 .28204 L
.18491 .28089 L
.18391 .28041 L
.18298 .28009 L
.18135 .27977 L
.17982 .27977 L
.17816 .2801 L
.17641 .28081 L
.17463 .28196 L
.17303 .28341 L
.17167 .28499 L
.17031 .28699 L
.16904 .28932 L
.16785 .29212 L
.16676 .29547 L
.16596 .29883 L
.16563 .3007 L
.16535 .30278 L
.16515 .30478 L
.16504 .30665 L
.165 .3102 L
.16508 .31219 L
.16521 .31397 L
.16565 .31743 L
.16624 .32051 L
.1671 .32372 L
.16822 .32686 L
.16937 .32936 L
.17057 .33146 L
.17201 .33347 L
.17368 .33527 L
.17533 .33658 L
.1763 .33717 L
.17722 .33761 L
.17912 .33817 L
.1802 .33829 L
.18119 .33828 L
.18285 .33799 L
.18464 .33729 L
.18644 .33615 L
.18804 .33473 L
.18983 .3326 L
.19136 .3302 L
.19258 .32774 L
.19372 .3248 L
.19474 .32131 L
.19516 .31946 L
.19553 .31738 L
Mistroke
.19579 .31556 L
.19599 .31358 L
.19612 .31169 L
.19618 .30996 L
.19613 .30654 L
.19602 .30482 L
.19584 .30294 L
.19537 .29969 L
.19475 .29675 L
.19381 .29349 L
.19276 .29071 L
.19142 .28795 L
.18981 .28541 L
.18837 .28365 L
.18674 .28211 L
.18511 .281 L
.18359 .28029 L
.18175 .27982 L
.18071 .27974 L
.17975 .27978 L
.17799 .28015 L
.17616 .28094 L
.1745 .28206 L
.17278 .28367 L
.17126 .28555 L
.16996 .28758 L
.16787 .29207 L
.16692 .29491 L
.16622 .29764 L
.16558 .30102 L
.1652 .30424 L
.165 .30784 L
.16499 .30966 L
.16505 .31166 L
.16532 .31499 L
.16582 .31847 L
.16651 .32163 L
.1673 .32436 L
.16825 .32692 L
.1694 .32942 L
.17182 .33324 L
.17333 .33494 L
.17483 .33623 L
.17655 .3373 L
.17754 .33773 L
.17846 .33802 L
.18003 .33828 L
.18149 .33825 L
.18308 .33792 L
.18476 .33723 L
Mistroke
.18646 .33614 L
.188 .33478 L
.18931 .33329 L
.19063 .33142 L
.19192 .32914 L
.193 .32673 L
.19408 .32371 L
.19488 .32074 L
.19546 .31782 L
.19585 .31502 L
.19611 .31188 L
.19618 .3085 L
.19613 .30656 L
.19602 .30479 L
.19584 .30287 L
.19557 .30087 L
.19495 .2976 L
.19404 .2942 L
.19303 .29137 L
.19177 .28861 L
.19052 .28645 L
.18907 .28445 L
.18727 .28256 L
.1855 .28123 L
.18448 .28067 L
.18351 .28026 L
.18244 .27995 L
.18127 .27977 L
.18031 .27974 L
.17927 .27984 L
.17819 .28009 L
.1772 .28044 L
.17546 .28137 L
.17367 .28277 L
.17202 .28455 L
.17038 .28688 L
.16899 .28943 L
.16787 .29206 L
.16701 .29462 L
.16622 .29762 L
.1656 .3009 L
.16521 .30407 L
.16501 .30751 L
.16499 .30925 L
.16503 .31118 L
.16527 .31455 L
.16568 .31766 L
.166 .31938 L
.16639 .32116 L
.16725 .3242 L
Mistroke
.16838 .32724 L
.16984 .33023 L
.17129 .33253 L
.17273 .33431 L
.17451 .33598 L
.17629 .33716 L
.17798 .33789 L
.17958 .33824 L
.18135 .33826 L
.1832 .33788 L
.18484 .33718 L
.1863 .33626 L
.18791 .33487 L
.18935 .33323 L
.19165 .32965 L
.19278 .32728 L
.19369 .32489 L
.19461 .32184 L
.19528 .31881 L
.19574 .31598 L
.19605 .31284 L
.19618 .30936 L
.19616 .3076 L
.19608 .30568 L
.19577 .30231 L
.19529 .29925 L
.19457 .29606 L
.19359 .29286 L
.19259 .29033 L
.19133 .2878 L
.18981 .28541 L
.18801 .28327 L
.18713 .28244 L
.18618 .28169 L
.18442 .28064 L
.18271 .28001 L
.18086 .27974 L
.17912 .27987 L
.17754 .2803 L
.17573 .28119 L
.17474 .28187 L
.17385 .28261 L
.17229 .28423 L
.17075 .28629 L
.16847 .29057 L
.16742 .29333 L
.16661 .29603 L
.16599 .29868 L
.16549 .30167 L
.16517 .30458 L
Mistroke
.16502 .30731 L
.16502 .31082 L
.16522 .31408 L
.16558 .31697 L
.16613 .31999 L
.16692 .32314 L
.16798 .32625 L
.16904 .32869 L
.17035 .3311 L
.17187 .3333 L
.1734 .335 L
.17518 .33648 L
.17611 .33706 L
.17716 .33758 L
.17894 .33813 L
.17996 .33827 L
.18089 .33829 L
.18269 .33803 L
.18438 .33742 L
.18595 .33651 L
.18755 .33522 L
.18898 .33369 L
.1902 .33207 L
.19153 .32989 L
.1928 .32723 L
.19384 .32446 L
.19463 .32174 L
.19531 .31867 L
.19583 .31523 L
.19611 .31191 L
.19618 .30884 L
.19605 .30525 L
.19588 .30324 L
.19565 .30141 L
.19506 .29813 L
.19469 .29653 L
.19423 .29482 L
.19312 .2916 L
.19192 .28891 L
.19042 .28629 L
.18865 .28396 L
.18698 .28231 L
.18534 .28113 L
.18348 .28025 L
.18241 .27994 L
.18143 .27978 L
.17969 .27979 L
.17806 .28013 L
.17632 .28086 L
.1745 .28206 L
Mistroke
.17363 .28282 L
.1727 .28376 L
.17111 .28576 L
.16971 .28804 L
.16854 .29043 L
.1675 .2931 L
.16667 .2958 L
.16606 .29835 L
.16555 .30122 L
.16518 .30445 L
.165 .30792 L
.16502 .3109 L
.16523 .31415 L
.16543 .31595 L
.16572 .31787 L
.16642 .32126 L
.16731 .32438 L
.1683 .32706 L
.16955 .3297 L
.17111 .33227 L
.17291 .33451 L
.17377 .33535 L
.17474 .33616 L
.17644 .33724 L
.1783 .33798 L
.18004 .33828 L
.18167 .33823 L
.18358 .33775 L
.18528 .33694 L
.1862 .33633 L
.18717 .33556 L
.18885 .33385 L
.19066 .33137 L
.19237 .3282 L
.19373 .32479 L
.19472 .32138 L
.19521 .31919 L
.19558 .31711 L
.19588 .31477 L
.19609 .31225 L
.19617 .31004 L
.19617 .30796 L
.19608 .30569 L
.19588 .30326 L
.19558 .30097 L
.19522 .29889 L
.19473 .29667 L
.1941 .29439 L
.19249 .2901 L
.1907 .28672 L
Mistroke
.18879 .28412 L
.18763 .2829 L
.18652 .28194 L
.18543 .28119 L
.18438 .28062 L
.18327 .28018 L
.18203 .27987 L
Mfstroke
.19619 .43998 m
.24946 .4153 L
.29508 .38826 L
.31305 .37462 L
.32852 .36003 L
.33464 .35295 L
.33958 .34625 L
.34358 .33979 L
.34664 .33373 L
.34923 .32705 L
.35028 .32351 L
.35115 .3197 L
.35149 .3178 L
.35178 .31572 L
.35198 .31376 L
.35211 .31194 L
.35219 .3085 L
.35213 .30658 L
.35203 .30483 L
.35166 .3014 L
.35113 .29824 L
.35034 .29477 L
.34927 .2911 L
.34691 .28493 L
.34353 .27816 L
.33301 .26311 L
.31717 .24697 L
.27658 .21784 L
.22305 .18987 L
.2059 .1822 L
.2012 .18018 L
.19605 .178 L
.19112 .17629 L
.18654 .17529 L
.17828 .17489 L
.16962 .17641 L
.16507 .17802 L
.16089 .18002 L
.15639 .18274 L
.1517 .18627 L
.14364 .19414 L
.13673 .20304 L
.12985 .21448 L
.12348 .22829 L
.11881 .2415 L
.11521 .25472 L
.11219 .26998 L
.11093 .27882 L
.11007 .28701 L
.10919 .30229 L
Mistroke
.10921 .31654 L
.11016 .33207 L
.11222 .34826 L
.11517 .36316 L
.11879 .37648 L
.12269 .38773 L
.12755 .399 L
.1334 .40982 L
.1395 .41884 L
.14714 .42762 L
.15455 .434 L
.16185 .43853 L
.16879 .44138 L
.17654 .443 L
.18481 .44298 L
.19304 .44116 L
.1976 .43939 L
.20172 .43764 L
.21679 .43102 L
.24817 .41596 L
.29588 .3877 L
.31437 .3735 L
.33037 .35799 L
.33616 .35099 L
.34143 .34341 L
.3452 .33672 L
.34831 .32966 L
.35034 .32328 L
.35116 .31966 L
.35171 .31627 L
.35203 .31317 L
.35217 .31033 L
.35215 .30705 L
.35195 .30395 L
.35155 .30065 L
.35123 .29877 L
.35087 .297 L
.3499 .29315 L
.34876 .28962 L
.34614 .28323 L
.34248 .27635 L
.33183 .26171 L
.3164 .24629 L
.28025 .22009 L
.25506 .20568 L
.22778 .19207 L
.21434 .18591 L
.19934 .17938 L
.1912 .17631 L
.18651 .17528 L
Mistroke
.18209 .17485 L
.17432 .17534 L
.16607 .17762 L
.1588 .18121 L
.15114 .18673 L
.14427 .19343 L
.13827 .20086 L
.12815 .2178 L
.1233 .22874 L
.11946 .23944 L
.11567 .25283 L
.11287 .26598 L
.11068 .28095 L
.10937 .2974 L
.10912 .30575 L
.10916 .31484 L
.11009 .33126 L
.11201 .34693 L
.11467 .36094 L
.11786 .3734 L
.12147 .38447 L
.12647 .39671 L
.13169 .40691 L
.13729 .4158 L
.14393 .42423 L
.15107 .43124 L
.15899 .43694 L
.16335 .43926 L
.16815 .44117 L
.17275 .44241 L
.17701 .44305 L
.1851 .44295 L
.19361 .44097 L
.19795 .43924 L
.20254 .43729 L
.21065 .43376 L
.22828 .42573 L
.27995 .39814 L
.31809 .37025 L
.33339 .35448 L
.3391 .34694 L
.34353 .33986 L
.34691 .3331 L
.34835 .32954 L
.34963 .3258 L
.3505 .32263 L
.35125 .31916 L
.35174 .31601 L
.35204 .31307 L
.35214 .31129 L
Mistroke
.35218 .30936 L
.3521 .30586 L
.35179 .30245 L
.35133 .2993 L
.35062 .2959 L
.3496 .29215 L
.34675 .28456 L
.34329 .27774 L
.33854 .27028 L
.32729 .2567 L
.31312 .24348 L
.29712 .23121 L
.25077 .20342 L
.21897 .188 L
.20365 .18123 L
.1952 .17765 L
.19036 .17608 L
.18591 .17519 L
.18165 .17484 L
.17701 .17499 L
.16862 .17671 L
.16043 .18027 L
.15309 .18514 L
.14574 .19184 L
.13816 .201 L
.13097 .2124 L
.125 .22464 L
.11973 .23861 L
.11525 .25457 L
.11235 .26898 L
.11111 .27739 L
.11022 .28534 L
.1095 .29472 L
.10915 .30364 L
.10911 .31167 L
.10935 .32036 L
.10996 .32979 L
.11098 .33965 L
.11217 .34794 L
.1138 .35687 L
.11754 .37229 L
.12203 .38601 L
.12678 .39738 L
.13267 .40861 L
.1398 .41923 L
.14811 .42857 L
.15237 .43232 L
.1565 .43537 L
.16444 .43975 L
.1723 .44231 L
Mistroke
.1807 .44322 L
.18787 .44252 L
.19565 .4402 L
.20385 .43673 L
.21238 .433 L
.22712 .42628 L
.27977 .39824 L
.30178 .38346 L
.32078 .36778 L
.3337 .3541 L
.33918 .34683 L
.34401 .33901 L
.34745 .33185 L
.34866 .32871 L
.34978 .32529 L
.35059 .32225 L
.35128 .31901 L
.35179 .31559 L
.35208 .31242 L
.35219 .30901 L
.35215 .30708 L
.35206 .30528 L
.3519 .30337 L
.35169 .30163 L
.35138 .29963 L
.35103 .29772 L
.34931 .29125 L
.34801 .28758 L
.34658 .28419 L
.33789 .26938 L
.33199 .26189 L
.32428 .25362 L
.28804 .22504 L
.24044 .19818 L
.21297 .1853 L
.20492 .18177 L
.20039 .17983 L
.19606 .178 L
.18747 .17545 L
.17958 .17483 L
.1712 .17598 L
.16702 .17726 L
.16247 .1792 L
.15462 .18398 L
.14759 .18997 L
.13981 .19879 L
.13327 .20842 L
.12653 .22121 L
.12101 .23484 L
.11706 .24749 L
Mistroke
.11412 .25959 L
.11155 .27416 L
.10995 .28831 L
.10921 .30165 L
.10915 .314 L
.10978 .3275 L
.11123 .34155 L
.1135 .35538 L
.1168 .3696 L
.12069 .38228 L
.12486 .39308 L
.13045 .40469 L
.13731 .41583 L
.14442 .42478 L
.15146 .43158 L
.15885 .43686 L
.16691 .44074 L
.17394 .44264 L
.18171 .4432 L
.19008 .44203 L
.19472 .44057 L
.19888 .43885 L
.21412 .43222 L
.26422 .40736 L
.28746 .39337 L
.30864 .37821 L
.32469 .364 L
.33639 .3507 L
.34447 .33814 L
.34775 .3311 L
.34996 .32466 L
.35088 .32101 L
.35151 .31763 L
.35178 .31568 L
.35197 .31392 L
.35211 .31188 L
.35218 .30997 L
.35213 .30647 L
.35189 .30326 L
.3514 .29974 L
.35108 .29796 L
.35065 .29602 L
.34959 .29213 L
.34834 .28845 L
.34532 .28155 L
.34111 .27413 L
.3354 .26606 L
.32215 .25155 L
.30649 .23814 L
.26584 .21158 L
Mistroke
.21608 .18669 L
.2082 .1832 L
.19933 .17938 L
.19072 .17618 L
.18259 .17487 L
.17451 .17531 L
.16725 .17718 L
.15904 .18106 L
.15159 .18636 L
.14385 .1939 L
.13627 .20372 L
.13037 .2135 L
.1246 .22557 L
.1193 .23992 L
.11682 .24834 L
.11478 .2566 L
.11315 .2645 L
.11168 .27329 L
.10989 .28906 L
.10914 .30429 L
.10927 .31833 L
.11031 .33361 L
.1124 .34936 L
.11505 .36262 L
.11817 .37444 L
.12228 .38667 L
.12743 .39875 L
.13385 .41056 L
.14164 .42155 L
.14967 .43001 L
.15753 .43604 L
.1649 .43995 L
.17322 .4425 L
.18202 .44319 L
.19023 .44199 L
.19877 .43889 L
.20782 .435 L
.2236 .42792 L
.25075 .41462 L
.2782 .39921 L
.30009 .3847 L
.31719 .37105 L
.33186 .35629 L
.33709 .34976 L
.34176 .34287 L
.34536 .33642 L
.34797 .33054 L
.35023 .32367 L
.35111 .31989 L
.3517 .3163 L
Mistroke
.35204 .313 L
.35218 .30994 L
.35213 .30659 L
.35186 .30302 L
.35136 .29946 L
.35097 .29746 L
.35055 .29562 L
.34842 .28867 L
.34693 .28499 L
.34502 .28096 L
.34028 .27284 L
.32877 .25828 L
.31438 .24454 L
.27824 .21885 L
.2259 .19118 L
.20913 .18361 L
.19952 .17946 L
.19471 .17746 L
.19026 .17605 L
.18222 .17486 L
.17358 .17547 L
.16911 .17656 L
.16429 .17835 L
.15981 .18062 L
.15573 .18319 L
.14778 .18978 L
.13993 .19863 L
.13375 .20763 L
.12763 .21887 L
.12188 .23245 L
.11681 .24839 L
.11479 .25656 L
.11315 .2645 L
.11081 .27982 L
.1095 .29483 L
.1091 .31093 L
.10958 .32466 L
.11098 .33959 L
.11346 .35518 L
.11529 .36365 L
.11723 .37118 L
.12141 .38432 L
.12672 .39725 L
.13255 .40841 L
.13841 .41737 L
.14485 .42524 L
.15113 .4313 L
.15885 .43686 L
.16304 .43911 L
.16753 .44096 L
Mistroke
.1752 .44283 L
.18369 .44309 L
.1916 .44161 L
.1987 .43892 L
.21408 .43224 L
.23978 .42019 L
.28534 .39474 L
.32086 .36771 L
.3341 .35362 L
.33966 .34613 L
.34452 .33806 L
.34792 .33067 L
.3491 .32744 L
.35017 .3239 L
.35098 .32055 L
.35154 .31743 L
.35195 .31414 L
.35216 .31062 L
.35216 .30723 L
.35206 .3053 L
.35191 .3035 L
.35142 .29987 L
.35105 .29783 L
.35064 .29597 L
.34855 .28903 L
.34577 .28245 L
.34158 .27487 L
.33677 .26785 L
.32253 .25192 L
.3061 .23784 L
.2881 .22508 L
.26511 .21117 L
.23704 .1965 L
.20848 .18332 L
.2001 .17971 L
.19539 .17773 L
.19087 .17622 L
.18663 .1753 L
.182 .17485 L
.17389 .17541 L
.16654 .17744 L
.15861 .18132 L
.15064 .18716 L
.14356 .19422 L
.13212 .21037 L
.12652 .22123 L
.12198 .23216 L
.1177 .2452 L
.11403 .26004 L
.11147 .27471 L
Mistroke
.10994 .28842 L
.10913 .30485 L
.10915 .31415 L
.10947 .3227 L
.11081 .33825 L
.11328 .35425 L
.11662 .36895 L
.12122 .38377 L
.12644 .39664 L
.1319 .40729 L
.13904 .41823 L
.14759 .42807 L
.15174 .4318 L
.15627 .43522 L
.16469 .43986 L
.16935 .44155 L
.1745 .44273 L
.17991 .44321 L
.18495 .44296 L
.18967 .44213 L
.19392 .44086 L
.20329 .43697 L
.24081 .41968 L
.2949 .38838 L
Mfstroke
.50819 .17805 m
.44383 .15337 L
.36062 .12633 L
.3136 .11269 L
.25956 .0981 L
.23194 .09102 L
.21803 .08754 L
.20499 .08433 L
.193 .08149 L
.18016 .0803 L
.16727 .08167 L
.15326 .08613 L
.14556 .08995 L
.13856 .09434 L
.12327 .10718 L
.11069 .12168 L
.09841 .14015 L
.08768 .16105 L
.07893 .18293 L
.07232 .20411 L
.06657 .22838 L
.06398 .2427 L
.06202 .25633 L
.0604 .27151 L
.05926 .28797 L
.05876 .30535 L
.05894 .32183 L
.05963 .33657 L
.06097 .35247 L
.06259 .36602 L
.06489 .38074 L
.07113 .40947 L
.0787 .43445 L
.08728 .4561 L
.0966 .47472 L
.108 .49272 L
.12105 .50857 L
.13406 .52041 L
.1469 .52882 L
.15892 .53409 L
.17307 .5373 L
.18653 .53746 L
.20111 .53466 L
.2163 .53092 L
.24291 .52423 L
.30005 .50911 L
.39461 .48117 L
.47126 .45466 L
.53359 .42884 L
.58056 .40491 L
Mistroke
.61924 .37932 L
.63485 .36581 L
.64783 .35142 L
.65308 .34395 L
.65762 .33588 L
.65931 .33218 L
.66082 .32827 L
.66189 .32489 L
.66282 .32127 L
.66349 .31774 L
.66391 .31453 L
.66414 .3113 L
.66418 .30824 L
.66401 .30468 L
.66366 .3014 L
.66304 .29779 L
.66212 .29396 L
.65993 .28739 L
.65677 .28047 L
.64897 .26812 L
.63748 .25483 L
.62124 .2403 L
.58246 .21423 L
.53534 .19 L
.38438 .13362 L
.29942 .10876 L
.24823 .09517 L
.222 .08853 L
.21029 .08563 L
.19736 .08247 L
.1839 .08039 L
.1711 .081 L
.15658 .08478 L
.14345 .09119 L
.13057 .10046 L
.11709 .11382 L
.10407 .13102 L
.09303 .14996 L
.08458 .16819 L
.07684 .18909 L
.07124 .20813 L
.06625 .23001 L
.06225 .25458 L
.05962 .2816 L
.05875 .30748 L
.05931 .33104 L
.06163 .35851 L
.06347 .37212 L
.06601 .38682 L
.07177 .4119 L
Mistroke
.07857 .43406 L
.08819 .45811 L
.0984 .47786 L
.11165 .4976 L
.12547 .51299 L
.13819 .52344 L
.15235 .53151 L
.16609 .53611 L
.17872 .53771 L
.19363 .53642 L
.20196 .53445 L
.20956 .53259 L
.23772 .52555 L
.43039 .46935 L
.50357 .44191 L
.55833 .4169 L
.60307 .39099 L
.63418 .36646 L
.64659 .35301 L
.65514 .34057 L
.65848 .33407 L
.66128 .32691 L
.66233 .32331 L
.66279 .32142 L
.6632 .31943 L
.66351 .31768 L
.66377 .31577 L
.66408 .31241 L
.66419 .30878 L
.66407 .30543 L
.66393 .30368 L
.66371 .30175 L
.66341 .29974 L
.66306 .29786 L
.66131 .29124 L
.65999 .28752 L
.65855 .28413 L
.65101 .27095 L
.64092 .25844 L
.62588 .24412 L
.60862 .23086 L
.55768 .20081 L
.49253 .17164 L
.41714 .14421 L
.33844 .11977 L
.23972 .09299 L
.21283 .08625 L
.2056 .08448 L
.19768 .08255 L
.18316 .08035 L
Mistroke
.16846 .08144 L
.15503 .08539 L
.14296 .09148 L
.13059 .10044 L
.11819 .11257 L
.10577 .1285 L
.09509 .14607 L
.08633 .1641 L
.07746 .18722 L
.07341 .20023 L
.06961 .21462 L
.06647 .22887 L
.06408 .24211 L
.06066 .26864 L
.05903 .2933 L
.05887 .31956 L
.06001 .34189 L
.06259 .36603 L
.0669 .39126 L
.06998 .40496 L
.07321 .41709 L
.08063 .4398 L
.08871 .45923 L
.10713 .49149 L
.11817 .50544 L
.13071 .5177 L
.14211 .52604 L
.15318 .53187 L
.16559 .536 L
.17915 .53772 L
.19348 .53645 L
.20637 .53337 L
.23464 .52633 L
.28331 .51365 L
.38293 .48487 L
.47119 .45469 L
.53791 .42685 L
.58684 .40124 L
.62565 .37411 L
.64051 .36005 L
.65115 .34688 L
.65583 .33934 L
.6592 .33244 L
.66069 .32863 L
.66201 .32448 L
.66298 .32056 L
.66362 .31692 L
.66402 .31337 L
.66413 .31159 L
.66418 .30963 L
Mistroke
.66411 .30616 L
.66385 .30293 L
.6636 .30096 L
.66329 .2991 L
.66256 .29562 L
.66152 .29188 L
.66009 .2878 L
.65699 .28089 L
.65275 .27356 L
.64269 .2604 L
.63014 .24783 L
.61576 .23605 L
.57356 .2092 L
.51768 .1821 L
.4445 .15361 L
.36257 .12692 L
.27697 .10269 L
.22812 .09006 L
.21423 .0866 L
.19931 .08294 L
.18638 .08056 L
.17211 .08086 L
.15726 .08453 L
.14907 .08809 L
.14172 .09225 L
.12792 .10277 L
.11556 .1156 L
.1041 .13098 L
.0944 .14735 L
.0849 .16743 L
.07624 .19093 L
.07017 .21232 L
.06569 .23291 L
.06202 .25633 L
.05962 .28167 L
.05877 .30405 L
.05904 .32495 L
.0605 .34772 L
.0634 .37164 L
.0681 .39689 L
.07493 .42291 L
.08294 .44581 L
.09158 .46522 L
.11084 .49655 L
.12176 .50931 L
.13455 .52078 L
.14851 .52967 L
.1619 .53503 L
.17685 .53763 L
.18525 .53757 L
Mistroke
.19284 .53658 L
.20666 .5333 L
.22138 .52966 L
.24743 .52307 L
.34084 .49756 L
.42793 .47019 L
.50781 .44014 L
.56459 .41366 L
.61128 .38529 L
.63079 .36961 L
.64469 .35532 L
.65005 .34844 L
.65491 .34095 L
.65832 .33441 L
.65981 .33097 L
.66113 .32735 L
.66214 .32402 L
.66301 .32039 L
.6636 .31708 L
.66396 .31401 L
.66416 .31084 L
.66418 .30795 L
.66401 .30463 L
.66367 .30149 L
.66309 .29803 L
.66223 .29436 L
.66009 .28779 L
.65691 .28072 L
.65235 .27295 L
.64102 .25855 L
.62466 .24309 L
.58407 .21517 L
.52942 .18729 L
.45376 .15692 L
.36581 .1279 L
.27297 .10163 L
.22065 .08819 L
.20575 .08451 L
.1975 .0825 L
.18976 .08095 L
.17598 .08046 L
.16095 .08329 L
.14709 .08911 L
.1344 .09737 L
.12348 .10698 L
.11225 .11966 L
.10094 .13594 L
.09013 .15578 L
.082 .17461 L
.07433 .19709 L
Mistroke
.07081 .2098 L
.06745 .22413 L
.06493 .23709 L
.0627 .2512 L
.05984 .27843 L
.05877 .30413 L
.05888 .31976 L
.05964 .33662 L
.06096 .3524 L
.06269 .36675 L
.06731 .39324 L
.07028 .40614 L
.07402 .41988 L
.082 .44343 L
.09093 .4639 L
.10271 .48491 L
.11466 .50137 L
.12681 .51425 L
.13868 .52378 L
.15224 .53146 L
.16708 .53633 L
.18004 .53773 L
.19422 .5363 L
.20885 .53277 L
.22226 .52945 L
.27026 .51713 L
.36835 .48937 L
.51026 .43911 L
.57107 .41021 L
.61455 .3829 L
.62926 .371 L
.64203 .35839 L
.64755 .35181 L
.65271 .34456 L
.65635 .33841 L
.65948 .3318 L
.66196 .32473 L
Mfstroke
.50819 .30902 m
.50809 .30579 L
.50784 .30284 L
.50736 .29945 L
.5067 .29624 L
.50508 .29053 L
.50265 .28433 L
.49916 .27751 L
.49453 .27027 L
.48385 .25729 L
.46961 .24389 L
.45331 .23134 L
.4055 .20276 L
.34142 .17361 L
.26924 .14693 L
.22387 .13221 L
.21075 .12818 L
.20342 .12597 L
.19644 .12388 L
.18985 .12231 L
.18267 .12155 L
.17613 .12169 L
.17014 .12253 L
.15834 .12622 L
.14761 .13202 L
.13631 .14093 L
.12495 .15329 L
.11407 .16912 L
.10493 .18658 L
.09782 .20404 L
.09138 .22466 L
.08683 .24431 L
.08374 .26308 L
.08157 .28425 L
.0807 .30689 L
.08114 .3267 L
.08255 .34495 L
.08518 .36457 L
.08922 .38481 L
.09502 .40576 L
.10283 .42673 L
.11155 .44453 L
.1206 .45895 L
.1295 .47015 L
.13996 .48032 L
.15148 .4884 L
.16267 .49349 L
.17476 .49621 L
.18165 .49652 L
.18804 .49601 L
Mistroke
.19964 .4932 L
.21176 .48955 L
.25383 .47625 L
.33671 .44633 L
.40023 .41796 L
.42776 .40306 L
.45241 .38733 L
.47034 .37353 L
.48601 .3584 L
.49157 .35176 L
.49664 .34464 L
.50026 .33854 L
.50346 .33182 L
.50594 .32475 L
.50691 .32087 L
.50757 .31724 L
.50798 .31385 L
.50816 .31075 L
.50816 .30735 L
.50794 .30377 L
.50772 .30185 L
.50747 .30012 L
.5067 .29622 L
.50574 .29261 L
.50462 .2892 L
.50133 .28157 L
.49658 .27329 L
.48569 .25928 L
.47029 .24447 L
.43271 .21792 L
.38343 .1919 L
.31686 .16398 L
.2795 .15045 L
.24101 .13763 L
.22333 .13205 L
.20391 .12612 L
.19354 .12309 L
.18192 .12152 L
.17134 .12231 L
.16149 .12497 L
.15083 .13002 L
.13983 .13783 L
.12997 .14737 L
.12154 .15778 L
.11241 .17198 L
.10359 .18957 L
.09643 .208 L
.09093 .22635 L
.08644 .24637 L
.08338 .26589 L
Mistroke
.08133 .28787 L
.0808 .30037 L
.08071 .31183 L
.08164 .33473 L
.08283 .34754 L
.08435 .35926 L
.08816 .38016 L
.09364 .40133 L
.1 .41982 L
.10684 .43549 L
.11533 .45098 L
.12529 .46517 L
.13466 .47554 L
.14391 .48343 L
.15449 .49001 L
.16618 .49457 L
.17675 .49639 L
.18829 .49597 L
.19909 .49336 L
.20893 .49041 L
.24577 .47887 L
.3805 .4275 L
.43574 .39826 L
.45546 .38516 L
.47344 .37083 L
.48742 .3568 L
.49721 .34376 L
.50129 .33654 L
.50419 .32999 L
.50545 .32635 L
.50655 .32242 L
.50696 .32061 L
.50733 .3187 L
.50783 .31528 L
.5081 .31212 L
.50818 .30924 L
.5081 .30591 L
.50783 .30275 L
.50742 .29984 L
.5069 .29714 L
.50524 .29103 L
.50399 .28754 L
.50261 .28425 L
.4995 .27812 L
.49006 .26437 L
.47811 .25151 L
.46156 .23742 L
.4172 .209 L
.36301 .18268 L
.30116 .15815 L
Mistroke
.26147 .14432 L
.23915 .13703 L
.21442 .1293 L
.2037 .12605 L
.19195 .12273 L
.18514 .1217 L
.17889 .12154 L
.16667 .12334 L
.15593 .12731 L
.14455 .13413 L
.13428 .14288 L
.12526 .1529 L
.1165 .16518 L
.1079 .1804 L
.10115 .19532 L
.09497 .21244 L
.09027 .2289 L
.08615 .2479 L
.08339 .26581 L
.08167 .28292 L
.08072 .30471 L
.08108 .32541 L
.08243 .34384 L
.085 .36349 L
.08906 .38411 L
.09474 .40489 L
.10065 .42146 L
.10822 .43827 L
.11595 .45198 L
.12502 .46483 L
.13579 .47661 L
.14644 .48523 L
.1524 .48891 L
.15899 .49209 L
.17118 .49569 L
.18319 .49646 L
.19423 .49477 L
.20442 .49177 L
.2138 .48892 L
.2346 .48245 L
.27433 .46936 L
.35226 .43995 L
.4117 .41201 L
.45521 .38534 L
.47409 .37024 L
.4879 .35624 L
.49323 .34957 L
.4975 .34329 L
.50076 .33758 L
.50356 .33156 L
Mistroke
.50476 .32842 L
.50587 .32498 L
.5067 .32181 L
.50729 .31893 L
.5078 .31551 L
.50799 .31364 L
.50811 .31186 L
.50818 .3087 L
.50806 .30527 L
.50773 .30191 L
.50724 .29884 L
.50651 .29546 L
.50552 .29191 L
.50333 .28591 L
.50019 .27937 L
.49021 .26457 L
.47736 .25081 L
.44064 .22284 L
.38576 .193 L
.31895 .16478 L
.27796 .14992 L
.23025 .13421 L
.20875 .12758 L
.20295 .12583 L
.19657 .12392 L
.18482 .12168 L
.17759 .12159 L
.17091 .12239 L
.1648 .12386 L
.15837 .12621 L
.14702 .13241 L
.14075 .13706 L
.13503 .14215 L
.12548 .15263 L
.11614 .16575 L
.10171 .19397 L
.09512 .21195 L
.09003 .22988 L
.08566 .25063 L
.0838 .26262 L
.08248 .27372 L
.081 .29444 L
.08073 .31402 L
.08169 .33544 L
.08418 .35807 L
.08597 .36912 L
.08833 .38092 L
.0937 .40154 L
.10018 .42028 L
.10722 .43627 L
Mistroke
.11533 .45098 L
.12372 .46318 L
.13191 .47276 L
.14105 .48122 L
.1515 .4884 L
.16143 .49305 L
.17234 .49589 L
.18443 .49639 L
.19068 .49557 L
.19743 .49386 L
.20952 .49023 L
.23153 .48342 L
.27793 .46813 L
.35088 .44053 L
.41085 .41247 L
.4541 .38613 L
.47106 .37291 L
.48577 .35866 L
.49219 .35096 L
.49778 .34284 L
.5016 .33592 L
.50339 .33198 L
.50479 .32835 L
.50585 .32502 L
.5068 .32137 L
.5075 .31769 L
.50778 .31568 L
.50798 .3138 L
.50817 .31035 L
.50815 .30719 L
.50807 .30544 L
.50791 .30354 L
.50746 .30008 L
.5068 .29669 L
.50603 .29362 L
.50367 .28675 L
.50073 .28039 L
.49728 .2744 L
.48629 .25996 L
.47285 .24669 L
.43079 .21677 L
.37916 .18992 L
.31922 .16488 L
.24033 .13741 L
.21507 .1295 L
.20224 .12561 L
.19014 .12237 L
.17903 .12153 L
.16728 .12318 L
.15567 .12744 L
Mistroke
.14921 .131 L
.14328 .13508 L
.13274 .14442 L
.12222 .15684 L
.11312 .17074 L
.10567 .185 L
.09798 .2036 L
.09113 .2256 L
.08853 .23623 L
.08617 .24779 L
.08298 .26912 L
.08124 .28949 L
.08071 .3116 L
.08148 .33244 L
.08326 .35121 L
.08662 .37263 L
.08911 .38435 L
.09179 .3949 L
.09754 .41323 L
.10494 .43148 L
.1124 .44604 L
.11993 .458 L
.1282 .46867 L
.13637 .47716 L
.1458 .48479 L
.15654 .49102 L
.1673 .49486 L
.17898 .4965 L
.19053 .4956 L
.197 .49399 L
.20291 .49222 L
.22475 .48554 L
.26347 .47305 L
.39312 .42149 L
.44527 .39218 L
.47994 .36475 L
.4921 .35107 L
.49715 .34385 L
.50148 .33616 L
.50323 .33235 L
.50463 .32877 L
.50578 .32528 L
.50663 .32207 L
.50727 .31902 L
.50777 .31579 L
.50807 .31255 L
.50818 .309 L
.50808 .30558 L
.50778 .30234 L
.50735 .29943 L
Mistroke
.50671 .29627 L
.5058 .29284 L
.50461 .28919 L
.50185 .28264 L
.49499 .27094 L
.48454 .25804 L
.47031 .24449 L
.45174 .23024 L
.40934 .20477 L
.35052 .17736 L
.27059 .14739 L
.23084 .1344 L
.2102 .12802 L
.20091 .12522 L
.19053 .12244 L
.18112 .12151 L
.17231 .12215 L
.16308 .12441 L
.15335 .12861 L
.14303 .13526 L
.13366 .14349 L
.11751 .16362 L
.10932 .17763 L
.10266 .19171 L
.09637 .20819 L
.09068 .2273 L
.08649 .24608 L
.08362 .26399 L
.08178 .28153 L
.08081 .30029 L
.08089 .32078 L
.08231 .34253 L
.08487 .36265 L
.08822 .3804 L
.09334 .40032 L
.10027 .4205 L
.10802 .43788 L
.11613 .45226 L
Mfstroke
.50819 .43998 m
.56146 .4153 L
.60708 .38826 L
.62505 .37462 L
.64053 .36003 L
.64664 .35295 L
.65158 .34625 L
.65558 .33979 L
.65864 .33373 L
.66123 .32705 L
.66228 .32351 L
.66315 .3197 L
.66349 .3178 L
.66378 .31572 L
.66399 .31376 L
.66411 .31194 L
.66419 .3085 L
.66414 .30658 L
.66403 .30483 L
.66366 .3014 L
.66313 .29824 L
.66234 .29477 L
.66127 .2911 L
.65891 .28493 L
.65553 .27816 L
.64502 .26311 L
.62917 .24697 L
.58858 .21784 L
.53506 .18987 L
.46066 .15943 L
.38279 .13313 L
.28222 .10409 L
.23025 .09059 L
.21543 .0869 L
.19956 .083 L
.1858 .08051 L
.17069 .08106 L
.15646 .08483 L
.14382 .09096 L
.12976 .10115 L
.1172 .11369 L
.10633 .12769 L
.09708 .14247 L
.08723 .16205 L
.07936 .18173 L
.07232 .2041 L
.06632 .22963 L
.06228 .25436 L
.05984 .27849 L
.05907 .29222 L
Mistroke
.05875 .3069 L
.05943 .33328 L
.06065 .34931 L
.06235 .36421 L
.06431 .37737 L
.06691 .39132 L
.07313 .41683 L
.08181 .44291 L
.09277 .46756 L
.10455 .48773 L
.11679 .50387 L
.12877 .51602 L
.13569 .52164 L
.14339 .52682 L
.15781 .5337 L
.17167 .53712 L
.18447 .53762 L
.19847 .5353 L
.21299 .53174 L
.26237 .5192 L
.36419 .49063 L
.44948 .46266 L
.52479 .43282 L
.58162 .4043 L
.62038 .37841 L
.63473 .36592 L
.64707 .3524 L
.65162 .34619 L
.65566 .33962 L
.65851 .33399 L
.66095 .32787 L
.66208 .32424 L
.66291 .32088 L
.6635 .31767 L
.66394 .31426 L
.66414 .31122 L
.66418 .30836 L
.66405 .30522 L
.66372 .30184 L
.66317 .29846 L
.66233 .29475 L
.66119 .29089 L
.65989 .28728 L
.65696 .28083 L
.65298 .27392 L
.64264 .26035 L
.62979 .24753 L
.5977 .22352 L
.54971 .19683 L
.48471 .16855 L
Mistroke
.33168 .11782 L
.23546 .09191 L
.22125 .08834 L
.20549 .08445 L
.19819 .08267 L
.19034 .08104 L
.17616 .08045 L
.16128 .08319 L
.14754 .08888 L
.13556 .09649 L
.12317 .10729 L
.11197 .12001 L
.10224 .13386 L
.0917 .15259 L
.08318 .17161 L
.07549 .19331 L
.06946 .21525 L
.0645 .23959 L
.06081 .26706 L
.05919 .28941 L
.05878 .31428 L
.05988 .34019 L
.06234 .36414 L
.06583 .38589 L
.07003 .40516 L
.0757 .4254 L
.08279 .44543 L
.09187 .46579 L
.10305 .48545 L
.11474 .50145 L
.12633 .51381 L
.13736 .52286 L
.14997 .5304 L
.16352 .53548 L
.17639 .5376 L
.19148 .53682 L
.20564 .53355 L
.23164 .52709 L
.28736 .51256 L
.45122 .46204 L
.51851 .43557 L
.57613 .40742 L
.59893 .39372 L
.61726 .38085 L
.63212 .3684 L
.64342 .3568 L
.6531 .34394 L
.657 .33713 L
.66024 .32985 L
.66151 .32618 L
Mistroke
.66261 .3222 L
.66302 .32038 L
.66338 .31844 L
.66387 .31497 L
.66413 .31164 L
.66419 .30853 L
.66405 .30511 L
.66388 .30319 L
.66367 .30143 L
.66314 .2983 L
.66239 .29497 L
.66053 .28897 L
.65747 .28183 L
.65389 .27536 L
.64459 .2626 L
.63312 .25058 L
.59805 .22374 L
.54674 .19538 L
.41827 .14459 L
.33418 .11854 L
.28261 .10419 L
.23029 .0906 L
.20562 .08448 L
.19291 .08147 L
.17873 .08033 L
.17137 .08096 L
.16347 .08257 L
.14939 .08792 L
.13578 .09632 L
.12384 .10662 L
.11347 .11813 L
.10441 .13052 L
.09448 .14721 L
.08634 .16407 L
.07926 .18201 L
.07267 .20284 L
.06703 .22612 L
.063 .24907 L
.06011 .27492 L
.05886 .29896 L
.05912 .32682 L
.06102 .35304 L
.0642 .37667 L
.06832 .3979 L
.07411 .42019 L
.08165 .44249 L
.09145 .46494 L
.10365 .48637 L
.1165 .50354 L
.12927 .51646 L
Mistroke
.14145 .52562 L
.15534 .53277 L
.1702 .5369 L
.18422 .53763 L
.19912 .53514 L
.20745 .53311 L
.21508 .53123 L
.24336 .52412 L
.29386 .5108 L
.39555 .48088 L
.53224 .42947 L
.58855 .40021 L
.60873 .3871 L
.62722 .37277 L
.64085 .35967 L
.65196 .34568 L
.65658 .33794 L
.65983 .33091 L
.66107 .32752 L
.66219 .32385 L
.66301 .32038 L
.66358 .31718 L
.66394 .31424 L
.66415 .31109 L
.66418 .30811 L
.66407 .30539 L
.66377 .30221 L
.66323 .29874 L
.66252 .29547 L
.66169 .29244 L
.65954 .28641 L
.6564 .27975 L
.64756 .26627 L
.63542 .25278 L
.61905 .23857 L
.58059 .21315 L
.52606 .18578 L
.45072 .15582 L
.36661 .12814 L
.2743 .10198 L
.21793 .08752 L
.20182 .08355 L
.19289 .08147 L
.18446 .08042 L
.16956 .08124 L
.16171 .08306 L
.15335 .08609 L
.13934 .09381 L
.13165 .09956 L
.12473 .10575 L
Mistroke
.11166 .12042 L
.10074 .13626 L
.08282 .17252 L
.07489 .19525 L
.06878 .21814 L
.06417 .24155 L
.06077 .26752 L
.05906 .29257 L
.0588 .31558 L
.06006 .34247 L
.06151 .35747 L
.06333 .37117 L
.06782 .39563 L
.07417 .4204 L
.08163 .44247 L
.09112 .46429 L
.10042 .48126 L
.11163 .49758 L
.12515 .51269 L
.1324 .51909 L
.14037 .52492 L
.14804 .52943 L
.15514 .53269 L
.16924 .53674 L
.18241 .53771 L
.19633 .53582 L
.20808 .53295 L
.22083 .5298 L
.27375 .51621 L
.3612 .49154 L
.51279 .43803 L
.57507 .408 L
.59739 .39472 L
.61762 .38057 L
.63433 .36632 L
.64626 .35341 L
.65095 .34718 L
.65521 .34044 L
.65846 .33412 L
.66083 .32824 L
.66197 .32462 L
.66281 .32133 L
.66351 .31768 L
.66379 .31567 L
.66398 .31377 L
.66411 .31192 L
.66418 .30997 L
.66413 .30645 L
.664 .3045 L
.66382 .30267 L
Mistroke
.66356 .30067 L
.66318 .29851 L
.66241 .29502 L
.6613 .2912 L
.65861 .28425 L
.65514 .27748 L
.65118 .2712 L
.63982 .25726 L
.62355 .24217 L
.58346 .21481 L
.53136 .18817 L
.47198 .16365 L
.31087 .11193 L
.25824 .09776 L
.2277 .08995 L
.21225 .08611 L
.19772 .08255 L
.18392 .08039 L
.16921 .0813 L
.15461 .08556 L
.14645 .08946 L
.13894 .09408 L
.12639 .10418 L
.11546 .11571 L
.10427 .13072 L
.09354 .14899 L
.07933 .18179 L
.07287 .20214 L
.06799 .22163 L
.06434 .24053 L
.06139 .26163 L
.0596 .28194 L
.05882 .30089 L
Mfstroke
.82019 .17805 m
.67263 .12633 L
.46436 .0718 L
.34256 .04508 L
.27004 .03038 L
.23296 .02316 L
.21637 .01999 L
.19788 .01649 L
.18735 .01499 L
.17746 .01477 L
.16702 .01582 L
.15587 .01839 L
.14386 .0229 L
.13265 .02881 L
.12281 .03543 L
.11237 .04404 L
.0949 .06256 L
.07783 .08674 L
.06347 .11336 L
.05212 .14031 L
.04166 .17261 L
.03406 .20433 L
.03089 .22154 L
.02807 .24082 L
.02588 .26127 L
.02454 .28059 L
.02386 .3165 L
.02527 .34916 L
.02688 .36703 L
.0293 .38621 L
.03541 .42015 L
.04311 .45051 L
.05175 .47672 L
.06286 .50338 L
.07623 .52866 L
.08827 .54689 L
.10212 .56381 L
.11831 .57911 L
.13413 .5901 L
.14404 .59521 L
.15331 .59883 L
.16361 .60159 L
.17459 .60311 L
.19308 .60239 L
.20354 .60048 L
.21325 .59864 L
.28314 .58506 L
.5429 .52728 L
.73611 .47149 L
.86314 .4205 L
Mistroke
.91149 .39336 L
.94435 .36819 L
.95804 .35369 L
.96714 .34056 L
.97083 .33328 L
.97239 .32945 L
.97374 .32541 L
.97469 .32186 L
.97509 .31999 L
.97546 .31798 L
.97592 .31445 L
.97615 .31115 L
.97617 .30779 L
.9761 .30587 L
.97597 .30408 L
.97552 .30046 L
.97517 .29843 L
.97478 .29657 L
.9729 .29001 L
.97166 .28671 L
.97008 .2831 L
.96594 .27546 L
.96036 .2673 L
.94726 .25263 L
.92991 .23768 L
.90982 .2236 L
.86258 .19726 L
.72279 .1421 L
.54513 .09132 L
.44069 .06638 L
.31605 .03961 L
.27685 .03173 L
.23865 .02426 L
.20349 .01755 L
.19372 .01575 L
.18327 .01476 L
.1645 .01627 L
.14742 .02138 L
.12945 .03081 L
.11314 .04334 L
.09892 .0578 L
.08419 .07693 L
.06951 .10133 L
.05604 .13027 L
.0454 .15996 L
.0369 .19128 L
.03311 .20915 L
.03013 .22628 L
.02625 .25724 L
.02407 .292 L
Mistroke
.02381 .3115 L
.02421 .33001 L
.02662 .36447 L
.0289 .38341 L
.03161 .4007 L
.0398 .43851 L
.04923 .46969 L
.05991 .49688 L
.08398 .54081 L
.09951 .56091 L
.11483 .57618 L
.13257 .58918 L
.14178 .59416 L
.15206 .59841 L
.17027 .60268 L
.18764 .60302 L
.20317 .60055 L
.21989 .59738 L
.28991 .5837 L
.40763 .55904 L
.6244 .50568 L
.71846 .47735 L
.80346 .44682 L
.86868 .41773 L
.91493 .39108 L
.94707 .36559 L
.95876 .35278 L
.96813 .33877 L
.97147 .33179 L
.97287 .32811 L
.97408 .32422 L
.97492 .32082 L
.97527 .31901 L
.97559 .31707 L
.97599 .31367 L
.97616 .31049 L
.97615 .30719 L
.97592 .3036 L
.97548 .30021 L
.97488 .29706 L
.97412 .29394 L
.97327 .29112 L
.97085 .2848 L
.96706 .27736 L
.9627 .27052 L
.94974 .2551 L
.93472 .2415 L
.91525 .22717 L
.87006 .201 L
.80793 .17301 L
Mistroke
.65988 .12254 L
.55746 .09446 L
.43 .06397 L
.36594 .04999 L
.29412 .03518 L
.22964 .02253 L
.21147 .01906 L
.20135 .01715 L
.19167 .01545 L
.17283 .01508 L
.15568 .01845 L
.13783 .02587 L
.12802 .03176 L
.11918 .03823 L
.10354 .05271 L
.08805 .07145 L
.06434 .11156 L
.05296 .13809 L
.04388 .16495 L
.03542 .19789 L
.02946 .23069 L
.0259 .26107 L
.02399 .29473 L
.02382 .31221 L
.02427 .33149 L
.02545 .35152 L
.02723 .37016 L
.03197 .40274 L
.03927 .43647 L
.04746 .46444 L
.05648 .48884 L
.06885 .51545 L
.08149 .53707 L
.09505 .55565 L
.11085 .5726 L
.12857 .58665 L
.14602 .59608 L
.16136 .6011 L
.17845 .60329 L
.19632 .60183 L
.2129 .5987 L
.27283 .5871 L
.50741 .53604 L
.70915 .48036 L
.79499 .45016 L
.85976 .42215 L
.90833 .39538 L
.92966 .38052 L
.94573 .36687 L
.95851 .35308 L
Mistroke
.96369 .34605 L
.96825 .33853 L
.97179 .33097 L
.97303 .32759 L
.97415 .32392 L
.97471 .32168 L
.97515 .31961 L
.97549 .31767 L
.97578 .31553 L
.97598 .31362 L
.9761 .31183 L
.97616 .30994 L
.97616 .3079 L
.97597 .3044 L
.9756 .30115 L
.97498 .29759 L
.97406 .29378 L
.9728 .28977 L
.97135 .286 L
.96793 .27893 L
.95949 .26619 L
.94701 .2524 L
.91396 .22632 L
.86337 .19765 L
.79459 .16773 L
.71558 .13975 L
.51512 .08387 L
.40833 .05916 L
.28255 .03287 L
.25098 .02665 L
.21612 .01995 L
.20626 .01808 L
.1958 .01611 L
.17696 .0148 L
.15935 .01743 L
.14038 .02456 L
.12359 .03486 L
.10894 .04725 L
.09297 .06496 L
.07901 .08485 L
.05741 .12696 L
.04732 .15402 L
.03949 .18073 L
.03273 .21114 L
.02754 .2452 L
.02467 .27821 L
.02381 .30877 L
.02495 .34445 L
.02662 .36445 L
.02881 .38278 L
Mistroke
.03443 .41552 L
.03845 .43321 L
.04262 .4488 L
.05258 .47895 L
.06513 .5081 L
.08102 .53635 L
.09737 .55843 L
.11386 .57533 L
.13012 .58766 L
.14869 .59716 L
.15933 .6006 L
.16911 .60253 L
.18646 .60311 L
.20269 .60063 L
.23906 .59369 L
.31001 .57965 L
.42843 .55442 L
.65368 .49732 L
.73967 .47027 L
.81582 .44179 L
.86975 .41718 L
.91519 .3909 L
.93388 .3772 L
.94839 .36428 L
.95883 .35268 L
.96326 .34669 L
.96738 .3401 L
.97033 .33434 L
.97283 .32816 L
.97391 .32475 L
.97472 .32163 L
.97535 .31849 L
.97578 .31552 L
.97604 .31279 L
.97616 .30989 L
.97613 .30715 L
.97599 .30467 L
.97568 .30175 L
.97517 .29858 L
.97453 .2956 L
.97379 .29286 L
Mfstroke
.82019 .30902 m
.8201 .30579 L
.81985 .30284 L
.81936 .29945 L
.81871 .29624 L
.81708 .29053 L
.81465 .28433 L
.81116 .27751 L
.80654 .27027 L
.79586 .25729 L
.78162 .24389 L
.76532 .23134 L
.7175 .20276 L
.65342 .17361 L
.58124 .14693 L
.4806 .11579 L
.37137 .08688 L
.26344 .06161 L
.23021 .05433 L
.21356 .05076 L
.19803 .04748 L
.18373 .04553 L
.16858 .04642 L
.15352 .0504 L
.13737 .05826 L
.12911 .06381 L
.12035 .07095 L
.10517 .0867 L
.0915 .10531 L
.08 .12515 L
.06899 .14908 L
.05871 .17815 L
.05435 .19367 L
.05026 .21096 L
.04705 .22763 L
.0446 .24347 L
.04151 .27295 L
.0406 .28875 L
.0402 .30571 L
.0404 .32357 L
.04118 .34036 L
.04417 .37138 L
.04875 .39966 L
.05444 .42474 L
.06224 .45083 L
.07216 .47645 L
.08297 .49845 L
.09619 .51965 L
.10987 .5367 L
.12342 .54974 L
Mistroke
.13752 .55987 L
.15071 .56654 L
.16629 .57121 L
.18112 .57258 L
.19737 .5707 L
.21432 .56711 L
.24408 .56069 L
.30846 .54621 L
.50271 .49585 L
.58532 .46971 L
.65999 .44173 L
.71705 .41551 L
.75865 .39127 L
.777 .37793 L
.79347 .36322 L
.80606 .34844 L
.81127 .34034 L
.81507 .33275 L
.81758 .32596 L
.81852 .32255 L
.81897 .3206 L
.81932 .31883 L
.81979 .31563 L
.8201 .31222 L
.82019 .30906 L
.82011 .30608 L
.81982 .3026 L
.81958 .30084 L
.81926 .29891 L
.81853 .29549 L
.81765 .2923 L
.81499 .2851 L
.81108 .27738 L
.80082 .26287 L
.78791 .24944 L
.74654 .21903 L
.69611 .19222 L
.62815 .16371 L
.46077 .11023 L
.36878 .08624 L
.25608 .05998 L
.22506 .05322 L
.20765 .04951 L
.19098 .04618 L
.17531 .04565 L
.1584 .04877 L
.1433 .05492 L
.12976 .06333 L
.11497 .07602 L
.10191 .09073 L
Mistroke
.08865 .10983 L
.07585 .1335 L
.06431 .1613 L
.05527 .19018 L
.04887 .21775 L
.04601 .2339 L
.04385 .24916 L
.04119 .27749 L
.04019 .30853 L
.04103 .33785 L
.04333 .3645 L
.04666 .38812 L
.05163 .41325 L
.05825 .43833 L
.06566 .46042 L
.0758 .48442 L
.08669 .50497 L
.09759 .5216 L
.11006 .53692 L
.12451 .55064 L
.13854 .56048 L
.15416 .56786 L
.16322 .57055 L
.17179 .57206 L
.18731 .57227 L
.2038 .56934 L
.23295 .56311 L
.29647 .54898 L
.41342 .52049 L
.58568 .46959 L
.66081 .44139 L
.72589 .41084 L
.75007 .39682 L
.77176 .38199 L
.78845 .36809 L
.80062 .3554 L
.80563 .34902 L
.81025 .34207 L
.81384 .33543 L
.8164 .32942 L
.81755 .32605 L
.81856 .32241 L
.81901 .32041 L
.81936 .31856 L
.81987 .31495 L
.82012 .31183 L
.82019 .30842 L
.82003 .30485 L
.81968 .30153 L
.81916 .29839 L
Mistroke
.8184 .29498 L
.81647 .28879 L
.81392 .28276 L
.81098 .27719 L
.80221 .26455 L
.78973 .25115 L
.75642 .22528 L
.70697 .19745 L
.58181 .14713 L
.49301 .11936 L
.38002 .08903 L
.3228 .07517 L
.25793 .06039 L
.22497 .0532 L
.20846 .04968 L
.19307 .0465 L
.17892 .04548 L
.16399 .04731 L
.14919 .05213 L
.13336 .06081 L
.11758 .07349 L
.10381 .08835 L
.08984 .10791 L
.07652 .13209 L
.06646 .1555 L
.05836 .17932 L
.0511 .20715 L
.04781 .22334 L
.04527 .23873 L
.04207 .266 L
.04035 .29637 L
.04048 .32613 L
.0426 .35768 L
.04639 .38648 L
.05152 .41278 L
.05738 .4354 L
.065 .45862 L
.07556 .48392 L
.08686 .50525 L
.10066 .5257 L
.11688 .54388 L
.12544 .5514 L
.13507 .55834 L
.14438 .56366 L
.15318 .56751 L
.17007 .57184 L
.1796 .57257 L
.18823 .57219 L
.20518 .56905 L
.22056 .56578 L
Mistroke
.25455 .55839 L
.31361 .54502 L
.52631 .48877 L
.60923 .46131 L
.67282 .43631 L
.72351 .41212 L
.76653 .38583 L
.7848 .37139 L
.79832 .35805 L
.80821 .3453 L
.81208 .33886 L
.81548 .33177 L
.81778 .32529 L
.81874 .32162 L
.81942 .31821 L
.8199 .31459 L
.82014 .31131 L
.82018 .30949 L
.82016 .30752 L
.81995 .30395 L
.81958 .30088 L
.81898 .29751 L
.81813 .29398 L
.81713 .29069 L
.81485 .2848 L
.8117 .27848 L
.80099 .26308 L
.78684 .24847 L
.74986 .22109 L
.70111 .1946 L
.63525 .16643 L
.4806 .11579 L
.38422 .09008 L
.32876 .07658 L
.26671 .06234 L
.23927 .0563 L
.20918 .04983 L
.20015 .04792 L
.19155 .04627 L
.17537 .04564 L
.16026 .04824 L
.14413 .0545 L
.13096 .06248 L
.11701 .07403 L
.10325 .08905 L
.09125 .10569 L
.07242 .141 L
.0635 .16357 L
.05651 .18568 L
.04949 .21468 L
Mistroke
.04463 .24326 L
.04176 .26966 L
.04029 .29867 L
.04065 .3305 L
.04161 .34644 L
.04325 .36378 L
.04765 .39381 L
.05344 .42079 L
.06084 .44661 L
.06922 .46951 L
.08817 .50743 L
.10039 .52536 L
.11258 .53959 L
.12676 .55244 L
.14256 .56272 L
.15899 .56944 L
.17433 .57231 L
.19125 .57181 L
.19972 .5702 L
.20891 .56826 L
.26921 .55514 L
.39496 .52524 L
.58069 .47129 L
.66102 .4413 L
.72058 .41366 L
.767 .38548 L
.78564 .37065 L
.801 .35494 L
.8061 .34837 L
.8107 .3413 L
.81395 .3352 L
.81671 .32854 L
.818 .32451 L
.81893 .32076 L
.81958 .31718 L
.81984 .31518 L
.82001 .31337 L
.82017 .30994 L
.82017 .30801 L
.82011 .30623 L
.81985 .30296 L
.81936 .29951 L
.81867 .29614 L
.81769 .29248 L
.81529 .28583 L
.81218 .27935 L
.80862 .27337 L
.79814 .25979 L
.78335 .24538 L
.75032 .22138 L
Mistroke
.70177 .19492 L
.66699 .17924 L
Mfstroke
.82019 .43998 m
.87346 .4153 L
.91909 .38826 L
.93705 .37462 L
.95253 .36003 L
.95864 .35295 L
.96358 .34625 L
.96758 .33979 L
.97064 .33373 L
.97323 .32705 L
.97428 .32351 L
.97515 .3197 L
.97549 .3178 L
.97578 .31572 L
.97599 .31376 L
.97612 .31194 L
.97619 .3085 L
.97614 .30658 L
.97603 .30483 L
.97566 .3014 L
.97514 .29824 L
.97435 .29477 L
.97327 .2911 L
.97092 .28493 L
.96753 .27816 L
.95702 .26311 L
.94117 .24697 L
.90059 .21784 L
.84706 .18987 L
.77266 .15943 L
.59423 .10409 L
.36459 .04971 L
.30066 .03649 L
.22819 .02224 L
.20732 .01827 L
.19581 .01611 L
.18504 .01483 L
.16594 .016 L
.15591 .01838 L
.14531 .02226 L
.13549 .02715 L
.12506 .03379 L
.10686 .04929 L
.09029 .06842 L
.07625 .08936 L
.06323 .11387 L
.05238 .13964 L
.04389 .16489 L
.03641 .19341 L
.0302 .22581 L
Mistroke
.02629 .25688 L
.02478 .27624 L
.024 .29459 L
.02417 .32896 L
.02611 .35928 L
.02996 .39068 L
.03469 .41673 L
.04132 .4442 L
.05012 .47222 L
.0613 .49999 L
.07245 .52212 L
.08555 .54309 L
.1025 .56422 L
.11934 .57993 L
.12842 .58655 L
.13843 .59248 L
.14963 .59753 L
.16028 .60084 L
.16963 .6026 L
.1799 .60332 L
.19061 .60272 L
.20053 .60104 L
.23677 .59414 L
.37043 .56709 L
.58857 .51546 L
.77006 .45956 L
.84539 .42894 L
.89967 .40074 L
.93803 .37379 L
.95236 .36021 L
.95854 .35306 L
.96422 .34529 L
.96864 .33782 L
.97183 .3309 L
.97407 .32429 L
.97489 .32095 L
.97525 .31916 L
.97557 .31727 L
.97597 .31396 L
.97615 .31092 L
.97617 .30766 L
.97597 .30408 L
.9756 .30098 L
.97502 .29767 L
.97428 .29454 L
.97346 .2917 L
.97064 .28432 L
.96716 .27752 L
.95619 .26213 L
.94295 .24857 L
Mistroke
.92527 .2342 L
.8839 .20829 L
.8258 .18043 L
.68499 .13009 L
.46489 .07192 L
.34298 .04517 L
.27552 .03147 L
.23603 .02375 L
.21686 .02008 L
.19875 .01666 L
.1805 .01472 L
.17082 .01529 L
.16049 .01714 L
.14976 .02046 L
.13973 .02488 L
.12144 .03646 L
.10478 .05141 L
.0903 .06842 L
.07564 .09037 L
.06173 .11709 L
.05172 .14141 L
.0425 .16964 L
.03541 .19793 L
.03034 .22496 L
.02639 .25586 L
.02412 .29035 L
.02409 .32662 L
.02619 .36013 L
.03003 .3911 L
.03617 .42356 L
.04379 .45279 L
.05229 .47817 L
.07197 .52126 L
.08348 .54007 L
.09719 .55822 L
.11314 .57469 L
.1285 .58661 L
.14696 .59647 L
.16494 .60185 L
.1817 .60331 L
.19722 .60167 L
.2141 .59848 L
.23186 .59508 L
.49091 .54 L
.70864 .48053 L
.78889 .45252 L
.85805 .42298 L
.90455 .39776 L
.94221 .37013 L
.9564 .35566 L
Mistroke
.96198 .34854 L
.96631 .34197 L
.9695 .33612 L
.9723 .32968 L
.97435 .3232 L
.97515 .31965 L
.9757 .31633 L
.97605 .31278 L
.97615 .31077 L
.97618 .30891 L
.97607 .30549 L
.97591 .30358 L
.97572 .30185 L
.97519 .29857 L
.9744 .29503 L
.97239 .2886 L
.96907 .28104 L
.96442 .27306 L
.95321 .25876 L
.93906 .24514 L
.92322 .23271 L
.87735 .20478 L
.82217 .17889 L
.75863 .15436 L
.57741 .09963 L
.36115 .04898 L
.29945 .03625 L
.26587 .02956 L
.22962 .02252 L
.21394 .01953 L
.19701 .01633 L
.17827 .01475 L
.16084 .01706 L
.14399 .02285 L
.12846 .03146 L
.115 .04171 L
.10103 .05542 L
.08541 .07516 L
.07202 .09669 L
.05893 .12339 L
.04692 .15523 L
.04178 .1722 L
.03687 .1914 L
.03317 .20883 L
.02989 .22785 L
.02732 .24705 L
.0256 .26469 L
.02389 .29953 L
.02441 .33473 L
.02686 .36678 L
Mistroke
.03169 .40114 L
.03495 .41796 L
.03914 .43594 L
.04762 .46493 L
.05856 .49378 L
.08263 .5388 L
.09729 .55835 L
.11473 .57609 L
.12391 .58341 L
.13405 .59006 L
.15292 .5987 L
.17112 .60278 L
.19039 .60274 L
.20675 .59987 L
.22444 .59651 L
.37532 .56604 L
.60629 .51068 L
.7779 .45666 L
.85075 .42644 L
.9025 .39902 L
.92276 .38565 L
.94065 .37151 L
.95318 .35929 L
.96361 .34617 L
.9681 .3388 L
.97133 .33208 L
.97259 .32884 L
.97375 .32532 L
.97463 .32201 L
.97528 .31891 L
.97581 .31533 L
.97599 .31342 L
.97612 .31137 L
.97617 .30933 L
.97614 .30719 L
.97605 .30536 L
.97588 .30335 L
.97539 .29975 L
.97501 .29773 L
.9746 .29589 L
.9725 .28895 L
.96983 .28262 L
.96604 .27565 L
.95568 .26156 L
.94286 .2485 L
.92803 .23627 L
.88469 .20873 L
.82267 .17911 L
.65452 .12097 L
.43773 .06571 L
Mistroke
.31466 .03934 L
.28011 .03238 L
.24174 .02486 L
.22378 .02141 L
.20457 .01776 L
.18798 .01505 L
.1697 .01543 L
.15131 .01989 L
.1349 .02749 L
.12605 .0331 L
.11664 .04031 L
.10024 .0563 L
.08593 .07441 L
.07199 .09676 L
.06113 .11843 L
.05079 .14396 L
.04228 .17042 L
.03583 .19602 L
.0309 .22149 L
.02709 .24909 L
.02457 .28009 L
.02381 .30923 L
.02475 .34119 L
.02779 .37489 L
.03159 .4006 L
.03719 .428 L
.04456 .45535 L
.05279 .47949 L
.07047 .5185 L
.08189 .53769 L
.09316 .55331 L
.10619 .56807 L
.12082 .5811 L
.13761 .59204 L
.15366 .59894 L
.1704 .60269 L
.18625 .60312 L
.20044 .60106 L
.21563 .59818 L
.42679 .55478 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oB?ooool0
0ol0003oooooooooo`3ooooooakooooo0018ooooo`03o`000?oooooooooo0?oooooo7_ooool004So
oooo00?o0000ooooooooool0oooooolNooooo`00B?ooool00ol0003oooooooooo`3ooooooakooooo
0018ooooo`03o`000?oooooooooo0?oooooo7_ooool003gooooo4?l0003ooooooacooooo000ioooo
o`Oo00002?ooool00ol0003oooooo`000007o`000?oooooo5oooool003Kooooo1_l0000<ooooo`;o
00001Oooool8o`000?oooooo4_ooool003Gooooo1?l0000?ooooo`03o`000?oooooooooo00Sooooo
2Ol0003oooooo`gooooo000cooooo`?o00004_ooool00ol0003oooooooooo`0=ooooo`Wo0000oooo
ool8ooooo`00<_ooool2o`0001Cooooo00?o0000ooooooooool04oooool8o`000?oooooo0oooool0
033ooooo0ol0000Eooooo`03o`000?oooooooooo01Oooooo2Ol0003mooooo`00;oooool2o`0001Oo
oooo00?o0000ooooooooool07?ooool9o`000?Sooooo000^ooooo`;o00003Oooool5o`0000Kooooo
00?o0000ooooooooool08Oooool9o`000??ooooo000]ooooo`;o00003_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool09_ooool8o`000>oooooo000/ooooo`;o00001ooo
ool6o`0000;ooooo4?l0000Yooooo`So0000j_ooool002_ooooo0_l0000=ooooo`Ko000000?o8B4Q
onk^k_ooool01Oooool00ol0003oooooo`000005o`0002[ooooo2?l0003Vooooo`00:_ooool2o`00
00cooooo1?l00004ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool01Oooool6o`00
02Wooooo2?l0003Qooooo`00:Oooool3o`0000[ooooo0ol00008ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool8o`0002Wooooo2?l0003Looooo`00:Oooool2o`0000Wooooo
0ol00006ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0<ooooo`So
0000:_ooool8o`000=Oooooo000Xooooo`;o00002Oooool2o`0000Sooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo013ooooo2?l0000Zooooo`Wo0000d_ooool002Oooooo
0_l00009ooooo`;o00005?ooool00ol0003oooooooooo`0Eooooo`Oo0000:oooool8o`000<kooooo
000Vooooo`;o00002Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo1_l0
000[ooooo`So0000b_ooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01oooooo1Ol0000[ooooo`So0000a_ooool002Gooooo0_l00008oooo
o`03o`000?oooooooooo01Kooooo0_l0000Tooooo`Ko0000:_ooool8o`000<;ooooo000Tooooo`;o
00002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Oooooo1Ol0000[ooooo`Wo
0000_Oooool002Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`co0000
;?ooool5o`0002_ooooo2Ol0002iooooo`008oooool2o`0000Oooooo00?o0000ooooooooool03?oo
ool5o`0000Sooooo1ol0000/ooooo`Go0000:_ooool9o`000;Gooooo000Rooooo`;o00001oooool0
0ol0003oooooooooo`0:ooooo`Co00003?ooool01?l0003oooooooooooooool7o`0002cooooo1Ol0
000Zooooo`Wo0000/Oooool002;ooooo0_l00006ooooo`;o00002_ooool4o`0000kooooo00?o0000
ooooooooool01Oooool7o`0002_ooooo1_l0000Zooooo`Wo0000[Oooool0027ooooo0_l00007oooo
o`03o`000?oooooooooo00Sooooo0ol0000@ooooo`03o`000?oooooooooo00Wooooo1ol0000[oooo
o`Ko0000:oooool8o`000:Wooooo000Pooooo`;o00001oooool00ol0003oooooooooo`08ooooo`;o
00004_ooool00ol0003oooooooooo`0=ooooo`Oo0000:oooool6o`0002_ooooo2?l0002Uooooo`00
8?ooool2o`0000Kooooo0_l00009ooooo`;o00004oooool2o`0001;ooooo1_l0000/ooooo`Ko0000
:oooool7o`000:;ooooo000Oooooo`;o00001oooool00ol0003oooooooooo`07ooooo`;o00005?oo
ool00ol0003oooooooooo`0Eooooo`Ko0000:oooool6o`0002_ooooo2?l0002Nooooo`007oooool2
o`0000Kooooo00?o0000ooooooooool01oooool2o`0001Gooooo00?o0000ooooooooool06?ooool6
o`0002cooooo1_l0000[ooooo`So0000V_ooool001kooooo0_l00006ooooo`;o00002?ooool2o`00
01Kooooo00?o0000ooooooooool07?ooool6o`0002cooooo1_l0000[ooooo`Oo0000Uoooool001ko
oooo0_l00006ooooo`03o`000?oooooooooo00Kooooo0_l0000Gooooo`03o`000?oooooooooo01oo
oooo1ol0000[ooooo`Oo0000:oooool7o`0009?ooooo000Nooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`;o00006?ooool00ol0003oooooooooo`0Sooooo`Ko0000;?ooool7o`0002[ooooo
2?l0002?ooooo`007Oooool2o`0000Kooooo00?o0000ooooooooool01_ooool2o`0001Sooooo00?o
0000ooooooooool09_ooool7o`0002_ooooo2?l0000Zooooo`Oo0000S?ooool001gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo0_l0000@ooooo`[o0000;?ooool6o`0002_ooooo2?l0000Z
ooooo`Oo0000ROooool001cooooo0_l00005ooooo`;o00001oooool2o`0000kooooo1Ol00006oooo
o`Ko0000;?ooool5o`0002_ooooo2?l0000Zooooo`Oo0000Q_ooool001cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`;o00003Oooool3o`0000_ooooo00?o0000ooooool0
00001Ol0000/ooooo`Ko0000:_ooool8o`0002_ooooo1_l00023ooooo`006oooool2o`0000Gooooo
0_l00007ooooo`03o`000?oooooooooo00[ooooo0ol0000=ooooo`03o`000?oooooooooo00?ooooo
1Ol0000/ooooo`Ko0000:_ooool8o`0002_ooooo1_l00020ooooo`006oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`?o00003_ooool00ol0003ooooooooo
o`06ooooo`Go0000;?ooool6o`0002_ooooo1ol0000/ooooo`Go0000OOooool001[ooooo0_l00005
ooooo`;o00001_ooool2o`0000_ooooo0_l0000@ooooo`03o`000?oooooooooo00Wooooo1_l0000[
ooooo`Ko0000:oooool7o`0002cooooo1Ol0001jooooo`006_ooool2o`0000Gooooo00?o0000oooo
ooooool01Oooool2o`0000[ooooo0_l0000Aooooo`03o`000?oooooooooo00gooooo1Ol0000[oooo
o`Ko0000:oooool7o`0002cooooo1Ol0001gooooo`006Oooool2o`0000Gooooo0_l00006ooooo`;o
00002_ooool2o`0001;ooooo00?o0000ooooooooool04?ooool5o`0002_ooooo1_l0000[ooooo`Oo
0000:oooool6o`0007Cooooo000Iooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o0000
2Oooool2o`0001?ooooo00?o0000ooooooooool04oooool5o`0002_ooooo1_l0000[ooooo`Oo0000
:oooool6o`00077ooooo000Iooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o00005?oo
ool00ol0003oooooooooo`0Fooooo`Co0000;?ooool6o`0002cooooo1_l0000[ooooo`Ko0000K_oo
ool001Sooooo0_l00005ooooo`;o00001_ooool2o`0000Sooooo0_l0000Eooooo`;o00006_ooool4
o`0002cooooo1_l0000/ooooo`Go0000;?ooool6o`0006_ooooo000Hooooo`;o00001?ooool2o`00
00Kooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Looooo`Co0000;?ooool6o`00
02cooooo1Ol0000/ooooo`Ko0000J?ooool001Sooooo0_l00004ooooo`;o00001_ooool00ol0003o
ooooooooo`07ooooo`;o00005_ooool00ol0003oooooooooo`0Oooooo`?o0000;Oooool6o`0002co
oooo1Ol0000/ooooo`Ko0000IOooool001Oooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo
0_l0000Gooooo`03o`000?oooooooooo027ooooo1?l0000]ooooo`Go0000;Oooool4o`0002gooooo
1_l0001Rooooo`005oooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo0ol0000]ooooo`Go0000;_ooool4o`0002cooooo1_l0
001Pooooo`005oooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001Sooooo00?o0000
ooooooooool09_ooool4o`0002gooooo1Ol0000^ooooo`?o0000;Oooool6o`0005gooooo000Goooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000?oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Yooooo`?o0000;Oooool6o`00
02gooooo1?l0000]ooooo`Ko0000F_ooool001Kooooo0_l00004ooooo`;o00001_ooool00ol0003o
ooooooooo`06ooooo`;o00004Oooool9o`0002gooooo1?l0000]ooooo`Go0000;_ooool3o`0002ko
oooo1_l0001Gooooo`005_ooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo
1_l00002ooooo`Go00001?ooool5o`0002gooooo1?l0000]ooooo`Go0000;_ooool4o`0002kooooo
1?l0001Fooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00gooooo0ol000000ooooooo0000ooooo`06ooooo`Go0000;_oo
ool3o`0002kooooo1Ol0000]ooooo`Co0000;_ooool4o`0005Cooooo000Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o00003Oooool3
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05o`0002gooooo0ol0000^
ooooo`Go0000;_ooool3o`0002oooooo0ol0001Booooo`005_ooool00ol0003oooooooooo`02oooo
o`;o00001Oooool2o`0000Oooooo00?o0000ooooooooool02oooool2o`0000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`Co0000;Oooool4o`0002kooooo1?l0000^oooo
o`Co0000;_ooool4o`0004oooooo000Eooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`;o
00001_ooool2o`0000cooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool4o`0002kooooo0ol0000^ooooo`Go0000;Oooool4o`0002kooooo1?l0001=ooooo`00
5Oooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o0000
2oooool2o`0000Gooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`07ooooo`Co0000
;_ooool3o`0002oooooo1?l0000^ooooo`Co0000;_ooool4o`0004[ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`;o00001oooool00ol0003oooooooooo`0:ooooo`;o00003ooo
ool00ol0003oooooooooo`09ooooo`Co0000;_ooool3o`0002oooooo1?l0000^ooooo`Co0000;_oo
ool4o`0004Sooooo000Eooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o00001_ooool2
o`0000_ooooo0_l0000@ooooo`03o`000?oooooooooo00_ooooo1?l0000^ooooo`?o0000;oooool4
o`0002kooooo1?l0000^ooooo`Co0000A_ooool001Cooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0_l0000Aooooo`03o`000?oooooooooo
00gooooo1?l0000^ooooo`?o0000;oooool3o`0002oooooo1?l0000^ooooo`?o0000AOooool001Co
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Wo
oooo0_l0000Aooooo`;o00004?ooool4o`0002kooooo0ol0000_ooooo`?o0000;oooool4o`0002ko
oooo0ol00013ooooo`005?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Kooooo
0_l0000:ooooo`;o00004_ooool00ol0003oooooooooo`0@ooooo`Co0000;oooool3o`0002oooooo
0ol0000_ooooo`?o0000;oooool3o`00047ooooo000Dooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`;o00004oooool00ol0003ooooooooo
o`0Booooo`Co0000;oooool2o`00033ooooo0ol0000_ooooo`?o0000;oooool2o`00043ooooo000C
ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0001?ooooo00?o0000
ooooooooool05?ooool4o`0002oooooo0_l0000`ooooo`?o0000;oooool3o`0002oooooo0_l0000n
ooooo`004oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l00009oooo
o`;o00005?ooool00ol0003oooooooooo`0Fooooo`Co0000;oooool2o`00033ooooo0_l0000`oooo
o`?o0000;_ooool3o`0003cooooo000Cooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o
00002Oooool2o`0001Cooooo00?o0000ooooooooool06?ooool3o`0002oooooo0ol0000_ooooo`?o
0000<?ooool2o`0002oooooo0_l0000kooooo`004oooool00ol0003oooooooooo`02ooooo`;o0000
1Oooool2o`0000Gooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Iooooo`Co0000
;oooool2o`00033ooooo0_l0000aooooo`;o0000;oooool2o`0003Wooooo000Cooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o00005Ooo
ool00ol0003oooooooooo`0Kooooo`?o0000;oooool3o`0002oooooo0ol0000`ooooo`;o0000<?oo
ool2o`0003Oooooo000Cooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001_ooool2
o`0000Wooooo00?o0000ooooooooool05?ooool2o`0001gooooo1?l0000_ooooo`?o0000;oooool3
o`0002oooooo0ol0000_ooooo`;o0000=_ooool001;ooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo0_l0000Fooooo`03o`000?oooooooooo
01kooooo0ol0000_ooooo`?o0000;oooool3o`00033ooooo0_l0000`ooooo`;o0000=?ooool001;o
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`;o0000;oooool3o`0002oo
oooo0ol0000`ooooo`;o0000<?ooool2o`0003?ooooo000Booooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool08Oooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`00033ooooo
0_l0000booooo`004_ooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l0
0008ooooo`;o00005oooool00ol0003oooooooooo`0Rooooo`;o0000<?ooool2o`00033ooooo0_l0
000aooooo`03o`000?oooooooooo02kooooo0_l0000aooooo`004_ooool2o`0000?ooooo0_l00004
ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00005oooool00ol0003oooooooooo`0S
ooooo`;o0000<?ooool2o`00033ooooo0_l0000aooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0;_ooool001;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Toooo
o`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002oooooo000Booooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`;o
00006?ooool00ol0003oooooooooo`0Uooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o
0000<?ooool2o`0002kooooo000Booooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
1_ooool00ol0003oooooooooo`06ooooo`;o00006?ooool2o`0002Oooooo0_l0000`ooooo`;o0000
<?ooool2o`00033ooooo0_l0000`ooooo`;o0000;Oooool001;ooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001Sooooo00?o0000ooooooooool09ooo
ool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`00033ooooo0_l0000/ooooo`004_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`;o0000<?ooool2
o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002_ooooo000Aooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool2o`00
01Wooooo00?o0000ooooooooool0:Oooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`00
033ooooo0_l0000Zooooo`003oooool01Oo^k^ko<S8bo`000?l0003ok^k^00?ooooo00Co0000oooo
oolQ8B7o8B4Q0_ooool01?l0003ooooooooooom4A4@2o`000003oc8b<_l0003ooooo00Oooooo0_l0
000Iooooo`03o`000?oooooooooo02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000?ooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08_ooool00ol0003oooooooooo`04o`000003
oa0@4?oooooooooo02?ooooo1?l000000ol@413o0000o`000002ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM02;ooooo00?o0000ooooooooool01Ol0000Uooooo`Oo00000oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`003oooool01OmgMgOoV9RHo`000?l0003o
MgMg00?ooooo00Go0000oooooolQ8B7o8B4Qooooo`02o`0000Gooooo00?oMgMgo`000?ooool01ooo
ool2o`0001Wooooo00?o0000ooooooooool09?ooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o
00000_ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08_ooool01Ol0003ooooooooooooooooo0000
02Wooooo00?o0000ooooooooool00_l00002ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Roooo
o`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A00Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0_l00003ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Iooooo`001oooool6o`0000;ooooo00Go
410@ooooool0003o0000oa0@4003ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`05oa0@
4?ooooooooooooooool@41000_ooool2o`0000cooooo00?o0000ooooooooool08Oooool2o`0000;o
oooo00?o0000ooooooooool09oooool01?l0003oooooooooooooool2o`0000cooooo00?o0000oooo
ooooool08_ooool01Ol0003ooooooiRHV?lQ8B7ok^k^02Oooooo00?oV9RHob4Q8Oo^k^h00_ooool2
o`0000gooooo00?o0000ooooooooool06?ooool000oooooo00?o0000ooooool000000_l00003oooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`03ogMgMol0003ooooo00Oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000000oooool2
o`0000[ooooo00?oMgMgoc8b<_ooool08oooool2o`000003ooooool0003ooooo02Sooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo00?oMgMgoc8b<_ooool08oooool2o`000004oooooonHV9So
8B4Qonk^kROooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`0000_ooooo00?oMgMgoc8b<_ooool06Ooo
ool000oooooo00?o0000ooooool000000_l00003ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`03o`000?lQ8B7o000000;o00002?ooool00ol0003oooooooooo`0Booooo`Co00000_ooool0
0ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000000oooool2o`0000Oooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Tooooo`;o000000?oooooo`000?ooool0:?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Uooooo`05
o`000?ooooooooooogMgMomVIVH0:?ooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo
00Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`003oooool01Ol@413oooooo`000?oooooo
410@00;ooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000Sooooo00?o0000
ooooooooool04Oooool01?l0003oooooooooooooool2o`000003ooooool0003o000002Gooooo00Go
410@oooooooooooooooooa0@4004ooooo`;o00001_ooool00ol0003oooooooooo`0Wooooo`?o0000
:Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Wooooo`;o0000
0_ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003o
ooooooooo`0Looooo`003oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00;ooooo0_l00004ooooo`;o
00000_ooool00ol0003oooooooooo`02o`0000Oooooo0_l0000Booooo`03o`000?oooooooooo00?o
oooo0ol0000Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Kooooo00?o0000oooo
ooooool09oooool3o`0002Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000oooo
ooooool09oooool2o`000003oooooonHV9So410@02Gooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool000oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`;o00001?ooool2o`0000;ooooo1Ol00007ooooo`;o00004Oooool2
o`0000Kooooo0_l0000Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Gooooo1?l0
000Vooooo`03oeEEEOl0003o000002Oooooo00?oEEEEofIVI_l000001_ooool2o`0000Gooooo1?l0
000Vooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`09Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo0_l00006ooooo`Co00006oooool0017ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo
0_l0000`ooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002Gooooo
000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`;o00001oooool2o`00017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0^ooooo`;o0000<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Sooooo`004Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool0017ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0_ooooo`;o00004_ooool2o`0000;ooooo0_l0000<oooo
o`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0_ooooo`;o0000<Oooool00ol0003oooooooooo`0@ooooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool000Woooooool00013o`0000cooooo00CogMgMo`00
0?l@413oc<c<3Oooool000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o
410@onk^kPgooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b3Oooool0017ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`;o00002?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04Oooool2o`0000;ooooo0_l0
000<ooooo`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`;o00004Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0S
ooooo`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`;o00004Oooool00ol0003oooooooooo`05oooo
o`;o0000<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02?ooooo000Aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`;o
00001oooool2o`00017ooooo0_l00006ooooo`;o0000<?ooool2o`00037ooooo00?o0000oooooooo
ool0;_ooool2o`00037ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Sooooo`00
4Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o0000
1oooool2o`00017ooooo0_l00006ooooo`;o0000<?ooool2o`00033ooooo00?o0000ooooooooool0
;oooool2o`00033ooooo0_l0000`ooooo`;o00009Oooool0017ooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l00005ooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`;o00001?oo
ool00ol0003oooooo`00000_ooooo`;o0000<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Tooooo`004Oooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`03o`000?oooooo
oooo017ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000;_ooool2o`00033ooooo0_l0
000`ooooo`;o0000<Oooool00ol0003oooooooooo`0^ooooo`;o00009_ooool0017ooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool00ol0003oooooooooo`0B
ooooo`?o00000oooool00ol0003oooooooooo`0/ooooo`;o0000<Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo0_l0000`ooooo`03o`000?oooooooooo02Gooooo000Aoooo
o`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0/ooooo`;o0000<?ooool2o`00033ooooo0_l0000`oooo
o`;o0000<?ooool2o`0002Oooooo000Aooooo`;o00000oooool2o`0000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0:oooool2o`00037ooooo00?o0000ooooooooool0;_ooool2o`00037ooooo00?o0000oooooooo
ool0;_ooool2o`0002Sooooo000Aooooo`;o00000oooool2o`0000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`;o00006Oooool00ol0003oooooooooo`0[ooooo`;o0000
<?ooool00ol0003oooooooooo`0_ooooo`;o0000<?ooool2o`00033ooooo00?o0000ooooooooool0
9oooool0017ooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Iooooo`03o`000?oooooooooo02[ooooo0_l0000`ooooo`03o`000?oo
oooooooo02oooooo0_l0000`ooooo`;o0000<?ooool2o`0002Wooooo000Aooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00006Oooool0
0ol0003oooooooooo`0Yooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2
o`0002[ooooo000Aooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo0_l00007ooooo`;o00006Oooool00ol0003oooooooooo`0Xooooo`;o0000<?ooool2o`00
033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002_ooooo000Aooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool2o`0000Sooooo00?o0000ooooooooool05oooool2o`0002So
oooo0_l0000`ooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000;?ooool001;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000Sooooo
0_l0000Hooooo`03o`000?oooooooooo02Kooooo0_l0000_ooooo`?o0000<?ooool2o`00033ooooo
0_l0000_ooooo`?o0000;Oooool001;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`;o00006?ooool00ol0003ooooooooo
o`0Tooooo`?o0000;oooool3o`0002oooooo0ol0000`ooooo`03o`000?oooooooooo02kooooo0ol0
000^ooooo`004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00006
ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`03o`000?oooooooooo02?ooooo0ol0000_
ooooo`?o0000;oooool3o`0002oooooo0_l0000`ooooo`?o0000;oooool001;ooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02;ooooo0ol0000_ooooo`?o0000;oooool3o`0002oooooo0_l0000`oooo
o`;o0000<Oooool001;ooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o
00002?ooool2o`0001Oooooo00?o0000ooooooooool08Oooool3o`0002kooooo0ol0000`ooooo`;o
0000<?ooool2o`00033ooooo0_l0000booooo`004_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0000Gooooo`03o`00
0?oooooooooo01oooooo0ol0000_ooooo`?o0000;oooool3o`00033ooooo0_l0000_ooooo`?o0000
<oooool001;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`?o0000;ooo
ool2o`00033ooooo0ol0000`ooooo`;o0000;oooool2o`0003Gooooo000Booooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00005_ooool0
0ol0003oooooooooo`0Looooo`Co0000;oooool2o`00033ooooo0ol0000_ooooo`;o0000<?ooool2
o`0003Kooooo000Cooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001_ooool00ol0
003oooooooooo`07ooooo`;o00005_ooool2o`0001cooooo0ol0000_ooooo`;o0000<Oooool2o`00
033ooooo0_l0000`ooooo`;o0000=oooool001?ooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool06Oooool3o`00033ooooo0_l0000`ooooo`?o0000;oooool3o`0002oo
oooo0ol0000hooooo`004oooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool2o`0001Gooooo00?o0000ooooooooool06?ooool3o`0002oooooo
0_l0000aooooo`;o0000;oooool3o`0002oooooo0ol0000jooooo`004oooool2o`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`?o0000;oooool3o`00033ooooo0_l0
000`ooooo`;o0000<?ooool3o`0003_ooooo000Cooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00001_ooool2o`0000Wooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo0ol0000_
ooooo`?o0000<?ooool3o`0002oooooo0_l0000`ooooo`?o0000?Oooool001?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00002_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo0ol0000^ooooo`?o0000<?ooool3o`0002oooooo0_l0000`oooo
o`?o0000?oooool001?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo0_l0000Cooooo`03o`000?oooooooooo017ooooo0ol0000_ooooo`?o
0000<?ooool2o`0002oooooo0ol0000_ooooo`?o0000@Oooool001Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03oooool4o`0002kooooo0ol0000`ooooo`?o0000
;_ooool3o`0002oooooo0ol00013ooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000Kooooo0_l0000:ooooo`;o00004_ooool2o`0000kooooo1?l0000^ooooo`Co0000;ooo
ool3o`0002kooooo1?l0000_ooooo`?o0000A?ooool001Cooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo0_l0000Aooooo`03o`000?oooooo
oooo00_ooooo1?l0000^ooooo`Co0000;oooool3o`0002kooooo1?l0000_ooooo`?o0000A_ooool0
01Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o00002oooool2o`00
013ooooo00?o0000ooooooooool02Oooool4o`0002kooooo1?l0000^ooooo`Co0000;_ooool4o`00
02oooooo0ol00018ooooo`005Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000<ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`Co0000;Oooool5o`0002ko
oooo1?l0000^ooooo`?o0000;oooool4o`0004[ooooo000Eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool2o`0000Oooooo0_l0000<ooooo`;o00003_ooool00ol0003ooooo
ooooo`04ooooo`Go0000;Oooool5o`0002kooooo1?l0000^ooooo`?o0000;oooool4o`0004cooooo
000Eooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0_l0
000=ooooo`;o00003Oooool00ol0003oooooooooo`02ooooo`Go0000;Oooool4o`0002oooooo1?l0
000^ooooo`?o0000;_ooool5o`0004kooooo000Eooooo`;o00001?ooool2o`0000Gooooo0_l00007
ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`04o`0002gooooo1Ol0000^ooooo`Go0000;_ooool3o`0002kooooo1Ol0001@
ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool2o`0000kooooo1?l000000ooooooo0000ooooo`06ooooo`Go0000;Oooool5o`00
02kooooo1?l0000_ooooo`?o0000;Oooool5o`0005?ooooo000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03_ooool4o`0000Ko
oooo1?l0000/ooooo`Ko0000;Oooool5o`0002kooooo0ol0000^ooooo`Go0000EOooool001Kooooo
0_l00004ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00004Oooool:o`0002cooooo
1_l0000]ooooo`Go0000;_ooool3o`0002gooooo1Ol0001Hooooo`005_ooool2o`0000Cooooo0_l0
0006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Oooooo1ol0000/ooooo`Go0000;_ooool4o`0002gooooo1Ol0
001Jooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`;o00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo1_l0000/
ooooo`Go0000;oooool3o`0002gooooo1_l0001Looooo`005oooool2o`0000Cooooo0_l00005oooo
o`;o00002?ooool2o`00013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Roooo
o`Ko0000;?ooool6o`0002kooooo0ol0000^ooooo`Ko0000G_ooool001Oooooo0_l00004ooooo`;o
00001_ooool2o`0000Oooooo0_l0000>ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool08?ooool5o`0002gooooo1Ol0000^ooooo`Co0000;Oooool6o`00067ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l0000Gooooo`03o`00
0?oooooooooo01gooooo1Ol0000]ooooo`Ko0000;_ooool3o`0002kooooo1Ol0001Tooooo`006?oo
ool2o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`0001Kooooo00?o0000ooooooooool06ooo
ool4o`0002gooooo1ol0000]ooooo`?o0000;_ooool5o`0006Oooooo000Hooooo`;o00001?ooool2
o`0000Kooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Hooooo`Co0000;Oooool7
o`0002gooooo1?l0000^ooooo`Co0000J_ooool001Sooooo0_l00005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool2o`0001Gooooo0_l0000Gooooo`Co0000;Oooool6o`00
02gooooo1?l0000^ooooo`Co0000KOooool001Wooooo00?o0000ooooooooool00oooool2o`0000Ko
oooo0_l00009ooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`Co0000;Oooool6o`0002go
oooo1?l0000^ooooo`Co0000L?ooool001Wooooo0_l00004ooooo`;o00001oooool2o`0000[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`Co0000;?ooool6o`0002gooooo
1?l0000^ooooo`Co0000Loooool001Wooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0
000Aooooo`03o`000?oooooooooo00kooooo1?l0000/ooooo`Ko0000;Oooool4o`0002gooooo1Ol0
001fooooo`006_ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0000_ooooo0_l0000@
ooooo`03o`000?oooooooooo00_ooooo1?l0000/ooooo`Ko0000;?ooool5o`0002gooooo1Ol0001i
ooooo`006_ooool2o`0000Gooooo0_l00006ooooo`;o00003?ooool3o`0000kooooo00?o0000oooo
ooooool01oooool5o`0002cooooo1_l0000/ooooo`Go0000;?ooool6o`0007cooooo000Kooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`;o00003?ooool3o`0000gooooo00?o0000oooooooo
ool01?ooool5o`0002cooooo1_l0000/ooooo`Go0000;?ooool6o`0007oooooo000Kooooo`03o`00
0?oooooooooo00Cooooo0_l00006ooooo`?o00003Oooool3o`0000_ooooo00?o0000ooooooooool0
1_l0000/ooooo`Ko0000:oooool6o`0002cooooo1_l00022ooooo`006oooool2o`0000Kooooo00?o
0000ooooooooool01Oooool2o`0000oooooo1?l00008ooooo`Ko0000;?ooool6o`0002_ooooo1Ol0
000/ooooo`Oo0000QOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000@
ooooo`co0000;?ooool6o`0002cooooo1Ol0000/ooooo`Oo0000R?ooool001cooooo0_l00006oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xoooo
o`Ko0000:oooool5o`0002cooooo2?l0002;ooooo`007Oooool00ol0003oooooooooo`04ooooo`;o
00001oooool2o`0001Wooooo00?o0000ooooooooool09?ooool7o`0002_ooooo1?l0000/ooooo`So
0000Soooool001gooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`03o`00
0?oooooooooo027ooooo1_l0000[ooooo`Co0000;Oooool7o`0009?ooooo000Mooooo`;o00001_oo
ool2o`0000Sooooo0_l0000Gooooo`03o`000?oooooooooo01kooooo1_l0000Zooooo`Go0000;?oo
ool7o`0009Oooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00005_ooool0
0ol0003oooooooooo`0Jooooo`Oo0000:Oooool5o`0002cooooo2?l0002Jooooo`007_ooool2o`00
00Oooooo00?o0000ooooooooool01oooool3o`0001Cooooo00?o0000ooooooooool05oooool6o`00
02Wooooo1_l0000/ooooo`So0000WOooool001oooooo0_l00006ooooo`;o00002_ooool2o`0001?o
oooo00?o0000ooooooooool04_ooool7o`0002Wooooo1ol0000[ooooo`Wo0000X?ooool001oooooo
0_l00007ooooo`03o`000?oooooooooo00Wooooo0ol0000Aooooo`;o00003oooool7o`0002[ooooo
1_l0000[ooooo`Wo0000Y?ooool0023ooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo0ol0
000@ooooo`03o`000?oooooooooo00_ooooo1_l0000Zooooo`Oo0000:oooool7o`000:Wooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool3o`0000oooooo00?o0000
ooooooooool01oooool6o`0002[ooooo2?l0000Zooooo`Oo0000[Oooool0027ooooo0_l00007oooo
o`;o00003?ooool4o`0000cooooo00?o0000ooooooooool00_ooool7o`0002[ooooo2?l0000Zoooo
o`Oo0000/Oooool002;ooooo0_l00007ooooo`;o00003Oooool5o`0000Wooooo2?l0000Zooooo`Oo
0000;?ooool5o`000;Kooooo000Sooooo`03o`000?oooooooooo00Kooooo0_l0000>ooooo`Oo0000
0_ooool8o`0002Wooooo1ol0000/ooooo`Go0000^_ooool002?ooooo0_l00008ooooo`;o00004Ooo
ool9o`0002Wooooo1_l0000/ooooo`Ko0000__ooool002Cooooo0_l00008ooooo`;o00006?ooool0
0ol0003oooooooooo`0Sooooo`Ko0000;?ooool5o`000<?ooooo000Tooooo`;o00002Oooool2o`00
01Oooooo0_l0000Pooooo`Ko0000:oooool6o`000<Oooooo000Uooooo`;o00002Oooool2o`0001Ko
oooo00?o0000ooooooooool06oooool6o`0002_ooooo1_l0003;ooooo`009_ooool2o`0000Wooooo
0ol0000Dooooo`03o`000?oooooooooo01Oooooo1Ol0000[ooooo`So0000c_ooool002Oooooo0_l0
000:ooooo`;o00004oooool00ol0003oooooooooo`0Booooo`Go0000;?ooool8o`000=;ooooo000X
ooooo`;o00002_ooool3o`00017ooooo00?o0000ooooooooool03_ooool5o`0002_ooooo2Ol0003F
ooooo`00:Oooool00ol0003oooooooooo`09ooooo`?o00004?ooool00ol0003oooooooooo`0:oooo
o`Go0000:_ooool:o`000=[ooooo000Zooooo`;o00002oooool4o`0000;ooooo1Ol00006ooooo`03
o`000?oooooooooo00Kooooo1Ol0000Zooooo`Wo0000goooool002_ooooo0_l0000<ooooo`Go0000
00Co8B4Qonk^k_ooooooA4A41_ooool01?l0003oooooooooooooool6o`0002Wooooo2Ol0003Toooo
o`00;?ooool2o`0000kooooo1_l00004ooooo`So0000:Oooool9o`000>Sooooo000]ooooo`;o0000
4?ooool00onHV9So0000o`000007o`0002Wooooo2Ol0003]ooooo`00;_ooool2o`00013ooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Rooooo`Wo0000l_ooool002oooooo0ol0000?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool8o`000?Oooooo000`oooo
o`?o00002_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool06Oooool8
o`000?cooooo000booooo`?o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool05?ooool9o`000?oooooo0Oooool003?ooooo1?l0000Aooooo`03o`000?oooooooooo
013ooooo2?l0003oooooo`Kooooo000dooooo`Co00004?ooool00ol0003oooooooooo`0;ooooo`So
0000ooooool;ooooo`00=oooool4o`0000gooooo00?o0000ooooooooool01_ooool7o`000?oooooo
4Oooool003Sooooo1_l0000:ooooo`;o000000?oooooo`000?l000001_l0003ooooooaKooooo000l
oooooa?o0000oooooolJooooo`00@?ooool9o`000?oooooo8?ooool004Sooooo00?o0000oooooooo
ool0oooooolNooooo`00B?ooool00ol0003oooooooooo`3ooooooakooooo0018ooooo`03o`000?oo
oooooooo0?oooooo7_ooool004Sooooo00?o0000ooooooooool0oooooolNooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00A_ooool01?l@413o0000o`000?l0
003ooooooaoooooo0017ooooo`03o`000?oooooooooo0?oooooo7oooool004Oooooo00?o0000oooo
ooooool0oooooolOooooo`00Aoooool01_l0003oMgMgo`000?l0003oEEEEonk^k_oooooo7?ooool0
04Oooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEGooooooacooooo0017ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0oooooolJooooo`00Aoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0?oooooo6_ooool004Oooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVKo
oooooacooooo0016ooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0oooooolKoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "These characteristics show particles falling toward ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", then rapidly reversing their velocities and returning to their initial \
heights. There is no damping in the equations of motion, so each particle in \
the gas continues to bounce off the bottom of the container forever. Unlike \
the  example of mixing dye presented earlier, the characteristics here are \
not chaotic. Each characteristic curve is parametrized by  the constant \
energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " of particles on the curve. The particle motion is periodic, with a \
frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " that depends on the energy:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Omega]\_o = \(\[Omega]\_o\)(
        E)\)]]], "NumberedEquation",
  CellTags->"(7.1.22)"],

Cell[TextData[{
  "Even though the motion is not chaotic, an initial distribution of \
particles will rapidly filament and mix. This kind of nonchaotic mixing is \
called ",
  StyleBox[" phase mixing",
    FontSlant->"Italic"],
  ".  The  phase mixing is due to particles moving around their energy \
surfaces at different frequencies. The particles get ",
  StyleBox["out of phase",
    FontSlant->"Italic"],
  " with one another in their periodic motion. An initially localized patch \
of phase-space density becomes stretched and filamented due to the range of \
frequencies within the patch."
}], "Text",
  CellTags->"i:8"],

Cell[TextData[{
  "\tWe can see this phase mixing by following ",
  Cell[BoxData[
      \(TraditionalForm\`M = 500\)]],
  " particles in their motion. We choose the particles with random initial \
velocities and positions in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 - 1/2\)]],
  ", and display their subsequent trajectories in Cell ",
  ButtonBox["7.7",
    ButtonData:>"Cell 7.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(M = 500;\)\), "\n", 
    \(\(\(particlepos[t1_]\  = 
        Table[c[0.5  Random[], 0.5  Random[]], {M}] /. t \[Rule] t1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Evaluate[particlepos[t1]], 
          PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
          AspectRatio \[Rule] 1, AxesLabel \[Rule] {"\<x\>", "\<p\>"}], {t1, 
          0, 50,  .4}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.7"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62963 .6271 Mdot
.65149 .5696 Mdot
.50576 .51665 Mdot
.52383 .6662 Mdot
.58363 .56646 Mdot
.62397 .60593 Mdot
.5048 .61315 Mdot
.72993 .50499 Mdot
.67404 .69205 Mdot
.552 .61242 Mdot
.54911 .64032 Mdot
.71963 .6004 Mdot
.66948 .51323 Mdot
.56814 .5308 Mdot
.66372 .74658 Mdot
.54431 .61459 Mdot
.58009 .68011 Mdot
.67034 .50867 Mdot
.57529 .56696 Mdot
.69041 .50368 Mdot
.65125 .62491 Mdot
.63842 .64126 Mdot
.60215 .73459 Mdot
.66878 .54086 Mdot
.68267 .72136 Mdot
.60064 .51006 Mdot
.51894 .72478 Mdot
.55633 .64547 Mdot
.68885 .54467 Mdot
.63599 .6368 Mdot
.61356 .72771 Mdot
.69558 .63313 Mdot
.71231 .6028 Mdot
.55716 .74187 Mdot
.61016 .61821 Mdot
.63838 .70101 Mdot
.67749 .64685 Mdot
.53773 .69095 Mdot
.65855 .67207 Mdot
.7314 .54548 Mdot
.7197 .62739 Mdot
.59541 .65867 Mdot
.60614 .64968 Mdot
.64983 .52554 Mdot
.64383 .54688 Mdot
.59267 .53367 Mdot
.53367 .67867 Mdot
.70429 .58266 Mdot
.60617 .53182 Mdot
.66656 .64171 Mdot
.69762 .60975 Mdot
.68516 .59624 Mdot
.72792 .73236 Mdot
.58975 .68757 Mdot
.62179 .58268 Mdot
.68992 .66202 Mdot
.72796 .5358 Mdot
.59725 .62835 Mdot
.69429 .60713 Mdot
.64295 .54569 Mdot
.58812 .57531 Mdot
.72639 .65398 Mdot
.64049 .71555 Mdot
.54124 .55774 Mdot
.66257 .73319 Mdot
.70149 .62017 Mdot
.54079 .65051 Mdot
.51157 .70815 Mdot
.56283 .61472 Mdot
.66432 .5798 Mdot
.61854 .50759 Mdot
.52137 .53411 Mdot
.53042 .68228 Mdot
.54497 .63013 Mdot
.63993 .71673 Mdot
.50374 .57239 Mdot
.72736 .73353 Mdot
.55225 .70222 Mdot
.68657 .58302 Mdot
.54069 .74407 Mdot
.62374 .7183 Mdot
.62636 .66427 Mdot
.5052 .71071 Mdot
.605 .63017 Mdot
.72478 .52843 Mdot
.56002 .50004 Mdot
.58485 .56171 Mdot
.55628 .67765 Mdot
.60749 .57817 Mdot
.50403 .72543 Mdot
.67092 .74515 Mdot
.71334 .73136 Mdot
.54718 .52685 Mdot
.58698 .56709 Mdot
.54198 .56614 Mdot
.73198 .68692 Mdot
.56721 .5377 Mdot
.67196 .68688 Mdot
.73236 .726 Mdot
.61568 .50924 Mdot
.62487 .64782 Mdot
.61165 .53381 Mdot
.70395 .65267 Mdot
.64831 .55245 Mdot
.65677 .62582 Mdot
.56133 .73537 Mdot
.61479 .55969 Mdot
.57935 .54845 Mdot
.54758 .52198 Mdot
.65739 .61156 Mdot
.56522 .54599 Mdot
.54171 .60232 Mdot
.69035 .64816 Mdot
.68006 .56851 Mdot
.7364 .74549 Mdot
.53175 .51606 Mdot
.57963 .61967 Mdot
.72042 .53069 Mdot
.71484 .55998 Mdot
.64107 .73224 Mdot
.66726 .538 Mdot
.73369 .62068 Mdot
.60204 .74201 Mdot
.69198 .51836 Mdot
.66168 .59385 Mdot
.51192 .69985 Mdot
.67528 .59836 Mdot
.73017 .68379 Mdot
.59565 .72869 Mdot
.50975 .6531 Mdot
.63081 .66871 Mdot
.61867 .67086 Mdot
.71355 .63071 Mdot
.63499 .55018 Mdot
.61151 .6387 Mdot
.69301 .53182 Mdot
.69983 .54485 Mdot
.68109 .58198 Mdot
.52454 .69649 Mdot
.70093 .64819 Mdot
.67889 .7178 Mdot
.69118 .74509 Mdot
.54809 .54909 Mdot
.57251 .57423 Mdot
.58454 .66838 Mdot
.68752 .52405 Mdot
.72303 .52968 Mdot
.74451 .74223 Mdot
.5232 .73482 Mdot
.56341 .66025 Mdot
.74866 .53833 Mdot
.61249 .51206 Mdot
.56976 .57054 Mdot
.67131 .51697 Mdot
.52168 .52145 Mdot
.5988 .69274 Mdot
.68714 .60307 Mdot
.66128 .66869 Mdot
.71411 .5734 Mdot
.66677 .67646 Mdot
.6909 .58857 Mdot
.60336 .5162 Mdot
.69224 .55024 Mdot
.74087 .50414 Mdot
.62248 .7297 Mdot
.56957 .73717 Mdot
.6008 .70825 Mdot
.72077 .54444 Mdot
.66367 .60518 Mdot
.55949 .62575 Mdot
.69956 .53179 Mdot
.64271 .6993 Mdot
.50866 .69321 Mdot
.53935 .68309 Mdot
.56642 .64298 Mdot
.54848 .67895 Mdot
.69394 .66327 Mdot
.72891 .69177 Mdot
.59313 .70502 Mdot
.50814 .64734 Mdot
.67947 .59984 Mdot
.69865 .52158 Mdot
.72991 .56805 Mdot
.55594 .57229 Mdot
.72125 .62484 Mdot
.51659 .6392 Mdot
.65483 .73186 Mdot
.71811 .71025 Mdot
.71089 .56859 Mdot
.7392 .51848 Mdot
.61776 .61357 Mdot
.73106 .62115 Mdot
.68829 .51373 Mdot
.5324 .59956 Mdot
.70838 .69568 Mdot
.72646 .52727 Mdot
.73714 .57084 Mdot
.70987 .63807 Mdot
.5823 .58898 Mdot
.74176 .67782 Mdot
.62141 .52039 Mdot
.50256 .65934 Mdot
.50365 .65682 Mdot
.52151 .53819 Mdot
.56536 .64308 Mdot
.7391 .68863 Mdot
.60698 .6974 Mdot
.51264 .66136 Mdot
.61984 .62656 Mdot
.55277 .52329 Mdot
.53754 .53759 Mdot
.56101 .59547 Mdot
.66613 .5172 Mdot
.55845 .68613 Mdot
.66247 .61038 Mdot
.53694 .64793 Mdot
.59711 .7173 Mdot
.54784 .7093 Mdot
.74013 .51989 Mdot
.53519 .54794 Mdot
.62029 .64333 Mdot
.73242 .52465 Mdot
.58275 .60574 Mdot
.67141 .67918 Mdot
.66663 .58854 Mdot
.61297 .74305 Mdot
.50415 .72816 Mdot
.57602 .59512 Mdot
.65704 .51086 Mdot
.52819 .63582 Mdot
.66691 .74097 Mdot
.74299 .58788 Mdot
.54662 .59764 Mdot
.51057 .56323 Mdot
.71386 .7419 Mdot
.58916 .63405 Mdot
.54724 .65335 Mdot
.72619 .641 Mdot
.54308 .67519 Mdot
.65017 .54589 Mdot
.63604 .66433 Mdot
.62198 .66007 Mdot
.71913 .67337 Mdot
.62899 .57219 Mdot
.67252 .57573 Mdot
.61842 .50896 Mdot
.70865 .58383 Mdot
.52926 .62491 Mdot
.66142 .68048 Mdot
.55306 .7339 Mdot
.61833 .50528 Mdot
.6529 .68802 Mdot
.73229 .59095 Mdot
.53091 .52794 Mdot
.51316 .66758 Mdot
.65193 .70575 Mdot
.59064 .59185 Mdot
.53351 .69679 Mdot
.63199 .50802 Mdot
.50425 .57188 Mdot
.72057 .57754 Mdot
.70119 .58798 Mdot
.60223 .57226 Mdot
.54829 .64996 Mdot
.61994 .73131 Mdot
.51738 .62202 Mdot
.60679 .56373 Mdot
.61545 .66626 Mdot
.51615 .72187 Mdot
.58194 .71947 Mdot
.63416 .71385 Mdot
.57769 .64759 Mdot
.66359 .63631 Mdot
.62651 .55962 Mdot
.56136 .56405 Mdot
.57822 .65965 Mdot
.69142 .58274 Mdot
.56084 .53764 Mdot
.58463 .51901 Mdot
.69539 .62137 Mdot
.56849 .54714 Mdot
.61345 .6519 Mdot
.68433 .58328 Mdot
.53576 .50431 Mdot
.52073 .69698 Mdot
.65925 .69469 Mdot
.70937 .63293 Mdot
.58104 .53504 Mdot
.51795 .55019 Mdot
.5202 .7474 Mdot
.68332 .53118 Mdot
.57481 .62602 Mdot
.61484 .73404 Mdot
.71136 .72412 Mdot
.68051 .65076 Mdot
.67561 .71982 Mdot
.65978 .70378 Mdot
.51636 .52513 Mdot
.70041 .57085 Mdot
.68532 .74009 Mdot
.68245 .52066 Mdot
.66512 .74269 Mdot
.74913 .73949 Mdot
.59032 .61667 Mdot
.63429 .50544 Mdot
.62896 .64254 Mdot
.70378 .60469 Mdot
.70335 .67273 Mdot
.544 .65091 Mdot
.68699 .6476 Mdot
.5936 .58005 Mdot
.50167 .65751 Mdot
.66114 .55939 Mdot
.58655 .66482 Mdot
.66201 .5699 Mdot
.74623 .54815 Mdot
.52772 .56446 Mdot
.61728 .65561 Mdot
.57394 .70977 Mdot
.66393 .73288 Mdot
.52993 .55886 Mdot
.72693 .58528 Mdot
.68634 .72881 Mdot
.72526 .67777 Mdot
.52519 .66942 Mdot
.63872 .51296 Mdot
.61318 .59952 Mdot
.64249 .71481 Mdot
.58546 .53506 Mdot
.52521 .5592 Mdot
.51153 .57529 Mdot
.61128 .57632 Mdot
.7316 .51643 Mdot
.63435 .74103 Mdot
.54526 .53762 Mdot
.65909 .56326 Mdot
.52007 .6182 Mdot
.52037 .5503 Mdot
.65688 .51868 Mdot
.62789 .5855 Mdot
.57142 .73362 Mdot
.60268 .5263 Mdot
.55989 .65833 Mdot
.74139 .69998 Mdot
.5783 .64191 Mdot
.60704 .70894 Mdot
.53304 .60429 Mdot
.69795 .64568 Mdot
.51297 .73609 Mdot
.67758 .59538 Mdot
.60609 .71741 Mdot
.54969 .50988 Mdot
.53467 .73379 Mdot
.69702 .73359 Mdot
.72477 .57546 Mdot
.70563 .53361 Mdot
.64647 .68355 Mdot
.59858 .57467 Mdot
.61344 .57926 Mdot
.65063 .67898 Mdot
.60046 .59316 Mdot
.72305 .5836 Mdot
.74437 .62575 Mdot
.67335 .57372 Mdot
.70971 .64196 Mdot
.72634 .59013 Mdot
.73493 .5665 Mdot
.52071 .55652 Mdot
.58846 .63295 Mdot
.67213 .73186 Mdot
.72502 .5537 Mdot
.5215 .55287 Mdot
.62456 .71053 Mdot
.54845 .71927 Mdot
.63019 .58479 Mdot
.62509 .64556 Mdot
.67048 .69283 Mdot
.64876 .55543 Mdot
.68554 .62633 Mdot
.62804 .74891 Mdot
.59708 .74338 Mdot
.70592 .51705 Mdot
.62206 .68969 Mdot
.68442 .71418 Mdot
.7475 .72915 Mdot
.63597 .7449 Mdot
.61731 .64436 Mdot
.51088 .59935 Mdot
.69683 .70153 Mdot
.61213 .54392 Mdot
.51129 .5752 Mdot
.73408 .54502 Mdot
.6642 .58182 Mdot
.52816 .52797 Mdot
.54214 .64214 Mdot
.59374 .56379 Mdot
.54464 .66299 Mdot
.70777 .56889 Mdot
.67733 .51862 Mdot
.69689 .71954 Mdot
.7305 .56709 Mdot
.58476 .67562 Mdot
.71921 .74188 Mdot
.60068 .6306 Mdot
.55501 .66006 Mdot
.57251 .60263 Mdot
.51287 .51792 Mdot
.72877 .53884 Mdot
.71822 .60494 Mdot
.521 .71995 Mdot
.54089 .58632 Mdot
.57411 .50041 Mdot
.56039 .51923 Mdot
.73935 .57479 Mdot
.59118 .52735 Mdot
.63867 .69419 Mdot
.53617 .61729 Mdot
.56616 .59156 Mdot
.5233 .59936 Mdot
.58739 .55272 Mdot
.55508 .74443 Mdot
.56638 .58277 Mdot
.51418 .65811 Mdot
.74227 .58236 Mdot
.70379 .63887 Mdot
.50292 .50756 Mdot
.61261 .61152 Mdot
.61425 .56337 Mdot
.57644 .74424 Mdot
.54809 .72181 Mdot
.55314 .64487 Mdot
.7107 .66909 Mdot
.74807 .65045 Mdot
.64432 .58632 Mdot
.73389 .74234 Mdot
.65205 .50396 Mdot
.53009 .60347 Mdot
.64913 .7464 Mdot
.66748 .74194 Mdot
.53488 .68303 Mdot
.59104 .7477 Mdot
.73679 .71122 Mdot
.53789 .60283 Mdot
.52609 .54213 Mdot
.53982 .70239 Mdot
.63177 .70581 Mdot
.55594 .71005 Mdot
.72972 .70185 Mdot
.52584 .60658 Mdot
.5806 .70545 Mdot
.60836 .61464 Mdot
.54571 .52242 Mdot
.51733 .61694 Mdot
.55892 .56121 Mdot
.72943 .51411 Mdot
.53283 .51908 Mdot
.68961 .56172 Mdot
.65105 .56327 Mdot
.63367 .60167 Mdot
.67133 .61142 Mdot
.60783 .74509 Mdot
.59073 .65598 Mdot
.74947 .63045 Mdot
.54502 .63355 Mdot
.73214 .51351 Mdot
.7361 .57235 Mdot
.50271 .74941 Mdot
.70328 .55327 Mdot
.56309 .68769 Mdot
.55222 .74 Mdot
.67942 .58602 Mdot
.63089 .62857 Mdot
.57159 .59092 Mdot
.54016 .7226 Mdot
.57213 .71048 Mdot
.74513 .58904 Mdot
.58999 .69696 Mdot
.50903 .5167 Mdot
.58728 .69756 Mdot
.55576 .71343 Mdot
.52419 .50987 Mdot
.50354 .72343 Mdot
.59477 .67385 Mdot
.62265 .59486 Mdot
.52317 .58293 Mdot
.58249 .62226 Mdot
.70105 .62245 Mdot
.58736 .53322 Mdot
.61106 .67549 Mdot
.57832 .51652 Mdot
.52378 .72793 Mdot
.52257 .55309 Mdot
.74959 .71806 Mdot
.51903 .57966 Mdot
.65483 .54421 Mdot
.64638 .73481 Mdot
.63165 .71128 Mdot
.56389 .61255 Mdot
.6806 .58882 Mdot
.72654 .57933 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0097ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0097ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool000Wooooo1?l000000ol@413ooooooooo
o`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`00
0?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01So
oooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool0
00Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001Sooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
00Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03
o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIV
o`00000Fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03
o`000?oooooooooo0:kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0
003oooooooooo`2_ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<oooo
o`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000Cooooo00Co0000
ooooool0003o00000oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool0
1_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo0ol00008ooooo`;o00006_ooool2o`000003ooooool0003ooooo00;o00001?ooool2o`0000[o
oooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool00:cooooo
0ol00005ooooo`;o00001_ooool2o`0000oooooo0_l00003ooooo`?o00000_ooool3o`0000[ooooo
0_l0000Aooooo`;o0000Koooool00:cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo0_l0
000?ooooo`;o00000_ooool4o`0000;ooooo1?l00004ooooo`;o00000oooool2o`0001;ooooo0_l0
001^ooooo`00[?ooool3o`0000Oooooo0_l0000=ooooo`;o00001oooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`?o0000K_ooool0
0:cooooo1_l00004ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00003oooool2o`000003ooooool0003o000000Co00000_ooool3o`0000?ooooo0_l00005oooo
o`?o000000?oooooo`000?l00000Joooool00:cooooo00?o0000ooooooooool00ol000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000[ooooo0_l00009oooo
o`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Wooooo0_l0001[ooooo`00[?ooool3o`0000;ooooo1?l00006ooooo`Co00005Oooool2o`0000Oo
oooo0_l00009ooooo`?o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00001[ooooo`00
[?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool3o`0000?ooooo1?l0000;ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000[ooooo0_l0000;ooooo`Co0000K_ooool00:cooooo00?o
0000ooooooooool01_ooool3o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0
003o000001Wooooo0_l00003ooooo`;o00001Oooool4o`00073ooooo002/ooooo`03o`000?oooooo
oooo00Cooooo0_l0000=ooooo`;o00001?ooool4o`0000?ooooo0ol0000Fooooo`;o000000?ooooo
o`000?l000001?l00003ooooo`?o0000LOooool00:cooooo00?o0000ooooooooool01?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`Co00000_ooool6o`0000?ooooo0ol0000Ioooo
o`;o00000_ooool2o`0000Kooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
00000oooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`Co00006Oooool2o`0001;o
oooo0_l00005ooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool01?ooool3o`0001_ooooo
0_l0000@ooooo`;o00004_ooool2o`0000Gooooo0_l0001Xooooo`00[?ooool00ol0003ooooooooo
o`05ooooo`;o00002oooool2o`0000kooooo0_l00008ooooo`Ko00002Oooool2o`0000;ooooo0_l0
0004ooooo`;o00000_ooool3o`0006gooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00002
ooooo`;o00001?ooool3o`0000;ooooo0_l0000Cooooo`Ko00002Oooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool3o`0000;ooooo0_l0001Yooooo`00[?ooool3o`0000;ooooo1?l00002oooo
o`;o00000_ooool2o`0000Gooooo0_l00002ooooo`Co00003_ooool2o`0000?ooooo0_l0000<oooo
o`;o00004?ooool2o`0006Wooooo002/ooooo`03o`000?oooooooooo00;ooooo1?l0000Cooooo`;o
00003_ooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l0001`ooooo`00
[?ooool00ol0003oooooooooo`03ooooo`Go00000_ooool2o`0002;ooooo0_l0000@ooooo`;o0000
1Oooool2o`00073ooooo002/ooooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`;o00001?oo
ool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`;o00001_oo
ool2o`0007Cooooo002/ooooo`03o`000?oooooooooo00;o00000oooool3o`0000Sooooo0ol00006
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003o00001oooool2o`0000Kooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`02
o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`00000Eooooo`Co0000KOoo
ool00:cooooo00?o0000ooooooooool02_ooool2o`0000Sooooo0ol000001?oooooo0000o`000?l0
000Dooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo1Ol00004ooooo`Go0000K?oo
ool00:cooooo0ol0000?ooooo`;o00000oooool2o`0000Sooooo0_l00007ooooo`;o00001_ooool2
o`000003ooooool0003o000000;ooooo1?l00005ooooo`Ko00001_ooool2o`0006cooooo002/oooo
o`Go00003Oooool2o`0000?ooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000Cooooo0_l0000=ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`?o0000Joooool0
0:cooooo00?o0000ooooooooool00_l000000ooooooo0000o`00000?ooooo`;o00001?ooool5o`00
0003ooooool0003o000000;o00003oooool2o`000003ooooool0003o000000gooooo1?l00003oooo
o`;o0000Joooool00:cooooo00?o0000ooooooooool00oooool3o`0000cooooo0_l00007ooooo`;o
00000oooool4o`000003ooooool0003o000000cooooo0_l00003ooooo`Ko00000_ooool2o`0000?o
oooo1?l00004ooooo`;o0000J_ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
0_l00006ooooo`;o00004Oooool5o`0000;ooooo0_l00005ooooo`;o00000oooool6o`0000;ooooo
0ol00003ooooo`?o00001?ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0
000<ooooo`;o00003Oooool3o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0ol00004ooooo`;o0000J_ooool00:cooooo00?o0000
ooooooooool04_ooool4o`0000;ooooo1?l0000Hooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000006ooooo`Co00000_ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo
01;ooooo1_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`00
00kooooo1?l0001^ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0000?o
oooo0_l00006ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`?o000000?oooooo`000?l0
0000OOooool00:cooooo1Ol00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
0_l0000?ooooo`;o00004_ooool6o`0000Wooooo0_l0001booooo`00[?ooool00ol0003ooooooooo
o`02o`0000;ooooo2?l00008ooooo`;o00003?ooool2o`0000Gooooo0_l0000=ooooo`Co00001ooo
ool4o`0007;ooooo002/ooooo`03o`000?oooooooooo00Gooooo1ol00008ooooo`;o00000_ooool2
o`0000_ooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000;o0000L_ooool00:cooooo00?o0000ooooooooool01Oooool2
o`00017ooooo0_l0000;ooooo`;o00002oooool3o`0000Sooooo1Ol00003ooooo`;o0000L_ooool0
0:cooooo0ol0000>ooooo`;o00000_ooool2o`0000kooooo0ol0000<ooooo`?o000000?oooooo`00
0?l000001oooool2o`0007Wooooo002/ooooo`?o00002oooool2o`000004ooooool0003o0000oooo
o`?o00003?ooool5o`0000cooooo0_l00002ooooo`;o0000P_ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`Co00001?ooool2o`0000Oooooo0_l00004
ooooo`?o0000U_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`02ooooo`?o00001?ooool2o`0000cooooo1Ol00005ooooo`;o00006_ooool4o`0000Sooooo0ol0
001]ooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`?o00000_ooool2o`0000;ooooo0_l0000?ooooo`?o00005?oo
ool2o`0000gooooo1?l00005ooooo`;o000000Coooooo`000?l0003o0000KOooool008Wooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`;o0000
1Oooool2o`000004ooooool0003o0000o`0000Cooooo1?l00008ooooo`;o00002Oooool3o`0000Go
oooo0_l0001Zooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool2o`00
00?ooooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00006
ooooo`;o00002?ooool2o`0000Oooooo1?l00006ooooo`Co0000J?ooool008Wooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0;ooooo`;o00003Oooool2o`0000;ooooo0ol0000Looooo`;o00000oooool3
o`0000[ooooo0_l0001Xooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool2o`0000?ooooo0_l0000=ooooo`;o00003Oooool2o`0000Sooooo0_l00008ooooo`;o00000ooo
ool2o`0007Gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
1Oooool2o`0001;ooooo0_l00006ooooo`;o00002?ooool2o`0000_ooooo1?l0001eooooo`00[?oo
ool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000[ooooo1?l00003ooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool02_oo
ool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00002oooool6o`000003ooooool0
003o000000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000?ooooo0_l0
001`ooooo`00[?ooool01?l0003oooooo`000?l00008ooooo`;o00000oooool3o`0000Gooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o000000Goooooo`000?l0003o
0000ooooo`03o`0007Sooooo002/ooooo`Co00002?ooool6o`0000Oooooo0_l00008ooooo`Co0000
0_ooool2o`00013ooooo1Ol00002ooooo`?o00003?ooool2o`0006Wooooo002/ooooo`03o`000?oo
oooooooo00;o00002?ooool5o`0000cooooo0_l00005ooooo`?o00004oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0006Wooooo002/ooooo`Ko00002Oooool2o`0000;ooooo0_l00009
ooooo`?o00001Oooool2o`0002;ooooo0_l0001`ooooo`00[?ooool3o`000003ooooool0003o0000
00cooooo1?l00003ooooo`;o00001?ooool2o`0000Oooooo0_l0000Dooooo`;o0000O?ooool00:co
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00002_ooool3o`000003ooooool0003o0000013ooooo1?l0001jooooo`00[?ooool01?l0003ooooo
ooooooooool2o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o00002?ooool2o`000004
ooooool0003o0000ooooo`;o00004_ooool2o`0007[ooooo002/ooooo`04o`000?oooooooooooooo
o`;o000000Coooooo`000?l0003o00004Oooool2o`0000Wooooo0ol00002ooooo`;o00002?ooool2
o`0000kooooo0_l0001eooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00004Oooool2o`00
00;ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0ol0000<ooooo`Co000000?oooooo`00
0?l00000L_ooool00:cooooo0ol0000;ooooo`;o00003?ooool2o`000003ooooool0003o000000?o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l0001booooo`00
[?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l000001?l00006ooooo`Co0000
1_ooool2o`0000_ooooo0_l00004ooooo`?o00004?ooool2o`0000?ooooo0_l0001[ooooo`00[?oo
ool00ol0003oooooooooo`07ooooo`Go000000?oooooo`000?l000000_l00006ooooo`;o00005Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0006_ooooo002/
ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`;o00006oooool2o`0000?ooooo0_l0000E
ooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool04?ooool3o`0000Oooooo0_l0000Aoooo
o`Co00001?ooool2o`0001;ooooo1?l0001/ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o
00001_ooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`0000Cooooo0ol0000@ooooo`Go
0000K?ooool00:cooooo00Co0000ooooool0003o00002?ooool2o`0001;ooooo0_l00006ooooo`;o
00000oooool2o`0000Gooooo0_l00002ooooo`?o00004?ooool2o`0006oooooo002/ooooo`04o`00
0?oooooo0000o`0000;ooooo1?l000000ooooooo0000o`00000?ooooo`?o000000Coooooo`000?l0
003ooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o0000M_ooool00:co
oooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000oooooo0ol00004ooooo`;o
00002?ooool4o`0001?ooooo0_l00009ooooo`;o0000Joooool00:cooooo00?o0000ooooooooool0
0_l00008ooooo`;o00000_ooool2o`0001[ooooo1?l00003ooooo`;o00002oooool2o`0000Sooooo
0_l00002ooooo`;o0000Joooool00:cooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0
0007ooooo`;o00000_ooool2o`0000_ooooo0_l00005ooooo`Co00002oooool2o`0000Sooooo0_l0
001_ooooo`00[?ooool00ol0003oooooooooo`02o`0000[ooooo0_l000000ooooooo0000o`000003
ooooo`Go00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000Gooooo0_l0000D
ooooo`;o0000L_ooool00:cooooo1Ol0000:ooooo`;o000000?oooooo`000?l000000oooool3o`00
00Oooooo1?l00004ooooo`Co00006oooool2o`0000Cooooo0_l0001/ooooo`00[?ooool3o`0000oo
oooo0_l0000Gooooo`Ko00002oooool2o`00013ooooo0_l0001/ooooo`00[?ooool00ol0003ooooo
ooooo`0=ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0_ooool5o`0000[ooooo0ol00003ooooo`;o00003oooool2o`0006Sooooo002/ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`Go00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001?ooool2o`0000[ooooo1?l00003ooooo`;o00003oooool2o`0006Sooooo002/
ooooo`?o00000_ooool3o`0000Gooooo1?l0000Yooooo`Co00001oooool2o`0007Gooooo002/oooo
o`?o00000oooool3o`0001Kooooo0_l00004ooooo`;o00007_ooool2o`0000Gooooo0_l0001^oooo
o`00[?ooool3o`0000Cooooo0_l0000Fooooo`;o00001?ooool5o`0001?ooooo0_l00007ooooo`;o
00001?ooool2o`0000?ooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000
1?ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool5o`0000Cooooo0_l00003ooooo`Oo0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l0001Yooooo`00[?oo
ool01?l0003oooooooooooooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo1?l000000ooooooo
0000o`000005o`0000Oooooo0_l00008ooooo`;o0000Koooool00:cooooo00Co0000oooooooooooo
oooo0_l000000ooooooo0000o`000008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Goooo
o`;o00002oooool2o`0001?ooooo0_l0001Xooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0>
ooooo`?o00003?ooool3o`0000;ooooo0_l00005ooooo`;o00002?ooool3o`0000Cooooo0_l00007
ooooo`Co00000oooool2o`000003ooooool0003o000000;o0000J?ooool0097ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00[ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo1ol00005ooooo`;o00000oooool2
o`0000?ooooo1?l00005ooooo`;o00001Oooool4o`0000?ooooo1Ol0001Zooooo`00TOooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005
ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo1?l00003
ooooo`;o00000oooool4o`0000Gooooo0_l0000=ooooo`;o0000K?ooool0097ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003ooooo`;o00005_ooool2
o`0000[ooooo0_l0002@ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo002A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo
00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMg
o`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool0
0:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003o
k^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomg
MgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63688 .40566 Mdot
.64027 .37325 Mdot
.50234 .56075 Mdot
.45125 .2705 Mdot
.49303 .19333 Mdot
.61517 .35853 Mdot
.45868 .65741 Mdot
.72883 .46651 Mdot
.69764 .6152 Mdot
.45605 .23552 Mdot
.48273 .21698 Mdot
.72594 .56144 Mdot
.6464 .34751 Mdot
.4272 .31054 Mdot
.68559 .69731 Mdot
.44088 .284 Mdot
.59671 .3742 Mdot
.64629 .34467 Mdot
.47011 .19702 Mdot
.67691 .38376 Mdot
.66463 .45285 Mdot
.65583 .44965 Mdot
.65556 .5402 Mdot
.65531 .37695 Mdot
.69697 .68627 Mdot
.49306 .17332 Mdot
.52657 .29288 Mdot
.5093 .23886 Mdot
.68532 .42565 Mdot
.65069 .43662 Mdot
.66267 .55236 Mdot
.70956 .56116 Mdot
.72035 .55023 Mdot
.61256 .44431 Mdot
.59943 .34282 Mdot
.67568 .55571 Mdot
.69701 .54531 Mdot
.52314 .27405 Mdot
.68592 .54725 Mdot
.73328 .51394 Mdot
.72579 .60067 Mdot
.60472 .37407 Mdot
.61545 .38557 Mdot
.6164 .31537 Mdot
.61576 .32603 Mdot
.4887 .17977 Mdot
.49492 .23513 Mdot
.71109 .50624 Mdot
.52391 .21142 Mdot
.68645 .51362 Mdot
.70875 .53033 Mdot
.69419 .48487 Mdot
.6967 .79192 Mdot
.61757 .41421 Mdot
.59577 .31876 Mdot
.70697 .59591 Mdot
.72922 .49591 Mdot
.58331 .32562 Mdot
.70538 .51963 Mdot
.61352 .32246 Mdot
.51387 .21731 Mdot
.7262 .6546 Mdot
.67919 .58814 Mdot
.42233 .53979 Mdot
.6885 .66866 Mdot
.71306 .55357 Mdot
.47362 .2245 Mdot
.48101 .2418 Mdot
.48811 .20836 Mdot
.6637 .41642 Mdot
.53895 .21778 Mdot
.47439 .68714 Mdot
.49152 .23412 Mdot
.45854 .23734 Mdot
.67894 .58919 Mdot
.48912 .63224 Mdot
.69601 .79305 Mdot
.5683 .34237 Mdot
.69254 .4696 Mdot
.59113 .40447 Mdot
.6682 .55652 Mdot
.65182 .46089 Mdot
.4681 .25273 Mdot
.59916 .34908 Mdot
.72523 .48128 Mdot
.41486 .48684 Mdot
.4918 .19096 Mdot
.54875 .3023 Mdot
.56303 .27512 Mdot
.4897 .24895 Mdot
.68743 .70878 Mdot
.69747 .76344 Mdot
.42218 .56791 Mdot
.50292 .20241 Mdot
.42075 .501 Mdot
.71891 .7191 Mdot
.42915 .30232 Mdot
.69654 .60171 Mdot
.70032 .78829 Mdot
.53279 .21195 Mdot
.64163 .42865 Mdot
.53913 .2286 Mdot
.71541 .60885 Mdot
.62661 .34365 Mdot
.6715 .46675 Mdot
.6132 .44063 Mdot
.5651 .26923 Mdot
.46413 .19697 Mdot
.42269 .57636 Mdot
.66694 .44625 Mdot
.43031 .30027 Mdot
.42808 .35631 Mdot
.7068 .57416 Mdot
.68069 .43631 Mdot
.68688 .83134 Mdot
.45746 .69584 Mdot
.53738 .26215 Mdot
.72074 .47508 Mdot
.71844 .49847 Mdot
.68009 .62212 Mdot
.65184 .37013 Mdot
.73438 .61776 Mdot
.65751 .5556 Mdot
.6828 .40248 Mdot
.66559 .43003 Mdot
.46858 .24795 Mdot
.68384 .4666 Mdot
.71965 .71045 Mdot
.64779 .51246 Mdot
.42744 .47885 Mdot
.65883 .47919 Mdot
.64579 .45443 Mdot
.72187 .59358 Mdot
.60084 .30853 Mdot
.61639 .38017 Mdot
.68756 .41961 Mdot
.69925 .44916 Mdot
.68592 .45642 Mdot
.49758 .24416 Mdot
.71374 .59564 Mdot
.6967 .67213 Mdot
.6898 .7479 Mdot
.41893 .48892 Mdot
.46966 .20009 Mdot
.59424 .36343 Mdot
.67792 .39911 Mdot
.72348 .47918 Mdot
.68792 .8395 Mdot
.54973 .33084 Mdot
.5444 .2886 Mdot
.7486 .53901 Mdot
.52644 .20641 Mdot
.45871 .21377 Mdot
.65075 .35563 Mdot
.48004 .68473 Mdot
.63316 .44723 Mdot
.69776 .49879 Mdot
.6875 .54728 Mdot
.71929 .51402 Mdot
.69265 .57249 Mdot
.69856 .48637 Mdot
.50503 .186 Mdot
.69112 .4396 Mdot
.74072 .48708 Mdot
.66938 .57653 Mdot
.62467 .46611 Mdot
.64388 .48292 Mdot
.72267 .4916 Mdot
.67232 .45088 Mdot
.49256 .21428 Mdot
.69614 .43343 Mdot
.67858 .56202 Mdot
.45118 .28288 Mdot
.51624 .26203 Mdot
.5315 .26472 Mdot
.53279 .28157 Mdot
.70933 .60612 Mdot
.71655 .72166 Mdot
.63336 .45757 Mdot
.42939 .52726 Mdot
.68894 .47778 Mdot
.69275 .42018 Mdot
.73305 .53861 Mdot
.43046 .31562 Mdot
.72685 .59988 Mdot
.42614 .47318 Mdot
.68602 .65022 Mdot
.70761 .73388 Mdot
.71559 .50131 Mdot
.73954 .49879 Mdot
.60958 .35481 Mdot
.73287 .61341 Mdot
.67629 .38961 Mdot
.42288 .47802 Mdot
.71066 .68975 Mdot
.72692 .48334 Mdot
.73899 .55622 Mdot
.71941 .59758 Mdot
.51217 .22063 Mdot
.72415 .72188 Mdot
.55371 .23901 Mdot
.43041 .52609 Mdot
.43028 .52746 Mdot
.47181 .68777 Mdot
.52909 .26179 Mdot
.71942 .73507 Mdot
.64539 .47636 Mdot
.42971 .39923 Mdot
.62166 .38084 Mdot
.41772 .51357 Mdot
.43406 .63391 Mdot
.46082 .21965 Mdot
.64213 .34415 Mdot
.56285 .32612 Mdot
.67272 .45592 Mdot
.46003 .24147 Mdot
.64427 .49235 Mdot
.56765 .3451 Mdot
.74052 .50212 Mdot
.43415 .62889 Mdot
.63271 .40987 Mdot
.73297 .49224 Mdot
.53052 .24817 Mdot
.69595 .587 Mdot
.67006 .43365 Mdot
.6652 .58271 Mdot
.49476 .25322 Mdot
.50186 .21154 Mdot
.62346 .31643 Mdot
.43115 .35619 Mdot
.68788 .69259 Mdot
.74267 .58967 Mdot
.43191 .32246 Mdot
.48206 .66147 Mdot
.69165 .78412 Mdot
.57235 .3135 Mdot
.49544 .22632 Mdot
.72814 .63393 Mdot
.51472 .25698 Mdot
.62666 .33997 Mdot
.66278 .48356 Mdot
.64436 .44302 Mdot
.71952 .67225 Mdot
.60263 .32233 Mdot
.67324 .42925 Mdot
.53947 .21889 Mdot
.71541 .51674 Mdot
.42673 .39629 Mdot
.68934 .56819 Mdot
.60057 .41512 Mdot
.53705 .21485 Mdot
.68423 .56339 Mdot
.7352 .57325 Mdot
.45369 .68739 Mdot
.43368 .36005 Mdot
.68542 .59404 Mdot
.53604 .24893 Mdot
.52102 .27371 Mdot
.57092 .25277 Mdot
.48862 .63492 Mdot
.72553 .53237 Mdot
.70887 .50702 Mdot
.54625 .2526 Mdot
.49364 .22372 Mdot
.66795 .57413 Mdot
.42892 .54789 Mdot
.54998 .25328 Mdot
.63929 .43832 Mdot
.51549 .27665 Mdot
.62845 .45933 Mdot
.67485 .571 Mdot
.56176 .3058 Mdot
.68217 .49847 Mdot
.58979 .29934 Mdot
.43448 .28759 Mdot
.57469 .32968 Mdot
.69784 .47952 Mdot
.42094 .37233 Mdot
.4551 .20072 Mdot
.70828 .54288 Mdot
.43702 .26687 Mdot
.62802 .40781 Mdot
.69005 .46516 Mdot
.45247 .69525 Mdot
.48794 .23793 Mdot
.68921 .58912 Mdot
.71917 .58867 Mdot
.45758 .20219 Mdot
.47341 .68144 Mdot
.55972 .35276 Mdot
.67388 .39797 Mdot
.53263 .25905 Mdot
.66495 .56823 Mdot
.70087 .74641 Mdot
.69987 .55799 Mdot
.69524 .66935 Mdot
.68986 .60696 Mdot
.48959 .65883 Mdot
.70512 .48265 Mdot
.69142 .72703 Mdot
.66951 .38437 Mdot
.687 .69242 Mdot
.68917 .8425 Mdot
.55869 .28731 Mdot
.57473 .25589 Mdot
.6443 .42948 Mdot
.71347 .53567 Mdot
.71341 .64061 Mdot
.48305 .22075 Mdot
.70438 .56635 Mdot
.53227 .23975 Mdot
.432 .54472 Mdot
.65082 .38233 Mdot
.59468 .36206 Mdot
.65648 .39794 Mdot
.74645 .54581 Mdot
.441 .64576 Mdot
.63567 .42375 Mdot
.61125 .41823 Mdot
.68898 .6708 Mdot
.43938 .64325 Mdot
.73116 .55518 Mdot
.69565 .70747 Mdot
.72031 .6912 Mdot
.45856 .25304 Mdot
.58812 .27471 Mdot
.59118 .3214 Mdot
.68034 .59101 Mdot
.46954 .186 Mdot
.44985 .669 Mdot
.47226 .67188 Mdot
.56984 .28259 Mdot
.73153 .48173 Mdot
.67671 .62545 Mdot
.42221 .55866 Mdot
.6493 .38257 Mdot
.42744 .536 Mdot
.46744 .68509 Mdot
.6264 .32442 Mdot
.60899 .33812 Mdot
.62463 .46302 Mdot
.51058 .19539 Mdot
.53409 .27444 Mdot
.71452 .75858 Mdot
.5573 .29718 Mdot
.6507 .49928 Mdot
.42313 .44898 Mdot
.71184 .58567 Mdot
.52941 .30174 Mdot
.68561 .46736 Mdot
.65316 .51405 Mdot
.42239 .5833 Mdot
.5705 .36282 Mdot
.6954 .73702 Mdot
.72902 .53799 Mdot
.70407 .44816 Mdot
.67846 .54129 Mdot
.53961 .24594 Mdot
.57661 .29238 Mdot
.68088 .54222 Mdot
.5599 .2781 Mdot
.72798 .54529 Mdot
.73904 .6454 Mdot
.67367 .42843 Mdot
.71919 .60329 Mdot
.73079 .56053 Mdot
.7372 .54645 Mdot
.46265 .68263 Mdot
.56991 .30968 Mdot
.69154 .6853 Mdot
.72778 .51117 Mdot
.46302 .68418 Mdot
.66703 .54308 Mdot
.5794 .36913 Mdot
.61267 .34282 Mdot
.6407 .42531 Mdot
.69572 .60926 Mdot
.62885 .34844 Mdot
.70061 .52994 Mdot
.6736 .62806 Mdot
.65411 .54698 Mdot
.70137 .43047 Mdot
.65803 .49731 Mdot
.69919 .67637 Mdot
.69705 .82088 Mdot
.67724 .63678 Mdot
.629 .40432 Mdot
.45563 .66045 Mdot
.70584 .67777 Mdot
.54753 .24209 Mdot
.47288 .67132 Mdot
.73576 .51865 Mdot
.66432 .41891 Mdot
.46065 .6932 Mdot
.46609 .22934 Mdot
.51789 .2173 Mdot
.50184 .23663 Mdot
.71249 .49532 Mdot
.661 .37087 Mdot
.70074 .71056 Mdot
.73351 .53855 Mdot
.60069 .3779 Mdot
.69137 .79385 Mdot
.59166 .33853 Mdot
.5245 .26308 Mdot
.50067 .21298 Mdot
.49756 .62452 Mdot
.73027 .50101 Mdot
.72501 .56505 Mdot
.52433 .28775 Mdot
.42189 .43339 Mdot
.42334 .31769 Mdot
.41642 .43198 Mdot
.74065 .56555 Mdot
.47931 .17742 Mdot
.67448 .54357 Mdot
.42975 .35345 Mdot
.47042 .20569 Mdot
.43066 .57969 Mdot
.49047 .18715 Mdot
.61175 .44462 Mdot
.46178 .21323 Mdot
.42941 .39943 Mdot
.74249 .58098 Mdot
.71555 .5867 Mdot
.5022 .52771 Mdot
.59896 .33849 Mdot
.56659 .27268 Mdot
.63609 .49909 Mdot
.58137 .37383 Mdot
.50003 .22778 Mdot
.71711 .64892 Mdot
.73475 .6896 Mdot
.63718 .3792 Mdot
.68955 .82103 Mdot
.61107 .29754 Mdot
.42345 .48794 Mdot
.68184 .66733 Mdot
.68774 .69565 Mdot
.50468 .2476 Mdot
.65062 .54206 Mdot
.70858 .76985 Mdot
.42475 .39772 Mdot
.45802 .68601 Mdot
.5431 .30587 Mdot
.67161 .55015 Mdot
.58313 .36989 Mdot
.7126 .74057 Mdot
.42542 .52333 Mdot
.61742 .42661 Mdot
.59343 .33243 Mdot
.42514 .59479 Mdot
.43106 .56996 Mdot
.42871 .32026 Mdot
.72901 .475 Mdot
.45329 .69042 Mdot
.69074 .44821 Mdot
.63653 .36391 Mdot
.62862 .37595 Mdot
.68322 .47702 Mdot
.66221 .57539 Mdot
.59456 .35682 Mdot
.74029 .66182 Mdot
.4628 .23097 Mdot
.73191 .47971 Mdot
.73818 .55614 Mdot
.52596 .30265 Mdot
.70499 .46649 Mdot
.57355 .34263 Mdot
.60445 .42677 Mdot
.68508 .45831 Mdot
.63951 .41108 Mdot
.48487 .19932 Mdot
.56802 .35274 Mdot
.60919 .41494 Mdot
.74398 .59529 Mdot
.62435 .43346 Mdot
.50135 .58918 Mdot
.62109 .42775 Mdot
.58612 .37678 Mdot
.47937 .69079 Mdot
.4849 .24702 Mdot
.61512 .40066 Mdot
.60559 .33859 Mdot
.43966 .63256 Mdot
.54668 .2747 Mdot
.71289 .55608 Mdot
.47329 .18235 Mdot
.63877 .44452 Mdot
.43849 .24617 Mdot
.54182 .31585 Mdot
.46021 .68305 Mdot
.70427 .80475 Mdot
.45101 .66236 Mdot
.63394 .34889 Mdot
.68235 .63844 Mdot
.67263 .56044 Mdot
.48844 .20769 Mdot
.68725 .46474 Mdot
.73067 .54654 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:Wo
oooo0_l000000ooooooo0000ooooo`2jooooo`00ZOooool2o`000004ooooool0003o0000o`000;Wo
oooo002Uooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00Xooo
ool4o`000003ooooool0003o000000;ooooo00?o0000ooooooooool0^Oooool00:;ooooo0ol00007
ooooo`?o0000^Oooool00:;ooooo0_l00004ooooo`;o00000_ooool3o`000;Wooooo002Xooooo`?o
000000?oooooo`000?ooool0^_ooool00:Wooooo0_l000001?oooooo0000ooooooooool2o`000;Oo
oooo002Pooooo`Co00001Oooool2o`000004ooooool0003oooooooooo`;o0000]oooool009gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`?o0000^Oooool009gooooo0ol0
0002ooooo`;o00000oooool2o`0000?ooooo0ol0002iooooo`00W_ooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool3o`0000Gooooo0_l0002booooo`00X_ooool2o`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00Woooool2o`0000Oooooo0_l00002ooooo`;o
00001Oooool2o`000003ooooool0003o00000;3ooooo002Nooooo`?o00002?ooool2o`000003oooo
ool0003o000000Gooooo0_l000000ooooooo0000o`000002o`000:kooooo002Nooooo`?o00001Ooo
ool2o`000005ooooool0003o0000ooooool000000oooool3o`0000Gooooo0ol0002]ooooo`00Wooo
ool2o`0000Gooooo0_l00004ooooo`04o`000?ooooooooooooooo`?o00001Oooool3o`000:gooooo
002Sooooo`;o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
0000]_ooool00:?ooooo0_l00004ooooo`Go00002_ooool2o`000:kooooo002Oooooo`?o00002?oo
ool4o`0000[ooooo0_l0002^ooooo`00Woooool3o`0000Oooooo0_l000000ooooooo0000ooooo`2j
ooooo`00WOooool3o`0000Sooooo1_l0002jooooo`00WOooool3o`0000Sooooo1_l000000ooooooo
0000o`000005ooooo`;o00001Oooool2o`000:Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@03ooooool0003o000000;ooooo00?oA4A4o`000?l000000_l00005ooooo`03
o`000?oooooooooo00;o00001Oooool2o`0000?ooooo1?l0002Yooooo`00TOooool01_mgMgOoV9RH
oooooonHV9SoMgMgooooo`;o00000_ooool2ob4Q8@03ooooool0003o000000Gooooo1?l00002oooo
o`;o00003?ooool4o`000:_ooooo0029ooooo`Ko00000_ooool01_l@413ooooooooooooooooo410@
ooooo`;o00002?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Oooooo1Ol0002]
ooooo`00TOooool01Ol0003ooooooooooooooooo000000Sooooo0_l000000ooooooo0000o`000002
ooooo`03ogMgMolb<S;ooooo00;o00000_ooool3o`0000Oooooo0ol00002ooooo`;o00001_ooool2
o`000:?ooooo002Aooooo`05o`000?ooooooooooooooool000002?ooool2o`000007ooooool0003o
0000ob4Q8Ol0003o<S8bolc<c003ooooo`?o00003_ooool3o`0000Gooooo0ol0002Rooooo`00TOoo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01Oooool3o`0000?ooooo
0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l0002Rooooo`00TOooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool3o`0000;o
oooo1Ol0002^ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03
o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000004o`000:kooooo002Gooooo`;o0000
4oooool00ol0003oooooooooo`05ooooo`Co0000/?ooool009Oooooo0_l00002ooooo`;o00003ooo
ool00ol0003oooooooooo`0Booooo`;o0000YOooool009_ooooo0_l0000?ooooo`03o`000?oooooo
oooo00Cooooo0_l0000<ooooo`?o0000Y?ooool00:cooooo0ol00002ooooo`Co00000_ooool2o`00
00;ooooo0_l00003ooooo`Co00001Oooool2o`0009gooooo002/ooooo`03o`000?oooooooooo00;o
oooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0ol00007ooooo`;o0000WOooool009_ooooo
0_l0000?ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o00000_ooool2o`000:?ooooo
002Hooooo`;o000000?oooooo`000?l000003oooool00ol0003oooooooooo`07ooooo`;o00002ooo
ool2o`000:?ooooo002Fooooo`Co00004_ooool00ol0003oooooooooo`05ooooo`;o00001?ooool2
o`0000?ooooo0_l0002Wooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool01Oooool2o`00
00Cooooo0_l00003ooooo`;o00001?ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo00Go
oooo0_l0000?ooooo`;o0000XOooool00:cooooo00?o0000ooooooooool01Oooool2o`0000Sooooo
0_l0000@ooooo`;o0000U_ooool009Gooooo0_l0000Eooooo`?o00003oooool2o`0000Wooooo0_l0
0005ooooo`;o0000U_ooool009Cooooo0ol0000Eooooo`03o`000?oooooooooo00Gooooo0ol00005
ooooo`;o00002oooool2o`0009gooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`05oooo
o`?o00000oooool4o`0000;ooooo0_l0002Vooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool02oooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o0000VOooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo01Cooooo0_l00008ooooo`;o0000VOooool009Gooooo0_l0
000Eooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`;o00003Oooool4o`0009;ooooo002B
ooooo`;o000000?oooooo`000?l000005Oooool00ol0003oooooooooo`0:ooooo`;o00004?ooool2
o`0000Gooooo1?l0002Booooo`00T_ooool5o`0001Gooooo00?o0000ooooooooool06oooool5o`00
00;ooooo0_l0002Eooooo`00U?ooool3o`0001Gooooo0ol0000Hooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00000_ooool2o`00097ooooo002/ooooo`03o`000?oooooooooo017o
oooo0_l00005ooooo`;o00002Oooool2o`000003ooooool0003o0000097ooooo002/ooooo`03o`00
0?oooooooooo00gooooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l0002Dooooo`00[?oo
ool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`0000Cooooo0_l0002Looooo`00[?ooool0
0ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool8o`00
00?ooooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0Cooooo`Co00001?ooool9o`0000;o
oooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0Cooooo`Co00001_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool4o`0008[ooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0
0008ooooo`;o00002?ooool8o`0008[ooooo002/ooooo`?o00004?ooool2o`000003ooooool0003o
000000Sooooo0_l00008ooooo`Co00000_ooool2o`0008[ooooo002Dooooo`;o00005_ooool00ol0
003oooooooooo`0@ooooo`;o000000?oooooo`000?l000003?ooool2o`0000_ooooo0_l00029oooo
o`00U?ooool3o`0001Gooooo00?o0000ooooooooool07?ooool2o`0000?ooooo1?l00009ooooo`;o
0000ROooool009Cooooo1?l0000Dooooo`03o`000?oooooooooo01cooooo0_l00005ooooo`;o0000
U?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`;o00003?oo
ool2o`0008gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`;o0000
1_ooool2o`0000cooooo0_l0002=ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01Oooooo0ol0000Eooooo`;o000000?oooooo`000?l00000QOooool0087ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Oooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo0ol00002ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000025ooooo`00
ROooool01Ol0003ooooooooooooooooo000000?ooooo0_l00008ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0001Oooooo1?l000001?oooooo0000o`000?ooool2o`00
00Kooooo0_l00002ooooo`;o00000oooool2o`0008Oooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0Iooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0008Oooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool2
o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0008Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Sooooo`Co00001oooool2o`0000Gooooo1?l00020ooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`0Sooooo`;o00004?ooool4o`00083ooooo002/ooooo`03o`000?oo
oooooooo03Oooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`0gooooo`;o0000P?ooool0
09?ooooo0_l0000Gooooo`03o`000?oooooooooo033ooooo0_l00004ooooo`;o0000POooool009?o
oooo0ol0000Fooooo`?o00008oooool2o`0000_ooooo0_l00004ooooo`?o0000P?ooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo01_ooooo0_l00006ooooo`;o00000_ooool2o`0000kooooo
1?l0001nooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00002_ooool2o`000003ooooool0
003o000000gooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Wooooo`Go0000SOooool0
0:cooooo00?o0000ooooooooool09oooool3o`000003ooooool0003o000008cooooo002/ooooo`03
o`000?oooooooooo01kooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00006ooooo`;o
0000Q?ooool00:cooooo00?o0000ooooooooool07_ooool2o`000003ooooool0003o000000;o0000
3_ooool2o`0000Gooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o00004?oo
ool2o`0000Gooooo1?l0001kooooo`00[?ooool3o`0002Wooooo1?l0000=ooooo`Co0000Noooool0
0:cooooo00?o0000ooooooooool07oooool2o`0000;ooooo1?l00002ooooo`Co00002Oooool2o`00
00;ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o00000_ooool4o`0000Co
oooo0ol00005ooooo`;o000000?oooooo`000?l000001oooool2o`0007Sooooo002@ooooo`Co0000
6?ooool00ol0003oooooooooo`0Vooooo`;o00001?ooool2o`0000Gooooo1Ol00005ooooo`Co0000
N?ooool0093ooooo1?l0000Hooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`0R
ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o0000Noooool0
0:cooooo00?o0000ooooooooool08_ooool2o`0000Oooooo0ol0000>ooooo`;o0000Noooool00:co
oooo00?o0000ooooooooool08Oooool3o`0000Kooooo1?l00006ooooo`;o0000Poooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo027ooooo0ol00005ooooo`?o00001?ooool2o`0000;ooooo
0_l00006ooooo`Ko0000Moooool009;ooooo0_l0000Hooooo`?o0000:Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo1_l0001gooooo`00[?ooool00ol0003oooooooooo`0]
ooooo`;o00001?ooool5o`00087ooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l00002oooo
o`;o00001oooool2o`0000;ooooo0_l0001mooooo`002Oooool4o`000003oa0@4?oooooooooo01Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000oooo
ooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`Ko00000_ooool2
o`000005odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000oooooooo
ool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`?o000000Co8B4Qonk^
k_ooooooA4A40_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool00oooool3o`0000Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00Wooooo0_l000001?ooooooV9RHob4Q8Oo^k^h9ooooo`;o00000_oo
ool4o`0000?ooooo0_l00003ooooo`03oa0@4?oooooooooo00;o00004?ooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000Wooooo0_l00002
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgo`000?l000000_ooool5o`0000;ooooo0_l00003
ooooo`03o`000?oooooooooo00;o00003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?l0
003oc<c<01Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Kooooo0_l00007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0000G
ooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oooooo0ol00002ooooo`03o`000?oo
oooooooo00Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?ooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool5o`0001Kooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4002o`0000;ooooo0_l00006ooooo`Co000000?oooooo`000?l0
00001Oooool6o`0000_ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1Ol0000Fooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`04oiRHV?l@413o0000ob4Q8@;o00000oooool4o`0000Kooooo0_l000000ooooooo0000o`000002
o`0000?ooooo00?ok^k^o`000?l000000ol0000;ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool0
0ol0003oooooooooo`0/ooooo`;o00001?ooool2o`0000Wooooo1Ol00005ooooo`Co0000K_ooool0
08oooooo1Ol0000Hooooo`03o`000?oooooooooo03;ooooo0_l00009ooooo`?o00003?ooool2o`00
06_ooooo002?ooooo`Go00006?ooool00ol0003oooooooooo`0/ooooo`;o00006?ooool2o`000004
ooooool0003o0000ooooo`;o0000H?ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003o
ooooooooo`0/ooooo`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o0000Hoooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo037ooooo0_l00006
ooooo`;o00002?ooool4o`000003ooooool0003o000006Gooooo00CogMgMo`000?l@413oc<c<1_oo
ool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000?ooooo0_l00007ooooo`03o`000?oo
oooooooo00Cooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo
0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Hooooo`;o00002?ooool2o`0000;ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000
ooooooooool0@_ooool2o`0007Gooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0]oooo
o`;o00002oooool2o`0000cooooo0_l0001_ooooo`00T?ooool2o`0001[ooooo00?o0000oooooooo
ool0;Oooool4o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0001]ooooo`00
[?ooool00ol0003oooooooooo`0_ooooo`;o00003oooool2o`0000;ooooo0ol00003ooooo`;o0000
KOooool00:cooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l00004ooooo`;o0000KOoo
ool009?ooooo0_l0000Gooooo`?o0000^Oooool009?ooooo1?l0000Eooooo`;o0000^_ooool009Co
oooo0ol0000Eooooo`;o0000@?ooool4o`0007Kooooo002/ooooo`03o`000?oooooooooo03oooooo
1?l00004ooooo`;o0000L?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo04?ooooo0_l0
0002ooooo`;o0000L?ooool009;ooooo1?l0000Fooooo`03o`000?oooooooooo033ooooo0_l0000A
ooooo`;o00000oooool4o`0000?ooooo0_l0001Xooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool0;_ooool4o`0000;ooooo1_l00007ooooo`;o00001Oooool4o`0000?ooooo0_l0001Xoooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool0;_ooool2o`0000Cooooo1_l00004ooooo`;o
000000?oooooo`000?l000001Oooool5o`000003ooooool0003o000006Wooooo002Dooooo`?o0000
5Oooool00ol0003oooooooooo`0_ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`Go0000
00?oooooo`000?l00000JOooool009Cooooo0_l0000Fooooo`?o0000;oooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000Wooooo0_l0001booooo`00[?ooool00ol0003ooooooooo
o`0aooooo`?o000000?oooooo`000?l000000_l0000:ooooo`Co00000_ooool2o`0006kooooo002B
ooooo`;o00006?ooool00ol0003oooooooooo`0aooooo`;o000000Coooooo`000?l0003ooooo0_l0
0006ooooo`;o00000_ooool2o`0000Cooooo1?l0001/ooooo`00T_ooool2o`0001Sooooo0_l0000e
ooooo`Ko00001Oooool2o`000004ooooool0003o0000o`0000;ooooo1_l0001/ooooo`00[?ooool2
o`0003Oooooo1Ol00007ooooo`;o00000oooool4o`0006kooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`0iooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o0000Joooool009;o
oooo0_l000000ooooooo0000o`00000Eooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool2o`0000[ooooo0_l0001[ooooo`00UOooool2o`0001Gooooo
00?o0000ooooooooool0<oooool5o`0000?ooooo0ol00003ooooo`;o00001oooool2o`0006gooooo
002Booooo`;o00006?ooool3o`0003;ooooo1?l00006ooooo`;o00000oooool2o`0000Oooooo0_l0
001]ooooo`00T_ooool2o`000003ooooool0003o000001Gooooo00?o0000ooooooooool0<_ooool4
o`0008?ooooo002Booooo`;o000000?oooooo`000?l000005Oooool00ol0003oooooooooo`0coooo
o`;o00006?ooool2o`0006[ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0cooooo`;o
00003Oooool2o`0000Wooooo0_l0001Zooooo`00[?ooool2o`0003Wooooo0_l000000ooooooo0000
o`000002o`0000?ooooo1Ol0001booooo`00[?ooool2o`0003Wooooo0_l000000ooooooo0000o`00
0002o`0000Gooooo0ol00006ooooo`;o0000J_ooool009?ooooo0_l0000Gooooo`03o`000?oooooo
oooo03Sooooo1?l0000:ooooo`;o00001Oooool2o`0006[ooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`0jooooo`;o00001Oooool7o`0000Gooooo0_l0001Zooooo`00[?ooool3o`00047o
oooo2?l0001`ooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o00001_ooool4o`00073ooooo
002/ooooo`03o`000?oooooooooo03_ooooo1?l00003ooooo`;o000000?oooooo`000?l00000L_oo
ool00:cooooo00?o0000ooooooooool0>oooool4o`0000?ooooo1?l0001cooooo`00[?ooool00ol0
003oooooooooo`0mooooo`;o00001Oooool2o`0000?ooooo0_l0001^ooooo`00[?ooool00ol0003o
ooooooooo`0nooooo`;o00002Oooool2o`0006kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0nooooo`;o00002_ooool2o`0006gooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0>?ooool2o`00013ooooo0_l0001]ooooo`00ROooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02
ooooo`Co0000=oooool3o`0007oooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000hooooo`?o0000P?ooool0
08Wooooo00Go0000ooooooooooooooooo`000008ooooo`;o00001?ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0fooooo`;o0000POoo
ool008Wooooo00Go410@oooooooooooooooooa0@4008ooooo`Co00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo04Sooooo0_l0
001_ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo1?l000001?nj^[[ooooooiRH
V?l@4104ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo03Oooooo
0_l0000?ooooo`;o0000Koooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo03Oo
oooo1?l00008ooooo`;o0000M?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo03Wooooo
0_l00008ooooo`;o0000M?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo04_ooooo0_l0
001/ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0_l0001/
ooooo`00[?ooool3o`0003[ooooo0_l00008ooooo`;o0000Loooool00:cooooo00?o0000oooooooo
ool0>_ooool2o`0000_ooooo0_l0001`ooooo`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`00
0?oooooooooo04Oooooo0_l0001`ooooo`00WOooool3o`0000Kooooo1?l00002ooooo`03o`000?oo
oooooooo04cooooo0_l0001[ooooo`00Voooool4o`0000Oooooo0_l00004ooooo`03o`000?oooooo
oooo04cooooo0_l0001[ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0>Oooool2o`00
07kooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0iooooo`Ko0000N_ooool009_ooooo
0_l00005ooooo`?o00001oooool00ol0003oooooooooo`0kooooo`Co00001_ooool2o`0007;ooooo
002Rooooo`?o00001oooool3o`0003gooooo0ol00005ooooo`;o0000L_ooool00:cooooo00?o0000
ooooooooool0?_ooool2o`000003ooooool0003o000007Kooooo002Nooooo`?o00000_ooool2o`00
00Oooooo00?o0000ooooooooool0@Oooool2o`0007Kooooo002Nooooo`Wo00001Oooool00ol0003o
ooooooooo`0looooo`Co0000NOooool009cooooo2ol00005ooooo`03o`000?oooooooooo03cooooo
1?l0001iooooo`00W?ooool2o`0000Cooooo1Ol00005ooooo`03o`000?oooooooooo04;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000KOooool009cooooo0_l000000ooooooo0000o`000004
ooooo`;o00001Oooool00ol0003oooooooooo`0jooooo`?o00001Oooool2o`000003ooooool0003o
000000?ooooo0_l0001]ooooo`00W?ooool5o`0000_ooooo00?o0000ooooooooool0>_ooool3o`00
07cooooo002Nooooo`;o00003?ooool3o`0003[ooooo0ol0001looooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o0000N_ooool00:cooooo00?o0000
ooooooooool0>_ooool2o`000003ooooool0003o000000Kooooo0_l0001booooo`00[?ooool00ol0
003oooooooooo`0jooooo`;o00000oooool2o`0000Cooooo0_l0001booooo`00[?ooool00ol0003o
ooooooooo`0oooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool0AOooool2o`0007;ooooo
002/ooooo`03o`000?oooooooooo04Cooooo1Ol0001`ooooo`00[?ooool3o`0004Cooooo0_l00000
0ooooooo0000o`00001`ooooo`00[?ooool00ol0003oooooooooo`0looooo`;o0000Noooool00:co
oooo00?o0000ooooooooool0??ooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo047ooooo
0_l0001fooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000;ooooo0_l0
001booooo`00[?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool4o`0007;ooooo002Aoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00TOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0?ooo
ool2o`0007Sooooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`;o0000N?ooool0097ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000kooooo`;o0000O?oo
ool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`;o0000M?ooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@oooool2o`0007Cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0?_ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo03kooooo0_l0
001iooooo`00[?ooool00ol0003oooooooooo`11ooooo`;o0000M_ooool00:cooooo00?o0000oooo
ooooool0@Oooool2o`0007Kooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0??ooool2
o`0007_ooooo002/ooooo`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`00001hoooo
o`00[?ooool00ol0003oooooooooo`0mooooo`Co0000N?ooool00:cooooo00?o0000ooooooooool0
??ooool3o`0007[ooooo002/ooooo`03o`000?oooooooooo03cooooo0ol0001jooooo`00[?ooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo043o
oooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`10ooooo`;o0000Moooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000007Wo
oooo002/ooooo`?o0000>oooool2o`000003ooooool0003o000007Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00[?ooool00ol0
003oooooooooo`0jooooo`;o0000OOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0>oooool2o`0007cooooo002/ooooo`03o`000?oooooooooo03_ooooo0_l0
001looooo`00[?ooool00ol0003oooooooooo`0kooooo`;o0000O?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029oooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63237 .38421 Mdot
.64118 .37689 Mdot
.44832 .56556 Mdot
.46991 .75186 Mdot
.40657 .41693 Mdot
.59952 .31114 Mdot
.48976 .33955 Mdot
.71356 .62803 Mdot
.65411 .73835 Mdot
.4391 .72662 Mdot
.41631 .61142 Mdot
.68021 .72249 Mdot
.65568 .38179 Mdot
.46165 .77932 Mdot
.6034 .84803 Mdot
.46938 .76326 Mdot
.55884 .26829 Mdot
.65618 .38068 Mdot
.40985 .58586 Mdot
.68912 .46384 Mdot
.66648 .48078 Mdot
.65661 .45805 Mdot
.65508 .54581 Mdot
.66289 .41304 Mdot
.60834 .85119 Mdot
.41193 .31647 Mdot
.4161 .38782 Mdot
.41016 .42318 Mdot
.6908 .50663 Mdot
.65066 .43644 Mdot
.65948 .57701 Mdot
.6775 .6892 Mdot
.68381 .69766 Mdot
.59219 .34676 Mdot
.57004 .26742 Mdot
.66659 .6104 Mdot
.67839 .64378 Mdot
.41531 .37578 Mdot
.67316 .62242 Mdot
.7002 .68241 Mdot
.66088 .77394 Mdot
.57626 .28946 Mdot
.59666 .32145 Mdot
.61254 .3052 Mdot
.60807 .30519 Mdot
.40644 .3891 Mdot
.41516 .58038 Mdot
.69427 .62981 Mdot
.44483 .18145 Mdot
.67933 .58551 Mdot
.68689 .6509 Mdot
.68902 .57349 Mdot
.5996 .34085 Mdot
.56852 .25485 Mdot
.66336 .72979 Mdot
.70489 .65602 Mdot
.53693 .22289 Mdot
.68831 .63213 Mdot
.60473 .29923 Mdot
.42011 .28544 Mdot
.62392 .85521 Mdot
.66112 .66073 Mdot
.53358 .60484 Mdot
.62445 .80413 Mdot
.68097 .68696 Mdot
.42795 .67797 Mdot
.43606 .69251 Mdot
.40897 .5358 Mdot
.66848 .45304 Mdot
.48038 .13873 Mdot
.4895 .32443 Mdot
.41823 .60808 Mdot
.44197 .72932 Mdot
.66077 .66164 Mdot
.44475 .44365 Mdot
.49236 .18438 Mdot
.6903 .55618 Mdot
.54497 .26487 Mdot
.66242 .59472 Mdot
.65154 .45752 Mdot
.4564 .7349 Mdot
.56811 .268 Mdot
.70759 .63413 Mdot
.51555 .71088 Mdot
.40632 .41748 Mdot
.45238 .19983 Mdot
.50606 .17207 Mdot
.43005 .6641 Mdot
.59233 .87242 Mdot
.52132 .99552 Mdot
.53568 .61055 Mdot
.41156 .34671 Mdot
.52868 .63294 Mdot
.56327 .95127 Mdot
.45991 .77672 Mdot
.66 .71653 Mdot
.46812 .14319 Mdot
.63853 .40948 Mdot
.47157 .14637 Mdot
.65701 .76504 Mdot
.62378 .33484 Mdot
.67254 .50768 Mdot
.59298 .34589 Mdot
.51516 .17877 Mdot
.40988 .59689 Mdot
.53651 .60747 Mdot
.66947 .48094 Mdot
.46122 .77575 Mdot
.49838 .73182 Mdot
.67224 .70015 Mdot
.68473 .5041 Mdot
.52527 .4179 Mdot
.44359 .20552 Mdot
.70709 .61946 Mdot
.69968 .63697 Mdot
.65006 .71199 Mdot
.65915 .40226 Mdot
.64912 .81484 Mdot
.65582 .56918 Mdot
.69213 .48661 Mdot
.66935 .4662 Mdot
.45172 .73134 Mdot
.68374 .53484 Mdot
.57287 .93711 Mdot
.64793 .49623 Mdot
.52841 .56906 Mdot
.65916 .48967 Mdot
.64402 .438 Mdot
.66487 .75643 Mdot
.58316 .26688 Mdot
.59893 .32164 Mdot
.69397 .50739 Mdot
.69898 .55347 Mdot
.68686 .53087 Mdot
.41647 .5845 Mdot
.66379 .74308 Mdot
.61975 .82646 Mdot
.54812 .9507 Mdot
.52465 .66079 Mdot
.41163 .60095 Mdot
.55456 .25848 Mdot
.68743 .47416 Mdot
.70735 .62868 Mdot
.40718 .97296 Mdot
.44545 .22912 Mdot
.44738 .20617 Mdot
.69268 .73967 Mdot
.45562 .15705 Mdot
.42061 .66755 Mdot
.66042 .3943 Mdot
.48276 .31716 Mdot
.62629 .40172 Mdot
.68883 .5945 Mdot
.67389 .62587 Mdot
.69558 .65463 Mdot
.66951 .66852 Mdot
.69166 .58417 Mdot
.42253 .2529 Mdot
.69393 .52896 Mdot
.71199 .67001 Mdot
.66002 .62336 Mdot
.6148 .39504 Mdot
.64237 .45759 Mdot
.70349 .63876 Mdot
.67472 .49658 Mdot
.40891 .52075 Mdot
.69934 .53508 Mdot
.66687 .62475 Mdot
.48087 .74041 Mdot
.41207 .42142 Mdot
.42959 .25895 Mdot
.4258 .28886 Mdot
.65861 .74898 Mdot
.56178 .95155 Mdot
.62709 .41012 Mdot
.52932 .52295 Mdot
.68633 .55573 Mdot
.69877 .51878 Mdot
.69079 .70915 Mdot
.47504 .77141 Mdot
.66125 .77491 Mdot
.5282 .58811 Mdot
.63646 .76857 Mdot
.55299 .95751 Mdot
.69763 .63403 Mdot
.70746 .67911 Mdot
.58906 .29605 Mdot
.65229 .80568 Mdot
.68729 .46549 Mdot
.52756 .62146 Mdot
.59935 .88382 Mdot
.70777 .63942 Mdot
.68379 .7416 Mdot
.66284 .75709 Mdot
.41622 .31662 Mdot
.55628 .96594 Mdot
.50462 .15764 Mdot
.52782 .51157 Mdot
.52808 .51267 Mdot
.49326 .33031 Mdot
.42633 .27427 Mdot
.54283 .98151 Mdot
.64395 .45532 Mdot
.51855 .64187 Mdot
.60867 .33511 Mdot
.52613 .66489 Mdot
.5385 .5212 Mdot
.42614 .68677 Mdot
.6498 .37109 Mdot
.48181 .17648 Mdot
.67466 .50145 Mdot
.44642 .73449 Mdot
.64326 .4674 Mdot
.48985 .1842 Mdot
.70654 .68435 Mdot
.53728 .51468 Mdot
.62556 .37641 Mdot
.70748 .65983 Mdot
.43559 .22546 Mdot
.66556 .69481 Mdot
.67401 .47875 Mdot
.65706 .62237 Mdot
.42517 .63801 Mdot
.40878 .40068 Mdot
.62547 .32199 Mdot
.50433 .70567 Mdot
.60649 .8442 Mdot
.66576 .79146 Mdot
.48409 .75884 Mdot
.45808 .3539 Mdot
.51285 .19295 Mdot
.41115 .54153 Mdot
.63924 .82686 Mdot
.41162 .42298 Mdot
.62473 .33405 Mdot
.66304 .50277 Mdot
.64212 .42597 Mdot
.61145 .87113 Mdot
.58243 .27247 Mdot
.67795 .48277 Mdot
.4809 .13903 Mdot
.69329 .64965 Mdot
.51415 .67523 Mdot
.66969 .65589 Mdot
.5663 .29634 Mdot
.47759 .13844 Mdot
.66899 .63877 Mdot
.67526 .75554 Mdot
.52621 .42599 Mdot
.50979 .67734 Mdot
.66102 .68232 Mdot
.44817 .18827 Mdot
.41385 .40033 Mdot
.54056 .19752 Mdot
.4452 .43552 Mdot
.69153 .6872 Mdot
.69303 .62607 Mdot
.47326 .15375 Mdot
.41144 .54969 Mdot
.65977 .61695 Mdot
.53154 .52692 Mdot
.48341 .15081 Mdot
.63506 .41037 Mdot
.41279 .47803 Mdot
.61994 .39919 Mdot
.66347 .62815 Mdot
.48666 .16946 Mdot
.67849 .56062 Mdot
.56197 .23906 Mdot
.45989 .77091 Mdot
.51352 .1997 Mdot
.69244 .5763 Mdot
.48888 .76627 Mdot
.40971 .61067 Mdot
.6831 .66439 Mdot
.44561 .75677 Mdot
.61795 .36372 Mdot
.68905 .54703 Mdot
.53336 .45096 Mdot
.42479 .64697 Mdot
.66346 .68355 Mdot
.6673 .74442 Mdot
.41167 .62061 Mdot
.48385 .32279 Mdot
.46595 .19625 Mdot
.68305 .46476 Mdot
.43447 .23479 Mdot
.65912 .60241 Mdot
.54192 .96869 Mdot
.67594 .66522 Mdot
.62224 .81888 Mdot
.65714 .71015 Mdot
.45718 .3479 Mdot
.6965 .59444 Mdot
.5716 .91396 Mdot
.68018 .44807 Mdot
.60696 .84214 Mdot
.40134 .95877 Mdot
.48699 .16303 Mdot
.54808 .20634 Mdot
.64229 .41642 Mdot
.68697 .66666 Mdot
.63801 .80849 Mdot
.4184 .62331 Mdot
.67452 .6851 Mdot
.4448 .19297 Mdot
.5264 .49139 Mdot
.65569 .40527 Mdot
.55577 .2593 Mdot
.66142 .42597 Mdot
.68927 .74346 Mdot
.53062 .46466 Mdot
.6298 .39188 Mdot
.5879 .32669 Mdot
.62285 .80872 Mdot
.53288 .47737 Mdot
.68354 .72508 Mdot
.58959 .88613 Mdot
.59314 .90462 Mdot
.45736 .74529 Mdot
.56942 .23645 Mdot
.55718 .24329 Mdot
.66067 .6672 Mdot
.40497 .53322 Mdot
.52245 .42087 Mdot
.47481 .32768 Mdot
.5203 .18886 Mdot
.71025 .64703 Mdot
.64841 .70985 Mdot
.53502 .60792 Mdot
.65346 .40188 Mdot
.53207 .5443 Mdot
.49694 .33945 Mdot
.62838 .33016 Mdot
.5914 .29074 Mdot
.61442 .39241 Mdot
.42684 .23639 Mdot
.43063 .259 Mdot
.47798 .1672 Mdot
.65059 .48962 Mdot
.52314 .64412 Mdot
.66826 .72565 Mdot
.4176 .37628 Mdot
.68513 .53935 Mdot
.65324 .51069 Mdot
.53679 .61402 Mdot
.49437 .19288 Mdot
.55758 .94045 Mdot
.69025 .70053 Mdot
.70282 .56272 Mdot
.67035 .59903 Mdot
.45956 .16551 Mdot
.53298 .2055 Mdot
.67154 .60545 Mdot
.49559 .16361 Mdot
.68719 .70698 Mdot
.62692 .86505 Mdot
.6785 .48313 Mdot
.65983 .76463 Mdot
.68113 .73093 Mdot
.68809 .72641 Mdot
.50371 .3579 Mdot
.5078 .18641 Mdot
.61114 .83873 Mdot
.69947 .66864 Mdot
.50446 .35916 Mdot
.66317 .57563 Mdot
.51755 .21898 Mdot
.59772 .30085 Mdot
.63726 .40506 Mdot
.65672 .7257 Mdot
.62669 .34145 Mdot
.68367 .63354 Mdot
.64706 .70721 Mdot
.65376 .55058 Mdot
.70428 .54388 Mdot
.65801 .50494 Mdot
.61566 .83858 Mdot
.64366 .72866 Mdot
.61973 .36427 Mdot
.50118 .36012 Mdot
.61212 .85401 Mdot
.48473 .14693 Mdot
.47344 .32856 Mdot
.69914 .69228 Mdot
.66896 .456 Mdot
.51739 .39251 Mdot
.43502 .70706 Mdot
.42725 .24561 Mdot
.41033 .50749 Mdot
.69769 .62175 Mdot
.67177 .42312 Mdot
.58381 .90158 Mdot
.6909 .71001 Mdot
.56728 .28018 Mdot
.55345 .24645 Mdot
.41886 .32654 Mdot
.40812 .42201 Mdot
.44346 .4239 Mdot
.70365 .66317 Mdot
.67854 .72515 Mdot
.41496 .40115 Mdot
.51778 .67482 Mdot
.45577 .78145 Mdot
.50432 .73756 Mdot
.67925 .75631 Mdot
.40377 .44561 Mdot
.66774 .59294 Mdot
.50026 .72287 Mdot
.41501 .62274 Mdot
.53294 .51518 Mdot
.40617 .4111 Mdot
.59074 .34482 Mdot
.42095 .66522 Mdot
.51834 .64436 Mdot
.67087 .7796 Mdot
.66807 .73453 Mdot
.45902 .60181 Mdot
.57003 .26545 Mdot
.51713 .18199 Mdot
.63397 .45395 Mdot
.52212 .22584 Mdot
.4092 .49437 Mdot
.63122 .82875 Mdot
.58688 .92874 Mdot
.63541 .37209 Mdot
.60842 .29111 Mdot
.52909 .60822 Mdot
.62675 .78826 Mdot
.60397 .84934 Mdot
.41149 .51409 Mdot
.65106 .53642 Mdot
.51135 .69266 Mdot
.51648 .39329 Mdot
.43774 .24405 Mdot
.66519 .5945 Mdot
.52701 .22973 Mdot
.54075 .97928 Mdot
.53231 .56997 Mdot
.59963 .34777 Mdot
.55912 .25023 Mdot
.53852 .5877 Mdot
.53096 .50658 Mdot
.47425 .77413 Mdot
.71116 .63588 Mdot
.52898 .43512 Mdot
.69221 .53471 Mdot
.63671 .36455 Mdot
.62157 .35022 Mdot
.68192 .54262 Mdot
.65672 .60569 Mdot
.55633 .25767 Mdot
.61189 .89318 Mdot
.4367 .71453 Mdot
.71103 .64591 Mdot
.68376 .73993 Mdot
.4154 .4202 Mdot
.69976 .57971 Mdot
.50686 .19757 Mdot
.57505 .31354 Mdot
.68588 .53059 Mdot
.6361 .39358 Mdot
.40719 .52015 Mdot
.48918 .18666 Mdot
.58381 .3194 Mdot
.66214 .80152 Mdot
.61187 .36995 Mdot
.44203 .50853 Mdot
.60613 .35794 Mdot
.53377 .24013 Mdot
.49054 .32125 Mdot
.43544 .68616 Mdot
.59522 .32746 Mdot
.58425 .28231 Mdot
.52853 .46102 Mdot
.46033 .17499 Mdot
.68005 .68971 Mdot
.40395 .50168 Mdot
.63438 .41355 Mdot
.42888 .72036 Mdot
.43238 .27219 Mdot
.50931 .37321 Mdot
.51531 .39967 Mdot
.63533 .35357 Mdot
.64292 .74207 Mdot
.66427 .60961 Mdot
.40861 .52989 Mdot
.68684 .54065 Mdot
.68714 .71374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1Ol00005ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o000000Coooooo`000?l0
003o00001Oooool00ol0003oooooooooo`2iooooo`00XOooool3o`0000?ooooo0_l00003ooooo`03
o`000?oooooooooo0;Wooooo002Rooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0
^Oooool00:Kooooo0_l00004ooooo`?o0000^Oooool00:?ooooo0_l000000ooooooo0000o`000004
ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00001?ooool2o`0000Oooooo0ol0002ioooo
o`00WOooool2o`0000gooooo0ol0002iooooo`00Yoooool2o`000004ooooool0003o0000o`000;_o
oooo002Nooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o0000^oooool009kooooo
0_l00004ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00Yooo
ool2o`0000?ooooo00Co0000ooooool0003o0000^?ooool009kooooo0_l00006ooooo`;o00001?oo
ool4o`000;Sooooo002Nooooo`;o00001_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2
o`000;Gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Wo
oooo0_l0000=ooooo`?o000000?oooooo`000?ooool00_l000000ooooooo0000o`00002eooooo`00
V_ooool2o`0000cooooo0ol000000ooooooo0000ooooo`02o`0000;ooooo0_l0002dooooo`00V_oo
ool2o`0000cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00VOooool2
o`0000oooooo0ol00003ooooo`;o0000]_ooool009Wooooo0_l00005ooooo`;o00002?ooool3o`00
0003ooooool0003o000000;o00001oooool2o`000:gooooo002Looooo`;o00000_ooool2o`0000[o
oooo1_l00007ooooo`;o0000[Oooool009cooooo0_l0000>ooooo`04o`000?ooooooooooooooo`;o
0000]_ooool009Wooooo0ol0000@ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o0000
Zoooool009Wooooo0ol0000@ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o0000Zooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo00;ooooo
0_l0002eooooo`00U_ooool2o`0001Cooooo0ol00004ooooo`;o00000oooool2o`000:kooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`000:kooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Kooooo0_l00002ooooo`;o
00004?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009?ooooo0_l000000ooooooo0000
o`00000Dooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool02?ooool2o`0000Oooooo1?l0002Tooooo`00TOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`08ooooo`;o00001Oooool4o`000:Kooooo002Aooooo`03ogMgMonHV9Sooooo00;o000000?o
ooooo`000?l000000_ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0>ooooo`?o0000Z?ooool008Wooooo1_l00002ooooo`03oa0@4?oooooooooo00;o000000?ooooo
o`000?l000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo0_l0002Y
ooooo`00TOooool3o`000003ooooool0003ooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
013ooooo0_l0002Wooooo`00TOooool3o`000003ooooool0003ooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo013ooooo0_l000000ooooooo0000o`00002Toooo
o`00TOooool00ol@413oooooooooo`03o`0000_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`;o00000_ooool2o`000:Cooooo002Aooooo`03ogMgMonHV9Sooooo00?o0000
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00TOoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo
0_l00002ooooo`;o0000Z?ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Kooooo0ol0
0002ooooo`;o0000Woooool00:cooooo00?o0000ooooooooool04?ooool2o`000004ooooool0003o
0000o`0000;ooooo0_l0002Oooooo`00Toooool4o`0001Gooooo00?o0000ooooooooool04?ooool2
o`0000Kooooo0_l0002Oooooo`00Toooool4o`0001Gooooo0ol0000Hooooo`;o0000Woooool00:co
oooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo
0_l00003ooooo`;o0000Woooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00TOooool4o`0001Oooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002Coooo
o`;o00005oooool00ol0003oooooooooo`0Fooooo`;o00000oooool2o`0000?ooooo0_l0002Goooo
o`00[?ooool00ol0003oooooooooo`0Kooooo`;o00000oooool2o`0009Oooooo002/ooooo`03o`00
0?oooooooooo01;ooooo0_l00006ooooo`;o0000WOooool00:cooooo0ol0000Booooo`;o00001_oo
ool2o`000003ooooool0003o000000;o0000V?ooool00:cooooo00?o0000ooooooooool07Oooool4
o`0009Sooooo002/ooooo`03o`000?oooooooooo023ooooo1?l0002Eooooo`00[?ooool00ol0003o
ooooooooo`0Pooooo`Co0000UOooool00:cooooo00?o0000ooooooooool05Oooool2o`0000Kooooo
0_l0002Jooooo`00S_ooool4o`0001[ooooo00?o0000ooooooooool05Oooool2o`0000Kooooo0_l0
002Jooooo`00S_ooool4o`0001Cooooo0_l00004ooooo`03o`000?oooooooooo01Sooooo0_l0002O
ooooo`00Y_ooool4o`0000;ooooo00?o0000ooooooooool06?ooool2o`0000;ooooo0ol00007oooo
o`;o0000TOooool00:Kooooo1?l00002ooooo`?o00007?ooool3o`0000Oooooo0_l0002Aooooo`00
TOooool2o`00013ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`0Jooooo`Co0000
Voooool0097ooooo0_l0000@ooooo`;o00001?ooool2o`000003ooooool0003ooooo01_ooooo1?l0
0009ooooo`;o0000T?ooool00:Wooooo0_l000000ooooooo0000ooooo`0Vooooo`Co0000T?ooool0
0:cooooo00?o0000ooooooooool08?ooool2o`0000?ooooo0ol0002Aooooo`00Z?ooool2o`000003
ooooool0003o000001oooooo0_l000000ooooooo0000o`00002Gooooo`00Z?ooool2o`000003oooo
ool0003o000001oooooo0_l00007ooooo`;o0000TOooool008kooooo0_l0000Looooo`03o`000?oo
oooooooo01_ooooo0_l00009ooooo`;o0000TOooool008kooooo0_l0000=ooooo`;o00003Oooool0
0ol0003oooooooooo`0Kooooo`Co0000V_ooool009gooooo0_l0000=ooooo`?o00007Oooool2o`00
00Kooooo0_l0002Booooo`00W_ooool2o`0000cooooo00?o0000ooooooooool09Oooool2o`0000;o
oooo0_l0002>ooooo`00W_ooool2o`0000cooooo0ol0000Pooooo`;o00001oooool2o`0008kooooo
002/ooooo`?o00008?ooool2o`0009Oooooo002/ooooo`?o00009?ooool2o`0000Cooooo0_l0002=
ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09?ooool2o`0000Cooooo0_l0
002=ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo
0_l0000;ooooo`;o0000ROooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_l0000Oooooo`;o00001_ooool2o`0000?ooooo0_l00029ooooo`00ROooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool5o`0002Cooooo0_l000000ooooooo0000o`000002o`0008cooooo0029ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000[ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_ooool2o`0000?ooooo0_l0002<ooooo`00
ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo0_l00027ooooo`00ROooool01?o^k^ko
<S8bo`000?lb<S82o`000003ooooool0003o000000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool008gooooo0_l000000ooo
oooo0000o`00000Jooooo`03o`000?oooooooooo02;ooooo0_l00003ooooo`;o0000T?ooool00:co
oooo00?o0000ooooooooool00_ooool2o`0001kooooo0_l00003ooooo`Co00001oooool2o`0008Go
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Nooooo`;o00001Oooool2o`0000Oooooo
0_l00025ooooo`00SOooool4o`0001_ooooo0ol00002ooooo`;o00008?ooool2o`0009?ooooo002=
ooooo`Co00006oooool00ol0003oooooooooo`02ooooo`;o00008?ooool4o`0000Oooooo1?l00026
ooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o00000_ooool2o`0000?ooooo1?l00026oooo
o`00[?ooool00ol0003oooooooooo`0Wooooo`Go00001?ooool2o`0008Oooooo002=ooooo`;o0000
7Oooool00ol0003oooooooooo`0Wooooo`Go00001_ooool2o`0008Gooooo002=ooooo`;o00007Ooo
ool00ol0003oooooooooo`0Yooooo`;o000000?oooooo`000?l000001?ooool2o`0008Gooooo002=
ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`;o00009Oooool2o`0008_ooooo002=oooo
o`Go00006_ooool00ol0003oooooooooo`04ooooo`?o0000/_ooool008gooooo1Ol00007ooooo`;o
00004Oooool3o`0000Cooooo0_l0000_ooooo`;o0000P_ooool008kooooo0_l00009ooooo`;o0000
4Oooool00ol0003oooooooooo`05ooooo`;o00009?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000022ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00009?ooool2o`0000Gooooo0_l0
0025ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000oooo
ooooool01_ooool2o`0002Kooooo0_l00029ooooo`00VOooool2o`00017ooooo00?o0000oooooooo
ool01_ooool2o`0002Cooooo1?l00029ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0
;?ooool2o`0008_ooooo002<ooooo`;o00002oooool2o`00017ooooo00?o0000ooooooooool0^Ooo
ool008cooooo0_l0000Nooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00[?ooool3o`00
00Sooooo0_l0000Zooooo`;o00000_ooool2o`0007oooooo002/ooooo`03o`000?oooooooooo00So
oooo0_l0000Oooooo`;o000000?oooooo`000?l000001_ooool2o`0008?ooooo002/ooooo`03o`00
0?oooooooooo02Wooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00023ooooo`00
2Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool01_ooool2o`00013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool6o`000003ooooool0003o000000?o000000?o<S8bomgM
gOooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooooooo
ool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`?o00003oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`02ooooo`Co00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool0
00Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`;o00003oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h00_l00006ooooo`;o00000oooool4o`0000Sooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool000003Oooool01?nHV9So8B4Qo`000?l00006ooooo`;o00001?ooool2o`00
00Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Ooo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0000Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41000_ooool3o`0001[ooooo00?o0000ooooooooool01oooool2o`0000oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`02ooooo`;o00003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEE
ofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo1_l0000Gooooo`03o`000?oooooooooo
00Oooooo0_l0000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo2?l0000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l0
00005_ooool00:cooooo00?o0000ooooooooool0=?ooool5o`00083ooooo002/ooooo`03o`000?oo
oooooooo03cooooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00009oooool2
o`000003ooooool0003o000000Wooooo0_l0001`ooooo`;o00000_ooool2o`0000Gooooo002>oooo
o`;o00007?ooool00ol0003oooooooooo`05ooooo`;o00009oooool2o`000003ooooool0003o0000
07_ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool0;Oooool2o`0000Oooooo0_l0001gooooo`04omgMgOl0003o410@olc<c0Kooooo0007
oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01_ooool4o`0001cooooo00?o0000ooooooooool01oooool2o`0001kooooo00?o0000
ooooooooool01oooool3o`0000Kooooo1Ol0000Aooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002>oooo
o`;o00002?ooool2o`0001;ooooo00?o0000ooooooooool01oooool2o`0002Sooooo0_l00003oooo
o`;o00001?ooool3o`0007[ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`06ooooo`;o
00009oooool2o`0000Gooooo0_l00021ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0
1_ooool5o`0002Cooooo0_l00028ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool01ooo
ool4o`0003?ooooo0_l0001iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02Oooool2
o`0003?ooooo0_l0001iooooo`00SOooool2o`0001gooooo0ol00006ooooo`;o000000?oooooo`00
0?l00000[_ooool00:cooooo00?o0000ooooooooool01_ooool3o`000;3ooooo002=ooooo`;o0000
7Oooool00ol0003oooooooooo`07ooooo`;o0000<Oooool2o`000003ooooool0003o000007[ooooo
002<ooooo`?o00007Oooool00ol0003oooooooooo`0iooooo`Ko0000N_ooool008cooooo1?l0000L
ooooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0001i
ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0;_ooool2o`0000[ooooo0_l00002oooo
o`;o0000NOooool008kooooo0_l0000Looooo`03o`000?oooooooooo03Wooooo0ol00004ooooo`;o
0000Moooool008kooooo0_l0000Looooo`03o`000?oooooooooo00Oooooo0_l0000Wooooo`;o0000
1oooool2o`0000Gooooo0_l0001gooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool01ooo
ool2o`0002Oooooo0_l00009ooooo`;o0000O?ooool008kooooo0_l0000Looooo`?o0000;oooool2
o`0000[ooooo0_l0001looooo`00[?ooool00ol0003oooooooooo`0_ooooo`;o00002Oooool2o`00
00;ooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0jooooo`?o000000?oooooo`000?l0
0000NOooool00:cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0001looooo`00[?oo
ool00ol0003oooooooooo`0gooooo`;o00001oooool2o`0007Oooooo002Kooooo`;o00003oooool0
0ol0003oooooooooo`10ooooo`;o0000Moooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo
00Kooooo0ol0000Wooooo`;o0000Qoooool00:cooooo00?o0000ooooooooool01_ooool3o`0002Oo
oooo0_l00009ooooo`;o0000O?ooool00:cooooo0ol0000aooooo`?o00001oooool3o`0007_ooooo
002/ooooo`03o`000?oooooooooo037ooooo0ol00008ooooo`;o000000?oooooo`000?l00000N?oo
ool0093ooooo0_l0000Jooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00S_ooool4o`00
01[ooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l0001kooooo`00S_ooool4o`0001[o
oooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o000002gooooo0_l00002ooooo`;o
0000Noooool00:cooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o00000:kooooo
002/ooooo`03o`000?oooooooooo03;ooooo1?l00005ooooo`Co0000N_ooool008kooooo0_l0000L
ooooo`03o`000?oooooooooo03;ooooo1?l00005ooooo`Co0000N_ooool008kooooo0_l0000Loooo
o`?o0000=Oooool2o`0008;ooooo002>ooooo`;o00003_ooool2o`0000cooooo00?o0000oooooooo
ool0<Oooool2o`0000;ooooo0_l00022ooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0
2?ooool3o`0002Gooooo0ol00002ooooo`;o0000P_ooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo00Kooooo1Ol0000Uooooo`;o000000?oooooo`000?l000000_l00022ooooo`00S_ooool5
o`0001Wooooo00?o0000ooooooooool01_ooool4o`0002Wooooo0ol00023ooooo`00S_ooool4o`00
01[ooooo00?o0000ooooooooool02Oooool2o`000:kooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`09ooooo`;o00009_ooool2o`0000kooooo0_l0001fooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01_ooool2o`0002Sooooo0ol0
0003ooooo`;o00001_ooool2o`000003ooooool0003o000007Kooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41001Ol00007ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0000Kooooo0_l0000Xooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o0000NOoo
ool008Wooooo00Go0000ooooooooooooooooo`000002ooooo`?o00002?ooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<Oooool7o`0000Cooooo0_l0
0003ooooo`Co0000M?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03?ooooo
0_l000000ooooooo0000o`000004ooooo`?o00000_ooool4o`0007Cooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool2o`00037ooooo1ol000000ooooooo0000o`00001fooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`00037ooooo1?l000001?oooooo
0000o`000?ooool3o`0007Gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00
00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0d
ooooo`;o00002?ooool6o`0007Gooooo002Cooooo`;o00005oooool00ol0003oooooooooo`03oooo
o`;o0000;oooool2o`000003ooooool0003o000000Oooooo0ol0001fooooo`00[?ooool00ol0003o
ooooooooo`03ooooo`?o0000<Oooool2o`0000Wooooo0_l0001eooooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool00oooool3o`0003Kooooo0_l00004ooooo`;o0000MOooool009?ooooo0_l0
000Gooooo`?o0000>_ooool4o`0000Cooooo0_l0001eooooo`00[?ooool00ol0003oooooooooo`0e
ooooo`;o00000oooool2o`000003ooooool0003o000007[ooooo002/ooooo`03o`000?oooooooooo
03Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000Moooool00:cooooo00?o0000oooooooo
ool01Oooool2o`0002_ooooo0_l0000<ooooo`?o0000M_ooool009Cooooo0_l0000Fooooo`03o`00
0?oooooooooo00Gooooo0_l0000[ooooo`;o00001Oooool2o`0000Gooooo0ol0001fooooo`00TOoo
ool2o`000003ooooool0003o000001Kooooo00?o0000ooooooooool01Oooool2o`0002_ooooo0_l0
0003ooooo`Go00001?ooool2o`0007Oooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0b
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0007Cooooo002/ooooo`03o`000?oooooooooo03Gooooo0_l00007ooooo`;o00000oooool2o`00
07Cooooo002/ooooo`?o000000Coooooo`000?l0003o0000]Oooool009Cooooo0_l0000Fooooo`03
o`000?oooooooooo00Co0000?Oooool2o`0007Kooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`02o`00033ooooo0_l0000;ooooo`Co0000M_ooool009Kooooo0_l0000Dooooo`03o`000?oo
oooooooo03;ooooo0ol000000ooooooo0000o`000007ooooo`Co0000M_ooool009?ooooo0_l00000
0ooooooo0000o`00000Dooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l00003ooooo`;o0000M_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo
03Oooooo0ol00002ooooo`Co0000NOooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;o
0000<Oooool2o`0000?ooooo0_l00004ooooo`;o0000NOooool009Kooooo0_l0000Dooooo`03o`00
0?oooooooooo00;o0000<Oooool2o`0000Cooooo0_l0001nooooo`00[?ooool3o`0003Gooooo0_l0
0002ooooo`Co0000O?ooool00:cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l0001l
ooooo`00U_ooool2o`0001Cooooo0ol0000]ooooo`;o00002oooool2o`0007gooooo002Fooooo`;o
00005?ooool3o`0002gooooo1Ol00008ooooo`Co0000Noooool00:cooooo00?o0000ooooooooool0
0_ooool2o`0002[ooooo1?l0000:ooooo`;o0000Noooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo00;ooooo0_l0000Zooooo`;o000000?oooooo`000?l000001oooool2o`0007gooooo002G
ooooo`;o00004oooool00ol0003oooooooooo`0aooooo`;o00001oooool2o`0007gooooo002Doooo
o`;o00005_ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool009Cooooo0_l0000Fooooo`?o
0000=?ooool2o`0000;ooooo0ol0001nooooo`00Uoooool2o`0001?ooooo0_l0000]ooooo`;o0000
0_ooool2o`0000;ooooo0_l00002ooooo`Go0000O?ooool009Oooooo0ol00002ooooo`;o00003_oo
ool00ol0003oooooooooo`0/ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`00
001looooo`00V?ooool6o`0000gooooo0_l0000dooooo`Co00000_ooool2o`0007oooooo002Joooo
o`;o000000?oooooo`000?l000003?ooool4o`0003Cooooo0_l00023ooooo`00WOooool2o`0000Ko
oooo0_l00005ooooo`?o0000;oooool2o`0000Sooooo0_l000000ooooooo0000o`00001kooooo`00
TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`03odA4A?l0003o000000;o
00001Oooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Co
oooo1Ol0001kooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42o`0000Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0/ooooo`;o00001Oooool3o`0000?o
oooo1?l0001looooo`00TOooool01Ol@413ooooooooooooooooo410@00Oooooo0_l00007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000008?o
oooo002Aooooo`05o`000?ooooooooooooooool000003?ooool2o`000003oooooomgMgOo<S8b00Go
oooo0ol0000aooooo`;o0000Q_ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`?o
000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000POooool0097ooooo
00Go410@oooooooooooooooooa0@4004ooooo`;o00001_ooool01?l0003oooooooooooooool2o`00
00Cooooo00?o0000ooooooooool0<_ooool3o`000003ooooool0003o000000;o0000Ooooool0097o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001_ooool01?l0003oooooooooooooool2
o`0000Cooooo00?o0000ooooooooool0<_ooool3o`0000?ooooo0_l0001oooooo`00TOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00006ooooo`03o`000?oooooooooo033ooooo0ol00026
ooooo`00XOooool2o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo033ooooo0ol00026oooo
o`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00
W_ooool2o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo02[ooooo0_l00006ooooo`;o0000
QOooool009kooooo0ol00002ooooo`;o00001oooool3o`0003;ooooo0_l00025ooooo`00W_ooool3
o`0000_ooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000008;ooooo002Moooo
o`Co00002oooool00ol0003oooooooooo`0eooooo`;o0000P_ooool009gooooo0_l0000=ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00[?oo
ool00ol0003oooooooooo`0Vooooo`;o00002oooool2o`0008Cooooo002/ooooo`03o`000?oooooo
oooo03?ooooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o0000QOooool00:cooooo00?o
0000ooooooooool09_ooool2o`0000Oooooo0_l000000ooooooo0000o`000025ooooo`00[?ooool0
0ol0003oooooooooo`0Uooooo`;o00000oooool2o`0000?ooooo0_l00028ooooo`00[?ooool00ol0
003oooooooooo`0Uooooo`;o00000oooool2o`0008gooooo002/ooooo`03o`000?oooooooooo02ko
oooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o00001oooool2o`0008Wooooo
002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo02Cooooo0_l00005ooooo`;o0000S?ooool00:cooooo00?o0000oooooooo
ool09?ooool2o`0000;ooooo0_l000000ooooooo0000o`00002<ooooo`00[?ooool00ol0003ooooo
ooooo`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool08Oooool4o`0009Cooooo002/ooooo`03o`000?oooooooooo023ooooo1Ol0002Doooo
o`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool0
7oooool3o`0009Oooooo002/ooooo`?o00007oooool3o`0009Oooooo002/ooooo`03o`000?oooooo
oooo023ooooo1?l000000ooooooo0000o`00002Booooo`00[?ooool00ol0003oooooooooo`0Roooo
o`;o000000?oooooo`000?l00000T_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0Vooooo`;o0000TOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool09_ooool2o`00097ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool2o`0000Co
oooo0_l0002Fooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`?o00006oooool2o`0000Cooooo0_l0002Fooooo`00
ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool2
o`000003ooooool0003o000009[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000o`00002J
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o
0000U_ooool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`?o0000^Ooo
ool00:cooooo00?o0000ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo
01Sooooo0_l000000ooooooo0000o`00002Looooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o
0000W?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool05?oo
ool2o`000:?ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0I
ooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`03
o`000?oooooooooo013ooooo0_l00003ooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool0
4?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o00003?ooool2o`0000?ooooo0_l0002Vooooo`00[?ooool00ol0003o
ooooooooo`0<ooooo`;o00000oooool2o`000:Kooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`0>ooooo`;o0000ZOooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00kooooo0_l0
002Yooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0?oooo
o`;o0000Z?ooool00:cooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l0002Xooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool02_ooool2o`000:gooooo002=ooooo`;o00007Ooo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool00ol0
003oooooooooo`0:ooooo`?o0000[?ooool00:cooooo00?o0000ooooooooool02oooool2o`000:co
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002R
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00Y?ooool00ol0003o
ooooooooo`05ooooo`?o00001?ooool2o`000;?ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`00
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Go
oooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko
0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIV
I_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62695 .36277 Mdot
.64206 .38053 Mdot
.47834 .36469 Mdot
.55143 .4954 Mdot
.45589 .80535 Mdot
.57938 .26375 Mdot
.48594 .66647 Mdot
.64611 .78954 Mdot
.58024 .86149 Mdot
.5498 .62181 Mdot
.52719 .70398 Mdot
.58261 .88354 Mdot
.66261 .41608 Mdot
.55944 .5982 Mdot
.47596 .98683 Mdot
.55669 .52728 Mdot
.49854 .16244 Mdot
.66347 .41669 Mdot
.50765 .76856 Mdot
.6885 .54391 Mdot
.66678 .50871 Mdot
.65725 .46645 Mdot
.65453 .55141 Mdot
.66786 .44913 Mdot
.46586 .99244 Mdot
.41553 .7062 Mdot
.48145 .78485 Mdot
.47622 .79994 Mdot
.68317 .58761 Mdot
.65064 .43625 Mdot
.65508 .60165 Mdot
.61266 .81723 Mdot
.60379 .84509 Mdot
.55278 .24922 Mdot
.52929 .19203 Mdot
.65153 .66508 Mdot
.64038 .74224 Mdot
.47064 .79379 Mdot
.64911 .6976 Mdot
.61036 .85088 Mdot
.53592 .94721 Mdot
.53347 .20485 Mdot
.56964 .25732 Mdot
.60847 .29503 Mdot
.59952 .28434 Mdot
.43972 .78532 Mdot
.52535 .7006 Mdot
.64692 .75339 Mdot
.39798 .46781 Mdot
.66186 .65741 Mdot
.63597 .77147 Mdot
.66814 .66211 Mdot
.38432 .1395 Mdot
.57086 .26749 Mdot
.53311 .19094 Mdot
.58391 .86366 Mdot
.6293 .81612 Mdot
.47015 .14539 Mdot
.64592 .74462 Mdot
.59486 .27599 Mdot
.419 .70875 Mdot
.4435 .9927 Mdot
.63252 .73332 Mdot
.49928 .28722 Mdot
.5237 .9396 Mdot
.6133 .82035 Mdot
.54268 .64409 Mdot
.54755 .58566 Mdot
.50331 .76959 Mdot
.67058 .48967 Mdot
.4206 .23184 Mdot
.48046 .68556 Mdot
.53174 .67864 Mdot
.55124 .60329 Mdot
.63209 .7341 Mdot
.50609 .4463 Mdot
.3851 .13566 Mdot
.40757 .37878 Mdot
.67308 .64276 Mdot
.46154 .16965 Mdot
.65372 .63293 Mdot
.65124 .45414 Mdot
.54941 .51344 Mdot
.52392 .18692 Mdot
.64323 .78698 Mdot
.55729 .44782 Mdot
.45491 .80509 Mdot
.40783 .60045 Mdot
.43555 .19184 Mdot
.54438 .60228 Mdot
.44587 .97599 Mdot
.35744 .44549 Mdot
.50992 .30511 Mdot
.43469 .76735 Mdot
.51462 .32187 Mdot
.3618 .65215 Mdot
.55879 .5992 Mdot
.59709 .83135 Mdot
.38444 .13683 Mdot
.40957 .2935 Mdot
.63468 .3903 Mdot
.40907 .30418 Mdot
.54983 .92122 Mdot
.62079 .32603 Mdot
.67024 .54861 Mdot
.55481 .25116 Mdot
.45178 .1535 Mdot
.5069 .77347 Mdot
.50911 .30263 Mdot
.66959 .51563 Mdot
.5591 .59074 Mdot
.54879 .4418 Mdot
.60593 .82615 Mdot
.67958 .57189 Mdot
.42965 .55808 Mdot
.40495 .59119 Mdot
.65174 .76384 Mdot
.64256 .77546 Mdot
.60388 .80186 Mdot
.6644 .43439 Mdot
.65375 .58277 Mdot
.68731 .57074 Mdot
.67048 .50237 Mdot
.55065 .53474 Mdot
.67433 .60307 Mdot
.36879 .72549 Mdot
.64755 .48 Mdot
.45488 .30614 Mdot
.65926 .50015 Mdot
.64171 .42157 Mdot
.55482 .91929 Mdot
.562 .22522 Mdot
.57462 .2631 Mdot
.68496 .59517 Mdot
.67694 .65777 Mdot
.67672 .60531 Mdot
.52846 .68624 Mdot
.57037 .89052 Mdot
.49518 .98029 Mdot
.37054 .71335 Mdot
.53219 .36469 Mdot
.51337 .75425 Mdot
.49285 .15502 Mdot
.68567 .54921 Mdot
.64652 .77818 Mdot
.42378 .69592 Mdot
.40836 .61302 Mdot
.55622 .94034 Mdot
.40149 .36938 Mdot
.53073 .70977 Mdot
.6671 .43296 Mdot
.48778 .6771 Mdot
.61528 .35622 Mdot
.66158 .69021 Mdot
.64793 .70446 Mdot
.63232 .79525 Mdot
.62792 .76455 Mdot
.66563 .68197 Mdot
.40351 .61794 Mdot
.68076 .61833 Mdot
.61632 .85297 Mdot
.64628 .67018 Mdot
.59483 .32397 Mdot
.63958 .43225 Mdot
.64099 .78591 Mdot
.67294 .54227 Mdot
.50131 .77201 Mdot
.68188 .63673 Mdot
.64728 .68748 Mdot
.54281 .44361 Mdot
.48374 .78956 Mdot
.42218 .70872 Mdot
.4382 .75672 Mdot
.56706 .89184 Mdot
.36232 .65573 Mdot
.61632 .36268 Mdot
.43561 .3936 Mdot
.67157 .63367 Mdot
.68535 .61737 Mdot
.59036 .8797 Mdot
.5599 .53551 Mdot
.53438 .94994 Mdot
.46926 .28136 Mdot
.55888 .88692 Mdot
.36216 .64203 Mdot
.64444 .76675 Mdot
.61036 .85941 Mdot
.56164 .23729 Mdot
.49778 .99785 Mdot
.68677 .54137 Mdot
.50046 .29543 Mdot
.41991 .94551 Mdot
.63989 .79549 Mdot
.55985 .92698 Mdot
.55537 .91661 Mdot
.43026 .75038 Mdot
.35613 .55741 Mdot
.44627 .15675 Mdot
.43256 .43351 Mdot
.43281 .42831 Mdot
.47582 .68828 Mdot
.42706 .72884 Mdot
.35528 .47737 Mdot
.64162 .43428 Mdot
.49949 .30205 Mdot
.5915 .28939 Mdot
.53862 .37876 Mdot
.44806 .30783 Mdot
.53907 .67622 Mdot
.65602 .39802 Mdot
.40431 .42483 Mdot
.67245 .54698 Mdot
.5525 .57952 Mdot
.64101 .44244 Mdot
.40627 .40174 Mdot
.60615 .86656 Mdot
.44303 .32809 Mdot
.61616 .34294 Mdot
.62583 .82741 Mdot
.40808 .62984 Mdot
.61193 .80263 Mdot
.6739 .52385 Mdot
.64578 .66203 Mdot
.54085 .62391 Mdot
.45756 .80246 Mdot
.62742 .32756 Mdot
.53574 .39562 Mdot
.47926 .98693 Mdot
.50742 .99325 Mdot
.55609 .49257 Mdot
.51075 .56175 Mdot
.36624 .28027 Mdot
.4334 .20844 Mdot
.51212 .74215 Mdot
.48258 .79176 Mdot
.62274 .32813 Mdot
.66256 .52199 Mdot
.63931 .40891 Mdot
.42907 .96851 Mdot
.55725 .22261 Mdot
.67693 .53628 Mdot
.42086 .23096 Mdot
.63585 .78256 Mdot
.52488 .35866 Mdot
.63465 .74359 Mdot
.50381 .17756 Mdot
.4183 .24201 Mdot
.64239 .71414 Mdot
.54886 .93784 Mdot
.42916 .54661 Mdot
.5179 .34725 Mdot
.62103 .7706 Mdot
.40052 .52505 Mdot
.47988 .79027 Mdot
.50408 .14228 Mdot
.50743 .45545 Mdot
.60959 .84203 Mdot
.64884 .7451 Mdot
.40624 .34068 Mdot
.51362 .73906 Mdot
.64792 .65977 Mdot
.43912 .3621 Mdot
.41444 .27638 Mdot
.62927 .38242 Mdot
.5073 .74097 Mdot
.6042 .33904 Mdot
.64556 .68529 Mdot
.40792 .35176 Mdot
.6671 .62278 Mdot
.52687 .17878 Mdot
.55835 .5843 Mdot
.42984 .22539 Mdot
.6683 .67307 Mdot
.56201 .51544 Mdot
.50446 .78377 Mdot
.62838 .7859 Mdot
.55239 .63535 Mdot
.60399 .31963 Mdot
.67464 .6289 Mdot
.42703 .45268 Mdot
.54045 .63814 Mdot
.61988 .77798 Mdot
.56691 .90015 Mdot
.51099 .76696 Mdot
.4887 .67093 Mdot
.40959 .59131 Mdot
.68329 .53155 Mdot
.41274 .66023 Mdot
.65095 .6366 Mdot
.35983 .59394 Mdot
.62901 .77245 Mdot
.50452 .9684 Mdot
.60313 .81333 Mdot
.51101 .57732 Mdot
.66289 .70624 Mdot
.39856 .8723 Mdot
.68274 .51177 Mdot
.48218 .98527 Mdot
.41083 .31543 Mdot
.51652 .15678 Mdot
.63993 .40336 Mdot
.62615 .79764 Mdot
.50624 .97637 Mdot
.5313 .68835 Mdot
.61646 .80385 Mdot
.40036 .53301 Mdot
.43098 .48532 Mdot
.65951 .42821 Mdot
.49574 .15707 Mdot
.66478 .454 Mdot
.55396 .94112 Mdot
.42831 .47229 Mdot
.62189 .36002 Mdot
.54779 .23515 Mdot
.51867 .94663 Mdot
.42964 .4311 Mdot
.57819 .89498 Mdot
.42556 .94979 Mdot
.39357 .86979 Mdot
.55281 .53303 Mdot
.5478 .1982 Mdot
.51097 .16517 Mdot
.62938 .74339 Mdot
.48439 .81213 Mdot
.43378 .58499 Mdot
.49974 .63209 Mdot
.45549 .15072 Mdot
.63431 .81232 Mdot
.60586 .79426 Mdot
.50587 .29801 Mdot
.65687 .42119 Mdot
.44734 .32329 Mdot
.47172 .68757 Mdot
.6303 .33589 Mdot
.56932 .24335 Mdot
.59424 .3218 Mdot
.40196 .59573 Mdot
.42454 .71574 Mdot
.36411 .28103 Mdot
.40422 .39641 Mdot
.65029 .47995 Mdot
.51296 .32406 Mdot
.58549 .86562 Mdot
.47986 .78415 Mdot
.67428 .61133 Mdot
.6533 .50732 Mdot
.51571 .3154 Mdot
.40719 .40073 Mdot
.37513 .75413 Mdot
.59865 .86306 Mdot
.67533 .67727 Mdot
.65559 .65676 Mdot
.4004 .42687 Mdot
.47468 .13639 Mdot
.65421 .66868 Mdot
.42116 .24768 Mdot
.59412 .86867 Mdot
.42405 .96984 Mdot
.67735 .53783 Mdot
.54841 .92596 Mdot
.5734 .90133 Mdot
.57423 .90636 Mdot
.46215 .68194 Mdot
.42761 .2285 Mdot
.48372 .98667 Mdot
.62156 .82611 Mdot
.46073 .68088 Mdot
.65718 .60817 Mdot
.42564 .25445 Mdot
.57924 .25888 Mdot
.63301 .38481 Mdot
.59061 .84213 Mdot
.62442 .33446 Mdot
.64527 .73713 Mdot
.60799 .78636 Mdot
.65338 .55417 Mdot
.68146 .65729 Mdot
.65788 .51256 Mdot
.47963 .99231 Mdot
.5932 .82054 Mdot
.60725 .32422 Mdot
.46914 .68045 Mdot
.45732 .99365 Mdot
.4186 .24915 Mdot
.50096 .62642 Mdot
.60222 .86592 Mdot
.67084 .49308 Mdot
.4394 .62686 Mdot
.54767 .62113 Mdot
.40774 .64084 Mdot
.50486 .75757 Mdot
.65092 .74819 Mdot
.67707 .47536 Mdot
.40629 .90392 Mdot
.58948 .88147 Mdot
.51477 .18245 Mdot
.37854 .17734 Mdot
.49828 .15446 Mdot
.44759 .77945 Mdot
.46606 .80652 Mdot
.51298 .48562 Mdot
.62443 .82533 Mdot
.58081 .88526 Mdot
.48478 .78278 Mdot
.53169 .37098 Mdot
.55674 .63182 Mdot
.56023 .477 Mdot
.54508 .94706 Mdot
.45512 .81069 Mdot
.65613 .64231 Mdot
.54426 .42472 Mdot
.52241 .72831 Mdot
.43707 .37005 Mdot
.4508 .80157 Mdot
.5498 .24502 Mdot
.53199 .70308 Mdot
.50171 .30644 Mdot
.52036 .97822 Mdot
.57688 .88235 Mdot
.46021 .39467 Mdot
.53043 .1924 Mdot
.45379 .15105 Mdot
.62777 .4088 Mdot
.43065 .23459 Mdot
.49768 .7763 Mdot
.36849 .73734 Mdot
.63353 .36497 Mdot
.60569 .28468 Mdot
.49088 .28034 Mdot
.54241 .90918 Mdot
.47323 .98831 Mdot
.51015 .74131 Mdot
.65144 .53077 Mdot
.36961 .2321 Mdot
.53621 .38928 Mdot
.4414 .63333 Mdot
.42569 .71131 Mdot
.65485 .63884 Mdot
.4389 .2059 Mdot
.35606 .50647 Mdot
.4644 .28216 Mdot
.56941 .26893 Mdot
.51129 .16801 Mdot
.4961 .27681 Mdot
.4332 .40747 Mdot
.56068 .54446 Mdot
.64156 .79677 Mdot
.42729 .51313 Mdot
.67873 .6212 Mdot
.63688 .36519 Mdot
.61321 .32449 Mdot
.67203 .60821 Mdot
.6494 .636 Mdot
.49844 .15858 Mdot
.39401 .88443 Mdot
.5486 .61939 Mdot
.63491 .8121 Mdot
.56179 .92372 Mdot
.49606 .76179 Mdot
.66889 .69293 Mdot
.41882 .28163 Mdot
.52 .20031 Mdot
.67624 .60288 Mdot
.63206 .37609 Mdot
.49368 .79219 Mdot
.40576 .42056 Mdot
.54017 .22386 Mdot
.59132 .30645 Mdot
.49888 .39802 Mdot
.58143 .28814 Mdot
.44829 .1845 Mdot
.47701 .69157 Mdot
.54691 .58089 Mdot
.5646 .25426 Mdot
.55658 .22603 Mdot
.42887 .49988 Mdot
.40096 .48284 Mdot
.6115 .82333 Mdot
.47404 .81771 Mdot
.62806 .38257 Mdot
.53711 .70367 Mdot
.4404 .75356 Mdot
.45312 .66826 Mdot
.44493 .64068 Mdot
.63668 .35825 Mdot
.58201 .8457 Mdot
.65108 .65877 Mdot
.5012 .77452 Mdot
.67491 .61657 Mdot
.58771 .88094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Gooooo0ol000001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`?o00001oooool0
0ol0003oooooooooo`2iooooo`00QOooool3o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00009Oooool3
o`000;Wooooo002Rooooo`;o00002?ooool3o`000;Wooooo002Rooooo`;o00002?ooool00ol0003o
ooooooooo`2iooooo`00W?ooool3o`0000gooooo0ol0002iooooo`00W?ooool3o`0000[ooooo1?l0
002kooooo`00V_ooool4o`0000_ooooo1?l00004ooooo`;o0000]Oooool009[ooooo0_l0000>oooo
o`?o00001?ooool2o`000;Gooooo002[ooooo`;o00000_ooool2o`000;Oooooo002[ooooo`;o0000
0_ooool2o`000;Oooooo002Oooooo`;o00002oooool00ol0003oooooooooo`02o`000;Oooooo002O
ooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00Poooool2o`0002Oooooo0ol0002ioooo
o`00Poooool2o`0002Oooooo0ol00005ooooo`;o0000/_ooool00:cooooo0ol000000ooooooo0000
o`000002ooooo`;o0000/_ooool009[ooooo0_l0000@ooooo`04o`000?ooooooooooooooo`;o0000
]_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool01?ooool5o`000;3ooooo002Fooooo`;o00005?ooool00ol0
003oooooooooo`06ooooo`?o0000/?ooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_o
oooo002/ooooo`?o00000oooool2o`0000Oooooo0_l0002[ooooo`00[?ooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00Sooooo0_l0002_
ooooo`00U_ooool3o`0001?ooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool0
09Cooooo0_l0000Fooooo`?o00002_ooool2o`0000?ooooo1?l0002Vooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool02_ooool2o`0000?ooooo1?l0002Vooooo`00TOooool2o`000003oooo
ool0003o000001Kooooo00?o0000ooooooooool03oooool2o`000:Sooooo0021ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o00004_ooool2
o`0001Gooooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l0002Vooooo`00[?ooool00ol0
003oooooooooo`0<ooooo`;o00000oooool2o`000:Kooooo002Aooooo`?o000000?o<S8bonk^k_oo
ool01?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00TOooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`0000Cooooo0_l0002Tooooo`00
ROooool6o`0000;ooooo0ol000000ooooooo410@ooooo`0?ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03Oooool3o`000:Wooooo002Aooooo`?o000000?oooooo`000?ooool03_oo
ool00omgMgOo<S8booooo`04ooooo`?o00003_ooool3o`000:Sooooo002Aooooo`03o`000?oooooo
000000;o00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03ooo
ool2o`000003ooooool0003o00000:Gooooo002Aooooo`05oa0@4?oooooo0000o`000?l@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo1?l000000ooooooo0000o`00
002Pooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?l00000X?ooool0097ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Eooooo`Co0000X?oo
ool00:cooooo00?o0000ooooooooool05?ooool5o`000:3ooooo002/ooooo`03o`000?oooooooooo
01?ooooo0ol0002Sooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008oooooo
0_l0000Iooooo`Go00007?ooool2o`0009_ooooo001oooooo`;o00003_ooool2o`0001Sooooo1?l0
000Nooooo`;o0000Voooool007oooooo0_l0000@ooooo`;o00003Oooool3o`0000Kooooo0_l00000
0ooooooo0000ooooo`2jooooo`00Ooooool2o`00013ooooo0_l0000=ooooo`?o00002Oooool00ol0
003oooooooooo`0Mooooo`Co0000V?ooool00:_ooooo0_l0000Iooooo`;o00000_ooool6o`0009So
oooo002[ooooo`;o00006Oooool2o`0000;ooooo0_l0002Looooo`00S_ooool2o`0001cooooo0_l0
000Qooooo`;o0000Uoooool008kooooo0_l0000Looooo`Co00007oooool2o`0009Oooooo002/oooo
o`Co0000^?ooool008kooooo0_l0000Kooooo`;o00000_ooool2o`000;Oooooo002>ooooo`;o0000
3Oooool2o`0000cooooo0ol000000ooooooo0000o`00000Iooooo`;o0000W?ooool009[ooooo0_l0
00000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000006Oooool2o`0009cooooo002J
ooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001cooooo00?o0000oooo
ooooool00_ooool2o`000;Gooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`;o
00006oooool2o`0009Sooooo002/ooooo`04o`000?ooooooooooooooo`;o00006Oooool2o`000003
ooooool0003o000009Sooooo002Jooooo`;o00004?ooool3o`000003ooooool0003o000001Wooooo
0_l00002ooooo`Co0000UOooool009Wooooo0ol0000@ooooo`04o`000?ooooooooooooooo`;o0000
6Oooool2o`0000;ooooo2Ol0002@ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool09?oo
ool5o`00093ooooo002/ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00[?ooool00ol0
003oooooooooo`0Vooooo`Co0000Soooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01oo
oooo0_l00007ooooo`;o0000Soooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01oooooo
0_l00002ooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool08oooool2o`0009Cooooo002/
ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00SOooool2o`0001gooooo0ol00002oooo
o`;o0000]Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00Gooooo0_l0000Looooo`;o00001Oooool2o`0008gooooo002Gooooo`;o00004ooo
ool00ol0003oooooooooo`05ooooo`;o00007?ooool4o`0000?ooooo0_l0002=ooooo`00Uoooool2
o`0000_ooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo0_l0000Jooooo`Go000000Cooooo
o`000?l0003o0000SOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o0000omgMg@05ooooo`03o`000?oooooooooo00Oooooo
0_l0000Jooooo`;o000000Coooooo`000?l0003ooooo0ol0002=ooooo`00ROooool01OmgMgOoV9RH
o`000?l0003oMgMg00Gooooo0_lQ8B42ooooo`;o000000GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01oooool2o`000;3ooooo0021ooooo`Ko
00000_ooool01Ol@413oooooo`000?l0003o410@00Wooooo0_l000001?ooooooV9RHob4Q8Oo^k^h9
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool2o`000;3ooooo0029oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000Xooooo`;o0000Soooool008Wooooo00Co0000oooooooooooooooo0_l0000=
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo00Wooooo0_l0000Mooooo`;o0000Soooool008Wooooo00Co410@oooooooooooooooo0_l0
000>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`;o00007?ooool2o`0000;ooooo0_l0002<ooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09oooool3o`000003ooooool0003o000008cooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03
o`000?oooooooooo00Wooooo0_l0000Mooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0
2Oooool2o`0001kooooo0_l0002>ooooo`00U_ooool2o`0000Kooooo0_l0000<ooooo`03o`000?oo
oooooooo02Wooooo0_l0002>ooooo`00S?ooool2o`0000Sooooo0_l00006ooooo`;o00002oooool2
o`0000[ooooo0_l0000Vooooo`;o0000Qoooool008cooooo0ol0000Looooo`Co00002?ooool2o`00
02Kooooo0_l00027ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0:oooool2o`0008co
oooo002=ooooo`;o00001oooool2o`0001Cooooo00?o0000ooooooooool0:oooool2o`0008cooooo
002Fooooo`;o00005?ooool00ol0003oooooooooo`0Wooooo`;o00000_ooool2o`0008cooooo002/
ooooo`03o`000?oooooooooo02Oooooo0_l00002ooooo`;o0000S?ooool00:cooooo00?o0000oooo
ooooool0<_ooool3o`0008Cooooo002/ooooo`03o`000?oooooooooo03;ooooo0ol00024ooooo`00
S?ooool2o`0001kooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l00027ooooo`00S?oo
ool2o`0001kooooo0ol0000;ooooo`;o00007_ooool2o`0000?ooooo0_l00027ooooo`00Roooool3
o`0000Oooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo0_l0000Tooooo`;o0000Q_ooool0
08_ooooo0_l00007ooooo`?o00005Oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool009Co
oooo0ol0000Eooooo`03o`000?oooooooooo02_ooooo0_l00006ooooo`?o0000Poooool009Gooooo
0_l0000Eooooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000o`000003ooooo`?o0000
Poooool00:cooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooo
oooo00_ooooo1?l0000Looooo`;o0000S?ooool007gooooo0_l0000]ooooo`04o`000?oooooo0000
o`0000[ooooo1?l0000Looooo`;o0000S?ooool007gooooo0_l0000]ooooo`04o`000?oooooo0000
o`0000kooooo0_l0000Sooooo`;o0000Poooool009?ooooo0_l0000Gooooo`?o00003oooool2o`00
02?ooooo0_l00023ooooo`00Toooool2o`0001Oooooo00Co0000ooooool0003o0000;Oooool2o`00
00?ooooo0_l00024ooooo`00[?ooool01?l0003oooooo`000?l0000]ooooo`;o00000oooool2o`00
08Cooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool0
00_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So0000o`000009ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01?ooool2o`0000?ooooo00?o0000
ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Ooo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000gooooo0_l000000oo^k^koooooooooo`05ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h00oooool2o`0000;ooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o0000ob4Q8Ol000000_l0000Fooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02o`0001Kooooo0ol0000@ooooo`;o00001_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`;o00003?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`04ogMgMonHV9SooooooiRHV0;o00002_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`;o00001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4003o`000003ooooool0003ooooo00Co
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Cok^k^oc8b<_l0003o<S8b0_l0000:ooooo`03
oiRHV?l@413o000000;o00001?ooool4o`0001Oooooo00?o0000ooooooooool06?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003o`000003ooooool0003o
000000;o00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo
002;ooooo`;o00002?ooool2o`0001Gooooo00Co0000oooooooooooooooo0_l0002fooooo`00UOoo
ool2o`0001Gooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0003ooooooooo
o`0eooooo`;o0000Moooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0>
ooooo`?o00009?ooool2o`0007Oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`?o00009?ooool2o`0007Sooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00000_ooool3o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool2o`0000Gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo
0_l00004ooooo`;o00006Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00O?ooool2o`0002kooooo00?o
0000ooooooooool0;oooool2o`0000?ooooo0_l00023ooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool03Oooool2o`0002;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000O_ooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o00007_ooool2o`00
00;ooooo0_l00002ooooo`;o0000O_ooool00:cooooo00?o0000ooooooooool04Oooool2o`0002;o
oooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0booooo`;o0000QOooool008_ooooo0_l0
000Oooooo`?o0000<_ooool2o`0000;ooooo0_l00021ooooo`00Roooool2o`0001oooooo00?o0000
ooooooooool03oooool2o`0002Gooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0?oooo
o`;o00007_ooool2o`0000Sooooo0_l0001nooooo`00Roooool2o`0001oooooo00?o0000oooooooo
ool03Oooool3o`0001oooooo0_l00008ooooo`;o0000O_ooool008_ooooo0_l0000Oooooo`03o`00
0?oooooooooo00gooooo1Ol0000Uooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool04?oo
ool2o`0002Gooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool3
o`0007cooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Aooooo`;o00008oooool2o`00
00;ooooo0ol0001looooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool04Oooool2o`0002;o
oooo0_l00003ooooo`;o0000OOooool00:cooooo0ol0000`ooooo`;o00000oooool2o`0000?ooooo
0_l0001mooooo`00[?ooool00ol0003oooooooooo`0_ooooo`?o0000Qoooool007cooooo0_l0000F
ooooo`;o00005_ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool007cooooo0_l0000Foooo
o`;o00005_ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`03o`000?oooooooooo00;o
0000]oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0>_oo
ool2o`0007gooooo002/ooooo`03o`000?oooooooooo03Sooooo1?l0001mooooo`00[?ooool3o`00
03Sooooo0_l0001oooooo`00[?ooool00ol0003oooooooooo`02o`0000cooooo0_l0002Yooooo`00
[?ooool00ol0003oooooooooo`02o`0000[ooooo1?l0000Oooooo`;o0000R?ooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00007Oooool2o`0008Sooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`;o00000_ooool2o`0002Oooooo0_l0001n
ooooo`00S?ooool4o`0001cooooo00?o0000ooooooooool04?ooool2o`0002Oooooo0_l0001noooo
o`00OOooool2o`0000gooooo1?l0000Looooo`03o`000?oooooooooo013ooooo0_l0000Xooooo`;o
0000OOooool007gooooo0_l0000<ooooo`;o00007oooool00ol0003oooooooooo`0@ooooo`;o0000
:?ooool2o`0007gooooo002;ooooo`Co00007Oooool3o`00013ooooo0_l0002Wooooo`00SOooool2
o`0001gooooo00?o0000ooooooooool02oooool4o`000003ooooool0003o000001kooooo0_l00004
ooooo`?o0000P?ooool00:cooooo00?o0000ooooooooool02oooool4o`00027ooooo0_l00004oooo
o`?o0000P?ooool00:cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo1?l00020ooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0ol00021ooooo`00SOoo
ool2o`0001gooooo00?o0000ooooooooool0=_ooool2o`00087ooooo0029ooooo`03onk^k_lb<S;o
000000;o00001Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0=ooooo`;o00009oooool6o`0007gooooo0029ooooo`03ogMgMonHV9So
oooo00;o00001Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03?ooool3o`0002Wooooo1?l0001mooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o00002_ooool5o`0002Gooooo0_l00002ooooo`;o0000Ooooool008Wooooo00Go0000
ooooooooooooooooo`00000:ooooo`;o000000CooooooiRHV?lQ8B7ok^k^1oooool00omgMgOo<S8b
ooooo`04ooooo`;o00002oooool2o`0002Sooooo0_l00023ooooo`00ROooool01?l0003ooooooooo
ooooool2o`0000Wooooo0_l00002ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`;o0000=oooool2o`00087ooooo0029ooooo`04oa0@4?ooooooooooooooo`;o
00002Oooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o
00004Oooool2o`0001kooooo0_l00004ooooo`?o0000POooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0:ooooo`;o000000Co^[ZjoooooonHV9So410@1?ooool00ol0003oooooooooo`06oooo
o`;o00004?ooool3o`0001gooooo0ol00004ooooo`;o00000_ooool2o`0007kooooo0029ooooo`04
onk^k_lb<S;o0000oc8b<P;o00002_ooool3o`000003ob4Q8Oo<c<cooooo00?ooooo1?l00006oooo
o`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o00007_ooool4o`0000Oooooo0_l0001noooo
o`00O_ooool2o`0000gooooo0_l0000:ooooo`;o00004Oooool00ol0003oooooooooo`0:ooooo`;o
00009?ooool2o`0000Cooooo0_l00021ooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0
2oooool2o`0002?ooooo0_l00004ooooo`;o0000POooool00:cooooo00?o0000ooooooooool02ooo
ool2o`000:cooooo001nooooo`;o0000;?ooool3o`000;Wooooo001nooooo`;o0000;?ooool00ol0
003oooooooooo`2iooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0;_ooool6o`0000?o
oooo0ol0001oooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0;Oooool7o`0000?ooooo
0ol0001oooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0;Oooool4o`0000?ooooo0_l0
0023ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l00023
ooooo`00W?ooool2o`0000Wooooo0ol00002ooooo`03o`000?oooooooooo02gooooo1?l00028oooo
o`00W?ooool2o`0000[ooooo0_l00002ooooo`03o`000?oooooooooo02gooooo1?l00003ooooo`;o
0000Poooool00:Sooooo0_l00002ooooo`?o00002Oooool2o`0002Wooooo0_l00023ooooo`00Z?oo
ool2o`0000;ooooo00?o0000ooooooooool01oooool4o`0002_ooooo0_l00021ooooo`00Woooool4
o`0000Wooooo00?o0000ooooooooool01oooool2o`0002[ooooo0_l000000ooooooo0000o`000021
ooooo`00Woooool4o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00Kooooo0_l0000Uoooo
o`;o00001?ooool2o`0008Cooooo002Rooooo`Go00001Oooool00ol0003oooooooooo`06ooooo`?o
00009?ooool2o`0008[ooooo002Rooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o0000
9?ooool2o`0000?ooooo0_l00025ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0<_oo
ool4o`0008?ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0^ooooo`;o00001?ooool2
o`0008?ooooo002Booooo`;o00006?ooool3o`0000Gooooo0_l0000Wooooo`;o0000ROooool00:co
oooo00?o0000ooooooooool01Oooool6o`0002;ooooo0_l0002:ooooo`00T?ooool2o`0001[ooooo
00?o0000ooooooooool01_ooool5o`0002;ooooo0_l00003ooooo`;o0000QOooool0093ooooo1?l0
000Hooooo`03o`000?oooooooooo00Oooooo0_l0000Yooooo`;o0000QOooool0087ooooo0_l0000>
ooooo`Co00005oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool0087ooooo0_l0000@oooo
o`;o00005oooool00ol0003oooooooooo`0/ooooo`;o0000Roooool009?ooooo0_l0000Gooooo`03
o`000?oooooooooo02cooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00P?oo
ool2o`0002[ooooo0ol0002iooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool01?ooool2
o`000;?ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`04ooooo`;o0000/oooool009?o
oooo0_l0000Gooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00P?ooool2o`0002[ooooo
00?o0000ooooooooool0:?ooool2o`0000?ooooo0_l0002:ooooo`00P?ooool2o`0002[ooooo00Co
0000oooooooooooooooo0_l0000Zooooo`;o0000R_ooool0097ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooool0
00000ol0000Tooooo`Ko0000S?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo000000?o00009?ooool9o`0008Wo
oooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02gooooo0ol00029ooooo`00TOooool01?l0003oooooooooooooool2o`0000ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`0002kooooo0_l00029ooooo`00P_ooool2o`0000gooooo
00Co0000oooooooooooooooo0_l000000ooooooo0000o`000008ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool01?l0003oooooooooooooool2o`0002[ooooo0_l0002:ooooo`00P_ooool2o`00
00gooooo00Ko410@oooooooooooooooooa0@4?ooool3o`0000Sooooo00?o0000ooooooooool01ooo
ool3o`000003ooooool0003o000002[ooooo0_l0002:ooooo`00TOooool01_mgMgOoV9RHoooooonH
V9SoMgMgooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`Go0000^Oooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool3o`0002Wooooo0_l00006ooooo`;o0000
R?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;o00009Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000028ooooo`00U_ooool2o`0001Cooooo1Ol0000Sooooo`;o00001Oooool2
o`0008_ooooo002/ooooo`Co00009?ooool6o`0008kooooo002[ooooo`Go00009_ooool4o`000003
ooooool0003o000008_ooooo002Jooooo`;o00003oooool3o`0002Gooooo0_l00006ooooo`?o0000
R_ooool009[ooooo0_l0000;ooooo`;o00000oooool00ol0003oooooooooo`0Tooooo`;o00000ooo
ool2o`0000;ooooo0_l0002:ooooo`00V?ooool2o`0000_ooooo1?l00003ooooo`?o00009oooool6
o`0008cooooo002Hooooo`;o00002oooool2o`0000Gooooo0ol0000Pooooo`;o00001Oooool2o`00
00;ooooo0ol0002;ooooo`00YOooool3o`000005ooooool0003o0000ooooool000008_ooool2o`00
00[ooooo0ol0002:ooooo`00X_ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000ooooo`0Qooooo`;o00001_ooool2o`0000?ooooo0_l0002:ooooo`00X_ooool2o`0000So
oooo00?o0000ooooooooool08?ooool2o`0000Cooooo1?l000000ooooooo0000o`00002<ooooo`00
Y?ooool2o`0000Kooooo0ol0000Vooooo`;o00000oooool2o`0008cooooo002Kooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Kooooo00?o0000ooooooooool07oooool2o`000004ooooool0
003o0000o`0009Cooooo002Kooooo`Oo00002_ooool00ol0003oooooooooo`0Oooooo`;o000000Co
ooooo`000?l0003o0000U?ooool009gooooo0_l000000ooooooo0000o`00000:ooooo`03o`000?oo
oooooooo0;Wooooo002Mooooo`;o00001oooool2o`0000Cooooo00?o0000ooooooooool07oooool2
o`0000Sooooo0_l0002>ooooo`00WOooool2o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo
01oooooo0_l00006ooooo`Co0000S_ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo02;o
oooo0_l00003ooooo`;o0000T?ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo01_ooooo
0_l00005ooooo`;o0000UOooool00:cooooo0ol0000Kooooo`;o00001?ooool3o`0000;ooooo0_l0
002Aooooo`00[?ooool00ol0003oooooooooo`0Pooooo`?o00000_ooool3o`00097ooooo002/oooo
o`03o`000?oooooooooo01gooooo0_l000000ooooooo0000o`000003ooooo`?o0000TOooool00:co
oooo00?o0000ooooooooool07Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00005
ooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool06?ooool4o`0000?ooooo1?l0002Foooo
o`00[?ooool00ol0003oooooooooo`0Hooooo`;o00001Oooool2o`0009Sooooo002/ooooo`?o0000
8Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo027ooooo1?l0002Dooooo`00[?ooool0
0ol0003oooooooooo`0Sooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool05oooool2o`00
00Sooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0Gooooo`?o00000oooool2o`0000;o
oooo0_l0002Fooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
01Sooooo0ol00002ooooo`Go0000Uoooool008Sooooo0_l000001?nHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool06Oooool2o`000003ooooool0003o000000Co0000Uoooool008Sooooo1?l000000ooooooo
410@ooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Looooo`;o0000Voooool008Wooooo0ol000000ooooooo0000ooooo`0=ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool008Wooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Fooooo`;o00000_ooool2o`0009gooooo0029ooooo`;o000000?ooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Fooooo`Ko0000WOooool008Wooooo0ol000000olb<S;ok^k^ooooo`0:ooooo`Go0000
1?ooool4o`0000Kooooo00?o0000ooooooooool04?ooool2o`0000Gooooo0ol0002Oooooo`00[?oo
ool00ol0003oooooooooo`0@ooooo`;o000000Coooooo`000?l0003o0000Xoooool00:cooooo00?o
0000ooooooooool04oooool5o`000:7ooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Q
ooooo`00[?ooool3o`0001?ooooo1?l0002Rooooo`00SOooool2o`0001gooooo00?o0000oooooooo
ool04oooool4o`000:;ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Eooooo`;o0000
X_ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Sooooo0_l0002Rooooo`00[?ooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00gooooo
1?l0002Xooooo`00[?ooool3o`0000gooooo0_l00002ooooo`;o0000Y_ooool00:cooooo00?o0000
ooooooooool03Oooool2o`000004ooooool0003o0000o`000:Kooooo002/ooooo`03o`000?oooooo
oooo00gooooo0_l000000ooooooo0000o`00002Wooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
1oooool4o`000:Sooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`Co0000Z?oo
ool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o0000ZOooool0
097ooooo1?l0000Gooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l00000[?ooool009?ooooo0_l0000Gooooo`?o00002?ooool2o`000003ooooool0003o00000:co
oooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00T_ooool4o`0001Kooooo0ol0002iooooo`00T_oo
ool4o`0001Kooooo0ol0002iooooo`00V_ooool2o`00013ooooo1?l0002hooooo`00V_ooool2o`00
013ooooo00Co0000ooooool0003o00000_ooool2o`000;Cooooo002Zooooo`?o00001Oooool2o`00
0;Cooooo002Vooooo`;o00000_ooool3o`000;_ooooo002Sooooo`Go00001?ooool00ol0003ooooo
ooooo`2iooooo`00Xoooool5o`0000Cooooo00?o0000ooooooooool0^Oooool009Wooooo0_l00002
ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`04o`000?oooooo0000o`000;Sooooo002I
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o000000?ooooo
o`000?l00000^?ooool00:Cooooo00?o0000ooooooooool01?ooool4o`000;Wooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo0000
0<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zoooo
o`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o
0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6206 .34133 Mdot
.64292 .38417 Mdot
.50099 .57097 Mdot
.4653 .25087 Mdot
.55088 .69279 Mdot
.55475 .21637 Mdot
.46244 .33584 Mdot
.5265 .95105 Mdot
.47624 .97264 Mdot
.5488 .37415 Mdot
.56789 .46989 Mdot
.43676 .96148 Mdot
.66719 .45037 Mdot
.55087 .36505 Mdot
.36904 .6117 Mdot
.49763 .25568 Mdot
.42747 .21744 Mdot
.66818 .45269 Mdot
.57502 .56896 Mdot
.67506 .62399 Mdot
.66551 .53664 Mdot
.65774 .47485 Mdot
.65392 .55702 Mdot
.67023 .48521 Mdot
.36452 .50641 Mdot
.49903 .81889 Mdot
.56521 .56523 Mdot
.56485 .61242 Mdot
.66242 .66858 Mdot
.65061 .43606 Mdot
.64946 .6263 Mdot
.51504 .94526 Mdot
.48041 .98455 Mdot
.49434 .15261 Mdot
.47744 .13052 Mdot
.63048 .71977 Mdot
.58298 .8407 Mdot
.56286 .60644 Mdot
.61375 .77277 Mdot
.46437 .99367 Mdot
.3825 .778 Mdot
.47668 .13528 Mdot
.5344 .19319 Mdot
.6042 .28486 Mdot
.59008 .26349 Mdot
.5343 .74394 Mdot
.56366 .45607 Mdot
.56902 .87696 Mdot
.43215 .78803 Mdot
.63405 .72931 Mdot
.55597 .89203 Mdot
.63155 .75072 Mdot
.63061 .11102 Mdot
.53136 .19412 Mdot
.48955 .13002 Mdot
.46905 .97745 Mdot
.50244 .97622 Mdot
.40902 .30212 Mdot
.57823 .85712 Mdot
.58391 .25276 Mdot
.51238 .78531 Mdot
.37455 .25344 Mdot
.59338 .80591 Mdot
.43772 .6711 Mdot
.40262 .85309 Mdot
.51004 .95375 Mdot
.55187 .39247 Mdot
.51688 .30503 Mdot
.57259 .55831 Mdot
.67 .52629 Mdot
.39408 .4889 Mdot
.48366 .3169 Mdot
.55842 .42772 Mdot
.53836 .34657 Mdot
.59292 .80655 Mdot
.468 .64316 Mdot
.63139 .11207 Mdot
.43869 .78155 Mdot
.64086 .72934 Mdot
.40067 .45251 Mdot
.6421 .67114 Mdot
.65092 .45075 Mdot
.46944 .25206 Mdot
.46744 .13491 Mdot
.53214 .93982 Mdot
.46302 .2361 Mdot
.54985 .69697 Mdot
.4973 .80065 Mdot
.39626 .45432 Mdot
.52297 .32148 Mdot
.36606 .42135 Mdot
.54368 .02759 Mdot
.42612 .61229 Mdot
.53209 .7437 Mdot
.42504 .59449 Mdot
.55029 .36457 Mdot
.50782 .94616 Mdot
.63356 .11287 Mdot
.39752 .59056 Mdot
.63011 .37112 Mdot
.40079 .62304 Mdot
.407 .88375 Mdot
.61765 .31723 Mdot
.66458 .58953 Mdot
.49868 .15648 Mdot
.4029 .33602 Mdot
.57534 .57973 Mdot
.42641 .61555 Mdot
.6673 .55032 Mdot
.54541 .35193 Mdot
.44208 .29264 Mdot
.50787 .95214 Mdot
.66524 .63968 Mdot
.70847 .20303 Mdot
.53162 .51973 Mdot
.48384 .82386 Mdot
.55472 .90822 Mdot
.54708 .91395 Mdot
.54155 .89173 Mdot
.66758 .46653 Mdot
.36132 .45233 Mdot
.65132 .59635 Mdot
.66833 .65486 Mdot
.669 .53854 Mdot
.48619 .25131 Mdot
.65561 .6713 Mdot
.64663 .46376 Mdot
.49896 .68494 Mdot
.65915 .51063 Mdot
.63887 .40514 Mdot
.40543 .88254 Mdot
.53736 .18356 Mdot
.54345 .20456 Mdot
.66055 .68295 Mdot
.63315 .76207 Mdot
.6555 .67975 Mdot
.55875 .43367 Mdot
.43713 .95465 Mdot
.37337 .67954 Mdot
.41982 .45417 Mdot
.57559 .54926 Mdot
.42331 .23176 Mdot
.67265 .62426 Mdot
.541 .92768 Mdot
.73243 .23402 Mdot
.53216 .71492 Mdot
.49789 .80185 Mdot
.37617 .75936 Mdot
.40827 .68992 Mdot
.57471 .49458 Mdot
.67079 .47163 Mdot
.47486 .3139 Mdot
.60013 .31073 Mdot
.61601 .78592 Mdot
.60962 .78305 Mdot
.52951 .93586 Mdot
.56789 .86057 Mdot
.62047 .77976 Mdot
.47098 .84029 Mdot
.65163 .70769 Mdot
.4549 .99531 Mdot
.62814 .71701 Mdot
.56475 .25289 Mdot
.6355 .40691 Mdot
.53519 .93306 Mdot
.66699 .58797 Mdot
.57187 .55857 Mdot
.64375 .73838 Mdot
.61983 .75021 Mdot
.43264 .34966 Mdot
.56682 .5778 Mdot
.5235 .75171 Mdot
.54361 .69205 Mdot
.43819 .95388 Mdot
.60104 .31525 Mdot
.52013 .59855 Mdot
.64466 .71162 Mdot
.65248 .71597 Mdot
.43553 .96463 Mdot
.51113 .27632 Mdot
.38037 .76501 Mdot
.48036 .71884 Mdot
.45471 .96136 Mdot
.55602 .89947 Mdot
.44992 .98935 Mdot
.52731 .17853 Mdot
.36153 .52688 Mdot
.67473 .61724 Mdot
.43996 .67393 Mdot
.38578 .18382 Mdot
.52329 .95156 Mdot
.39006 .83219 Mdot
.40905 .89299 Mdot
.5291 .74723 Mdot
.53329 .01 Mdot
.40249 .3292 Mdot
.52388 .56376 Mdot
.52355 .56852 Mdot
.48956 .3233 Mdot
.52985 .73661 Mdot
.55184 .02794 Mdot
.63841 .41323 Mdot
.44613 .68577 Mdot
.57015 .24366 Mdot
.42318 .38996 Mdot
.49701 .70436 Mdot
.56725 .44641 Mdot
.66079 .42496 Mdot
.44852 .8026 Mdot
.6661 .59251 Mdot
.52363 .31241 Mdot
.63752 .41748 Mdot
.44614 .79577 Mdot
.44201 .98088 Mdot
.50457 .68142 Mdot
.60453 .30947 Mdot
.48803 .99207 Mdot
.4929 .81627 Mdot
.53505 .91044 Mdot
.66971 .56896 Mdot
.63136 .70168 Mdot
.53305 .34784 Mdot
.55366 .67723 Mdot
.62931 .33312 Mdot
.42264 .4344 Mdot
.36953 .62237 Mdot
.36044 .52688 Mdot
.47634 .23806 Mdot
.43822 .49811 Mdot
.58622 .06854 Mdot
.39788 .52609 Mdot
.57054 .51434 Mdot
.36249 .42635 Mdot
.5667 .58412 Mdot
.62067 .32221 Mdot
.66135 .5412 Mdot
.6359 .39185 Mdot
.38199 .20225 Mdot
.5271 .17274 Mdot
.67019 .5898 Mdot
.39411 .48829 Mdot
.54307 .91547 Mdot
.42201 .53456 Mdot
.58423 .8313 Mdot
.42612 .23075 Mdot
.39412 .50537 Mdot
.60442 .78951 Mdot
.38445 .79847 Mdot
.53111 .52402 Mdot
.42785 .5963 Mdot
.56546 .85889 Mdot
.4589 .82617 Mdot
.56561 .58134 Mdot
.46272 .12379 Mdot
.46449 .64037 Mdot
.47983 .98847 Mdot
.57632 .86414 Mdot
.41075 .69335 Mdot
.57065 .51133 Mdot
.6324 .70258 Mdot
.51488 .63183 Mdot
.39992 .603 Mdot
.6219 .35446 Mdot
.56535 .49574 Mdot
.58122 .2789 Mdot
.62112 .74244 Mdot
.42337 .74221 Mdot
.64797 .68493 Mdot
.48459 .12489 Mdot
.53966 .33937 Mdot
.40071 .57635 Mdot
.62545 .76985 Mdot
.50459 .25988 Mdot
.575 .59996 Mdot
.54414 .9074 Mdot
.56213 .4074 Mdot
.58614 .27554 Mdot
.64684 .71076 Mdot
.52625 .59758 Mdot
.54351 .37343 Mdot
.55846 .8724 Mdot
.42449 .93417 Mdot
.57665 .57494 Mdot
.46838 .32086 Mdot
.5062 .77422 Mdot
.67462 .59833 Mdot
.50592 .79115 Mdot
.64044 .67078 Mdot
.55908 .87967 Mdot
.38002 .73666 Mdot
.52782 .9165 Mdot
.43826 .45008 Mdot
.60428 .81803 Mdot
.3999 .1223 Mdot
.67718 .57546 Mdot
.37104 .64267 Mdot
.74323 .24851 Mdot
.41141 .68857 Mdot
.48023 .11754 Mdot
.63724 .3903 Mdot
.53102 .92863 Mdot
.37108 .67228 Mdot
.56404 .4477 Mdot
.53019 .92259 Mdot
.45884 .82753 Mdot
.52584 .52524 Mdot
.66228 .45115 Mdot
.42661 .21825 Mdot
.66657 .48203 Mdot
.37684 .76143 Mdot
.52767 .56484 Mdot
.61195 .32815 Mdot
.49095 .14595 Mdot
.39679 .82912 Mdot
.52421 .59584 Mdot
.42207 .93665 Mdot
.37581 .26675 Mdot
.42401 .03377 Mdot
.49091 .25234 Mdot
.52325 .15995 Mdot
.45486 .14297 Mdot
.58649 .81958 Mdot
.56672 .64131 Mdot
.52841 .48253 Mdot
.44808 .37674 Mdot
.40388 .33132 Mdot
.50374 .97762 Mdot
.54906 .87866 Mdot
.43005 .63694 Mdot
.65954 .4405 Mdot
.505 .67037 Mdot
.49314 .33024 Mdot
.63215 .34163 Mdot
.54276 .19597 Mdot
.56409 .25119 Mdot
.46627 .83815 Mdot
.52791 .73885 Mdot
.60143 .07579 Mdot
.43341 .77629 Mdot
.64982 .47029 Mdot
.42842 .61412 Mdot
.46421 .9789 Mdot
.56457 .56431 Mdot
.65307 .68331 Mdot
.65334 .50396 Mdot
.42154 .57163 Mdot
.45001 .79888 Mdot
.44451 .00453 Mdot
.45544 .98509 Mdot
.6216 .79181 Mdot
.63415 .71449 Mdot
.42969 .77493 Mdot
.41775 .24179 Mdot
.62888 .7319 Mdot
.3989 .57624 Mdot
.45046 .98009 Mdot
.39753 .10928 Mdot
.67022 .59254 Mdot
.40113 .86498 Mdot
.41636 .92213 Mdot
.40767 .90147 Mdot
.5041 .35928 Mdot
.39944 .56663 Mdot
.37003 .63423 Mdot
.49406 .98284 Mdot
.50618 .36543 Mdot
.64908 .64071 Mdot
.41037 .65961 Mdot
.55724 .21691 Mdot
.62793 .36456 Mdot
.49739 .9584 Mdot
.62205 .32747 Mdot
.5854 .84073 Mdot
.5564 .86551 Mdot
.65298 .55776 Mdot
.63293 .77069 Mdot
.65763 .52018 Mdot
.36626 .57951 Mdot
.71258 .20432 Mdot
.52586 .91242 Mdot
.59156 .28416 Mdot
.48884 .32848 Mdot
.36471 .41826 Mdot
.39611 .54551 Mdot
.44645 .3854 Mdot
.44703 .98266 Mdot
.66998 .53017 Mdot
.5271 .45705 Mdot
.54435 .36587 Mdot
.48811 .8269 Mdot
.57023 .53121 Mdot
.57218 .87462 Mdot
.67691 .52761 Mdot
.39497 .14015 Mdot
.43343 .96145 Mdot
.44715 .16446 Mdot
.61594 .09778 Mdot
.43415 .18878 Mdot
.54996 .67511 Mdot
.55921 .65442 Mdot
.44883 .60949 Mdot
.49263 .98636 Mdot
.43565 .95908 Mdot
.5659 .55891 Mdot
.42036 .46653 Mdot
.56683 .41467 Mdot
.48069 .23054 Mdot
.37625 .74985 Mdot
.54763 .71047 Mdot
.63964 .69169 Mdot
.43203 .34035 Mdot
.57438 .5125 Mdot
.51601 .63097 Mdot
.54601 .71012 Mdot
.48897 .1487 Mdot
.57295 .48315 Mdot
.44334 .67785 Mdot
.36295 .60212 Mdot
.44447 .96575 Mdot
.50248 .478 Mdot
.48035 .1299 Mdot
.40381 .32851 Mdot
.61749 .36364 Mdot
.40661 .6274 Mdot
.5706 .5594 Mdot
.36281 .50679 Mdot
.63156 .35784 Mdot
.68919 .17841 Mdot
.60288 .27824 Mdot
.45085 .70402 Mdot
.43347 .9334 Mdot
.36756 .58739 Mdot
.56835 .50589 Mdot
.65176 .52512 Mdot
.61091 .0871 Mdot
.42235 .42567 Mdot
.52477 .44441 Mdot
.53247 .7198 Mdot
.64057 .68317 Mdot
.40126 .56165 Mdot
.53813 .018 Mdot
.4831 .71997 Mdot
.52676 .19009 Mdot
.45265 .14784 Mdot
.43789 .67653 Mdot
.52174 .5962 Mdot
.51867 .29027 Mdot
.52018 .95765 Mdot
.53057 .55114 Mdot
.65028 .7077 Mdot
.63705 .36583 Mdot
.60351 .29877 Mdot
.65354 .67379 Mdot
.64024 .6663 Mdot
.43064 .20301 Mdot
.54486 .36585 Mdot
.50355 .9783 Mdot
.39294 .84519 Mdot
.56466 .51563 Mdot
.61238 .80615 Mdot
.41282 .68299 Mdot
.44427 .1784 Mdot
.65613 .67517 Mdot
.62742 .35858 Mdot
.57098 .59424 Mdot
.4537 .80517 Mdot
.47854 .14129 Mdot
.36032 .44994 Mdot
.5627 .24294 Mdot
.48149 .64478 Mdot
.54698 .21833 Mdot
.39957 .50452 Mdot
.49272 .32535 Mdot
.51153 .29525 Mdot
.52326 .18106 Mdot
.52257 .16975 Mdot
.52852 .53911 Mdot
.4529 .81649 Mdot
.50723 .95695 Mdot
.56103 .6656 Mdot
.61982 .35158 Mdot
.57859 .50045 Mdot
.54767 .6675 Mdot
.514 .39331 Mdot
.69353 .17811 Mdot
.51891 .41965 Mdot
.63799 .36292 Mdot
.49962 .94933 Mdot
.63305 .70793 Mdot
.57233 .56501 Mdot
.65144 .69249 Mdot
.43607 .96369 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009Wooooo0_l00009ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009Wooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`;o0000[oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`;o0000[oooool00:;ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool0
2Oooool2o`000:kooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool02oooool2
o`000003ooooool0003o00000:Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l000000ooo
oooo0000o`00002Yooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0002N
ooooo`00[?ooool3o`0001kooooo0_l0002Iooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
0000VOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo
027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0Sooooo`;o0000U?ooool00:cooooo0ol0000Sooooo`;o0000U?ooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0000Pooooo`03
o`000?oooooooooo0;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Xooooo`?o0000
S_ooool00:cooooo00?o0000ooooooooool0:?ooool3o`0008kooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool00om4A4Co0000o`00
0002o`0000Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?l0003o0000ogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`;o00001Oooool00ol0003ooooooooo
o`2iooooo`00POooool6o`0000;ooooo00Go410@ooooool0003o0000oa0@400=ooooo`04ojVYZOmE
EEGoooooooooo`;o00001Oooool2o`0000Cooooo0ol0002iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool00_l00004ooooo`03ogMgMol0003o000000Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00?o0000ob4Q8Ol000000_l000000ooooooo0000o`000002ooooo`03o`00
0?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`02ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo00?o0000oooooooo
ool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S800oooool2o`000003ooooool0003o000000Kooooo00?o0000ooooooooool0^Oooool008Wo
oooo0ol000000olb<S;ok^k^ooooo`0:ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool0^Oooool008Wooooo0_l0000Booooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool0
^Oooool009gooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003ooooo0;[ooooo002L
ooooo`;o00002_ooool3o`000003ooooool0003ooooo0;[ooooo002Looooo`;o00002_ooool7o`00
0;Wooooo002Zooooo`?o0000^oooool00:_ooooo0_l0002kooooo`00Zoooool2o`0000Kooooo0_l0
002cooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
0000/oooool00:cooooo00?o0000ooooooooool01?ooool4o`000;7ooooo002/ooooo`?o00001_oo
ool2o`000;7ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`;o0000<oooool3
o`0007_ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`04ooooo`Co0000<oooool3o`00
07_ooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`000:ko
oooo0026ooooo`;o00003_ooool2o`0001Cooooo00?o0000ooooooooool02Oooool2o`000:kooooo
002Fooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000
ooooooooool01Oooool5o`000:oooooo002/ooooo`03o`000?oooooooooo00Oooooo0ol000000ooo
oooo0000o`00002/ooooo`00[?ooool3o`0000_ooooo0_l0002/ooooo`00QOooool2o`0000kooooo
0_l0000Eooooo`03o`000?oooooooooo00_ooooo0_l0000dooooo`Co0000M?ooool008Gooooo0_l0
000>ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`;o0000=?ooool4o`0007Cooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo00oooooo0_l0002Xooooo`00Toooool3o`0001Kooooo00?o0000ooooooooool0
3?ooool2o`000003ooooool0003o00000:Sooooo002Cooooo`?o00005_ooool00ol0003ooooooooo
o`0<ooooo`;o000000?oooooo`000?l00000Z?ooool00:cooooo0ol0002iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00T_ooool3o`00013ooooo0_l00005ooooo`03o`000?oooooooooo0;Wo
oooo002Booooo`?o00004?ooool2o`0000Gooooo00?o0000ooooooooool0BOooool2o`0006kooooo
002Oooooo`;o00002oooool00ol0003oooooooooo`19ooooo`;o0000K_ooool009oooooo0_l00003
ooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00T?ooool2o`000004oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000o`000?oMgMd01Oooool00ol0003ooooooooo
o`0Aooooo`;o000000?oooooo`000?l00000Xoooool0093ooooo0_l000001?nHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo017ooooo0_l0
00000ooooooo0000o`00002Sooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool2o`0006[ooooo002A
ooooo`05o`000?ooooooooooooooool000002_ooool3o`0000;ooooo00?oMgMgoc8b<_l000000ol0
00001?oooooo0000o`000?l0000Booooo`;o00001?ooool2o`0003?ooooo0_l0001Zooooo`00P_oo
ool2o`0000gooooo00Go0000ooooooooooooooooo`00000:ooooo`?o000000Co8B4Qo`000?lb<S;o
c<c<1_l0000Dooooo`;o00001?ooool2o`0009oooooo0022ooooo`;o00003Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`000;_ooooo002Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`?o0000^Oooool0097ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool3o`0001[ooooo0_l0002Mooooo`00
Poooool2o`0002Oooooo00?o0000ooooooooool06_ooool2o`0009gooooo0023ooooo`;o00009ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool5o`00
01Oooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`02o`0001Gooooo1?l00004ooooo`;o
0000V?ooool00:cooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00[?oo
ool00ol0003oooooooooo`0Kooooo`;o00000_ooool2o`0009Sooooo002/ooooo`03o`000?oooooo
oooo01_ooooo0_l00002ooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool00oooool2o`00
0;Cooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`02o`000003ooooool0003o00000;Co
oooo002Hooooo`;o00004_ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`?o00007ooo
ool2o`0009Sooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0
08kooooo0_l0000Looooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003o
ooooooooo`02ooooo`;o00006oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo00Cooooo
0_l0000Hooooo`?o0000V?ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo0_l0
000Hooooo`;o0000VOooool00:?ooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooo
oooo01kooooo0_l00003ooooo`;o0000U?ooool00:7ooooo0_l00003ooooo`;o00001?ooool00ol0
003oooooooooo`04ooooo`;o00007Oooool3o`0009?ooooo002Qooooo`;o00001Oooool3o`000004
ooooool0003o0000o`0000Cooooo0_l0000Nooooo`;o0000Toooool008cooooo0_l0000Jooooo`?o
000000?oooooo`000?ooool08oooool2o`000003ooooool0003o000009;ooooo002;ooooo`?o0000
6_ooool3o`000003ooooool0003ooooo02?ooooo0_l000000ooooooo0000o`00002Booooo`00Rooo
ool3o`0001_ooooo0_l000000ooooooo0000ooooo`0Xooooo`;o0000T?ooool008cooooo0_l0000A
ooooo`;o00002oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool008cooooo0_l00007oooo
o`;o00002?ooool2o`0000_ooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`0:ooooo`;o00006?ooool2o`0000;ooooo0_l0002?ooooo`00
[?ooool00ol0003oooooooooo`09ooooo`;o00006Oooool2o`0000;ooooo0_l0002?ooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool01oooool4o`000:kooooo002Eooooo`;o00005Oooool3
o`0000Oooooo0_l00003ooooo`;o00005_ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo
00cooooo0_l0000Fooooo`?o0000T_ooool00:cooooo00?o0000ooooooooool09Oooool5o`0008oo
oooo002/ooooo`?o00009oooool3o`0008oooooo002/ooooo`?o00003Oooool2o`0001Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l00000SOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`00
0?oooooo0000o`0000[ooooo1?l0000Dooooo`;o00000_ooool2o`000003ooooool0003o000008go
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000ooooool0003o00002_ooool2
o`0001_ooooo1?l0002=ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`Co00006Oooool2o`0008oooooo0029ooooo`05o`000?ooooooooooooooool000003?ooool2
o`000003ob4Q8Oo^k^kooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000_ooooo1?l0002Z
ooooo`00ROooool01Ol0003ooooooooooooooooo000000cooooo0_l000000omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool3o`000003oiRHV?l@413ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0/ooooo`;o0000Roooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l0
003o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`0>ooooo`;o00006Oooool3o`0008gooooo002B
ooooo`;o00006?ooool01?l0003oooooooooooooool2o`0000_ooooo0_l0000Iooooo`?o0000SOoo
ool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Fooooo`?o
0000SOooool00:cooooo00?o0000ooooooooool04Oooool2o`0001Kooooo0ol0002=ooooo`00[?oo
ool00ol0003oooooooooo`0Zooooo`;o0000SOooool00:cooooo00?o0000ooooooooool04oooool2
o`0001Gooooo0_l0002=ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool00oooool2o`00
00kooooo0_l0000Eooooo`;o0000SOooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00?o
oooo0_l0000Uooooo`;o0000SOooool007oooooo0_l0000Aooooo`;o00006?ooool3o`0003;ooooo
0_l00025ooooo`00O_ooool2o`0001;ooooo0_l0000Hooooo`03o`000?oooooooooo013ooooo0_l0
000Pooooo`;o0000QOooool007kooooo0_l0000/ooooo`03o`000?oooooooooo013ooooo0_l0002W
ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`0@ooooo`;o00007?ooool2o`0008Wooooo002/ooooo`03o`00
0?oooooooooo02kooooo0_l000000ooooooo0000o`000026ooooo`00[?ooool00ol0003ooooooooo
o`0aooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool01Oooool2o`0000cooooo0_l0002T
ooooo`00OOooool2o`0002gooooo00?o0000ooooooooool01Oooool2o`0000_ooooo0ol0002Toooo
o`00OOooool3o`0000_ooooo0_l0000:ooooo`;o00004oooool3o`0001;ooooo0_l0000Jooooo`;o
00000_ooool4o`0008?ooooo001nooooo`;o00002Oooool4o`0000Cooooo0_l00004ooooo`;o0000
4oooool00ol0003oooooooooo`0Booooo`;o00006_ooool2o`0000;ooooo1?l00023ooooo`00ROoo
ool2o`0000Kooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o0000YOoo
ool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool0
4_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A002o`0000Gooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003o
ooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00cooooo00CoV9RHob4Q8Oo^k^ko
oooo0_l00005ooooo`;o00003oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01?ooool2o`000003oooo
oomgMgOo<S8b01Kooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001?ooool2o`0000oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_oo
ool00ol0003oooooooooo`0Cooooo`;o00000oooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00_l000001Ooooooo0000ob4Q8Ol0003o<S8b00;o00003_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
6_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`00
01Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`;o00003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool06?ooool2o`0001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool2o`0001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009
ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005oooool2o`00
00Oooooo0_l0000=ooooo`;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool5o`0000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omE
EEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00003Oooool2o`0001go
oooo0ol00022ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0000Gooooo002/
ooooo`03o`000?oooooooooo01Gooooo0_l0002Gooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
1Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l000000ooooooo0000o`00
002Hooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ
8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00001Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08Ooo
ool3o`0000;ooooo00?o0000ooooooooool00oooool3o`00023ooooo00?o0000ooooooooool04ooo
ool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Ooo
ool007kooooo0ol00008ooooo`;o00008Oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool0
0:cooooo00?o0000ooooooooool05?ooool3o`0001[ooooo0_l00026ooooo`00[?ooool00ol0003o
ooooooooo`0Booooo`Go00006_ooool2o`0008Kooooo002/ooooo`03o`000?oooooooooo01;ooooo
1?l0002Sooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000:?ooool2o`0008Kooooo002/
ooooo`?o00001Oooool4o`0002Kooooo1?l00026ooooo`00OOooool3o`0000[ooooo0_l0000Poooo
o`03o`000?oooooooooo00Gooooo1?l0000Vooooo`;o00001?ooool4o`00083ooooo001mooooo`?o
00002_ooool2o`00023ooooo00?o0000ooooooooool05?ooool2o`0001oooooo1?l00020ooooo`00
T_ooool2o`0001Sooooo00?o0000ooooooooool05?ooool2o`0001oooooo0_l00022ooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002/ooooo`03o`000?oooooo
oooo00Kooooo0_l0000[ooooo`?o0000Poooool00:cooooo00?o0000ooooooooool01_ooool2o`00
02[ooooo1?l00023ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0<_ooool2o`0008Go
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:cooooo0ol0
0007ooooo`;o00003Oooool2o`0001cooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`07
ooooo`;o0000:oooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo01;ooooo1Ol0000Hoooo
o`;o0000R?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo01;ooooo1Ol0000Hooooo`;o
0000R?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00Cooooo1?l0000:ooooo`Co0000
Xoooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo1?l0000:ooooo`Co0000Xooo
ool008[ooooo0_l0000Pooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`00000N
ooooo`;o0000P_ooool009;ooooo0_l0000Hooooo`;o00001Oooool2o`0000oooooo0_l0000Noooo
o`;o0000P_ooool008[ooooo0ol00005ooooo`;o00006?ooool3o`0001Kooooo0_l0000Oooooo`;o
0000P?ooool007oooooo0_l00009ooooo`?o00007oooool00ol0003oooooooooo`0Cooooo`Go0000
7oooool2o`00083ooooo001oooooo`;o0000:oooool00ol0003oooooooooo`0Booooo`Go0000X_oo
ool00:cooooo00?o0000ooooooooool04_ooool3o`000:Cooooo0020ooooo`;o0000:_ooool00ol0
003oooooooooo`0Cooooo`;o00007oooool2o`0008?ooooo0020ooooo`;o00002?ooool2o`00023o
oooo00?o0000ooooooooool0<oooool4o`0008;ooooo002:ooooo`;o00001oooool2o`0001Oooooo
00?o0000ooooooooool05?ooool2o`0001gooooo1?l00022ooooo`00Toooool3o`0001Kooooo00?o
0000ooooooooool01?ooool3o`0000gooooo0_l0000Iooooo`;o00000_ooool5o`00087ooooo002D
ooooo`;o00005_ooool3o`0000?ooooo1?l0000>ooooo`;o00006?ooool2o`0000Gooooo0_l00021
ooooo`00O_ooool2o`0000_ooooo0_l0000Oooooo`03o`000?oooooooooo00?ooooo0_l0000@oooo
o`;o0000X_ooool007kooooo0_l0000;ooooo`;o00007oooool00ol0003oooooooooo`0Aooooo`;o
0000Y_ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00P?oo
ool2o`00017ooooo0_l00006ooooo`;o00003oooool00ol0003oooooooooo`0Booooo`;o0000YOoo
ool0083ooooo0_l0000Aooooo`?o00005_ooool00ol0003oooooooooo`0Booooo`;o0000YOooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`?o00000oooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Kooooo0_l00021ooooo`00P?ooool2
o`0000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000
POooool0083ooooo0_l00007ooooo`05oa0@4?oooooo0000o`000?l@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000fooooo`;o0000POooool008Wooooo00?o
0000ooooool000000ol0000<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0^ooooo`;o00001_ooool2o`00087ooooo0029ooooo`04o`000?oooooo
ooooooooo`;o00003Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`02ooooo`;o0000:_ooool2o`0008Wooooo0021ooooo`;o00001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`?o0000]Oooool0087ooooo0_l00006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0000?ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l0002fooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_oo
ool6o`0000Kooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l00024ooooo`00POooool2
o`0001gooooo0ol00009ooooo`03o`000?oooooooooo01?ooooo0_l0000Iooooo`;o00000oooool2
o`0008Cooooo0021ooooo`;o00007_ooool2o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00008_ooool2o`0008?ooooo002/
ooooo`03o`000?oooooooooo013ooooo0_l0000Rooooo`;o0000Poooool008kooooo0_l0000Loooo
o`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0001Sooooo0_l0002<ooooo`00Uooo
ool2o`0001?ooooo0ol0000<ooooo`;o00000oooool2o`0001Sooooo0_l00005ooooo`;o0000QOoo
ool0087ooooo0_l0000Dooooo`?o00004_ooool3o`0002_ooooo0_l00002ooooo`Go0000QOooool0
087ooooo0_l0000Dooooo`?o00004_ooool3o`0000gooooo0_l0000Pooooo`?o0000Qoooool008;o
oooo0_l0000Cooooo`Co00004Oooool00ol0003oooooooooo`0=ooooo`?o00008?ooool2o`0008Oo
oooo0022ooooo`;o00002oooool2o`0000Sooooo0_l0000Aooooo`?o00003_ooool2o`0001_ooooo
0_l00003ooooo`Co0000QOooool008oooooo0_l00009ooooo`;o00003oooool4o`0002_ooooo1_l0
00000ooooooo0000o`000025ooooo`00S_ooool2o`0000[ooooo0_l0000?ooooo`;o0000;oooool4
o`0008Sooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`0;ooooo`;o00007_ooool2o`00
08cooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`0;ooooo`Co00007?ooool2o`0000;o
oooo0_l00028ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03Oooool2o`00023ooooo
0_l00028ooooo`00[?ooool3o`0000gooooo0_l0002Zooooo`00Voooool2o`0000kooooo0_l0000Z
ooooo`;o0000Soooool009_ooooo0_l0000>ooooo`;o0000:_ooool2o`0008oooooo002/ooooo`03
o`000?oooooooooo00cooooo0_l0000Jooooo`;o00001?ooool3o`0008Sooooo002/ooooo`03o`00
0?oooooooooo00cooooo0_l0000Jooooo`;o00000_ooool5o`0008Sooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l0000Pooooo`;o000000?oooooo`000?l000000ol00028ooooo`00YOooool2
o`0000Gooooo00?o0000ooooooooool01oooool2o`0001kooooo1?l00004ooooo`;o0000R?ooool0
0:Gooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo0_l0000Nooooo`?o0000Soooool00:Ko
oooo0_l00004ooooo`?o00001oooool2o`0001oooooo0_l0002?ooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Yooooo`Co0000S?ooool00:cooooo00?o0000
ooooooooool09oooool6o`0008cooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`06oooo
o`;o00007oooool2o`00093ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`06ooooo`;o
00009?ooool2o`0008_ooooo002Aooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo0ol0000Loooo
o`;o00001Oooool2o`0008_ooooo002Aooooo`05ogMgMol0003o0000oiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`?o00006oooool2o`00
09;ooooo0023ooooo`;o00003?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`Co0000[oooool008?ooooo0_l0000<ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00001?ooool4o`00
01cooooo0_l00002ooooo`;o0000Soooool0097ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o00007_ooool2
o`0000;ooooo0_l0002?ooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2iooooo`00Poooool2o`0000cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0
08?ooooo0ol0000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool0:Oooool2o`0008kooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0Yoooo
o`;o0000S_ooool00:cooooo00?o0000ooooooooool09_ooool4o`0008oooooo002/ooooo`03o`00
0?oooooooooo02;ooooo0_l00002ooooo`Co0000Soooool009Cooooo1?l0000Dooooo`Co00008Ooo
ool2o`0009Gooooo0025ooooo`;o00003Oooool4o`0001Cooooo00Co0000ooooool0003o00008ooo
ool2o`0009?ooooo0025ooooo`;o00004?ooool2o`0001?ooooo00?o0000ooooooooool08Oooool2
o`000003ooooool0003o000009?ooooo002Gooooo`;o00004oooool01?l0003oooooooooooooool2
o`0001kooooo1?l0002Dooooo`00UOooool2o`0001Gooooo00Co0000oooooooooooooooo0_l0000P
ooooo`;o0000U?ooool009Gooooo0_l0000Eooooo`04o`000?oooooo0000o`0001kooooo0_l00004
ooooo`;o0000T_ooool00:cooooo00Co0000ooooool0003o00007_ooool2o`0000Cooooo0_l0002B
ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool008Gooooo0_l0000Cooooo`?o
00003_ooool4o`000;Wooooo0025ooooo`;o00005?ooool2o`0000kooooo0_l0002kooooo`00Vooo
ool3o`0000gooooo0_l0000Mooooo`;o00001Oooool2o`0009Gooooo002Looooo`;o00003_ooool0
0ol0003oooooooooo`0Kooooo`;o00001Oooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Looooo`;o00002oooool2o`000003ooooool0003ooooo0;[ooooo002Looooo`;o0000
2oooool4o`0001_ooooo0_l00004ooooo`;o0000V?ooool00:_ooooo0_l0000Kooooo`;o00001?oo
ool2o`0009Sooooo002Vooooo`;o00001?ooool3o`000;Wooooo002Nooooo`;o00001_ooool4o`00
00;ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Cooooo`;o00002?ooool2o`0000;o
oooo00?o0000ooooooooool06?ooool2o`0009oooooo0027ooooo`Co00008Oooool00ol0003ooooo
ooooo`0Hooooo`;o0000Woooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo0;Wooooo002P
ooooo`Co00002?ooool00ol0003oooooooooo`0Hooooo`?o0000W_ooool00:3ooooo1?l00008oooo
o`03o`000?oooooooooo01Sooooo0ol0002Nooooo`00R?ooool2o`0002;ooooo00?o0000oooooooo
ool0^Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Ooo
ool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0
003oooooooooo`0Booooo`;o00000_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo01;o
oooo0ol000000ooooooo0000o`00002Qooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0
4oooool2o`000003ooooool0003o00000:7ooooo0029ooooo`05onk^k_lb<S;o0000o`000?o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0002Qooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`;o0000Yoooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00013ooooo0_l000001?oooooo
0000o`000?l0002Sooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2
o`000004ooooool0003o0000ooooo`?o0000Xoooool008Wooooo00?o410@ooooooooool00_l0000>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`;o000000?oooooo`000?l00000Yoooool008Wooooo00?oMgMgoiRHV?ooool00ol0000:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`04onk^k_lb<S;o0000oc8b<P;o00002_ooool5o`0000Cooooo1?l00006
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l00003oooo
o`;o0000Z?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o
0000Z?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00003ooo
ool2o`000:Sooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool0
08gooooo0_l0000Mooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003o
ooooooooo`08ooooo`;o000000?oooooo`000?l000000_ooool2o`000:Sooooo002/ooooo`03o`00
0?oooooooooo00Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000Z?ooool00:cooooo00?o
0000ooooooooool01Oooool3o`0000?ooooo0ol0002[ooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o00000oooool3o`000:_ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`2ioooo
o`00T?ooool2o`0001[ooooo0ol00007ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool0
1oooool2o`000003ooooool0003o00000:gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0
00000ooooooo0000o`00002]ooooo`00Toooool2o`000003ooooool0003o000001Cooooo00?o0000
ooooooooool02?ooool2o`000:oooooo002Booooo`?o000000?oooooo`000?l000005?ooool00ol0
003oooooooooo`06ooooo`Co0000[oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Ko
oooo0ol0002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00Go
0000ooooool0003o0000ooooo`02o`000;Gooooo002[ooooo`;o000000Coooooo`000?l0003ooooo
0_l0002eooooo`00Zoooool5o`0000?ooooo0ol0002booooo`00Uoooool2o`0001?ooooo00?o0000
ooooool000000_l00002ooooo`?o0000/_ooool009Oooooo0_l0000Booooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`000;Cooooo002Fooooo`?o00001?ooool2o`0000cooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000]?ooool009Kooooo0ol00004ooooo`;o00003Oooool00ol0003o
ooooooooo`2iooooo`00U_ooool2o`000003ooooool0003o0000017ooooo00?o0000ooooooooool0
^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o00001_ooool0
0ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Kooooo0ol0002iooooo`00Voooool2o`0000?o
oooo0ol00009ooooo`?o0000^Oooool009Sooooo1Ol00003ooooo`?o00001oooool5o`000;Wooooo
002Hooooo`Co000000?oooooo`000?l000001_ooool2o`0000?ooooo0ol0002kooooo`00WOooool2
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?ooool0^_ooool009_ooooo0_l00008oooo
o`;o000000Koooooo`000?l0003o0000ooooool0002kooooo`00Voooool2o`0000?ooooo1_l00000
1?l@413oooooo`000?l00002ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Moooo
o`;o00001Oooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`00
0?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003o
EEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o
000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61334 .31989 Mdot
.64375 .38781 Mdot
.4471 .55441 Mdot
.45555 .73745 Mdot
.58772 .51806 Mdot
.52563 .169 Mdot
.5079 .5985 Mdot
.38475 .78205 Mdot
.38131 .71874 Mdot
.43729 .27932 Mdot
.49899 .23583 Mdot
.36771 .39045 Mdot
.66942 .48466 Mdot
.4422 .25492 Mdot
.42724 .06251 Mdot
.42222 .61926 Mdot
.39595 .50761 Mdot
.67028 .48869 Mdot
.5627 .36936 Mdot
.64878 .70408 Mdot
.66268 .56457 Mdot
.65809 .48325 Mdot
.65325 .56262 Mdot
.66999 .5213 Mdot
.46301 .00879 Mdot
.5681 .6807 Mdot
.54168 .33331 Mdot
.56862 .4058 Mdot
.62856 .74955 Mdot
.65059 .43586 Mdot
.64263 .65095 Mdot
.40185 .84464 Mdot
.37143 .64436 Mdot
.42794 .2104 Mdot
.42532 .2046 Mdot
.60345 .77447 Mdot
.5062 .93916 Mdot
.56199 .38953 Mdot
.56709 .84794 Mdot
.36416 .48407 Mdot
.4109 .09226 Mdot
.42023 .22966 Mdot
.49096 .1313 Mdot
.59971 .27468 Mdot
.57978 .24263 Mdot
.58641 .586 Mdot
.48262 .22265 Mdot
.46145 .96899 Mdot
.51145 .80941 Mdot
.59591 .80121 Mdot
.44895 .95671 Mdot
.57926 .83934 Mdot
.76516 .37058 Mdot
.48126 .13035 Mdot
.44248 .15362 Mdot
.37343 .64941 Mdot
.37336 .68743 Mdot
.3998 .6145 Mdot
.48528 .96492 Mdot
.57188 .22952 Mdot
.57758 .62732 Mdot
.55333 .05642 Mdot
.5437 .8785 Mdot
.54339 .53427 Mdot
.37565 .32106 Mdot
.39406 .8121 Mdot
.44323 .26389 Mdot
.41754 .53682 Mdot
.55259 .34704 Mdot
.66673 .56291 Mdot
.41703 .75274 Mdot
.48641 .68006 Mdot
.4617 .23054 Mdot
.423 .35744 Mdot
.54325 .879 Mdot
.45885 .37247 Mdot
.76539 .37157 Mdot
.53406 .74308 Mdot
.59366 .81591 Mdot
.4414 .80028 Mdot
.62756 .70935 Mdot
.65058 .44737 Mdot
.45515 .73283 Mdot
.41519 .24922 Mdot
.3951 .83228 Mdot
.44158 .724 Mdot
.58807 .52402 Mdot
.57208 .62554 Mdot
.41927 .75296 Mdot
.41697 .49934 Mdot
.48084 .00721 Mdot
.70909 .25965 Mdot
.54001 .58878 Mdot
.58524 .57902 Mdot
.53849 .58866 Mdot
.68603 .2156 Mdot
.44099 .25919 Mdot
.40687 .85573 Mdot
.76784 .37515 Mdot
.44053 .82327 Mdot
.62479 .35194 Mdot
.45355 .8407 Mdot
.37872 .26687 Mdot
.61435 .30842 Mdot
.65558 .63045 Mdot
.43311 .1932 Mdot
.39871 .62018 Mdot
.56869 .38598 Mdot
.5403 .58808 Mdot
.66261 .585 Mdot
.43274 .28995 Mdot
.47903 .75367 Mdot
.39808 .8263 Mdot
.64171 .70746 Mdot
.79654 .48887 Mdot
.43693 .3754 Mdot
.5635 .67452 Mdot
.42306 .92414 Mdot
.42105 .9156 Mdot
.46384 .95278 Mdot
.6687 .49865 Mdot
.50715 .00899 Mdot
.64852 .60993 Mdot
.6352 .73898 Mdot
.66491 .57471 Mdot
.43697 .68821 Mdot
.62757 .73953 Mdot
.66811 .19043 Mdot
.64519 .44752 Mdot
.50208 .32364 Mdot
.65882 .52111 Mdot
.63548 .38871 Mdot
.38209 .23451 Mdot
.50926 .1419 Mdot
.50543 .14601 Mdot
.62073 .77073 Mdot
.56761 .86637 Mdot
.6232 .75419 Mdot
.46363 .2297 Mdot
.36711 .44939 Mdot
.41634 .08768 Mdot
.63312 .15631 Mdot
.51939 .67637 Mdot
.55376 .34426 Mdot
.39607 .52804 Mdot
.64837 .69931 Mdot
.40513 .8725 Mdot
.8022 .53128 Mdot
.57823 .51094 Mdot
.5721 .63035 Mdot
.44041 .01144 Mdot
.47033 .85312 Mdot
.52606 .27938 Mdot
.67149 .51029 Mdot
.49506 .66304 Mdot
.58084 .26524 Mdot
.55212 .88163 Mdot
.55895 .86164 Mdot
.40306 .85844 Mdot
.48945 .95412 Mdot
.55619 .87755 Mdot
.54841 .73496 Mdot
.60653 .79705 Mdot
.36581 .37776 Mdot
.60563 .76383 Mdot
.52457 .18182 Mdot
.63014 .38158 Mdot
.40222 .85956 Mdot
.65687 .63366 Mdot
.55131 .34513 Mdot
.58495 .84004 Mdot
.5845 .81294 Mdot
.50339 .70638 Mdot
.55235 .35674 Mdot
.58146 .57345 Mdot
.58047 .49467 Mdot
.3672 .4735 Mdot
.68234 .21132 Mdot
.58126 .26781 Mdot
.45917 .30678 Mdot
.60559 .78957 Mdot
.60017 .81456 Mdot
.36942 .34479 Mdot
.41469 .53024 Mdot
.41524 .07823 Mdot
.52311 .38664 Mdot
.37514 .64708 Mdot
.67514 .20476 Mdot
.43631 .94514 Mdot
.36673 .36745 Mdot
.48613 .12494 Mdot
.65118 .69312 Mdot
.54201 .51731 Mdot
.56345 .07195 Mdot
.38652 .78832 Mdot
.40842 .09258 Mdot
.37856 .26457 Mdot
.584 .57887 Mdot
.7129 .25406 Mdot
.39546 .58823 Mdot
.44379 .35523 Mdot
.44564 .34669 Mdot
.47983 .68707 Mdot
.58277 .55531 Mdot
.72377 .27437 Mdot
.63432 .39218 Mdot
.53837 .48253 Mdot
.54462 .19794 Mdot
.50475 .72036 Mdot
.52099 .36599 Mdot
.48985 .22034 Mdot
.6641 .4519 Mdot
.54198 .72608 Mdot
.6556 .63805 Mdot
.41561 .47199 Mdot
.63277 .39252 Mdot
.54143 .72407 Mdot
.3696 .32437 Mdot
.51092 .337 Mdot
.59065 .27599 Mdot
.36619 .59343 Mdot
.56823 .66032 Mdot
.43863 .93539 Mdot
.66146 .61407 Mdot
.61379 .74134 Mdot
.41904 .4221 Mdot
.58503 .49365 Mdot
.63113 .33869 Mdot
.51925 .66546 Mdot
.42579 .06523 Mdot
.43756 .70151 Mdot
.51106 .44082 Mdot
.73655 .31075 Mdot
.44368 .81623 Mdot
.52518 .28653 Mdot
.50863 .01271 Mdot
.5558 .36591 Mdot
.61853 .31629 Mdot
.6594 .56042 Mdot
.63192 .37479 Mdot
.56334 .0689 Mdot
.49199 .1246 Mdot
.65771 .64331 Mdot
.41709 .75281 Mdot
.42242 .9158 Mdot
.53298 .60895 Mdot
.51843 .91899 Mdot
.39862 .55993 Mdot
.42004 .7654 Mdot
.55511 .86488 Mdot
.41378 .07797 Mdot
.43767 .37225 Mdot
.53799 .55695 Mdot
.4943 .94644 Mdot
.54419 .73426 Mdot
.55213 .35824 Mdot
.42429 .19482 Mdot
.46294 .36214 Mdot
.36855 .61159 Mdot
.47569 .97054 Mdot
.4821 .84488 Mdot
.52395 .2836 Mdot
.61322 .7454 Mdot
.47866 .28907 Mdot
.4529 .83701 Mdot
.61298 .32649 Mdot
.50312 .25051 Mdot
.551 .21875 Mdot
.59014 .79959 Mdot
.51137 .79682 Mdot
.62112 .74707 Mdot
.44016 .15609 Mdot
.42506 .33244 Mdot
.46118 .83523 Mdot
.56384 .86663 Mdot
.41521 .55697 Mdot
.57796 .41615 Mdot
.43474 .93612 Mdot
.46916 .21273 Mdot
.56439 .23145 Mdot
.60563 .79263 Mdot
.47292 .2805 Mdot
.42845 .33064 Mdot
.47936 .95746 Mdot
.37051 .3545 Mdot
.56855 .38292 Mdot
.50201 .63586 Mdot
.57507 .57958 Mdot
.65702 .66512 Mdot
.57527 .62418 Mdot
.6276 .70495 Mdot
.67936 .21324 Mdot
.46673 .963 Mdot
.40155 .14152 Mdot
.4356 .92749 Mdot
.51685 .48863 Mdot
.52068 .92982 Mdot
.57307 .08782 Mdot
.66351 .63915 Mdot
.42007 .08028 Mdot
.80382 .55151 Mdot
.48805 .83619 Mdot
.44304 .14448 Mdot
.63421 .37725 Mdot
.41273 .88691 Mdot
.42938 .04828 Mdot
.48124 .21984 Mdot
.42319 .90939 Mdot
.54327 .73819 Mdot
.43396 .42732 Mdot
.66399 .47408 Mdot
.39556 .50119 Mdot
.66679 .51006 Mdot
.43689 .01833 Mdot
.45067 .31963 Mdot
.59998 .29628 Mdot
.42809 .20601 Mdot
.37967 .27888 Mdot
.46625 .28938 Mdot
.37478 .28595 Mdot
.53025 .04345 Mdot
.62106 .13148 Mdot
.43058 .66413 Mdot
.49576 .12217 Mdot
.40823 .28455 Mdot
.53198 .89577 Mdot
.58529 .46256 Mdot
.42993 .47581 Mdot
.51506 .54614 Mdot
.3994 .6237 Mdot
.37137 .67203 Mdot
.47819 .95248 Mdot
.54201 .56827 Mdot
.66147 .45981 Mdot
.49883 .31246 Mdot
.47603 .68808 Mdot
.63393 .34737 Mdot
.5117 .14858 Mdot
.52396 .18057 Mdot
.54535 .74088 Mdot
.58194 .55495 Mdot
.75396 .33439 Mdot
.52362 .77354 Mdot
.64915 .46063 Mdot
.53983 .56387 Mdot
.36993 .60426 Mdot
.5398 .32996 Mdot
.6215 .75529 Mdot
.65336 .5006 Mdot
.53551 .6195 Mdot
.54609 .70792 Mdot
.62719 .14731 Mdot
.36499 .4698 Mdot
.54162 .90635 Mdot
.60605 .77222 Mdot
.51277 .8023 Mdot
.3937 .49541 Mdot
.59556 .79513 Mdot
.45038 .83093 Mdot
.36543 .45077 Mdot
.60364 .10434 Mdot
.65711 .64724 Mdot
.38464 .21881 Mdot
.37798 .25776 Mdot
.3879 .18358 Mdot
.46165 .68122 Mdot
.45419 .83163 Mdot
.42487 .06628 Mdot
.37154 .66219 Mdot
.45849 .67702 Mdot
.63886 .67326 Mdot
.49517 .81763 Mdot
.53171 .17494 Mdot
.62203 .34431 Mdot
.39784 .81793 Mdot
.61959 .32047 Mdot
.50407 .94433 Mdot
.49228 .9433 Mdot
.65255 .56135 Mdot
.55867 .8841 Mdot
.65726 .5278 Mdot
.44433 .02674 Mdot
.79999 .49603 Mdot
.44445 .93563 Mdot
.57266 .2441 Mdot
.48338 .67845 Mdot
.49387 .00724 Mdot
.43467 .80664 Mdot
.51556 .53712 Mdot
.36659 .38346 Mdot
.66637 .56725 Mdot
.42969 .51943 Mdot
.42992 .3151 Mdot
.56367 .68477 Mdot
.53312 .30485 Mdot
.46226 .97093 Mdot
.6713 .57985 Mdot
.57172 .08363 Mdot
.37034 .3314 Mdot
.39959 .38019 Mdot
.75514 .34974 Mdot
.39619 .4225 Mdot
.58014 .47811 Mdot
.58181 .46479 Mdot
.48972 .35389 Mdot
.36915 .63673 Mdot
.36789 .38919 Mdot
.53934 .32669 Mdot
.52291 .65945 Mdot
.48282 .20779 Mdot
.4274 .66714 Mdot
.43297 .02871 Mdot
.58971 .54709 Mdot
.61827 .74107 Mdot
.4969 .72986 Mdot
.5332 .29669 Mdot
.48065 .2878 Mdot
.58843 .5416 Mdot
.42259 .23097 Mdot
.51716 .26321 Mdot
.53912 .49265 Mdot
.36654 .48225 Mdot
.47037 .62263 Mdot
.42894 .19159 Mdot
.39818 .61277 Mdot
.60313 .31848 Mdot
.48589 .82774 Mdot
.54926 .34229 Mdot
.68487 .20704 Mdot
.62948 .35072 Mdot
.79077 .4571 Mdot
.59998 .2718 Mdot
.54044 .48116 Mdot
.36994 .53972 Mdot
.4349 .04575 Mdot
.5157 .27047 Mdot
.65201 .51947 Mdot
.75759 .34572 Mdot
.51639 .6791 Mdot
.43169 .5533 Mdot
.58024 .52328 Mdot
.62236 .72751 Mdot
.4651 .83256 Mdot
.71127 .25671 Mdot
.52461 .38781 Mdot
.47222 .13238 Mdot
.4056 .30589 Mdot
.5445 .54137 Mdot
.46079 .30137 Mdot
.4139 .478 Mdot
.38142 .75877 Mdot
.44823 .32294 Mdot
.60687 .79418 Mdot
.63722 .36647 Mdot
.59249 .27304 Mdot
.62644 .73938 Mdot
.62924 .6966 Mdot
.3955 .46612 Mdot
.64807 .1559 Mdot
.43072 .30989 Mdot
.37089 .66748 Mdot
.40401 .1088 Mdot
.51148 .26886 Mdot
.53024 .91937 Mdot
.49761 .81716 Mdot
.39772 .44631 Mdot
.62558 .74746 Mdot
.62216 .34108 Mdot
.56881 .39491 Mdot
.54833 .70341 Mdot
.41682 .25256 Mdot
.51686 .014 Mdot
.52602 .17943 Mdot
.44908 .40851 Mdot
.50278 .14853 Mdot
.45019 .81858 Mdot
.47466 .69177 Mdot
.42009 .57517 Mdot
.47176 .12949 Mdot
.48236 .12178 Mdot
.43969 .36729 Mdot
.54132 .73688 Mdot
.39201 .80132 Mdot
.58839 .49207 Mdot
.60966 .3206 Mdot
.53748 .29723 Mdot
.57374 .45541 Mdot
.44675 .64807 Mdot
.79589 .46479 Mdot
.43983 .61456 Mdot
.63925 .3676 Mdot
.40942 .85779 Mdot
.61019 .75709 Mdot
.55568 .3555 Mdot
.61645 .7684 Mdot
.36868 .36129 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool3o`0000?ooooo0ol0002kooooo`00Woooool2o`0000?ooooo0ol0
0003ooooo`?o000000?oooooo`000?l00000^?ooool009Sooooo0_l00005ooooo`;o00000oooool0
0ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`000;Sooooo002Hooooo`;o00002?ooool0
0omEEEGoIVIVo`000007ooooo`05o`000?oooooo0000o`000?ooool00_l0002eooooo`00Uoooool2
o`0001?ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Gooooo`;o00004oooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002Eooooo`;o00000_ooool2o`00017ooooo
00?o0000ooooooooool0^Oooool009Gooooo0_l00002ooooo`;o00004Oooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000
/?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00U?ooool4
o`0001Cooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`?o0000^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo
002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00Toooool3o`0001Kooooo00?o0000
ooooooooool0^Oooool009?ooooo0ol0000Fooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o
00005oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool0
4Oooool3o`000:Gooooo002/ooooo`?o00004_ooool2o`000:Gooooo002?ooooo`Co00006Oooool0
0ol0003oooooooooo`2iooooo`00Soooool4o`0001Wooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool05?ooool2o`000:?ooooo002@ooooo`;o00006_ooool00ol0003ooooo
ooooo`0Dooooo`?o0000X_ooool008gooooo1Ol0000Jooooo`03o`000?oooooooooo01Gooooo0_l0
002Rooooo`00SOooool3o`0001cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000
V?ooool00:cooooo00?o0000ooooooooool07oooool2o`0009Sooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgo`000?l000000_ooool3o`000;_ooooo0021ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool9o`00
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;o000000?o000000?oooooo`000?ooool0^_ooool008Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo1Ol00002ooooo`;o000000?oooooo`00
0?ooool09_ooool2o`0009;ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003ooooo
02Kooooo0_l0002Booooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2i
ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool00_l0002gooooo`00Roooool2o`0000co
oooo0_l0000Aooooo`Go0000]oooool009Wooooo0_l0000Aooooo`Go00009Oooool2o`00093ooooo
002/ooooo`Go00009Oooool2o`00093ooooo002Hooooo`?o00004Oooool00ol0003oooooooooo`0]
ooooo`;o0000R_ooool009Sooooo0ol0000Aooooo`03o`000?oooooooooo02Wooooo0_l00002oooo
o`;o0000R_ooool00:cooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:co
oooo0ol00007ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool01Oooool4o`000;3ooooo
002/ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00Qoooool2o`0002?ooooo00?o0000
ooooooooool01?ooool3o`000;;ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`2ioooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool0=?ooool2o`0008?ooooo002Cooooo`Co0000
5Oooool00ol0003oooooooooo`0dooooo`;o0000Poooool009?ooooo1?l0000Eooooo`03o`000?oo
oooooooo00_ooooo0_l0002/ooooo`00[?ooool3o`0000_ooooo0_l0002/ooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool0^Oooool009?ooooo0ol0000Fooooo`03o`000?oooooooooo03Ko
oooo0_l00002ooooo`;o0000OOooool009Cooooo0_l0000@ooooo`;o00001?ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool2o`0007gooooo002Dooooo`;o00002oooool2o`0000?ooooo0_l0
0004ooooo`03o`000?oooooooooo03Sooooo0ol0001nooooo`00XOooool2o`0000Wooooo00?o0000
ooooooooool0>?ooool4o`0007gooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0=oooo
o`;o0000:oooool2o`0007gooooo0025ooooo`;o00007_ooool5o`0000;ooooo00?o0000oooooooo
ool03Oooool2o`000:[ooooo002Uooooo`Go00000_ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`?o00002oooool3o`0000[ooooo00?o0000ooooooooool04_ooool4
o`000:?ooooo0025ooooo`;o00002_ooool3o`0000_ooooo0ol0000:ooooo`03o`000?oooooooooo
01;ooooo1?l0002Sooooo`00QOooool2o`0002Cooooo0_l0002kooooo`00Zoooool2o`000;_ooooo
002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00TOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool05Oooool4o`000:3ooooo0029ooooo`Ko000000?oooooo`000?l000000oooool00ol@413ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo
002@ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002iooooo`00T?ooool2o`0000?ooooo00?o0000ooooooooool00_l00008ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool3o`0004?ooooo0_l0001dooooo`00Poooool2o`0000cooooo00Go410@
oooooooooooooooooa0@4002ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04;ooooo0ol0001dooooo`00Poooool2o`0000cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`02ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo0_l0
001eooooo`00Poooool2o`0000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`?o00001ooo
ool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`0001?ooooo0_l0000Yooooo`;o0000MOoo
ool008?ooooo0ol0000Cooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`;o00004oooool2
o`000:3ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`04o`0001?ooooo0_l0002Poooo
o`00[?ooool00ol0003oooooooooo`04o`0001Oooooo0_l000000ooooooo0000o`00002Iooooo`00
[?ooool3o`0001[ooooo1_l0000Vooooo`;o0000LOooool008Cooooo0_l0000Aooooo`;o00004ooo
ool00ol0003oooooooooo`05ooooo`;o00004oooool2o`000003ooooool0003o000002Oooooo0_l0
001aooooo`00Q?ooool2o`00017ooooo0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`;o0000/_ooool008;ooooo0_l00009ooooo`;o00005?ooool2o`0000Oooooo00?o0000oooo
ooooool01?ooool2o`000;?ooooo0022ooooo`;o00002Oooool2o`00017ooooo0_l00003ooooo`;o
00001Oooool00ol0003oooooooooo`04ooooo`?o0000/_ooool009Gooooo0_l00009ooooo`;o0000
0oooool2o`0000Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`08ooooo`?o00004oooool2
o`0009Wooooo002Oooooo`;o00002oooool3o`0000Sooooo0ol0000Cooooo`;o0000VOooool009oo
oooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00004?ooool2o`0000cooooo
00?o0000ooooooooool01oooool2o`000;3ooooo002<ooooo`;o00001oooool2o`0000Oooooo0_l0
000<ooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o0000UOooool009Gooooo0_l0000D
ooooo`;o00009?ooool2o`0002Oooooo0_l0001/ooooo`00U?ooool2o`0001Gooooo0_l0000Voooo
o`;o00009Oooool2o`0006cooooo002Dooooo`;o00001Oooool2o`0000oooooo00?o0000oooooooo
ool07oooool2o`0000?ooooo0_l0002Cooooo`00Poooool2o`0001Kooooo0_l0000?ooooo`03o`00
0?oooooooooo01oooooo1ol0002Cooooo`00POooool4o`0001Gooooo0_l0000@ooooo`?o00008Ooo
ool5o`0009?ooooo0021ooooo`;o00005oooool2o`00013ooooo0_l0000;ooooo`;o00005_ooool2
o`0009Gooooo0021ooooo`;o00004Oooool2o`0001Kooooo00?o0000ooooooooool02_ooool2o`00
01Kooooo0_l0002Eooooo`00POooool2o`00013ooooo0ol0000Fooooo`03o`000?oooooooooo00[o
oooo0_l00014ooooo`;o0000Ioooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00;o0000
2?ooool2o`0004Cooooo0_l0001Wooooo`00[?ooool00ol0003oooooooooo`02o`0002Kooooo0_l0
002?ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00005_ooool2o`000003ooooool0003o
000008oooooo0020ooooo`;o00006?ooool2o`00013ooooo00?o0000ooooooooool03Oooool3o`00
01Gooooo0_l0000[ooooo`;o0000IOooool0083ooooo0_l0000Hooooo`;o00004?ooool00ol0003o
ooooooooo`0>ooooo`;o00005Oooool2o`0000;ooooo0_l0000Vooooo`?o0000IOooool00:cooooo
0ol0000>ooooo`;o00005_ooool5o`0002Kooooo0_l0001Vooooo`00POooool2o`0001Kooooo0_l0
000=ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`;o00005Oooool3o`00093ooooo0021
ooooo`;o00003oooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool00ol0003oooooooooo`0>
ooooo`?o0000Z?ooool0083ooooo0_l0000@ooooo`;o00002oooool2o`0000_ooooo00?o0000oooo
ooooool03_ooool2o`000:Wooooo0020ooooo`;o00007Oooool2o`0000_ooooo00?o0000oooooooo
ool0^Oooool0083ooooo0_l00007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?o
oooo1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03oooo
o`;o00002_ooool2o`0001Wooooo0ol0002<ooooo`00P?ooool2o`0000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q0oooool2o`000004ob4Q8Oo^k^koooooodA4A0Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`03ooooo`;o00002_ooool4o`0001Oooooo0ol0000W
ooooo`;o0000Hoooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002Oooool2
o`000005oooooonHV9So8B4Qonk^k_ooool00_l00006ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool2o`00047ooooo0_l0001Sooooo`00ROooool01Ol0003ooooooooooooo
oooo000000Wooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^00;o00001Oooool00omgMgOo<S8boooo
o`04ooooo`?o0000:?ooool3o`0002Wooooo0ol0001Rooooo`00Ooooool2o`0000Sooooo0ol00000
0ooooooo0000ooooo`08ooooo`;o00000oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Xooooo`?o0000:_ooool2o`0006;ooooo001o
ooooo`;o00002?ooool01Ol@413o0000o`000?oooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l0000Cooooo`;o0000Sooo
ool0083ooooo0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o0000
4oooool2o`0008oooooo0020ooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`04ooooo`?o
00003?ooool2o`0001Cooooo0_l000000ooooooo0000o`00002;ooooo`00P?ooool2o`0002[ooooo
00?o0000ooooooooool01?ooool3o`0000[ooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
Roooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo017ooooo1?l0000Cooooo`?o0000S_oo
ool00:cooooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0002?ooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo
0_l0002Tooooo`00Voooool2o`0000oooooo00?o0000ooooooooool04oooool2o`000:Cooooo002K
ooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Foooo
o`;o0000XOooool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0029ooooo`;o0000
1_ooool2o`0001Wooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00006ooooo`;o00006Ooo
ool3o`000;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00;o0000;?oo
ool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool008[ooooo0_l0000Poooo
o`03o`000?oooooooooo0;Wooooo0020ooooo`;o00002?ooool2o`00023ooooo00?o0000oooooooo
ool0;?ooool4o`0008Wooooo001oooooo`?o0000:_ooool3o`0002cooooo1?l00003ooooo`;o0000
Q?ooool007oooooo0_l0000[ooooo`03o`000?oooooooooo01Gooooo0_l0000Looooo`;o0000Q?oo
ool00:cooooo00?o0000ooooooooool05Oooool2o`0004Kooooo0_l0001Jooooo`002Oooool4o`00
0003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM01Kooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go000000Goooooo`000?l0003oooooodA4A002o`000003oc8b<_oMgMgooooo00kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo0_l0000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413ooooooooo
o`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo0ol000000onHV9SoMgMgooooo`04oooo
o`;o8B4Q1?ooool01_nHV9So8B4Qonk^k_ooooooA4A4ooooo`;o00000_ooool2o`000003ogMgMolb
<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`02ooooo`;o00002_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
1_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo0_l000000oo^k^koooooooooo`07ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool06?ooool3o`000003ooooool@413ooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool01?l0003oooooooooooooool2o`0000[ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002?ooool2
o`000003ob4Q8Oo^k^kooooo00Kooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00?ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Wooooo00?oMgMgofIVI_ooool0
0_ooool2o`000004ob4Q8Ol0003o<S8bolc<c1Kooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?l0003o
c<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000[ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00005_ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00Co0000ooooool0003o00004?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00;ooooo0ol00002ooooo`;o00005_ooool00ol0003oooooooooo`0G
ooooo`;o000000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool2o`0000Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`Ko00005oooool00ol0003o
ooooooooo`09ooooo`?o00002oooool2o`000004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEE
EOmVIVKo000001Kooooo001oooooo`?o0000:_ooool00ol0003oooooooooo`09ooooo`?o00009Ooo
ool2o`000003ooooool0003o000008?ooooo001oooooo`;o0000:oooool00ol0003oooooooooo`02
ooooo`;o0000<?ooool3o`0002Oooooo0_l0001Iooooo`00[?ooool00ol0003oooooooooo`02oooo
o`;o00005_ooool2o`0001Wooooo0_l0000Wooooo`;o0000C_ooool2o`0000;ooooo0_l00005oooo
o`00R?ooool2o`0002;ooooo00?o0000ooooooooool02Oooool2o`0000cooooo1Ol0002Booooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo
00Wooooo0_l0000<ooooo`Co0000AOooool2o`0004gooooo00CogMgMo`000?l@413oc<c<1_ooool0
00Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool3o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`;o00000oooool2o`000003ooooool0003ooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`00
00;ooooo0_l00005ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0=?ooool3o`0008;o
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Fooooo`;o00007?ooool3o`0008;ooooo
002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool02_ooool2o`0000kooooo0_l0000Cooooo`;o0000R?ooool009Cooooo0_l0000Foooo
o`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o00004oooool4o`0000;ooooo0_l00022oooo
o`00[?ooool3o`0001Oooooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool2o`0008;o
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l00000
5?ooool2o`0008Oooooo0029ooooo`;o00001?ooool2o`0001_ooooo00?o0000ooooooooool0<?oo
ool2o`0002kooooo0_l0001Gooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool02oooool2
o`0005?ooooo0_l0001Gooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool00_ooool2o`00
00Oooooo0_l0002/ooooo`00POooool2o`0000gooooo0_l0000Jooooo`03o`000?oooooooooo00;o
oooo0_l0002eooooo`00POooool2o`0002Wooooo00?o0000ooooooooool02oooool2o`0000gooooo
0_l0002Mooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`0000gooooo0_l0
002Mooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00005_ooool2o`0009gooooo002/oooo
o`?o00006_ooool2o`0004Gooooo0_l0001Fooooo`00UOooool2o`0000?ooooo0_l0000@ooooo`03
o`000?oooooooooo01Sooooo0_l00017ooooo`;o0000E_ooool0093ooooo0_l00003ooooo`;o0000
0oooool2o`00013ooooo00?o0000ooooooooool02Oooool2o`0000gooooo0_l0002Oooooo`00R_oo
ool2o`0000Cooooo0_l0000Jooooo`03o`000?oooooooooo00Wooooo0_l0000Tooooo`Co0000Q_oo
ool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00[ooooo0_l0000Sooooo`Oo0000Poooool0
0:cooooo00?o0000ooooooooool02_ooool2o`0002?ooooo0_l000000ooooooo0000o`000002o`00
08?ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000Wooooo`;o0000Q?ooool00:cooooo
00?o0000ooooooooool02_ooool2o`0000_ooooo0_l0002Pooooo`00TOooool2o`0001Wooooo0ol0
000Gooooo`;o00006_ooool2o`0008Cooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0E
ooooo`;o000000Coooooo`000?l0003o00006?ooool4o`0008;ooooo002/ooooo`03o`000?oooooo
oooo01Gooooo0_l000001?oooooo0000o`000?l0000Jooooo`;o0000P_ooool00:cooooo00?o0000
ooooooooool06Oooool2o`0001Oooooo0_l00025ooooo`00ROooool2o`00027ooooo00?o0000oooo
ooooool02Oooool3o`0000gooooo0_l0000Gooooo`;o0000QOooool008Wooooo0_l0000Qooooo`03
o`000?oooooooooo00Wooooo0ol0002]ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0
^Oooool007oooooo0_l0000[ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`Co0000^?ooool0
087ooooo0_l0000Yooooo`04o`000?oooooo0000o`000;Sooooo0021ooooo`;o0000:Oooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00009Oooool2o`0008Wo
oooo0020ooooo`;o00002?ooool2o`00023ooooo00?o0000ooooooooool01oooool2o`0002Gooooo
0_l00029ooooo`00P?ooool2o`0000Sooooo0_l0000<ooooo`;o00004_ooool00ol0003ooooooooo
o`0booooo`;o0000QOooool008Wooooo00Gok^k^o`000?l0003o<S8bonk^kP04ooooo`;o000000Co
8B4Qoooooooooooooooo1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`08ooooo`;o0000:?ooool2o`0008Gooooo0029ooooo`05ogMgMol0003o0000oiRHV?mg
MgL01?ooool2o`000003ob4Q8Ooooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A004oooo
o`;o000000?oooooogMgMolb<S801Oooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wo
oooo00Go410@o`000?l0003ooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l00002oooo
o`03o`000?oooooooooo00?ooooo0ol0000Dooooo`?o0000X_ooool008Wooooo0ol000000ooooooo
0000ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Dooooo`Co0000XOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
01Cooooo1?l0000Hooooo`;o0000Qoooool008Wooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`;o00006_ooool2o`0008Oooooo0020ooooo`;o00001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l0000a
ooooo`;o0000Qoooool0083ooooo0_l00007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000<Oooool2o`000003ooooool0
003o000008Cooooo002/ooooo`03o`000?oooooooooo033ooooo1Ol00024ooooo`00POooool2o`00
02Wooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo0021ooooo`?o00005_ooool2o`00013o
oooo00?o0000ooooooooool0<?ooool2o`0008Oooooo0022ooooo`;o00005_ooool2o`00013ooooo
0ol0000/ooooo`;o00000_ooool2o`0008Oooooo002/ooooo`03o`000?oooooooooo02cooooo0_l0
002;ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04oooo
o`;o00003Oooool2o`000:Cooooo0021ooooo`;o00004_ooool2o`0001?ooooo0ol00006ooooo`;o
00003Oooool2o`000:Cooooo0021ooooo`;o00004Oooool3o`0001?ooooo0ol00005ooooo`;o0000
:oooool2o`0008Oooooo0021ooooo`;o00004Oooool2o`0001Kooooo00?o0000ooooooooool00ooo
ool2o`0002_ooooo0_l00027ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0:_ooool2
o`0008gooooo0021ooooo`;o00006oooool2o`0000cooooo0ol00003ooooo`;o00003Oooool2o`00
01Kooooo0_l0002=ooooo`00W_ooool2o`0000Kooooo0ol00003ooooo`03o`000?oooooooooo00;o
oooo0ol0000=ooooo`;o0000YOooool009oooooo0_l00005ooooo`?o00000oooool00ol0003ooooo
ooooo`02ooooo`;o00003oooool2o`000:Cooooo002Oooooo`;o00002oooool00ol0003ooooooooo
o`0Booooo`?o0000Y?ooool008;ooooo0_l0000Cooooo`;o00002oooool3o`0000Gooooo00?o0000
ooooooooool04_ooool2o`000:Gooooo0022ooooo`;o00004oooool2o`0000[ooooo1?l00005oooo
o`03o`000?oooooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`0^ooooo`;o
0000ROooool00:cooooo00?o0000ooooooooool09oooool2o`0000Gooooo0_l00029ooooo`00[?oo
ool3o`0002Oooooo0_l00005ooooo`;o0000ROooool009Oooooo0_l0000Cooooo`03o`000?oooooo
oooo00gooooo0_l0000Oooooo`;o0000ROooool009Oooooo0_l0000Cooooo`?o00003Oooool2o`00
01Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000ROooool00:cooooo0ol0000<ooooo`;o
00006Oooool2o`0000;ooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000
6Oooool2o`00093ooooo002/ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00009_ooool0
0ol0003oooooooooo`2iooooo`00Q?ooool2o`0002Kooooo0ol0002iooooo`00V?ooool2o`0001;o
oooo0ol0000:ooooo`;o0000[Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00[ooooo
0_l0000Iooooo`;o0000T_ooool00:_ooooo0_l0000<ooooo`;o00006Oooool2o`0009;ooooo002M
ooooo`;o00003?ooool2o`0000gooooo0_l0002/ooooo`00WOooool2o`0000gooooo00?o0000oooo
ooooool02_ooool5o`000:[ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`Go
00005oooool5o`0008kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo0_l000001?oo
oooo0000o`000?l0000Dooooo`Wo0000S_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo0_l00002
ooooo`;o00005?ooool4o`0009?ooooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo0_l000000ooooooo0000o`000002
o`00093ooooo002@ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Uooooo`Co0000T?ooool0093ooooo0ol00002ooooo`03o`000?oooooooooo00[o
oooo00?o0000ob4Q8Ol000000_l00005ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00
Q?ooool2o`0000_ooooo0_l00002ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool0
0_l00005ooooo`03o`000?oooooooooo027ooooo0_l00002ooooo`;o0000T_ooool008Cooooo0_l0
000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo027ooooo0_l0002Fooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00TOooool2o`0001Wooooo00?o
0000ooooooooool07oooool2o`0009Sooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0S
ooooo`?o0000Toooool00:cooooo00?o0000ooooooooool01?ooool2o`0001[ooooo0_l000001?oo
oooo0000o`000?l0002Cooooo`00[?ooool3o`0000Cooooo0_l0000Iooooo`?o0000Uoooool00:co
oooo00?o0000ooooooooool07oooool2o`0009Sooooo0026ooooo`;o00009?ooool00ol0003ooooo
ooooo`2iooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0000T
ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0Ooooo
o`;o0000V?ooool00:cooooo00?o0000ooooooooool07?ooool2o`000004ooooool0003o0000o`00
09Oooooo002/ooooo`03o`000?oooooooooo00;o00006_ooool2o`000004ooooool0003o0000o`00
09Oooooo0028ooooo`;o00003_ooool2o`0001;ooooo1Ol0000Hooooo`Co00000_ooool2o`0009Oo
oooo0028ooooo`;o00003_ooool2o`0001;ooooo00Co0000oooooooooooooooo0_l0000Gooooo`Co
0000Voooool009Kooooo0_l0000Dooooo`04o`000?ooooooooooooooo`;o0000]_ooool009Kooooo
0_l0000Dooooo`03o`000?oooooooooo00;o0000]oooool008Wooooo0_l0000Qooooo`03o`000?oo
oooooooo00;o00005_ooool2o`0009oooooo0029ooooo`;o00003_ooool2o`00017ooooo00?o0000
ooooooooool06?ooool2o`000004ooooool0003o0000ooooo`;o0000VOooool008[ooooo0_l0000=
ooooo`Co00003Oooool3o`0001gooooo0_l000000ooooooo0000o`00002Iooooo`00R_ooool2o`00
00oooooo0_l0000=ooooo`?o0000^oooool009Sooooo0_l0000Booooo`?o0000^Oooool008[ooooo
0_l0000<ooooo`;o00003Oooool2o`0000?ooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0
000?ooooo`?o00002Oooool2o`0000?ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000@
ooooo`?o00000_ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Aoooo
o`;o000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
09cooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool00ol0003oooooooooo`0Goooo
o`Co0000W_ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo01Oooooo1?l0002Nooooo`00
Roooool2o`0001Wooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00006Ooo
ool2o`0000Cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`?o00004oooool2
o`000:Cooooo002=ooooo`;o00004oooool2o`0000Sooooo00?o0000ooooooooool0^Oooool008co
oooo1?l0000Booooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00Roooool5o`0001cooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo002;ooooo`;o00007oooool00ol0003ooooooooo
o`0?ooooo`?o0000Yoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0?ooooo`;o000000Coooooo`000?l0003o0000Y?ooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool04_ooool3o`000:Cooooo0029ooooo`03oa0@4?oooooooooo00;o0000
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
^Oooool008Wooooo00?o0000ooooooooool00_l0000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0;ooooo`;o00000_ooool2o`000:Sooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool2o`000004ooooool0003o0000o`000:Sooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0>ooooo`Co0000Yoooool008Wooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2
o`0000Sooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
08oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool3o`0000Oooooo0_l0
002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:oooo
o`;o0000[Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00
T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool2
o`000;3ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o0000/?ooool009;o
oooo0_l0000Hooooo`?o0000^Oooool009;ooooo0_l00002ooooo`;o00005?ooool00ol0003ooooo
ooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00U_ooool5o`00017ooooo00?o0000oooo
ooooool0^Oooool009Kooooo1Ol0000Aooooo`04o`000?oooooo0000o`000;Sooooo002Yooooo`;o
000000?oooooo`000?ooool00_l0002hooooo`00Uoooool2o`00013ooooo1_l0002iooooo`00Uooo
ool2o`00017ooooo1Ol0002iooooo`00X?ooool2o`0000;ooooo0_l00006ooooo`?o0000^Oooool0
0:3ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool009_o
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00
Voooool2o`0000Sooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o00001?oo
ool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00004ooooo`;o00000oooool0
0ol0003oooooooooo`2iooooo`00Woooool2o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo
0;Wooooo002Oooooo`;o00000oooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`00
0?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003o
EEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o
000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60515 .29844 Mdot
.64455 .39144 Mdot
.48108 .36662 Mdot
.55085 .52458 Mdot
.5635 .34332 Mdot
.49203 .12332 Mdot
.44135 .41366 Mdot
.40107 .13512 Mdot
.389 .22524 Mdot
.45819 .76737 Mdot
.41185 .53903 Mdot
.48534 .01003 Mdot
.6693 .51895 Mdot
.44344 .74833 Mdot
.56467 .1002 Mdot
.53785 .63993 Mdot
.43023 .79145 Mdot
.6698 .52469 Mdot
.47156 .19663 Mdot
.60968 .78417 Mdot
.6583 .5925 Mdot
.6583 .49165 Mdot
.65252 .56822 Mdot
.66716 .55739 Mdot
.60629 .14591 Mdot
.59894 .54248 Mdot
.42878 .3019 Mdot
.48708 .20493 Mdot
.5816 .83052 Mdot
.65056 .43567 Mdot
.63458 .6756 Mdot
.37461 .34435 Mdot
.4179 .0875 Mdot
.39514 .47502 Mdot
.39495 .40804 Mdot
.57043 .82916 Mdot
.41928 .88662 Mdot
.46827 .20711 Mdot
.50913 .92311 Mdot
.47147 .00429 Mdot
.57088 .09374 Mdot
.39367 .47163 Mdot
.44366 .15159 Mdot
.59502 .2645 Mdot
.56861 .22177 Mdot
.58863 .42807 Mdot
.41999 .63254 Mdot
.37521 .65637 Mdot
.57146 .689 Mdot
.54743 .8731 Mdot
.3727 .61333 Mdot
.51127 .92795 Mdot
.76498 .63013 Mdot
.42953 .19004 Mdot
.40575 .28735 Mdot
.40684 .13156 Mdot
.41942 .07579 Mdot
.44973 .83682 Mdot
.39268 .78762 Mdot
.55878 .20629 Mdot
.59284 .46932 Mdot
.69105 .25702 Mdot
.48356 .94496 Mdot
.46652 .26415 Mdot
.47754 .02113 Mdot
.38028 .27864 Mdot
.45391 .75892 Mdot
.52827 .66315 Mdot
.44867 .22682 Mdot
.66078 .59953 Mdot
.47542 .86206 Mdot
.47763 .31322 Mdot
.4362 .71456 Mdot
.48565 .76858 Mdot
.48317 .94503 Mdot
.50857 .52019 Mdot
.7647 .63108 Mdot
.58622 .58322 Mdot
.53146 .90249 Mdot
.52904 .76686 Mdot
.61011 .74756 Mdot
.65021 .44399 Mdot
.54933 .51612 Mdot
.39305 .48977 Mdot
.38607 .2173 Mdot
.55088 .59556 Mdot
.56647 .35106 Mdot
.58536 .45019 Mdot
.48639 .85143 Mdot
.52277 .67908 Mdot
.6177 .16337 Mdot
.76679 .49172 Mdot
.50095 .28334 Mdot
.58415 .41435 Mdot
.49688 .27802 Mdot
.76418 .44777 Mdot
.44561 .75269 Mdot
.37168 .42335 Mdot
.76454 .63743 Mdot
.50805 .82819 Mdot
.61875 .33275 Mdot
.52445 .7972 Mdot
.50969 .03357 Mdot
.6109 .29961 Mdot
.64323 .67137 Mdot
.39585 .43732 Mdot
.4418 .82985 Mdot
.48706 .19787 Mdot
.50107 .28323 Mdot
.65551 .61969 Mdot
.45797 .77209 Mdot
.55182 .48124 Mdot
.37608 .32947 Mdot
.60898 .77525 Mdot
.72119 .77472 Mdot
.51723 .62155 Mdot
.59366 .51699 Mdot
.36951 .39367 Mdot
.36956 .40745 Mdot
.39436 .7783 Mdot
.66775 .53078 Mdot
.66184 .20607 Mdot
.64535 .62351 Mdot
.58792 .82309 Mdot
.65819 .61088 Mdot
.54701 .56961 Mdot
.59023 .80776 Mdot
.75707 .41709 Mdot
.64322 .43127 Mdot
.45159 .68633 Mdot
.65827 .53159 Mdot
.63155 .37228 Mdot
.5236 .045 Mdot
.47792 .11293 Mdot
.46186 .12613 Mdot
.56549 .85852 Mdot
.48043 .96232 Mdot
.57981 .82862 Mdot
.43554 .71098 Mdot
.45905 .02012 Mdot
.55775 .08943 Mdot
.7314 .35912 Mdot
.53615 .38025 Mdot
.45209 .21712 Mdot
.43343 .80136 Mdot
.61282 .77435 Mdot
.37779 .28227 Mdot
.69524 .82853 Mdot
.54108 .30696 Mdot
.58739 .45871 Mdot
.62172 .14167 Mdot
.53837 .7725 Mdot
.41724 .3568 Mdot
.6692 .54895 Mdot
.46696 .31741 Mdot
.55742 .21975 Mdot
.47033 .95806 Mdot
.49593 .93985 Mdot
.37658 .30438 Mdot
.40756 .84561 Mdot
.4731 .95953 Mdot
.59265 .60475 Mdot
.54545 .88641 Mdot
.50946 .01891 Mdot
.57873 .81066 Mdot
.47468 .1281 Mdot
.62349 .35623 Mdot
.37886 .27558 Mdot
.64256 .67935 Mdot
.446 .23359 Mdot
.50548 .94169 Mdot
.54131 .87566 Mdot
.53474 .39396 Mdot
.4465 .23707 Mdot
.57587 .39519 Mdot
.53941 .29729 Mdot
.44953 .03082 Mdot
.76222 .4412 Mdot
.55697 .22037 Mdot
.49952 .67412 Mdot
.55436 .86752 Mdot
.52843 .91315 Mdot
.50488 .02078 Mdot
.52167 .69872 Mdot
.57681 .09998 Mdot
.42873 .57508 Mdot
.39738 .18286 Mdot
.75718 .42838 Mdot
.36822 .50624 Mdot
.50916 .02003 Mdot
.44254 .1506 Mdot
.64492 .18249 Mdot
.61612 .769 Mdot
.45348 .28659 Mdot
.69192 .26602 Mdot
.39612 .1605 Mdot
.58035 .09775 Mdot
.51328 .03562 Mdot
.58221 .41052 Mdot
.77338 .49812 Mdot
.42874 .80253 Mdot
.51451 .61592 Mdot
.51277 .62436 Mdot
.48572 .3179 Mdot
.56996 .37401 Mdot
.77424 .5208 Mdot
.62934 .37114 Mdot
.43476 .36292 Mdot
.5149 .15222 Mdot
.54899 .43422 Mdot
.42786 .58363 Mdot
.41275 .57154 Mdot
.66597 .47883 Mdot
.58873 .56607 Mdot
.64096 .68358 Mdot
.51427 .71108 Mdot
.62678 .36756 Mdot
.58806 .55985 Mdot
.52054 .03098 Mdot
.43716 .64614 Mdot
.57454 .24252 Mdot
.44635 .02135 Mdot
.59393 .50275 Mdot
.37428 .61454 Mdot
.64913 .65919 Mdot
.59308 .781 Mdot
.50797 .71963 Mdot
.549 .31007 Mdot
.6329 .34425 Mdot
.52572 .3554 Mdot
.56418 .09903 Mdot
.65879 .19681 Mdot
.54849 .58749 Mdot
.45734 .64432 Mdot
.76957 .55296 Mdot
.52293 .79016 Mdot
.4156 .3874 Mdot
.65942 .20564 Mdot
.45365 .22223 Mdot
.61632 .31038 Mdot
.6567 .57964 Mdot
.62736 .35772 Mdot
.69526 .26778 Mdot
.45411 .12856 Mdot
.63951 .69683 Mdot
.47566 .86192 Mdot
.36912 .4368 Mdot
.50175 .29238 Mdot
.44073 .92778 Mdot
.44953 .82757 Mdot
.47999 .86106 Mdot
.49443 .93953 Mdot
.5825 .10243 Mdot
.5168 .62202 Mdot
.4686 .26998 Mdot
.41771 .87564 Mdot
.59073 .59132 Mdot
.44579 .23988 Mdot
.398 .33883 Mdot
.50789 .53898 Mdot
.43079 .05281 Mdot
.38331 .73081 Mdot
.55241 .73461 Mdot
.41498 .3941 Mdot
.59038 .78821 Mdot
.47718 .71134 Mdot
.5264 .7906 Mdot
.6025 .29853 Mdot
.41335 .54309 Mdot
.51355 .1586 Mdot
.55263 .85674 Mdot
.57544 .65503 Mdot
.58655 .80922 Mdot
.40561 .28492 Mdot
.47352 .77914 Mdot
.54131 .74979 Mdot
.48358 .95748 Mdot
.52493 .69318 Mdot
.51335 .23234 Mdot
.36995 .54358 Mdot
.42031 .65294 Mdot
.53876 .18735 Mdot
.55101 .87449 Mdot
.47704 .71951 Mdot
.48183 .76663 Mdot
.40142 .81838 Mdot
.48853 .01434 Mdot
.48681 .19672 Mdot
.45386 .34498 Mdot
.56816 .38494 Mdot
.63051 .7319 Mdot
.58886 .45721 Mdot
.61242 .73913 Mdot
.75743 .43551 Mdot
.3855 .73563 Mdot
.53681 .06744 Mdot
.37501 .61755 Mdot
.44128 .58208 Mdot
.42056 .89832 Mdot
.69222 .27475 Mdot
.64173 .70283 Mdot
.55695 .09127 Mdot
.68079 .85451 Mdot
.55935 .71112 Mdot
.41204 .24012 Mdot
.63083 .36419 Mdot
.37108 .3938 Mdot
.58273 .11213 Mdot
.41923 .6306 Mdot
.36982 .49707 Mdot
.59042 .59786 Mdot
.52298 .55906 Mdot
.66466 .49702 Mdot
.42703 .78318 Mdot
.66544 .53808 Mdot
.61636 .13643 Mdot
.50464 .66502 Mdot
.58598 .26442 Mdot
.39495 .45234 Mdot
.49011 .02452 Mdot
.48763 .70664 Mdot
.51775 .03476 Mdot
.66147 .22211 Mdot
.73281 .3449 Mdot
.54455 .59663 Mdot
.46621 .11291 Mdot
.39289 .5271 Mdot
.4665 .94685 Mdot
.53996 .28382 Mdot
.52676 .54417 Mdot
.43649 .49514 Mdot
.44502 .83411 Mdot
.42713 .05443 Mdot
.40799 .83933 Mdot
.48837 .26422 Mdot
.66265 .47912 Mdot
.45374 .69362 Mdot
.48915 .32281 Mdot
.63565 .3531 Mdot
.47644 .11575 Mdot
.47428 .12787 Mdot
.59128 .60998 Mdot
.56833 .37104 Mdot
.77273 .59299 Mdot
.58184 .62883 Mdot
.64829 .45097 Mdot
.47886 .26312 Mdot
.41992 .08647 Mdot
.42632 .31611 Mdot
.57957 .82727 Mdot
.65335 .49724 Mdot
.5177 .32086 Mdot
.58796 .53693 Mdot
.7293 .35074 Mdot
.46886 .00785 Mdot
.439 .93969 Mdot
.57129 .82995 Mdot
.57403 .67356 Mdot
.41631 .75166 Mdot
.55424 .85836 Mdot
.52637 .7877 Mdot
.4723 .00767 Mdot
.7292 .32399 Mdot
.63801 .70195 Mdot
.52613 .04864 Mdot
.52481 .04213 Mdot
.5512 .06624 Mdot
.50448 .36065 Mdot
.53321 .77005 Mdot
.56506 .09899 Mdot
.42248 .06961 Mdot
.50782 .37167 Mdot
.62653 .7058 Mdot
.56823 .66821 Mdot
.50266 .13297 Mdot
.61531 .32405 Mdot
.37467 .36273 Mdot
.61702 .31347 Mdot
.41308 .87058 Mdot
.42368 .88706 Mdot
.65209 .56493 Mdot
.4597 .96262 Mdot
.65678 .53541 Mdot
.5898 .12518 Mdot
.7172 .78775 Mdot
.38286 .69656 Mdot
.55055 .20404 Mdot
.4748 .31767 Mdot
.63675 .18269 Mdot
.50445 .83106 Mdot
.43672 .51156 Mdot
.49914 .01321 Mdot
.66001 .60433 Mdot
.52848 .52156 Mdot
.47318 .77344 Mdot
.59634 .53825 Mdot
.42103 .34044 Mdot
.3743 .64904 Mdot
.66022 .63209 Mdot
.6943 .27465 Mdot
.50879 .02438 Mdot
.40606 .68179 Mdot
.76737 .60171 Mdot
.40873 .70589 Mdot
.53271 .28111 Mdot
.5325 .27515 Mdot
.48989 .64577 Mdot
.43192 .04652 Mdot
.48472 .01026 Mdot
.4261 .31549 Mdot
.52749 .3556 Mdot
.41128 .57349 Mdot
.5426 .63473 Mdot
.60698 .12857 Mdot
.5784 .38371 Mdot
.59202 .79045 Mdot
.54532 .43215 Mdot
.42259 .32083 Mdot
.47369 .71362 Mdot
.57405 .37307 Mdot
.39527 .51377 Mdot
.41241 .41406 Mdot
.4384 .34227 Mdot
.64372 .17545 Mdot
.45216 .02552 Mdot
.45151 .43341 Mdot
.39651 .38032 Mdot
.44039 .82679 Mdot
.5847 .27331 Mdot
.56273 .6859 Mdot
.44187 .24569 Mdot
.62921 .16822 Mdot
.7678 .44618 Mdot
.62731 .3436 Mdot
.73702 .73579 Mdot
.597 .26536 Mdot
.43712 .34318 Mdot
.41779 .10393 Mdot
.57424 .11042 Mdot
.41217 .45606 Mdot
.6522 .51382 Mdot
.77051 .60434 Mdot
.53302 .37571 Mdot
.52784 .49554 Mdot
.55077 .32676 Mdot
.60022 .77185 Mdot
.54764 .72895 Mdot
.77044 .49541 Mdot
.427 .5601 Mdot
.4196 .22811 Mdot
.39442 .56424 Mdot
.47421 .25773 Mdot
.49648 .68511 Mdot
.51082 .72769 Mdot
.40533 .11915 Mdot
.50525 .66714 Mdot
.54851 .88067 Mdot
.6374 .36711 Mdot
.58015 .2473 Mdot
.59073 .80497 Mdot
.61641 .72691 Mdot
.41889 .75417 Mdot
.75376 .38725 Mdot
.47083 .77387 Mdot
.42892 .05017 Mdot
.57429 .09129 Mdot
.41279 .50321 Mdot
.42844 .91863 Mdot
.56864 .67227 Mdot
.42389 .76473 Mdot
.58458 .81975 Mdot
.61629 .32358 Mdot
.48726 .20108 Mdot
.58858 .53354 Mdot
.39507 .53382 Mdot
.67479 .22023 Mdot
.48142 .12523 Mdot
.50887 .47904 Mdot
.45163 .14239 Mdot
.53532 .75687 Mdot
.49482 .32995 Mdot
.53432 .63833 Mdot
.42198 .21494 Mdot
.44065 .15282 Mdot
.51632 .61716 Mdot
.58946 .58932 Mdot
.38187 .26531 Mdot
.55553 .31855 Mdot
.59758 .28961 Mdot
.42928 .27801 Mdot
.50985 .24332 Mdot
.51788 .41338 Mdot
.7339 .75146 Mdot
.52172 .43959 Mdot
.64046 .37228 Mdot
.37165 .48025 Mdot
.5825 .80625 Mdot
.4548 .21557 Mdot
.56994 .84431 Mdot
.49792 .01542 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:;ooooo0ol00007ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`?o00001oooool00ol0003oooooooooo`2iooooo`00XOooool4o`0000;ooooo0_l0
0003ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o000000Coooooo`000?oooooooooo0_l0
0002ooooo`;o0000^oooool00:;ooooo00?oEEEEofIVI_l000000oooool2o`000003ooooool0003o
00000;_ooooo002Xooooo`;o000000?oooooo`000?l000000_ooool2o`000;Oooooo002Jooooo`;o
00000_ooool2o`0000Cooooo0_l00006ooooo`Go0000]oooool009[ooooo1_l00004ooooo`;o0000
0_ooool2o`0000;ooooo1Ol0002gooooo`00W?ooool2o`0000[ooooo0_l00002ooooo`04o`000?oo
oooo0000o`000;Sooooo002Kooooo`;o00003oooool00ol0003oooooooooo`03ooooo`;o0000]?oo
ool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00Go0000]?ooool00:cooooo00?o0000oooo
ooooool01?l0002eooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`03
o`000?oooooooooo00Gooooo0_l0002booooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
1?ooool3o`000;;ooooo002Dooooo`?o00005Oooool00ol0003oooooooooo`04ooooo`?o0000/_oo
ool009Cooooo0ol0000Eooooo`?o00001Oooool2o`000;;ooooo002Dooooo`?o00005Oooool00ol0
003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool02Oooool2o`0000;ooooo0_l0002Zooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo0_l0002Zooooo`00T_ooool2o`0001Sooooo00?o0000oooooooo
ool0^Oooool0097ooooo0_l0000Iooooo`?o0000^Oooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`2iooooo`00T?ooool3o`0001Wooooo00?o0000ooooooooool04?ooool2o`000:Oo
oooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0?ooooo`?o00000oooool2o`000:;ooooo
002/ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`?o0000X_ooool00:cooooo00?o0000
ooooooooool05?ooool2o`000003ooooool0003o00000:3ooooo002/ooooo`?o00004_ooool2o`00
00;ooooo0ol0002Pooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool04_ooool2o`0000;o
oooo1?l0002Oooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool06?ooool2o`0009oooooo
002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00X?ooool2o`0000;ooooo0_l00006
ooooo`03o`000?oooooooooo01Gooooo0_l000000ooooooo0000o`00002Oooooo`00X?ooool2o`00
00;ooooo0_l00006ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00ROooool00oo^k^ko
<S8bo`000002o`0000Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o0000omgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`03ogMgMonHV9Sooooo00;o
00001Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool01oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Joooo
o`;o0000WOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`;o000000?oooooo`00
0?l000000_ooool4o`0000;ooooo0_l000000ooooooo0000ooooo`0Kooooo`;o00001?ooool2o`00
09Oooooo0029ooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`000004ooooool0003o0000
ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool0
08Wooooo00Co410@oooooooooooooooo0_l0000=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool2o`000;[ooooo0029ooooo`05ogMgMonHV9So0000o`000?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool2o`0002Cooooo0_l0
002Dooooo`00ROooool01Oo^k^ko<S8bo`000?l0003ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`0Sooooo`;o0000U?ooool009cooooo0_l0000>ooooo`03o`000?oooooo
oooo02Gooooo0_l0002Booooo`00W?ooool2o`0000kooooo00?o0000ooooooooool08?ooool2o`00
00?ooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool009Sooooo
0ol0000Aooooo`?o000000?oooooo`000?l00000]_ooool009Sooooo0ol0000Aooooo`04o`000?oo
ooooooooooooo`;o0000]_ooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00ROoo
ool2o`00027ooooo00Co0000oooooooooooooooo0_l0002fooooo`00ROooool2o`00027ooooo00?o
0000ooooooooool08oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l00002
ooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool09oooool2o`00093ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000;?ooool2o`0008_ooooo002/ooooo`03o`000?oo
oooooooo02cooooo0_l0002;ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0:_ooool4
o`0008_ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Zooooo`Co0000Roooool00:co
oooo00?o0000ooooooooool02Oooool2o`000:kooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`09ooooo`;o0000[_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002R
ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002Roooo
o`;o00000oooool2o`0000?ooooo0ol0000aooooo`;o0000Q_ooool00:Oooooo0_l00003ooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00XOooool2o`0000Cooooo0_l00003ooooo`03o`00
0?oooooooooo00gooooo0_l000000ooooooo0000o`00000Oooooo`?o0000QOooool00:7ooooo0_l0
0004ooooo`;o00000oooool00ol0003oooooooooo`0@ooooo`;o00007oooool3o`0008Gooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00002Oooool2o`0000gooooo00?o0000oooo
ooooool0^Oooool008Kooooo0_l0000:ooooo`;o00002?ooool3o`0000gooooo00?o0000oooooooo
ool04?ooool2o`000:Oooooo0026ooooo`;o00005?ooool2o`0000kooooo00?o0000ooooooooool0
3oooool3o`000003ooooool0003o000001gooooo0_l00002ooooo`;o0000POooool008Oooooo0_l0
000Cooooo`;o00003_ooool3o`0000oooooo0_l00002ooooo`;o00007Oooool2o`0000;ooooo0_l0
0021ooooo`00Qoooool2o`0000Sooooo0_l00008ooooo`;o00003oooool00ol0003oooooooooo`2i
ooooo`00TOooool2o`0000Sooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o
00004?ooool01?l0003oooooooooooooool2o`000;Kooooo002Jooooo`;o00004?ooool01?l0003o
ooooooooooooool2o`000;Kooooo002?ooooo`;o00002Oooool2o`00013ooooo00?o0000oooooooo
ool0^Oooool008oooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7o
ooooooooo`03ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`02o`00
01?ooooo0_l0002Rooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooo
oooo8B4Qob4Q8@08ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_l0000Coooo
o`;o0000X_ooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00
00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0097o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Goooo
o`;o0000X?ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo
410@00cooooo0ol00007ooooo`03o`000?oooooooooo03cooooo0_l0001kooooo`00TOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo0ol00007ooooo`03o`000?oooooooooo03cooooo0_l0001k
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1_l000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo01Wooooo0_l000000ooooooo0000o`00002Kooooo`00QOooool2o`00
01[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`0Ioooo
o`;o000000Coooooo`000?l0003o00007Oooool3o`0007[ooooo0025ooooo`;o00006_ooool2o`00
00Wooooo00?o0000ooooooooool07Oooool2o`0001gooooo0ol0001jooooo`00XOooool2o`0000Wo
oooo00?o0000ooooooooool06Oooool2o`0009kooooo0024ooooo`;o00009_ooool3o`0000Oooooo
0_l0000@ooooo`;o00008Oooool3o`0007[ooooo0024ooooo`;o00003_ooool2o`0001Gooooo0_l0
0009ooooo`;o0000<oooool3o`0007[ooooo0023ooooo`?o00003_ooool2o`0001Gooooo0ol00008
ooooo`;o0000/?ooool008?ooooo0_l00007ooooo`;o00007_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`00002]ooooo`00S?ooool2o`0000kooooo0_l0000>ooooo`03o`000?oooooooooo00[o
oooo0_l0002]ooooo`00S?ooool2o`0000kooooo0_l0000>ooooo`;o00007_ooool2o`0009[ooooo
002/ooooo`;o00007_ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000B
ooooo`?o0000V?ooool00:cooooo0ol0000:ooooo`;o00004_ooool5o`0009Kooooo0023ooooo`;o
00003oooool2o`0001Kooooo00?o0000ooooooooool08Oooool2o`0009Kooooo0023ooooo`;o0000
3oooool2o`0001Kooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oo
oooooooo00[ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000U?ooool00:Cooooo0_l00006
ooooo`03o`000?oooooooooo00gooooo0_l0000Dooooo`;o0000U?ooool009?ooooo0_l0000?oooo
o`;o00001_ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool009?ooooo0_l0000<ooooo`Co
00000_ooool2o`0000?ooooo00?o0000ooooooooool03oooool2o`000:Sooooo002Booooo`;o0000
3Oooool4o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`;o0000
Z?ooool009;ooooo0_l0000Dooooo`;o00000_ooool3o`0000;ooooo0_l0000Oooooo`;o00008ooo
ool2o`0006oooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`;o00005?ooool2
o`0002?ooooo0_l0001_ooooo`00Poooool2o`0002Gooooo0ol0000?ooooo`;o0000Z_ooool008?o
oooo0_l0000Uooooo`?o00009_ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo02Cooooo
0_l0002Cooooo`00R_ooool2o`0000Gooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002:
ooooo`;o00001Oooool2o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l0000C
ooooo`;o0000T?ooool008;ooooo0_l0000Cooooo`;o00000oooool2o`0000kooooo00?o0000oooo
ooooool04_ooool2o`0001?ooooo0ol0000Oooooo`;o0000K_ooool008;ooooo0_l0000Hooooo`;o
00003_ooool00ol0003oooooooooo`0Xooooo`;o00007oooool2o`0006kooooo002/ooooo`?o0000
4oooool2o`0003?ooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`05ooooo`?o00002ooo
ool2o`0001Cooooo0_l0000Mooooo`;o0000Koooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo00Gooooo0ol0000Mooooo`Ko00007_ooool2o`0006kooooo002@ooooo`;o00006_ooool3o`00
02Gooooo1?l0000Pooooo`;o0000K_ooool008;ooooo0_l0000Booooo`;o00005?ooool3o`0002So
oooo0_l0002?ooooo`00P_ooool2o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q00Coooooo`000?l0003ooooo1Ol00004ooooo`03odA4A?l0003o000000;o00001Oooool00ol0
003oooooooooo`0Vooooo`Ko0000SOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo0_l00005ooooo`03o`000?oooooo
oooo01?ooooo0_l0000Aooooo`?o000000?oooooo`000?l00000SOooool0087ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo00Co0000ooooool0003o00004_ooool4o`00013ooooo0ol000000ooooooo0000o`00
002<ooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`Co00001_ooool2o`0000_ooooo0ol0000Aooooo`;o000000?o
ooooo`000?l00000S?ooool008Wooooo0_l00002ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01ooo
ool3o`000:oooooo0029ooooo`;o00000_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0
08Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000o`00
002Qooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00007ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool04oooool2o`000003oooo
ool0003o000003Sooooo0_l0001Wooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0;?oo
ool2o`0002;ooooo0_l0001Wooooo`00P?ooool3o`0000cooooo0_l0000Kooooo`03o`000?oooooo
oooo00Sooooo0_l0000<ooooo`;o00005?ooool2o`0008_ooooo0020ooooo`?o00003?ooool2o`00
01_ooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0002Qooooo`00[?ooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o0000:Oooool00ol0003ooooooooo
o`2iooooo`00POooool2o`0000Kooooo0_l0000Qooooo`03o`000?oooooooooo01Sooooo0_l0002O
ooooo`00ROooool2o`0000gooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo0_l0000Doooo
o`;o0000Woooool008oooooo0_l00007ooooo`;o00004_ooool00ol0003oooooooooo`02ooooo`;o
00005?ooool2o`0009oooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Hooooo`;o0000
=oooool2o`0006Kooooo002/ooooo`03o`000?oooooooooo057ooooo0_l0001Vooooo`00POooool2
o`0002Wooooo0ol0002iooooo`00POooool2o`0002Wooooo00?o0000ooooooooool06_ooool2o`00
03Gooooo0_l0001Vooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00004?ooool2o`0002?o
oooo0_l0001Vooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool03?ooool3o`0001gooooo
0_l0002;ooooo`00P?ooool2o`0000Oooooo0_l0000Aooooo`;o00003_ooool00ol0003ooooooooo
o`0<ooooo`?o00007oooool2o`0002;ooooo0_l0001Uooooo`00P?ooool2o`0000Oooooo0_l0000Q
ooooo`03o`000?oooooooooo00Cooooo0_l0000Xooooo`;o00008_ooool2o`0006Gooooo002/oooo
o`03o`000?oooooooooo00Cooooo0_l0001=ooooo`;o0000I?ooool00:cooooo00?o0000oooooooo
ool0;_ooool2o`0002?ooooo1?l0001Rooooo`00[?ooool00ol0003oooooooooo`0^ooooo`;o0000
9?ooool3o`0006;ooooo0029ooooo`;o00008Oooool3o`0001Wooooo0_l0000Cooooo`;o00009?oo
ool2o`0006?ooooo0029ooooo`;o00001?ooool2o`0001_ooooo00?o0000ooooooooool06Oooool2
o`0001?ooooo0_l00029ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool06Oooool3o`00
09gooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_l0003o0000
o`000?o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool0
00_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`02o`0000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000_ooooo0_l000000oooooooMgMgofIVIP04
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00;o00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400;ooooo`?o000000?oooooo`000?ooool00oooool00ol0003o
ooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001Oooool3o`00
0003oiRHV?l@413ooooo00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooo`000?l0000G
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
1?l0000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o0000
1Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`04o`000?oooooo0000o`00
00gooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l0
00005_ooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0aooooo`;o00008_ooool2
o`0005Oooooo0_l00002ooooo`;o00001Oooool008Sooooo0_l0000=ooooo`;o00004oooool00ol0
003oooooooooo`0aooooo`;o00008_ooool3o`0005Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd5ooooo`00POooool2o`0001Cooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo0_l0000W
ooooo`;o00000_ooool2o`00027ooooo0ol0001Fooooo`04omgMgOl0003o410@olc<c0Kooooo0007
oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol0
0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02?ooooo0_l0
00000ooooooo0000ooooo`0:ooooo`;o00006oooool00ol0003oooooooooo`0Looooo`;o00002Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo0020ooooo`;o0000:_ooool0
0ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool008Wo
oooo0_l0000<ooooo`;o00004oooool00ol0003oooooooooo`0=ooooo`;o00008?ooool2o`0008So
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0=ooooo`;o00003?ooool2o`0001;ooooo
0_l00003ooooo`;o0000Poooool00:cooooo00Co0000ooooool0003o00001Oooool2o`0001?ooooo
0_l0000Gooooo`;o00008Oooool2o`00063ooooo002/ooooo`Co00001Oooool2o`0000Gooooo0_l0
000Vooooo`;o00008?ooool2o`00063ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0=
ooooo`;o00009_ooool2o`0008;ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0aoooo
o`;o000000?oooooo`000?l00000Poooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo01[o
oooo0_l0000Eooooo`;o000000?oooooo`000?l00000Poooool008Wooooo0_l0000Qooooo`03o`00
0?oooooooooo01[ooooo0_l0000Dooooo`;o0000Qoooool008kooooo0_l0000Looooo`04o`000?oo
oooo0000o`0001Wooooo1?l0000Booooo`;o000000?oooooo`000?l00000Q?ooool0087ooooo0_l0
000;ooooo`?o00006oooool01?l0003oooooo`000?l0000Kooooo`?o00005?ooool2o`0008Cooooo
0021ooooo`;o00003?ooool2o`0001_ooooo00?o0000ooooooooool01Oooool2o`0001Kooooo0_l0
002Jooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000;Oooool2o`0008?ooooo002/oooo
o`?o0000=?ooool2o`00023ooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`1Fooooo`;o
0000HOooool00:cooooo00?o0000ooooooooool01?ooool2o`0002kooooo0_l00023ooooo`00Tooo
ool2o`0001Oooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l0000Hooooo`;o0000Pooo
ool008Wooooo0_l00008ooooo`;o00005oooool00ol0003oooooooooo`0Jooooo`;o00004oooool2
o`0008Sooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Jooooo`;o00004oooool2o`00
08Sooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o00004oooool2o`0008So
oooo002>ooooo`?o00006oooool00ol0003oooooooooo`0<ooooo`;o00008Oooool2o`0008Sooooo
002>ooooo`?o00000oooool2o`0001Kooooo0ol0002iooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool0<?ooool2o`0008Oooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Ioooo
o`;o00005Oooool2o`0008Oooooo002Dooooo`;o00000_ooool2o`0001;ooooo00?o0000oooooooo
ool06Oooool2o`0009kooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0=ooooo`;o0000
2oooool2o`0009gooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000;ooooo`?o0000W?oo
ool00:cooooo00?o0000ooooooooool06oooool2o`0001Cooooo0_l0000Tooooo`;o0000H?ooool0
0:cooooo00?o0000ooooooooool02oooool4o`0000_ooooo0_l0000Eooooo`;o00009?ooool2o`00
063ooooo002/ooooo`?o00002oooool4o`0000_ooooo0_l0000Fooooo`;o0000QOooool00:cooooo
00?o0000ooooooooool0<Oooool3o`00027ooooo0ol0001Qooooo`00[?ooool00ol0003ooooooooo
o`0Kooooo`;o00005?ooool2o`0002;ooooo0ol0001Qooooo`00[?ooool00ol0003oooooooooo`0K
ooooo`;o0000W?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01_ooooo0_l0000Doooo
o`;o0000Q_ooool008;ooooo0_l0000Xooooo`04o`000?ooooooooooooooo`;o0000;_ooool2o`00
08Kooooo0022ooooo`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooooooo0ol0
002eooooo`00P_ooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o0000;?ooool2o`0008Oooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol000001?oooooo0000
o`000?l0000Yooooo`;o000000?oooooo`000?l00000Qoooool008Wooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003o
ooooooooooooool2o`0002[ooooo0_l0002:ooooo`00ROooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l00009ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo01Sooooo0_l0000jooooo`;o0000Hoooool008Wooooo00Go410@oooo
oooooooooooooa0@4003ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool2o`0000_ooooo0_l0000Gooooo`;o00008Oooool2
o`0006?ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Kooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool2o`0002Cooooo0_l0000Qooooo`;o0000Hoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0
2?ooool3o`0004Wooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`08ooooo`?o0000[_oo
ool009Oooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
08;ooooo0_l0000Cooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`03o`000?oooooooooo
0;Wooooo0022ooooo`;o00003Oooool2o`0001Wooooo0ol0002iooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool05Oooool2o`000:;ooooo0022ooooo`;o0000:?ooool00ol0003ooooooooo
o`0Eooooo`;o0000X_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo02kooooo0_l00029
ooooo`00[?ooool3o`0000Kooooo0_l0000Vooooo`;o0000ROooool00:cooooo0ol00006ooooo`;o
0000/Oooool00:cooooo0ol0000Cooooo`;o0000Y?ooool00:_ooooo0_l0000Eooooo`Co00005Ooo
ool2o`0008_ooooo002[ooooo`Co00004oooool4o`0001;ooooo0_l000000ooooooo0000o`00002;
ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00008oooool2o`000003ooooool0003o0000
08_ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`04ooooo`;o00009_ooool2o`0008_o
oooo002=ooooo`;o00006oooool3o`0001?ooooo0_l0000Hooooo`;o0000S?ooool009cooooo0_l0
000<ooooo`?o00004oooool2o`000003ooooool0003o000001Gooooo0_l0002<ooooo`00W?ooool2
o`0000kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Looooo`;o00003_ooool00ol0
003oooooooooo`05ooooo`;o0000/_ooool008Gooooo0_l0000Eooooo`;o00003_ooool00ol0003o
ooooooooo`05ooooo`;o00009?ooool2o`0008cooooo0025ooooo`;o00009Oooool3o`0000Cooooo
0_l0000Uooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool01?ooool2o`0002Cooooo0ol0
002<ooooo`00SOooool2o`0001Sooooo0_l00003ooooo`03o`000?oooooooooo02Kooooo0_l00002
ooooo`?o0000S?ooool008gooooo0_l0000Hooooo`;o00000oooool00ol0003oooooooooo`0Voooo
o`;o0000TOooool009Kooooo0_l0000<ooooo`;o00001_ooool01?l0003oooooooooooooool2o`00
00gooooo0_l0002Wooooo`00U_ooool3o`0000[ooooo0ol00006ooooo`04o`000?oooooooooooooo
o`;o00003Oooool2o`000:Oooooo002Gooooo`;o00002_ooool3o`0000Kooooo00?o0000oooooooo
ool0^Oooool00:Cooooo0_l00006ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`Co0000
^?ooool00:cooooo00?o0000ooooooooool00_l0000Qooooo`;o0000U?ooool008Gooooo0_l0000U
ooooo`03o`000?oooooooooo00;o00002_ooool2o`0001Gooooo0_l0002Dooooo`00QOooool2o`00
02Gooooo00?o0000ooooooooool03?ooool4o`0001Sooooo0_l0002?ooooo`00Q_ooool2o`0002Co
oooo00?o0000ooooooooool03_ooool2o`0001Sooooo0_l0000Qooooo`;o0000K?ooool008Kooooo
0_l0000Tooooo`03o`000?oooooooooo02;ooooo0_l0000Wooooo`;o0000K?ooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool08_ooool2o`0009Gooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00
TOooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0002Fooooo`00T?ooool2o`0000?ooooo
00Co0000oooooooooooooooo0ol00009ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000:ooooo`;o
00005Oooool2o`0002Oooooo0_l0001]ooooo`00T?ooool3o`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04[o
oooo0_l0001]ooooo`00TOooool2o`0000;ooooo00?o410@ooooooooool01?ooool2o`0000Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo0_l0002_ooooo`00TOooool01Oo^k^ko0000o`000?lb<S;ok^k^00cooooo
1?l00006ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00002_ooool2o`0000Kooooo0_l0
0004ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00W_ooool2o`0000Kooooo0ol00003
ooooo`03o`000?oooooooooo00Kooooo1?l0000Iooooo`;o0000U?ooool009kooooo0_l00002oooo
o`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool02?ooool3o`0001?ooooo0_l00003oooo
o`;o0000U?ooool009kooooo0_l00002ooooo`?o00001oooool3o`0000Wooooo0_l0000Cooooo`;o
000000Coooooo`000?l0003o00008_ooool2o`00077ooooo0029ooooo`;o00006?ooool2o`0000Oo
oooo00?o0000ooooooooool08Oooool3o`0002;ooooo0_l0001aooooo`00ROooool2o`0000Sooooo
0_l0000>ooooo`;o00001oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool009?ooooo0_l0
000Gooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`;o0000U_ooool008Sooooo0_l0000R
ooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o00001Oooool2o`00027ooooo0_l0001c
ooooo`00R?ooool2o`0000_ooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo0ol0000Coooo
o`?o00009oooool2o`0007?ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`04ooooo`?o
00005?ooool2o`0009cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00U_oo
ool2o`0001Cooooo0ol00005ooooo`;o0000/_ooool009Cooooo1?l0000Dooooo`03o`000?oooooo
oooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Hooooo`;o000000?oooooo`00
0?l00000W?ooool00:cooooo00?o0000ooooooooool06?ooool5o`0009cooooo002/ooooo`03o`00
0?oooooooooo01Oooooo1Ol0002Mooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000X?oo
ool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0
003oooooooooo`0Hooooo`;o0000Woooool00:cooooo0ol0000Hooooo`Co0000WOooool009Sooooo
0_l000000ooooooo0000o`00000?ooooo`04o`000?oooooo0000o`0001Kooooo0_l000000ooooooo
0000o`00000Qooooo`;o0000N_ooool009Sooooo0_l000000ooooooo0000o`00000?ooooo`Co0000
4oooool2o`000004ooooool0003o0000o`0002?ooooo0_l0001jooooo`00V?ooool3o`00017ooooo
0ol0000Dooooo`;o00000_ooool2o`0009oooooo002Iooooo`Co00003oooool00ol0003ooooooooo
o`2iooooo`00SOooool2o`0000cooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002=oooo
o`;o00007Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0001gooooo00?o0000oooooooo
ool05?ooool2o`000:?ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Dooooo`;o0000
Xoooool00:Oooooo0_l00003ooooo`?o0000^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooo
oooo03Sooooo0_l0001oooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`00
02Cooooo0_l0001oooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool03_ooool2o`0000;o
oooo0_l0002Uooooo`00Xoooool4o`0000Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wooooo
00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000;ooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wo
oooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000[ooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00ROooool01Ol0
003ooooooooooooooooo000000;ooooo0_l0000:ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000[ooooo1Ol0002Zooooo`00ROooool01Ol0003ooooooooooooooooo
000000;ooooo0_l0000:ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00002Zooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool3o`0000Gooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0<ooooo`;o0000
Zoooool0097ooooo0ol0000Hooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Oooool0097o
oooo0_l0000Iooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo
002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo1Ol0002gooooo`00V?ooool2o`00
01;ooooo00?o0000ooooooooool00_l0002gooooo`00V?ooool2o`0001;ooooo00?o0000oooooooo
ool00_l0002gooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Uoooool2o`00017ooooo0ol0002kooooo`00Uoooool2o`00017ooooo1Ol0002ioooo
o`00Y_ooool2o`0000Cooooo0ol0002iooooo`00XOooool2o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo0;Wooooo002Qooooo`;o00002Oooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Rooooo`;o00000_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool00:;o
oooo0ol000000ooooooo0000o`000004ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o0000
0oooool4o`0000Gooooo00?o0000ooooooooool0^Oooool009kooooo0_l00005ooooo`;o00001Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59604 .27699 Mdot
.64532 .39508 Mdot
.49944 .5811 Mdot
.48 .24811 Mdot
.47854 .18331 Mdot
.45589 .12532 Mdot
.51728 .51796 Mdot
.54852 .07407 Mdot
.4909 .03271 Mdot
.55766 .58354 Mdot
.51427 .73351 Mdot
.61859 .16665 Mdot
.66682 .55323 Mdot
.55155 .63242 Mdot
.66247 .25091 Mdot
.54004 .36809 Mdot
.50177 .8328 Mdot
.66673 .5607 Mdot
.40945 .57961 Mdot
.55774 .86427 Mdot
.65235 .62043 Mdot
.65837 .50006 Mdot
.65172 .57381 Mdot
.66172 .59349 Mdot
.69587 .31082 Mdot
.59158 .40426 Mdot
.4585 .77663 Mdot
.40823 .52885 Mdot
.52152 .91149 Mdot
.65054 .43548 Mdot
.62531 .70025 Mdot
.46525 .02683 Mdot
.55259 .08735 Mdot
.41938 .75748 Mdot
.39963 .65174 Mdot
.53144 .88385 Mdot
.37286 .55401 Mdot
.41635 .63377 Mdot
.44304 .92452 Mdot
.61535 .1563 Mdot
.68163 .26701 Mdot
.41151 .72908 Mdot
.4064 .2834 Mdot
.59013 .25433 Mdot
.55658 .20093 Mdot
.54097 .27013 Mdot
.53391 .67795 Mdot
.39896 .17141 Mdot
.60247 .56859 Mdot
.48864 .94206 Mdot
.40429 .15048 Mdot
.43276 .9138 Mdot
.63006 .88969 Mdot
.39669 .37851 Mdot
.39104 .4887 Mdot
.52719 .06529 Mdot
.56635 .09641 Mdot
.5198 .80646 Mdot
.37662 .34293 Mdot
.5446 .18307 Mdot
.55818 .31132 Mdot
.74829 .45762 Mdot
.42166 .87757 Mdot
.4675 .7365 Mdot
.59164 .14601 Mdot
.48608 .02464 Mdot
.55604 .58599 Mdot
.54108 .38251 Mdot
.42525 .69747 Mdot
.65215 .63615 Mdot
.53503 .78907 Mdot
.49213 .67075 Mdot
.54826 .62401 Mdot
.56151 .51967 Mdot
.42145 .87689 Mdot
.44982 .59379 Mdot
.62932 .89059 Mdot
.58727 .42336 Mdot
.4557 .94554 Mdot
.58406 .62725 Mdot
.58973 .78576 Mdot
.64982 .4406 Mdot
.47077 .25154 Mdot
.41216 .73548 Mdot
.51902 .04551 Mdot
.53195 .33249 Mdot
.48515 .18521 Mdot
.53714 .27483 Mdot
.54923 .75369 Mdot
.54449 .39827 Mdot
.7011 .32701 Mdot
.71678 .72379 Mdot
.4319 .65249 Mdot
.52882 .24968 Mdot
.43707 .67341 Mdot
.73454 .67994 Mdot
.55274 .62605 Mdot
.4362 .06495 Mdot
.62365 .89971 Mdot
.56245 .73089 Mdot
.61196 .31357 Mdot
.57593 .69195 Mdot
.63099 .18974 Mdot
.60729 .29079 Mdot
.62753 .71229 Mdot
.41209 .72381 Mdot
.50547 .83596 Mdot
.40638 .49553 Mdot
.43161 .65134 Mdot
.646 .65438 Mdot
.55799 .59666 Mdot
.46013 .25454 Mdot
.46695 .02724 Mdot
.56707 .84303 Mdot
.47366 .28913 Mdot
.5742 .35947 Mdot
.46876 .01722 Mdot
.46018 .02404 Mdot
.37423 .43352 Mdot
.66474 .5629 Mdot
.73886 .40314 Mdot
.64181 .63709 Mdot
.52649 .90721 Mdot
.64886 .64705 Mdot
.50271 .27833 Mdot
.54358 .87599 Mdot
.74327 .64375 Mdot
.64072 .41503 Mdot
.52953 .43957 Mdot
.6575 .54209 Mdot
.62708 .35585 Mdot
.64527 .20785 Mdot
.4462 .13475 Mdot
.42181 .20565 Mdot
.49484 .9457 Mdot
.39519 .79486 Mdot
.52535 .90306 Mdot
.54792 .6234 Mdot
.58806 .13283 Mdot
.66066 .24375 Mdot
.74742 .56193 Mdot
.42178 .4204 Mdot
.41987 .67241 Mdot
.50481 .82875 Mdot
.56601 .8494 Mdot
.49985 .02666 Mdot
.43327 .26331 Mdot
.54376 .28707 Mdot
.72526 .34233 Mdot
.58479 .66685 Mdot
.46499 .79194 Mdot
.66392 .58761 Mdot
.50162 .6432 Mdot
.52987 .17428 Mdot
.39459 .78447 Mdot
.42739 .89611 Mdot
.48629 .02101 Mdot
.37243 .49746 Mdot
.39494 .78819 Mdot
.60297 .47453 Mdot
.4689 .95444 Mdot
.65203 .20188 Mdot
.54744 .85748 Mdot
.42536 .20162 Mdot
.61556 .33088 Mdot
.49935 .02737 Mdot
.62408 .72504 Mdot
.42843 .71076 Mdot
.41592 .8785 Mdot
.49026 .9362 Mdot
.42231 .44568 Mdot
.43226 .721 Mdot
.50673 .21693 Mdot
.4329 .26012 Mdot
.57652 .12042 Mdot
.73641 .67107 Mdot
.52819 .17292 Mdot
.48968 .30497 Mdot
.49101 .94363 Mdot
.44065 .93362 Mdot
.63925 .19132 Mdot
.5575 .43952 Mdot
.68619 .275 Mdot
.5347 .53553 Mdot
.49875 .04197 Mdot
.7392 .65199 Mdot
.43372 .05954 Mdot
.64973 .20033 Mdot
.40772 .27062 Mdot
.73005 .37477 Mdot
.56954 .84487 Mdot
.48532 .72951 Mdot
.74508 .46009 Mdot
.53685 .0637 Mdot
.69512 .28312 Mdot
.63598 .19512 Mdot
.52374 .24216 Mdot
.71473 .74218 Mdot
.48547 .86349 Mdot
.46168 .30792 Mdot
.46564 .30254 Mdot
.4838 .68414 Mdot
.49143 .19515 Mdot
.70326 .76723 Mdot
.62347 .35009 Mdot
.5121 .66302 Mdot
.48116 .11581 Mdot
.44114 .29293 Mdot
.53649 .54956 Mdot
.51852 .72715 Mdot
.66638 .50576 Mdot
.58427 .40606 Mdot
.62217 .72913 Mdot
.55568 .44397 Mdot
.61955 .3426 Mdot
.58075 .39563 Mdot
.65826 .21319 Mdot
.53747 .50371 Mdot
.55618 .20905 Mdot
.59625 .13017 Mdot
.56996 .34517 Mdot
.39654 .19519 Mdot
.63273 .7043 Mdot
.56922 .82066 Mdot
.55302 .44355 Mdot
.45 .20833 Mdot
.6346 .34981 Mdot
.42083 .52107 Mdot
.66277 .25062 Mdot
.74043 .3986 Mdot
.52051 .31122 Mdot
.48287 .3393 Mdot
.68524 .79517 Mdot
.57836 .6696 Mdot
.47925 .7879 Mdot
.73578 .39856 Mdot
.42528 .69191 Mdot
.61404 .30446 Mdot
.65327 .59886 Mdot
.62221 .34066 Mdot
.74808 .46666 Mdot
.42032 .20521 Mdot
.61558 .75035 Mdot
.53534 .78836 Mdot
.44865 .03707 Mdot
.43538 .6611 Mdot
.38317 .69454 Mdot
.52733 .78363 Mdot
.53893 .78183 Mdot
.42883 .89763 Mdot
.69422 .28473 Mdot
.47307 .28997 Mdot
.47162 .7313 Mdot
.37502 .58256 Mdot
.5964 .44838 Mdot
.43404 .72622 Mdot
.39012 .52138 Mdot
.44596 .57105 Mdot
.57172 .10649 Mdot
.38541 .25328 Mdot
.59424 .61494 Mdot
.48082 .7874 Mdot
.56386 .83103 Mdot
.51579 .37167 Mdot
.57839 .68017 Mdot
.59044 .27056 Mdot
.51922 .71481 Mdot
.46952 .12317 Mdot
.50859 .91389 Mdot
.5993 .51323 Mdot
.54426 .87136 Mdot
.39076 .47482 Mdot
.56191 .55963 Mdot
.58935 .6198 Mdot
.40266 .82574 Mdot
.55836 .43762 Mdot
.41395 .34854 Mdot
.41749 .10444 Mdot
.53245 .69558 Mdot
.50924 .14325 Mdot
.48308 .94994 Mdot
.52433 .39304 Mdot
.55931 .51454 Mdot
.37291 .46543 Mdot
.61637 .16734 Mdot
.40619 .49203 Mdot
.51183 .59294 Mdot
.4856 .19726 Mdot
.59508 .79867 Mdot
.54669 .29024 Mdot
.59491 .77331 Mdot
.73669 .65779 Mdot
.38047 .30765 Mdot
.6438 .21695 Mdot
.39369 .21442 Mdot
.50697 .39992 Mdot
.37064 .51042 Mdot
.74149 .46168 Mdot
.61184 .76651 Mdot
.65691 .24097 Mdot
.39078 .92083 Mdot
.59724 .58176 Mdot
.3932 .386 Mdot
.62711 .35114 Mdot
.4565 .03053 Mdot
.68478 .28001 Mdot
.53251 .68509 Mdot
.42434 .08777 Mdot
.5982 .45754 Mdot
.44066 .37597 Mdot
.66427 .51995 Mdot
.49626 .8423 Mdot
.66252 .56611 Mdot
.72102 .33408 Mdot
.49129 .30236 Mdot
.56995 .23255 Mdot
.41253 .72887 Mdot
.60279 .16036 Mdot
.51201 .35377 Mdot
.64697 .20465 Mdot
.72884 .40077 Mdot
.75346 .55833 Mdot
.51874 .31253 Mdot
.43768 .14854 Mdot
.41602 .75694 Mdot
.40546 .82311 Mdot
.43904 .2292 Mdot
.43944 .37383 Mdot
.5156 .46016 Mdot
.51054 .82644 Mdot
.57834 .10819 Mdot
.37421 .54186 Mdot
.44349 .69826 Mdot
.66308 .49843 Mdot
.53024 .43844 Mdot
.48035 .68661 Mdot
.6373 .35883 Mdot
.44097 .14712 Mdot
.42528 .20157 Mdot
.60293 .47908 Mdot
.48715 .19258 Mdot
.65777 .85159 Mdot
.59819 .48411 Mdot
.64725 .44129 Mdot
.45671 .72298 Mdot
.5474 .08554 Mdot
.46385 .78057 Mdot
.52727 .89925 Mdot
.65332 .49388 Mdot
.42083 .5599 Mdot
.57135 .36595 Mdot
.74864 .55417 Mdot
.60842 .15065 Mdot
.37229 .59086 Mdot
.52987 .88767 Mdot
.60214 .54482 Mdot
.47261 .86346 Mdot
.50492 .92159 Mdot
.57934 .67263 Mdot
.61012 .15372 Mdot
.75827 .54363 Mdot
.61292 .75665 Mdot
.64574 .20997 Mdot
.65181 .21252 Mdot
.67492 .24618 Mdot
.46116 .68047 Mdot
.58459 .64677 Mdot
.66457 .25241 Mdot
.5667 .0985 Mdot
.45632 .67264 Mdot
.61208 .73834 Mdot
.5962 .51807 Mdot
.47065 .11336 Mdot
.60778 .3038 Mdot
.45082 .04343 Mdot
.61436 .30647 Mdot
.37156 .50116 Mdot
.37974 .64486 Mdot
.65161 .56852 Mdot
.37908 .68626 Mdot
.65618 .54302 Mdot
.68508 .28737 Mdot
.38007 .33205 Mdot
.52522 .16397 Mdot
.4966 .65465 Mdot
.71753 .35891 Mdot
.56151 .72922 Mdot
.51421 .44779 Mdot
.63804 .18683 Mdot
.65089 .64141 Mdot
.43465 .40576 Mdot
.56033 .5448 Mdot
.58609 .39174 Mdot
.46659 .78686 Mdot
.40196 .15602 Mdot
.64369 .68433 Mdot
.74391 .46568 Mdot
.64248 .19584 Mdot
.46194 .85311 Mdot
.65264 .85367 Mdot
.46374 .85734 Mdot
.42581 .28851 Mdot
.42741 .27584 Mdot
.4487 .39114 Mdot
.57954 .11177 Mdot
.61739 .16557 Mdot
.46263 .78074 Mdot
.41985 .5004 Mdot
.51357 .74605 Mdot
.54492 .37417 Mdot
.7123 .31932 Mdot
.51371 .22033 Mdot
.5609 .83982 Mdot
.4345 .3279 Mdot
.45594 .78244 Mdot
.52002 .38533 Mdot
.50287 .20455 Mdot
.42739 .78631 Mdot
.48144 .79137 Mdot
.50719 .67883 Mdot
.73319 .37407 Mdot
.58306 .12582 Mdot
.49782 .42896 Mdot
.3964 .61834 Mdot
.50416 .83778 Mdot
.56219 .22815 Mdot
.59585 .5379 Mdot
.43402 .7303 Mdot
.71619 .34804 Mdot
.73635 .68532 Mdot
.62503 .33648 Mdot
.59393 .25891 Mdot
.50625 .68583 Mdot
.52661 .07196 Mdot
.67036 .26411 Mdot
.49857 .76413 Mdot
.65232 .50816 Mdot
.64966 .86296 Mdot
.42073 .45473 Mdot
.43087 .46234 Mdot
.44901 .21757 Mdot
.57415 .81618 Mdot
.59217 .58879 Mdot
.71565 .73412 Mdot
.53458 .55116 Mdot
.39341 .45355 Mdot
.42487 .7894 Mdot
.45693 .72843 Mdot
.49701 .31613 Mdot
.56196 .4735 Mdot
.55271 .07939 Mdot
.49548 .30687 Mdot
.47542 .95378 Mdot
.63756 .36775 Mdot
.56648 .22157 Mdot
.54643 .87056 Mdot
.60174 .75721 Mdot
.4836 .85508 Mdot
.7524 .6186 Mdot
.56018 .55165 Mdot
.58075 .11068 Mdot
.69074 .27508 Mdot
.51266 .72856 Mdot
.37094 .54509 Mdot
.59757 .52719 Mdot
.49815 .83406 Mdot
.53312 .89204 Mdot
.60981 .30607 Mdot
.40708 .50933 Mdot
.57111 .36366 Mdot
.42823 .79185 Mdot
.74764 .42647 Mdot
.43533 .16863 Mdot
.45837 .62758 Mdot
.40929 .27094 Mdot
.58685 .62022 Mdot
.47232 .69139 Mdot
.53176 .3527 Mdot
.39413 .41831 Mdot
.40746 .27001 Mdot
.46702 .29684 Mdot
.59404 .44176 Mdot
.48965 .02646 Mdot
.46401 .18609 Mdot
.58358 .25862 Mdot
.43804 .75253 Mdot
.41026 .43365 Mdot
.4413 .62315 Mdot
.43584 .58486 Mdot
.64164 .37696 Mdot
.41649 .1185 Mdot
.54997 .8554 Mdot
.42033 .67109 Mdot
.51191 .92021 Mdot
.63204 .18253 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00
XOooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00001ooo
ool2o`0000?ooooo0ol0002iooooo`00W_ooool5o`0000Cooooo0ol000001?oooooo0000o`000?l0
002jooooo`00WOooool2o`000004ooooool0003o0000o`0000Gooooo0_l000001?oooooo0000o`00
0?l0002jooooo`00WOooool2o`0000[ooooo0_l000000ooooooo0000ooooo`2jooooo`00Voooool2
o`0000cooooo0_l000000ooooooo0000ooooo`2jooooo`00Voooool2o`0000oooooo00?o0000oooo
ooooool0^Oooool009_ooooo0_l0000>ooooo`;o0000^oooool009_ooooo0_l0000>ooooo`;o0000
1Oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool3o`0001?ooooo00?o
0000ooooooooool01_ooool2o`000003ooooool0003o00000:kooooo002Gooooo`;o00004oooool0
0ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l00000[_ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo0_l0002Zooooo`00
[?ooool3o`0000Gooooo0_l00006ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool03_oo
ool2o`000:Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0
003oooooooooo`0<ooooo`;o0000Zoooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00co
oooo1?l0002Yooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03_ooool2o`000:Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01;ooooo0ol0002T
ooooo`00[?ooool3o`0001;ooooo0ol0002Tooooo`00T?ooool2o`0001[ooooo00?o0000oooooooo
ool0^Oooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`Go0000X?ooool00:;ooooo0_l00008ooooo`03o`000?oooooo
oooo01Kooooo0ol0002Pooooo`00X_ooool2o`000003ooooool0003o000000Gooooo00?o0000oooo
ooooool05oooool2o`000:3ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`00
0003oooooolQ8B7o8B4Q00Kooooo00?o0000onk^k_ooool01?ooool00om4A4Co0000o`000002o`00
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`;o000000?oooooob4Q8OlQ8B401_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0021ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00gooooo00CoZJVYoeEEEOl0003o00000oooool2o`0000;ooooo00?o0000
ooooooooool00oooool3o`0001Kooooo1?l0002Oooooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qo`000?l000000oooool2o`000003oooooomgMgOo<S8b00Gooooo00?o0000
ooooooooool06?ooool2o`0009oooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Looooo`;o0000Voooool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`;o000000?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo1?l0
002Kooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@o`000?l0003ooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool2o`0009gooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000
ooooooooool00_l0000Iooooo`;o0000W?ooool009Oooooo0ol0000Booooo`03o`000?oooooooooo
01_ooooo0_l0002Looooo`00S?ooool2o`0000Wooooo0ol0000Booooo`?o00008?ooool2o`0009Oo
oooo002;ooooo`?o00007_ooool00ol0003oooooooooo`0Pooooo`?o0000U_ooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo027ooooo1?l0002Dooooo`00[?ooool00ol0003oooooooooo`0N
ooooo`;o00000oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Goooo
o`;o0000VOooool00:cooooo00?o0000ooooooooool01Oooool2o`0001cooooo0ol0002Cooooo`00
U_ooool2o`0001Cooooo00?o0000ooooooooool08oooool3o`0009?ooooo002:ooooo`;o00002_oo
ool2o`0001Cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002:ooooo`;o00008?ooool3
o`0000Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Ko
oooo00?o0000ooooooooool02oooool2o`0001_ooooo0_l0002?ooooo`00X?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00_ooooo0_l0000Kooooo`;o0000
Soooool00:3ooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`0Zooooo`;o0000SOoo
ool00:cooooo00?o0000ooooooooool0:?ooool5o`0008cooooo0029ooooo`;o00007?ooool4o`00
0003ooooool0003ooooo02Wooooo1Ol0002<ooooo`00ROooool2o`0001cooooo1?l000000ooooooo
0000ooooo`0Zooooo`;o000000?oooooo`000?l00000Roooool009?ooooo0_l0000Booooo`;o0000
0oooool3o`0000oooooo0_l0000Kooooo`Co0000ROooool009?ooooo0_l0000Gooooo`?o00003ooo
ool2o`0001cooooo1?l00028ooooo`00TOooool3o`0001Sooooo0ol0000]ooooo`Co0000R?ooool0
097ooooo0ol00007ooooo`;o00003oooool00ol0003oooooooooo`0?ooooo`;o00007?ooool2o`00
08[ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0?ooooo`;o00007?ooool6o`0008Ko
oooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0_ooooo`Co0000Q_ooool008Sooooo0_l0
000Aooooo`;o00003oooool01?l0003oooooo`000?l0000[ooooo`;o0000Roooool009_ooooo0_l0
000?ooooo`03o`000?oooooo000000?o00004?ooool2o`0001Oooooo0_l0002;ooooo`00[?ooool3
o`000003ooooool0003o0000013ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0Aoooo
o`;o0000Y_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`03o`000?oo
oooooooo01Cooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool01?ooool2o`0002[ooooo1?l00025ooooo`00TOooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool01?ooool2o`0002cooooo0_l00002ooooo`;o0000POooool008Wooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003oooool2o`0000Gooooo00?o0000ooooooooool01_oo
ool2o`0002kooooo0_l00021ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo0_l0
00000ooooooo0000o`000005ooooo`?o00001_ooool2o`0002[ooooo0ol00024ooooo`00Q_ooool2
o`0000Wooooo00Go0000ooooooooooooooooo`000008ooooo`;o00000_ooool3o`000003oc8b<_o<
c<cooooo00Cooooo00?o0000ooooooooool06_ooool2o`0001Kooooo0ol00024ooooo`00Q_ooool2
o`0000Wooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00000_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Sooooo1_l0002Kooooo`00TOooool01?mgMgOoV9RHoooooonH
V9P2o`0000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`;o00000_oo
ool2o`0009_ooooo002Aooooo`04onk^k_lb<S;o0000oc8b<P?o00002_ooool4o`0000Kooooo00?o
0000ooooooooool0=Oooool2o`0008;ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0e
ooooo`;o00000_ooool2o`0007kooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`0:oooo
o`;o00003_ooool2o`0001gooooo0_l0001nooooo`00SOooool3o`0001cooooo00?o0000oooooooo
ool02_ooool2o`0000kooooo0_l0002Mooooo`00U?ooool2o`0001Kooooo0ol00009ooooo`;o0000
4Oooool2o`0001cooooo1?l0001kooooo`00U?ooool2o`0001Kooooo0_l0000:ooooo`;o00004Ooo
ool2o`0001cooooo1?l0001kooooo`00SOooool2o`0001gooooo0_l0000kooooo`;o000000?ooooo
o`000?l00000N_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo03gooooo0_l0001joooo
o`00Toooool2o`0000kooooo0_l00007ooooo`03o`000?oooooooooo00_ooooo0_l0000]ooooo`;o
000000?oooooo`000?l00000N_ooool009?ooooo0_l0000>ooooo`;o00001oooool00ol0003ooooo
ooooo`0;ooooo`?o00004_ooool2o`0001Sooooo0_l0001mooooo`00V?ooool2o`0000Wooooo0_l0
0007ooooo`03o`000?oooooooooo00cooooo0_l0000Booooo`;o0000Uoooool009Sooooo0_l00007
ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo0ol0002ioooo
o`00X?ooool2o`0000Oooooo0_l000000ooooooo0000ooooo`0Qooooo`Co0000UOooool008Cooooo
0_l0000Jooooo`;o00001_ooool5o`0002;ooooo1?l0002Eooooo`00Q?ooool2o`0001Wooooo0_l0
0007ooooo`Go00008oooool3o`0009Gooooo002Oooooo`;o00002oooool00ol0003oooooooooo`03
ooooo`;o00002oooool2o`00013ooooo0_l0000Iooooo`;o0000N_ooool00:_ooooo0_l00005oooo
o`;o00002oooool2o`00013ooooo0_l0000Iooooo`;o0000N_ooool00:_ooooo0_l00015ooooo`;o
0000M?ooool00:cooooo00?o0000ooooooooool0@oooool2o`0007Cooooo002/ooooo`?o0000^Ooo
ool009Kooooo0_l0000Dooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool08oooool2o`0001[ooooo0_l0001hooooo`00Q?ooool2o`0002Ko
oooo00?o0000ooooooooool01oooool2o`0001[ooooo0_l0000Qooooo`;o0000LOooool008Cooooo
0_l0000Vooooo`03o`000?oooooooooo00Oooooo0_l0000Mooooo`;o00007_ooool2o`00077ooooo
002Vooooo`;o00001?ooool00ol0003oooooooooo`0Uooooo`?o0000TOooool008?ooooo0_l0000Q
ooooo`;o00001?ooool00ol0003oooooooooo`0Tooooo`?o00008?ooool2o`00073ooooo0023oooo
o`;o00009oooool00ol0003oooooooooo`0Dooooo`;o00003_ooool2o`00027ooooo0_l0001`oooo
o`00Soooool2o`0001_ooooo00?o0000ooooooooool05?ooool2o`0001?ooooo0_l0000Iooooo`;o
0000Loooool008oooooo0_l0000Kooooo`?o00001oooool2o`0001cooooo1_l0000Iooooo`;o0000
Loooool00:cooooo00Co0000oooooooooooooooo0_l00004ooooo`;o00007?ooool4o`00093ooooo
002/ooooo`04o`000?ooooooooooooooo`;o00009?ooool2o`000003ooooool0003o000001Sooooo
0_l0001cooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00004oooool2o`0001Sooooo0_l0
001cooooo`00[?ooool00ol0003oooooooooo`0Dooooo`?o0000X_ooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`;o00005?ooool2o`0008gooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_ooool2o`0000Sooooo
0_l0000Dooooo`;o0000SOooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2_ooool2o`000003oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`;o00001oooool2o`0003gooooo0_l0001]ooooo`00ROooool01Ol0003ooooooooo
oooooooo000000[ooooo0_l000001?ooooooV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol00002ooooo`;o00001oooool2o`0001kooooo0_l0000Looooo`?o0000KOooool008Wooooo
0_l00002ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02_ooooo0_l0000Looooo`;o
0000K_ooool008Wooooo0_l00002ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00R?oo
ool2o`000004oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0002]ooooo`00
R?ooool2o`000004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool009_ooooo0_l0000?ooooo`03
o`000?oooooooooo01Wooooo0_l0002Nooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0
1Oooool2o`0001;ooooo0_l0000Booooo`;o0000R_ooool00:cooooo00?o0000ooooooooool01Ooo
ool2o`0000Cooooo0_l0000:ooooo`;o00005?ooool2o`0008[ooooo002/ooooo`Co00002_ooool2
o`0000[ooooo0_l0000_ooooo`Ko0000Joooool00:cooooo00Co0000ooooool0003o00006_ooool2
o`0002_ooooo1_l0001[ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool06?ooool2o`00
0003ooooool0003o000002kooooo0_l0001/ooooo`00U_ooool2o`0001Cooooo00?o0000oooooooo
ool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo02_ooooo0_l0002<ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0:oooool2
o`0008cooooo0029ooooo`;o00001oooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;o
oooo0_l0000Hooooo`?o00006Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Wooooo
0_l0000cooooo`;o0000JOooool00:_ooooo0_l0001@ooooo`;o0000JOooool008;ooooo0_l0000:
ooooo`;o00006oooool2o`000;_ooooo0022ooooo`;o00002_ooool2o`0001cooooo00?o0000oooo
ooooool04?ooool2o`0001cooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`06ooooo`?o
00001oooool2o`0001cooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`06ooooo`?o0000
1Oooool4o`0000[ooooo0_l0000?ooooo`?o0000ROooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo00kooooo0ol0000;ooooo`;o00003oooool2o`0008[ooooo002Booooo`;o00006?ooool0
1?l0003oooooooooooooool2o`0000cooooo0_l0000;ooooo`;o0000Voooool00:cooooo0ol00000
0ooooooo0000o`00000Iooooo`;o0000Voooool008Sooooo0_l00007ooooo`;o00006Oooool00ol0
003oooooooooo`2iooooo`00R?ooool2o`0000Oooooo0_l0000Iooooo`03o`000?oooooooooo01go
oooo0_l0000`ooooo`;o0000J?ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00;o
oooo0_l0000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00003ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool5o`0000Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo0000o`00000Eooooo`03o`000?oooooooooo00;ooooo
0_l0000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`?o00000_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o
0000ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001Oooool00onHV9So
8B4Qonk^kP09ooooo`;o00005Oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooo
oooooooooooooa0@4003ooooo`?o00002_ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool0
00001Oooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol00009
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003ooooooooo
o`0Aooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool2o`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o00004Oooool2o`00
00Gooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l000000oooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;ooooo0_l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool06?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo0_l00007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?oo
ool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008Sooooo0_l0000Rooooo`03o`000?oooooo
oooo01gooooo0_l0002Jooooo`00R?ooool2o`0000?ooooo0_l0000Mooooo`03o`000?oooooooooo
0:kooooo0_l00002ooooo`;o00001Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo02oo
oooo0_l0001mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0087ooooo0_l0000:oooo
o`;o00007Oooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l00000Noooool01?oM
gMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6
ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool3o`0000Oooooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
ool0003o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4Q
ogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`;o00007?ooool00ol0003oooooooooo`09ooooo`;o00006oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005
ooooo`00POooool2o`0000[ooooo0_l0000Mooooo`03o`000?oooooooooo02oooooo0_l00002oooo
o`;o0000Q?ooool0087ooooo0_l0000:ooooo`;o00007Oooool00ol0003oooooooooo`0Mooooo`;o
00004?ooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000;ooooo`;o0000
V_ooool00:cooooo00?o0000ooooooooool00_ooool2o`0000cooooo0ol00009ooooo`;o0000Vooo
ool008Oooooo0_l00008ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o00003Oooool2
o`0000Wooooo0_l0000Eooooo`;o0000Q?ooool008Oooooo0_l00008ooooo`;o00006Oooool3o`00
03?ooooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008gooooo
0_l0000Mooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00SOooool2o`0001gooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002/oooo
o`03o`000?oooooooooo00Sooooo0_l0000Booooo`;o0000Voooool008;ooooo0_l0000Xooooo`03
o`000?oooooooooo01cooooo0_l0000Booooo`?o00007oooool2o`0006Gooooo0021ooooo`?o0000
:?ooool00ol0003oooooooooo`0@ooooo`;o00003?ooool2o`00013ooooo0ol0000Oooooo`;o0000
IOooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`;o00003?oo
ool2o`0009Wooooo002/ooooo`?o00002?ooool3o`0000Gooooo0_l0002Wooooo`00P_ooool2o`00
02Sooooo00?o0000ooooooooool02?ooool2o`0000Kooooo0_l0000Rooooo`;o00006Oooool2o`00
06Sooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0dooooo`;o00006Oooool3o`0006Oo
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Aooooo`;o00008Oooool2o`0001Sooooo
1?l0001Wooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool04Oooool2o`00023ooooo0ol0
000Hooooo`;o0000JOooool00:cooooo00?o0000ooooooooool0<_ooool3o`0008Cooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`0Nooooo`;o00003oooool2o`000003ooooool0003o0000
08Gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Nooooo`;o00003oooool2o`0008So
oooo002/ooooo`?o0000;oooool2o`0008Sooooo002>ooooo`;o00007?ooool00ol0003ooooooooo
o`2iooooo`00P_ooool2o`0000[ooooo0_l0000Kooooo`;o00007oooool2o`0009[ooooo0022oooo
o`;o00004_ooool2o`0001?ooooo0_l0000Aooooo`?o00002oooool2o`0009[ooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`0?ooooo`?o00002Oooool2o`0001Kooooo0_l00024ooooo`00
POooool2o`0002Wooooo00?o0000ooooooooool06oooool2o`0001Kooooo0_l00024ooooo`00POoo
ool2o`0001Sooooo0_l0000?ooooo`03o`000?oooooooooo00;o0000<?ooool2o`0008Gooooo002K
ooooo`;o00003oooool00ol0003oooooooooo`02o`0000kooooo0_l0000Pooooo`;o0000QOooool0
0:cooooo0ol0000@ooooo`;o00007Oooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo02oo
oooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Loooo
o`;o0000Voooool008Wooooo0ol000000olb<S;ok^k^ooooo`04ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01cooooo0_l0000boooo
o`;o0000Ioooool008Wooooo0_l000000oooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Ioooo
o`?o00004oooool2o`0001oooooo0_l0001Wooooo`00ROooool01Ol@413ooooooooooooooooo410@
00[ooooo0_l000000onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000<oooo
o`;o00002oooool3o`0001?ooooo0_l00028ooooo`00ROooool01Ol0003ooooooooooooooooo0000
00[ooooo0_l000001?ooooooV9RHob4Q8Oo^k^h2o`0000Gooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0<ooooo`Co00002?ooool2o`0009oooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool01?mgMgOoIVIVo`000?l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0>ooooo`;o00002?ooool2o`0009oooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41000_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00;ooooo0_l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0000Kooooo`;o00000_ooool2o`0008So
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o0000R?ooool00:co
oooo0_l0000_ooooo`;o00007Oooool2o`0006[ooooo0024ooooo`;o00009_ooool2o`0001Wooooo
0_l0000Dooooo`;o00007Oooool2o`0006[ooooo0024ooooo`;o00009_ooool00ol0003ooooooooo
o`0Hooooo`;o00005?ooool2o`0008Wooooo002:ooooo`;o00002Oooool2o`0001Gooooo0ol0000^
ooooo`;o00007?ooool2o`0006_ooooo002:ooooo`;o00002Oooool2o`0001?ooooo0ol0000_oooo
o`;o00007Oooool2o`0006_ooooo002Zooooo`?o0000;oooool2o`0001cooooo0_l0001/ooooo`00
U_ooool2o`0001Cooooo00?o0000ooooooooool0Boooool2o`0006cooooo002Fooooo`;o00005?oo
ool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
5_ooool2o`0009kooooo002Aooooo`;o00005_ooool2o`000003ooooool0003ooooo01Oooooo0_l0
00000ooooooo0000o`00000`ooooo`;o0000K?ooool0097ooooo0_l00004ooooo`;o00001?ooool2
o`0000[ooooo0_l000000ooooooo0000ooooo`0Gooooo`?o0000<_ooool2o`0006cooooo002Aoooo
o`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`?o00005oooool2o`000:3ooooo002/ooooo`04
o`000?oooooo0000o`0000Oooooo0_l0000<ooooo`;o0000<_ooool2o`0006gooooo002Oooooo`;o
00002oooool01?l0003oooooo`000?l00007ooooo`;o00003?ooool2o`0003;ooooo0_l0001]oooo
o`00Q?ooool2o`0001Wooooo0_l00005ooooo`;o00001?ooool01?l0003oooooo`000?l00006oooo
o`;o00008oooool2o`0001gooooo0_l0001/ooooo`00Q?ooool2o`0001oooooo0ol00004ooooo`04
o`000?oooooo0000o`0000Kooooo0_l0000Sooooo`;o00007Oooool2o`0006cooooo002Cooooo`;o
00003Oooool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool05_ooool2o`000:7o
oooo0025ooooo`;o00003?ooool2o`0000gooooo0_l00008ooooo`03o`000?oooooooooo01Kooooo
0_l0002Qooooo`00QOooool2o`0000cooooo0_l00004ooooo`;o00004Oooool00ol0003ooooooooo
o`07ooooo`;o0000/?ooool009?ooooo0_l00004ooooo`;o00004Oooool3o`0000Oooooo0_l0000M
ooooo`;o0000TOooool00:cooooo00?o0000ooooooooool09_ooool4o`0008oooooo002/ooooo`03
o`000?oooooooooo02Sooooo0_l0002?ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool09oooool2o`00093ooooo002Dooooo`;o00005_ooool0
0ol0003oooooooooo`03ooooo`;o00008_ooool2o`00093ooooo002/ooooo`03o`000?oooooooooo
00?ooooo0_l0002dooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool008oooooo
0_l00004ooooo`;o00001_ooool2o`0000gooooo0ol0000Vooooo`;o00007?ooool2o`0007?ooooo
002?ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`04o`000?ooooooooooooooo`Co0000
8Oooool2o`0001cooooo0_l0001cooooo`00S_ooool3o`0000Gooooo0_l00005ooooo`;o00000ooo
ool2o`0000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`Co00003?ooool2o`0001;ooooo
0_l0002Booooo`00S_ooool3o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l0000>ooooo`;o00004_ooool2o`0001gooooo0_l0001cooooo`00Sooo
ool2o`00013ooooo0_l00009ooooo`04o`000?ooooooooooooooo`;o0000@Oooool2o`0007?ooooo
002?ooooo`;o00004?ooool2o`0000Wooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo02;ooooo0_l0000Oooooo`;o0000M?ooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`04o`00
0?ooooooooooooooo`;o0000@?ooool2o`0007Cooooo002Aooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000]_ooool0097o
oooo00Ko0000ooooooooooooooooo`000?ooool2o`0000cooooo00?oMgMgoc8b<_ooool01?ooool3
o`0002?ooooo0_l0002Dooooo`00TOooool01_l0003ooooooooooooooooo0000ooooo`;o00002Ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2o`0001Cooooo
0_l0002Dooooo`00T?ooool3o`0000;ooooo00?o410@ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`;o00000_ooool2o`0009Gooooo002@
ooooo`?o000000?ooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01kooooo0_l00002ooooo`;o0000UOooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001Oooool2o`000;_ooooo002[ooooo`;o00008oooool2o`0001gooooo0_l0001goooo
o`00[?ooool00ol0003oooooooooo`0Qooooo`;o00007Oooool2o`0007Oooooo002/ooooo`03o`00
0?oooooooooo01cooooo0_l0002Kooooo`00W_ooool2o`0000cooooo0ol0000Looooo`;o0000Vooo
ool009kooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`Go00002_ooool00ol0
003oooooooooo`09ooooo`;o0000[_ooool008Wooooo0_l0000Booooo`Go00002_ooool00ol0003o
ooooooooo`06ooooo`;o000000?oooooo`000?l000003oooool2o`0009gooooo0029ooooo`;o0000
2Oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`Co0000
4?ooool2o`0009gooooo0029ooooo`;o00002?ooool3o`0000[ooooo0ol00002ooooo`;o00001Ooo
ool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo0_l00008ooooo`?o00002_ooool2
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00ROooool2o`00
027ooooo00?o0000ooooooooool0>_ooool2o`0007gooooo002/ooooo`?o00007?ooool2o`0009_o
oooo002/ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00
[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool04ooo
ool2o`000:Cooooo002<ooooo`;o00007_ooool3o`0001?ooooo0_l0002Tooooo`00Roooool3o`00
01kooooo00?o0000ooooooooool00_l0002gooooo`00Roooool2o`0001oooooo1Ol0000@ooooo`;o
0000YOooool00:_ooooo1?l0000Booooo`;o0000YOooool00:_ooooo1?l0002iooooo`00[?ooool3
o`00017ooooo0_l0002Vooooo`00Z_ooool5o`00017ooooo1?l0002Tooooo`00Z_ooool3o`0001Go
oooo0ol0002Sooooo`00[?ooool00ol0003oooooooooo`0Booooo`Co0000Xoooool00:cooooo0ol0
000Booooo`;o00007Oooool2o`0008Kooooo002Oooooo`;o00001Oooool2o`0000Cooooo00?o0000
ooooooooool03Oooool2o`00023ooooo1?l00026ooooo`00Woooool3o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo00cooooo0ol0000Pooooo`;o0000R?ooool00:3ooooo0_l0000:ooooo`03
o`000?oooooooooo00cooooo0_l0002[ooooo`00Xoooool2o`0000;ooooo0_l00003ooooo`03o`00
0?oooooooooo013ooooo0_l0000Looooo`;o0000ROooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_l00003ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`;o0000ROooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool3o`000:_ooooo0029ooooo`05o`000?ooooooooooooooool0
00001?ooool2o`0000Sooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
00002oooool2o`000:cooooo0029ooooo`05o`000?ooooooooooooooool000000_ooool4o`0000So
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool02oooool2o`000:cooooo0029ooooo`05oa0@4?ooooooooooooooool@41000_ooool4o`00
00Sooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool01_ooool3o`000;3ooooo002/ooooo`03o`000?oooooooooo00Kooooo0ol0000Noooo
o`;o0000T?ooool00:cooooo00?o0000ooooooooool01oooool2o`0001kooooo0_l0002@ooooo`00
U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`?o00001_oo
ool2o`0001gooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`05ooooo`?o00007Oooool2
o`0009;ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo
002Eooooo`;o00005Oooool01?l0003oooooo`000?l00003ooooo`;o0000/oooool009Gooooo0_l0
000Eooooo`04o`000?oooooo0000o`000;Sooooo0028ooooo`;o00008_ooool5o`000;Oooooo0028
ooooo`;o00003oooool2o`00017ooooo1Ol0002gooooo`00VOooool2o`00017ooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`03o`00
0?oooooooooo0;Wooooo002Hooooo`;o00003_ooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool00:Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`?o000000?oooooo`00
0?ooool0^_ooool009gooooo0_l00009ooooo`Go0000^oooool009gooooo0_l0000;ooooo`?o0000
^oooool00:Kooooo0_l00004ooooo`?o0000^Oooool00:7ooooo1?l000000ooooooo0000o`000004
ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`Co00001oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52956 .84089 Mdot
.44099 .1183 Mdot
.50402 .4553 Mdot
.5503 .53383 Mdot
.42328 .28312 Mdot
.61363 .35315 Mdot
.51745 .488 Mdot
.41261 .0943 Mdot
.57958 .86241 Mdot
.56055 .56384 Mdot
.43192 .71017 Mdot
.49534 .01635 Mdot
.66963 .49607 Mdot
.47888 .78507 Mdot
.48178 .01412 Mdot
.41588 .50466 Mdot
.61148 .46765 Mdot
.66998 .52072 Mdot
.5741 .57527 Mdot
.43102 .09473 Mdot
.66685 .49967 Mdot
.55857 .18408 Mdot
.5841 .2297 Mdot
.66749 .55444 Mdot
.6386 .19494 Mdot
.54047 .74552 Mdot
.41471 .40378 Mdot
.57744 .50606 Mdot
.47954 .04953 Mdot
.44136 .11977 Mdot
.66323 .54666 Mdot
.56768 .88159 Mdot
.36717 .55295 Mdot
.58013 .68852 Mdot
.41113 .73458 Mdot
.41156 .83282 Mdot
.69298 .4221 Mdot
.54725 .33587 Mdot
.50723 .07466 Mdot
.55069 .07247 Mdot
.66102 .22633 Mdot
.49739 .85078 Mdot
.46582 .1267 Mdot
.45632 .89498 Mdot
.57228 .77156 Mdot
.57813 .37481 Mdot
.52601 .69892 Mdot
.64365 .75974 Mdot
.41839 .26425 Mdot
.43377 .09362 Mdot
.65277 .73849 Mdot
.61264 .21405 Mdot
.67033 .16599 Mdot
.39507 .40188 Mdot
.42248 .20683 Mdot
.46271 .97503 Mdot
.42008 .0741 Mdot
.61315 .47632 Mdot
.69431 .60697 Mdot
.59329 .72745 Mdot
.58663 .41538 Mdot
.72353 .66293 Mdot
.50786 .07682 Mdot
.48988 .7294 Mdot
.38659 .77039 Mdot
.50943 .95442 Mdot
.56321 .51464 Mdot
.44129 .71129 Mdot
.56104 .37777 Mdot
.6602 .60239 Mdot
.6084 .60096 Mdot
.446 .36511 Mdot
.55982 .56173 Mdot
.54797 .38202 Mdot
.50694 .07581 Mdot
.44246 .48294 Mdot
.67072 .16659 Mdot
.59311 .50503 Mdot
.58326 .16806 Mdot
.41756 .71626 Mdot
.59967 .76779 Mdot
.42117 .17153 Mdot
.54409 .42593 Mdot
.47085 .86618 Mdot
.36592 .51098 Mdot
.42984 .3219 Mdot
.43892 .22593 Mdot
.47952 .18389 Mdot
.60717 .41989 Mdot
.43582 .69139 Mdot
.64086 .19973 Mdot
.35688 .51765 Mdot
.42519 .39624 Mdot
.54031 .27378 Mdot
.42499 .59393 Mdot
.36702 .71497 Mdot
.49258 .77376 Mdot
.65683 .72366 Mdot
.69209 .19781 Mdot
.6142 .46054 Mdot
.4848 .89661 Mdot
.58519 .33394 Mdot
.47267 .01048 Mdot
.41956 .81949 Mdot
.62358 .72138 Mdot
.56121 .73565 Mdot
.59854 .64074 Mdot
.54935 .67985 Mdot
.42714 .37857 Mdot
.65958 .60122 Mdot
.53052 .69185 Mdot
.55133 .5289 Mdot
.57984 .86394 Mdot
.37638 .55211 Mdot
.79442 .54722 Mdot
.51355 .36418 Mdot
.59299 .46908 Mdot
.43345 .94646 Mdot
.49228 .97428 Mdot
.67808 .36995 Mdot
.66845 .48415 Mdot
.74235 .57668 Mdot
.64448 .373 Mdot
.50239 .06422 Mdot
.65867 .60867 Mdot
.54179 .60031 Mdot
.37796 .40458 Mdot
.42811 .98215 Mdot
.39625 .69084 Mdot
.51905 .61882 Mdot
.59527 .24701 Mdot
.43002 .84626 Mdot
.54861 .07338 Mdot
.62749 .40002 Mdot
.53136 .18477 Mdot
.56165 .13619 Mdot
.69433 .41343 Mdot
.41963 .12719 Mdot
.56156 .53983 Mdot
.3713 .35751 Mdot
.50773 .03248 Mdot
.6688 .78714 Mdot
.52432 .33827 Mdot
.57708 .46934 Mdot
.61222 .47423 Mdot
.39005 .26277 Mdot
.37845 .72347 Mdot
.76162 .7038 Mdot
.55552 .65108 Mdot
.51473 .2273 Mdot
.74779 .54824 Mdot
.57447 .30466 Mdot
.51292 .25138 Mdot
.66608 .57419 Mdot
.43511 .4471 Mdot
.63529 .47408 Mdot
.67029 .33428 Mdot
.54986 .12601 Mdot
.44806 .96632 Mdot
.69029 .41279 Mdot
.67714 .35306 Mdot
.44031 .80342 Mdot
.59235 .17997 Mdot
.67762 .24846 Mdot
.49407 .9248 Mdot
.43671 .16988 Mdot
.52027 .85198 Mdot
.38991 .80073 Mdot
.5953 .78183 Mdot
.55078 .34345 Mdot
.68044 .35814 Mdot
.38084 .36732 Mdot
.42651 .39299 Mdot
.50565 .24074 Mdot
.42557 .27527 Mdot
.52577 .73395 Mdot
.36926 .59726 Mdot
.38265 .82801 Mdot
.63275 .45089 Mdot
.48063 .2958 Mdot
.48416 .05251 Mdot
.6587 .29896 Mdot
.59473 .12611 Mdot
.50819 .26984 Mdot
.67436 .25009 Mdot
.42971 .58626 Mdot
.60293 .825 Mdot
.56205 .89183 Mdot
.66275 .22292 Mdot
.51192 .15545 Mdot
.74571 .5052 Mdot
.39151 .25187 Mdot
.5368 .57417 Mdot
.7353 .60655 Mdot
.3748 .30281 Mdot
.72014 .35162 Mdot
.50867 .03069 Mdot
.51282 .2218 Mdot
.41485 .03793 Mdot
.54672 .77404 Mdot
.43004 .49555 Mdot
.43162 .44436 Mdot
.46302 .3195 Mdot
.40683 .42666 Mdot
.47138 .89771 Mdot
.50067 .30507 Mdot
.62659 .40364 Mdot
.55154 .54207 Mdot
.45765 .28689 Mdot
.41603 .61435 Mdot
.65086 .37525 Mdot
.59289 .48602 Mdot
.59365 .78463 Mdot
.45516 .24813 Mdot
.50901 .86783 Mdot
.58603 .42508 Mdot
.67952 .25304 Mdot
.42518 .48193 Mdot
.62098 .64088 Mdot
.52 .03846 Mdot
.59183 .45421 Mdot
.69266 .60412 Mdot
.60923 .75541 Mdot
.57146 .81711 Mdot
.41702 .46175 Mdot
.41781 .67933 Mdot
.42269 .161 Mdot
.4258 .39656 Mdot
.48965 .01714 Mdot
.73756 .6147 Mdot
.44637 .72858 Mdot
.44125 .56532 Mdot
.48004 .15489 Mdot
.41824 .36283 Mdot
.74486 .53485 Mdot
.53081 .29271 Mdot
.39607 .70047 Mdot
.65115 .39096 Mdot
.44595 .87844 Mdot
.72468 .65652 Mdot
.58325 .27432 Mdot
.52963 .88551 Mdot
.60899 .59748 Mdot
.54728 .91038 Mdot
.44737 .7051 Mdot
.64713 .28356 Mdot
.5581 .27711 Mdot
.61079 .58697 Mdot
.52323 .0938 Mdot
.71009 .32544 Mdot
.50742 .34425 Mdot
.53923 .54451 Mdot
.66119 .31819 Mdot
.54478 .733 Mdot
.48903 .21578 Mdot
.48289 .12144 Mdot
.44783 .41548 Mdot
.39065 .18894 Mdot
.67193 .69228 Mdot
.44987 .17241 Mdot
.41777 .36673 Mdot
.54449 .85909 Mdot
.53223 .4957 Mdot
.5558 .26538 Mdot
.57404 .76274 Mdot
.51401 .72661 Mdot
.56071 .23659 Mdot
.38417 .66547 Mdot
.50235 .81164 Mdot
.38213 .64882 Mdot
.45144 .13747 Mdot
.55978 .57536 Mdot
.40068 .42422 Mdot
.66975 .33116 Mdot
.52802 .31501 Mdot
.45866 .80356 Mdot
.63967 .76542 Mdot
.41791 .63418 Mdot
.63475 .45806 Mdot
.52557 .09297 Mdot
.48504 .71503 Mdot
.50793 .27289 Mdot
.68818 .40536 Mdot
.44706 .0268 Mdot
.54117 .70272 Mdot
.45866 .66617 Mdot
.45519 .79333 Mdot
.39311 .7503 Mdot
.54516 .28661 Mdot
.62336 .71503 Mdot
.69883 .56643 Mdot
.43826 .04239 Mdot
.69832 .55443 Mdot
.48714 .33713 Mdot
.70188 .55945 Mdot
.74101 .54409 Mdot
.43471 .9036 Mdot
.46276 .01679 Mdot
.72726 .78142 Mdot
.39881 .51788 Mdot
.55219 .21342 Mdot
.41038 .77972 Mdot
.55441 .90041 Mdot
.63759 .19085 Mdot
.50103 .75638 Mdot
.64762 .74727 Mdot
.52514 .77359 Mdot
.46709 .69418 Mdot
.64195 .34929 Mdot
.61356 .51229 Mdot
.66401 .44634 Mdot
.74837 .51294 Mdot
.52163 .39885 Mdot
.6084 .68187 Mdot
.54473 .77058 Mdot
.37135 .62562 Mdot
.5313 .54553 Mdot
.59993 .13358 Mdot
.73039 .40882 Mdot
.61318 .87904 Mdot
.4987 .73485 Mdot
.63313 .42426 Mdot
.45314 .855 Mdot
.55445 .13372 Mdot
.40698 .58153 Mdot
.43015 .53111 Mdot
.5074 .40115 Mdot
.60801 .59537 Mdot
.47768 .00583 Mdot
.64885 .29126 Mdot
.42509 .59662 Mdot
.61959 .29145 Mdot
.50568 .66833 Mdot
.46488 .31741 Mdot
.43033 .13969 Mdot
.60705 .33229 Mdot
.44014 .16208 Mdot
.44231 .80744 Mdot
.40558 .53287 Mdot
.63719 .12028 Mdot
.53721 .74743 Mdot
.39032 .35941 Mdot
.49449 .72092 Mdot
.39689 .8311 Mdot
.4113 .50723 Mdot
.40149 .19819 Mdot
.46111 .09752 Mdot
.48315 .2531 Mdot
.55473 .31402 Mdot
.67036 .78497 Mdot
.49353 .01412 Mdot
.70235 .56625 Mdot
.39249 .73767 Mdot
.40251 .60745 Mdot
.56747 .72856 Mdot
.37817 .4127 Mdot
.52311 .2067 Mdot
.48868 .01135 Mdot
.58354 .92027 Mdot
.51578 .90374 Mdot
.53784 .06182 Mdot
.60915 .14602 Mdot
.68436 .26553 Mdot
.50648 .36805 Mdot
.44369 .18534 Mdot
.50783 .03307 Mdot
.4021 .13381 Mdot
.51552 .40645 Mdot
.64208 .66368 Mdot
.54976 .71624 Mdot
.63232 .42899 Mdot
.50118 .8809 Mdot
.64238 .75545 Mdot
.4002 .72891 Mdot
.70123 .4838 Mdot
.60883 .21513 Mdot
.56884 .20426 Mdot
.7052 .5314 Mdot
.57913 .21911 Mdot
.6057 .14704 Mdot
.78721 .61294 Mdot
.6887 .4149 Mdot
.6376 .52299 Mdot
.43793 .5758 Mdot
.71332 .34473 Mdot
.60574 .40885 Mdot
.50028 .37097 Mdot
.6133 .14956 Mdot
.65832 .61208 Mdot
.43053 .54343 Mdot
.55687 .42609 Mdot
.57994 .63365 Mdot
.43279 .28076 Mdot
.62738 .79177 Mdot
.58363 .80665 Mdot
.73788 .58489 Mdot
.60463 .13894 Mdot
.60149 .61879 Mdot
.59219 .06929 Mdot
.58498 .68098 Mdot
.53082 .72316 Mdot
.48076 .80803 Mdot
.49975 .61583 Mdot
.45175 .01841 Mdot
.48556 .01062 Mdot
.41288 .43148 Mdot
.46033 .26226 Mdot
.44973 .22826 Mdot
.46453 .23344 Mdot
.74086 .43608 Mdot
.53417 .25968 Mdot
.48848 .9304 Mdot
.53028 .35989 Mdot
.5166 .25931 Mdot
.52908 .56384 Mdot
.48925 .18599 Mdot
.59289 .64808 Mdot
.4624 .2127 Mdot
.51586 .34734 Mdot
.74525 .56166 Mdot
.37038 .371 Mdot
.44958 .55025 Mdot
.39729 .62947 Mdot
.59866 .63999 Mdot
.6351 .53138 Mdot
.52866 .76195 Mdot
.52814 .28556 Mdot
.72144 .36641 Mdot
.35754 .41475 Mdot
.38962 .63588 Mdot
.78944 .4438 Mdot
.42401 .83547 Mdot
.53725 .44056 Mdot
.56462 .88105 Mdot
.52091 .04714 Mdot
.42655 .68418 Mdot
.45331 .10571 Mdot
.6459 .13191 Mdot
.47366 .25318 Mdot
.45487 .67957 Mdot
.50498 .77531 Mdot
.54479 .85963 Mdot
.44103 .79912 Mdot
.37449 .21556 Mdot
.42841 .42074 Mdot
.40191 .6687 Mdot
.49724 .85229 Mdot
.44111 .68904 Mdot
.51227 .3632 Mdot
.54545 .36882 Mdot
.41209 .09634 Mdot
.53297 .48546 Mdot
.56772 .14547 Mdot
.40296 .2475 Mdot
.58716 .73839 Mdot
.37611 .52534 Mdot
.64229 .65998 Mdot
.60984 .5723 Mdot
.41414 .95263 Mdot
.56085 .4553 Mdot
.48871 .00903 Mdot
.71216 .32919 Mdot
.51632 .72039 Mdot
.70192 .56466 Mdot
.51639 .78622 Mdot
.59746 .38882 Mdot
.39888 .21118 Mdot
.47677 .89981 Mdot
.5689 .6046 Mdot
.55909 .32506 Mdot
.57841 .69495 Mdot
.71976 .68245 Mdot
.50894 .15383 Mdot
.44199 .50144 Mdot
.42658 .19681 Mdot
.40735 .64928 Mdot
.50534 .36245 Mdot
.48913 .74893 Mdot
.39336 .43531 Mdot
.53023 .18158 Mdot
.463 .30085 Mdot
.56815 .67115 Mdot
.5042 .96025 Mdot
.41969 .30058 Mdot
.59453 .71747 Mdot
.576 .44903 Mdot
.57506 .47412 Mdot
.52465 .52684 Mdot
.79613 .53149 Mdot
.52263 .5523 Mdot
.43547 .1285 Mdot
.69289 .59286 Mdot
.47672 .93443 Mdot
.56896 .41284 Mdot
.44457 .07285 Mdot
.56234 .08712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:?ooooo0ol0
00001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o00000_oo
ool3o`0000;ooooo00?o0000ooooooooool0^Oooool009oooooo0_l000001OooooooEEEEofIVI_l0
003ooooo00Oo0000^oooool009cooooo0_l000000ooooooo0000o`000005ooooo`Oo0000^oooool0
09cooooo0_l0000:ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00Co
0000ooooool0003o0000^?ooool00:cooooo00Co0000ooooool0003o0000^?ooool008oooooo0_l0
000Kooooo`04o`000?oooooo0000o`000;Sooooo002?ooooo`;o00006oooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0002d
ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Uooooo`;o
00001Oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:Gooooo0ol00004ooooo`?o0000
^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool2o`0000[o
oooo0_l0002^ooooo`00[?ooool2o`000;[ooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0
002Looooo`00TOooool2o`0000Kooooo0_l0000Aooooo`03o`000?oooooooooo00gooooo0_l0000<
ooooo`;o0000W?ooool0097ooooo0_l00006ooooo`;o00004Oooool4o`0000cooooo0_l0002Zoooo
o`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_oo
ool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002?ooooo`;o00001?ooool3o`00
01Cooooo00?o0000ooooooooool01?ooool3o`000;;ooooo002?ooooo`;o00001?ooool3o`0000Oo
oooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00Soooool2o`0000kooooo
0_l0000;ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>
ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`;o000000?oooooo`000?o^k^h0
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0oooool2o`000003oooooomEEEGoZJVY00So
oooo00?oMgMgo`000?l000001?ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool0087ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`;o
00001?ooool3o`0002[ooooo0_l0002=ooooo`00ROooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00003ooooo`;o00001?ooool01?lQ8B7oooooooooooooool2o`0000?ooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0=ooooo`;o00003Oooool2o`0009_ooooo0029ooooo`05
o`000?ooooooooooooooool000000oooool2o`0000?ooooo0_l00004ooooo`04oeEEEOo<c<cooooo
ooooo`?o000000Co8B4Qo`000?lb<S;oc<c<1Oooool00ol0003oooooooooo`0=ooooo`;o00003Ooo
ool2o`0000oooooo0_l0002:ooooo`00ROooool01Ol@413oooooo`000?l0003o410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0
000=ooooo`;o00003Oooool2o`0008[ooooo0029ooooo`05ogMgMonHV9So0000o`000?mgMgL02ooo
ool00ol@413oooooooooo`02o`0000Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`Co00002oooool2o`0009Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool2o`0000;ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Aooooo`;o00003?oo
ool2o`0009Sooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0
0:cooooo00?o0000ooooooooool04oooool2o`0000[ooooo1?l0002Fooooo`00[?ooool00ol0003o
ooooooooo`0Cooooo`;o00002_ooool5o`0009Gooooo002/ooooo`?o00008_ooool2o`0009Gooooo
002Uooooo`;o00001Oooool00ol0003oooooooooo`02o`000;Oooooo002Uooooo`;o00001Oooool0
0ol0003oooooooooo`02o`000;Oooooo002Booooo`;o00001?ooool2o`0001;ooooo00?o0000oooo
ooooool0^Oooool009;ooooo0_l00004ooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`0Hooooo`;o00006oooool2o`0008;ooooo002Gooooo`;o00004ooo
ool00ol0003oooooooooo`0Hooooo`;o00006oooool2o`0008;ooooo002Booooo`;o00000oooool2
o`0000;ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00001oooool2o`00
00oooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo
00?o0000ooooooooool01oooool2o`0001;ooooo0_l0002Looooo`00VOooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o0000Yooo
ool008Oooooo0_l0000@ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo00?o0000
ooooooooool01oooool2o`0000Oooooo0_l0002Wooooo`00Qoooool2o`0002?ooooo00?o0000oooo
ooooool0:_ooool2o`0008gooooo002/ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00
Roooool2o`0000Kooooo0_l0000Gooooo`03o`000?oooooooooo02[ooooo0_l0000@ooooo`;o0000
Noooool008_ooooo0_l00006ooooo`;o00005oooool3o`0002_ooooo0_l0000?ooooo`;o0000Nooo
ool00:cooooo00?o0000ooooooooool04oooool2o`0001Kooooo0_l0002<ooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool01?ooool2o`0000gooooo0_l0002Tooooo`00T_ooool2o`0001So
oooo00?o0000ooooooooool01?ooool2o`000;?ooooo002:ooooo`;o00004oooool2o`0000_ooooo
00?o0000ooooooooool03_ooool2o`000:Wooooo0022ooooo`;o00001_ooool2o`0001?ooooo0_l0
0007ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`;o00004?ooool4o`0009Gooooo0022
ooooo`;o00009?ooool2o`0000;ooooo00?o0000ooooooooool05oooool2o`0000Oooooo1?l0002E
ooooo`00[?ooool01?l0003oooooooooooooool2o`0001Cooooo0_l0002Pooooo`00[?ooool3o`00
0003ooooool0003o000002oooooo0_l00025ooooo`00Uoooool2o`0000;ooooo0_l0000?ooooo`04
o`000?ooooooooooooooo`;o0000;oooool2o`0008Gooooo002Gooooo`;o00000_ooool2o`0000oo
oooo00Co0000oooooooooooooooo0_l0000Eooooo`;o00006?ooool2o`0008Gooooo002Pooooo`;o
00002_ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:3ooooo0_l0000:ooooo`03o`00
0?oooooooooo017ooooo0_l0002Vooooo`00[?ooool3o`00017ooooo0_l0002Vooooo`00TOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool3o`000;Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool008Wooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Looooo`;o00006?ooool3o`00083ooooo0028ooooo`;o00000_oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001_ooool00omgMgOo0000
o`000004ooooo`?o000000?oooooo`000?l00000<oooool4o`0007oooooo0028ooooo`;o00001ooo
ool01Ol0003ooooooooooooooooo000000cooooo0ol000000olb<S;o0000o`000004ooooo`04o`00
0?ooooooooooooooo`;o0000=Oooool2o`0007oooooo002Aooooo`05oa0@4?ooooooooooooooool@
41003?ooool3o`0000Oooooo00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000Co
oooo0_l0002_ooooo`00Qoooool2o`0000Sooooo0ol000000olb<S;ok^k^ooooo`07ooooo`;o0000
0_ooool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0002_ooooo`00Qooo
ool2o`0000Sooooo0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`0?ooooo`;o0000:?oo
ool2o`0007kooooo002/ooooo`04o`000?oooooo0000o`0000kooooo0_l0000Xooooo`;o0000O_oo
ool00:cooooo00Co0000ooooool0003o00002Oooool2o`0000cooooo0_l0002Oooooo`00Toooool2
o`0001Oooooo1?l00009ooooo`;o00001?ooool2o`0000Kooooo0_l0002Oooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Booooo`;o000000?oooooo`000?l0
00005Oooool00ol0003oooooooooo`2iooooo`00T_ooool2o`000003ooooool0003o000001Gooooo
00?o0000ooooooooool01_ooool2o`0002Gooooo0_l0002:ooooo`00W_ooool2o`0000cooooo00?o
0000ooooooooool01_ooool2o`0000?ooooo0_l0000Pooooo`;o0000R_ooool009kooooo0_l0000<
ooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o00002?ooool2o`0008Wooooo002/oooo
o`03o`000?oooooooooo00Oooooo0_l0000Kooooo`;o00002?ooool2o`0008Wooooo002Uooooo`;o
00001Oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool0097ooooo0_l0000<ooooo`;o0000
1?ooool2o`0000Gooooo0ol0000aooooo`;o0000Q_ooool008;ooooo0_l0000=ooooo`;o00003?oo
ool2o`0000_ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo0022ooooo`;o0000:?ooool2
o`0001Kooooo0_l0002Rooooo`00[?ooool2o`0001Kooooo0_l0002Rooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`000:Sooooo
002Oooooo`?o00002_ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`00027ooooo0_l0
0025ooooo`00U?ooool2o`0000Wooooo0ol0000:ooooo`03o`000?oooooooooo03;ooooo0_l00025
ooooo`00U?ooool2o`0001Kooooo0ol0000@ooooo`;o0000<?ooool2o`0007Gooooo002/ooooo`03
o`000?oooooooooo013ooooo0_l0000`ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool0
=Oooool2o`0000cooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00001Ooo
ool2o`0001?ooooo0_l0000<ooooo`;o0000M?ooool00:Oooooo0_l00003ooooo`03o`000?oooooo
oooo00cooooo0_l0000;ooooo`;o00001Oooool2o`0001?ooooo0_l00022ooooo`00Yoooool2o`00
00?ooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0002[ooooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool2o`000:[ooooo002/ooooo`04o`000?oooooo0000o`0000co
oooo0_l0000dooooo`;o0000M?ooool00:cooooo00Go0000ooooool0003o0000ooooo`02o`0002Oo
oooo0_l0000Fooooo`;o0000M?ooool00:cooooo0ol00002ooooo`;o00009oooool2o`0000[ooooo
0_l0000<ooooo`;o0000L_ooool00:cooooo00?o0000ooooooooool08_ooool2o`0001?ooooo0_l0
000<ooooo`;o0000L_ooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo02;ooooo0_l0000D
ooooo`;o0000Ooooool0087ooooo0_l00004ooooo`;o00008oooool00ol0003oooooooooo`07oooo
o`;o0000;oooool2o`0007oooooo0027ooooo`;o00002?ooool2o`0000Oooooo0_l0000@ooooo`?o
000000?oooooo`000?l000001?ooool2o`000;3ooooo0024ooooo`;o00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo0ol00002ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool6o`0004?ooooo0_l0001aooooo`00POooool2o`000003ooooool0003o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool4o`0000_ooooo0_l0000Y
ooooo`;o00003Oooool2o`00077ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`;o00003Oooool2
o`0001kooooo0_l00009ooooo`;o0000P?ooool008Wooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Kooooo0_l0000D
ooooo`Co0000ROooool008Wooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Aooooo`;o00000oooool2o`0001Kooooo0_l00029ooooo`00ROooool01Ol@413ooooooooooooo
oooo410@00Kooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`000:Kooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooooooo
ool07Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0000?ooooo`;o0000
ROooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00Toooool2
o`0001Oooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`Co00000oooool2o`00
027ooooo0_l0002@ooooo`00Poooool2o`0000Cooooo0_l00004ooooo`;o00006oooool01?l0003o
ooooo`000?l00003ooooo`;o00008?ooool3o`00093ooooo0023ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo0_l0000Rooooo`;o00004oooool2o`0007co
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o00006_ooool2o`0000cooooo
0_l0001^ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool04oooool2o`0000[ooooo0_l0
000Jooooo`Co00002_ooool2o`0006kooooo001mooooo`;o00001?ooool2o`0001Gooooo0_l0000@
ooooo`03o`000?oooooooooo01?ooooo0_l00004ooooo`;o00008?ooool4o`0007[ooooo001moooo
o`;o00006oooool2o`00013ooooo00?o0000ooooooooool06Oooool2o`00023ooooo0_l0001loooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool08?ooool2o`0001[ooooo0_l0001kooooo`00
Roooool2o`0000Oooooo0_l0000Fooooo`?o00006Oooool2o`0000Gooooo0_l00007ooooo`;o0000
4Oooool2o`0007_ooooo002;ooooo`Co00007Oooool00ol0003oooooooooo`0;ooooo`;o00000_oo
ool2o`0000Sooooo0_l0000>ooooo`;o0000S_ooool008gooooo1?l0000Kooooo`03o`000?oooooo
oooo00_ooooo0_l00002ooooo`;o00005oooool2o`0008oooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`0Xooooo`;o0000Soooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo04co
oooo0_l0001[ooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool02Oooool2o`00047ooooo
0_l0001[ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000DOooool2o`0005_ooooo002E
ooooo`;o00005Oooool00ol0003oooooooooo`0cooooo`;o00009oooool2o`0005_ooooo002Eoooo
o`?o00005?ooool00ol0003oooooooooo`0Fooooo`;o00006oooool2o`0008Cooooo002Fooooo`;o
00005?ooool3o`0001Kooooo0_l0000@ooooo`;o0000Soooool00:cooooo0ol0000Aooooo`;o0000
2?ooool2o`0000_ooooo0_l0002?ooooo`00[?ooool3o`00017ooooo0_l00008ooooo`;o00003?oo
ool2o`0008kooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00003
ooooo`Co000000?o<S8bomgMgOooool05Oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_oo
ool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo0_l00002oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00001_ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool05Oooool00ol0003oooooooooo`0Fooooo`?o00000_ooool2o`0000Cooooo0_l00007
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooooooo01Gooooo1?l00002ooooo`;o00001Oooool2o`0000Gooooo0_l000000omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001Gooooo0_l000000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00?ooooo0_l00005ooooo`;o000000?oooooo`00
0?ooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`;o00004Oooool00ol0003o
ooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l00000
5_ooool009?ooooo0_l00004ooooo`;o00004Oooool00ol0003oooooooooo`07ooooo`;o00004_oo
ool2o`0001Oooooo0_l00009ooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool00_ooool2
o`0000?ooooo0_l0000Booooo`;o00005oooool2o`0000Wooooo0_l0001hooooo`00[?ooool00ol0
003oooooooooo`02ooooo`;o0000Z_ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003o
ooooooooo`2^ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool009Cooooo0_l0000Foooo
o`03o`000?oooooooooo00Oooooo0_l0000/ooooo`;o0000N?ooool01?oMgMgo0000oa0@4?o<c<`6
ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo1?l0000Jooooo`03o`000?oooooo
oooo01Kooooo0_l00003ooooo`;o00002_ooool00ol0003oooooooooo`0Tooooo`?o0000:?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool0
08kooooo1?l0000Jooooo`03o`000?oooooooooo01Kooooo0_l00003ooooo`;o0000<Oooool2o`00
06Wooooo001oooooo`;o0000:oooool00ol0003oooooooooo`0Rooooo`;o0000:oooool2o`0006So
oooo001oooooo`;o0000:oooool00ol0003oooooooooo`0Aooooo`;o00003oooool2o`0002_ooooo
0_l0001Xooooo`00O?ooool2o`0000cooooo0_l0000Pooooo`03o`000?oooooooooo017ooooo0_l0
002Vooooo`00O?ooool2o`0000cooooo0_l0000Pooooo`03o`000?oooooooooo03Gooooo0_l00022
ooooo`00Poooool2o`0002Oooooo0ol0000Zooooo`;o00002Oooool2o`0008;ooooo0023ooooo`;o
00009oooool00ol0003oooooooooo`05ooooo`;o00008oooool2o`0008gooooo002Eooooo`;o0000
5Oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0001Wooooo0_l0000Eooooo`;o0000
7?ooool2o`0005Wooooo002<ooooo`;o00001oooool2o`0001Gooooo00?o0000ooooooooool03Ooo
ool3o`0001Wooooo0_l0000Eooooo`;o00007?ooool2o`0005Wooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`0=ooooo`;o0000?_ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo
017ooooo0_l0000jooooo`;o0000J_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00ko
oooo0_l000000ooooooo0000o`00002Vooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
1oooool2o`000003ooooool0003o000000;ooooo0_l0000Rooooo`;o00006?ooool2o`0006_ooooo
002/ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`00000Vooooo`;o00006?oo
ool4o`0000kooooo0_l0001Iooooo`00P?ooool2o`000003ooooool0003o000001Kooooo0_l0000?
ooooo`?o00001?ooool2o`0004Sooooo0_l0000>ooooo`;o0000FOooool0083ooooo0_l000000ooo
oooo0000o`00000Fooooo`;o00003oooool00ol0003oooooooooo`04ooooo`;o0000;_ooool2o`00
00Sooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0dooooo`;o00002?ooool2o`0007Wo
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000]ooooo`;o00003Oooool2o`0006Wooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`?o0000;?ooool2o`0000gooooo0_l0
001Yooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l0000[
ooooo`?o0000N?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo03kooooo0ol0001hoooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o00005_ooool2o`00013ooooo0_l00024ooooo`00
Uoooool2o`0001?ooooo0ol00009ooooo`;o00001Oooool2o`0000?ooooo0_l0000:ooooo`;o0000
4?ooool2o`0001Sooooo0_l0001Zooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool04?oo
ool2o`0000?ooooo0_l0000fooooo`;o0000J_ooool008gooooo0_l0000Mooooo`03o`000?oooooo
oooo0;Wooooo002=ooooo`;o00001Oooool2o`0001Kooooo00?o0000ooooooooool0Boooool2o`00
06cooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Qooooo`;o0000:?ooool2o`0006co
oooo002/ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool08?ooool2o`0001[ooooo0_l0001kooooo`00P?ooool2o`00017ooooo0_l0000G
ooooo`03o`000?oooooooooo023ooooo0ol0000Iooooo`;o0000Noooool0083ooooo0_l0000Aoooo
o`;o00005oooool3o`0000[ooooo0_l0000Dooooo`?o00003_ooool2o`0008Kooooo002/ooooo`03
o`000?oooooooooo00[ooooo0_l0000Dooooo`;o00003oooool2o`0000Wooooo0_l0001kooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool04oooool2o`0001cooooo0_l00009ooooo`?o0000
2oooool2o`0006gooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Cooooo`;o00007?oo
ool2o`0000[ooooo0_l0000;ooooo`;o0000KOooool00:cooooo00?o0000ooooooooool0<Oooool2
o`0002Sooooo0_l0001Looooo`00T?ooool2o`0001Wooooo0_l0000cooooo`;o00006?ooool2o`00
00kooooo0_l0001Looooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooo
oooo8B4Qob4Q8@04ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l00005
ooooo`;o00006Oooool2o`0002_ooooo0_l0001/ooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00?ooooo0_l0000Iooooo`;o0000VOooool0087ooooo0_l00006
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0002iooooo`00POooool2o`0000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2iooooo`00ROooool3o`000003ooooool0003ooooo00gooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@
o`000?l0003ooooooa0@4002ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool2o`000:3ooooo0027ooooo`;o000000GoMgMg
oiRHV?ooooooV9RHogMgM`02ooooo`;o00001oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool008Oooooo0_l0
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool0
7Oooool2o`0000Kooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o0000T_oo
ool008Gooooo0_l00006ooooo`;o00007Oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0
08Gooooo0_l00006ooooo`;o00007Oooool3o`0000oooooo0_l0000:ooooo`;o0000W?ooool00:co
oooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo04Oooooo
0_l0001`ooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o00006Oooool2o`00073ooooo002/
ooooo`03o`000?oooooooooo02_ooooo0ol0000Hooooo`;o0000LOooool008Gooooo0_l0000Goooo
o`;o00003?ooool00ol0003oooooooooo`0[ooooo`;o00006Oooool2o`00077ooooo0025ooooo`;o
00001?ooool2o`00017ooooo0_l0000<ooooo`?o00004oooool2o`000:Cooooo002;ooooo`;o0000
7oooool3o`0001?ooooo0_l0002Tooooo`00[?ooool3o`000;Wooooo002@ooooo`;o00002oooool2
o`0000gooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002@ooooo`;o00002oooool2o`00
00gooooo00?o0000ooooooooool03Oooool2o`0000[ooooo0_l00005ooooo`;o00008oooool2o`00
07;ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Iooooo`;o00001Oooool2o`0002?o
oooo0_l0001booooo`00Toooool2o`0000?ooooo0_l0000Booooo`03o`000?oooooooooo01Oooooo
0_l0002Pooooo`00ROooool2o`0000_ooooo1?l0000Booooo`03o`000?oooooooooo00Oooooo0_l0
000>ooooo`;o00007?ooool2o`0008;ooooo0029ooooo`;o00002oooool2o`0000Wooooo0_l00009
ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o00007Oooool2o`0008;ooooo002Qoooo
o`;o00002Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool008Wooooo0_l0000Qooooo`?o
00001Oooool2o`000;;ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`05ooooo`;o0000
0oooool2o`0004Oooooo0_l0001Tooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool02_oo
ool2o`0004Oooooo0_l0001Tooooo`00UOooool2o`0000?ooooo0_l0000@ooooo`03o`000?oooooo
oooo0;Wooooo002Eooooo`;o000000?oooooo`000?l000004_ooool00ol0003oooooooooo`2ioooo
o`00P?ooool2o`0000kooooo0_l00006ooooo`;o00003Oooool2o`0000?ooooo00?o0000oooooooo
ool03Oooool2o`0001Kooooo0_l0002Booooo`00P?ooool2o`0000kooooo0_l0000Eooooo`;o0000
0oooool00ol0003oooooooooo`0=ooooo`;o00003Oooool2o`0000Oooooo0_l0002Booooo`00Z_oo
ool3o`0000Cooooo0_l0000Hooooo`;o00001oooool2o`0009;ooooo0023ooooo`;o00009Oooool5
o`0000;ooooo0_l00003ooooo`;o00007?ooool2o`0000Wooooo0_l00027ooooo`00Poooool2o`00
01Gooooo0_l0000@ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0000[ooooo0_l00006
ooooo`;o00004oooool2o`0008Oooooo002;ooooo`;o00003Oooool2o`0000cooooo0_l00002oooo
o`04o`000?ooooooooooooooo`;o00004?ooool2o`0000Kooooo0_l0002Looooo`00Roooool2o`00
0003ooooool0003o000001Sooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo0_l00004oooo
o`;o0000[?ooool008Sooooo0_l00004ooooo`;o00006oooool2o`0000Oooooo0_l00004ooooo`;o
00001?ooool2o`000:Kooooo0028ooooo`;o00008Oooool2o`0001?ooooo0_l00006ooooo`;o0000
5?ooool2o`0008Sooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Wooooo0_l0000Dooooo`;o
0000R?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00TOooool01Ol@413ooooo
oooooooooooo410@013ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`09oooo
o`?o00008Oooool2o`0008[ooooo0028ooooo`;o00001oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool00_l00002ooooo`?o00002Oooool2o`0002;ooooo0_l0002:oooo
o`00R?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Qooooo`;o00002Oooool2o`0008_ooooo002Aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`;o00008_ooool2
o`0000Wooooo0_l0002;ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool2o`0000Oooooo0_l0000Tooooo`;o0000Roooool0097ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`06ooooo`;o00003Oooool2
o`0001Gooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00001_ooool2o`00
00cooooo0_l0002<ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool02oooool2o`00013o
oooo0_l0000<ooooo`;o0000S?ooool008Kooooo0_l0000Qooooo`;o000000?oooooo`000?ooool0
1_ooool2o`0000Cooooo0ol00006ooooo`;o0000Xoooool00:Wooooo0_l000001?oooooo0000o`00
0?l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0002Sooooo`00S_ooool2o`0001cooooo0ol0
002iooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool07?ooool2o`0002[ooooo0_l0001_
ooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0001Oooooo0ol0000Goooo
o`;o00004Oooool2o`0006oooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o
00005oooool2o`0001Oooooo0ol00022ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o0000
2oooool2o`0008?ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0Wooooo`;o0000T?oo
ool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00003oooool2o`00
01;ooooo0ol0002iooooo`00Qoooool2o`0000oooooo0_l00004ooooo`;o00003?ooool00ol0003o
ooooooooo`2iooooo`00V?ooool3o`0000?ooooo0_l0000<ooooo`03o`000?oooooooooo01Sooooo
0_l0002Oooooo`00VOooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00YOooool2o`0000Gooooo0_l0002jooooo`00[?ooool2o`000;[ooooo002Aooooo`;o
00006Oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool0097ooooo0_l0000Iooooo`03o`00
0?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool3o`0001oooooo0_l0002Hooooo`00QOooool2
o`0002Gooooo00?o0000ooooooooool07oooool2o`0009Sooooo0025ooooo`;o00000oooool2o`00
023ooooo00?o0000ooooooooool0^Oooool008[ooooo0_l00002ooooo`;o00007?ooool00ol0003o
ooooooooo`2iooooo`00S_ooool2o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o0000/Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0002aoooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:_ooooo1?l00003ooooo`;o0000
]?ooool009cooooo0_l0000=ooooo`;o00001Oooool2o`000;Cooooo002Looooo`;o00003_ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:co
oooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l0002Pooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo0ol000000olb<S;o
gMgMooooo`04ooooo`03o`000?oooooooooo00;o00005Oooool2o`000:3ooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01?ooool2o`000003
oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool00_l0002gooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROooool01Ol0003ooooo
oooooooooooo000000cooooo0_l000000omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool008Wooooo00Go410@oooooooo
oooooooooa0@400<ooooo`;o000000?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07oooo
o`;o00004oooool3o`0000gooooo0_l0002Eooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo0_l00007
ooooo`;o00002_ooool3o`000:Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0
003oooooooooo`0Aooooo`;o0000Y_ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo017o
oooo0_l0002Vooooo`00WOooool2o`0000?ooooo0_l00003ooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00X_ooool4o`000003ooooool0003o000000?ooooo0ol0000?ooooo`;o0000Z?oo
ool009Kooooo0_l0000<ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`;o00002oooool2
o`000:Sooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:co
oooo00?o0000ooooooooool03?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo00cooooo
0_l0002[ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:[ooooo1Ol0000Hooooo`;o
0000Woooool00:[ooooo0ol0002kooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool00:Cooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`00
00Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00Soooool2o`0001_ooooo0ol0002ioooo
o`00Soooool2o`0001_ooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003ooooo
ooooo`02o`000;Oooooo002/ooooo`?o0000^Oooool00:cooooo0ol0002iooooo`00V_ooool2o`00
013ooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00002?ooool2o`000004ooooool0
003o0000o`000;Wooooo002Oooooo`;o00002?ooool2o`000003ooooool0003ooooo0;[ooooo002D
ooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000oooo
ooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`00
0?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFg
ooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03
o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6305 .37645 Mdot
.53667 .84591 Mdot
.45096 .58342 Mdot
.44649 .28163 Mdot
.48107 .18409 Mdot
.42912 .82495 Mdot
.49613 .35456 Mdot
.49176 .01337 Mdot
.60078 .83188 Mdot
.54852 .37311 Mdot
.50432 .7539 Mdot
.56882 .09892 Mdot
.579 .19892 Mdot
.5408 .6681 Mdot
.53026 .05928 Mdot
.52696 .67454 Mdot
.49424 .84296 Mdot
.59683 .22873 Mdot
.57387 .57681 Mdot
.37908 .63745 Mdot
.56662 .18342 Mdot
.40888 .78887 Mdot
.39223 .68071 Mdot
.61414 .26271 Mdot
.68739 .28962 Mdot
.40412 .61297 Mdot
.43042 .70545 Mdot
.57706 .47948 Mdot
.37639 .40589 Mdot
.5439 .83288 Mdot
.58732 .22056 Mdot
.5796 .86564 Mdot
.3704 .37145 Mdot
.40194 .35364 Mdot
.60427 .35912 Mdot
.59193 .79469 Mdot
.6657 .31741 Mdot
.52047 .26822 Mdot
.38047 .35197 Mdot
.62967 .17783 Mdot
.71223 .34609 Mdot
.52882 .19709 Mdot
.60923 .63895 Mdot
.65034 .51211 Mdot
.60952 .30895 Mdot
.59195 .54302 Mdot
.56515 .52073 Mdot
.65802 .73042 Mdot
.58823 .36235 Mdot
.38761 .71541 Mdot
.66962 .70004 Mdot
.51788 .07985 Mdot
.77991 .54457 Mdot
.62417 .473 Mdot
.62279 .57631 Mdot
.46111 .97414 Mdot
.49619 .01758 Mdot
.48044 .85443 Mdot
.70379 .54443 Mdot
.58632 .25769 Mdot
.58683 .58337 Mdot
.6171 .86466 Mdot
.3789 .3786 Mdot
.48858 .26899 Mdot
.38331 .74755 Mdot
.5093 .95455 Mdot
.52659 .30806 Mdot
.55394 .53062 Mdot
.54796 .3326 Mdot
.63543 .31225 Mdot
.39463 .54351 Mdot
.43956 .40056 Mdot
.54344 .35789 Mdot
.4491 .25308 Mdot
.37856 .38434 Mdot
.50605 .55398 Mdot
.77985 .5451 Mdot
.56573 .66555 Mdot
.47076 .04659 Mdot
.46676 .16624 Mdot
.67107 .48237 Mdot
.5675 .79298 Mdot
.42029 .54714 Mdot
.55751 .24619 Mdot
.37929 .26574 Mdot
.47284 .76909 Mdot
.50499 .21076 Mdot
.53444 .26894 Mdot
.51898 .80757 Mdot
.55294 .54354 Mdot
.68718 .29063 Mdot
.58741 .07639 Mdot
.5424 .57405 Mdot
.5843 .41518 Mdot
.54436 .45555 Mdot
.54927 .0335 Mdot
.54979 .63723 Mdot
.67864 .66797 Mdot
.77626 .58456 Mdot
.47814 .85786 Mdot
.64368 .44491 Mdot
.5675 .71272 Mdot
.53678 .06359 Mdot
.64652 .56727 Mdot
.66946 .44409 Mdot
.42705 .21145 Mdot
.39598 .42272 Mdot
.53972 .70487 Mdot
.54071 .58566 Mdot
.6319 .30525 Mdot
.56599 .53649 Mdot
.44924 .2733 Mdot
.59543 .84185 Mdot
.50495 .92401 Mdot
.53086 .53362 Mdot
.57465 .6389 Mdot
.40611 .87276 Mdot
.47762 .98039 Mdot
.62711 .23947 Mdot
.56663 .18051 Mdot
.6765 .76783 Mdot
.43101 .13339 Mdot
.38737 .27369 Mdot
.63705 .31714 Mdot
.48203 .24828 Mdot
.471 .94399 Mdot
.64026 .58761 Mdot
.44766 .67526 Mdot
.3833 .56009 Mdot
.6472 .52564 Mdot
.61627 .16186 Mdot
.39562 .65477 Mdot
.56801 .75042 Mdot
.44604 .06442 Mdot
.67164 .32626 Mdot
.39221 .7514 Mdot
.53406 .32946 Mdot
.39036 .19652 Mdot
.56255 .09534 Mdot
.50569 .99554 Mdot
.43774 .68765 Mdot
.57545 .44934 Mdot
.48737 .84975 Mdot
.42134 .87818 Mdot
.36639 .52188 Mdot
.36329 .75702 Mdot
.56009 .63511 Mdot
.5637 .34067 Mdot
.68752 .75019 Mdot
.57949 .68202 Mdot
.47931 .20528 Mdot
.62752 .2901 Mdot
.43342 .50625 Mdot
.38961 .44862 Mdot
.6201 .22136 Mdot
.41276 .14682 Mdot
.42845 .93431 Mdot
.65822 .3008 Mdot
.63438 .24633 Mdot
.46202 .1642 Mdot
.49051 .05006 Mdot
.73034 .39728 Mdot
.64766 .66603 Mdot
.62044 .57328 Mdot
.62874 .37587 Mdot
.37134 .64258 Mdot
.67437 .51889 Mdot
.53104 .28963 Mdot
.6444 .26303 Mdot
.47689 .94142 Mdot
.54393 .54524 Mdot
.45782 .21811 Mdot
.47507 .18479 Mdot
.52076 .74442 Mdot
.36719 .47525 Mdot
.38988 .55231 Mdot
.52031 .40243 Mdot
.37606 .42171 Mdot
.6059 .19469 Mdot
.66569 .23766 Mdot
.41434 .49188 Mdot
.7212 .37507 Mdot
.48694 .28645 Mdot
.63025 .77982 Mdot
.42231 .03175 Mdot
.56355 .88992 Mdot
.72097 .36378 Mdot
.58216 .72016 Mdot
.7126 .68203 Mdot
.41718 .86619 Mdot
.42275 .48588 Mdot
.66333 .78865 Mdot
.41809 .08177 Mdot
.7421 .50778 Mdot
.57617 .10917 Mdot
.56722 .34834 Mdot
.69872 .22678 Mdot
.48489 .13619 Mdot
.44364 .35589 Mdot
.45494 .31922 Mdot
.45668 .33049 Mdot
.43168 .25344 Mdot
.72537 .27798 Mdot
.64392 .45516 Mdot
.5275 .60568 Mdot
.39952 .68561 Mdot
.46418 .24807 Mdot
.5388 .51178 Mdot
.46897 .78616 Mdot
.46989 .07763 Mdot
.57179 .64594 Mdot
.67421 .52123 Mdot
.45172 .7459 Mdot
.63283 .39285 Mdot
.58699 .56822 Mdot
.73044 .39965 Mdot
.51756 .35887 Mdot
.51152 .14042 Mdot
.60426 .14118 Mdot
.57859 .62384 Mdot
.70275 .5275 Mdot
.67438 .49072 Mdot
.67073 .53599 Mdot
.52595 .67389 Mdot
.40518 .50774 Mdot
.54992 .82745 Mdot
.54374 .55367 Mdot
.53973 .06963 Mdot
.64828 .82005 Mdot
.55468 .53821 Mdot
.49704 .63166 Mdot
.71443 .25933 Mdot
.60558 .46084 Mdot
.41839 .63838 Mdot
.70043 .71366 Mdot
.49528 .22063 Mdot
.63751 .62148 Mdot
.46045 .08611 Mdot
.64758 .50153 Mdot
.62447 .85314 Mdot
.49381 .87363 Mdot
.65692 .64605 Mdot
.39509 .5574 Mdot
.54834 .90908 Mdot
.52527 .36012 Mdot
.56908 .1466 Mdot
.59737 .60198 Mdot
.39693 .59462 Mdot
.38777 .27965 Mdot
.73981 .47238 Mdot
.53162 .50728 Mdot
.42668 .58371 Mdot
.59375 .18298 Mdot
.41346 .68925 Mdot
.43769 .26152 Mdot
.59495 .69261 Mdot
.4951 .61761 Mdot
.44208 .03377 Mdot
.68662 .64926 Mdot
.60102 .41981 Mdot
.41877 .64156 Mdot
.66578 .58745 Mdot
.50327 .67023 Mdot
.59557 .62362 Mdot
.59413 .27877 Mdot
.56328 .54559 Mdot
.54255 .79587 Mdot
.55264 .85672 Mdot
.40088 .45428 Mdot
.53858 .87891 Mdot
.61239 .63281 Mdot
.55454 .39552 Mdot
.55088 .27016 Mdot
.62069 .22149 Mdot
.42385 .35029 Mdot
.42419 .71415 Mdot
.65725 .72993 Mdot
.46949 .78737 Mdot
.38873 .48737 Mdot
.39847 .2057 Mdot
.42989 .41306 Mdot
.41582 .54431 Mdot
.65244 .28858 Mdot
.51177 .03605 Mdot
.52722 .73461 Mdot
.48417 .67683 Mdot
.44309 .77117 Mdot
.54987 .86661 Mdot
.58408 .41873 Mdot
.6628 .41753 Mdot
.41335 .055 Mdot
.70309 .48813 Mdot
.4846 .0157 Mdot
.69998 .46386 Mdot
.44263 .40769 Mdot
.70539 .49478 Mdot
.70099 .70487 Mdot
.59636 .7941 Mdot
.50979 .03718 Mdot
.35626 .30773 Mdot
.53706 .2414 Mdot
.535 .81513 Mdot
.64461 .56825 Mdot
.56001 .89335 Mdot
.6909 .29443 Mdot
.55799 .59365 Mdot
.66739 .70338 Mdot
.40093 .55256 Mdot
.44719 .65327 Mdot
.43732 .1143 Mdot
.45515 .84399 Mdot
.53028 .13039 Mdot
.70615 .70589 Mdot
.52756 .56556 Mdot
.543 .1862 Mdot
.45677 .14817 Mdot
.3687 .56817 Mdot
.47563 .71416 Mdot
.66826 .24322 Mdot
.73669 .54485 Mdot
.39268 .86581 Mdot
.54356 .39839 Mdot
.38833 .5338 Mdot
.57513 .28103 Mdot
.41244 .14951 Mdot
.41316 .3493 Mdot
.44218 .35979 Mdot
.46397 .33495 Mdot
.39792 .60385 Mdot
.56498 .09151 Mdot
.56594 .14436 Mdot
.54502 .45953 Mdot
.39404 .28909 Mdot
.43027 .58062 Mdot
.45799 .32795 Mdot
.54225 .83908 Mdot
.44351 .85755 Mdot
.61957 .58014 Mdot
.4581 .16806 Mdot
.41275 .35881 Mdot
.78135 .496 Mdot
.4107 .66806 Mdot
.60831 .70588 Mdot
.47796 .26288 Mdot
.38503 .76414 Mdot
.45525 .77093 Mdot
.41326 .85063 Mdot
.53316 .84668 Mdot
.48832 .74235 Mdot
.58442 .43003 Mdot
.50632 .99523 Mdot
.57102 .10073 Mdot
.70664 .50983 Mdot
.56589 .83802 Mdot
.5221 .21356 Mdot
.43905 .17387 Mdot
.48601 .93901 Mdot
.60698 .54632 Mdot
.56492 .09368 Mdot
.36261 .64153 Mdot
.65061 .66785 Mdot
.6043 .1457 Mdot
.67547 .25715 Mdot
.73037 .40529 Mdot
.50703 .37012 Mdot
.59554 .39717 Mdot
.56038 .09323 Mdot
.46617 .0113 Mdot
.5173 .41649 Mdot
.64962 .36125 Mdot
.43372 .77377 Mdot
.38957 .56232 Mdot
.63987 .42007 Mdot
.66577 .7046 Mdot
.64007 .60838 Mdot
.69037 .39454 Mdot
.48975 .05488 Mdot
.40745 .77847 Mdot
.70538 .47154 Mdot
.39332 .69265 Mdot
.65928 .23354 Mdot
.65206 .29052 Mdot
.41085 .23862 Mdot
.45355 .65501 Mdot
.73671 .47331 Mdot
.5232 .8014 Mdot
.45289 .35982 Mdot
.68339 .27042 Mdot
.63964 .32325 Mdot
.44152 .36211 Mdot
.47586 .22649 Mdot
.47734 .83196 Mdot
.41054 .52418 Mdot
.63905 .77103 Mdot
.67366 .56333 Mdot
.67853 .75798 Mdot
.67411 .25326 Mdot
.3967 .57401 Mdot
.77209 .42509 Mdot
.40515 .31936 Mdot
.52531 .73518 Mdot
.45542 .79645 Mdot
.49948 .38306 Mdot
.53407 .05709 Mdot
.55829 .08655 Mdot
.43584 .72624 Mdot
.51665 .67798 Mdot
.41933 .34308 Mdot
.43163 .68872 Mdot
.73321 .60836 Mdot
.5831 .40608 Mdot
.6434 .68158 Mdot
.43347 .66708 Mdot
.48231 .20681 Mdot
.4695 .71225 Mdot
.55336 .30817 Mdot
.39522 .50398 Mdot
.4234 .31981 Mdot
.51439 .65738 Mdot
.68274 .75751 Mdot
.38909 .20341 Mdot
.48421 .38274 Mdot
.61591 .40444 Mdot
.39578 .42774 Mdot
.40668 .26501 Mdot
.41003 .65926 Mdot
.49406 .2183 Mdot
.73925 .50585 Mdot
.62305 .11578 Mdot
.63304 .63686 Mdot
.64838 .87976 Mdot
.64735 .56843 Mdot
.46447 .72596 Mdot
.59168 .84371 Mdot
.57245 .10815 Mdot
.49989 .76169 Mdot
.54428 .82878 Mdot
.78133 .50774 Mdot
.5054 .70749 Mdot
.43274 .56803 Mdot
.49717 .78886 Mdot
.66554 .59266 Mdot
.43703 .21066 Mdot
.6547 .15978 Mdot
.52411 .38559 Mdot
.60607 .37069 Mdot
.53497 .20584 Mdot
.53572 .39762 Mdot
.53083 .51227 Mdot
.44812 .25363 Mdot
.48923 .01208 Mdot
.50128 .67859 Mdot
.45029 .0599 Mdot
.57861 .77646 Mdot
.58692 .2611 Mdot
.50473 .92308 Mdot
.64561 .35076 Mdot
.41227 .72109 Mdot
.49575 .24168 Mdot
.57626 .10496 Mdot
.74096 .48057 Mdot
.56379 .53323 Mdot
.70608 .50426 Mdot
.40194 .56375 Mdot
.55414 .73598 Mdot
.41575 .85928 Mdot
.64587 .46082 Mdot
.56837 .6071 Mdot
.58672 .4455 Mdot
.40617 .31519 Mdot
.59214 .90114 Mdot
.58887 .69977 Mdot
.507 .54792 Mdot
.62247 .56197 Mdot
.49274 .17211 Mdot
.50796 .37232 Mdot
.54557 .41122 Mdot
.62364 .46337 Mdot
.56593 .75631 Mdot
.51129 .36308 Mdot
.45511 .81942 Mdot
.50347 .96103 Mdot
.47886 .18274 Mdot
.56585 .22436 Mdot
.57452 .43618 Mdot
.57022 .42576 Mdot
.52176 .56012 Mdot
.55558 .99146 Mdot
.51808 .58533 Mdot
.53962 .84226 Mdot
.7015 .50375 Mdot
.63847 .69446 Mdot
.56087 .37476 Mdot
.37865 .62377 Mdot
.63585 .18862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00002
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool0^_ooool00:3ooooo0_l00000
1?mEEEGoIVIVo`000?ooool5o`000003ooooool0003ooooo0;[ooooo002Vooooo`;o00000_ooool3
o`000;_ooooo002Zooooo`?o0000^oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l00004
ooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool009Sooooo0_l0000Boooo
o`03o`000?oooooooooo00;o00002oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00;o
0000]oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oo
oooooooo0;Wooooo002Rooooo`;o00001?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
0:Sooooo0_l00002ooooo`?o0000^Oooool008oooooo0_l0000Gooooo`;o00000_ooool00ol0003o
ooooooooo`2iooooo`00Soooool2o`0001Oooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo
0_l0002_ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool01oooool3o`000:oooooo002J
ooooo`?o00003oooool00ol0003oooooooooo`07ooooo`Co0000[_ooool009[ooooo0_l0000@oooo
o`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o
0000[Oooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`?o00006Ooo
ool2o`0009kooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`;o00005Oooool2
o`0009kooooo002Aooooo`;o00003oooool2o`0000Sooooo00?o0000ooooooooool00_ooool2o`00
0;Gooooo002Aooooo`;o00003?ooool2o`0000_ooooo00?o0000ooooooooool0^Oooool009oooooo
0_l0000;ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003ooooooooo
o`0@ooooo`Co0000YOooool00:cooooo00?o0000ooooooooool04?ooool4o`000:Gooooo002/oooo
o`03o`000?oooooooooo013ooooo1?l0002Uooooo`00[?ooool3o`0001?ooooo0ol0002Sooooo`00
[?ooool00ol0003oooooooooo`0Cooooo`?o0000Xoooool00:cooooo00?o0000ooooooooool05_oo
ool2o`000:7ooooo002/ooooo`03o`000?oooooooooo01Cooooo1?l0002Qooooo`00[?ooool00ol0
003oooooooooo`0Dooooo`Co0000XOooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo02Go
oooo0_l0002Booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`;o
00000_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Uooooo`;o0000T_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`07
ooooo`;o0000/?ooool008Wooooo00Go410@oooooooooooooooooa0@4007ooooo`;o00001Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2
o`000;3ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000;ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
00000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000
ooooooooool00_l0000Mooooo`;o0000V?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo
01;ooooo0ol0000:ooooo`;o0000V?ooool008oooooo0_l0000<ooooo`;o00003Oooool00ol0003o
ooooooooo`0Booooo`?o00002_ooool2o`0009Sooooo002?ooooo`;o00003?ooool2o`0000gooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o00002oooool2o`0008Oooooo002Oooooo`;o
00002oooool00ol0003oooooooooo`0Sooooo`;o00002oooool2o`0008Oooooo002Nooooo`Go0000
2Oooool00ol0003oooooooooo`2iooooo`00W_ooool2o`000003ooooool0003o000000Wooooo00?o
0000ooooooooool0^Oooool009Oooooo0_l0000@ooooo`;o000000?oooooo`000?ooool0^_ooool0
09Oooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o0000^Oooool00:cooooo00?o0000oooo
ooooool09oooool2o`00093ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`;o
00001oooool2o`0000Wooooo0_l0002@ooooo`00Xoooool4o`0000Gooooo00?o0000ooooooooool0
2oooool2o`0000Kooooo0_l00007ooooo`;o0000Voooool00:?ooooo1?l00005ooooo`03o`000?oo
oooooooo00_ooooo0_l0000Looooo`;o0000S_ooool00:cooooo00?o0000ooooooooool0:Oooool2
o`0008kooooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00Qoooool2o`0002?o
oooo00?o0000ooooooooool01_ooool2o`0001Sooooo0_l0002Gooooo`00Qoooool2o`0002?ooooo
0ol00006ooooo`;o00003oooool2o`000:3ooooo0027ooooo`;o00008oooool00ol0003ooooooooo
o`0Gooooo`;o0000X?ooool008Oooooo0_l000000ooooooo0000o`00000Iooooo`?o00001?ooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool008[ooooo0_l0000;ooooo`;o00003?ooool3o`00
00Cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Cooooo`;o00000_ooool2o`0001?o
oooo0ol00004ooooo`;o0000/oooool009?ooooo0_l0000Gooooo`?o00001?ooool2o`000;?ooooo
002Nooooo`;o00002_ooool3o`000;_ooooo002Nooooo`;o00002_ooool3o`0001_ooooo0_l00009
ooooo`;o0000Toooool00:[ooooo1Ol0000Booooo`;o00001Oooool2o`0000Wooooo0_l0002Coooo
o`00Y?ooool2o`0000Kooooo00?o0000ooooooooool04_ooool2o`0000Wooooo0_l0000Oooooo`;o
0000NOooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo01gooooo0_l0000Oooooo`;o0000
NOooool00:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002/ooooo`03o`000?oooooo
oooo037ooooo1?l00024ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool09oooool2o`00
00[ooooo0_l00024ooooo`00S_ooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`?o00002oooool2o`0001cooooo0_l0
000;ooooo`;o0000Poooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`02ooooo`?o00002oooool2o`0000Gooooo0_l0000Gooooo`;o00002Ooo
ool2o`0008?ooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00[ooooo0_l0
0004ooooo`;o00001?ooool00ol0003oooooooooo`0@ooooo`;o00005oooool2o`0008kooooo002A
ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000?ooooo0_l00003ooooo`03ogMgMol0
003o000000Cooooo0ol0002iooooo`00TOooool01?l0003oooooooooooooool2o`0000?ooooo0ol0
0005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0fooooo`;o0000
POooool0097ooooo00Co410@oooooooooooooooo0_l00003ooooo`;o00001_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Wooooo0_l0000Kooooo`;o0000POooool0097ooooo00Ko
MgMgoiRHV?ooooooV9RHogMgMoooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Iooooo`;o00006oooool2o`0000_ooooo0_l0001dooooo`00SOooool2o`0000;ooooo
00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000Wooooo1?l00006ooooo`03o`000?oooooooooo
01Wooooo0_l00007ooooo`;o00002?ooool2o`0001Gooooo0_l0001dooooo`00Q?ooool2o`0000Oo
oooo0_l0000Eooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o00007Oooool2o`0000So
oooo0_l0002;ooooo`00Q?ooool2o`0002;ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`;o00000oooool2o`0002[ooooo0_l0001nooooo`00Q_ooool2o`0001?ooooo0_l0
000;ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0002[ooooo0_l0
001nooooo`00Q_ooool2o`0001?ooooo0_l0000?ooooo`?o0000^Oooool008Oooooo0_l0000Soooo
o`03o`000?oooooooooo01cooooo0_l0000Yooooo`;o0000L?ooool008Oooooo0_l0000Aooooo`;o
00004?ooool00ol0003oooooooooo`0Eooooo`;o00001Oooool2o`0002Wooooo0_l0001`ooooo`00
V_ooool2o`0000_ooooo0_l00003ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00ROoo
ool2o`0001cooooo0_l00003ooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00ROooool2
o`00027ooooo00?o0000ooooooooool01oooool2o`0001kooooo0_l00006ooooo`;o00002Oooool2
o`0007gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Nooooo`;o00001_ooool2o`00
00Wooooo1?l0001kooooo`00[?ooool00ol0003oooooooooo`0looooo`;o0000Noooool00:cooooo
0ol0000aooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002/
ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00O?ooool2o`0002kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l0000Aooooo`;o00001Oooool2o`0008oooooo001looooo`;o
0000;_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`00017ooooo0_l00006ooooo`;o
0000S_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00S?oo
ool3o`0000kooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo0_l00007ooooo`;o0000Q?oo
ool008cooooo0_l00004ooooo`;o00002Oooool2o`0000gooooo00?o0000ooooooooool0:_ooool2
o`0000Oooooo0_l00024ooooo`00T_ooool2o`0001Sooooo0ol0000[ooooo`;o0000S?ooool009ko
oooo0_l0000<ooooo`03o`000?oooooooooo02_ooooo0_l00008ooooo`;o0000P_ooool009gooooo
0ol0000<ooooo`03o`000?oooooooooo00Sooooo0_l0000[ooooo`;o0000P_ooool009gooooo0_l0
000=ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o0000Zoooool00:3ooooo0_l0000:
ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00X?ooool2o`0000[ooooo00?o0000oooo
ooooool04_ooool2o`000:Gooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Booooo`;o
0000YOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00Sooo
ool2o`0001_ooooo00?o0000ooooooooool04oooool2o`0002kooooo0_l0001dooooo`00Q?ooool2
o`0000Wooooo0_l000000ooooooo0000o`00000Hooooo`?o00004oooool2o`0001Sooooo0_l0002:
ooooo`00Q?ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000oooooo0ol0000_oooo
o`;o0000R_ooool008_ooooo0_l00002ooooo`;o00002?ooool2o`0000oooooo0ol00004ooooo`;o
00001oooool2o`0001;ooooo0_l0002Hooooo`00Soooool2o`0000Oooooo0_l00002ooooo`;o0000
3_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool2o`0001;ooooo
0_l0000=ooooo`;o0000ROooool009Sooooo0_l00002ooooo`;o00003_ooool00ol0003ooooooooo
o`02o`0000?ooooo0_l0000Cooooo`;o00004_ooool2o`0001Kooooo0_l0001aooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_l0000Hooooo`;o0000:_ooool2o`00077ooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000ooooool0003o00007oooool2o`00
09Oooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0000cooooo0_l0000A
ooooo`;o0000Uoooool0087ooooo0_l00006ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo1?l0000<ooooo`;o00000_ooool2
o`0001Cooooo0ol0000Looooo`;o0000LOooool008Cooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0Aooooo`;o00005?ooool3o`0001cooooo0_l0001aooooo`00Q?ooool2
o`0000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0_l00003ooooo`;o0000^oooool008?ooooo0_l00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00Co0000oooooooo
oooooooo0_l00003ooooo`;o00001oooool2o`000;;ooooo0023ooooo`;o00001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0:?ooool2o`00017ooooo0_l0001looooo`00[?ooool00ol0003ooooo
ooooo`08ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0000:ooooo`;o0000
4Oooool2o`0000cooooo0_l0001^ooooo`00V?ooool2o`0001;ooooo0ol00008ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000_ooooo0_l0000[ooooo`;o0000K_ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00?ooooo0_l0000Nooooo`;o00009?ooool2o`0006kooooo0023oooo
o`;o00009oooool00ol0003oooooooooo`03ooooo`;o00004oooool2o`0000Wooooo0_l0000Toooo
o`;o0000K_ooool008?ooooo0_l0000Dooooo`;o00004Oooool00ol0003oooooooooo`0Hooooo`;o
0000;oooool2o`0006kooooo002Dooooo`;o00000oooool2o`00017ooooo00?o0000ooooooooool0
3?ooool2o`000:_ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`;o00002?oo
ool2o`0000[ooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00005?ooool2
o`0001Sooooo0_l00025ooooo`00Poooool2o`0000Cooooo0_l0000Qooooo`03o`000?oooooooooo
01Sooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l00025ooooo`00Poooool2o`0000Co
oooo0_l0000Qooooo`?o00005?ooool2o`0000Sooooo0_l0000;ooooo`;o0000:Oooool2o`00067o
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Dooooo`;o0000@?ooool2o`00067ooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:cooooo00?o0000
ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Roooo
o`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool06Oooool2o`00017ooooo0_l00007ooooo`;o0000P_oo
ool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01Gooooo0_l00002ooooo`;o00004Oooool2
o`0000Oooooo0_l00022ooooo`00Qoooool2o`0002?ooooo0ol0000Eooooo`;o0000X_ooool008_o
oooo0_l0000Oooooo`03o`000?oooooooooo00_ooooo0_l0000Oooooo`;o0000Roooool008_ooooo
0_l0000Oooooo`03o`000?oooooooooo00_ooooo0_l0000Oooooo`;o0000Roooool000Wooooo1?l0
00000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Fooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo1ol00002ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooooooo
ool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0;ooooo`;o00002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00;ooooo0_l000001?oooooo8B4Qob4Q8Oooool2o`000006oooooonHV9So8B4Qonk^
k_ooooooA4A40_l00005ooooo`03ogMgMolb<S;ooooo00Sooooo0_l00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
6Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooo
oooooooooooooa0@4008ooooo`;o00000_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00Oooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000Wooooo0_l00003ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00:ooooo`;o00000oooool01_l0003ooooooooooooooooo
0000ooooo`?o00002?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Joooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00?ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool3o`0001Sooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`06oa0@4?ooooooooooooooool@
413ooooo0ol00008ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Kooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5oooool00ol0003oooooooooo`0Fooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool6o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
ooooo`;o00002?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool009;ooooo0_l0000Hooooo`03o`000?oooooo
oooo03Gooooo0_l0000Eooooo`;o0000Joooool008Oooooo0_l00009ooooo`;o00006?ooool00ol0
003oooooooooo`10ooooo`;o0000Moooool008Oooooo0_l00006ooooo`;o00006oooool00ol0003o
ooooooooo`0fooooo`;o00002?ooool2o`0006cooooo0_l00002ooooo`;o00001Oooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo03Kooooo0_l00008ooooo`;o0000K?ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo043ooooo0_l0000Gooooo`;o
0000E?ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko
8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000Oo
oooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool00oooool2o`0000_ooooo0_l0000Dooooo`03o`000?oooooooooo00Oo
oooo0_l0000Nooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`Co00002Oooool2o`0000;o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`;o00001Oooool008cooooo0_l00008ooooo`;o00005?ooool00ol0003ooooo
ooooo`07ooooo`;o0000>?ooool2o`0000Wooooo0_l0000;ooooo`;o0000G_ooool008cooooo0_l0
000Nooooo`03o`000?oooooooooo00Oooooo1?l0000Sooooo`;o00004Oooool2o`0000Wooooo0_l0
000;ooooo`;o0000G_ooool00:cooooo00?o0000ooooooooool01oooool4o`0002?ooooo0_l00029
ooooo`00[?ooool00ol0003oooooooooo`0fooooo`;o0000POooool007oooooo0_l0000[ooooo`03
o`000?oooooooooo01;ooooo0_l0000Rooooo`;o0000POooool007oooooo0_l0000=ooooo`;o0000
7?ooool3o`0001;ooooo0_l0000Iooooo`;o00001oooool2o`00087ooooo002>ooooo`;o00007?oo
ool00ol0003oooooooooo`0]ooooo`;o00004?ooool2o`0007Sooooo002/ooooo`03o`000?oooooo
oooo00kooooo0_l0000_ooooo`;o0000N?ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo
00Oooooo0_l00005ooooo`;o00000_ooool2o`000:Gooooo0027ooooo`;o00008oooool00ol0003o
ooooooooo`07ooooo`;o00002Oooool2o`00027ooooo0_l00022ooooo`00[?ooool00ol0003ooooo
ooooo`0?ooooo`;o000000?oooooo`000?l000008Oooool2o`0008;ooooo0029ooooo`;o00008Ooo
ool00ol0003oooooooooo`0>ooooo`?o00002_ooool2o`0009cooooo0029ooooo`;o00001Oooool2
o`0001[ooooo00?o0000ooooooooool02oooool2o`000004ooooool0003o0000ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000Nooooo`;o00002Oooool2o`0000cooooo0_l0001Nooooo`00T?ooool3
o`0001Wooooo00Co0000ooooool0003o00002_ooool2o`0000Cooooo0_l0000=ooooo`;o00007_oo
ool2o`0000Wooooo0_l0000<ooooo`;o0000G_ooool008Oooooo0_l00002ooooo`;o00001?ooool2
o`0001Wooooo1?l0002hooooo`00Qoooool2o`0000;ooooo0_l0000Oooooo`04o`000?oooooo0000
o`0000[ooooo0_l0002/ooooo`00ROooool2o`00027ooooo00Co0000ooooool0003o00002_ooool2
o`000:cooooo0025ooooo`;o00000_ooool2o`00027ooooo00?o0000ooooooooool01?ooool2o`00
01oooooo0_l0002Booooo`00QOooool4o`0000;ooooo0_l0000Oooooo`03o`000?oooooooooo00Co
oooo0_l0000Oooooo`;o00003oooool2o`00087ooooo0027ooooo`;o00000_ooool2o`0000Sooooo
0_l0000Eooooo`03o`000?oooooooooo00Kooooo0_l0000Uooooo`;o00001oooool2o`00087ooooo
0020ooooo`;o00004oooool2o`0001Gooooo00?o0000ooooooooool01_ooool2o`00017ooooo0_l0
000Aooooo`?o0000R_ooool0083ooooo0_l00007ooooo`;o00008Oooool00ol0003oooooooooo`0;
ooooo`;o00003?ooool2o`0000Wooooo0_l00006ooooo`?o0000R_ooool008Wooooo0_l0000Qoooo
o`?o00002oooool2o`0000Sooooo0_l0000=ooooo`?o0000T_ooool00:cooooo00?o0000oooooooo
ool05Oooool2o`0000gooooo0ol0002Booooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
9?ooool2o`0009?ooooo002Cooooo`Co00001?ooool2o`0000oooooo00?o0000ooooooooool00ooo
ool2o`0000Gooooo0_l0000=ooooo`;o0000?Oooool2o`0005oooooo002Cooooo`;o00001_ooool2
o`0000oooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0000=ooooo`;o00004?ooool2
o`0000Kooooo0_l0000Sooooo`;o0000Goooool00:cooooo00?o0000ooooooooool0:oooool2o`00
00Kooooo0_l00024ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool04?ooool2o`00027o
oooo0_l00024ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool04?ooool2o`00027ooooo
0_l00024ooooo`00[?ooool3o`000;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0M
ooooo`;o0000V_ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00Kooooo0_l0000;oooo
o`;o00002?ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o
00005_ooool2o`0001gooooo0_l0001]ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
:oooool2o`0001gooooo0_l0001]ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@03ooooo`?o0000^oooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool00_ooool3o`0002cooooo0_l0002=ooooo`00Q?ooool2o`0000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001Oo
oooo0_l00003ooooo`;o00003?ooool2o`0008gooooo0024ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01Oooooo0_l00003ooooo`;o0000Voooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`;o0000^oooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool2o`0002Cooooo0_l0002Eooooo`00Q?ooool2o`0000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00000@
ooooo`;o00001?ooool2o`0008oooooo0024ooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo0_l00006ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool03Oooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00001Ooo
ool2o`0008oooooo001nooooo`;o000000?oooooo`000?l000003_ooool2o`0001Wooooo00?o0000
ooooooooool05Oooool2o`0000[ooooo0_l0002Fooooo`00O_ooool2o`000003ooooool0003o0000
00kooooo0_l0000Iooooo`03o`000?oooooooooo01Cooooo0_l0000Jooooo`;o0000Qoooool00:co
oooo00?o0000ooooooooool05?ooool2o`0001[ooooo0_l00008ooooo`;o0000OOooool00:cooooo
0ol0000jooooo`;o0000OOooool008Wooooo0_l0000?ooooo`Co00003_ooool00ol0003ooooooooo
o`2iooooo`00ROooool2o`0000oooooo1?l0000>ooooo`04o`000?ooooooooooooooo`;o0000]_oo
ool008kooooo0_l0000Looooo`04o`000?ooooooooooooooo`;o0000]_ooool008kooooo0_l0000L
ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00001_ooool2o`0001Cooooo00?o0000oooo
ooooool02_ooool2o`0000Kooooo0_l0000Iooooo`?o00002?ooool2o`0007oooooo002>ooooo`;o
00001_ooool2o`0001Cooooo0ol0000:ooooo`;o00001_ooool2o`0001Wooooo0ol00008ooooo`;o
0000Ooooool00:cooooo0ol00005ooooo`;o0000/_ooool009[ooooo0_l0000:ooooo`;o00001?oo
ool3o`0000Gooooo0_l0002booooo`00V_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2
o`000003ooooool0003o00000;;ooooo0028ooooo`;o00008_ooool2o`0000?ooooo0_l0000Coooo
o`;o00004oooool2o`0001Gooooo0_l0001dooooo`00R?ooool4o`00023ooooo00?o0000oooooooo
ool05oooool2o`0001?ooooo0_l0000Eooooo`;o0000M?ooool008[ooooo0_l00003ooooo`;o0000
1?ooool4o`0001?ooooo00?o0000ooooooooool0^Oooool008oooooo0_l00004ooooo`Co00004ooo
ool00ol0003oooooooooo`2iooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool07?ooool2
o`0000cooooo0_l0002=ooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool07?ooool2o`00
00cooooo0_l0002=ooooo`00[?ooool3o`0001[ooooo0_l0000Iooooo`;o0000P_ooool00:cooooo
00?o0000ooooooooool06_ooool2o`0001Sooooo0ol00022ooooo`00UOooool2o`0001Gooooo0ol0
000:ooooo`;o00005?ooool2o`00017ooooo0ol00009ooooo`Co0000M_ooool009Gooooo0_l0000E
ooooo`?o00002_ooool2o`0001Cooooo0_l0000Aooooo`;o00002_ooool4o`0007Kooooo002Qoooo
o`;o00002Oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008Kooooo0_l0000;ooooo`;o
00003?ooool2o`000003ooooool0003o000000Kooooo00?o0000ooooooooool04oooool2o`0002[o
oooo0_l0001hooooo`00Q_ooool2o`0000_ooooo0_l0000?ooooo`;o00001_ooool00ol0003ooooo
ooooo`0oooooo`;o0000N?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00Soooool2o`0001_ooooo0ol0000Hooooo`;o0000Woooool009Kooooo0_l00008oooo
o`;o00002_ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000Sooooo0_l0000:ooooo`03
o`000?oooooooooo033ooooo0ol00026ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
:?ooool3o`0008Kooooo002/ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`;o0000ZOoo
ool00:cooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l0002Yooooo`00TOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo
0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00olQ8B7o0000o`000007ooooo`03ogMgMolb<S;ooooo00;o00000_ooool00ol0003ooooo
ooooo`03ooooo`;o0000]?ooool008Gooooo0_l0000:ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool008Gooooo0_l000000ooooooo0000o`000007ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`?o00004oooool2o`0002Gooooo0_l0001mooooo`00R?oo
ool2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool3o`0001?ooooo0_l0000Uooooo`;o0000OOooool007kooooo0_l0000Aooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`?o00004_ooool2o`0002?o
oooo1?l0001nooooo`00O_ooool2o`00017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo0_l0000Cooooo`;o00008oooool4o`0007kooooo0026ooooo`;o0000
2Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000^_ooool008Kooooo
0_l0000Tooooo`03o`000?oooooooooo03Oooooo0_l00020ooooo`00WOooool2o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo02[ooooo0_l0000;ooooo`;o0000P?ooool009Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0:_ooool2
o`0008gooooo002Fooooo`;o000000?oooooo`000?l000004Oooool3o`0001Oooooo0_l0002Poooo
o`00SOooool2o`0001gooooo00?o0000ooooooooool05oooool2o`0000oooooo0_l0002?ooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002Qooooo`;o00002Ooo
ool00ol0003oooooooooo`2iooooo`00SOooool2o`0001;ooooo0_l00008ooooo`;o0000=?ooool2
o`0008Gooooo002=ooooo`;o00004_ooool2o`0000Sooooo0_l0000dooooo`;o0000QOooool00:co
oooo00?o0000ooooooooool04oooool2o`0000Kooooo0ol0002Kooooo`00WOooool2o`0000gooooo
00?o0000ooooooooool02oooool2o`0000Kooooo0_l00006ooooo`?o0000Voooool009gooooo0_l0
000=ooooo`?o00001?ooool2o`0000Gooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`04
ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?oo
ool00ol0003oooooooooo`08ooooo`;o0000[oooool009gooooo0_l0000=ooooo`03o`000?oooooo
oooo00Sooooo0_l0002_ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0;_ooool2o`00
08Wooooo002Dooooo`;o00005_ooool3o`0002kooooo0_l00029ooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00_ooooo1?l0
002Zooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`00017ooooo0_l0002I
ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`00017ooooo0_l0002Ioooo
o`00[?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool2o`000:Gooooo002Zooooo`?o0000
3?ooool3o`0000Gooooo0_l00007ooooo`?o0000Voooool009gooooo0_l0000;ooooo`?o00002_oo
ool4o`0000oooooo0ol0002Kooooo`00WOooool2o`0000Sooooo0_l00003ooooo`03o`000?oooooo
oooo00Sooooo0ol0002^ooooo`00Soooool2o`0001Kooooo0_l00003ooooo`?o0000^Oooool008oo
oooo0_l0000Dooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`;o0000TOooool009Wooooo
0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`0>ooooo`;o00005_ooool2o`00097ooooo
002@ooooo`;o00001oooool2o`0000Wooooo0_l00006ooooo`03o`000?oooooooooo00kooooo0_l0
002Yooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool08oooool2o`0009Cooooo0028oooo
o`;o000000Co<S8bo`000?lb<S;ok^k^0_ooool2o`000003oooooolQ8B7o8B4Q00Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Ooo
ool2o`0000Sooooo0_l0000:ooooo`;o0000U?ooool008Sooooo0_l000001?nHV9SooooooiRHV?mg
MgL2ooooo`;o000000?oooooob4Q8OlQ8B401_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l0002Pooooo`00ROooool0
1?l@413oooooooooooooool2o`0000cooooo00?oZJVYoeEEEOooool02?ooool01?l0003ooooooooo
ooooool3o`000;_ooooo0029ooooo`04o`000?ooooooooooooooo`;o00003Oooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00;ooooo1Ol0002iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000Cooooo0_l00008ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00Wooooo0_l0000Sooooo`;o0000ROooool008Wooooo
00Go410@oooooooooooooooooa0@4004ooooo`;o00002?ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`0002?ooooo0_l00029ooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo013ooooo
1?l0002Uooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo0ol0000K
ooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?oo
ool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Doooo
o`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool0^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00X_ooool4o`0000Kooooo00?o0000
ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003ooooooooo
o`02o`000;Oooooo002/ooooo`?o0000^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Woooool2o`0000_ooooo0ol0002iooooo`00Woooool2o`0000_ooooo00?o0000oooo
ooooool0^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o0000
1_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:;ooooo1?l000000ol@413oooooooooo`03oooo
o`04o`000?oooooo0000o`0000kooooo0_l0002Xooooo`00Y?ooool00ol0003oooooooooo`05oooo
o`Co0000^?ooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04
oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo
00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03
o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0
]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000
ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "A series of filamentary structures form and then are stretched out to such \
a fine scale that they can no longer be discerned. Although ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " continues to evolve on finer and finer scales as the filaments are \
stretched and wrapped up, on larger scales ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " becomes time-independent. That is, the number of particles in any finite \
phase-space element ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", namely ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", eventually becomes independent of time.  The time-independent solution \
",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can be found by dropping the  partial time derivative in Eq.  ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text",
  CellTags->"i:9"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(p\/m\) \[PartialD]f\_eq\/\[PartialD]x - \(\
\[PartialD]V\/\[PartialD]x\) \[PartialD]f\_eq\/\[PartialD]p = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.23)"],

Cell[TextData[{
  "Here we have used the fact that the force ",
  Cell[BoxData[
      \(TraditionalForm\`F(x)\)]],
  " in this example is derivable from a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " via ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(-\[PartialD]V\)/\[PartialD]x\)]],
  ". The solution to Eq. ",
  ButtonBox["(7.1.23)",
    ButtonData:>{"Chapter7.nb", "(7.1.23)"},
    ButtonStyle->"Hyperlink"],
  "   can be found by making a change of variables from ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\((E, p)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`E\  = \ p\^2/\((2\ m)\) + V(x)\)]],
  " is the energy.  In these variables, ",
  Cell[BoxData[
      \(TraditionalForm\`f\_eq = \(f\_eq\)(E, p)\)]],
  ", and it is left as  an exercise in partial derivatives to show that Eq. \
",
  ButtonBox["(7.1.23)",
    ButtonData:>{"Chapter7.nb", "(7.1.23)"},
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(-\(\[PartialD]V\/\[PartialD]x\)\) \[PartialD]f\_eq\/\
\[PartialD]p\), 
          SubscriptBox[
            StyleBox["|",
              FontSize->14], "E"]}], "=", "0."}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(7.1.24)"],

Cell["This equation can be integrated, yielding ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f\_eq = \ \(f\_eq\)(E)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.25)"],

Cell[TextData[{
  "The equilibrium is a function only of the energy ",
  Cell[BoxData[
      \(TraditionalForm\`E = p\^2/\((2\ m)\) + V(x)\)]],
  ". This can be easily understood intuitively: the phase mixing of the \
particle distribution eventually spreads particles out evenly along each \
energy surface, so that the particle density becomes constant on each \
surface, but may vary from surface to surface. "
}], "Text"],

Cell[TextData[{
  "\tThe functional form of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  " is determined by the initial conditions. For an initial distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x, p)\)]],
  ", energy conservation implies that the number of particles between the \
energy surfaces ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E + \[DifferentialD]E\)]],
  " remains constant over time. This number can be written either as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(E)\)\ \[DifferentialD]E\)]],
  " or as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\[DifferentialD]x \[DifferentialD]p\ \
\(\(f\_o\)(x, p)\)\)]],
  ", where the area integral is over the infinitesimal area between energy \
surfaces ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E + \[DifferentialD]E\)]],
  "  [",
  Cell[BoxData[
      \(TraditionalForm\`E \[LessEqual] H(x, p) \[LessEqual] \ 
        E + \ \[DifferentialD]E\)]],
  "], and where ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, p) = p\^2/\((2\ m)\) + V(x)\)]],
  " is the Hamiltonian. Therefore, the equilibrium is determined by the \
equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(
            E)\)\ \[DifferentialD]E = \(\[Integral]\[DifferentialD]x \
\[DifferentialD]p\)\+\(E \[LessEqual] \ H(x, p)\  \[LessEqual] \ E + \ \
\[DifferentialD]E\)\ \(\(f\_o\)(x, p)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.26)"],

Cell[TextData[{
  "\tEven though the area integral is an infinitessimal, it is nontrivial to \
evaluate because the distance between energy surfaces varies from place to \
place along the surfaces. (The integral can be evaluated using action-angle \
variables, but we will not involve ourselves with the canonical \
transformations required to define these variables.) On the other hand, the \
integral can be performed numerically if we convert ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]E\)]],
  " to a finite quantity ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe first define the initial particle density. Since there are ",
  Cell[BoxData[
      \(TraditionalForm\`M = 500\)]],
  " particles spread uniformly over a region ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < p < 1/2\)]],
  ", we define the initial distribution:"
}], "Text"],

Cell[BoxData[{
    \(\(f0[x_, p_]\  := \ 
        4\ M /; \ 0 < x < 1/2\  && \ 0 < p < 1/2;\)\), "\n", 
    \(f0[x_, p_]\  := \ 
      0\  /; \ Not[0 < x < 1/2\  && \ 0 < p < 1/2]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.8"],

Cell[TextData[{
  "With this definition, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\[DifferentialD]x \[DifferentialD]p\ \
\(\(f\_o\)(x, p)\) = M\)]],
  ". Next, we define the potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " for this problem, and the Hamiltonian function ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, p)\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(m = \(g = 1\); k = 20;\), "\n", 
    \(\(V[x_]\  = m\ g\ x\  + \ k\ x\^2/2\ \ UnitStep[\(-x\)]\ ;\)\), "\n", 
    \(\(H[x_, p_]\  = \ p\^2/\((2\ m)\)\  + \ V[x];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.9"],

Cell[TextData[{
  "Finally, we integrate over the area between two constant energy surfaces \
separated by ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " using ",
  StyleBox["Boole",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " notation:"
}], "Text"],

Cell[BoxData[{
    \(\(\(<< Calculus`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(feq[e_]\  := \ 
        NIntegrate[
            Boole[e < H[x, p] < e + \[CapitalDelta]E]\ f0[x, p], {x, 0, 
              1/2}, {p, 0, 1/2}]/\[CapitalDelta]E;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta]E\  = \ 0.001;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.10"],

Cell[TextData[{
  "A plot of the equilibrium energy distribution is shown in Cell ",
  ButtonBox["7.11",
    ButtonData:>"Cell 7.11",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{e, feq[e]}, {e, \(- .2\), 1,  .025}], 
        PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {"\<E\>", \*"\"\<\!\(f\_eq\)(E)\>\""}];\)\)], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 7.11"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.793651 0.0147151 0.000588604 [
[.02381 .00222 -12 -9 ]
[.02381 .00222 12 0 ]
[.34127 .00222 -9 -9 ]
[.34127 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -9 -9 ]
[.65873 .00222 9 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.17004 .13244 -18 -4.5 ]
[.17004 .13244 0 4.5 ]
[.17004 .25016 -18 -4.5 ]
[.17004 .25016 0 4.5 ]
[.17004 .36788 -18 -4.5 ]
[.17004 .36788 0 4.5 ]
[.17004 .4856 -18 -4.5 ]
[.17004 .4856 0 4.5 ]
[.17004 .60332 -24 -4.5 ]
[.17004 .60332 0 4.5 ]
[.18254 .64303 -18.7188 0 ]
[.18254 .64303 18.7188 12.9375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-0.2)] .02381 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(0.2)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.4)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(0.6)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(0.8)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.06349 .01472 m
.06349 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.22222 .01472 m
.22222 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30159 .01472 m
.30159 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.42063 .01472 m
.42063 .01847 L
s
.46032 .01472 m
.46032 .01847 L
s
.53968 .01472 m
.53968 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.69841 .01472 m
.69841 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.77778 .01472 m
.77778 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.93651 .01472 m
.93651 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 .13244 m
.18879 .13244 L
s
[(200)] .17004 .13244 1 0 Mshowa
.18254 .25016 m
.18879 .25016 L
s
[(400)] .17004 .25016 1 0 Mshowa
.18254 .36788 m
.18879 .36788 L
s
[(600)] .17004 .36788 1 0 Mshowa
.18254 .4856 m
.18879 .4856 L
s
[(800)] .17004 .4856 1 0 Mshowa
.18254 .60332 m
.18879 .60332 L
s
[(1000)] .17004 .60332 1 0 Mshowa
.125 Mabswid
.18254 .04415 m
.18629 .04415 L
s
.18254 .07358 m
.18629 .07358 L
s
.18254 .10301 m
.18629 .10301 L
s
.18254 .16187 m
.18629 .16187 L
s
.18254 .1913 m
.18629 .1913 L
s
.18254 .22073 m
.18629 .22073 L
s
.18254 .27959 m
.18629 .27959 L
s
.18254 .30902 m
.18629 .30902 L
s
.18254 .33845 m
.18629 .33845 L
s
.18254 .39731 m
.18629 .39731 L
s
.18254 .42674 m
.18629 .42674 L
s
.18254 .45617 m
.18629 .45617 L
s
.18254 .51503 m
.18629 .51503 L
s
.18254 .54446 m
.18629 .54446 L
s
.18254 .57389 m
.18629 .57389 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -79.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(eq) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.438 13.000 moveto
(H) show
84.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.438 13.000 moveto
(L) show
96.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04365 .01472 L
.06349 .01472 L
.08333 .01472 L
.10317 .01472 L
.12302 .01472 L
.14286 .01472 L
.1627 .01472 L
.18254 .02712 L
.20238 .27794 L
.22222 .38698 L
.24206 .47064 L
.2619 .54118 L
.28175 .60302 L
.30159 .60332 L
.32143 .60332 L
.34127 .60332 L
.36111 .60332 L
.38095 .60332 L
.40079 .60332 L
.42063 .60332 L
.44048 .60332 L
.46032 .60332 L
.48016 .60332 L
.5 .60332 L
.51984 .60332 L
.53968 .60332 L
.55952 .60332 L
.57937 .59091 L
.59921 .34009 L
.61905 .23105 L
.63889 .14739 L
.65873 .07686 L
.67857 .01501 L
.69841 .01472 L
.71825 .01472 L
.7381 .01472 L
.75794 .01472 L
.77778 .01472 L
.79762 .01472 L
.81746 .01472 L
.8373 .01472 L
.85714 .01472 L
.87698 .01472 L
.89683 .01472 L
.91667 .01472 L
.93651 .01472 L
.95635 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`005_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000Aoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool06Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`06oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`09?ooool4o`000003oa0@4?oooooooooo02Kooooo000Fooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A017ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool06_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B409_ooool00ol0003oooooooooo`0Xooooo`003_ooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^04Sooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^01cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00006oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000oooo
ooooool0:?ooool001Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
04Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01_ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Vooooo`03o`000?oooooooooo02Sooooo000F
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`16ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Jooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool0000Looooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<01_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`09_ooool00ol0003oooooooooo`0Xooooo`005_ooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool0AOooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool06Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000007?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool07Ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Vooooo`03
o`000?oooooooooo02Sooooo000Fooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@04Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
7?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P07Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Vooooo`03o`000?oooooo
oooo02Sooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<04Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool06oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Tooooo`03oeEEEOmVIVKo000002[o
oooo003oooooofWooooo001=ooooo`03o`000?oooooooooo0?oooooo6Oooool004gooooo00?o0000
ooooooooool0o_ooool6o`0001Cooooo001=ooooo`03o`000?oooooooooo0?oooooo00Go0000oooo
ooooooooooooo`00000Dooooo`00COooool00ol0003oooooooooo`3oooooo`05o`000?oooooooooo
ooooool@41005?ooool001Koooooool0000`o`0000[ooooo00?o0000ooooool@41005_ooool001go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo0ol0000Foooo
o`007Oooool00ol0003oooooooooo`0Zooooo`;o000000?oooooo`000?ooool0;_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool01Ol0003o
oooooa0@4?oooooo410@01Cooooo001<ooooo`;o0000U?ooool00ol0003oooooooooo`1Zooooo`05
o`000?ooooooooooooooool000005?ooool004gooooo00?o0000ooooooooool0T_ooool00ol0003o
ooooooooo`1Yooooo`Ko00005?ooool004gooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`23ooooo`00COooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo08Cooooo001=
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0Q?ooool004gooooo00?o0000oooo
ooooool0TOooool00ol0003oooooooooo`24ooooo`00COooool2o`00097ooooo00?o0000oooooooo
ool0QOooool004gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`25ooooo`00COoo
ool2o`00097ooooo00?o0000ooooooooool0QOooool004gooooo0_l0002@ooooo`03o`000?oooooo
oooo08Kooooo001=ooooo`;o0000T?ooool00ol0003oooooooooo`26ooooo`00COooool2o`00093o
oooo00?o0000ooooooooool0Q_ooool004gooooo0_l0002?ooooo`03o`000?oooooooooo08Oooooo
001=ooooo`;o0000Soooool00ol0003oooooooooo`27ooooo`00COooool2o`0008oooooo00?o0000
ooooooooool0Qoooool004gooooo0_l0002>ooooo`03o`000?oooooooooo08Sooooo001=ooooo`;o
0000S_ooool00ol0003oooooooooo`28ooooo`00COooool2o`0008kooooo00?o0000ooooooooool0
R?ooool004gooooo0_l0002>ooooo`03o`000?oooooooooo08Sooooo001=ooooo`;o0000SOooool0
0ol0003oooooooooo`29ooooo`00COooool2o`0008gooooo00?o0000ooooooooool0ROooool004go
oooo00?o0000ooooool00000S?ooool00ol0003oooooooooo`29ooooo`00COooool00ol0003ooooo
o`00002;ooooo`03o`000?oooooooooo08[ooooo001=ooooo`03o`000?oooooo000008_ooooo00?o
0000ooooooooool0R_ooool004gooooo0ol0002;ooooo`03o`000?oooooooooo08[ooooo001=oooo
o`03o`000?oooooo000008_ooooo00?o0000ooooooooool0R_ooool004gooooo00?o0000ooooool0
0000R_ooool00ol0003oooooooooo`2;ooooo`00COooool00ol0003oooooo`00002:ooooo`03o`00
0?oooooooooo08_ooooo001=ooooo`03o`000?oooooo000008[ooooo00?o0000ooooooooool0Rooo
ool004gooooo00?o0000ooooool00000ROooool00ol0003oooooooooo`2<ooooo`00<_ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooo`000029ooooo`03o`000?oooooooooo08cooooo000booooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooo000008Wooooo00?o0000ooooooooool0S?ooool003?ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooo000008Wooooo00?o0000ooooooooool0S?ooool003Co
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o0000R?ooool00ol0003oooooooooo`2=ooooo`00=Oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000Qoooool00ol0003oooooooooo`2=ooooo`00=_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00Co0000oooooooooooo0000Qoooool00ol0003oooooooooo`2=oooo
o`00<_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01?l0003oooooooooool00026ooooo`03o`00
0?oooooooooo08kooooo000booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?oooooooooo
o`0008Kooooo00?o0000ooooooooool0S_ooool004gooooo00Co0000oooooooooooo0000Q_ooool0
0ol0003oooooooooo`2>ooooo`00COooool01?l0003oooooooooool00026ooooo`03o`000?oooooo
oooo08kooooo001=ooooo`04o`000?ooooooooooo`0008Gooooo00?o0000ooooooooool0Soooool0
04gooooo00Co0000oooooooooooo0000QOooool00ol0003oooooooooo`2?ooooo`00COooool2o`00
0003ooooool0003ooooo08Cooooo00?o0000ooooooooool0Soooool004gooooo00Co0000oooooooo
oooo0000QOooool00ol0003oooooooooo`2?ooooo`00COooool01?l0003oooooooooool00024oooo
o`03o`000?oooooooooo093ooooo001=ooooo`04o`000?ooooooooooo`0008Cooooo00?o0000oooo
ooooool0T?ooool004gooooo00Go0000ooooooooooooooooo`000023ooooo`03o`000?oooooooooo
093ooooo001=ooooo`05o`000?ooooooooooooooool00000Poooool00ol0003oooooooooo`2@oooo
o`00COooool01Ol0003ooooooooooooooooo000008?ooooo00?o0000ooooooooool0T?ooool004go
oooo00Go0000ooooooooooooooooo`000022ooooo`03o`000?oooooooooo097ooooo001=ooooo`05
o`000?ooooooooooooooool00000P_ooool00ol0003oooooooooo`2Aooooo`00COooool2o`0000;o
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`2Aooooo`00COooool01Ol0003ooooo
oooooooooooo000008;ooooo00?o0000ooooooooool0TOooool004gooooo00Go0000oooooooooooo
ooooo`000021ooooo`03o`000?oooooooooo09;ooooo001=ooooo`05o`000?ooooooooooooooool0
0000POooool00ol0003oooooooooo`2Booooo`00COooool01Ol0003ooooooooooooooooo0000087o
oooo00?o0000ooooooooool0T_ooool004gooooo00Go0000ooooooooooooooooo`000021ooooo`03
o`000?oooooooooo09;ooooo001=ooooo`05o`000?ooooooooooooooool00000P?ooool00ol0003o
ooooooooo`2Cooooo`00COooool01Ol0003ooooooooooooooooo0000083ooooo00?o0000oooooooo
ool0Toooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1mooooo`03o`00
0?oooooooooo09?ooooo001=ooooo`;o00000oooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo09?ooooo001=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`2Cooooo`00COooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool0U?ooool004gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1looooo`03o`000?oooooooooo09Cooooo001=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`2Dooooo`00COooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0U?ooool003Cooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool0U?ooool003Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`2Eooooo`00<_ooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000;ooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`2Eooooo`00<_ooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo09Go
oooo000booooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool0UOooool003?ooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2Eooooo`00<oooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo09Kooooo000dooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool0U_ooool004gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo09Kooooo001=ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2Fooooo`00COooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0U_ooool0
04gooooo0_l00004ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0U_ooool004go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo09Oo
oooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`2Gooooo`00COooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0Uoooool004gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo09Oooooo001=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Moooool00ol0003oooooooooo`2Gooooo`00COooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool0V?ooool004gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo09Sooooo001=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2Hooooo`00COooool2
o`0000Kooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2Hooooo`00COooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0V?ooool004go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo09So
oooo001=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`2Iooooo`00COooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool0VOooool004gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo09Wooooo001=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`2Iooooo`00COooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0VOooool004gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo09[ooooo001=ooooo`;o00001ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo09[ooooo001=ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Jooooo`00COooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0V_ooool004go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo09[o
oooo001=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`2Jooooo`00COooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0V_ooool004gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo09[ooooo000booooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2Jooooo`00<_oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0Voooool003;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0
0008ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0Voooool003;ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo09_ooooo000booooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Kooooo`00<_ooool00omE
EEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo09_ooooo000booooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0Voooool003?ooooo00Coc<c<odA4A?l0003o410@
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`2Koooo
o`00COooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool0Voooool004gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo09_ooooo001=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`2Kooooo`00COooool2o`0000_ooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`2Kooooo`00COooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool0Voooool004gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo09_ooooo001=ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`2Looooo`00COooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0W?ooool004gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09cooooo001=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`2Loooo
o`00COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0W?ooool004gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo09cooooo001=ooooo`;o00003Oooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo09cooooo001=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`2Looooo`00COooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool0W?ooool004gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo09cooooo001=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Looooo`00COooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0W?ooool004gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo09cooooo001=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Moooo
o`00COooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool0WOooool004gooooo0_l0000?ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
WOooool004gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo09gooooo001=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`2Mooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool0WOooool004gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo09gooooo001=ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2Mooooo`00<_ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool0WOooool003;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo09gooooo000booooo`05o`000?oooooo
ooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`2Mooooo`00<_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`2Mooooo`00<_ooool01Oo<c<co0000o`000?l0003o
c<c<00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
W_ooool003;ooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo09kooooo000booooo`05o`000?nj^[[ooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`2Nooooo`00<_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool0W_ooool004gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo09kooooo001=ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Nooooo`00COooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0W_ooool0
04gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
09kooooo001=ooooo`;o00005?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09ko
oooo001=ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`2Nooooo`00COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0W_ooool004gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo09kooooo001=ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`2Nooooo`00COooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0Woooool004gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo09oooooo001=ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`2Oooooo`00COooool2
o`0001Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`2Oooooo`00COooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Woooool004go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo09oo
oooo001=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`2Oooooo`00COooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool0Woooool004gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo09oooooo001=ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`2Oooooo`00COooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool0Woooool004gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo09oooooo001=ooooo`;o00006Ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo09oooooo001=ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`2Pooooo`00COooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0X?ooool004go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0:3o
oooo001=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`2Pooooo`00COooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0X?ooool004gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1G
ooooo`;o0000X_ooool002_ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0EOooool2o`000:Cooooo000]ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Booooo`;o0000Y_ooool002gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001_ooool3o`0001_oooooEOl0002Xooooo`00;Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo6Oooool0
02gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3ooooooaWooooo000]ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool0oooooolIooooo`00;Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo6Oooool002_ooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0016ooooo`?o0000oooooolPoooo
o`00Aoooool00ol0003oooooooooo`3ooooooaoooooo0010ooooo`?o00000_ooool3o`0000Sooooo
00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`3oooooo`_ooooo000oooooo`;o00000ooo
ool01?l0003oooooooooool00007ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd0
ooooool;ooooo`00>Oooool00ol@413o0000o`000002o`000003oa0@4?l0003ooooo00;o000000Go
ooooo`000?ooooooooooo`000007ooooo`04oeEEEOnHV9Soooooooooo`Ko00000oooool00on7QhOo
IVIVooooo`3oooooo`[ooooo000kooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`?o0000
1oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00oo^k^ko
0000ooooo`3oooooo`[ooooo000kooooo`03o`000?oooooooooo017ooooo00?o<S8booooooooool0
0_ooool01Ol0003ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0ooooool9ooooo`00
>oooool00ol0003oooooooooo`0Aooooo`03oc8b<_oooooooooo00;ooooo00?o0000ooooool@4100
1_ooool00ol0003oooooooooo`3oooooo`Wooooo000kooooo`03o`000?oooooooooo017ooooo00?o
0000onk^k_ooool00_ooool3o`0000Gooooo00?ok^k^o`000?ooool0ooooool:ooooo`00>Oooool0
0ol@413o0000o`000003o`00013ooooo00?oEEEEogMgMoooool00_ooool01Ol0003ooooooa0@4?oo
oooo410@00?ooooo00?oMgMgoeEEEOooool0ooooool:ooooo`00>oooool00ol0003oooooooooo`0A
ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03onk^k_l@
413ogMgM0?oooooo2oooool003_ooooo00?o410@okZj^_ooool04_ooool00omgMgOoIVIVooooo`06
o`0000;ooooo00?oIVIVogMgMoooool0ooooool;ooooo`00>oooool01?nj^[[o410@o`000?l@413o
ooooob[ooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.321714, -84.3828, \
0.00520376, 7.01655}}]
}, Open  ]],

Cell[TextData[{
  "(Using ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rather than ",
  StyleBox["Plot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "speeds up the evaluation considerably by reducing the number of function \
evaluations). "
}], "Text"],

Cell[TextData[{
  "\tThe distribution goes to zero for ",
  Cell[BoxData[
      \(TraditionalForm\`E < 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E \[GreaterTilde] 0.6\)]],
  " due to our choice of initial conditions, with all particles concentrated \
in this energy range. Also, it can be easily verified that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                  f\_eq\)(E)\) \[DifferentialD]E = M\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "\tWe must now translate this distribution over energies back to a \
distribution in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " plane. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(E)\) \[DifferentialD]E\)]],
  " is the number of particles between energy surfaces ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E + \[DifferentialD]E\)]],
  ", the distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " is related to ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  " by the same formula as we used in Eq. ",
  ButtonBox["(7.1.26)",
    ButtonData:>{"Chapter7.nb", "(7.1.26)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(
            E)\)\ \[DifferentialD]E = \(\[Integral]\[DifferentialD]x \
\[DifferentialD]p\)\+\(E \[LessEqual] \ H(x, p)\  \[LessEqual] \ E + \ \
\[DifferentialD]E\)\ \(\(f\_eq\)(x, p)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In fact, since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(f\_eq\)(x, p)\)\)\)]],
  " is constant along the energy surfaces, we can take it out of the integral \
and write "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(
            E)\)\ \[DifferentialD]E = \[DifferentialD]\(A(E)\)\ \(\(f\_eq\)(
            x, p)\)\)]],
  ","
}], "UNNEQ"],

Cell[" where", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\(A(
            E)\) = \(\[Integral]\[DifferentialD]x \[DifferentialD]p\)\+\(E \
\[LessEqual] \ H(x, p)\  \[LessEqual] \ E + \ \[DifferentialD]E\)\)]]
}], "UNNEQ"],

Cell[" is the area between adjacent energy surfaces. Thus,", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, 
          p)\  = \(\(\(\(f\_eq\)(
              E)\)/\(\[DifferentialD]A\/\[DifferentialD]E\)\) \((E)\)\(\ \)\)\
\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.27)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`E = H(x, p)\)]],
  ".  [Using action-angle variables, one can show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]A/\[DifferentialD]E = 
        2\ \[Pi]/\(\(\[Omega]\_o\)(E)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_o\)(E)\)]],
  " is the orbit frequency of particles with energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ". ]"
}], "Text"],

Cell[TextData[{
  "\tIn order to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " we must first work out ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]A/\[DifferentialD]E\)]],
  ". We do so numerically by first evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`A(E)\)]],
  ", the phase space area within energy surface ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ", and then taking a derivative: "
}], "Text"],

Cell[BoxData[
    \(A[e_]\  := \ 
      NIntegrate[
        Boole[H[x, p] < e], {x, \(-Infinity\), Infinity}, {p, \(-Infinity\), 
          Infinity}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.12"],

Cell[TextData[{
  "In mechanics, this phase-space area is  called the ",
  StyleBox["action",
    FontSlant->"Italic"],
  " for a given energy surface. To take the derivative of this numerical \
function, it is best to first interpolate the function, and then take a \
derivative of the interpolating function:"
}], "Text",
  CellTags->"i:10"],

Cell[BoxData[{
    \(\(\(areadata\  = \ Table[{e, A[e]}, {e, 0, 2,  .1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Ainterp = Interpolation[areadata];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(dAdE[e_] := D[Ainterp[e1], e1] /. e1 \[Rule] e\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.13"],

Cell[TextData[{
  "This derivative of the action is plotted in Cell ",
  ButtonBox["7.14",
    ButtonData:>"Cell 7.14",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[dAdE[e], {e, 0, 1}, 
        PlotLabel \[Rule] "\<\[DifferentialD]A/\[DifferentialD]E\>", 
        AxesLabel \[Rule] {"\<E\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.14"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.359092 0.267253 [
[.21429 .16291 -9 -9 ]
[.21429 .16291 9 0 ]
[.40476 .16291 -9 -9 ]
[.40476 .16291 9 0 ]
[.59524 .16291 -9 -9 ]
[.59524 .16291 9 0 ]
[.78571 .16291 -9 -9 ]
[.78571 .16291 9 0 ]
[.97619 .16291 -3 -9 ]
[.97619 .16291 3 0 ]
[1.025 .17541 0 -6 ]
[1.025 .17541 10 6 ]
[.01131 .04179 -18 -4.5 ]
[.01131 .04179 0 4.5 ]
[.01131 .30904 -18 -4.5 ]
[.01131 .30904 0 4.5 ]
[.01131 .44267 -6 -4.5 ]
[.01131 .44267 0 4.5 ]
[.01131 .57629 -18 -4.5 ]
[.01131 .57629 0 4.5 ]
[.5 .63053 -16.9688 0 ]
[.5 .63053 16.9688 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .17541 m
.21429 .18166 L
s
[(0.2)] .21429 .16291 0 1 Mshowa
.40476 .17541 m
.40476 .18166 L
s
[(0.4)] .40476 .16291 0 1 Mshowa
.59524 .17541 m
.59524 .18166 L
s
[(0.6)] .59524 .16291 0 1 Mshowa
.78571 .17541 m
.78571 .18166 L
s
[(0.8)] .78571 .16291 0 1 Mshowa
.97619 .17541 m
.97619 .18166 L
s
[(1)] .97619 .16291 0 1 Mshowa
.125 Mabswid
.07143 .17541 m
.07143 .17916 L
s
.11905 .17541 m
.11905 .17916 L
s
.16667 .17541 m
.16667 .17916 L
s
.2619 .17541 m
.2619 .17916 L
s
.30952 .17541 m
.30952 .17916 L
s
.35714 .17541 m
.35714 .17916 L
s
.45238 .17541 m
.45238 .17916 L
s
.5 .17541 m
.5 .17916 L
s
.54762 .17541 m
.54762 .17916 L
s
.64286 .17541 m
.64286 .17916 L
s
.69048 .17541 m
.69048 .17916 L
s
.7381 .17541 m
.7381 .17916 L
s
.83333 .17541 m
.83333 .17916 L
s
.88095 .17541 m
.88095 .17916 L
s
.92857 .17541 m
.92857 .17916 L
s
.25 Mabswid
0 .17541 m
1 .17541 L
s
gsave
1.025 .17541 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .04179 m
.03006 .04179 L
s
[(1.5)] .01131 .04179 1 0 Mshowa
.02381 .30904 m
.03006 .30904 L
s
[(2.5)] .01131 .30904 1 0 Mshowa
.02381 .44267 m
.03006 .44267 L
s
[(3)] .01131 .44267 1 0 Mshowa
.02381 .57629 m
.03006 .57629 L
s
[(3.5)] .01131 .57629 1 0 Mshowa
.125 Mabswid
.02381 .06851 m
.02756 .06851 L
s
.02381 .09524 m
.02756 .09524 L
s
.02381 .12196 m
.02756 .12196 L
s
.02381 .14869 m
.02756 .14869 L
s
.02381 .20214 m
.02756 .20214 L
s
.02381 .22886 m
.02756 .22886 L
s
.02381 .25559 m
.02756 .25559 L
s
.02381 .28231 m
.02756 .28231 L
s
.02381 .33577 m
.02756 .33577 L
s
.02381 .36249 m
.02756 .36249 L
s
.02381 .38922 m
.02756 .38922 L
s
.02381 .41594 m
.02756 .41594 L
s
.02381 .46939 m
.02756 .46939 L
s
.02381 .49612 m
.02756 .49612 L
s
.02381 .52284 m
.02756 .52284 L
s
.02381 .54957 m
.02756 .54957 L
s
.02381 .01506 m
.02756 .01506 L
s
.02381 .60302 m
.02756 .60302 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -77.9688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\342) show
68.938 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(\\220) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\342) show
86.938 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
92.938 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06076 L
.10458 .10705 L
.14415 .14678 L
.18221 .18158 L
.22272 .21345 L
.26171 .24309 L
.30316 .27241 L
.34309 .2981 L
.3815 .32222 L
.42237 .3462 L
.46172 .36863 L
.49955 .38934 L
.53984 .41034 L
.57861 .43007 L
.61984 .45018 L
.65954 .46911 L
.69774 .48669 L
.73838 .50499 L
.77751 .52216 L
.81909 .53987 L
.85916 .5566 L
.89771 .57227 L
.93871 .58865 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000oooooom=ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000oooooom=ooooo`006_ooool0
0ol0003oooooo`00003oooooodcooooo000Jooooo`04o`000?ooooooooooo`000?ooooooBoooool0
01[ooooo00Go0000ooooooooooooooooo`00003ooooood[ooooo0004o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01Ol0003ooooooooooooo
oooo00000?ooooooB_ooool000;ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAoooool0
00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom6ooooo`000_ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol00004ooooo`03o`000?oooooooooo0?ooooooAOooool000;ooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooodCooooo0002ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
A?ooool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom3ooooo`0000?oEEEEofIVI_l000003Oooool4
o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000Joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0?oooooo@?ooool001[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`3ooooood3ooooo000Jooooo`;o00002oooool00ol0003ooooooooo
o`3oooooocoooooo000Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooooln
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo?Oooool001[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3ooooooccooooo000Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0oooooolkooooo`006_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0?oooooo>_ooool001[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3oooooocWooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0oooooolhooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oo
oooo=oooool001[ooooo0_l0000Dooooo`03o`000?oooooooooo0?oooooo=_ooool001[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`3oooooocGooooo000Jooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0ooooooldooooo`006_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo0?oooooo<oooool001[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`3ooooooc;ooooo000Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
oooooolaooooo`006_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo<?oo
ool001[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooooboooooo000Joooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0ooooool^ooooo`006_ooool2o`0001go
oooo00?o0000ooooooooool0ooooool]ooooo`006_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo0?oooooo;?ooool001[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`3oooooob_ooooo000Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0oooooolZ
ooooo`006_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<033ooooo1?l00000
0ol@413oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A402Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`0Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@0Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@0booooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Xooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Sooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003ooooooooo
o`0Kooooo`006_ooool00ol0003oooooooooo`0Sooooo`;o00002_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo0000:Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@0Xooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b03;ooooo00?o0000ooooooooool06oooool001[ooooo0_l0000Vooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01_o
oooo000Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l00000:Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool0:_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@400booooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@400Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Yoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Zooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000003;ooooo00?o0000ooooooooool0
6oooool001[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Mooooo`006_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo0?oooooo8?ooool001[ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`3ooooooaoooooo000Jooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0oooooolCooooo`Ko00001Oooool001[ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`3ooooooa?ooooo00Go0000ooooooooooooooooo`000005ooooo`006_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo4_ooool01Ol0003ooooooooooooooooo
410@00Gooooo000Boooooooo0000@_l0000;ooooo`03o`000?oooooo410@00Oooooo000Jooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
017ooooo0ol00007ooooo`006_ooool00ol0003oooooooooo`0`ooooo`;o00002?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo017ooooo00Go0000ooooool@413ooooooa0@4005oooo
o`006_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0?oooooo3Oooool01Ol0003o
oooooooooooooooo000000Gooooo000Jooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0ooooool;ooooo`Ko00001Oooool001[ooooo00?o0000ooooooooool0=?ooool2o`000?oooooo
5_ooool001[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3ooooooa?ooooo000J
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0oooooolBooooo`006_ooool2o`00
03Wooooo00?o0000ooooooooool0oooooolAooooo`006_ooool00ol0003oooooooooo`0iooooo`;o
0000oooooolAooooo`006_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0?oooooo
3_ooool001[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`3oooooo`gooooo000J
ooooo`03o`000?oooooooooo03gooooo0_l0003oooooo`gooooo000Jooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0ooooool:ooooo`006_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo0?oooooo2Oooool001[ooooo00?o0000ooooooooool0@Oooool2o`000?oooooo
2Oooool001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3oooooo`Kooooo000J
ooooo`;o0000AOooool00ol0003oooooooooo`3oooooo`Gooooo000Jooooo`03o`000?oooooooooo
04Gooooo0_l0003oooooo`Gooooo000Jooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0ooooool2ooooo`006_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?oooooo
0Oooool001[ooooo00?o0000ooooooooool0BOooool2o`000?oooooo0Oooool001[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`3mooooo`006_ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo0?cooooo000Jooooo`03o`000?oooooooooo04gooooo0_l0003looooo`00
6_ooool2o`00053ooooo00?o0000ooooooooool0nOooool001[ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`3hooooo`006_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo0?Oooooo000Jooooo`03o`000?oooooooooo05;ooooo0_l0003gooooo`006_ooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo0?Cooooo000Jooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool0loooool001[ooooo00?o0000ooooooooool0E_ooool2o`000??ooooo000J
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0l?ooool001[ooooo00?o0000oooo
ooooool0FOooool2o`000?3ooooo000Jooooo`;o0000G?ooool2o`000>kooooo000Jooooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0joooool001[ooooo00?o0000ooooooooool0G_oo
ool2o`000>_ooooo000Jooooo`03o`000?oooooooooo063ooooo0_l0003Yooooo`006_ooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo0>Kooooo000Jooooo`03o`000?oooooooooo06?o
oooo0_l0003Vooooo`001?l00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`3Sooooo`0000Co8B4Qonk^k_oooooo
A4A41Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Vooooo`;o
0000hoooool00003oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3o`0006Sooooo
00?o0000ooooooooool0h?ooool00004oooooonHV9So8B4Qonk^kPoooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`1Yooooo`;o0000h?ooool000;ooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`3Mooooo`000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0K?ooool2o`000=gooooo00001?nj^[[ooooooiRHV?l@410<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`3Jooooo`0000Co410@
o`000?lQ8B7oc<c<3?ooool4o`0000Kooooo00?o0000ooooooooool0Koooool2o`000=[ooooo000J
ooooo`03o`000?oooooooooo077ooooo0_l0003Hooooo`006_ooool00ol0003oooooooooo`1coooo
o`;o0000e_ooool001[ooooo00?o0000ooooooooool0MOooool2o`000=Cooooo000Jooooo`;o0000
N?ooool00ol0003oooooooooo`3Aooooo`006_ooool00ol0003oooooooooo`1hooooo`;o0000dOoo
ool001[ooooo00?o0000ooooooooool0N_ooool2o`000<oooooo000Jooooo`03o`000?oooooooooo
07cooooo0_l0003=ooooo`006_ooool00ol0003oooooooooo`1nooooo`;o0000boooool001[ooooo
00?o0000ooooooooool0P?ooool2o`000<Wooooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0
0037ooooo`006_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo0<Cooooo000Joooo
o`;o0000Q_ooool2o`000<Cooooo000Jooooo`03o`000?oooooooooo08Oooooo0_l00032ooooo`00
6_ooool00ol0003oooooooooo`29ooooo`;o0000`?ooool001[ooooo00?o0000ooooooooool0Rooo
ool2o`000;kooooo000Jooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0^oooool0
01[ooooo00?o0000ooooooooool0S_ooool2o`000;_ooooo000Jooooo`03o`000?oooooooooo093o
oooo0_l0002iooooo`006_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo0;Kooooo
000Jooooo`03o`000?oooooooooo09?ooooo0_l0002fooooo`006_ooool2o`0009Kooooo0_l0002d
ooooo`006_ooool00ol0003oooooooooo`2Gooooo`;o0000/_ooool001[ooooo00?o0000oooooooo
ool0VOooool2o`000;3ooooo000Jooooo`03o`000?oooooooooo09_ooooo0_l0002^ooooo`006_oo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo0:_ooooo000Jooooo`03o`000?oooooo
oooo09kooooo0_l0002[ooooo`006_ooool00ol0003oooooooooo`2Pooooo`;o0000ZOooool001[o
oooo00?o0000ooooooooool0X_ooool2o`000:Oooooo000Jooooo`;o0000YOooool2o`000:Gooooo
000Jooooo`03o`000?oooooooooo0:Kooooo0_l0002Sooooo`006_ooool00ol0003oooooooooo`2X
ooooo`;o0000XOooool001[ooooo00?o0000ooooooooool0Z_ooool2o`0009oooooo000Jooooo`03
o`000?oooooooooo0:cooooo0_l0002Mooooo`006_ooool00ol0003oooooooooo`2^ooooo`;o0000
Voooool001[ooooo00?o0000ooooooooool0/?ooool3o`0009Sooooo000?ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`2cooooo`;o0000U_ooool000oooooo00Go410@
okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0;Gooooo0_l0002Dooooo`004oooool0
0ol0003oooooooooo`04ooooo`?o0000]oooool3o`00097ooooo000Booooo`03ojVYZOl@413ooooo
00Gooooo00?o0000ooooooooool0^_ooool2o`0008oooooo000Aooooo`03oa0@4?l0003o^[Zj00Ko
oooo00?o0000ooooooooool0_?ooool2o`0008gooooo000Booooo`03okZj^_lQ8B7ooooo00Gooooo
00?o0000ooooooooool0__ooool2o`0008_ooooo000?ooooo`05oa0@4?nHV9SooooookZj^_l00000
1_ooool00ol0003oooooooooo`30ooooo`;o0000ROooool000oooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo0<;ooooo0_l00027ooooo`006_ooool00ol0003ooooooooo
o`34ooooo`;o0000QOooool001[ooooo00?o0000ooooooooool0a_ooool2o`0008?ooooo000Joooo
o`03o`000?oooooooooo0<Sooooo0_l00021ooooo`006_ooool2o`000<_ooooo0_l0001oooooo`00
6_ooool00ol0003oooooooooo`3<ooooo`;o0000OOooool001[ooooo00?o0000ooooooooool0c_oo
ool2o`0007_ooooo000Jooooo`03o`000?oooooooooo0=3ooooo0_l0001iooooo`006_ooool00ol0
003oooooooooo`3Booooo`;o0000Moooool001[ooooo00?o0000ooooooooool0e?ooool2o`0007Go
oooo000Jooooo`03o`000?oooooooooo0=Kooooo0_l0001cooooo`006_ooool00ol0003ooooooooo
o`3Hooooo`;o0000LOooool001[ooooo0_l0003Kooooo`?o0000K_ooool001[ooooo00?o0000oooo
ooooool0gOooool2o`0006cooooo000Jooooo`03o`000?oooooooooo0=oooooo0_l0001Zooooo`00
6_ooool00ol0003oooooooooo`3Qooooo`;o0000J?ooool001[ooooo00?o0000ooooooooool0hooo
ool3o`0006Gooooo000Jooooo`03o`000?oooooooooo0>Kooooo0ol0001Rooooo`006_ooool00ol0
003oooooooooo`3Yooooo`;o0000H?ooool001[ooooo00?o0000ooooooooool0joooool3o`0005go
oooo000Jooooo`03o`000?oooooooooo0>kooooo0_l0001Kooooo`006_ooool2o`000?7ooooo0_l0
001Iooooo`006_ooool00ol0003oooooooooo`3booooo`;o0000Eoooool001[ooooo00?o0000oooo
ooooool0m?ooool3o`0005Cooooo000Jooooo`03o`000?oooooooooo0?Oooooo0_l0001Booooo`00
6_ooool00ol0003oooooooooo`3iooooo`;o0000D?ooool001[ooooo00?o0000ooooooooool0nooo
ool2o`0004kooooo000Jooooo`03o`000?oooooooooo0?gooooo0ol0001;ooooo`006_ooool00ol0
003oooooooooo`3oooooo`7ooooo0ol00018ooooo`006_ooool2o`000?oooooo1Oooool2o`0004Ko
oooo000Jooooo`03o`000?oooooooooo0?oooooo1_ooool3o`0004?ooooo000Jooooo`03o`000?oo
oooooooo0?oooooo2Oooool2o`00047ooooo000Jooooo`03o`000?oooooooooo0?oooooo2oooool3
o`0003kooooo000Jooooo`03o`000?oooooooooo0?oooooo3_ooool2o`0003cooooo000Jooooo`03
o`000?oooooooooo0?oooooo4?ooool2o`0003[ooooo00001?l@413o0000oc8b<_o<c<`5ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolBoooo
o`?o0000=oooool00004okZj^_ooooooMgMgoc8b<PGooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolEooooo`;o0000=Oooool000?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo5oooool2o`0003?o
oooo0002ooooo`03ojVYZOl@413ooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo
6Oooool2o`00037ooooo00001?oooooo410@o`000?nj^[X<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3ooooooa_ooooo0ol0000^ooooo`000_ooool00onj^[[o8B4Q
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolNooooo`;o0000
;?ooool00004oiRHV?oooooo^[Zjo`0000cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooob3ooooo0_l0000Zooooo`0000Co410@o`000?l@413oZJVY3?ooool4o`0000Kooooo
00?o0000ooooooooool0oooooolRooooo`?o00009oooool001[ooooo00?o0000ooooooooool0oooo
oolUooooo`?o00009?ooool001[ooooo00?o0000ooooooooool0oooooolXooooo`?o00008Oooool0
01[ooooo00?o0000ooooooooool0ooooool[ooooo`?o00007_ooool001[ooooo0_l0003ooooooboo
oooo00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002`ooooo`03ob4Q8OoMgMgooooo0;Gooooo002Poooo
o`04olc<c?l@413o0000oeEEE@Ko00000_ooool3o`000003oooooonHV9SoEEEE00Gooooo00Coc<c<
oa0@4?l0003oEEEE2?l0002Uooooo`00X?ooool02_m4A4CoMgMgoooooomEEEGo0000okZj^_l0003o
k^k^o`000?o^k^h3ooooo`06o`000?oMgMgoooooooooool0003ogMgM1?ooool01_m4A4CoMgMgoooo
oomEEEGo0000okZj^P;o00000oooool00ol0003oooooooooo`2Sooooo`00X?ooool02Ol0003ooooo
oooooonj^[[o0000okZj^_l0003ooooooeEEE@04o`000004odA4A?ooooooooooooooo`;oMgMg1?oo
ool01_l0003ooooooooooonj^[[o0000okZj^P;o00000oooool00ol@413oooooooooo`2Sooooo`00
X?ooool02_l0003ooooooooooonj^[[o0000okZj^_l0003oooooojVYZOm4A4@2ooooo`03odA4A?nH
V9Sooooo00;ooooo00?ok^k^oa0@4?o^k^h00oooool01_l0003ooooooooooonj^[[o0000okZj^P;o
000000?ooooooa0@4?ooool0Y_ooool00:3ooooo00OoA4A4ohN7QoooooooEEEEo`000?nj^[[o0000
00;ooooo00Co0000onk^k_o^k^ko00001Oooool00omEEEGoV9RHooooo`02ooooo`06odA4A?n7QhOo
oooooeEEEOl0003o^[Zj1?l0002Wooooo`00X?ooool01oo<c<co410@o`000?mEEEGo0000okZj^_l0
00000_ooool01?mVIVKoV9RHohN7QomVIVH5ooooo`03omgMgOl@413ooooo00;ooooo00Koc<c<oa0@
4?l0003oEEEEo`000?nj^[X2o`000004ooooool@413ooooooa0@4:Gooooo002Sooooo`04okZj^_l0
003o^[Zjo`0000;ooooo00Coc<c<odA4A?lQ8B7ogMgM1_ooool00omEEEGoV9RHooooo`04ooooo`03
okZj^_l0003o^[Zj00;o00000oooool00ol0003oooooooooo`2Sooooo`00Xoooool4o`000005oooo
ool@413o0000o`000?lb<S801oooool00onj^[[oA4A4ooooo`04ooooo`Wo0000YOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0870454, 1.31528, \
0.00410642, 0.0146336}}]
}, Open  ]],

Cell[TextData[{
  "To speed up the evaluation it is best to also create an interpolation \
function for  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(feqinterp\  = \ 
        Interpolation[Table[{e, feq[e]}, {e, 0, 1,  .025}], 
          InterpolationOrder \[Rule] 1];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.15"],

Cell[TextData[{
  "We use an ",
  StyleBox["InterpolationOrder ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "of only 1 because ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  " has a discontinuous first derivative. We then define the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " according to Eq. ",
  ButtonBox["(7.1.27)",
    ButtonData:>{"Chapter7.nb", "(7.1.27)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(feq[x_, p_]\  := \ 
        feqinterp[H[x, p]]/dAdE[H[x, p]]\  /; \ 
          0 < H[x, p] < \ 1;\)\), "\n", 
    \(feq[x_, p_]\  := \ 0\  /; \ Not[0 < H[x, p] < \ 1]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.16"],

Cell[TextData[{
  "The use of the conditional statements allows us to extend the definition \
to energies beyond the range of the interpolation function.  We plot the \
equilibrium in Cell ",
  ButtonBox["7.17",
    ButtonData:>"Cell 7.17",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[feq[x, p], {x, \(-1\), 1}, {p, \(-1\), 1}, 
        PlotRange \[Rule] All, PlotPoints \[Rule] 40, 
        AxesLabel \[Rule] \ {"\<x\>", "\<p\>", "\<\>"}, 
        PlotLabel -> \*"\"\<\!\(f\_eq\)(x,p)\>\""];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.17"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -24.7188 0 ]
[.5 .82364 24.7188 12.9375 ]
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01124 .34581 -18 -2.81061 ]
[.01124 .34581 0 6.18939 ]
[-0.00233 .43086 -18 -2.88296 ]
[-0.00233 .43086 0 6.11704 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -85.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(eq) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.438 13.000 moveto
(H) show
84.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
90.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
96.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.438 13.000 moveto
(L) show
108.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-1)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.5)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.5)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02352 .3412 m
.02966 .33889 L
s
[(200)] .01124 .34581 1 -0.37542 Mshowa
.01002 .42642 m
.01619 .4242 L
s
[(400)] -0.00233 .43086 1 -0.35934 Mshowa
.125 Mabswid
.03319 .28016 m
.03687 .27874 L
s
.03001 .30024 m
.03369 .29883 L
s
.02679 .32059 m
.03047 .31919 L
s
.02021 .36208 m
.0239 .36071 L
s
.01686 .38324 m
.02055 .38188 L
s
.01346 .40469 m
.01716 .40334 L
s
.00653 .44845 m
.01024 .44713 L
s
.00299 .47078 m
.0067 .46947 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Metetra
.664 .741 .908 r
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Metetra
.664 .741 .908 r
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Metetra
.664 .741 .908 r
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Metetra
.664 .741 .908 r
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Metetra
.664 .741 .908 r
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Metetra
.664 .741 .908 r
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Metetra
.664 .741 .908 r
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Metetra
.664 .741 .908 r
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Metetra
.664 .741 .908 r
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Metetra
.664 .741 .908 r
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Metetra
.664 .741 .908 r
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Metetra
.664 .741 .908 r
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Metetra
.664 .741 .908 r
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Metetra
.664 .741 .908 r
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Metetra
0 .109 .623 r
.60203 .53463 .60921 .54249 .62337 .53826 .61672 .54791 Metetra
.922 .61 .435 r
.61672 .54791 .62337 .53826 .63966 .59555 .63485 .66349 Metetra
.576 .325 .499 r
.63485 .66349 .63966 .59555 .65713 .66785 .65007 .66654 Metetra
.479 .877 .959 r
.65007 .66654 .65713 .66785 .67213 .66402 .66514 .66254 Metetra
.749 .957 .94 r
.66514 .66254 .67213 .66402 .68411 .59384 .68006 .65336 Metetra
0 0 .291 r
.68006 .65336 .68411 .59384 .69665 .54415 .69189 .58026 Metetra
0 0 .192 r
.69189 .58026 .69665 .54415 .70984 .51235 .70445 .53089 Metetra
.70445 .53089 .70984 .51235 .72452 .5079 .71775 .49976 Metetra
.665 .743 .908 r
.71775 .49976 .72452 .5079 .73926 .50347 .73255 .49524 Metetra
.664 .741 .908 r
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Metetra
.664 .741 .908 r
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Metetra
.664 .741 .908 r
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Metetra
.664 .741 .908 r
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Metetra
.664 .741 .908 r
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Metetra
.664 .741 .908 r
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Metetra
.664 .741 .908 r
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Metetra
.664 .741 .908 r
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Metetra
.664 .741 .908 r
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Metetra
.664 .741 .908 r
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Metetra
.664 .741 .908 r
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Metetra
.664 .741 .908 r
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Metetra
.664 .741 .908 r
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Metetra
.664 .741 .908 r
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Metetra
.664 .741 .908 r
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Metetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Metetra
.664 .741 .908 r
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Metetra
.664 .741 .908 r
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Metetra
.664 .741 .908 r
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Metetra
.664 .741 .908 r
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Metetra
.664 .741 .908 r
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Metetra
.664 .741 .908 r
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Metetra
.664 .741 .908 r
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Metetra
.664 .741 .908 r
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Metetra
.664 .741 .908 r
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Metetra
.664 .741 .908 r
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Metetra
.664 .741 .908 r
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Metetra
.664 .741 .908 r
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Metetra
.664 .741 .908 r
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Metetra
.664 .741 .908 r
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Metetra
.929 .546 .197 r
.59479 .5267 .60203 .53463 .61672 .54791 .61037 .57474 Metetra
.858 .552 .471 r
.61037 .57474 .61672 .54791 .63485 .66349 .62763 .66227 Metetra
0 .489 .709 r
.62763 .66227 .63485 .66349 .65007 .66654 .64289 .66464 Metetra
.515 .881 .979 r
.64289 .66464 .65007 .66654 .66514 .66254 .65804 .66062 Metetra
.771 .948 .935 r
.65804 .66062 .66514 .66254 .68006 .65336 .67303 .6509 Metetra
.794 .936 .923 r
.67303 .6509 .68006 .65336 .69189 .58026 .68803 .64043 Metetra
0 0 .278 r
.68803 .64043 .69189 .58026 .70445 .53089 .69963 .56372 Metetra
0 0 .148 r
.69963 .56372 .70445 .53089 .71775 .49976 .71228 .51578 Metetra
.71228 .51578 .71775 .49976 .73255 .49524 .72577 .48697 Metetra
.665 .743 .908 r
.72577 .48697 .73255 .49524 .74743 .49075 .7407 .4824 Metetra
.664 .741 .908 r
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Metetra
.664 .741 .908 r
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Metetra
.664 .741 .908 r
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Metetra
.664 .741 .908 r
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Metetra
.664 .741 .908 r
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Metetra
.664 .741 .908 r
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Metetra
.664 .741 .908 r
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Metetra
.664 .741 .908 r
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Metetra
.664 .741 .908 r
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Metetra
.664 .741 .908 r
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Metetra
.664 .741 .908 r
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Metetra
.664 .741 .908 r
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Metetra
.664 .741 .908 r
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Metetra
.664 .741 .908 r
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Metetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Metetra
.664 .741 .908 r
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Metetra
.664 .741 .908 r
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Metetra
.664 .741 .908 r
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Metetra
.664 .741 .908 r
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Metetra
.664 .741 .908 r
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Metetra
.664 .741 .908 r
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Metetra
.664 .741 .908 r
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Metetra
.664 .741 .908 r
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Metetra
.664 .741 .908 r
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Metetra
.664 .741 .908 r
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Metetra
.664 .741 .908 r
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Metetra
.664 .741 .908 r
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Metetra
.664 .741 .908 r
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Metetra
.664 .741 .908 r
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Metetra
.96 .646 .383 r
.58748 .51869 .59479 .5267 .61037 .57474 .60486 .64762 Metetra
.606 .351 .505 r
.60486 .64762 .61037 .57474 .62763 .66227 .62027 .65989 Metetra
0 .493 .772 r
.62027 .65989 .62763 .66227 .64289 .66464 .63563 .66325 Metetra
.479 .876 .961 r
.63563 .66325 .64289 .66464 .65804 .66062 .65086 .65923 Metetra
.786 .962 .921 r
.65086 .65923 .65804 .66062 .67303 .6509 .66592 .64858 Metetra
.794 .941 .923 r
.66592 .64858 .67303 .6509 .68803 .64043 .681 .638 Metetra
.81 .939 .913 r
.681 .638 .68803 .64043 .69963 .56372 .69608 .62672 Metetra
0 0 .273 r
.69608 .62672 .69963 .56372 .71228 .51578 .70732 .54424 Metetra
0 0 .082 r
.70732 .54424 .71228 .51578 .72577 .48697 .72011 .49884 Metetra
.72011 .49884 .72577 .48697 .7407 .4824 .73391 .47399 Metetra
.664 .742 .908 r
.73391 .47399 .7407 .4824 .75571 .47784 .74897 .46936 Metetra
.664 .741 .908 r
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Metetra
.664 .741 .908 r
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Metetra
.664 .741 .908 r
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Metetra
.664 .741 .908 r
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Metetra
.664 .741 .908 r
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Metetra
.664 .741 .908 r
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Metetra
.664 .741 .908 r
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Metetra
.664 .741 .908 r
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Metetra
.664 .741 .908 r
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Metetra
.664 .741 .908 r
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Metetra
.664 .741 .908 r
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Metetra
.664 .741 .908 r
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Metetra
.664 .741 .908 r
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Metetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Metetra
.664 .741 .908 r
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Metetra
.664 .741 .908 r
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Metetra
.664 .741 .908 r
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Metetra
.664 .741 .908 r
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Metetra
.664 .741 .908 r
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Metetra
.664 .741 .908 r
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Metetra
.664 .741 .908 r
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Metetra
.664 .741 .908 r
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Metetra
.664 .741 .908 r
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Metetra
.664 .741 .908 r
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Metetra
.664 .741 .908 r
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Metetra
.664 .741 .908 r
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Metetra
.664 .741 .908 r
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Metetra
.536 .695 .941 r
.56582 .51499 .57325 .52304 .58748 .51869 .58017 .51446 Metetra
.954 .642 .401 r
.58017 .51446 .58748 .51869 .60486 .64762 .59744 .64878 Metetra
.619 .071 0 r
.59744 .64878 .60486 .64762 .62027 .65989 .61283 .65791 Metetra
.192 0 0 r
.61283 .65791 .62027 .65989 .63563 .66325 .62828 .66214 Metetra
.456 .871 .947 r
.62828 .66214 .63563 .66325 .65086 .65923 .6436 .65812 Metetra
.8 .968 .91 r
.6436 .65812 .65086 .65923 .66592 .64858 .65873 .64669 Metetra
.811 .952 .911 r
.65873 .64669 .66592 .64858 .681 .638 .67387 .63513 Metetra
.793 .929 .924 r
.67387 .63513 .681 .638 .69608 .62672 .68908 .62462 Metetra
.828 .949 .899 r
.68908 .62462 .69608 .62672 .70732 .54424 .70422 .61224 Metetra
0 0 .275 r
.70422 .61224 .70732 .54424 .72011 .49884 .71495 .52189 Metetra
.71495 .52189 .72011 .49884 .73391 .47399 .72795 .48007 Metetra
.707 .908 .552 r
.72795 .48007 .73391 .47399 .74897 .46936 .74217 .4608 Metetra
.664 .741 .908 r
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Metetra
.664 .741 .908 r
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Metetra
.664 .741 .908 r
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Metetra
.664 .741 .908 r
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Metetra
.664 .741 .908 r
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Metetra
.664 .741 .908 r
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Metetra
.664 .741 .908 r
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Metetra
.664 .741 .908 r
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Metetra
.664 .741 .908 r
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Metetra
.664 .741 .908 r
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Metetra
.664 .741 .908 r
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Metetra
.664 .741 .908 r
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Metetra
.664 .741 .908 r
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Metetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Metetra
.664 .741 .908 r
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Metetra
.664 .741 .908 r
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Metetra
.664 .741 .908 r
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Metetra
.664 .741 .908 r
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Metetra
.664 .741 .908 r
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Metetra
.664 .741 .908 r
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Metetra
.664 .741 .908 r
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Metetra
.664 .741 .908 r
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Metetra
.664 .741 .908 r
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Metetra
.664 .741 .908 r
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Metetra
.664 .741 .908 r
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Metetra
.664 .741 .908 r
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Metetra
.664 .741 .908 r
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Metetra
.743 .269 0 r
.55833 .50688 .56582 .51499 .58017 .51446 .57304 .5292 Metetra
.908 .6 .45 r
.57304 .5292 .58017 .51446 .59744 .64878 .58982 .64547 Metetra
.534 0 0 r
.58982 .64547 .59744 .64878 .61283 .65791 .60529 .65626 Metetra
.319 0 0 r
.60529 .65626 .61283 .65791 .62828 .66214 .62084 .66178 Metetra
.394 .848 .903 r
.62084 .66178 .62828 .66214 .6436 .65812 .63626 .65777 Metetra
.815 .982 .889 r
.63626 .65777 .6436 .65812 .65873 .64669 .65145 .64516 Metetra
.828 .959 .897 r
.65145 .64516 .65873 .64669 .67387 .63513 .66665 .63258 Metetra
.807 .938 .915 r
.66665 .63258 .67387 .63513 .68908 .62462 .68192 .62127 Metetra
.793 .918 .923 r
.68192 .62127 .68908 .62462 .70422 .61224 .69726 .61076 Metetra
.964 .878 .7 r
.69726 .61076 .70422 .61224 .71495 .52189 .71153 .58014 Metetra
0 0 .241 r
.71153 .58014 .71495 .52189 .72795 .48007 .72261 .49873 Metetra
.72261 .49873 .72795 .48007 .74217 .4608 .73582 .46028 Metetra
.821 .988 .875 r
.73582 .46028 .74217 .4608 .75737 .45613 .75056 .44744 Metetra
.664 .741 .908 r
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Metetra
.664 .741 .908 r
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Metetra
.664 .741 .908 r
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Metetra
.664 .741 .908 r
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Metetra
.664 .741 .908 r
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Metetra
.664 .741 .908 r
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Metetra
.664 .741 .908 r
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Metetra
.664 .741 .908 r
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Metetra
.664 .741 .908 r
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Metetra
.664 .741 .908 r
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Metetra
.664 .741 .908 r
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Metetra
.664 .741 .908 r
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Metetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Metetra
.664 .741 .908 r
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Metetra
.664 .741 .908 r
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Metetra
.664 .741 .908 r
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Metetra
.664 .741 .908 r
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Metetra
.664 .741 .908 r
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Metetra
.664 .741 .908 r
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Metetra
.664 .741 .908 r
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Metetra
.664 .741 .908 r
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Metetra
.664 .741 .908 r
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Metetra
.664 .741 .908 r
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Metetra
.664 .741 .908 r
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Metetra
.664 .741 .908 r
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Metetra
.664 .741 .908 r
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Metetra
.937 .564 .233 r
.55076 .49868 .55833 .50688 .57304 .5292 .56582 .55107 Metetra
.874 .565 .46 r
.56582 .55107 .57304 .5292 .58982 .64547 .5821 .64217 Metetra
.61 .046 0 r
.5821 .64217 .58982 .64547 .60529 .65626 .59766 .65475 Metetra
.442 0 0 r
.59766 .65475 .60529 .65626 .62084 .66178 .61332 .66206 Metetra
.334 .816 .851 r
.61332 .66206 .62084 .66178 .63626 .65777 .62883 .65807 Metetra
.839 .988 .862 r
.62883 .65807 .63626 .65777 .65145 .64516 .64408 .64383 Metetra
.843 .961 .884 r
.64408 .64383 .65145 .64516 .66665 .63258 .65935 .63027 Metetra
.825 .943 .902 r
.65935 .63027 .66665 .63258 .68192 .62127 .67468 .61795 Metetra
.804 .92 .916 r
.67468 .61795 .68192 .62127 .69726 .61076 .69009 .60683 Metetra
.789 .905 .922 r
.69009 .60683 .69726 .61076 .71153 .58014 .70556 .59645 Metetra
.944 .828 .385 r
.70556 .59645 .71153 .58014 .72261 .49873 .7179 .53122 Metetra
0 0 .056 r
.7179 .53122 .72261 .49873 .73582 .46028 .73028 .47425 Metetra
.683 .762 .272 r
.73028 .47425 .73582 .46028 .75056 .44744 .74371 .43911 Metetra
.675 .757 .913 r
.74371 .43911 .75056 .44744 .7659 .4427 .75908 .43387 Metetra
.664 .741 .908 r
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Metetra
.664 .741 .908 r
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Metetra
.664 .741 .908 r
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Metetra
.664 .741 .908 r
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Metetra
.664 .741 .908 r
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Metetra
.664 .741 .908 r
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Metetra
.664 .741 .908 r
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Metetra
.664 .741 .908 r
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Metetra
.664 .741 .908 r
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Metetra
.664 .741 .908 r
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Metetra
.664 .741 .908 r
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Metetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Metetra
.664 .741 .908 r
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Metetra
.664 .741 .908 r
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Metetra
.664 .741 .908 r
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Metetra
.664 .741 .908 r
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Metetra
.664 .741 .908 r
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Metetra
.664 .741 .908 r
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Metetra
.664 .741 .908 r
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Metetra
.664 .741 .908 r
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Metetra
.664 .741 .908 r
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Metetra
.664 .741 .908 r
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Metetra
.664 .741 .908 r
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Metetra
.664 .741 .908 r
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Metetra
.664 .741 .908 r
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Metetra
.959 .64 .376 r
.54311 .4904 .55076 .49868 .56582 .55107 .5587 .60368 Metetra
.698 .415 .491 r
.5587 .60368 .56582 .55107 .5821 .64217 .57429 .63906 Metetra
.685 .14 0 r
.57429 .63906 .5821 .64217 .59766 .65475 .58993 .65385 Metetra
.532 0 0 r
.58993 .65385 .59766 .65475 .61332 .66206 .60568 .66245 Metetra
.321 .808 .842 r
.60568 .66245 .61332 .66206 .62883 .65807 .62129 .65848 Metetra
.857 .986 .849 r
.62129 .65848 .62883 .65807 .64408 .64383 .63662 .64315 Metetra
.865 .969 .86 r
.63662 .64315 .64408 .64383 .65935 .63027 .65195 .62796 Metetra
.838 .942 .892 r
.65195 .62796 .65935 .63027 .67468 .61795 .66736 .61485 Metetra
.819 .926 .905 r
.66736 .61485 .67468 .61795 .69009 .60683 .68282 .60284 Metetra
.798 .905 .916 r
.68282 .60284 .69009 .60683 .70556 .59645 .69836 .59194 Metetra
.814 .892 .899 r
.69836 .59194 .70556 .59645 .7179 .53122 .71388 .58015 Metetra
0 0 .108 r
.71388 .58015 .7179 .53122 .73028 .47425 .725 .49518 Metetra
.725 .49518 .73028 .47425 .74371 .43911 .73801 .44952 Metetra
.73801 .44952 .74371 .43911 .75908 .43387 .75219 .42498 Metetra
.664 .742 .908 r
.75219 .42498 .75908 .43387 .77456 .42905 .76773 .42009 Metetra
.664 .741 .908 r
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Metetra
.664 .741 .908 r
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Metetra
.664 .741 .908 r
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Metetra
.664 .741 .908 r
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Metetra
.664 .741 .908 r
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Metetra
.664 .741 .908 r
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Metetra
.664 .741 .908 r
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Metetra
.664 .741 .908 r
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Metetra
.664 .741 .908 r
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Metetra
.664 .741 .908 r
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Metetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Metetra
.664 .741 .908 r
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Metetra
.664 .741 .908 r
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Metetra
.664 .741 .908 r
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Metetra
.664 .741 .908 r
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Metetra
.664 .741 .908 r
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Metetra
.664 .741 .908 r
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Metetra
.664 .741 .908 r
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Metetra
.664 .741 .908 r
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Metetra
.664 .741 .908 r
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Metetra
.664 .741 .908 r
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Metetra
.664 .741 .908 r
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Metetra
.664 .741 .908 r
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Metetra
.664 .741 .908 r
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Metetra
.96 .649 .395 r
.53539 .48205 .54311 .4904 .5587 .60368 .55094 .6194 Metetra
.708 .34 .35 r
.55094 .6194 .5587 .60368 .57429 .63906 .56638 .636 Metetra
.742 .219 0 r
.56638 .636 .57429 .63906 .58993 .65385 .5821 .65333 Metetra
.625 .063 0 r
.5821 .65333 .58993 .65385 .60568 .66245 .59796 .66421 Metetra
.187 .713 .704 r
.59796 .66421 .60568 .66245 .62129 .65848 .61367 .66029 Metetra
.878 .992 .8 r
.61367 .66029 .62129 .65848 .63662 .64315 .62906 .64234 Metetra
.879 .962 .848 r
.62906 .64234 .63662 .64315 .65195 .62796 .64447 .6261 Metetra
.854 .95 .877 r
.64447 .6261 .65195 .62796 .66736 .61485 .65993 .61181 Metetra
.833 .928 .895 r
.65993 .61181 .66736 .61485 .68282 .60284 .67546 .59896 Metetra
.81 .909 .908 r
.67546 .59896 .68282 .60284 .69836 .59194 .69107 .58738 Metetra
.794 .892 .915 r
.69107 .58738 .69836 .59194 .71388 .58015 .70674 .57661 Metetra
.955 .856 .704 r
.70674 .57661 .71388 .58015 .725 .49518 .72126 .54552 Metetra
0 0 .147 r
.72126 .54552 .725 .49518 .73801 .44952 .73238 .46312 Metetra
.769 .804 .319 r
.73238 .46312 .73801 .44952 .75219 .42498 .74578 .42415 Metetra
.823 .987 .877 r
.74578 .42415 .75219 .42498 .76773 .42009 .76082 .41104 Metetra
.664 .741 .908 r
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Metetra
.664 .741 .908 r
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Metetra
.664 .741 .908 r
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Metetra
.664 .741 .908 r
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Metetra
.664 .741 .908 r
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Metetra
.664 .741 .908 r
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Metetra
.664 .741 .908 r
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Metetra
.664 .741 .908 r
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Metetra
.664 .741 .908 r
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Metetra
.664 .741 .908 r
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Metetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Metetra
.664 .741 .908 r
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Metetra
.664 .741 .908 r
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Metetra
.664 .741 .908 r
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Metetra
.664 .741 .908 r
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Metetra
.664 .741 .908 r
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Metetra
.664 .741 .908 r
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Metetra
.664 .741 .908 r
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Metetra
.664 .741 .908 r
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Metetra
.664 .741 .908 r
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Metetra
.664 .741 .908 r
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Metetra
.664 .741 .908 r
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Metetra
.664 .741 .908 r
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Metetra
.664 .741 .908 r
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Metetra
.96 .65 .397 r
.5276 .47361 .53539 .48205 .55094 .6194 .54289 .61452 Metetra
.732 .213 0 r
.54289 .61452 .55094 .6194 .56638 .636 .55836 .63276 Metetra
.78 .275 0 r
.55836 .63276 .56638 .636 .5821 .65333 .57414 .65259 Metetra
.703 .169 0 r
.57414 .65259 .5821 .65333 .59796 .66421 .59013 .66678 Metetra
.59013 .66678 .59796 .66421 .61367 .66029 .60595 .6629 Metetra
.9 .987 .765 r
.60595 .6629 .61367 .66029 .62906 .64234 .62141 .6425 Metetra
.896 .971 .821 r
.62141 .6425 .62906 .64234 .64447 .6261 .63688 .62443 Metetra
.874 .949 .858 r
.63688 .62443 .64447 .6261 .65993 .61181 .65241 .60863 Metetra
.843 .923 .885 r
.65241 .60863 .65993 .61181 .67546 .59896 .66801 .59504 Metetra
.823 .909 .898 r
.66801 .59504 .67546 .59896 .69107 .58738 .68368 .58265 Metetra
.801 .889 .908 r
.68368 .58265 .69107 .58738 .70674 .57661 .69942 .57141 Metetra
.794 .878 .908 r
.69942 .57141 .70674 .57661 .72126 .54552 .71521 .56047 Metetra
.977 .818 .408 r
.71521 .56047 .72126 .54552 .73238 .46312 .72694 .48259 Metetra
.727 .733 .213 r
.72694 .48259 .73238 .46312 .74578 .42415 .73989 .4326 Metetra
.834 .893 .471 r
.73989 .4326 .74578 .42415 .76082 .41104 .75385 .40194 Metetra
.665 .743 .908 r
.75385 .40194 .76082 .41104 .77651 .4061 .7696 .39691 Metetra
.664 .741 .908 r
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Metetra
.664 .741 .908 r
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Metetra
.664 .741 .908 r
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Metetra
.664 .741 .908 r
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Metetra
.664 .741 .908 r
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Metetra
.664 .741 .908 r
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Metetra
.664 .741 .908 r
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Metetra
.664 .741 .908 r
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Metetra
.664 .741 .908 r
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Metetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Metetra
.664 .741 .908 r
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Metetra
.664 .741 .908 r
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Metetra
.664 .741 .908 r
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Metetra
.664 .741 .908 r
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Metetra
.664 .741 .908 r
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Metetra
.664 .741 .908 r
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Metetra
.664 .741 .908 r
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Metetra
.664 .741 .908 r
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Metetra
.664 .741 .908 r
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Metetra
.664 .741 .908 r
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Metetra
.664 .741 .908 r
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Metetra
.664 .741 .908 r
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Metetra
.662 .741 .908 r
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46514 Metetra
.96 .651 .399 r
.51973 .46514 .5276 .47361 .54289 .61452 .53474 .60942 Metetra
.767 .262 0 r
.53474 .60942 .54289 .61452 .55836 .63276 .55024 .62972 Metetra
.819 .338 .024 r
.55024 .62972 .55836 .63276 .57414 .65259 .56609 .65283 Metetra
.535 .922 .908 r
.56609 .65283 .57414 .65259 .59013 .66678 .58178 .64617 Metetra
.643 .576 .765 r
.58178 .64617 .59013 .66678 .60595 .6629 .59758 .6409 Metetra
.53 .504 .771 r
.59758 .6409 .60595 .6629 .62141 .6425 .61365 .64315 Metetra
.92 .963 .788 r
.61365 .64315 .62141 .6425 .63688 .62443 .62918 .62232 Metetra
.883 .937 .848 r
.62918 .62232 .63688 .62443 .65241 .60863 .64479 .60567 Metetra
.859 .926 .871 r
.64479 .60567 .65241 .60863 .66801 .59504 .66045 .59084 Metetra
.83 .902 .89 r
.66045 .59084 .66801 .59504 .68368 .58265 .6762 .57789 Metetra
.81 .89 .901 r
.6762 .57789 .68368 .58265 .69942 .57141 .69201 .56605 Metetra
.794 .876 .907 r
.69201 .56605 .69942 .57141 .71521 .56047 .70789 .55506 Metetra
.907 .86 .783 r
.70789 .55506 .71521 .56047 .72694 .48259 .72318 .53343 Metetra
0 0 .103 r
.72318 .53343 .72694 .48259 .73989 .4326 .73401 .44335 Metetra
.879 .866 .421 r
.73401 .44335 .73989 .4326 .75385 .40194 .74753 .40306 Metetra
.82 1 .803 r
.74753 .40306 .75385 .40194 .7696 .39691 .76262 .38762 Metetra
.664 .741 .908 r
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Metetra
.664 .741 .908 r
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Metetra
.664 .741 .908 r
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Metetra
.664 .741 .908 r
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Metetra
.664 .741 .908 r
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Metetra
.664 .741 .908 r
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Metetra
.664 .741 .908 r
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Metetra
.664 .741 .908 r
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Metetra
.664 .741 .908 r
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Metetra
.664 .741 .908 r
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Metetra
.664 .741 .908 r
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Metetra
.664 .741 .908 r
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Metetra
.664 .741 .908 r
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Metetra
.664 .741 .908 r
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Metetra
.664 .741 .908 r
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Metetra
.664 .741 .908 r
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Metetra
.664 .741 .908 r
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Metetra
.664 .741 .908 r
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Metetra
.664 .741 .908 r
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Metetra
.664 .741 .908 r
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Metetra
.664 .741 .908 r
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Metetra
.664 .741 .908 r
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Metetra
.274 .565 .934 r
.49724 .46116 .50523 .46972 .51973 .46514 .51175 .46531 Metetra
.944 .636 .421 r
.51175 .46531 .51973 .46514 .53474 .60942 .52649 .60405 Metetra
.798 .307 0 r
.52649 .60405 .53474 .60942 .55024 .62972 .54201 .6266 Metetra
.847 .387 .08 r
.54201 .6266 .55024 .62972 .56609 .65283 .55791 .65329 Metetra
.967 .886 .698 r
.55791 .65329 .56609 .65283 .58178 .64617 .57334 .62076 Metetra
.634 .541 .732 r
.57334 .62076 .58178 .64617 .59758 .6409 .58912 .61522 Metetra
.022 .149 .658 r
.58912 .61522 .59758 .6409 .61365 .64315 .60568 .63987 Metetra
.898 .899 .819 r
.60568 .63987 .61365 .64315 .62918 .62232 .62138 .62084 Metetra
.898 .943 .83 r
.62138 .62084 .62918 .62232 .64479 .60567 .63707 .60264 Metetra
.872 .922 .857 r
.63707 .60264 .64479 .60567 .66045 .59084 .6528 .5867 Metetra
.84 .904 .881 r
.6528 .5867 .66045 .59084 .6762 .57789 .66862 .57297 Metetra
.82 .887 .892 r
.66862 .57297 .6762 .57789 .69201 .56605 .68449 .56042 Metetra
.799 .87 .901 r
.68449 .56042 .69201 .56605 .70789 .55506 .70045 .54904 Metetra
.795 .862 .899 r
.70045 .54904 .70789 .55506 .72318 .53343 .71645 .53778 Metetra
.999 .802 .499 r
.71645 .53778 .72318 .53343 .73401 .44335 .72824 .45818 Metetra
.86 .821 .341 r
.72824 .45818 .73401 .44335 .74753 .40306 .74137 .40837 Metetra
.92 .939 .58 r
.74137 .40837 .74753 .40306 .76262 .38762 .75556 .37828 Metetra
.665 .743 .908 r
.75556 .37828 .76262 .38762 .77851 .38255 .77152 .37312 Metetra
.664 .741 .908 r
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Metetra
.664 .741 .908 r
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Metetra
.664 .741 .908 r
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Metetra
.664 .741 .908 r
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Metetra
.664 .741 .908 r
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Metetra
.664 .741 .908 r
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Metetra
.664 .741 .908 r
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Metetra
.664 .741 .908 r
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Metetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Metetra
.664 .741 .908 r
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Metetra
.664 .741 .908 r
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Metetra
.664 .741 .908 r
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Metetra
.664 .741 .908 r
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Metetra
.664 .741 .908 r
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Metetra
.664 .741 .908 r
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Metetra
.664 .741 .908 r
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Metetra
.664 .741 .908 r
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Metetra
.664 .741 .908 r
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Metetra
.664 .741 .908 r
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Metetra
.664 .741 .908 r
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Metetra
.664 .741 .908 r
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Metetra
.568 .078 0 r
.48916 .45252 .49724 .46116 .51175 .46531 .50363 .46909 Metetra
.936 .625 .427 r
.50363 .46909 .51175 .46531 .52649 .60405 .51813 .59853 Metetra
.822 .346 0 r
.51813 .59853 .52649 .60405 .54201 .6266 .53367 .62329 Metetra
.705 .168 0 r
.53367 .62329 .54201 .6266 .55791 .65329 .5495 .63927 Metetra
.9 .719 .648 r
.5495 .63927 .55791 .65329 .57334 .62076 .56486 .59167 Metetra
.631 .522 .711 r
.56486 .59167 .57334 .62076 .58912 .61522 .58059 .58567 Metetra
0 .011 .566 r
.58059 .58567 .58912 .61522 .60568 .63987 .59724 .61956 Metetra
.565 .54 .786 r
.59724 .61956 .60568 .63987 .62138 .62084 .61347 .61937 Metetra
.913 .935 .81 r
.61347 .61937 .62138 .62084 .63707 .60264 .62923 .59943 Metetra
.882 .915 .844 r
.62923 .59943 .63707 .60264 .6528 .5867 .64504 .58237 Metetra
.85 .899 .871 r
.64504 .58237 .6528 .5867 .66862 .57297 .66093 .5678 Metetra
.827 .882 .883 r
.66093 .5678 .66862 .57297 .68449 .56042 .67688 .55465 Metetra
.805 .869 .895 r
.67688 .55465 .68449 .56042 .70045 .54904 .69291 .54278 Metetra
.79 .857 .9 r
.69291 .54278 .70045 .54904 .71645 .53778 .70901 .53172 Metetra
.954 .815 .668 r
.70901 .53172 .71645 .53778 .72824 .45818 .72352 .49352 Metetra
.72352 .49352 .72824 .45818 .74137 .40837 .73515 .41458 Metetra
.959 .906 .536 r
.73515 .41458 .74137 .40837 .75556 .37828 .74892 .37562 Metetra
.812 .957 .909 r
.74892 .37562 .75556 .37828 .77152 .37312 .76445 .36359 Metetra
.664 .741 .908 r
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Metetra
.664 .741 .908 r
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Metetra
.664 .741 .908 r
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Metetra
.664 .741 .908 r
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Metetra
.664 .741 .908 r
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Metetra
.664 .741 .908 r
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Metetra
.664 .741 .908 r
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Metetra
.664 .741 .908 r
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Metetra
.664 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Metetra
.664 .741 .908 r
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Metetra
.664 .741 .908 r
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Metetra
.664 .741 .908 r
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Metetra
.664 .741 .908 r
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Metetra
.664 .741 .908 r
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Metetra
.664 .741 .908 r
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Metetra
.664 .741 .908 r
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Metetra
.664 .741 .908 r
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Metetra
.664 .741 .908 r
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Metetra
.664 .741 .908 r
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Metetra
.664 .741 .908 r
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Metetra
.664 .741 .908 r
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Metetra
.851 .408 0 r
.48101 .44379 .48916 .45252 .50363 .46909 .49536 .47292 Metetra
.934 .62 .422 r
.49536 .47292 .50363 .46909 .51813 .59853 .50968 .59274 Metetra
.836 .368 0 r
.50968 .59274 .51813 .59853 .53367 .62329 .52521 .61915 Metetra
.32 .737 .977 r
.52521 .61915 .53367 .62329 .5495 .63927 .541 .61918 Metetra
.891 .687 .62 r
.541 .61918 .5495 .63927 .56486 .59167 .55634 .55763 Metetra
.629 .502 .689 r
.55634 .55763 .56486 .59167 .58059 .58567 .572 .55083 Metetra
0 0 .452 r
.572 .55083 .58059 .58567 .59724 .61956 .58874 .59751 Metetra
.048 .201 .701 r
.58874 .59751 .59724 .61956 .61347 .61937 .60543 .61766 Metetra
.927 .919 .787 r
.60543 .61766 .61347 .61937 .62923 .59943 .62126 .59538 Metetra
.883 .895 .835 r
.62126 .59538 .62923 .59943 .64504 .58237 .63717 .57775 Metetra
.86 .891 .857 r
.63717 .57775 .64504 .58237 .66093 .5678 .65313 .56213 Metetra
.829 .871 .875 r
.65313 .56213 .66093 .5678 .67688 .55465 .66916 .54858 Metetra
.812 .863 .886 r
.66916 .54858 .67688 .55465 .69291 .54278 .68526 .53614 Metetra
.792 .849 .894 r
.68526 .53614 .69291 .54278 .70901 .53172 .70144 .52479 Metetra
.812 .846 .875 r
.70144 .52479 .70901 .53172 .72352 .49352 .71757 .51203 Metetra
.965 .799 .365 r
.71757 .51203 .72352 .49352 .73515 .41458 .72885 .42181 Metetra
.968 .886 .507 r
.72885 .42181 .73515 .41458 .74892 .37562 .74243 .37671 Metetra
.927 .973 .73 r
.74243 .37671 .74892 .37562 .76445 .36359 .75732 .35397 Metetra
.664 .742 .908 r
.75732 .35397 .76445 .36359 .78056 .35838 .77349 .3487 Metetra
.664 .741 .908 r
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Metetra
.664 .741 .908 r
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Metetra
.664 .741 .908 r
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Metetra
.664 .741 .908 r
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Metetra
.664 .741 .908 r
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Metetra
.664 .741 .908 r
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Metetra
.664 .741 .908 r
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Metetra
.664 .741 .908 r
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Metetra
.664 .741 .908 r
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Metetra
.664 .741 .908 r
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Metetra
.664 .741 .908 r
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Metetra
.664 .741 .908 r
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Metetra
.664 .741 .908 r
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Metetra
.664 .741 .908 r
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Metetra
.664 .741 .908 r
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Metetra
.664 .741 .908 r
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Metetra
.664 .741 .908 r
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Metetra
.664 .741 .908 r
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Metetra
.664 .741 .908 r
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Metetra
.664 .741 .908 r
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Metetra
.917 .52 .162 r
.47277 .43498 .48101 .44379 .49536 .47292 .48694 .47651 Metetra
.932 .614 .416 r
.48694 .47651 .49536 .47292 .50968 .59274 .50113 .58663 Metetra
.851 .394 .029 r
.50113 .58663 .50968 .59274 .52521 .61915 .51665 .61515 Metetra
.867 .885 .847 r
.51665 .61515 .52521 .61915 .541 .61918 .53246 .59892 Metetra
.912 .691 .591 r
.53246 .59892 .541 .61918 .55634 .55763 .5478 .51519 Metetra
.64 .488 .661 r
.5478 .51519 .55634 .55763 .572 .55083 .56333 .50466 Metetra
0 0 .326 r
.56333 .50466 .572 .55083 .58874 .59751 .5802 .57451 Metetra
0 0 .497 r
.5802 .57451 .58874 .59751 .60543 .61766 .5971 .60741 Metetra
.817 .77 .808 r
.5971 .60741 .60543 .61766 .62126 .59538 .61319 .59152 Metetra
.893 .897 .824 r
.61319 .59152 .62126 .59538 .63717 .57775 .62918 .57272 Metetra
.865 .881 .846 r
.62918 .57272 .63717 .57775 .65313 .56213 .64522 .5563 Metetra
.835 .868 .868 r
.64522 .5563 .65313 .56213 .66916 .54858 .66134 .54217 Metetra
.816 .856 .879 r
.66134 .54217 .66916 .54858 .68526 .53614 .67751 .52927 Metetra
.796 .846 .889 r
.67751 .52927 .68526 .53614 .70144 .52479 .69377 .51756 Metetra
.783 .837 .893 r
.69377 .51756 .70144 .52479 .71757 .51203 .71009 .50651 Metetra
.98 .768 .547 r
.71009 .50651 .71757 .51203 .72885 .42181 .72244 .42943 Metetra
.981 .867 .493 r
.72244 .42943 .72885 .42181 .74243 .37671 .73579 .37732 Metetra
.98 .912 .653 r
.73579 .37732 .74243 .37671 .75732 .35397 .75011 .34428 Metetra
.665 .743 .908 r
.75011 .34428 .75732 .35397 .77349 .3487 .76634 .33891 Metetra
.664 .741 .908 r
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Metetra
.664 .741 .908 r
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Metetra
.664 .741 .908 r
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Metetra
.664 .741 .908 r
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Metetra
.664 .741 .908 r
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Metetra
.664 .741 .908 r
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Metetra
.664 .741 .908 r
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Metetra
.664 .741 .908 r
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Metetra
.664 .741 .908 r
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Metetra
.664 .741 .908 r
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Metetra
.664 .741 .908 r
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Metetra
.664 .741 .908 r
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Metetra
.664 .741 .908 r
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Metetra
.664 .741 .908 r
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Metetra
.664 .741 .908 r
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Metetra
.664 .741 .908 r
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Metetra
.664 .741 .908 r
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Metetra
.664 .741 .908 r
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Metetra
.664 .741 .908 r
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Metetra
.664 .741 .908 r
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Metetra
.94 .572 .25 r
.46446 .42608 .47277 .43498 .48694 .47651 .47837 .48061 Metetra
.927 .605 .41 r
.47837 .48061 .48694 .47651 .50113 .58663 .49248 .58013 Metetra
.863 .415 .05 r
.49248 .58013 .50113 .58663 .51665 .61515 .50797 .61065 Metetra
.937 .821 .706 r
.50797 .61065 .51665 .61515 .53246 .59892 .5239 .57728 Metetra
.929 .691 .556 r
.5239 .57728 .53246 .59892 .5478 .51519 .53923 .44802 Metetra
.613 .437 .62 r
.53923 .44802 .5478 .51519 .56333 .50466 .55455 .43712 Metetra
0 0 .197 r
.55455 .43712 .56333 .50466 .5802 .57451 .57165 .55196 Metetra
0 0 .355 r
.57165 .55196 .5802 .57451 .5971 .60741 .58857 .59119 Metetra
.629 .621 .824 r
.58857 .59119 .5971 .60741 .61319 .59152 .605 .58713 Metetra
.897 .883 .811 r
.605 .58713 .61319 .59152 .62918 .57272 .62108 .56719 Metetra
.868 .87 .836 r
.62108 .56719 .62918 .57272 .64522 .5563 .6372 .55003 Metetra
.838 .859 .86 r
.6372 .55003 .64522 .5563 .66134 .54217 .6534 .53534 Metetra
.818 .848 .871 r
.6534 .53534 .66134 .54217 .67751 .52927 .66966 .52202 Metetra
.798 .839 .882 r
.66966 .52202 .67751 .52927 .69377 .51756 .68599 .50998 Metetra
.784 .831 .889 r
.68599 .50998 .69377 .51756 .71009 .50651 .70239 .49874 Metetra
.958 .787 .627 r
.70239 .49874 .71009 .50651 .72244 .42943 .71666 .4503 Metetra
.889 .787 .296 r
.71666 .4503 .72244 .42943 .73579 .37732 .72902 .37757 Metetra
.988 .886 .625 r
.72902 .37757 .73579 .37732 .75011 .34428 .74315 .33914 Metetra
.775 .895 .928 r
.74315 .33914 .75011 .34428 .76634 .33891 .75912 .32902 Metetra
.664 .741 .908 r
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Metetra
.664 .741 .908 r
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Metetra
.664 .741 .908 r
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Metetra
.664 .741 .908 r
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Metetra
.664 .741 .908 r
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Metetra
.664 .741 .908 r
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Metetra
.664 .741 .908 r
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Metetra
.664 .741 .908 r
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Metetra
.664 .741 .908 r
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Metetra
.664 .741 .908 r
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Metetra
.664 .741 .908 r
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Metetra
.664 .741 .908 r
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Metetra
.664 .741 .908 r
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Metetra
.664 .741 .908 r
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Metetra
.664 .741 .908 r
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Metetra
.664 .741 .908 r
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Metetra
.664 .741 .908 r
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Metetra
.664 .741 .908 r
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Metetra
.664 .741 .908 r
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Metetra
.664 .741 .908 r
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Metetra
.948 .597 .296 r
.45606 .41709 .46446 .42608 .47837 .48061 .46968 .48296 Metetra
.929 .6 .396 r
.46968 .48296 .47837 .48061 .49248 .58013 .48373 .57319 Metetra
.872 .431 .065 r
.48373 .57319 .49248 .58013 .50797 .61065 .49918 .6055 Metetra
.949 .787 .647 r
.49918 .6055 .50797 .61065 .5239 .57728 .5153 .5575 Metetra
.941 .695 .537 r
.5153 .5575 .5239 .57728 .53923 .44802 .53089 .39228 Metetra
.591 .432 .634 r
.53089 .39228 .53923 .44802 .55455 .43712 .5461 .38723 Metetra
.893 .619 .108 r
.5461 .38723 .55455 .43712 .57165 .55196 .56306 .52773 Metetra
0 0 .242 r
.56306 .52773 .57165 .55196 .58857 .59119 .58 .57517 Metetra
.347 .474 .846 r
.58 .57517 .58857 .59119 .605 .58713 .59668 .582 Metetra
.902 .865 .794 r
.59668 .582 .605 .58713 .62108 .56719 .61284 .56049 Metetra
.86 .846 .829 r
.61284 .56049 .62108 .56719 .6372 .55003 .62907 .54323 Metetra
.842 .848 .849 r
.62907 .54323 .6372 .55003 .6534 .53534 .64535 .52784 Metetra
.815 .834 .864 r
.64535 .52784 .6534 .53534 .66966 .52202 .66169 .51436 Metetra
.799 .831 .876 r
.66169 .51436 .66966 .52202 .68599 .50998 .67811 .50201 Metetra
.785 .824 .883 r
.67811 .50201 .68599 .50998 .70239 .49874 .69459 .49053 Metetra
.889 .822 .775 r
.69459 .49053 .70239 .49874 .71666 .4503 .7105 .4682 Metetra
.969 .799 .371 r
.7105 .4682 .71666 .4503 .72902 .37757 .72204 .37625 Metetra
.988 .862 .624 r
.72204 .37625 .72902 .37757 .74315 .33914 .73616 .33501 Metetra
.874 .922 .855 r
.73616 .33501 .74315 .33914 .75912 .32902 .75182 .31903 Metetra
.664 .741 .908 r
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Metetra
.664 .741 .908 r
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Metetra
.664 .741 .908 r
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Metetra
.664 .741 .908 r
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Metetra
.664 .741 .908 r
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Metetra
.664 .741 .908 r
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Metetra
.664 .741 .908 r
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Metetra
.664 .741 .908 r
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Metetra
.664 .741 .908 r
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Metetra
.664 .741 .908 r
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Metetra
.664 .741 .908 r
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Metetra
.664 .741 .908 r
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Metetra
.664 .741 .908 r
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Metetra
.664 .741 .908 r
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Metetra
.664 .741 .908 r
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Metetra
.664 .741 .908 r
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Metetra
.664 .741 .908 r
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Metetra
.664 .741 .908 r
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Metetra
.664 .741 .908 r
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Metetra
.664 .741 .908 r
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Metetra
.953 .615 .331 r
.44757 .40801 .45606 .41709 .46968 .48296 .4608 .4871 Metetra
.918 .583 .391 r
.4608 .4871 .46968 .48296 .48373 .57319 .47489 .56578 Metetra
.878 .442 .074 r
.47489 .56578 .48373 .57319 .49918 .6055 .49029 .59955 Metetra
.952 .765 .614 r
.49029 .59955 .49918 .6055 .5153 .5575 .50667 .53749 Metetra
.939 .695 .542 r
.50667 .53749 .5153 .5575 .53089 .39228 .52267 .38294 Metetra
.664 .741 .908 r
.52267 .38294 .53089 .39228 .5461 .38723 .53793 .37785 Metetra
.962 .638 .349 r
.53793 .37785 .5461 .38723 .56306 .52773 .55447 .50595 Metetra
.808 .46 0 r
.55447 .50595 .56306 .52773 .58 .57517 .57138 .5603 Metetra
0 .215 .739 r
.57138 .5603 .58 .57517 .59668 .582 .58824 .57599 Metetra
.899 .848 .785 r
.58824 .57599 .59668 .582 .61284 .56049 .6045 .55363 Metetra
.863 .844 .824 r
.6045 .55363 .61284 .56049 .62907 .54323 .62082 .53583 Metetra
.842 .837 .841 r
.62082 .53583 .62907 .54323 .64535 .52784 .63719 .52002 Metetra
.816 .829 .859 r
.63719 .52002 .64535 .52784 .66169 .51436 .65362 .50624 Metetra
.801 .823 .869 r
.65362 .50624 .66169 .51436 .67811 .50201 .67011 .49355 Metetra
.783 .815 .878 r
.67011 .49355 .67811 .50201 .69459 .49053 .68668 .48194 Metetra
.809 .818 .857 r
.68668 .48194 .69459 .49053 .7105 .4682 .70318 .46839 Metetra
.994 .775 .496 r
.70318 .46839 .7105 .4682 .72204 .37625 .71487 .37364 Metetra
.985 .843 .619 r
.71487 .37364 .72204 .37625 .73616 .33501 .72899 .32957 Metetra
.908 .881 .796 r
.72899 .32957 .73616 .33501 .75182 .31903 .74444 .30893 Metetra
.664 .741 .908 r
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Metetra
.664 .741 .908 r
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Metetra
.664 .741 .908 r
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Metetra
.664 .741 .908 r
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Metetra
.664 .741 .908 r
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Metetra
.664 .741 .908 r
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Metetra
.664 .741 .908 r
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Metetra
.664 .741 .908 r
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Metetra
.664 .741 .908 r
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Metetra
.664 .741 .908 r
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Metetra
.664 .741 .908 r
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Metetra
.664 .741 .908 r
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Metetra
.664 .741 .908 r
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Metetra
.664 .741 .908 r
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Metetra
.664 .741 .908 r
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Metetra
.664 .741 .908 r
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Metetra
.664 .741 .908 r
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Metetra
.664 .741 .908 r
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Metetra
.664 .741 .908 r
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Metetra
.664 .741 .908 r
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Metetra
.956 .627 .355 r
.439 .39883 .44757 .40801 .4608 .4871 .45176 .4912 Metetra
.91 .564 .375 r
.45176 .4912 .4608 .4871 .47489 .56578 .46595 .55784 Metetra
.881 .449 .075 r
.46595 .55784 .47489 .56578 .49029 .59955 .4813 .59265 Metetra
.952 .751 .597 r
.4813 .59265 .49029 .59955 .50667 .53749 .49798 .52015 Metetra
.942 .7 .542 r
.49798 .52015 .50667 .53749 .52267 .38294 .51436 .37351 Metetra
.664 .741 .908 r
.51436 .37351 .52267 .38294 .53793 .37785 .52969 .36836 Metetra
.961 .634 .341 r
.52969 .36836 .53793 .37785 .55447 .50595 .54589 .48803 Metetra
.892 .525 .055 r
.54589 .48803 .55447 .50595 .57138 .5603 .56272 .54719 Metetra
0 0 .514 r
.56272 .54719 .57138 .5603 .58824 .57599 .57967 .56897 Metetra
.894 .831 .777 r
.57967 .56897 .58824 .57599 .6045 .55363 .59604 .54599 Metetra
.86 .83 .816 r
.59604 .54599 .6045 .55363 .62082 .53583 .61246 .52777 Metetra
.839 .825 .834 r
.61246 .52777 .62082 .53583 .63719 .52002 .62891 .51164 Metetra
.815 .819 .853 r
.62891 .51164 .63719 .52002 .65362 .50624 .64543 .49762 Metetra
.8 .814 .863 r
.64543 .49762 .65362 .50624 .67011 .49355 .66201 .48473 Metetra
.783 .809 .874 r
.66201 .48473 .67011 .49355 .68668 .48194 .67866 .47295 Metetra
.8 .81 .86 r
.67866 .47295 .68668 .48194 .70318 .46839 .69528 .45992 Metetra
.975 .749 .532 r
.69528 .45992 .70318 .46839 .71487 .37364 .70749 .36933 Metetra
.98 .823 .617 r
.70749 .36933 .71487 .37364 .72899 .32957 .72165 .32285 Metetra
.919 .85 .759 r
.72165 .32285 .72899 .32957 .74444 .30893 .73699 .29873 Metetra
.664 .742 .908 r
.73699 .29873 .74444 .30893 .76097 .30341 .75358 .29314 Metetra
.664 .741 .908 r
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Metetra
.664 .741 .908 r
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Metetra
.664 .741 .908 r
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Metetra
.664 .741 .908 r
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Metetra
.664 .741 .908 r
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Metetra
.664 .741 .908 r
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Metetra
.664 .741 .908 r
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Metetra
.664 .741 .908 r
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Metetra
.664 .741 .908 r
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Metetra
.664 .741 .908 r
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Metetra
.664 .741 .908 r
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Metetra
.664 .741 .908 r
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Metetra
.664 .741 .908 r
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Metetra
.664 .741 .908 r
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Metetra
.664 .741 .908 r
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Metetra
.664 .741 .908 r
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Metetra
.664 .741 .908 r
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Metetra
.664 .741 .908 r
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Metetra
.664 .741 .908 r
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Metetra
.957 .632 .364 r
.43034 .38956 .439 .39883 .45176 .4912 .44271 .48876 Metetra
.927 .567 .322 r
.44271 .48876 .45176 .4912 .46595 .55784 .45691 .54936 Metetra
.882 .451 .071 r
.45691 .54936 .46595 .55784 .4813 .59265 .47221 .58473 Metetra
.95 .744 .591 r
.47221 .58473 .4813 .59265 .49798 .52015 .4892 .50679 Metetra
.949 .709 .54 r
.4892 .50679 .49798 .52015 .51436 .37351 .50597 .36399 Metetra
.664 .741 .908 r
.50597 .36399 .51436 .37351 .52969 .36836 .52135 .35878 Metetra
.96 .631 .336 r
.52135 .35878 .52969 .36836 .54589 .48803 .53727 .47426 Metetra
.925 .551 .144 r
.53727 .47426 .54589 .48803 .56272 .54719 .554 .53594 Metetra
.646 .189 0 r
.554 .53594 .56272 .54719 .57967 .56897 .57098 .56084 Metetra
.887 .814 .77 r
.57098 .56084 .57967 .56897 .59604 .54599 .58747 .53748 Metetra
.855 .815 .809 r
.58747 .53748 .59604 .54599 .61246 .52777 .60399 .519 Metetra
.836 .812 .827 r
.60399 .519 .61246 .52777 .62891 .51164 .62053 .50266 Metetra
.812 .809 .847 r
.62053 .50266 .62891 .51164 .64543 .49762 .63714 .48848 Metetra
.798 .805 .858 r
.63714 .48848 .64543 .49762 .66201 .48473 .6538 .47544 Metetra
.781 .801 .869 r
.6538 .47544 .66201 .48473 .67866 .47295 .67054 .46355 Metetra
.793 .802 .859 r
.67054 .46355 .67866 .47295 .69528 .45992 .68727 .45073 Metetra
.973 .748 .537 r
.68727 .45073 .69528 .45992 .70749 .36933 .69985 .36212 Metetra
.966 .797 .622 r
.69985 .36212 .70749 .36933 .72165 .32285 .71411 .31435 Metetra
.912 .819 .741 r
.71411 .31435 .72165 .32285 .73699 .29873 .72945 .28842 Metetra
.664 .742 .908 r
.72945 .28842 .73699 .29873 .75358 .29314 .74611 .28276 Metetra
.664 .741 .908 r
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Metetra
.664 .741 .908 r
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Metetra
.664 .741 .908 r
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Metetra
.664 .741 .908 r
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Metetra
.664 .741 .908 r
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Metetra
.664 .741 .908 r
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Metetra
.664 .741 .908 r
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Metetra
.664 .741 .908 r
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Metetra
.664 .741 .908 r
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Metetra
.664 .741 .908 r
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Metetra
.664 .741 .908 r
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Metetra
.664 .741 .908 r
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Metetra
.664 .741 .908 r
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Metetra
.664 .741 .908 r
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Metetra
.664 .741 .908 r
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Metetra
.664 .741 .908 r
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Metetra
.664 .741 .908 r
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Metetra
.664 .741 .908 r
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Metetra
.664 .741 .908 r
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Metetra
.957 .632 .364 r
.42159 .3802 .43034 .38956 .44271 .48876 .43372 .47959 Metetra
.942 .578 .264 r
.43372 .47959 .44271 .48876 .45691 .54936 .44779 .54031 Metetra
.879 .449 .059 r
.44779 .54031 .45691 .54936 .47221 .58473 .46304 .57574 Metetra
.946 .74 .592 r
.46304 .57574 .47221 .58473 .4892 .50679 .48029 .49754 Metetra
.957 .718 .535 r
.48029 .49754 .4892 .50679 .50597 .36399 .49749 .35436 Metetra
.664 .741 .908 r
.49749 .35436 .50597 .36399 .52135 .35878 .51293 .3491 Metetra
.96 .631 .336 r
.51293 .3491 .52135 .35878 .53727 .47426 .52859 .46481 Metetra
.934 .557 .204 r
.52859 .46481 .53727 .47426 .554 .53594 .54521 .52661 Metetra
.712 .233 0 r
.54521 .52661 .554 .53594 .57098 .56084 .56218 .55154 Metetra
.879 .797 .766 r
.56218 .55154 .57098 .56084 .58747 .53748 .57878 .52807 Metetra
.848 .8 .804 r
.57878 .52807 .58747 .53748 .60399 .519 .5954 .5095 Metetra
.831 .8 .822 r
.5954 .5095 .60399 .519 .62053 .50266 .61204 .49307 Metetra
.808 .798 .842 r
.61204 .49307 .62053 .50266 .63714 .48848 .62874 .4788 Metetra
.794 .796 .853 r
.62874 .4788 .63714 .48848 .6538 .47544 .64549 .46569 Metetra
.779 .793 .864 r
.64549 .46569 .6538 .47544 .67054 .46355 .66231 .45372 Metetra
.791 .796 .856 r
.66231 .45372 .67054 .46355 .68727 .45073 .67912 .44082 Metetra
.971 .745 .538 r
.67912 .44082 .68727 .45073 .69985 .36212 .69196 .35194 Metetra
.95 .773 .627 r
.69196 .35194 .69985 .36212 .71411 .31435 .70638 .30402 Metetra
.897 .792 .736 r
.70638 .30402 .71411 .31435 .72945 .28842 .72184 .27799 Metetra
.664 .742 .908 r
.72184 .27799 .72945 .28842 .74611 .28276 .73856 .27227 Metetra
.664 .741 .908 r
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Metetra
.664 .741 .908 r
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Metetra
.664 .741 .908 r
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Metetra
.664 .741 .908 r
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Metetra
.664 .741 .908 r
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Metetra
.664 .741 .908 r
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Metetra
.664 .741 .908 r
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Metetra
.664 .741 .908 r
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Metetra
.664 .741 .908 r
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Metetra
.664 .741 .908 r
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Metetra
.664 .741 .908 r
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Metetra
.664 .741 .908 r
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Metetra
.664 .741 .908 r
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Metetra
.664 .741 .908 r
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Metetra
.664 .741 .908 r
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Metetra
.664 .741 .908 r
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Metetra
.664 .741 .908 r
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Metetra
.664 .741 .908 r
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Metetra
.664 .741 .908 r
.39777 .37588 .40666 .38529 .42159 .3802 .41275 .37074 Metetra
.956 .627 .355 r
.41275 .37074 .42159 .3802 .43372 .47959 .42483 .46364 Metetra
.948 .595 .221 r
.42483 .46364 .43372 .47959 .44779 .54031 .43858 .53069 Metetra
.873 .442 .04 r
.43858 .53069 .44779 .54031 .46304 .57574 .45378 .56567 Metetra
.941 .738 .6 r
.45378 .56567 .46304 .57574 .48029 .49754 .47121 .49245 Metetra
.964 .726 .528 r
.47121 .49245 .48029 .49754 .49749 .35436 .48892 .34463 Metetra
.664 .741 .908 r
.48892 .34463 .49749 .35436 .51293 .3491 .50442 .33932 Metetra
.961 .634 .341 r
.50442 .33932 .51293 .3491 .52859 .46481 .5198 .45971 Metetra
.929 .548 .244 r
.5198 .45971 .52859 .46481 .54521 .52661 .53632 .51921 Metetra
.703 .197 0 r
.53632 .51921 .54521 .52661 .56218 .55154 .55327 .54105 Metetra
.869 .782 .763 r
.55327 .54105 .56218 .55154 .57878 .52807 .56998 .51774 Metetra
.841 .786 .799 r
.56998 .51774 .57878 .52807 .5954 .5095 .5867 .49925 Metetra
.824 .788 .818 r
.5867 .49925 .5954 .5095 .61204 .49307 .60344 .48285 Metetra
.804 .788 .838 r
.60344 .48285 .61204 .49307 .62874 .4788 .62023 .46858 Metetra
.791 .787 .849 r
.62023 .46858 .62874 .4788 .64549 .46569 .63707 .45545 Metetra
.776 .785 .861 r
.63707 .45545 .64549 .46569 .66231 .45372 .65398 .44345 Metetra
.793 .79 .849 r
.65398 .44345 .66231 .45372 .67912 .44082 .67086 .43017 Metetra
.97 .742 .537 r
.67086 .43017 .67912 .44082 .69196 .35194 .68385 .33879 Metetra
.932 .751 .634 r
.68385 .33879 .69196 .35194 .70638 .30402 .69848 .29186 Metetra
.874 .767 .741 r
.69848 .29186 .70638 .30402 .72184 .27799 .71413 .26744 Metetra
.664 .741 .908 r
.71413 .26744 .72184 .27799 .73856 .27227 .73093 .26167 Metetra
.664 .741 .908 r
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Metetra
.664 .741 .908 r
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Metetra
.664 .741 .908 r
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Metetra
.664 .741 .908 r
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Metetra
.664 .741 .908 r
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Metetra
.664 .741 .908 r
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Metetra
.664 .741 .908 r
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Metetra
.664 .741 .908 r
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Metetra
.664 .741 .908 r
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Metetra
.664 .741 .908 r
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Metetra
.664 .741 .908 r
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Metetra
.664 .741 .908 r
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Metetra
.664 .741 .908 r
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Metetra
.664 .741 .908 r
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Metetra
.664 .741 .908 r
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Metetra
.664 .741 .908 r
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Metetra
.664 .741 .908 r
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Metetra
.664 .741 .908 r
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Metetra
.664 .741 .908 r
.38879 .36638 .39777 .37588 .41275 .37074 .40382 .36119 Metetra
.953 .615 .331 r
.40382 .36119 .41275 .37074 .42483 .46364 .41611 .441 Metetra
.951 .618 .211 r
.41611 .441 .42483 .46364 .43858 .53069 .42929 .5205 Metetra
.863 .429 .013 r
.42929 .5205 .43858 .53069 .45378 .56567 .44445 .55455 Metetra
.932 .738 .618 r
.44445 .55455 .45378 .56567 .47121 .49245 .46193 .49142 Metetra
.971 .732 .52 r
.46193 .49142 .47121 .49245 .48892 .34463 .48027 .3348 Metetra
.664 .741 .908 r
.48027 .3348 .48892 .34463 .50442 .33932 .49582 .32943 Metetra
.962 .638 .349 r
.49582 .32943 .50442 .33932 .5198 .45971 .51088 .45885 Metetra
.914 .53 .269 r
.51088 .45885 .5198 .45971 .53632 .51921 .52733 .51371 Metetra
.601 .052 0 r
.52733 .51371 .53632 .51921 .55327 .54105 .54426 .52941 Metetra
.858 .767 .761 r
.54426 .52941 .55327 .54105 .56998 .51774 .56108 .50653 Metetra
.832 .773 .796 r
.56108 .50653 .56998 .51774 .5867 .49925 .5779 .48827 Metetra
.817 .777 .815 r
.5779 .48827 .5867 .49925 .60344 .48285 .59473 .47201 Metetra
.798 .778 .834 r
.59473 .47201 .60344 .48285 .62023 .46858 .61161 .45782 Metetra
.786 .778 .846 r
.61161 .45782 .62023 .46858 .63707 .45545 .62854 .44474 Metetra
.772 .778 .857 r
.62854 .44474 .63707 .45545 .65398 .44345 .64554 .43275 Metetra
.798 .785 .841 r
.64554 .43275 .65398 .44345 .67086 .43017 .66249 .4188 Metetra
.969 .737 .532 r
.66249 .4188 .67086 .43017 .68385 .33879 .67551 .32267 Metetra
.912 .729 .642 r
.67551 .32267 .68385 .33879 .69848 .29186 .6904 .27787 Metetra
.839 .74 .755 r
.6904 .27787 .69848 .29186 .71413 .26744 .70635 .25677 Metetra
.664 .741 .908 r
.70635 .25677 .71413 .26744 .73093 .26167 .72322 .25095 Metetra
.664 .741 .908 r
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Metetra
.664 .741 .908 r
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Metetra
.664 .741 .908 r
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Metetra
.664 .741 .908 r
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Metetra
.664 .741 .908 r
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Metetra
.664 .741 .908 r
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Metetra
.664 .741 .908 r
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Metetra
.664 .741 .908 r
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Metetra
.664 .741 .908 r
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Metetra
.664 .741 .908 r
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Metetra
.664 .741 .908 r
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Metetra
.664 .741 .908 r
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Metetra
.664 .741 .908 r
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Metetra
.664 .741 .908 r
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Metetra
.664 .741 .908 r
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Metetra
.664 .741 .908 r
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Metetra
.664 .741 .908 r
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Metetra
.664 .741 .908 r
.36472 .36199 .37384 .37154 .38879 .36638 .37972 .35677 Metetra
.664 .741 .908 r
.37972 .35677 .38879 .36638 .40382 .36119 .3948 .35153 Metetra
.948 .597 .296 r
.3948 .35153 .40382 .36119 .41611 .441 .40736 .41818 Metetra
.962 .636 .257 r
.40736 .41818 .41611 .441 .42929 .5205 .41991 .50977 Metetra
.848 .409 0 r
.41991 .50977 .42929 .5205 .44445 .55455 .43505 .54243 Metetra
.916 .74 .649 r
.43505 .54243 .44445 .55455 .46193 .49142 .45244 .49321 Metetra
.974 .735 .513 r
.45244 .49321 .46193 .49142 .48027 .3348 .47152 .32487 Metetra
.664 .741 .908 r
.47152 .32487 .48027 .3348 .49582 .32943 .48713 .31945 Metetra
.963 .643 .359 r
.48713 .31945 .49582 .32943 .51088 .45885 .50178 .462 Metetra
.89 .499 .283 r
.50178 .462 .51088 .45885 .52733 .51371 .51821 .51005 Metetra
0 .329 .663 r
.51821 .51005 .52733 .51371 .54426 .52941 .53515 .51672 Metetra
.846 .754 .761 r
.53515 .51672 .54426 .52941 .56108 .50653 .55208 .49448 Metetra
.823 .761 .794 r
.55208 .49448 .56108 .50653 .5779 .48827 .569 .47659 Metetra
.81 .766 .812 r
.569 .47659 .5779 .48827 .59473 .47201 .58593 .46059 Metetra
.792 .768 .831 r
.58593 .46059 .59473 .47201 .61161 .45782 .6029 .44655 Metetra
.78 .77 .844 r
.6029 .44655 .61161 .45782 .62854 .44474 .61992 .43365 Metetra
.77 .772 .855 r
.61992 .43365 .62854 .44474 .64554 .43275 .63699 .42163 Metetra
.871 .786 .765 r
.63699 .42163 .64554 .43275 .66249 .4188 .65367 .39858 Metetra
.944 .708 .55 r
.65367 .39858 .66249 .4188 .67551 .32267 .66705 .30476 Metetra
.896 .715 .65 r
.66705 .30476 .67551 .32267 .6904 .27787 .68219 .26256 Metetra
.793 .712 .776 r
.68219 .26256 .6904 .27787 .70635 .25677 .69848 .24599 Metetra
.664 .741 .908 r
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Metetra
.664 .741 .908 r
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Metetra
.664 .741 .908 r
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Metetra
.664 .741 .908 r
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Metetra
.664 .741 .908 r
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Metetra
.664 .741 .908 r
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Metetra
.664 .741 .908 r
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Metetra
.664 .741 .908 r
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Metetra
.664 .741 .908 r
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Metetra
.664 .741 .908 r
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Metetra
.664 .741 .908 r
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Metetra
.664 .741 .908 r
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Metetra
.664 .741 .908 r
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Metetra
.664 .741 .908 r
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Metetra
.664 .741 .908 r
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Metetra
.664 .741 .908 r
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Metetra
.664 .741 .908 r
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Metetra
.664 .741 .908 r
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35234 Metetra
.664 .741 .908 r
.35549 .35234 .36472 .36199 .37972 .35677 .37055 .34707 Metetra
.664 .741 .908 r
.37055 .34707 .37972 .35677 .3948 .35153 .38569 .34178 Metetra
.94 .572 .25 r
.38569 .34178 .3948 .35153 .40736 .41818 .39853 .39707 Metetra
.968 .645 .298 r
.39853 .39707 .40736 .41818 .41991 .50977 .41045 .49852 Metetra
.826 .382 0 r
.41045 .49852 .41991 .50977 .43505 .54243 .42558 .52945 Metetra
.885 .74 .696 r
.42558 .52945 .43505 .54243 .45244 .49321 .44278 .49487 Metetra
.976 .748 .527 r
.44278 .49487 .45244 .49321 .47152 .32487 .46174 .36228 Metetra
.363 .059 .309 r
.46174 .36228 .47152 .32487 .48713 .31945 .47773 .35076 Metetra
.878 .56 .444 r
.47773 .35076 .48713 .31945 .50178 .462 .49249 .4678 Metetra
.859 .458 .276 r
.49249 .4678 .50178 .462 .51821 .51005 .50894 .50762 Metetra
.489 .873 .972 r
.50894 .50762 .51821 .51005 .53515 .51672 .52595 .50308 Metetra
.831 .741 .766 r
.52595 .50308 .53515 .51672 .55208 .49448 .54299 .48225 Metetra
.822 .76 .794 r
.54299 .48225 .55208 .49448 .569 .47659 .56 .46427 Metetra
.8 .756 .813 r
.56 .46427 .569 .47659 .58593 .46059 .57702 .44882 Metetra
.79 .764 .83 r
.57702 .44882 .58593 .46059 .6029 .44655 .59408 .43477 Metetra
.774 .762 .842 r
.59408 .43477 .6029 .44655 .61992 .43365 .61118 .42203 Metetra
.765 .764 .851 r
.61118 .42203 .61992 .43365 .63699 .42163 .62835 .41011 Metetra
.943 .765 .631 r
.62835 .41011 .63699 .42163 .65367 .39858 .64413 .36015 Metetra
.869 .637 .585 r
.64413 .36015 .65367 .39858 .66705 .30476 .65847 .28546 Metetra
.882 .704 .657 r
.65847 .28546 .66705 .30476 .68219 .26256 .67385 .24585 Metetra
.721 .669 .799 r
.67385 .24585 .68219 .26256 .69848 .24599 .69052 .2351 Metetra
.664 .741 .908 r
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Metetra
.664 .741 .908 r
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Metetra
.664 .741 .908 r
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Metetra
.664 .741 .908 r
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Metetra
.664 .741 .908 r
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Metetra
.664 .741 .908 r
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Metetra
.664 .741 .908 r
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Metetra
.664 .741 .908 r
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Metetra
.664 .741 .908 r
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Metetra
.664 .741 .908 r
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Metetra
.664 .741 .908 r
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Metetra
.664 .741 .908 r
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Metetra
.664 .741 .908 r
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Metetra
.664 .741 .908 r
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Metetra
.664 .741 .908 r
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Metetra
.664 .741 .908 r
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Metetra
.664 .741 .908 r
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Metetra
.664 .741 .908 r
.33116 .34789 .34053 .35758 .35549 .35234 .34618 .34259 Metetra
.664 .741 .908 r
.34618 .34259 .35549 .35234 .37055 .34707 .36128 .33727 Metetra
.664 .741 .908 r
.36128 .33727 .37055 .34707 .38569 .34178 .37647 .33192 Metetra
.917 .52 .162 r
.37647 .33192 .38569 .34178 .39853 .39707 .38974 .37404 Metetra
.971 .655 .311 r
.38974 .37404 .39853 .39707 .41045 .49852 .40091 .48679 Metetra
.796 .347 0 r
.40091 .48679 .41045 .49852 .42558 .52945 .41605 .51575 Metetra
.801 .727 .783 r
.41605 .51575 .42558 .52945 .44278 .49487 .43289 .49857 Metetra
.985 .788 .557 r
.43289 .49857 .44278 .49487 .46174 .36228 .45131 .41191 Metetra
.409 .121 .36 r
.45131 .41191 .46174 .36228 .47773 .35076 .46767 .40063 Metetra
.784 .469 .457 r
.46767 .40063 .47773 .35076 .49249 .4678 .48301 .47203 Metetra
.844 .421 .228 r
.48301 .47203 .49249 .4678 .50894 .50762 .49953 .50549 Metetra
.868 .95 .864 r
.49953 .50549 .50894 .50762 .52595 .50308 .51668 .48862 Metetra
.819 .731 .768 r
.51668 .48862 .52595 .50308 .54299 .48225 .5338 .46877 Metetra
.808 .742 .79 r
.5338 .46877 .54299 .48225 .56 .46427 .5509 .45136 Metetra
.792 .748 .812 r
.5509 .45136 .56 .46427 .57702 .44882 .56802 .43632 Metetra
.781 .752 .827 r
.56802 .43632 .57702 .44882 .59408 .43477 .58516 .42254 Metetra
.769 .755 .84 r
.58516 .42254 .59408 .43477 .61118 .42203 .60235 .40999 Metetra
.762 .757 .849 r
.60235 .40999 .61118 .42203 .62835 .41011 .6196 .3981 Metetra
.962 .744 .561 r
.6196 .3981 .62835 .41011 .64413 .36015 .63452 .31841 Metetra
.819 .602 .609 r
.63452 .31841 .64413 .36015 .65847 .28546 .64978 .26447 Metetra
.855 .686 .672 r
.64978 .26447 .65847 .28546 .67385 .24585 .6655 .23012 Metetra
.654 .654 .837 r
.6655 .23012 .67385 .24585 .69052 .2351 .68248 .22408 Metetra
.664 .741 .908 r
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Metetra
.664 .741 .908 r
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Metetra
.664 .741 .908 r
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Metetra
.664 .741 .908 r
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Metetra
.664 .741 .908 r
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Metetra
.664 .741 .908 r
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Metetra
.664 .741 .908 r
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Metetra
.664 .741 .908 r
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Metetra
.664 .741 .908 r
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Metetra
.664 .741 .908 r
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Metetra
.664 .741 .908 r
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Metetra
.664 .741 .908 r
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Metetra
.664 .741 .908 r
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Metetra
.664 .741 .908 r
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Metetra
.664 .741 .908 r
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Metetra
.664 .741 .908 r
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Metetra
.664 .741 .908 r
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .33809 Metetra
.664 .741 .908 r
.32169 .33809 .33116 .34789 .34618 .34259 .33676 .33274 Metetra
.664 .741 .908 r
.33676 .33274 .34618 .34259 .36128 .33727 .35192 .32736 Metetra
.664 .741 .908 r
.35192 .32736 .36128 .33727 .37647 .33192 .36716 .32195 Metetra
.851 .408 0 r
.36716 .32195 .37647 .33192 .38974 .37404 .38091 .3514 Metetra
.972 .66 .332 r
.38091 .3514 .38974 .37404 .40091 .48679 .39129 .47463 Metetra
.756 .302 0 r
.39129 .47463 .40091 .48679 .41605 .51575 .40644 .50147 Metetra
.527 .62 .888 r
.40644 .50147 .41605 .51575 .43289 .49857 .42285 .50097 Metetra
.985 .816 .594 r
.42285 .50097 .43289 .49857 .45131 .41191 .44106 .43668 Metetra
.334 0 .197 r
.44106 .43668 .45131 .41191 .46767 .40063 .45759 .42909 Metetra
.79 .446 .406 r
.45759 .42909 .46767 .40063 .48301 .47203 .47334 .47688 Metetra
.76 .292 .134 r
.47334 .47688 .48301 .47203 .49953 .50549 .49003 .49722 Metetra
.888 .82 .776 r
.49003 .49722 .49953 .50549 .51668 .48862 .50732 .47355 Metetra
.807 .723 .771 r
.50732 .47355 .51668 .48862 .5338 .46877 .52453 .45471 Metetra
.799 .734 .792 r
.52453 .45471 .5338 .46877 .5509 .45136 .54172 .43796 Metetra
.784 .74 .813 r
.54172 .43796 .5509 .45136 .56802 .43632 .55892 .42335 Metetra
.775 .745 .826 r
.55892 .42335 .56802 .43632 .58516 .42254 .57615 .40988 Metetra
.763 .749 .839 r
.57615 .40988 .58516 .42254 .60235 .40999 .59342 .39755 Metetra
.783 .758 .831 r
.59342 .39755 .60235 .40999 .6196 .3981 .6107 .38375 Metetra
.96 .729 .544 r
.6107 .38375 .6196 .3981 .63452 .31841 .62542 .29004 Metetra
.854 .653 .63 r
.62542 .29004 .63452 .31841 .64978 .26447 .64104 .24301 Metetra
.804 .664 .709 r
.64104 .24301 .64978 .26447 .6655 .23012 .6573 .219 Metetra
.664 .741 .907 r
.6573 .219 .6655 .23012 .68248 .22408 .67434 .21294 Metetra
.664 .741 .908 r
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Metetra
.664 .741 .908 r
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Metetra
.664 .741 .908 r
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Metetra
.664 .741 .908 r
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Metetra
.664 .741 .908 r
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Metetra
.664 .741 .908 r
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Metetra
.664 .741 .908 r
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Metetra
.664 .741 .908 r
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Metetra
.664 .741 .908 r
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Metetra
.664 .741 .908 r
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Metetra
.664 .741 .908 r
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Metetra
.664 .741 .908 r
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Metetra
.664 .741 .908 r
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Metetra
.664 .741 .908 r
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Metetra
.664 .741 .908 r
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Metetra
.664 .741 .908 r
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33357 Metetra
.664 .741 .908 r
.29708 .33357 .3067 .34341 .32169 .33809 .31212 .32819 Metetra
.664 .741 .908 r
.31212 .32819 .32169 .33809 .33676 .33274 .32725 .32279 Metetra
.664 .741 .908 r
.32725 .32279 .33676 .33274 .35192 .32736 .34246 .31735 Metetra
.664 .741 .908 r
.34246 .31735 .35192 .32736 .36716 .32195 .35775 .31188 Metetra
.568 .078 0 r
.35775 .31188 .36716 .32195 .38091 .3514 .37207 .32839 Metetra
.973 .664 .345 r
.37207 .32839 .38091 .3514 .39129 .47463 .38158 .46208 Metetra
.716 .262 0 r
.38158 .46208 .39129 .47463 .40644 .50147 .39675 .48727 Metetra
0 .102 .649 r
.39675 .48727 .40644 .50147 .42285 .50097 .41263 .50331 Metetra
.983 .85 .631 r
.41263 .50331 .42285 .50097 .44106 .43668 .43073 .45307 Metetra
.238 0 .027 r
.43073 .45307 .44106 .43668 .45759 .42909 .44745 .44619 Metetra
.79 .412 .34 r
.44745 .44619 .45759 .42909 .47334 .47688 .46349 .48088 Metetra
.16 0 0 r
.46349 .48088 .47334 .47688 .49003 .49722 .48052 .48004 Metetra
.81 .702 .746 r
.48052 .48004 .49003 .49722 .50732 .47355 .49788 .4586 Metetra
.806 .725 .776 r
.49788 .4586 .50732 .47355 .52453 .45471 .51517 .44017 Metetra
.787 .726 .796 r
.51517 .44017 .52453 .45471 .54172 .43796 .53244 .42433 Metetra
.78 .738 .814 r
.53244 .42433 .54172 .43796 .55892 .42335 .54972 .40997 Metetra
.767 .739 .828 r
.54972 .40997 .55892 .42335 .57615 .40988 .56704 .39694 Metetra
.759 .745 .84 r
.56704 .39694 .57615 .40988 .59342 .39755 .5844 .38475 Metetra
.92 .763 .669 r
.5844 .38475 .59342 .39755 .6107 .38375 .60112 .34437 Metetra
.878 .641 .577 r
.60112 .34437 .6107 .38375 .62542 .29004 .61632 .26191 Metetra
.839 .647 .643 r
.61632 .26191 .62542 .29004 .64104 .24301 .63224 .22095 Metetra
.717 .621 .748 r
.63224 .22095 .64104 .24301 .6573 .219 .649 .2078 Metetra
.664 .741 .908 r
.649 .2078 .6573 .219 .67434 .21294 .66611 .20168 Metetra
.664 .741 .908 r
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Metetra
.664 .741 .908 r
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Metetra
.664 .741 .908 r
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Metetra
.664 .741 .908 r
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Metetra
.664 .741 .908 r
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Metetra
.664 .741 .908 r
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Metetra
.664 .741 .908 r
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Metetra
.664 .741 .908 r
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Metetra
.664 .741 .908 r
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Metetra
.664 .741 .908 r
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Metetra
.664 .741 .908 r
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Metetra
.664 .741 .908 r
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Metetra
.664 .741 .908 r
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Metetra
.664 .741 .908 r
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Metetra
.664 .741 .908 r
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32902 Metetra
.664 .741 .908 r
.27236 .32902 .28213 .33891 .29708 .33357 .28736 .32362 Metetra
.664 .741 .908 r
.28736 .32362 .29708 .33357 .31212 .32819 .30245 .31819 Metetra
.664 .741 .908 r
.30245 .31819 .31212 .32819 .32725 .32279 .31763 .31273 Metetra
.664 .741 .908 r
.31763 .31273 .32725 .32279 .34246 .31735 .33289 .30723 Metetra
.664 .741 .908 r
.33289 .30723 .34246 .31735 .35775 .31188 .34825 .30171 Metetra
.274 .565 .934 r
.34825 .30171 .35775 .31188 .37207 .32839 .36321 .3053 Metetra
.974 .667 .357 r
.36321 .3053 .37207 .32839 .38158 .46208 .37179 .4492 Metetra
.653 .198 0 r
.37179 .4492 .38158 .46208 .39675 .48727 .38701 .47212 Metetra
.68 .255 0 r
.38701 .47212 .39675 .48727 .41263 .50331 .40244 .49941 Metetra
.945 .841 .71 r
.40244 .49941 .41263 .50331 .43073 .45307 .42028 .46459 Metetra
.124 0 0 r
.42028 .46459 .43073 .45307 .44745 .44619 .43717 .45807 Metetra
.765 .351 .266 r
.43717 .45807 .44745 .44619 .46349 .48088 .45347 .4832 Metetra
.884 .99 .794 r
.45347 .4832 .46349 .48088 .48052 .48004 .47095 .46251 Metetra
.798 .696 .753 r
.47095 .46251 .48052 .48004 .49788 .4586 .48837 .4427 Metetra
.791 .712 .776 r
.48837 .4427 .49788 .4586 .51517 .44017 .50573 .42525 Metetra
.778 .721 .799 r
.50573 .42525 .51517 .44017 .53244 .42433 .52308 .41012 Metetra
.771 .729 .814 r
.52308 .41012 .53244 .42433 .54972 .40997 .54044 .39623 Metetra
.76 .734 .828 r
.54044 .39623 .54972 .40997 .56704 .39694 .55783 .38356 Metetra
.761 .741 .834 r
.55783 .38356 .56704 .39694 .5844 .38475 .57527 .37101 Metetra
.957 .735 .561 r
.57527 .37101 .5844 .38475 .60112 .34437 .59122 .28722 Metetra
.772 .552 .6 r
.59122 .28722 .60112 .34437 .61632 .26191 .60725 .23467 Metetra
.811 .638 .667 r
.60725 .23467 .61632 .26191 .63224 .22095 .62353 .20267 Metetra
.646 .623 .812 r
.62353 .20267 .63224 .22095 .649 .2078 .64061 .19647 Metetra
.664 .741 .908 r
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Metetra
.664 .741 .908 r
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Metetra
.664 .741 .908 r
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Metetra
.664 .741 .908 r
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Metetra
.664 .741 .908 r
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Metetra
.664 .741 .908 r
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Metetra
.664 .741 .908 r
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Metetra
.664 .741 .908 r
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Metetra
.664 .741 .908 r
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Metetra
.664 .741 .908 r
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Metetra
.664 .741 .908 r
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Metetra
.664 .741 .908 r
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Metetra
.664 .741 .908 r
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Metetra
.664 .741 .908 r
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Metetra
.664 .741 .908 r
.23263 .32985 .24261 .33973 .25744 .33439 .24752 .32445 Metetra
.664 .741 .908 r
.24752 .32445 .25744 .33439 .27236 .32902 .26248 .31903 Metetra
.664 .741 .908 r
.26248 .31903 .27236 .32902 .28736 .32362 .27754 .31357 Metetra
.664 .741 .908 r
.27754 .31357 .28736 .32362 .30245 .31819 .29268 .30808 Metetra
.664 .741 .908 r
.29268 .30808 .30245 .31819 .31763 .31273 .30791 .30256 Metetra
.664 .741 .908 r
.30791 .30256 .31763 .31273 .33289 .30723 .32323 .29701 Metetra
.664 .741 .908 r
.32323 .29701 .33289 .30723 .34825 .30171 .33863 .29142 Metetra
.662 .741 .908 r
.33863 .29142 .34825 .30171 .36321 .3053 .35413 .28585 Metetra
.971 .664 .375 r
.35413 .28585 .36321 .3053 .37179 .4492 .36192 .43612 Metetra
.576 .124 0 r
.36192 .43612 .37179 .4492 .38701 .47212 .37719 .4567 Metetra
0 0 .404 r
.37719 .4567 .38701 .47212 .40244 .49941 .3927 .48028 Metetra
.668 .628 .8 r
.3927 .48028 .40244 .49941 .42028 .46459 .40971 .47246 Metetra
.40971 .47246 .42028 .46459 .43717 .45807 .42676 .4661 Metetra
.384 0 0 r
.42676 .4661 .43717 .45807 .45347 .4832 .44371 .46767 Metetra
.829 .725 .749 r
.44371 .46767 .45347 .4832 .47095 .46251 .46131 .44489 Metetra
.787 .694 .761 r
.46131 .44489 .47095 .46251 .48837 .4427 .47878 .42652 Metetra
.782 .707 .782 r
.47878 .42652 .48837 .4427 .50573 .42525 .49621 .41007 Metetra
.77 .717 .803 r
.49621 .41007 .50573 .42525 .52308 .41012 .51363 .39559 Metetra
.762 .724 .817 r
.51363 .39559 .52308 .41012 .54044 .39623 .53107 .38229 Metetra
.755 .731 .83 r
.53107 .38229 .54044 .39623 .55783 .38356 .54854 .36987 Metetra
.854 .757 .755 r
.54854 .36987 .55783 .38356 .57527 .37101 .5659 .34627 Metetra
.931 .694 .557 r
.5659 .34627 .57527 .37101 .59122 .28722 .58186 .25113 Metetra
.811 .609 .63 r
.58186 .25113 .59122 .28722 .60725 .23467 .59818 .20824 Metetra
.729 .6 .712 r
.59818 .20824 .60725 .23467 .62353 .20267 .61497 .19124 Metetra
.663 .74 .907 r
.61497 .19124 .62353 .20267 .64061 .19647 .63212 .18502 Metetra
.664 .741 .908 r
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Metetra
.664 .741 .908 r
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Metetra
.664 .741 .908 r
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Metetra
.664 .741 .908 r
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Metetra
.664 .741 .908 r
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Metetra
.664 .741 .908 r
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Metetra
.664 .741 .908 r
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Metetra
.664 .741 .908 r
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Metetra
.664 .741 .908 r
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Metetra
.664 .741 .908 r
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Metetra
.664 .741 .908 r
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Metetra
.664 .741 .908 r
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Metetra
.664 .741 .908 r
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Metetra
.664 .741 .908 r
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31986 Metetra
.664 .741 .908 r
.22255 .31986 .23263 .32985 .24752 .32445 .23748 .31441 Metetra
.664 .741 .908 r
.23748 .31441 .24752 .32445 .26248 .31903 .2525 .30893 Metetra
.664 .741 .908 r
.2525 .30893 .26248 .31903 .27754 .31357 .26761 .30341 Metetra
.664 .741 .908 r
.26761 .30341 .27754 .31357 .29268 .30808 .2828 .29786 Metetra
.664 .741 .908 r
.2828 .29786 .29268 .30808 .30791 .30256 .29809 .29228 Metetra
.664 .741 .908 r
.29809 .29228 .30791 .30256 .32323 .29701 .31346 .28667 Metetra
.664 .741 .908 r
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Metetra
.664 .741 .908 r
.32892 .28102 .33863 .29142 .35413 .28585 .34447 .27534 Metetra
.96 .65 .397 r
.34447 .27534 .35413 .28585 .36192 .43612 .35196 .42269 Metetra
0 0 .504 r
.35196 .42269 .36192 .43612 .37719 .4567 .36729 .44112 Metetra
0 0 .521 r
.36729 .44112 .37719 .4567 .3927 .48028 .3829 .46126 Metetra
.001 .239 .748 r
.3829 .46126 .3927 .48028 .40971 .47246 .39909 .47543 Metetra
.207 .723 .689 r
.39909 .47543 .40971 .47246 .42676 .4661 .41623 .47043 Metetra
.883 .991 .756 r
.41623 .47043 .42676 .4661 .44371 .46767 .43397 .44789 Metetra
.785 .675 .742 r
.43397 .44789 .44371 .46767 .46131 .44489 .45159 .42783 Metetra
.786 .7 .77 r
.45159 .42783 .46131 .44489 .47878 .42652 .46912 .41017 Metetra
.77 .704 .789 r
.46912 .41017 .47878 .42652 .49621 .41007 .48661 .39487 Metetra
.766 .717 .807 r
.48661 .39487 .49621 .41007 .51363 .39559 .50409 .38082 Metetra
.755 .72 .82 r
.50409 .38082 .51363 .39559 .53107 .38229 .5216 .36799 Metetra
.754 .728 .828 r
.5216 .36799 .53107 .38229 .54854 .36987 .53914 .35547 Metetra
.954 .733 .566 r
.53914 .35547 .54854 .36987 .5659 .34627 .55602 .27249 Metetra
.739 .515 .589 r
.55602 .27249 .5659 .34627 .58186 .25113 .57261 .2191 Metetra
.793 .611 .654 r
.57261 .2191 .58186 .25113 .59818 .20824 .5892 .18603 Metetra
.634 .58 .776 r
.5892 .18603 .59818 .20824 .61497 .19124 .60632 .17973 Metetra
.664 .741 .908 r
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Metetra
.664 .741 .908 r
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Metetra
.664 .741 .908 r
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Metetra
.664 .741 .908 r
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Metetra
.664 .741 .908 r
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Metetra
.664 .741 .908 r
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Metetra
.664 .741 .908 r
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Metetra
.664 .741 .908 r
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Metetra
.664 .741 .908 r
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Metetra
.664 .741 .908 r
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Metetra
.664 .741 .908 r
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Metetra
.664 .741 .908 r
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Metetra
.664 .741 .908 r
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Metetra
.664 .741 .908 r
.18265 .3207 .19294 .33068 .2077 .32529 .19747 .31525 Metetra
.664 .741 .908 r
.19747 .31525 .2077 .32529 .22255 .31986 .21236 .30977 Metetra
.664 .741 .908 r
.21236 .30977 .22255 .31986 .23748 .31441 .22735 .30426 Metetra
.664 .741 .908 r
.22735 .30426 .23748 .31441 .2525 .30893 .24242 .29872 Metetra
.664 .741 .908 r
.24242 .29872 .2525 .30893 .26761 .30341 .25758 .29314 Metetra
.664 .741 .908 r
.25758 .29314 .26761 .30341 .2828 .29786 .27282 .28753 Metetra
.664 .741 .908 r
.27282 .28753 .2828 .29786 .29809 .29228 .28816 .28189 Metetra
.664 .741 .908 r
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Metetra
.664 .741 .908 r
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Metetra
.664 .741 .908 r
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Metetra
.96 .649 .395 r
.33471 .26477 .34447 .27534 .35196 .42269 .34192 .40896 Metetra
0 .029 .577 r
.34192 .40896 .35196 .42269 .36729 .44112 .3573 .42566 Metetra
0 .048 .605 r
.3573 .42566 .36729 .44112 .3829 .46126 .37298 .44314 Metetra
.128 .34 .804 r
.37298 .44314 .3829 .46126 .39909 .47543 .38928 .45379 Metetra
.619 .584 .792 r
.38928 .45379 .39909 .47543 .41623 .47043 .40643 .44862 Metetra
.774 .655 .732 r
.40643 .44862 .41623 .47043 .43397 .44789 .42416 .4285 Metetra
.776 .675 .753 r
.42416 .4285 .43397 .44789 .45159 .42783 .4418 .41019 Metetra
.77 .69 .775 r
.4418 .41019 .45159 .42783 .46912 .41017 .45937 .39398 Metetra
.766 .705 .795 r
.45937 .39398 .46912 .41017 .48661 .39487 .47692 .37928 Metetra
.756 .711 .81 r
.47692 .37928 .48661 .39487 .50409 .38082 .49447 .36594 Metetra
.75 .719 .823 r
.49447 .36594 .50409 .38082 .5216 .36799 .51204 .35346 Metetra
.892 .75 .698 r
.51204 .35346 .5216 .36799 .53914 .35547 .52963 .31942 Metetra
.893 .656 .572 r
.52963 .31942 .53914 .35547 .55602 .27249 .54663 .23135 Metetra
.79 .586 .625 r
.54663 .23135 .55602 .27249 .57261 .2191 .5634 .18929 Metetra
.697 .566 .704 r
.5634 .18929 .57261 .2191 .5892 .18603 .58037 .17441 Metetra
.663 .74 .907 r
.58037 .17441 .5892 .18603 .60632 .17973 .59756 .16809 Metetra
.664 .741 .908 r
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Metetra
.664 .741 .908 r
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Metetra
.664 .741 .908 r
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Metetra
.664 .741 .908 r
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Metetra
.664 .741 .908 r
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Metetra
.664 .741 .908 r
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Metetra
.664 .741 .908 r
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Metetra
.664 .741 .908 r
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Metetra
.664 .741 .908 r
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Metetra
.664 .741 .908 r
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Metetra
.664 .741 .908 r
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Metetra
.664 .741 .908 r
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Metetra
.664 .741 .908 r
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Metetra
.664 .741 .908 r
.17226 .31062 .18265 .3207 .19747 .31525 .18712 .30511 Metetra
.664 .741 .908 r
.18712 .30511 .19747 .31525 .21236 .30977 .20207 .29957 Metetra
.664 .741 .908 r
.20207 .29957 .21236 .30977 .22735 .30426 .2171 .294 Metetra
.664 .741 .908 r
.2171 .294 .22735 .30426 .24242 .29872 .23222 .2884 Metetra
.664 .741 .908 r
.23222 .2884 .24242 .29872 .25758 .29314 .24743 .28276 Metetra
.664 .741 .908 r
.24743 .28276 .25758 .29314 .27282 .28753 .26273 .2771 Metetra
.664 .741 .908 r
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Metetra
.664 .741 .908 r
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Metetra
.664 .741 .908 r
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Metetra
.664 .741 .908 r
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Metetra
.959 .64 .376 r
.32484 .25409 .33471 .26477 .34192 .40896 .33309 .37319 Metetra
0 0 .437 r
.33309 .37319 .34192 .40896 .3573 .42566 .34724 .40991 Metetra
0 .156 .696 r
.34724 .40991 .3573 .42566 .37298 .44314 .363 .42469 Metetra
.239 .407 .828 r
.363 .42469 .37298 .44314 .38928 .45379 .37939 .43285 Metetra
.623 .593 .8 r
.37939 .43285 .38928 .45379 .40643 .44862 .39655 .42752 Metetra
.759 .656 .747 r
.39655 .42752 .40643 .44862 .42416 .4285 .41425 .41001 Metetra
.774 .684 .764 r
.41425 .41001 .42416 .4285 .4418 .41019 .43193 .39266 Metetra
.761 .69 .783 r
.43193 .39266 .4418 .41019 .45937 .39398 .44954 .37753 Metetra
.757 .701 .799 r
.44954 .37753 .45937 .39398 .47692 .37928 .46714 .36359 Metetra
.748 .709 .814 r
.46714 .36359 .47692 .37928 .49447 .36594 .48475 .35081 Metetra
.763 .722 .814 r
.48475 .35081 .49447 .36594 .51204 .35346 .50241 .33708 Metetra
.95 .723 .559 r
.50241 .33708 .51204 .35346 .52963 .31942 .52021 .24562 Metetra
.729 .507 .59 r
.52021 .24562 .52963 .31942 .54663 .23135 .53734 .19617 Metetra
.753 .579 .66 r
.53734 .19617 .54663 .23135 .5634 .18929 .5543 .16909 Metetra
.64 .604 .798 r
.5543 .16909 .5634 .18929 .58037 .17441 .57145 .16271 Metetra
.664 .741 .908 r
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Metetra
.664 .741 .908 r
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Metetra
.664 .741 .908 r
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Metetra
.664 .741 .908 r
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Metetra
.664 .741 .908 r
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Metetra
.664 .741 .908 r
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Metetra
.664 .741 .908 r
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Metetra
.664 .741 .908 r
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Metetra
.664 .741 .908 r
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Metetra
.664 .741 .908 r
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Metetra
.664 .741 .908 r
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Metetra
.664 .741 .908 r
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Metetra
.664 .741 .908 r
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Metetra
.664 .741 .908 r
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Metetra
.664 .741 .908 r
.16175 .30043 .17226 .31062 .18712 .30511 .17666 .29486 Metetra
.664 .741 .908 r
.17666 .29486 .18712 .30511 .20207 .29957 .19166 .28926 Metetra
.664 .741 .908 r
.19166 .28926 .20207 .29957 .2171 .294 .20674 .28363 Metetra
.664 .741 .908 r
.20674 .28363 .2171 .294 .23222 .2884 .22192 .27797 Metetra
.664 .741 .908 r
.22192 .27797 .23222 .2884 .24743 .28276 .23718 .27227 Metetra
.664 .741 .908 r
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Metetra
.664 .741 .908 r
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Metetra
.664 .741 .908 r
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Metetra
.664 .741 .908 r
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Metetra
.664 .741 .908 r
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Metetra
.937 .564 .233 r
.31485 .24328 .32484 .25409 .33309 .37319 .32683 .29781 Metetra
0 0 .164 r
.32683 .29781 .33309 .37319 .34724 .40991 .33708 .39414 Metetra
0 .247 .761 r
.33708 .39414 .34724 .40991 .363 .42469 .35294 .40653 Metetra
.285 .441 .842 r
.35294 .40653 .363 .42469 .37939 .43285 .36937 .41325 Metetra
.627 .611 .815 r
.36937 .41325 .37939 .43285 .39655 .42752 .38656 .40778 Metetra
.76 .668 .761 r
.38656 .40778 .39655 .42752 .41425 .41001 .40427 .39128 Metetra
.76 .678 .772 r
.40427 .39128 .41425 .41001 .43193 .39266 .42196 .37551 Metetra
.757 .694 .791 r
.42196 .37551 .43193 .39266 .44954 .37753 .43962 .36107 Metetra
.748 .7 .806 r
.43962 .36107 .44954 .37753 .46714 .36359 .45727 .34791 Metetra
.744 .709 .819 r
.45727 .34791 .46714 .36359 .48475 .35081 .47495 .33555 Metetra
.942 .733 .592 r
.47495 .33555 .48475 .35081 .50241 .33708 .49326 .26455 Metetra
.762 .532 .584 r
.49326 .26455 .50241 .33708 .52021 .24562 .51092 .20268 Metetra
.773 .572 .627 r
.51092 .20268 .52021 .24562 .53734 .19617 .52808 .16417 Metetra
.613 .508 .71 r
.52808 .16417 .53734 .19617 .5543 .16909 .5452 .1573 Metetra
.664 .741 .908 r
.5452 .1573 .5543 .16909 .57145 .16271 .56242 .15087 Metetra
.664 .741 .908 r
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Metetra
.664 .741 .908 r
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Metetra
.664 .741 .908 r
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Metetra
.664 .741 .908 r
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Metetra
.664 .741 .908 r
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Metetra
.664 .741 .908 r
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Metetra
.664 .741 .908 r
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Metetra
.664 .741 .908 r
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Metetra
.664 .741 .908 r
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Metetra
.664 .741 .908 r
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Metetra
.664 .741 .908 r
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Metetra
.664 .741 .908 r
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Metetra
.664 .741 .908 r
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Metetra
.664 .741 .908 r
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Metetra
.664 .741 .908 r
.15113 .29013 .16175 .30043 .17666 .29486 .16609 .2845 Metetra
.664 .741 .908 r
.16609 .2845 .17666 .29486 .19166 .28926 .18114 .27884 Metetra
.664 .741 .908 r
.18114 .27884 .19166 .28926 .20674 .28363 .19627 .27315 Metetra
.664 .741 .908 r
.19627 .27315 .20674 .28363 .22192 .27797 .2115 .26743 Metetra
.664 .741 .908 r
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Metetra
.664 .741 .908 r
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Metetra
.664 .741 .908 r
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Metetra
.664 .741 .908 r
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Metetra
.664 .741 .908 r
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Metetra
.664 .741 .908 r
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Metetra
.743 .269 0 r
.30476 .23236 .31485 .24328 .32683 .29781 .31873 .2549 Metetra
.959 .668 .237 r
.31873 .2549 .32683 .29781 .33708 .39414 .32682 .37848 Metetra
.024 .318 .805 r
.32682 .37848 .33708 .39414 .35294 .40653 .34277 .3889 Metetra
.349 .49 .859 r
.34277 .3889 .35294 .40653 .36937 .41325 .35928 .39363 Metetra
.628 .612 .815 r
.35928 .39363 .36937 .41325 .38656 .40778 .3765 .38803 Metetra
.746 .664 .77 r
.3765 .38803 .38656 .40778 .40427 .39128 .3942 .37313 Metetra
.755 .683 .782 r
.3942 .37313 .40427 .39128 .42196 .37551 .41192 .35825 Metetra
.747 .691 .798 r
.41192 .35825 .42196 .37551 .43962 .36107 .42962 .34474 Metetra
.743 .701 .812 r
.42962 .34474 .43962 .36107 .45727 .34791 .44732 .33209 Metetra
.883 .738 .696 r
.44732 .33209 .45727 .34791 .47495 .33555 .46548 .29779 Metetra
.888 .652 .575 r
.46548 .29779 .47495 .33555 .49326 .26455 .48416 .20925 Metetra
.749 .538 .609 r
.48416 .20925 .49326 .26455 .51092 .20268 .50167 .16692 Metetra
.676 .531 .68 r
.50167 .16692 .51092 .20268 .52808 .16417 .51881 .15187 Metetra
.663 .732 .901 r
.51881 .15187 .52808 .16417 .5452 .1573 .536 .1454 Metetra
.664 .741 .908 r
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Metetra
.664 .741 .908 r
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Metetra
.664 .741 .908 r
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Metetra
.664 .741 .908 r
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Metetra
.664 .741 .908 r
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Metetra
.664 .741 .908 r
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Metetra
.664 .741 .908 r
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Metetra
.664 .741 .908 r
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Metetra
.664 .741 .908 r
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Metetra
.664 .741 .908 r
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Metetra
.664 .741 .908 r
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Metetra
.664 .741 .908 r
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Metetra
.664 .741 .908 r
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Metetra
.664 .741 .908 r
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Metetra
.664 .741 .908 r
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Metetra
.664 .741 .908 r
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Metetra
.664 .741 .908 r
.15541 .27403 .16609 .2845 .18114 .27884 .1705 .26831 Metetra
.664 .741 .908 r
.1705 .26831 .18114 .27884 .19627 .27315 .18569 .26256 Metetra
.664 .741 .908 r
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Metetra
.664 .741 .908 r
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Metetra
.664 .741 .908 r
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Metetra
.664 .741 .908 r
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Metetra
.664 .741 .908 r
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Metetra
.664 .741 .908 r
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Metetra
.664 .741 .908 r
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Metetra
.536 .695 .941 r
.29456 .22131 .30476 .23236 .31873 .2549 .3102 .2194 Metetra
.977 .677 .314 r
.3102 .2194 .31873 .2549 .32682 .37848 .31647 .36274 Metetra
.119 .382 .839 r
.31647 .36274 .32682 .37848 .34277 .3889 .33251 .37132 Metetra
.398 .52 .864 r
.33251 .37132 .34277 .3889 .35928 .39363 .34909 .37459 Metetra
.631 .622 .823 r
.34909 .37459 .35928 .39363 .3765 .38803 .36633 .36886 Metetra
.738 .668 .781 r
.36633 .36886 .3765 .38803 .3942 .37313 .38404 .35508 Metetra
.746 .683 .79 r
.38404 .35508 .3942 .37313 .41192 .35825 .40179 .34115 Metetra
.74 .692 .805 r
.40179 .34115 .41192 .35825 .42962 .34474 .41952 .32835 Metetra
.766 .71 .799 r
.41952 .32835 .42962 .34474 .44732 .33209 .43735 .31352 Metetra
.944 .714 .558 r
.43735 .31352 .44732 .33209 .46548 .29779 .45707 .2147 Metetra
.705 .482 .584 r
.45707 .2147 .46548 .29779 .48416 .20925 .47498 .16846 Metetra
.706 .535 .654 r
.47498 .16846 .48416 .20925 .50167 .16692 .49228 .1464 Metetra
.638 .604 .799 r
.49228 .1464 .50167 .16692 .51881 .15187 .50943 .1399 Metetra
.664 .741 .908 r
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Metetra
.664 .741 .908 r
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Metetra
.664 .741 .908 r
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Metetra
.664 .741 .908 r
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Metetra
.664 .741 .908 r
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Metetra
.664 .741 .908 r
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Metetra
.664 .741 .908 r
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Metetra
.664 .741 .908 r
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Metetra
.664 .741 .908 r
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Metetra
.664 .741 .908 r
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Metetra
.664 .741 .908 r
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Metetra
.664 .741 .908 r
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Metetra
.664 .741 .908 r
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Metetra
.664 .741 .908 r
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Metetra
.664 .741 .908 r
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Metetra
.664 .741 .908 r
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Metetra
.664 .741 .908 r
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Metetra
.664 .741 .908 r
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Metetra
.664 .741 .908 r
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Metetra
.664 .741 .908 r
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Metetra
.664 .741 .908 r
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Metetra
.664 .741 .908 r
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Metetra
.664 .741 .908 r
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Metetra
.664 .741 .908 r
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Metetra
.664 .741 .908 r
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Metetra
.664 .741 .908 r
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Metetra
.664 .741 .908 r
.28424 .21014 .29456 .22131 .3102 .2194 .30023 .20404 Metetra
.965 .652 .373 r
.30023 .20404 .3102 .2194 .31647 .36274 .30636 .34204 Metetra
.088 .283 .766 r
.30636 .34204 .31647 .36274 .33251 .37132 .32214 .354 Metetra
.427 .542 .87 r
.32214 .354 .33251 .37132 .34909 .37459 .33879 .35623 Metetra
.633 .633 .832 r
.33879 .35623 .34909 .37459 .36633 .36886 .35606 .35039 Metetra
.735 .675 .792 r
.35606 .35039 .36633 .36886 .38404 .35508 .37379 .33731 Metetra
.738 .684 .799 r
.37379 .33731 .38404 .35508 .40179 .34115 .39155 .32429 Metetra
.753 .701 .803 r
.39155 .32429 .40179 .34115 .41952 .32835 .40938 .3105 Metetra
.942 .717 .569 r
.40938 .3105 .41952 .32835 .43735 .31352 .42966 .21958 Metetra
.7 .473 .576 r
.42966 .21958 .43735 .31352 .45707 .2147 .44805 .16915 Metetra
.723 .535 .636 r
.44805 .16915 .45707 .2147 .47498 .16846 .46561 .14093 Metetra
.618 .536 .74 r
.46561 .14093 .47498 .16846 .49228 .1464 .48273 .13437 Metetra
.664 .741 .908 r
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Metetra
.664 .741 .908 r
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Metetra
.664 .741 .908 r
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Metetra
.664 .741 .908 r
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Metetra
.664 .741 .908 r
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Metetra
.664 .741 .908 r
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Metetra
.664 .741 .908 r
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Metetra
.664 .741 .908 r
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Metetra
.664 .741 .908 r
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Metetra
.664 .741 .908 r
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Metetra
.664 .741 .908 r
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Metetra
.664 .741 .908 r
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Metetra
.664 .741 .908 r
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Metetra
.664 .741 .908 r
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Metetra
.664 .741 .908 r
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Metetra
.664 .741 .908 r
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Metetra
.664 .741 .908 r
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Metetra
.664 .741 .908 r
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Metetra
.664 .741 .908 r
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Metetra
.664 .741 .908 r
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Metetra
.664 .741 .908 r
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Metetra
.664 .741 .908 r
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Metetra
.664 .741 .908 r
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Metetra
.664 .741 .908 r
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Metetra
.664 .741 .908 r
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Metetra
.664 .741 .908 r
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Metetra
.664 .741 .908 r
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Metetra
.664 .741 .908 r
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Metetra
.929 .546 .197 r
.28986 .19267 .30023 .20404 .30636 .34204 .30188 .24309 Metetra
0 0 .289 r
.30188 .24309 .30636 .34204 .32214 .354 .31166 .337 Metetra
.459 .567 .876 r
.31166 .337 .32214 .354 .33879 .35623 .32838 .33806 Metetra
.635 .637 .836 r
.32838 .33806 .33879 .35623 .35606 .35039 .34569 .33211 Metetra
.726 .675 .8 r
.34569 .33211 .35606 .35039 .37379 .33731 .36343 .3199 Metetra
.741 .691 .803 r
.36343 .3199 .37379 .33731 .39155 .32429 .38125 .30684 Metetra
.939 .719 .579 r
.38125 .30684 .39155 .32429 .40938 .3105 .40203 .22163 Metetra
.715 .486 .578 r
.40203 .22163 .40938 .3105 .42966 .21958 .42093 .16813 Metetra
.725 .526 .621 r
.42093 .16813 .42966 .21958 .44805 .16915 .4388 .13542 Metetra
.603 .494 .703 r
.4388 .13542 .44805 .16915 .46561 .14093 .45588 .12881 Metetra
.664 .741 .908 r
.45588 .12881 .46561 .14093 .48273 .13437 .47306 .12221 Metetra
.664 .741 .908 r
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Metetra
.664 .741 .908 r
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Metetra
.664 .741 .908 r
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Metetra
.664 .741 .908 r
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Metetra
.664 .741 .908 r
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Metetra
.664 .741 .908 r
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Metetra
.664 .741 .908 r
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Metetra
.664 .741 .908 r
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Metetra
.664 .741 .908 r
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Metetra
.664 .741 .908 r
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Metetra
.664 .741 .908 r
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Metetra
.664 .741 .908 r
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Metetra
.664 .741 .908 r
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Metetra
.664 .741 .908 r
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Metetra
.664 .741 .908 r
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Metetra
.664 .741 .908 r
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Metetra
.664 .741 .908 r
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Metetra
.664 .741 .908 r
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Metetra
.664 .741 .908 r
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Metetra
.664 .741 .908 r
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Metetra
.664 .741 .908 r
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Metetra
.664 .741 .908 r
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Metetra
.664 .741 .908 r
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Metetra
.664 .741 .908 r
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Metetra
.664 .741 .908 r
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Metetra
.664 .741 .908 r
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Metetra
.664 .741 .908 r
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Metetra
.664 .741 .908 r
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Metetra
0 .109 .623 r
.27936 .18118 .28986 .19267 .30188 .24309 .29411 .19393 Metetra
.946 .665 .208 r
.29411 .19393 .30188 .24309 .31166 .337 .30119 .3186 Metetra
.443 .539 .86 r
.30119 .3186 .31166 .337 .32838 .33806 .31786 .32035 Metetra
.637 .646 .843 r
.31786 .32035 .32838 .33806 .34569 .33211 .3352 .31429 Metetra
.723 .681 .808 r
.3352 .31429 .34569 .33211 .36343 .3199 .35297 .30252 Metetra
.936 .719 .585 r
.35297 .30252 .36343 .3199 .38125 .30684 .37425 .22073 Metetra
.724 .494 .578 r
.37425 .22073 .38125 .30684 .40203 .22163 .39365 .16532 Metetra
.723 .518 .612 r
.39365 .16532 .40203 .22163 .42093 .16813 .41185 .12988 Metetra
.593 .471 .682 r
.41185 .12988 .42093 .16813 .4388 .13542 .42888 .12323 Metetra
.663 .74 .907 r
.42888 .12323 .4388 .13542 .45588 .12881 .44602 .11658 Metetra
.664 .741 .908 r
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Metetra
.664 .741 .908 r
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Metetra
.664 .741 .908 r
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Metetra
.664 .741 .908 r
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Metetra
.664 .741 .908 r
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Metetra
.664 .741 .908 r
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Metetra
.664 .741 .908 r
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Metetra
.664 .741 .908 r
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Metetra
.664 .741 .908 r
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Metetra
.664 .741 .908 r
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Metetra
.664 .741 .908 r
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Metetra
.664 .741 .908 r
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Metetra
.664 .741 .908 r
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Metetra
.664 .741 .908 r
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Metetra
.664 .741 .908 r
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Metetra
.664 .741 .908 r
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Metetra
.664 .741 .908 r
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Metetra
.664 .741 .908 r
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Metetra
.664 .741 .908 r
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Metetra
.664 .741 .908 r
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Metetra
.664 .741 .908 r
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Metetra
.664 .741 .908 r
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Metetra
.664 .741 .908 r
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Metetra
.664 .741 .908 r
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Metetra
.664 .741 .908 r
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Metetra
.664 .741 .908 r
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Metetra
.664 .741 .908 r
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Metetra
.664 .741 .908 r
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Metetra
.664 .741 .908 r
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Metetra
.663 .741 .908 r
.26875 .16955 .27936 .18118 .29411 .19393 .28501 .16322 Metetra
.87 .553 .037 r
.28501 .16322 .29411 .19393 .30119 .3186 .29634 .22399 Metetra
0 0 .352 r
.29634 .22399 .30119 .3186 .31786 .32035 .3073 .30185 Metetra
.632 .636 .836 r
.3073 .30185 .31786 .32035 .3352 .31429 .32466 .29587 Metetra
.929 .715 .592 r
.32466 .29587 .3352 .31429 .35297 .30252 .34643 .21681 Metetra
.726 .496 .578 r
.34643 .21681 .35297 .30252 .37425 .22073 .36628 .1607 Metetra
.718 .51 .607 r
.36628 .1607 .37425 .22073 .39365 .16532 .38475 .1243 Metetra
.587 .457 .671 r
.38475 .1243 .39365 .16532 .41185 .12988 .40174 .11761 Metetra
.663 .74 .907 r
.40174 .11761 .41185 .12988 .42888 .12323 .41884 .11093 Metetra
.664 .741 .908 r
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Metetra
.664 .741 .908 r
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Metetra
.664 .741 .908 r
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Metetra
.664 .741 .908 r
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Metetra
.664 .741 .908 r
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Metetra
.664 .741 .908 r
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Metetra
.664 .741 .908 r
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Metetra
.664 .741 .908 r
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Metetra
.664 .741 .908 r
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Metetra
.664 .741 .908 r
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Metetra
.664 .741 .908 r
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Metetra
.664 .741 .908 r
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Metetra
.664 .741 .908 r
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Metetra
.664 .741 .908 r
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Metetra
.664 .741 .908 r
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{331.375, 268.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006N0001D2000`400?l00000o`00003ooooooonO
ooooo`00oooooonOooooo`00oooooonOooooo`00oooooolIooooo`Co000000?o410@ooooooooool0
Ooooool00?oooooo6oooool00ol0003oooooooooo`21ooooo`00oooooolKooooo`03o`000?oooooo
oooo087ooooo003ooooooa_ooooo00?o0000ooooooooool0POooool00?oooooo6oooool00ol0003o
ooooooooo`21ooooo`00oooooolKooooo`03o`000?oooooooooo087ooooo003ooooooa_ooooo00?o
0000ooooooooool04?ooool4o`000003oa0@4?oooooooooo06[ooooo003ooooooaWooooo00?oEEEE
ofIVI_l000005?ooool00ol0003oooooooooo`1/ooooo`00oooooolUooooo`Ko00001Oooool00ol0
003oooooooooo`1/ooooo`00ooooool`ooooo`03o`000?oooooooooo06cooooo003ooooooc3ooooo
00?o0000ooooooooool0K?ooool00?oooooo<?ooool00ol0003oooooooooo`1/ooooo`00ooooool`
ooooo`03o`000?oooooooooo06cooooo003ooooooaoooooo0_l0000=ooooo`03oeEEEOmVIVKo0000
06kooooo003ooooooacooooo0ol000000ooooooo0000ooooo`1mooooo`00oooooolJooooo`;o0000
0_ooool4o`0007gooooo003ooooooaOooooo0ol000001?oooooo0000o`000?l00002ojVmj003o`00
0?oooooo000007cooooo003ooooooaGooooo0_l000001?oooooo0000o`000?l00005ojVmj0?o0000
O?ooool00?oooooo4_ooool6o`000003ojVmj?l0003oZKgX00GoZKgX00Co0000ojVmj?l0003o0000
Noooool00?oooooo3oooool3o`000003ooooool0003o000000GoZKgX00?o0000ojVmj?nY_NP00onY
_NP01Ol0003oZKgXo`000?oooooo000007[ooooo003oooooo`gooooo0_l00002ooooo`;o00002?nY
_NP00ol0003oZKgXojVmj002ojVmj0Go0000N_ooool00?oooooo2_ooool3o`000006ooooool0003o
0000o`000?nY_NSo00002?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ooooool00000
NOooool00?oooooo2?ooool2o`0000;ooooo0_l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol0
0002ojVmj007o`000?nY_NSoZKgXojVmj?l0003oooooo`00001hooooo`00ooooool5ooooo`?o0000
0_ooool2o`0000SoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00?oZKgX
00Co0000ojVmj?nY_NSoZKgX0_l0001hooooo`00ooooool3ooooo`;o000000?oooooo`000?ooool0
0_l000000onY_NSo0000ojVmj008ojVmj004o`000?nY_NSo0000o`0000CoZKgX00Go0000ojVmj?nY
_NSoZKgXo`000004ojVmj0;o0000Moooool00?oooooo0ol00003ooooo`;o00001?nY_NP00ol0003o
ZKgXojVmj006ojVmj0;o00001onY_NP01?l0003oZKgXojVmj?l00003ojVmj0?o0000Moooool00<Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM027ooooo0_l00003ooooo`?o00001onY_NP00ol0003oZKgXojVmj002ojVmj0?o000000?oZKgX
o`000?nY_NP01onY_NP00ol0003oZKgXo`000003o`0000;oZKgX0_l0001fooooo`00a_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01gooooo0ol00002
ooooo`?o00000_nY_NP00ol0003oZKgXojVmj006ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o
0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX0_l0001eooooo`00a_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool06Oooool3o`0000;ooooo0ol00006ojVmj003o`000?nY
_NSoZKgX00CoZKgX0ol00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?l00000
1onY_NP00ol0003oooooooooo`1cooooo`00a_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool06?ooool3o`000006ooooool0003o0000o`000?nY_NSo00002?nY_NP00ol0
003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01_nY_NP01?l0003oZKgXo`000?l00005
ojVmj003o`000?nY_NSoZKgX00GoZKgX0_l0001dooooo`00Q?ooool2o`0000;ooooo0_l0000loooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo0ol0
0002ooooo`;o00001OnY_NP00ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVm
j005ojVmj0;o00001onY_NP2o`0000GoZKgX1?l0001cooooo`00Q?ooool01_o^k^ko8B4QohN7Qonj
^[[o0000omgMgCcooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Ko
oooo0_l00002ooooo`?o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX
00OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj006ojVmj0;o00000_nY_NP3
o`0000;oZKgX0_l0001cooooo`00QOooool01?oMgMgo0000oa0@4?o<c<`mooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`?o000000Coooooo`000?l0003o0000
0_nY_NP00ol0003oZKgXojVmj006ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY
_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00006ojVm
j0;o0000L_ooool008Gooooo00Cok^k^ob4Q8Ol@413ok^k^?Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`;o000000Coooooo`000?l0003o00001_nY_NP00ol0003oZKgXojVm
j005ojVmj0;o00002?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00002?nY_NP01?l0003oZKgXojVm
j?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX0_l0001aooooo`00QOooool01?lQ8B7oMgMgogMg
Molb<S9Oooooo`?o000000Goooooo`000?l0003oZKgXo`000008ojVmj004o`000?nY_NSoZKgXojVm
j0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01_nY_NP01?l0003oZKgXo`000?l00002ojVmj004o`000?nY_NSoZKgXo`0000OoZKgX0_l0
001aooooo`00Q?ooool2o`0000;ooooo0_l0001Looooo`;o00000_ooool2o`0000CoZKgX00?o0000
ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol0
0006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00004ojVmj005o`000?nY_NSoZKgXojVmj?l00000
0onY_NP3o`000003ojVmj?l0003o0000073ooooo003Sooooo`?o00000_ooool2o`0000OoZKgX00?o
0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0
003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Ko
0000ojVmj?nY_NSoZKgXo`000?nY_NP2o`0000GoZKgX0_l0001_ooooo`00h?ooool3o`0000;ooooo
0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgX
ojVmj006ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000Ko
ZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ojVmj0;o00002?nY_NP00ol0003oooooooooo`1]oooo
o`00g_ooool2o`0000?ooooo0_l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00007ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00Co000000?oZKgXo`000?nY_NP01onY_NP2o`0006ko
oooo003Kooooo`Co00000_ooool2o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj006ojVmj004
o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005
ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol0001]ooooo`00fOooool2o`0000?ooooo0ol00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001onY_NP00ol0003oZKgXojVmj004
ojVmj0;o000000?oZKgXo`000?nY_NP01OnY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0
003o000006gooooo003Fooooo`?o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY
_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000Go
ZKgXo`000?nY_NSoZKgXo`000005ojVmj004o`000?nY_NSo0000o`0000GoZKgX0_l0001/ooooo`00
e?ooool2o`0000;ooooo0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY
_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ojVmj?l0
00001?nY_NP3o`0000SoZKgX0_l0001[ooooo`00dOooool3o`0000;ooooo0_l00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`00
0?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP01?l0003oZKgXojVmj?nY_NP3o`00
0003ojVmj?l0003oZKgX00KoZKgX0_l000001?nY_NSo0000o`000?l00002ojVmj003o`000?nY_NSo
ZKgX00KoZKgX0_l0001[ooooo`00coooool3o`0000;ooooo0_l00008ojVmj004o`000?nY_NSoZKgX
ojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
ZKgX00OoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY
_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP4o`0006[ooooo003<ooooo`?o00000_ooool3o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY
_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0_l00008ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00008ojVmj004o`00
0?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ooooool00000JOooool00<Wooooo0ol00002ooooo`?o00001_nY_NP00ol0003oZKgX
ojVmj004ojVmj0;o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00Ko
ZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY
_NP00ol00002ojVmj003o`000?nY_NSoZKgX00KoZKgX00Co0000ojVmj?l0003o00000onY_NP2o`00
00OoZKgX0ol00006ojVmj0;o0000JOooool00<Oooooo0_l00002ooooo`?o000000?oZKgXo`000?nY
_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003o
ZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP0
0ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP0
0ol0003oZKgXo`000004ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP2o`0006Sooooo0034oooo
o`?o00000_ooool2o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX00?o0000ojVm
j?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVm
j003o`000?nY_NSoZKgX00?oZKgX00Go0000ojVmj?nY_NSo0000ojVmj002o`0000CoZKgX00?o0000
ojVmj?nY_NP01OnY_NP2o`0006Sooooo0032ooooo`;o000000?oooooo`000?ooool00_l00008ojVm
j004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003
o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
ZKgX00KoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;o00001onY_NP00ol0003oZKgXojVm
j003ojVmj0Co0000Ioooool009Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Tooooo`?o00000_oo
ool3o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY
_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ooooool00000I_ooool009Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Rooooo`;o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0
003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY_NP3
o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX0_l0001V
ooooo`00U_ooool01Ol@413ooooooooooooooooo410@01oooooo0ol000001_oooooo0000o`000?l0
003oZKgXo`0000SoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`00
00CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`00
00SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000001OnY_NSo0000ojVmj?nY_NSo000000GoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0;o0000IOooool009Kooooo00Go0000
ooooooooooooooooo`00000Mooooo`;o00000_ooool2o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000OoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o0000
1OnY_NP00ol0003oZKgXo`000005ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj005ojVmj0?o0000
4Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd0?Oooool009Kooooo00Go0000ooooooooooooooooo`00000Jooooo`?o000000Coooooo`00
0?l0003o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol0
0002ojVmj003o`000?nY_NSoZKgX00KoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgX
ojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00002?nY_NP2o`0000;oZKgX
0ol000000onY_NSo0000ojVmj006ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?l0
00004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
03cooooo002Fooooo`05oa0@4?ooooooooooooooool@41005oooool3o`0000;ooooo0ol00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004
ojVmj0?o00001onY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0Co00001OnY_NP00ol0003oZKgXojVm
j004ojVmj004o`000?nY_NSo0000o`0000GoZKgX0_l00008ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool0>oooool009Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Eooooo`;o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX
00?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00008ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00008
ojVmj0;o00003oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0??oo
ool009Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`?o00000_ooool2o`000003oiIdZol0
003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co
0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005ojVmj0?o00001OnY_NP00ol0003oZKgX
ojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00002?nY_NP01?l0003oZKgX
ojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0;o
00003oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00m
ooooo`00Zoooool2o`0000?ooooo0_l00004oiIdZ`03o`000?nY_NSoZKgX00GoZKgX0ol00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgX
o`000?nY_NP01_nY_NP00ol0003oZKgXojVmj002ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l0
0005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj0;o00001_nY_NP4o`0000GoZKgX00?o
0000ojVmj?nY_NP01?nY_NP4o`0000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo03oooooo002Xooooo`?o000000Goooooo`000?ooooooooooo`000007oiIdZ`03o`00
0?nY_NSoZKgX00;oZKgX0_l000000onGN:ko0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY
_NP01OnY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgX
o`000?nY_NP01_nY_NP2o`0000;oZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000
ojVmj?nY_NP00ol00002ojVmj0?o00003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool0?oooool00:Kooooo0_l00007ooooo`03o`000?nFM:_oUWB[00KoUWB[00Co0000
ojVmj?l0003o00001?nGN:h00ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVm
j004ojVmj0;o00002?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001onY_NP01?l0003oZKgXojVm
j?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000
ojVmj007ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000Ko
ZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX0_l0000=ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0003kooooo002Sooooo`?o00002?ooool2o`0000WoUWB[00?o0000oiMh[_nG
N:h01OnGN:h00ol0003oZKgXojVmj002ojVmj0;o000000?oVWjco`000?nY_NP01onY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX
00GoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00007ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgX
o`000?nY_NP01onY_NP2o`0005oooooo002Qooooo`;o00002oooool00ol0003o]h:Ko`000008oiId
Z`03o`000?nGN:koUgR^00KoUgR^00Co0000ojVmj?l0003o00001?nJO[<00ol0003oZKgXojVmj005
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004
ojVmj0;o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00KoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0
003oZKgXojVmj005ojVmj0?o0000G_ooool009kooooo0ol0000<ooooo`04o`000?ngPY_o]h:Ko`00
00OoUWB[0_l00009oiMh[P03o`000?nJO[?oVWjc00GoVWjc00?o0000ojVmj?nY_NP00_nY_NP2o`00
0003oij9_Ol0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVm
j?l0003o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004
ojVmj0?o00000onY_NP01Ol0003oZKgXojVmj?nY_NSo000000GoZKgX0ol00007ojVmj004o`000?nY
_NSoZKgXojVmj0?o000000?oZKgXo`000?l00000G_ooool009cooooo0_l00002ooooo`03o`000?oo
oooooooo00[ooooo00Co0000okN2VongPY_o00001onFM:/00ol0003o^HBLo`000008oiMh[P03o`00
0?nJO[?oVWjc00KoVWjc00Co0000ojVmj?l0003o00001?nNRKd00ol0003oZKgXojVmj005ojVmj0?o
00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o
00002?nY_NP01?l0003oZKgXojVmj?nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj005o`000?nY_NSoZKgXojVmj?l000000onY_NP00ol0003oZKgXojVmj003
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj0;o0000GOoo
ool009Wooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00Go0000okN2VongPY_o]h:Ko`00
0006oiIdZ`04o`000?niQ9co^HBLo`0000OoUgR^0_l00009oiYn/`03o`000?nNRKgoWXVm00GoWXVm
00?o0000ojVmj?nY_NP00_nY_NP2o`000003oj>Jc?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP0
0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1onY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj004
o`000?nY_NSoZKgXo`0000?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVm
j0;o0000G?ooool009Kooooo0ol0000Booooo`03o`000?ngPY_o]h:K00;o]h:K00?o0000oiIdZonF
M:/01?nFM:/01?l0003o^HBLokV4W?l00007oiMh[P03o`000?niQYko000000SoVWjc00?o0000oij9
_OnNRKd01_nNRKd01?l0003oZKgXo`000?l00004oj>Jc003o`000?nY_NSoZKgX00GoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00007
ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSo
000000?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
ZKgX00OoZKgX0_l0001Looooo`00U?ooool2o`0001Gooooo00?o0000okN2VongPY/00ongPY/00ol0
003oUWB[oiIdZ`02oiIdZ`05o`000?niQ9co^HBLokV4W?l000001_nGN:h01?l0003o^HJNokV6W_l0
0007oiYn/`;o00002OnNRKd00ol0003oXi[<oj>Jc005oj>Jc004o`000?nY_NSoZKgXojVmj0?o0000
00?oZK_Vo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01_nY_NP01?l0003oZKgX
o`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00Co
ZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l0001Kooooo`00TOooool3o`000003oooo
ool0003ooooo01?ooooo00?o0000okN2VongPY/01?ngPY/01Ol0003oUWB[oiIdZonFM:_o000000Co
^HBL00?o0000oiMh[_nGN:h00onGN:h01Ol0003o^HJNokV6W_niQYko000000KoVWjc00Co0000okV8
X_niR:;o00002?nNRKd00ol0003oXi[<oj>Jc005oj>Jc004o`000?nY_NSo0000o`0000GoZK_V00?o
0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000
o`000006ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`00
0?nY_NSoZKgX00?o00000_nY_NP3o`0005[ooooo002?ooooo`;o00006Oooool00ol0003o]h:KokN2
V`04okN2V`05o`000?nFM:_oUWB[oiIdZol000001OniQ9`00ol0003oUgR^oiMh[P02oiMh[P05o`00
0?niQYko^HJNokV6W_l000001_nJO[<01?l0003o^HRRokV8X_l00007oij9_@03o`000?ndR:Oo0000
00KoXi[<0_l00008ojVkiP04o`000?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY
_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj0;o0000F_oo
ool008cooooo0ol0000Jooooo`03o`000?ngPY_o]h:K00Go]h:K00Co0000oiIdZonFM:_o00001_ni
Q9`01Ol0003oUgR^oiMh[_nGN:ko000000Go^HJN00?o0000oiYn/onJO[<00_nJO[<01Ol0003o^HRR
okV8X_niR:;o000000KoWXVm00Co0000okB8YondR:Oo00001OnSV/`01?l0003o[HN^ojf7[_l00007
ojVkiP04o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX0_l0
0003ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0
003oZKgX00OoZKgX0_l0001Iooooo`00R_ooool2o`0001gooooo00?o0000okN2VongPY/01OngPY/0
1?l0003oUWB[oiIdZol00006okV4W005o`000?nGN:koUgR^oiMh[_l000001OniQYh01Ol0003oVWjc
oiYn/onJO[?o000000Go^HRR00?o0000oij9_OnNRKd00_nNRKd00ol0003o]8RWokB8Y`02okB8Y`05
o`000?nSV/coXi[<oj>Jc?l000001?n]Qjh00ol0003oZK_VojVkiP04ojVkiP;o00001onY_NP00ol0
003oZKgXojVmj002ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`00
0003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVm
j0;o000000?oZKgXo`000?l000001?nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o0000FOooool008Oooooo0ol0000Nooooo`03o`000?ngPY_o]h:K00Oo
]h:K0_l00007okV4W004o`000?nGN:koUgR^o`0000Ko^HJN00Co0000oiYn/onJO[?o00001_niR:80
1Ol0003oWXVmoij9_OnNRKgo000000Go]8RW00Co0000oj>Jc?nSV/co00001_n]Qjh00ol0003oZK_V
ojVkiP03o`000003oib2]Ol0003oZKgX00OoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003o
ZKgXojVmj005ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0Co00001OnY_NP00ol0003o
ZKgXojVmj004ojVmj0?o00001onY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX
00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o0000F?ooool004cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02?ooooo0_l00002
ooooo`;o00007Oooool00ol0003o]h:KokN2V`07okN2V`;o00001oniQ9`00ol0003oUgR^o`000007
okV6WP04o`000?nJO[?oVWjco`0000Ko^HRR00Co0000oij9_OnNRKgo00001_ndR:L00ol0003oXi[<
o`000008ojf7[P;o00001OnLP[D00ol0003oZKgXojVmj004ojVmj0?o00001onY_NP01?l0003oZKgX
ojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP01?l000000onY_NSo0000ojVmj006ojVmj004
o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX0_l0001Goooo
o`00C?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
01oooooo0ol000001_oooooo0000o`000?l0003oZKgXo`0001cooooo0_l00009okN2V`03o`000?ni
Q9co^HBL00Oo^HBL0_l00008okV6WP;o00002?niR:82o`0000So]8RW00?o0000ojf7[_n]Qjh01on]
Qjh00ol0003oW8:eoib2]@05oib2]@03o`000?nY_NSoZKgX00?o00000_nSV/`00ol0003oZKgXojVm
j005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX
00?o0000ojVmj?nY_NP01?nY_NP3o`0000?oZKgX00Co0000ojVmj?nY_NSo00001_nY_NP2o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo0000ojVmj007ojVmj003o`000?oooooooooo
05Gooooo0014ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool06oooool3o`000004ooooool0003o0000o`0000CoZKgX00?o0000ooooooooool06_ooool2
o`0000Wo]h:K00?o0000okV4W?niQ9`01oniQ9`00ol0003o^HJNokV6WP07okV6WP03o`000?niR:;o
^HRR00Oo^HRR00?o0000okB8YondR:L01ondR:L00ol0003o[HN^ojf7[P06ojf7[P;o00002?nLP[D2
o`0000KoXi[<00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0_l0
00000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP00onY
_NP01Ol0003oZKgXojVmj?nY_NSo000000;oZKgX0ol000000onY_NSo0000ojVmj007ojVmj004o`00
0?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP2o`0005Kooooo001<ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Iooooo`?o00000_ooool2o`000003
ojVmj?l0003oZKgX00CoZKgX0_l0000Kooooo`;o00002?ngPY/2o`0000Wo^HBL00?o0000okV6W_ni
QYh01oniQYh00ol0003o^HRRokV8XP07okV8XP03o`000?ndR:Oo]8RW00Ko]8RW0_l00008ojf7[P03
o`000?o5TZ3o000000OoW8:e00?o0000oj>Jc?nSV/`01_nSV/`00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX
00GoZKgX0ol00005ojVmj005o`000?nY_NSoZKgXojVmj?l000000_nY_NP4o`0000GoZKgX00?o0000
ojVmj?nY_NP01?nY_NP3o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000o`00
001Eooooo`00C?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Hooooo`?o00000_ooool2o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003ooooo
ooooo`0Hooooo`04o`000?niOY?o^GjCo`0000Oo]h:K0_l00008okV4W0;o00002?niQYh2o`0000So
^HRR0_l00008okB8Y`03o`000?noRI_o000000Ko[HN^00Co0000olFBX?o5TZ3o00001_nLP[D00ol0
003o`9BXo`000008oj>Jc0;o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP01?l0
003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
ZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oooooooooo`1Cooooo`00C?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool06?ooool2o`0000?ooooo0_l0
0007ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ooooooooool06?ooool01?l0003o^GjCokUn
Tol00007okN2V`03o`000?niOY?o000000Oo^HBL0_l00008okV6WP03o`000?ncNI?o000000Oo^HRR
00?o0000okAkUOl000001ondR:L00ol0003o_hVKo`000006ojf7[P04o`000?o5TZ3oaI:Po`0000Go
W8:e00Co0000ol2DZ?o0U:So00001onSV/`2o`0000SoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj006ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3
o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000OoZKgX0_l0001Dooooo`00C?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool05Oooool3o`0000;ooooo0ol00002ojVmj003o`000?nY_NSo
ZKgX00GoZKgX00Co0000ojVmj?nY_NSoZKgX0_l0000Iooooo`04o`000?niOY?o^GjCo`0000Ko]h:K
00Co0000okUnToniOY?o00001oniQ9`00ol0003o]gbCo`000007okV6WP03o`000?ncNI?o000000Oo
^HRR00?o0000okAkUOl000001_ndR:L01?l0003o_hVKokn9Vol00005ojf7[P05o`000?o5TZ3oaI:P
olFBX?l000001OnLP[D01Ol0003o`9BXol2DZ?o0U:So000000GoXi[<00Co0000ok:@]?nbT;Co0000
1_nY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00Co0000ojVmj?nY_NSo
ZKgX0_l000001OnY_NSo0000ojVmj?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0
003oooooo`00001Cooooo`00C?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000Boooo
o`;o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`000003ojVmj?l0003o0000
01Sooooo00Go0000okUnToniOY?o^GjCo`000006okN2V`04o`000?niOY?o^GjCo`0000Ko^HBL00Co
0000okMlTongO9?o00001_niQYh01?l0003o/gVCok=iTol00006okV8XP04o`000?ndNiGo]7^Eo`00
00Ko]8RW00Co0000okn9VonoRI_o00001On]Qjh00ol0003oaI:PolFBX002olFBX005o`000?nLP[Go
W8:eoib2]Ol000001?o0U:P00ol0003oXi[<oj>Jc002oj>Jc003o`000?nbT;Co/Y2d00;o/Y2d00?o
0000ojVmj?nY_NP00ol00002oj:DaP03o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol0
0002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgX
o`000005ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0Co00001OnY_NP00ol0003oZKgX
ojVmj004ojVmj0?o0000Doooool0073ooooo0ol000001?oooooo0000o`000?l00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0Co00006?ooool01Ol0003o^GjC
okUnToniOY?o000000Ko]h:K00Co0000okUnToniOY?o00001_niQ9`01?l0003o]gbCokMlTol00006
okV6WP04o`000?ncNI?o/gVCo`0000Ko^HRR00Co0000okAkUOndNiGo00001_ndR:L01Ol0003o_hVK
okn9VonoRI_o000000?o[HN^00?o0000olFBX?o5TZ000oo5TZ001Ol0003oW8:eoib2]OnLP[Go0000
00Go`9BX00Co0000oj>Jc?nSV/co00001_nbT;@2o`0000KoXYC600?o0000ojVmj?nY_NP01?nY_NP3
o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX0_l00002ojVmj0?o000000?oZKgX
o`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP0
0ol0003oZKgXojVmj003o`000004ojVmj?l0003oooooo`0005;ooooo001^ooooo`;o000000Cooooo
o`000?l0003o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP3o`0001Sooooo00Go
0000okUnToniOY?o^GjCo`000005okN2V`05o`000?niOY?o^GjCokUnTol000001_niQ9`01?l0003o
]gbCokMlTol00006okV6WP05o`000?ncNI?o/gVCok=iTol000001OniR:801Ol0003o]7^EokAkUOnd
NiGo000000Co]8RW00?o0000okn9VonoRI/00_noRI/01Ol0003o[HN^ojf7[_n]Qjko000000GoaI:P
00Co0000oib2]OnLP[Go00001_o0U:P00ol0003oXi[<o`000007ok:@]003o`000?nRU<KoXYC600Ko
XYC600?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?nY_NP01_nY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000Ko
ZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000GoZKgX00?o0000ooooool00000DOooool006_ooooo
1_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol0000Fooooo`03o`000?niOY?o^GjC00;o^GjC00?o0000okN2VongPY/0
0ongPY/01Ol0003o^GjCokUnToniOY?o000000Go^HBL00Go0000okMlTongO9?o]gbCo`000005okV6
WP03o`000?ncNI?o/gVC00;o/gVC00?o0000okV8X_niR:800_niR:800ol0003o]7^EokAkU@02okAk
U@03o`000?ndR:Oo]8RW00;o]8RW00?o0000okn9VonoRI/00_noRI/01?l0003o[HN^ojf7[_l00006
olFBX003o`000?nLP[Go000000So`9BX00?o0000ok:@]?nbT;@01OnbT;@00ol0003obibWo`000008
oj:DaP;o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0Co00001OnY_NP00ol0003oZKgXojVmj004
ojVmj0;o00002?nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000
ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX0_l0000Zooooo`04oa0@4?l0003o
0000o`0002?ooooo001Xooooo`?o000000?oooooo`000?l000001_nY_NP00ol0003oZKgXojVmj004
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00005_ooool00ol0003o^GjCokUnT`03
okUnT`03o`000?ngPY_o]h:K00;o]h:K00Go0000okUnToniOY?o^GjCo`000005okV4W005o`000?ng
O9?o]gbCokMlTol000001OniQYh00ol0003o/gVCok=iT`02ok=iT`03o`000?niR:;o^HRR00;o^HRR
00?o0000okAkUOndNiD00_ndNiD01Ol0003o]8RWokB8YondR:Oo000000Go_hVK00Co0000ojf7[_n]
Qjko00001oo5TZ02o`0000So`9BX00?o0000ok:@]?nbT;@01OnbT;@00ol0003obibWo`000008oj:D
aP03o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0Co0000:Oooool00ol0
003oooooooooo`0Sooooo`00IOooool3o`0000;ooooo0_l000000onY_NSo0000ojVmj006ojVmj003
o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?l000005_ooool00ol0003o^GjCokUnT`03okUnT`05o`000?ngPY_o]h:KokN2
Vol000001OniOY<01Ol0003o^HBLokV4W?niQ9co000000Go]gbC00Go0000okV6W_niQYko^HJNo`00
0005ok=iT`03o`000?niR:;o^HRR00;o^HRR00?o0000okAkUOndNiD00ondNiD01?l0003o]8RWokB8
Yol00005okn9V`03o`000?n]Qjko000000SoaI:P00?o0000ol2DZ?o0U:P01_o0U:P2o`0000Ko/Y2d
00Go0000ol^LYoo;W:OobibWo`000006oj:DaP03o`000?njVKKo000000KoZKgX0ol00006ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00004ojVmj0;o00001?nY_NP3o`000003ojVmj?l0003oZKgX00Ko
ZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o
000000CoZKgXo`000?oooooo0000:Oooool00ol0003oooooooooo`0Sooooo`00Hoooool4o`000003
ooooool0003o000000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY
_NP01?nY_NP3o`0000CoZKgX0ol0000Dooooo`03o`000?niOY?o^GjC00Co^GjC00Go0000okN2Vong
PY_o]h:Ko`000005okUnT`05o`000?niQ9co^HBLokV4W?l000001OngO9<01Ol0003o^HJNokV6W_ni
QYko000000Go/gVC00Go0000okV8X_niR:;o^HRRo`000006okAkU@04o`000?ndR:Oo]8RWo`0000Ko
_hVK0_l00008olFBX003o`000?o0U:So`9BX00Ko`9BX00?o0000olZFWol000001OnbT;@01Ol0003o
bibWol^LYoo;W:Oo000000GoXYC600Go0000okZI]_njVKKo^YVfo`000002ojVmj0?o000000?oYIo?
o`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00CoZKgX00Co0000
ojVmj?l0003oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY
_NSoZKgX00CoZKgX1?l00005ojVmj0;o0000:Oooool01_l0003oMgMgo`000?l0003oEEEEonk^kR3o
oooo001Qooooo`;o00000oooool2o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o
000000?okH/bo`000?ooool04_ooool00ol0003o^GjCokUnT`04okUnT`05o`000?ngPY_o]h:KokN2
Vol000001OniOY<01Ol0003o^HBLokV4W?niQ9co000000Go]gbC00Go0000okV6W_niQYko^HJNo`00
0006ok=iT`04o`000?niR:;o^HRRo`0000Ko]7^E00?o0000okB8Yol000001onoRI/00ol0003oaI:P
olFBX006olFBX0;o00002?o0U:P00ol0003obYJOo`000004ok:@]003o`000?o;W:OobibW00;obibW
00?o0000oj:Da_nRU<H00_nRU<H00ol0003o^YVfokZI]P03okZI]P;o00001OnUWll00ol0003oZKgX
ojVmj004ojVmj0Co00001OnY_NP00ol0003oZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX
00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj0;o0000:?ooool01_l0003oEEEEonk^k_oooooo
MgMgoeEEEB3ooooo001Nooooo`?o00000_ooool3o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP0
0ol0003oZKgXo`000004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSo
ZKgX00;oZKgX0_l000000oo]Rc;o0000ooooo`0Aooooo`03o`000?niOY?o^GjC00Co^GjC00Co0000
okN2VongPY_o00001_niOY<01?l0003o^HBLokV4W?l00006okMlT`04o`000?niQYko^HJNo`0000Oo
/gVC00Co0000okV8X_niR:;o00001_ndNiD00ol0003o]8RWo`000007okn9V`03o`000?o5TZ3oaI:P
00KoaI:P00?o0000okZ1Uol000001_o0U:P01?l0003obYJOolZFWol00004ok:@]003o`000?o;W:Oo
bibW00?obibW00Co0000oj:Da_nRU<Ko00001_njVKH00ol0003oYIo?ojFOc`05ojFOc`03o`000?nY
_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?o
ZKgXo`000?nY_NP01onY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX
0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0000Wooooo`03o`000?o^k^kooooo00;ooooo
00?o0000ooooooooool07_ooool005cooooo0_l00002ooooo`?o00001_nY_NP00ol0003oZKgXojVm
j004ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj002ojVmj0;o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj003o`000?nY_NSoZKgX00?o000000?okH/bo`000?ooool04?ooool00ol0003o^GjCokUn
T`05okUnT`04o`000?ngPY_o]h:Ko`0000Ko^GjC00Co0000okV4W?niQ9co00001_ngO9<01?l0003o
^HJNokV6W_l00007ok=iT`03o`000?niR:;o000000So]7^E0_l00007okn9V`03o`000?o5TZ3oaI:P
00KoaI:P00?o0000okZ1Uol000001_o0U:P01Ol0003obYJOolZFWoo:UYoo000000?o/Y2d00?o0000
ol^LYoo;W:L00oo;W:L00ol0003oXYC6o`000006okZI]P03o`000?o?Xj[o000000KoYIo?0ol00006
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol000000onY_NSo0000ojVmj002ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01onY
_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o000002Oooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`0Nooooo`00FOooool3o`000004ooooool0003o0000o`0000;oZKgX00?o
0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00Co
0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o000000CoZKgXo`000?l0003o
kH/b0_l0000@ooooo`03o`000?niOY?o^GjC00Go^GjC00Co0000okN2VongPY_o00001_niOY<01?l0
003o^HBLokV4W?l00006okMlT`04o`000?niQYko^HJNo`0000Oo/gVC00?o0000okV8X_l000002?nd
NiD00ol0003o_hVKokn9V`05okn9V`03o`000?o3R9Go000000KoaI:P00Co0000okZ1UonjPIOo0000
1Oo0U:P00ol0003obYJOolZFW`02olZFW`04o`000?nbT;Co/Y2do`0000OobibW00?o0000okZI]_nj
VKH01OnjVKH00ol0003ocj>Zo`000005ojFOc`03o`000?ngW[oo000000SoZKgX00?o0000ojVmj?nY
_NP00ol000001OnY_NSo0000ojVmj?nY_NSo000000CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgXojVmj004
ojVmj0Co00001OnY_NP2o`0002Kooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVHPooooo`00Eooo
ool2o`000004ooooool0003o0000o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj005o`00
0?nY_NSo0000o`000?o]Rc800_l0000@ooooo`03o`000?niOY?o^GjC00Ko^GjC0_l00007okUnT`03
o`000?niQ9co000000Oo]gbC00?o0000okV6W_l000002OncNI<2o`0000So]7^E00?o0000okn9Vono
RI/01OnoRI/00ol0003o`hREo`000006olFBX005o`000?njPIOo^X6GokZ1Uol000001?o0U:P00ol0
003obYJOolZFW`02olZFW`04o`000?nbT;Co/Y2do`0000OobibW00?o0000okZI]_njVKH01?njVKH0
1Ol0003ocj>ZolnSZ_o?Xj[o000000?oYIo?00Go0000okNN_ongW[oo]ijoo`000007ojVmj0?o0000
1OnY_NP00ol0003oZKgXo`000004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o0000
1onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP2o`0002Cooooo
00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`0Oooooo`00E?ooool6o`0000;oZKgX00?o
0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY
_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX0ol0
00001?o]Rc;o0000ooNVGol0000>ooooo`03o`000?niOY?o^GjC00Oo^GjC0_l00008okUnT`;o0000
2?ngO9<2o`0000Wo/gVC00?o0000okAkUOndNiD01ondNiD00ol0003o_hVKokn9V`05okn9V`03o`00
0?o3R9Go000000KoaI:P00Go0000okZ1UonjPIOo^X6Go`000004ol2DZ003o`000?o:UYoobYJO00;o
bYJO00?o0000ok:@]?l000001oo;W:L00ol0003oci^Qo`000005okZI]P05o`000?o?Xj[ocj>ZolnS
Z_l000000_nUWll00ol0003o]ijookNN_`03okNN_`04o`000?nY_NSoZKgXojVmj0?o000000?oZKgX
o`000?nY_NP01_nY_NP2o`000006ojVmj?l0003o0000o`000?nY_NSo00001onY_NP00ol0003oZKgX
ojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP0
0onY_NP4o`0004[ooooo001Aooooo`Ko00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj002ojVmj0;o000000?o
ZKgXo`000?nY_NP01onY_NP2o`000004onf;<_l0003omjIOo`0000kooooo00?o0000okUnToniOY<0
1oniOY<2o`0000So^GjC0_l00008okMlT`;o00002OncNI<00ol0003o]7^EokAkU@06okAkU@;o0000
1onoRI/00ol0003o`hREo`000005olFBX003o`000?njPIOo^X6G00;o^X6G00Go0000ol2DZ?o0U:So
`9BXo`000006olZFW`;o00001oo;W:L00ol0003oci^Qo`000004okZI]P03o`000?o?Xj[ocj>Z00;o
cj>Z00?o0000ojFOcol000001_ngW[l01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX
00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP2o`00
04[ooooo001?ooooo`;o000000?oooooo`000?l000000_nY_NP00ol0003oZKgXojVmj005ojVmj003
o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o
00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVm
j?nY_NP01OnY_NP4o`0000;omjIO00?o0000ooooooooool02oooool00ol0003o^GjCokUnT`07okUn
T`03o`000?niOY?o^GjC00Oo^GjC00?o0000okMlTongO9<01ongO9<00ol0003o/gVCok=iT`08ok=i
T`03o`000?ndNiGo]7^E00Ko]7^E00?o0000on>VTol000001OnoRI/01Ol0003o`hREol>8UOo3R9Go
000000CoaI:P00?o0000okZ1UonjPIL00onjPIL01?l0003o`9BXol2DZ?l00006olZFW`03o`000?o;
W:OobibW00KobibW00?o0000olnKXOl000001?njVKH00ol0003ocj>ZolnSZP03olnSZP03o`000?ng
W[oo]ijo00Ko]ijo00?o0000ojVmj?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0
003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj004o`000?nY
_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ooooooooool0
2?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03_ooooo000Uooooo`Co000000?o410@ooooooooool0
8?ooool3o`000003ooooool0003o000000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX
00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX
00?o0000ojVmj?nY_NP00_nY_NP2o`000004ojVmj?l0003o0000o`0000;omjIO00?o0000oooooooo
ool02oooool00ol0003o^GjCokUnT`07okUnT`03o`000?niOY?o^GjC00Oo^GjC00?o0000okMlTong
O9<01ongO9<00ol0003o/gVCok=iT`07ok=iT`;o00002?ndNiD00ol0003ohjJCo`000005okn9V`05
o`000?o3R9Go`hREol>8UOl000001?o5TZ000ol0003o^X6GokZ1U`03okZ1U`03o`000?o0U:So0000
00OobYJO00?o0000ol^LYoo;W:L01Oo;W:L01Ol0003oci^QolnKXOo?Vj7o000000;o^YVf00?o0000
olnSZ_o?XjX01?o?XjX00ol0003o]ijookNN_`06okNN_`03o`000?nY_NSoZKgX00KoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00007
ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01_nY_NP2o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0kooooo`009oooool00ol0003oooooooooo`0Pooooo`;o00000ooo
ool2o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00000onY_NP3o`0000;o
mjIO00?o0000ooooooooool02_ooool2o`0000Wo^GjC00?o0000okUnToniOY<01oniOY<00ol0003o
]gbCokMlT`07okMlT`03o`000?ncNI?o/gVC00Oo/gVC0_l00008okAkU@03o`000?oSYY?o000000Go
_hVK00Go0000ol>8UOo3R9Go`hREo`000003olFBX003o`000?njPIOo^X6G00Co^X6G00?o0000ol2D
Z?l000001oo:UYl2o`0000KobibW00Go0000olnKXOo?Vj7oci^Qo`000002okZI]P03o`000?o?Xj[o
cj>Z00?ocj>Z00?o0000omJUY?l000001_ngW[l00ol0003ocJVeo`000004ojVmj0?o000000?oYjOF
o`000?nY_NP01OnY_NP2o`0000;oZKgX0ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000Sooooo00Go410@oooooooooooooooooa0@400kooooo`007?oo
ool6o`0000Gooooo00?o0000ooooooooool07Oooool3o`0000;ooooo0ol00002ojVmj003o`000?nY
_NSoZKgX00GoZKgX00?o0000ojVmj?l000001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001OnY
_NP3o`0000;omjIO0_l0000;ooooo`;o00002?niOY<2o`0000So^GjC0_l00008okMlT`;o00002Onc
NI<2o`0000So]7^E00?o0000on>VTol000001OnoRI/01Ol0003o`hREol>8UOo3R9Go000000?oaI:P
00?o0000okZ1UonjPIL01OnjPIL2o`0000KobYJO00?o0000okf3U_l000001Oo;W:L00ol0003oci^Q
olnKX@02olnKX@03o`000?njVKKo000000Kocj>Z00?o0000omJUY?l000001OngW[l01_l0003ocJVe
olfY]Oo=ZKGo0000ojVmj0;o00001OnWYmH00ol0003oZKgXojVmj003ojVmj0Co00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001onY_NP00ol0
003oZKgXojVmj003o`000003ojVmj?l0003o000000Sooooo00Go0000ooooooooooooooooo`00000k
ooooo`009oooool00ol0003oooooooooo`0Jooooo`?o00000_ooool3o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00GoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00002ooNVG`;o00002oooool2o`00
00So^GjC0_l00008okUnT`;o00002?ngO9<2o`0000Wo/gVC00?o0000oo6fS_l000001_ndNiD01?l0
003ohjJCon>VTol00004okn9V`03o`000?o3R9Go`hRE00?o`hRE00Co0000olFBX?o5TZ3o00001onj
PIL00ol0003obYJOolZFW`05olZFW`03o`000?nmPiKo000000GobibW00?o0000olnKXOo?Vj400oo?
Vj42o`0000Kocj>Z00?o0000omJUY?l000001?ngW[l00ol0003ocJVeolfY]@03olfY]@03o`000?nW
YmKoYjOF00KoYjOF00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o
0000ojVmj?nY_NP01OnY_NP3o`0000GoZKgX0_l00007ooooo`05o`000?ooooooooooooooool00000
>oooool002Oooooo00?o0000ooooooooool06?ooool7o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY
_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00Co
0000ojVmj?nY_NSoZKgX0ol00002ooNVG`;o00002_ooool00ol0003okKNGo`000008okUnT`;o0000
2?niOY<2o`0000So]gbC0_l00009ok=iT`03o`000?oa]Xko000000Ko]7^E00Co0000on>VTooSYY?o
00001?noRI/00ol0003o`hREol>8U@03ol>8U@03o`000?o5TZ3o000000So^X6G00?o0000olZFWoo:
UYl01Oo:UYl01?l0003o_H>Fokf3U_l00004ol^LY`03o`000?o?Vj7oci^Q00?oci^Q00?o0000olnS
Z_o?XjX01?o?XjX01Ol0003oeZFTomJUY?oFYJCo000000?o]ijo00?o0000olfY]Oo=ZKD00oo=ZKD0
0ol0003oYjOFojNWeP06ojNWeP?o00000_nY_NP01?l0003oZKgXojVmj?l00006ojVmj0?o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj002ojVmj0;o000000?o
ZKgXo`000?nY_NP01_nY_NP2o`0000Kooooo00Go410@oooooooooooooooooa0@400kooooo`009ooo
ool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000ol00002ooNVG`03o`00
0?oj[E3o000000Wooooo00?o0000onfgUol000002?niOY<00ol0003okkREo`000007okUnT`03o`00
0?o`^9Co000000Oo]gbC0_l00008ok=iT`04o`000?oa]XkolKJ>o`0000Ko]7^E00Co0000on>VTooS
YY?o00001?noRI/00ol0003o`hREol>8U@03ol>8U@03o`000?o5TZ3o000000So^X6G00?o0000olZF
Woo:UYl01?o:UYl01Ol0003o_H>Fokf3U_nmPiKo000000?obibW00?o0000olnKXOo?Vj401?o?Vj40
0ol0003ocj>ZolnSZP04olnSZP05o`000?oFYJCoeZFTomJUY?l000000_ngW[l00ol0003ocJVeolfY
]@03olfY]@03o`000?oJ[jco000000GoYjOF0_l000000onhZlco0000ojVmj002ojVmj005o`000?nY
_NSoZKgXojVmj?l000000_nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol000000onY_NSo0000ojVmj007ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY
_NP01?nY_NP3o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0kooooo`009oooool00ol0003o
ooooooooo`0Cooooo`?o000000Coooooo`000?l0003o00000_nY_NP00ol0003oZKgXojVmj004ojVm
j003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo0000
00GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`000004ojVmj?l0003o0000o`0000;omjIO00?o0000
ooZ]D?l000002Oooool00ol0003okKNGo`000007okUnT`04o`000?o_^9GokkREo`0000Oo^GjC00?o
0000oo2hU?l000001ongO9<00ol0003olKNAo`000007ok=iT`04o`000?oa]XkolKJ>o`0000Ko]7^E
00Go0000on>VTooSYY?ohjJCo`000002okn9V`03o`000?o3R9Go`hRE00Co`hRE00?o0000olFBX?l0
00001onjPIL00ol0003oi:NBo`000005olZFW`05o`000?nmPiKo_H>Fokf3U_l000000oo;W:L00ol0
003oci^QolnKX@04olnKX@03o`000?o?Xj[ocj>Z00?ocj>Z00?o0000omJUY?oFYJ@00_oFYJ@00ol0
003o]ijoo`000006olfY]@04o`000?oJ[jcofZn/o`0000?oYjOF00?o0000okR[c?nhZl`00_nhZl`0
1?l0003oZKgXojVmj?l00003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0
003o000000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0kooooo`009Oooool00omEEEGoIVIVo`00
000Booooo`?o000000Coooooo`000?l0003o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o0000
1_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX
00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00Co000000ComjIOo`000?oj[E3o
00002Oooool01?l0003okKNGonfgUol00006okUnT`04o`000?o_^9GokkREo`0000Ko^GjC00Co0000
oo2hU?o`^9Co00001_ngO9<01?l0003olKNAoo6gTOl00007ok=iT`04o`000?oa]XkolKJ>o`0000Ko
]7^E00Go0000on>VTooSYY?ohjJCo`000002okn9V`03o`000?o3R9Go`hRE00Go`hRE00?o0000okZ1
UonjPIL01_njPIL00ol0003oi:NBo`000005olZFW`03o`000?nmPiKo_H>F00;o_H>F00?o0000ol^L
Yol000001_o?Vj400ol0003oaHfIo`000004olnSZP03o`000?oFYJCoeZFT00?oeZFT00?o0000olfY
]Oo=ZKD01Oo=ZKD01Ol0003ofZn/omZ_[?l0003oYjOF00;o00001_nhZl`00ol0003oZKgXo`000003
o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006
ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001OnY_NP2
o`0004Cooooo000hooooo`Ko00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001OnY_NP5o`000005ooNVGol0003onZe@ooZ]D?l000001oooool0
1Ol0003okKNGonfgUoo]]iOo000000Ko^GjC00Co0000onnhUOo_^9Go00001_niOY<01?l0003ol;RD
oo2hU?l00006okMlT`04o`000?oa]i7olKNAo`0000Oo/gVC00Co0000oo6fS_oa]Xko00001OndNiD0
0ol0003ohjJCon>VT`02on>VT`04o`000?noRI_o_hVKo`0000Oo`hRE00?o0000okZ1UonjPIL01_nj
PIL00ol0003oi:NBo`000004olZFW`03o`000?nmPiKo_H>F00?o_H>F00?o0000ol^LYol000001_o?
Vj400ol0003oaHfIo`000004olnSZP03o`000?oFYJCoeZFT00?oeZFT00?o0000olfY]Oo=ZKD01?o=
ZKD00ol0003ofZn/omZ_[002omZ_[003o`000?nhZlco^:_<00Oo^:_<0_l00005ojVmj003o`000?nY
_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj004o`000?nY
_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oooooooooo`12ooooo`00=Ooo
ool7o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj004ojVmj0Co00000_ogYUl01?l0003onZe@o`000?l00006ooooo`05
o`000?o]]iOokKNGonfgUol000001OniOY<01Ol0003okkREonnhUOo_^9Go000000Ko^GjC00Co0000
oo2hU?o`^9Co00001_ngO9<01?l0003olKNAoo6gTOl00006ok=iT`05o`000?oa]XkolKJ>oo6fS_l0
00001OndNiD00ol0003ohjJCon>VT`02on>VT`04o`000?noRI_o_hVKo`0000Oo`hRE00?o0000okZ1
UonjPIL01_njPIL00ol0003oi:NBo`000004olZFW`03o`000?nmPiKo_H>F00?o_H>F00?o0000ol^L
Yol000001_o?Vj400ol0003oaHfIo`000003olnSZP03o`000?oFYJCoeZFT00CoeZFT0_l00005olfY
]@03o`000?oJ[jcofZn/00;ofZn/00?o0000okR[c?nhZl`01?nhZl`5o`0000KoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01_nY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00013
ooooo`00<oooool2o`000003ooooool0003o000000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0
003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`00
00;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000005ojVmj003o`000?nY_NSoZKgX
00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX
00?oZKgX1?l00002ooNVG`05o`000?oj[E3o0000onn@>ol000001Oooool01Ol0003okKNGonfgUoo]
]iOo000000Go^GjC00Go0000onnhUOo_^9GokkREo`000006okUnT`04o`000?o`^9Col;RDo`0000Ko
]gbC00Co0000oo6gTOoa]i7o00001_ncNI<01Ol0003olKJ>oo6fS_oa]Xko000000Go]7^E00?o0000
on>VTooSYY<00_oSYY<00ol0003o_hVKo`000008ol>8U@03o`000?njPIOo^X6G00Ko^X6G00?o0000
onBWT_l000001?o:UYl00ol0003o_H>Fokf3UP04okf3UP03o`000?o?Vj7oci^Q00Coci^Q00Go0000
olF=VOo5SIWoaHfIo`000002olnSZP03o`000?oFYJCoeZFT00?oeZFT00?o0000omZWXOl000001?o=
ZKD00ol0003ofZn/omZ_[002omZ_[003o`000?oQ]:So000000;o^:_<0ol000001?nhZlco0000ol^f
a_o;]/H2o`0000CoZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP2o`0004;ooooo
000`ooooo`?o00000_ooool00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0
0006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l0
0007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY
_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000Ko00000_og
YUl01_l0003onZe@ooZ]D?l0003oki0ko`0000Cooooo00Go0000onfgUoo]]iOokKNGo`000005okUn
T`05o`000?o_^9GokkREonnhUOl000001OniOY<01Ol0003ol;RDoo2hU?o`^9Co000000Ko]gbC00Co
0000oo6gTOoa]i7o00001_ncNI<01Ol0003olKJ>oo6fS_oa]Xko000000Go]7^E00?o0000on>VTooS
YY<00_oSYY<00ol0003o_hVKo`000007ol>8U@;o00001onjPIL01Ol0003oi:NBonBWT_oTYi;o0000
00;obYJO00?o0000okf3U_nmPiH01OnmPiH00ol0003oci^QolnKX@04olnKX@07o`000?o5SIWoaHfI
olF=VOl0003ocj>Zo`000006omJUY004o`000?oJYj7ofZNQo`0000?ocJVe00?o0000omZ_[?oJ[j`0
0_oJ[j`00ol0003ohKBXo`000002o`0000?o^:_<00Ko0000ol^fa_o;]/KobkK6o`000?nY_NP4o`00
00;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX
00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj0?o00001_nY_NP00ol0
003oooooooooo`10ooooo`00;oooool2o`0000;ooooo0_l00008ojVmj003o`000?nY_NSo000000;o
00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003o
ZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj0?o
00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o
00000onY_NP4o`0000;omjIO00Ko0000ooZ]D?oj[E3o0000onn@>ol00003ooooo`03o`000?o]]iOo
kKNG00;okKNG00?o0000okUnToniOY<00oniOY<01Ol0003okkREonnhUOo_^9Go000000Go^GjC00Go
0000oo2hU?o`^9Col;RDo`000005okMlT`05o`000?oa]i7olKNAoo6gTOl000001_ncNI<01Ol0003o
lKJ>oo6fS_oa]Xko000000Co]7^E00?o0000on>VTooSYY<00ooSYY<00ol0003o_hVKo`000007ol>8
U@;o00001onjPIL01Ol0003oi:NBonBWT_oTYi;o000000;obYJO00?o0000okf3U_nmPiH01OnmPiH0
0ol0003oci^QolnKX@04olnKX@07o`000?o5SIWoaHfIolF=VOl0003ocj>Zo`000006omJUY004o`00
0?oJYj7ofZNQo`0000;ocJVe00?o0000omZ_[?oJ[j`00_oJ[j`3o`000003on6dZ?l0003o^:_<00;o
^:_<00?o0000ol^fa_o;]/H00oo;]/H3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000Go
ZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003
ojVmj?l0003oZKgX00KoZKgX0_l00011ooooo`00;oooool4o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00Go
ZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY
_NP00ol000000onY_NSo0000ojVmj003ojVmj0?o00000_ogYUl01Ol0003onZe@ooZ]D?l0003oki0k
00;o00000_ooool00ol0003okKNGonfgU`02onfgU`03o`000?niOY?o^GjC00;o^GjC00?o0000onnh
UOo_^9D00_o_^9D00ol0003o^GjCokUnT`03okUnT`05o`000?o`^9Col;RDoo2hU?l000001OngO9<0
1Ol0003olKNAoo6gTOoa]i7o000000Ko/gVC00?o0000oo6fS_oa]Xh00_oa]Xh01Ol0003o]7^EokAk
UOndNiGo000000KohjJC0_l00007ol>8U@;o00001onjPIL01Ol0003oi:NBonBWT_oTYi;o000000;o
bYJO00?o0000okf3U_nmPiH01OnmPiH2o`0000Coci^Q00?o0000olF=VOo5SIT00oo5SIT2o`0000Go
eZFT00?o0000omZWXOoJYj400_oJYj401?l0003ocJVeo`000?oJ[j`4o`0000?ohKBX00Co0000okR[
c?nhZlco00001_o;]/H00ol0003oZKgXo`000005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP0
1?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00010ooooo`00;_ooool2
o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000005ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj004o`000?nY_NSo
ZKgXojVmj0?o00000_ogYUl02_l0003onZe@ooZ]D?l0003oki0ko`000?oeXf3o0000ooooool00004
onfgU`03o`000?niOY?o^GjC00;o^GjC00?o0000onnhUOo_^9D00_o_^9D00ol0003o^GjCokUnT`03
okUnT`05o`000?o`^9Col;RDoo2hU?l000001OngO9<01Ol0003olKNAoo6gTOoa]i7o000000Go/gVC
00?o0000oo6fS_oa]Xh00ooa]Xh01Ol0003o]7^EokAkUOndNiGo000000KohjJC00?o0000ol>8UOo3
R9D01_o3R9D00ol0003olkV?o`000006okZ1U`07o`000?oTYi;oi:NBonBWT_l0003obYJOo`000007
okf3UP03o`000?o^/Hko000000Coci^Q00?o0000olF=VOo5SIT00oo5SIT00ol0003oeZFTomJUY004
omJUY003o`000?oJYj7ofZNQ00;ofZNQ1?l00003omZ_[007o`000?oQ]:SohKBXon6dZ?l0003o^:_<
o`000006ol^faP05o`000?oF_L7o0000ojVmj?l000001?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY
_NP00onY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY
_NP00ol000000onY_NSo0000o`000010ooooo`00;oooool2o`0000KoZKgX00Co0000ojVmj?l0003o
00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o
00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;omjIO00Ko0000ooZ]D?oj[E3o0000onn@>ol00002
ooFSH003o`000?o]]iOokKNG00?okKNG00?o0000okUnToniOY<00_niOY<00ol0003okkREonnhU@02
onnhU@03o`000?niOY?o^GjC00?o^GjC00Go0000oo2hU?o`^9Col;RDo`000005okMlT`05o`000?oa
]i7olKNAoo6gTOl000001OncNI<00ol0003olKJ>oo6fSP03oo6fSP05o`000?ndNiGo]7^EokAkUOl0
00001_oSYY<00ol0003o`hREol>8U@06ol>8U@03o`000?oc^Hoo000000Ko^X6G00Oo0000onBWT_oT
Yi;oi:NBo`000?o:UYoo000000Oo_H>F00?o0000onjaS_l000001?o?Vj400ol0003oaHfIolF=V@03
olF=V@03o`000?oFYJCoeZFT00CoeZFT00?o0000omZWXOoJYj401?l00005omZ_[003o`000?oQ]:So
hKBX00;ohKBX00?o0000ol^fa_o;]/H01?o;]/H01_l0003oe[g1omJm`OoF_L7o0000ojVmj0Co0000
00?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
0_l0000oooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo
00001OnY_NP3o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00Go
ZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY
_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX1_l00002ooNVG`03o`000?oj[E3onZe@00?o
00000_oeXf000ol0003okKNGonfgU`03onfgU`03o`000?niOY?o^GjC00;o^GjC00?o0000onnhUOo_
^9D00oo_^9D01Ol0003o^GjCokUnToniOY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000004
oo6gT@03o`000?ncNI?o/gVC00?o/gVC00?o0000oo6fS_oa]Xh00ooa]Xh01Ol0003o]7^EokAkUOnd
NiGo000000KohjJC00?o0000ol>8UOo3R9D01Oo3R9D01?l0003olkV?oo>iSol00005okZ1U`03o`00
0?oTYi;oi:NB00?oi:NB0_l00007okf3UP03o`000?o^/Hko000000Coci^Q00?o0000olF=VOo5SIT0
0oo5SIT2o`0000GoeZFT0ol00003omZWX@03o`000?oJ[jcofZn/00;ofZn/00?o0000on6dZ?oQ]:P0
0ooQ]:P00ol0003obkK6ol^faP04ol^faP03o`000?oF_L7oe[g100;oe[g10_l00005ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00006ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP2o`0003kooooo000Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool01_l0003ooooooooooooooooo0000ojVmj0?o00000onY_NP00ol0
003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0
003oZKgXo`000002o`0000;oZKgX1?l00002ooNVG`03o`000?oj[E3onZe@00?o00000_oeXf000ol0
003okKNGonfgU`03onfgU`05o`000?niOY?o^GjCokUnTol000001_o_^9D01Ol0003o^GjCokUnToni
OY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000005oo6gT@03o`000?ncNI?o/gVC00;o/gVC
00?o0000oo6fS_oa]Xh00ooa]Xh01?l0003o]7^EokAkUOl00007on>VT`03o`000?o3R9Go`hRE00Go
`hRE00Co0000oo>iSooc^Hoo00001OnjPIL00ol0003oi:NBonBWTP03onBWTP03o`000?nmPiKo_H>F
00Ko_H>F00?o0000onjaS_l000000oo?Vj400ol0003oaHfIolF=V@04olF=V@;o00000ooFYJ@3o`00
00GofZNQ0_l00003omZ_[003o`000?oQ]:SohKBX00;ohKBX00?o0000onFgY_l000001?o;]/H00ol0
003oe[g1omJm`@03omJm`@03o`000?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVm
j0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0;o0000?_ooool002?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo00;ooooo00?o0000ojVmj?nY_NP01OnY_NP00ol0
003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`00
00;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000KoZKgX0ol00002ooNVG`03o`000?oj[E3onZe@00?o00000_oeXf000ol0
003okKNGonfgU`03onfgU`05o`000?niOY?o^GjCokUnTol000001_o_^9D01Ol0003o^GjCokUnToni
OY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000005oo6gT@05o`000?ncNI?o/gVCok=iTol0
00001_oa]Xh01?l0003o]7^EokAkUOl00006on>VT`;o00001oo3R9D01?l0003olkV?oo>iSol00005
okZ1U`03o`000?oTYi;oi:NB00?oi:NB00?o0000okf3U_nmPiH01_nmPiH01?l0003ok[6>onjaS_l0
0002olnKX@03o`000?o5SIWoaHfI00?oaHfI00?o0000on2TTol000000ol000000ooFYJCo0000omZW
X@04omZWX@03o`000?oAVY_o000000?ofZn/00?o0000on6dZ?oQ]:P00_oQ]:P01?l0003oiKNVonFg
Y_l00003ol^faP03o`000?oF_L7oe[g100;oe[g100Go0000omo4_Ol0003oZKgXo`000004ojVmj0?o
00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`00
0003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000moooo
o`008oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP2o`0000;oZKgX00?o0000
ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000
ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?l005[o000000;omjIO00?o0000
ooZ]D?oj[E000_l000000oo_T3_o0000o`000006onfgU`05o`000?niOY?o^GjCokUnTol000001_o_
^9D01Ol0003o^GjCokUnToniOY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000005oo6gT@05
o`000?ncNI?o/gVCok=iTol000001_oa]Xh01?l0003o]7^EokAkUOl00006on>VT`;o00001oo3R9D0
1?l0003olkV?oo>iSol00005okZ1U`03o`000?oTYi;oi:NB00?oi:NB00?o0000okf3U_nmPiH01_nm
PiH01?l0003ok[6>onjaS_l00002olnKX@03o`000?o5SIWoaHfI00?oaHfI1?l00003omJUY003o`00
0?oJYj7ofZNQ00?ofZNQ00?o0000om6JVol000000_oJ[j`00ol0003ohKBXon6dZ003on6dZ007o`00
0?oU]jKoiKNVonFgY_l0003obkK6o`000005omJm`@05o`000?oOa;goglBmo`000?nY_NP01?l00000
0onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP0
1?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00005ojVmj0;o0000??oo
ool002?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00Co
0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o0000
1OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj003o`00
0?l005[o000000;omjIO00Ko0000ooZ]D?oj[E3onZe@o`000?o_T3/2o`0000KokKNG00Go0000okUn
ToniOY?o^GjCo`000006onnhU@05o`000?niOY?o^GjCokUnTol000001Oo`^9@01Ol0003o]gbCokMl
TongO9?o000000GolKNA00Go0000ok=iToncNI?o/gVCo`000006oo6fSP04o`000?ndNiGo]7^Eo`00
00KohjJC00?o0000oo6kUol000001_o3R9D01?l0003olkV?oo>iSol00004okZ1U`03o`000?oTYi;o
i:NB00Coi:NB00?o0000okf3U_nmPiH01OnmPiH01ol0003ok[6>onjaS_o^/Hko0000olnKXOl00000
0oo5SIT4o`0000;oh:BC00Go0000omJUY?oFYJCoeZFTo`000005omZWX@06o`000?oAVY_odIZKo`00
0?oJ[jco00001?oQ]:P00ol0003oiKNVonFgYP03onFgYP03o`000?oF_L7oe[g100?oe[g100?o0000
omo4_OoOa;d00_oOa;d2o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l0000looooo`008oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00006
ooooo`03o`000?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol000001Ol005[o0000o`000?og
YUoo000000?onZe@1?l00006onfgU`04o`000?niOY?o^GjCo`0000OokkRE00Co0000okUnToniOY?o
00001_o`^9@01?l0003o]gbCokMlTol00006oo6gT@05o`000?ncNI?o/gVCok=iTol000001_oa]Xh0
1?l0003o]7^EokAkUOl00006on>VT`03o`000?oa^iOo000000Go`hRE00Go0000oo>iSooc^HoolkV?
o`000004okZ1U`03o`000?oTYi;oi:NB00Coi:NB00?o0000okf3U_nmPiH01OnmPiH01_l0003ok[6>
onjaS_o^/Hko0000olnKX@Co00000oo5SIT01?l0003oh:BCon2TTol00002omJUY003o`000?oJYj7o
fZNQ00?ofZNQ00Oo0000om6JVooAVY_odIZKo`000?oJ[jco000000CohKBX00?o0000onFgY_oU]jH0
0ooU]jH00ol0003oe[g1omJm`@02omJm`@03o`000?oOa;goglBm00?oglBm00?o0000ojVmj?l00000
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol0000kooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
1oooool2o`0000KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX
00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP0
0ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00002ojVmj006o`000?l005[o0000o`000?og
YUoo00000ooj[E04o`0000OokKNG00?o0000okUnTol000001oo_^9D01?l0003o^GjCokUnTol00006
oo2hU004o`000?ngO9?o]gbCo`0000KolKNA00Go0000ok=iToncNI?o/gVCo`000006oo6fSP03o`00
0?ndNiGo000000KohjJC00Co0000oo6kUooa^iOo00001Oo3R9D01Ol0003olkV?oo>iSooc^Hoo0000
00Co^X6G00?o0000onBWT_oTYi800ooTYi800ol0003om;^@o`000006okf3UP04o`000?o^/Hkok[6>
onjaSP?o00001_o5SIT01ol0003oh:BCon2TTooPY9?o0000omJUY?l000001OoJYj401?l0003odIZK
om6JVooAVY/2o`0000GohKBX00?o0000onFgY_oU]jH00_oU]jH00ol0003ojKZTo`000003omJm`@03
o`000?oOa;goglBm00;oglBm00Go0000onG:_?l0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX
00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000kooooo`008oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02Oooool00ol0003oZKgXojVmj003ojVm
j0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVm
j0?o00001onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0
003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`00
00;oZKgX00Go0000ojVmj?nY_NSo0000o`00FP02o`000003ooNVGol0003onZe@00;onZe@0ol00008
onfgU`03o`000?niOY?o000000OokkRE00Co0000okUnToniOY?o00001_o`^9@01?l0003o]gbCokMl
Tol00006oo6gT@04o`000?ncNI?o/gVCo`0000OolKJ>00?o0000okAkUOl000001_oSYY<01?l0003o
lK^Goo6kUol00005ol>8U@03o`000?oc^HoolkV?00;olkV?00Go0000okZ1UonjPIOo^X6Go`000005
onBWTP03o`000?od^i3o000000Ko_H>F1?l000000oo^/Hko0000olF=V@06olF=V@07o`000?oPY9?o
h:BCon2TTol0003oeZFTo`000005omZWX@03o`000?oAVY_odIZK00;odIZK00?o0000on6dZ?oQ]:P0
0_oQ]:P00ol0003oiKNVonFgYP03onFgYP06o`000?oY^ZCojKZTo`000?oF_L7o00001?oOa;d01_l0
003oiLZlonG:_?oUb[co0000ojVmj0Co000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVm
j003o`000003ojVmj?l0003oZKgX00KoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0
0005ojVmj0;o0000>_ooool002gooooo00?o0000ooooooooool02_ooool00ol0003oZKgXo`000002
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000KoZKgX00Co0000ojVmj?l0003o001J0_l000000oogYUoo0000ooZ]D002ooZ]D0?o00002?o]
]iL2o`0000SokkRE00Co0000okUnToniOY?o00001_o`^9@01?l0003o]gbCokMlTol00006oo6gT@04
o`000?ncNI?o/gVCo`0000SolKJ>0_l00006on>VT`04o`000?oa^iOolK^Go`0000Go`hRE00?o0000
oo>iSooc^Hl00_oc^Hl01Ol0003o^X6GokZ1UonjPIOo000000Goi:NB00?o0000ooBkT?l000001Onm
PiH2o`0000Cok[6>00?o0000olF=VOo5SIT01?o5SIT00ol0003oh:BCon2TT`02on2TT`;o00001OoJ
Yj400ol0003odIZKom6JV`03om6JV`03o`000?oQ]:SohKBX00;ohKBX00?o0000onFgY_oU]jH00ooU
]jH01_l0003ojKZTonVjY?l0003oe[g1o`0000CoglBm00?o0000onG:_?oUb[`00_oUb[`2o`0000Go
ZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003
ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj0;o
0000>Oooool002gooooo00?o0000ooooooooool02oooool00ol0003oZKgXojVmj004ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`00
0?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o0000
00?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX
0_l000001Ol005[o0000o`000?ogYUoo000000?onZe@0ol00008onfgU`;o00002?o_^9D00ol0003o
^GjCo`000007oo2hU004o`000?ngO9?o]gbCo`0000KolKNA00Co0000ok=iToncNI?o00002?oa]Xh2
o`0000GohjJC00Go0000oo6kUooa^iOolK^Go`000005ol>8U@03o`000?oc^HoolkV?00;olkV?00Co
0000okZ1UonjPIOo00001_oTYi800ol0003om;^@o`000002okf3UP?o000000?o_H>Fo`000?o^/Hh0
0oo^/Hh00ol0003oaHfIolF=V@04olF=V@03o`000?oPY9?oh:BC00?oh:BC00?o0000omZWXOoJYj40
0ooJYj400ol0003odIZKom6JV`03om6JV`;o00000ooQ]:P00ol0003oiKNVonFgYP02onFgYP03o`00
0?oY^ZCojKZT00;ojKZT00?o0000omo4_OoOa;d00_oOa;d00ol0003oiLZlonG:_003onG:_003o`00
0?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj004o`00
0?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY
_NP01?nY_NP2o`0003Wooooo000]ooooo`03o`000?oooooooooo00cooooo00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgX
ojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000;o001J00Co0000ooNVGoogYUoo00000_oj[E02o`0000WokKNG0_l00008onnhU@03
o`000?niOY?o000000Ool;RD00?o0000okMlTol000001ooa]i401?l0003o/gVCok=iTol00008oo6f
SP;o00001OoSYY<01Ol0003olK^Goo6kUooa^iOo000000Co`hRE00?o0000oo>iSooc^Hl00ooc^Hl0
1?l0003o^X6GokZ1Uol00006onBWTP03o`000?od^i3o000000;o00000onmPiH00ol0003ok[6>onja
SP03onjaSP03o`000?o5SIWoaHfI00CoaHfI00?o0000on2TTooPY9<00ooPY9<00ol0003ofZNQomZW
X@03omZWX@03o`000?oAVY_odIZK00;odIZK00?o0000omjSUOl000000_oQ]:P00ol0003oiKNVonFg
YP03onFgYP03o`000?oY^ZCojKZT00;ojKZT00?o0000omo4_OoOa;d00_oOa;d00ol0003oiLZlonG:
_002onG:_005o`000?oYdKgo0000ojVmj?l000001?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?l00000>?ooool002gooooo00?o0000ooooooooool03Ooo
ool00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY
_NP01?l0003oZKgXojVmj?nY_NP2o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgX
o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX
00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`000005ojVmj?l0003o0000o`00F_l0
00000_ogYUl00ol0003onZe@o`000002o`0000WokKNG0_l00009onnhU@;o00002?o`^9@2o`0000Oo
lKNA00?o0000ok=iTol000002Ooa]Xh00ol0003ohjJCon>VT`04on>VT`05o`000?oa^iOolK^Goo6k
Uol000001?o3R9D00ol0003olkV?oo>iS`03oo>iS`04o`000?njPIOo^X6Go`0000Goi:NB1?l00005
okf3UP03o`000?o^/Hkok[6>00?ok[6>00?o0000olF=VOo5SIT01?o5SIT00ol0003oh:BCon2TT`03
on2TT`03o`000?oJYj7ofZNQ00?ofZNQ00?o0000om6JVooAVY/00_oAVY/01_l0003ogZ>EomjSUOl0
003ohKBXo`0000GoiKNV00Oo0000onVjY?oY^ZCojKZTo`000?o^`:;o000000;oglBm00?o0000onG:
_?oUb[`00_oUb[`01?l0003ojM6monWA_OoYdKd2o`000006ojVmj?l0003o0000o`000?nY_NSo0000
1onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00005ojVmj003o`00
0?nY_NSoZKgX00?oZKgX1?l00005ojVmj0;o0000=oooool002cooooo0ol0000?ooooo`03o`000?nY
_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY
_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP01?nY
_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000GoZKgX00Co0000o`00F_l0003omjIO0ol00002oj6ReP03o`000?o]]iOokKNG00OokKNG
00?o0000onnhUOo_^9D02?o_^9D2o`0000Sol;RD0_l00008oo6gT@;o00002Ooa]Xh00ol0003ohjJC
on>VT`04on>VT`05o`000?oa^iOolK^Goo6kUol000001?o3R9D00ol0003olkV?oo>iS`03oo>iS`04
o`000?njPIOo^X6Go`0000;oi:NB1?l00002ooBkT003o`000?nmPiKo_H>F00?o_H>F00?o0000onja
S_o^/Hh00_o^/Hh00ol0003om;b?o`000005olF=V@03o`000?oPY9?oh:BC00?oh:BC0_l00003omZW
X@03o`000?oAVY_odIZK00?odIZK00Ko0000omjSUOoNXiGo0000on6dZ?l00004onFgYP03o`000?oY
^ZCojKZT00;ojKZT00Go0000onk0X_l0003oglBmo`000005onG:_003o`000?oYdKgojM6m00;ojM6m
0_l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgX
ojVmj004ojVmj0?o0000=_ooool002cooooo00?o0000ooooooooool04?ooool00ol0003oZKgXojVm
j004ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0
0006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXo`00
0002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o
0000ojVmj?nY_NP00_nY_NP01?l0003o001Jo`000?l00006oj6ReP03o`000?o]]iOokKNG00GokKNG
0_l0000:onnhU@;o00002?o`^9@2o`0000SolKNA0_l00009oo6fSP03o`000?oSYY?ohjJC00?ohjJC
00?o0000oo6kUooa^iL00ooa^iL01Ol0003o`hREol>8UOo3R9Go000000GolkV?00?o0000okZ1Uonj
PIL00ol00003onBWTP05o`000?od^i3om;^@ooBkT?l000001?nmPiH00ol0003ok[6>onjaSP02onja
SP03o`000?od_8oo000000GoaHfI00?o0000on2TTooPY9<00_oPY9<00ol0003omKZ;o`000003omZW
X@03o`000?oAVY_odIZK00?odIZK00?o0000omjSUOoNXiD00_l00005onFgYP03o`000?oY^ZCojKZT
00;ojKZT00Go0000onk0X_l0003oglBmo`000004onG:_003o`000?oYdKgojM6m00?ojM6m00?o0000
ojVmj?l000001OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX0ol00006
ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0000f
ooooo`00;?ooool00ol0003oooooooooo`0Aooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00003ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSoZKgX00;o000000?o001Jo`00
0?nQX]H01_nQX]H00ol0003okKNGonfgU`04onfgU`03o`000?ni[/ko000000[okkRE00?o0000oo2h
U?o`^9@01oo`^9@2o`0000SolKNA0_l00008oo6fSP;o00001OoSYY<00ol0003olK^Goo6kU`03oo6k
U`05o`000?o3R9Go`hREol>8UOl000001Ooc^Hl3o`0000Koi:NB00Go0000ooBkT?od^i3om;^@o`00
0004okf3UP03o`000?o^/Hkok[6>00;ok[6>00?o0000ooBlSol000001?o5SIT00ol0003oh:BCon2T
T`03on2TT`03o`000?oe^X_o000000?ofZNQ00?o0000om6JVooAVY/00ooAVY/01Ol0003ogZ>EomjS
UOoNXiGo000000GoiKNV00Go0000onVjY?oY^ZCojKZTo`000003onk0XP03o`000?oUb[coiLZl00?o
iLZl00?o0000onWA_OoYdKd00_oYdKd01Ol0003ojmW2o`000?nY_NSo000000?oZKgX1?l00005ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`00
0003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o0000=Oooool002co
oooo00?o0000ooooooooool04_ooool00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003o
ZKgXojVmj003ojVmj0?o00001onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`000005ojVmj?l0003o001Jo`00
F_l000001onQX]H00ol0003okKNGonfgU`02onfgU`05o`000?ni[/ko^Jk>okV^c_l000002?o_^9D2
o`0000Wol;RD00?o0000oo6gTOoa]i401ooa]i42o`0000SolKJ>00?o0000on:l/_l000001?oSYY<0
0ol0003olK^Goo6kU`03oo6kU`04o`000?o3R9Go`hREo`0000?olkV?1?l000000onjPIOo0000onBW
TP05onBWTP05o`000?od^i3om;^@ooBkT?l000000onmPiH00ol0003ok[6>onjaSP03onjaSP03o`00
0?od_8oo000000CoaHfI00?o0000on2TTooPY9<00ooPY9<01_l0003omKZ;ooFjRol0003ofZNQo`00
00GodIZK00?o0000omjSUOoNXiD00_oNXiD00ol0003oiKNVonFgYP02onFgYP03o`000?oY^ZCojKZT
00;ojKZT00Go0000onk0X_o^`:;ok/2Ro`000004onG:_003o`000?oYdKgojM6m00;ojM6m00Go0000
on_I`_o[fL;o0000ojVmj004o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ooooooooool0<oooool002cooooo00?o0000ooooooooool04oooool00ol0003oZKgXo`000002
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
000000;o001J00?o0000oj6Re_nQX]H01_nQX]H01?l0003okKNGonfgUol00004okV^cP03o`000?o_
^9GokkRE00GokkRE00?o0000okf`cOl000002?o`^9@2o`0000WolKNA00?o0000oo6fS_oa]Xh01_oa
]Xh01?l0003oh[bbon:l/_l00004on>VT`03o`000?oa^iOolK^G00?olK^G00?o0000ol>8UOo3R9D0
1?l00004oo>iS`;o00001OoTYi800ol0003om;^@ooBkT002ooBkT005o`000?nmPiKo_H>Fokf3U_l0
00001Oo^/Hh00ol0003om;b?o`000004olF=V@03o`000?oPY9?oh:BC00?oh:BC00Ko0000ooFjRooe
^X_o0000omZWXOl00005om6JV`03o`000?oNXiGogZ>E00;ogZ>E0_l00003onFgYP03o`000?oY^ZCo
jKZT00;ojKZT00Co0000onk0X_o^`:;ok/2R0_l00002onG:_003o`000?oYdKgojM6m00?ojM6m00Co
0000on_I`_o[fL;ojmW20ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l0000dooooo`00;?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo000000;o00000_nY
_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVm
j003ojVmj0?o00001_nY_NP2o`0000?o001J00?o0000oj6Re_nQX]H01OnQX]H00ol0003okKNGo`00
0006okV^cP03o`000?o_^9GokkRE00;okkRE0_l00003okf`c@03o`000?o`^9Col;RD00Col;RD00?o
0000ol2ccOl000002Ooa]i400ol0003olKJ>oo6fSP05oo6fSP05o`000?oR_;;oh[bbon:l/_l00000
0ooSYY<00ol0003olK^Goo6kU`04oo6kU`04o`000?o3R9Go0000o`0000OolkV?0_l00005onBWTP03
o`000?od^i3om;^@00;om;^@00Go0000okf3U_nmPiKo_H>Fo`000004onjaSP05o`000?od_8oom;b?
ooBlSol000000oo5SIT00ol0003oh:BCon2TT`03on2TT`06o`000?oe^X_omKZ;o`000?oJYj7o0000
1OoAVY/00ol0003ogZ>EomjSU@02omjSU@;o00000ooU]jH01Ol0003ojKZTonVjY?oY^ZCo000000?o
k/2R00Ko0000oo?5X?ocaJ3o0000onG:_?l00004onWA_@03o`000?o[fL;ojmW200;ojmW20_l00000
0onY_NSo0000ojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP0
0ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
000003?ooooo000[ooooo`03o`000?oooooooooo01Kooooo00?o0000ojVmj?nY_NP01?nY_NP00ol0
003oZKgXojVmj003o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVm
j?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000o`00F_l005X00_l005X00ol0
003oXJ;Foj6ReP03oj6ReP?o00002?ni[/h01?l0003okkREonnhUOl00005okf`c@03o`000?o`^9Co
l;RD00;ol;RD0_l00003ol2cc@03o`000?oa]i7olKNA00GolKNA0_l00007oo6fSP05o`000?oR_;;o
h[bbon:l/_l000000ooSYY<00ol0003olK^Goo6kU`03oo6kU`?o000000?o`hREo`000?oc^Hl01_oc
^Hl2o`0000Goi:NB00?o0000ooBkT?od^i000_od^i001Ol0003o_H>Fokf3U_nmPiKo000000Cok[6>
00Go0000ooBlSood_8oom;b?o`000003olF=V@03o`000?oPY9?oh:BC00;oh:BC00?o0000ooFjRooe
^X/00_oe^X/00ol0003odIZKom6JV`04om6JV`05o`000?oNXiGogZ>EomjSUOl000000_oa]H`00ol0
003oiKNVo`000004onVjY005o`000?o^`:;ok/2Ronk0X_l000000oocaJ000ol0003ojM6monWA_@02
onWA_@03o`000?o[fL;ojmW200;ojmW200Go0000onSQbooXhL_o0000ojVmj004o`000003ojVmj?l0
003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP4o`0000GoZKgX00?o0000ooooooooool0<Ooo
ool002_ooooo0_l0000Hooooo`03o`000?nY_NSoZKgX00?oZKgX0ol00007ojVmj003o`000?nY_NSo
000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004
ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0Co000000Co001Jo`000?nQX]KoXJ;F0ol0
0002oj>Ue`03o`000?ni[/ko^Jk>00Ko^Jk>00?o0000onnhUOl000001onm/<d01?l0003ol;RDoo2h
U?l00005ol2cc@03o`000?oa]i7olKNA00ColKNA00Co0000olBec?o4]Lco00001Ooa]Xh00ol0003o
h[bbon:l/P03on:l/P04o`000?oSYY?ohjJCo`0000;olK^G0ol000001Ooa^iOo0000ol>8UOo3R9Go
000000OolkV?00?o0000onBWT_oTYi801?oTYi800ol0003om;^@ooBkT002ooBkT005o`000?nmPiKo
_H>Fokf3U_l000001?o^/Hh01Ol0003om;b?ooBlSood_8oo000000?oaHfI00?o0000on2TTooPY9<0
0_oPY9<00ol0003omKZ;ooFjR`02ooFjR`03o`000?oAVY_odIZK00CodIZK00Go0000omjSUOoNXiGo
gZ>Eo`000002oo6eS003o`000?oU]jKo000000CojKZT00Go0000onk0X_o^`:;ok/2Ro`000003oo?5
X0;o00000ooYdKd01Ol0003ojmW2on_I`_o[fL;o000000Coj>7;0_l00005ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj0?o0000<Oooool002_ooooo00?o0000oooo
ooooool06?ooool00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`00
00KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`00
00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX
00Co00000omaRM`4o`0000KoXjGG00?o0000okV^c_ni[/h01Oni[/h2o`0000So_K3=00?o0000oo2h
U?l000001oo0/ld00ol0003olKNAoo6gT@02oo6gT@05o`000?o4]Lcoa;G<olBec?l000001Ooa]Xh0
0ol0003oh[bbon:l/P03on:l/P03o`000?oSYY?o000000?o00001?oa^iL00ol0003o`hREo`000008
oo>iS`03o`000?oTYi;oi:NB00Coi:NB00?o0000ooBkT?od^i000ood^i001?l0003o_H>Fokf3U_l0
0004onjaSP05o`000?od_8oom;b?ooBlSol000000oo5SIT00ol0003oh:BCon2TT`02on2TT`03o`00
0?oe^X_omKZ;00;omKZ;00?o0000om6JVooAVY/00ooAVY/00ol0003ogZ>EomjSU@02omjSU@06o`00
0?oa]HcolKF<o`000?oU]jKo00000ooY^Z@01Ol0003ok/2Ronk0X_o^`:;o000000CollFP00Go0000
ooO<Wol0003ojM6mo`000003on_I`P03o`000?oXhL_oj>7;00;oj>7;0_l000000onY_NSo0000ojVm
j004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVm
j003o`000003ojVmj?l0003oZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0
0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Booooo`00:oooool00ol0003oooooooooo`0Iooooo`;o00001_nY_NP00ol0003oZKgX
ojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX
00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000CoZKgX00?o0000og69g?maRM`0
0_maRM`00ol0003oXjGGoj>Ue`05oj>Ue`03o`000?ni[/ko^Jk>00?o^Jk>0_l000000oni[<co0000
okf`c@07okf`c@;o00002Oo0/ld01?l0003olKNAoo6gTOl00005olBec005o`000?oa]XkolKJ>oo6f
S_l000001_oR_;83o`0000OolK^G00?o0000ol>8UOl000002?oc^Hl00ol0003oi:NBonBWTP03onBW
TP03o`000?od^i3om;^@00Com;^@00?o0000okf3U_l000001Oo^/Hh01Ol0003om;b?ooBlSood_8oo
000000;oaHfI00?o0000on2TTooPY9<00ooPY9<00ol0003omKZ;ooFjR`02ooFjR`03o`000?oAVY_o
dIZK00?odIZK00?o0000omjSUOoNXiD00_oNXiD01Ol0003olKF<oo6eS?oa]Hco000000CojKZT00Go
0000onk0X_o^`:;ok/2Ro`000003oo?5X004o`000?ogc9oomlbOooO<W`;o00000oo[fL801Ol0003o
j>7;onSQbooXhL_o000000;ogncJ00?o0000ojVmj?l000001?nY_NP3o`0000GoZKgX00?o0000ojVm
j?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l000002Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo017ooooo000[ooooo`03o`000?oooooooooo
01_ooooo00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVm
j003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00;oZKgX00?o0000og69g?maRM`00omaRM`00ol0003oXjGGoj>Ue`05oj>Ue`05o`000?ni[/ko^Jk>
okV^c_l000001?ni[<`00ol0003o_K3=okf`c@04okf`c@03o`000?nl[lco000000Wo`;?=00?o0000
oo6gTOl000001oo4]L`00ol0003olKJ>o`000004on:l/PCo000000?ohjJCo`000?oa^iL01ooa^iL2
o`0000OolkV?0_l00005onBWTP03o`000?od^i3om;^@00Com;^@00?o0000okf3U_l000001?o^/Hh0
0ol0003om;b?ooBlS`03ooBlS`03o`000?o5SIWo000000Goh:BC00Co0000ooFjRooe^X_omKZ;0_l0
0005om6JV`03o`000?oNXiGogZ>E00;ogZ>E00Go0000oo6eS?oa]HcolKF<o`000004onVjY005o`00
0?o^`:;ok/2Ronk0X_l000000oocaJ002Ol0003omlbOooO<Woogc9oo0000oo[BWOl0003ojmW2o`00
0003onSQb`03o`000?oOk=[ogncJ00;ogncJ0_l000001_nY_NSo0000o`000?l0003oZKgXo`0000Oo
ZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0?o00001OnY_NP00ol0003o
ZKgXojVmj004ojVmj0?o00001OnY_NP2o`0000Sooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo013ooooo000[ooooo`03o`000?oooooooooo01cooooo00?o0000ojVmj?l0
00000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00002ojVmj003
o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00Co
ZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00;o
ZKgX00?o0000og69g?maRM`00omaRM`00ol0003oXjGGoj>Ue`04oj>Ue`04o`000?ni[/ko0000o`00
00Ko^Jc<00?o0000okf`cOnm/<d00_nm/<d01Ol0003o_:o<okb_c?nl[lco000000So`;?=0_l00008
olBec004o`000?oa]Xko0000on:l/P?o00000ooR_;800ol0003ohjJCo`000008oo6kU`;o00001ooc
^Hl00ol0003oi;nbo`000004onBWTP03o`000?od^i3om;^@00Com;^@00?o0000okf3U_l000001?o^
/Hh00ol0003om;b?ooBlS`03ooBlS`03o`000?o5SIWo000000Goh:BC00Oo0000ooFjRooe^X_omKZ;
o`000?of_Xoo000000CodIZK00?o0000omjSUOoNXiD00_oNXiD01?l0003olKF<oo6eS?oa]H`2o`00
00;ojKZT00Go0000onk0X_o^`:;ok/2Ro`000004oo?5X005o`000?ogc9oomlbOooO<Wol000000_oj
dYd01Ol0003oj>7;onSQbooXhL_o000000GogncJ0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX
0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgX
ojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX0_l00007ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Aooooo`00:oooool00ol0003oooooooooo`0Mooooo`03o`00
0?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l00000
0ol00004og69g003o`000?nSYMOoXjGG00CoXjGG0_l00008okV/c005o`000?nm/<go_K3=okf`cOl0
00001?nl[l`00ol0003o`;?=ol2cc@05ol2cc@03o`000?nm/Lko000000Soa;G<1?l00007on:l/P03
o`000?oa^iOolK^G00OolK^G0_l00006oo>iS`04o`000?oT_k;oi;nbo`0000Coi:NB00?o0000ooBk
T?od^i001?od^i000ol0003o_H>Fo`000004onjaSP03o`000?od_8oom;b?00?om;b?00?o0000olF=
VOl000001?oPY9<00ol0003omKZ;ooFjR`02ooFjR`03o`000?of_Xoo000000?odIZK00?o0000omjS
UOoNXiD00ooNXiD01?l0003olKF<oo6eS?oa]H`2o`0000;ojKZT00Go0000onk0X_o^`:;ok/2Ro`00
0003oo?5X005o`000?ogc9oomlbOooO<Wol000000oojdYd2o`000003onSQbol0003ogncJ00CogncJ
00Go0000olKUkOl0003oZKgXo`000005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY
_NP01OnY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY
_NP01?nY_NP2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04_ooool002[ooooo00?o0000ooooooooool07oooool00ol0003oZKgXojVmj004ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXo`000002o`00
00?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000;oZKgX0_l00005og69g003o`000?nSYMOoXjGG
00?o000000?oXZ?Fo`000?ni[<`02?ni[<`00ol0003o_K3=o`000006okb_c003o`000?o0/lgo`;?=
00;o`;?=0_l00003okfacP03o`000?o4]Lcoa;G<00Coa;G<0ol00008on:l/P;o00002Ooa^iL00ol0
003olkV?oo>iS`05oo>iS`04o`000?oT_k;oi;nbo`0000Coi:NB00?o0000ooBkT?od^i001?od^i00
0ol0003o_H>Fo`000004onjaSP03o`000?od_8oom;b?00?om;b?00?o0000olF=VOl000001?oPY9<0
0ol0003omKZ;ooFjR`02ooFjR`03o`000?of_Xoo000000?odIZK00?o0000omjSUOoNXiD00_oNXiD0
1Ol0003olKF<oo6eS?oa]Hco000000;on;b800?o0000onVjY?l000000oo^`:801Ol0003ollFPoo?5
X?ocaJ3o000000?omlbO00Ko0000oo[BWOojdYgon]:Mo`000?oleih2o`0000?ogncJ0_l00003olKU
k@03o`000?nY_NSo000000CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000o`000006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Dooooo`00:_ooool00ol0003oooooooooo`0Pooooo`03o`000?nY_NSoZKgX
00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP01?l0003oZKgXo`000?l004T8
o`0000GoXZ?F00?o0000okV/c?ni[<`01_ni[<`2o`0000So_:o<00Co0000ol2ccOo0/lgo00001Onm
/Lh01?l0003oa;G<olBec?o4]L`3o`0000?o_[??00?o0000on:l/_oR_;801?oR_;800ol0003o_[GA
o`000008oo6kU`;o00001_oc^Hl00ol0003oi;nbonBo/P02onBo/P04o`000?oTYi;oi:NBo`0000Oo
m;^@00?o0000okf3U_l000001?o^/Hh00ol0003om;b?ooBlS`03ooBlS`03o`000?o5SIWo000000Co
h:BC00?o0000ooFjRooe^X/00_oe^X/00ol0003om[j?o`000003om6JV`03o`000?oNXiGogZ>E00;o
gZ>E00Go0000oo6eS?oa]HcolKF<o`000002ooRlR0;o00001?o^`:801Ol0003ollFPoo?5X?ocaJ3o
000000?omlbO00Co0000oo[BWOojdYgo00000_oleih01Ol0003oo=bOo`000?oOk=[o000000Koa^G]
0_l000001_nY_NSo0000o`000?l0003oZKgXo`0000KoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX
00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00005ojVmj0;o00001Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05?ooool002[ooooo0ol0000Qoooo
o`03o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX
00?o00000onY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP2o`000003o`00BOl0003oMI7P
00CoMI7P00?o0000oj:Se_nRXmH01?nRXmH00ol0003o^Jc<okV/c005okV/c003o`000?nl[<[o0000
00So_:o<00?o0000ol2ccOl000001onm/Lh4o`0000Ko_[??00?o0000on:l/_oR_;800_oR_;801Ol0
003o_[GAokjedOnn]M7o000000KolK^G00?o0000ol>hd?l000001_oc^Hl00ol0003oi;nbonBo/P02
onBo/P04o`000?oTYi;oi:NBo`0000Som;^@00?o0000onjaS_o^/Hh00_o^/Hh00ol0003om;b?ooBl
S`05ooBlS`03o`000?oPY9?oh:BC00?oh:BC00Go0000ooFjRooe^X_omKZ;o`000002ooJnS`05o`00
0?oAVY_odIZKom6JVol000001?oNXiD01Ol0003olKF<oo6eS?oa]Hco000000?on;b800Go0000onk0
X_o^`:;ok/2Ro`000003oo?5X005o`000?ogc9oomlbOooO<Wol000000oojdYd00ol0003oo=NNo`00
0003oocLW`;o00001_o6iNd3o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVm
j003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000Gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004oooool002[ooooo00?o0000ooooooooool08_ooool2o`0000GoZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY
_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY
_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003ojVmj0?o000000?o0019o`000?meTN001?me
TN000ol0003oXZ?Foj:SeP04oj:SeP03o`000?ni[<co^Jc<00;o^Jc<0_l00003okb/bP03o`000?nl
[lco_:o<00Go_:o<0_l00005okfacPCo000000?oa;G<o`000?nn/ll01_nn/ll01Ol0003oh[bbon:l
/_oR_;;o000000Go_[GA00?o0000oo6kUooa^iL00_oa^iL01Ol0003o`kS@ol>hd?o3^=3o000000Co
lkV?00?o0000onBo/_oT_k800ooT_k801?l0003oi:NBonBWT_l00008ooBkT003o`000?o^/Hkok[6>
00;ok[6>00?o0000ooBlSood_8l01Ood_8l00ol0003oh:BCon2TT`03on2TT`05o`000?oe^X_omKZ;
ooFjRol000000oof_Xl01?l0003odIZKom6JVol00004omjSU@05o`000?oa]HcolKF<oo6eS?l00000
0ooh_8P01Ol0003ok/2Ronk0X_o^`:;o000000?ollFP00Go0000ooO<Woogc9oomlbOo`000003oo[B
W@03o`000?oleiko000000?oo=bO00?o0000oocRWol000000_o6iNd3o`000004ojZnj?l0003oZKgX
o`0000CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSo
ZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l00000;?ooool0
00kooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo00?o0000ooooooooool09?ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSo000000;o00000onY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVm
j003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP00ol0003oZKgXo`00
0002o`000006ojVmj?l0003o5TS4o`000?l004Wo00001?meTN000ol0003oXZ?Foj:SeP05oj:SeP04
o`000?ni[<co^Jc<o`0000Go_:c:00?o0000okb_c?nl[l`01?nl[l`00ol0003o_Zk:o`000002okfa
cP?o00000onm/Lh2o`0000Wo_[??00?o0000on:l/_l000001_nn]M401Ol0003olK^Goo6kUooa^iOo
000000Go`kS@00Go0000oo>iSooc^HoolkV?o`000006onBo/P03o`000?oTYi;o000000Som;^@00?o
0000onjaS_o^/Hh00_o^/Hh00ol0003om;b?ooBlS`05ooBlS`03o`000?oPY9?oh:BC00?oh:BC00Go
0000ooFjRooe^X_omKZ;o`000003ooJnS`03o`000?oAVY_o000000GogZ>E00Go0000oo6eS?oa]Hco
lKF<o`000003ooRlR0;o00000_o^`:801Ol0003ollFPoo?5X?ocaJ3o000000?omlbO00Co0000oo[B
WOojdYgo00000_oleih01?l0003oo=bOoocLWol00003oocRW`;o00001OnZ_^P00ol0003oZKgXo`00
0003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY
_NP00ol0003oooooooooo`0Zooooo`003_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003o
ooooooooo`0Uooooo`04o`000?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXojVmj003o`00
0003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX
00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00005ojVm
j004o`000?lFB<Co0000o`0000GoMI7P00?o0000oj:Se_nRXmH01?nRXmH00ol0003o^Jc<o`000007
okb/bP03o`000?nl[lco_:o<00;o_:o<00?o0000okj^b_nn[/X00ol00005okfacP03o`000?no/<co
000000Wo_[??0_l00008okjed@03o`000?oa^iOo000000Ko`kS@00Co0000oo>iSooc^Hoo00001ooT
_k800ol0003oi:NBo`000008ooBkT003o`000?o^/Hkok[6>00;ok[6>00?o0000ooBlSood_8l01Ood
_8l00ol0003oh:BCon2TT`02on2TT`03o`000?oe^X_omKZ;00;omKZ;00Oo0000ooJnSoof_Xoom[j?
o`000?oAVY_o000000GogZ>E00Go0000oo6eS?oa]HcolKF<o`000003ooRlR004o`000?oh_HWo0000
o`0000CollFP00Co0000ooO<Woogc9oo00000oojdYd00ol0003oo=NNo`000003oocLW`05o`000?ol
hYooo>:OoocRWol000001_nZ_^P3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000
ojVmj005ojVmj0;o0000:oooool000oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02Oo
oooo0ol00004ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00Co
ZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?nY_NP01?nY_NP01Ol0003o5TS4oaI8a?lFB<Co000000GoMI7P00?o0000oj:S
e_nRXmH00onRXmH2o`0000Wo_:c:00?o0000okb_c?nl[l`01?l00002okj^bP03o`000?nm/Lko_K7>
00;o_K7>00Go0000okn`c?no/<co_k3<o`000007okjcc`03o`000?no/lko000000So_[GA0_l00008
ol>hd003o`000?oc^Hoo000000Ooi;nb0_l00008ooBkT0;o00001?o^/Hh00ol0003om;b?ooBlS`04
ooBlS`;o00001?oPY9<00ol0003omKZ;ooFjR`02ooFjR`07o`000?of_Xoom[j?ooJnSol0003odIZK
o`000005omjSU@05o`000?oa]HcolKF<oo6eS?l000000_oh_8P01Ol0003on;f9ooRmROoh_HWo0000
00?ollFP00Go0000ooO<Woogc9oomlbOo`000003oo[BW@03o`000?oleiko000000?oo=bO00Ko0000
oocRWoolhYoo0000oo[YYol00002ojZnj0?o000000CoZKgXo`000?nY_NSo00001OnY_NP00ol0003o
ZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0000Zooooo`00
4?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0:?ooool00ol0003oZKgXojVmj004ojVm
j003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX
00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000onY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj004o`000?lFB<Co5TS4
oaI8a0Co000000CoMI7Po`000?nRXmKoXZ?F0ol000000onRX]Co0000okb/bP08okb/bPCo00001Onn
[/X01Ol0003o_K7>okfac_nm/Lko000000Go_k3<00?o0000okjcconn/ll00_nn/ll2o`0000?o_k?>
00?o0000okjedOnn]M401?nn]M400ol0003o_kG@o`000008ol>hd0;o00002OoT_k800ol0003om;^@
ooBkT005ooBkT004o`000?oJ`L7of/71o`0000;ok[6>00?o0000ooBlSood_8l01Ood_8l00ol0003o
jl>[o`000003on2TT`05o`000?oe^X_omKZ;ooFjRol000001?of_Xl00ol0003odIZKo`000004omjS
U@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P01Ol0003on;f9ooRmROoh_HWo000000?ollFP00Go
0000ooO<Woogc9oomlbOo`000002oo[BW@04o`000?oleikoo=NNo`0000;oo=bO00Go0000oocRWool
hYooo>:Oo`000002oo[YY`;o00001OnY_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX
00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000Zooooo`004Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0:Oooool00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000OoZKgX00?o
0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP01?l0
0002oaI8a004o`000?m]R]koKH[Noff:gPCo00001OnRX]@00ol0003o_:c:okb/bP05okb/bP?o0000
2?nn[/X00ol0003o_K7>o`000006okn`c005o`000?nn/loo_[??okjccol000001Ono/lh00ol0003o
_[GAokjed@02okjed@;o00000ono]M000ol0003o`kS@ol>hd004ol>hd003o`000?no^=;o000000So
i;nb0_l00006ooBkT005o`000?oJ`L7of/71om[1`Ol000000_o^/Hh00ol0003om;b?ooBlS`04ooBl
S`04o`000?o[`j_ojl>[o`0000?oh:BC00Go0000ooFjRooe^X_omKZ;o`000005ooJnS`;o00001?oN
XiD01Ol0003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWon;f90_l00002oo?5X005
o`000?ogc9oomlbOooO<Wol000000_ojdYd00ol0003oo=NNo`000003oocLW`04o`000?olhYooo>:O
o`0000?on^VW00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000003o`000003ojVmj?l0003o
ZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj0?o0000:?ooool001;ooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY
_NSoZKgX00CoZKgX00?o0000ojVmj?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l0
0004ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0
0003ojVmj005o`000?lFB<Co5TS4oaI8a?l000001?m]R]h00ol0003oXZ;Doj:Re004oj:Re003o`00
0?nl[<[o_:c:00;o_:c:1?l000000onlZlOo0000okj^bP07okj^bP;o00002?no/<`00ol0003o_[??
o`000007oknccP04o`000?nn]M7o_[GAo`0000Go_kG@00?o0000ol>hd?o3^=000_o3^=02o`0000?o
_kSB00?o0000onBo/_oT_k800ooT_k82o`000003ol6jdol0003om;^@00Com;^@00?o0000om[1`OoJ
`L400_oJ`L401?l0003ok[6>onjaS_l00006ooBlS`04o`000?o[`j_ojl>[o`0000?oh:BC00Go0000
ooFjRooe^X_omKZ;o`000005ooJnS`03o`000?oNXiGogZ>E00?ogZ>E00Go0000oo6eS?oa]HcolKF<
o`000003ooRlR006o`000?oh_HWon;f9ooRmROl0003on;j90_l00003ooO<W`07o`000?ojdYgon]:M
oo[BWOl0003oo=NNo`000003oocLW`04o`000?olhYooo>:Oo`0000;on^VW00?o0000ongi^_l00000
1_nY_NP3o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00006ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00Ko
ZKgX0_l0000Xooooo`003_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0002cooooo00?o0000
ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXo`000002
o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
ZKgX00KoZKgX00?o0000ojVmj?l000000_l00003ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?o
5TS4o`000?m]R]h01?m]R]h00ol0003oXZ;Doj:Re004oj:Re0Co000000?o_:c:o`000?l000000onl
ZlL00ol0003o_Zk:okj^bP04okj^bP03o`000?o1[/So000000So_k3<0_l00008oknccP03o`000?nn
]M7o000000Oo_kG@00Co0000ol>hd?o3^=3o00001_no^=801Ol0003oi;nbonBo/_oT_k;o000000Co
`K[C00?o0000ooBkT?od^i000_od^i000ol0003of/71om[1`@03om[1`@03o`000?o^/Hko000000Go
m;b?00Go0000on_3Zoo[`j_ojl>[o`000002on2TT`03o`000?oe^X_omKZ;00;omKZ;00?o0000ooJn
Soof_Xl00oof_Xl00ol0003ogZ>EomjSU@03omjSU@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P0
1?l0003on;f9ooRmROl00003ooRnR@05o`000?ogc9oomlbOooO<Wol000000_ojdYd01?l0003oo=NN
oocGW_l00002oocLW`04o`000?olhYooo>:Oo`0000?on^VW00Co0000ongi^_o]nK[o00000_nY_NP3
o`000004ojVmj?l0003oZKgXo`0000CoZKgX1?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0
0005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l0
000Xooooo`003_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0[ooooo`03
o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00Co
ZKgX0_l00007ojVmj008o`000?nY_NSo0000o`000?lNHMKo0000oaI8a?l00004off:gP03o`000?nR
X]CoXZ;D00;oXZ;D1?l00002okb/bP03o`000?nlZlOo_:_700?o_:_700?o0000okj^b_nn[/X00_nn
[/X2o`0000?o`Jk800?o0000okn`c?no/<`01?no/<`00ol0003o`K7:o`000008oknccP;o00002?no
]M000ol0003o`kS@o`000007oknhdP04o`000?oT_k;o0000o`0000Ko`K[C00Co0000ooBkT?od^i3o
00001_oJ`L400ol0003ok[6>o`000005ooBlS`05o`000?o[`j_ojl>[on_3Zol000000_oPY9<00ol0
003omKZ;ooFjR`02ooFjR`03o`000?of_Xoom[j?00?om[j?00?o0000omjSUOoNXiD00ooNXiD01Ol0
003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWo00000ooh_XT2o`0000;omlbO00Ko
0000oo[BWOojdYgo0000oocGW_l00003oocLW`04o`000?olhYooo>:Oo`0000;on^VW00Co0000ongi
^_o]nK[okOVj0ol00005ojVmj003o`000?nY_NSo000000?o000000?oZKgXo`000?nY_NP01_nY_NP0
0ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000W
ooooo`00:?ooool00ol0003oooooooooo`0]ooooo`03o`000?nY_NSoZKgX00CoZKgX0_l00007ojVm
j003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0
003oZKgXojVmj004ojVmj0;o00000_nY_NP00ol0003o7V7Fo`000002o`0000CoKH[N1?l00003oj:R
e003o`000?nl[<[o000000Oo_:_700Co0000okj^b_nn[/[o00001_o1[/P00ol0003o_k3<okn`c002
okn`c005o`000?o1/L[o`K7:ol6ab_l000001_no/lh00ol0003o`K?<o`000008okned0;o00002?no
^=82o`0000So`K[C00?o0000ooBkT?l000001ooJ`L42o`0000Gom;b?00?o0000on_3Zoo[`j/00oo[
`j/00ol0003oh:BCo`000003ooFjR`03o`000?of_Xoom[j?00Com[j?00?o0000omjSUOoNXiD00ooN
XiD01Ol0003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWo00000ooh_XT01?l0003o
nKn9o`000?l00003oo[BW@03o`000?oleiko000000?oo=bO00?o0000oocRWol000000_ojjJL01ol0
003okOVjongi^_o]nK[o0000olodj?l000001_nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX
1Ol00005ojVmj0;o00009_ooool002Sooooo00?o0000ooooooooool0;_ooool00ol0003oZKgXojVm
j003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000ojVmj002ojVmj004o`000?lNHMKo7V7Fo`0000;oKH[N1?l00005oj:Re0;o0000
2?nlZlL00ol0003o_Zk:o`000007ol6^b005o`000?no/<co_k3<okn`c?l000001Oo1/LX00ol0003o
_k?>oknccP02oknccP05o`000?o1/lco`K?<ol6cc?l000001_no]M000ol0003o`KK?o`000007oknh
dP03o`000?o1^=7o000000So`K[C0_l00009om[1`@03o`000?od_8oom;b?00?om;b?00?o0000on_3
Zoo[`j/00oo[`j/00ol0003oh:BCo`000003ooFjR`03o`000?of_Xoom[j?00?om[j?00?o0000oo73
XOl000001?oNXiD01Ol0003olKF<oo6eS?oa]Hco000000;on;b800Go0000ooRmROoh_HWon;f9o`00
0003ooRnR@03o`000?oi_hWonKn900Co00000_oleih01?l0003oo=bOoocLWol00002oocRW`05o`00
0?ojjJOon^VWo`000?o]nKX00_l00003olodj003o`000?nY_NSoZKgX00?o000000CoZKgXo`000?nY
_NSo00001OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00003ojVmj003o`000?nY_NSoZKgX
00CoZKgX0_l0000Vooooo`00:?ooool00ol0003oooooooooo`0_ooooo`;o00001_nY_NP00ol0003o
ZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00003ojVmj003
o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00005ojVmj004o`000?nY_NSoZKgXo`0000;o7V7F1Ol000001?m]R]ko0000oj:Re?nRX]@3
o`000003oj6Od_l0003o_:_700So_:_700?o0000ol6^b?o1[/P01oo1[/P00ol0003o_k3<o`000006
ol6abP05o`000?no/lko_k?>okncc_l000001Oo1/l`00ol0003o_kG@okned002okned005o`000?o1
]/oo`KK?ol6fcol000001Ono^=801Ol0003o`KSAol6hdOo1^=7o000000Ko`K[C00?o0000ol6ke?l0
00002?oJ`L42o`0000Gom;b?00?o0000on_3Zoo[`j/00oo[`j/00ol0003oh:BCo`000003ooFjR`03
o`000?of_Xoom[j?00?om[j?00?o0000oo73XOl000000ooNXiD01Ol0003olKF<oo6eS?oa]Hco0000
00?on;b800Go0000ooRmROoh_HWon;f9o`000002ooRnR@05o`000?oi_hWonKn9ooVoROl000000_oi
_hP3o`0000?oo=bO00?o0000oocRWol000000_ojjJL00ol0003okOVjo`000005olodj0?o00001OnY
_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000o`00000Uooooo`00:?ooool00ol0003oooooooooo`0aooooo`03o`000?nY_NSo
ZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj004o`000?nY_NSo
ZKgXojVmj0?o00001onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY
_NP00ol0003oZKgXo`000002o`000003oaiQe_l0003oIHGM00;oIHGM1?l00005oj6OdP03o`000?nl
ZlOo_:_700Go_:_70_l00009ol6^b0;o00002?o1/LX00ol0003o_k?>o`000006ol6cc005o`000?no
]M3o_kG@okned?l000001Oo1]/l01Ol0003o_kSBoknhd_no^=;o000000Go`KSA00?o0000ol6jdoo1
^]<00_o1^]<01Ol0003o`K_Dol6ke?o1^mCo000000Kof/7100?o0000ol:meOl000001?od_8l00ol0
003ojl>[on_3Z`04on_3Z`03o`000?oPY9?o000000?omKZ;00?o0000ooJnSoof_Xl00oof_Xl00ol0
003olL>Qo`000003omjSU@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P01Ol0003on;f9ooRmROoh
_HWo000000;on;j900Go0000ooVoROoi_hWonKn9o`000002ooVoR003o`000?onaWko000000;o0000
00Coo=bOo`000?olhYoo00000_ojjJL4o`000006olodj?l0003o0000o`000?nZ_^So00001onY_NP0
0ol0003oZKgXo`000003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005
ojVmj0;o00009?ooool002Sooooo00?o0000ooooooooool0<_ooool00ol0003oZKgXo`000002o`00
00;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVm
j?nY_NP00onY_NP3o`000005ojVmj?l0003o0000oaiQe_l000001?mUQMd00ol0003oXIoBoj6OdP04
oj6OdP03o`000?nlZlOo_:_700Co_:_700Co0000okjYaOnnZLGo00001oo1[/P00ol0003o`Zg5o`00
0008ol6abP;o00002?o1/l`00ol0003o_kG@o`000007ol6fc`03o`000?no^=;o000000Ko`KSA00Go
0000ol6jdoo1^]?o`K[Co`000005ol6ke004o`000?oJ`L7of/71om[1`@;o00000oo2_MD01Ol0003o
m;b?ooBlSood_8oo000000Kojl>[0_l00004ooFjR`03o`000?of_Xoom[j?00;om[j?00Go0000oo73
XOoa`j7olL>Qo`000002omjSU@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P01Ol0003on;f9ooRm
ROoh_HWo000000;on;j900Go0000ooVoROoi_hWonKn9o`000002ooVoR003o`000?onaWko000000;o
n<aN1_l000001OoghX7o0000ooGWROoeihWo000000GoZ[kX00?o0000ojVmj?nY_NP01?nY_NP3o`00
00GoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgX
o`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX0_l0000T
ooooo`00:?ooool00ol0003oooooooooo`0cooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVm
j?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXo`000002o`00
00?oZKgX0_l000000ol6DLko0000o`000005ofF5g@03o`000?nQWm;oXIoB00CoXIoB00?o0000okb[
aonlZlL00_nlZlL01Ol0003o_ZW5okjYaOnnZLGo000000Ko`Jk800Go0000ol:]aOo2[LGo`Zg5o`00
0006ol6abP03o`000?o2/<So000000So`K?<0_l00008ol6fc`;o00002?o1^=400ol0003o`K[Co`00
0007ol6ke003o`000?oJ`L7o000000Ko`[gE00?o0000ooBlSol000002?o[`j/01Ol0003omKZ;ooFj
Rooe^X_o000000Gom[j?00Go0000oo73XOoa`j7olL>Qo`000002omjSU@05o`000?oa]HcolKF<oo6e
S?l000000ooh_8P01?l0003on;f9ooRmROl00003ooRnR@04o`000?oi_hWonKn9o`0000?onKn800?o
0000ook6O_l000000_ohc5h00ol0003ohlU;o`000002oo_MOP;o00000ooeihT00ol0003oZ[kXojZn
j004ojZnj003o`000?nY_NSoZKgX00?o000000CoZKgXo`000?nY_NSo00001?nY_NP4o`0000CoZKgX
00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX
00Co0000ojVmj?nY_NSoZKgX1Ol0000Sooooo`009oooool3o`0003Gooooo00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX
00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX
0_l000000ol6DLko0000o`000004ofF5g@03o`000?nQWm;oXIoB00GoXIoB00Co0000okb[aonlZlOo
00001OnnZLD00ol0003o`Jk8ol6^b002ol6^b003o`000?o2[LGo`Zg500;o`Zg500?o0000ol6ab_o1
/LX00_o1/LX2o`0000?o`[3800?o0000ol6cc?o1/l`01?o1/l`00ol0003oa;C;o`000007ol6fc`03
o`000?o4]lko000000So`KSA0_l00008ol6ke0;o00001oo2_MD00ol0003om;b?o`000007on_3Z`;o
00000ooe^X/00ol0003om[j?ooJnS`03ooJnS`05o`000?oa`j7olL>Qoo73XOl000000_oNXiD01Ol0
003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWo00000ooh_XT01?l0003onKn9ooVo
ROl00002ooVoR004o`000?onaWkoo/Ino`0000;on<aN00?o0000on?9Bol000000_okgGh2o`0000;o
mNN900?o0000on_`U?l000001OnZ_^P3o`0000GoZKgX00?o0000ojVmj?l000000ol000000onY_NSo
0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003o
ZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00004ojVmj0;o00008_ooool002Oooooo
00?o0000ooooooooool0=_ooool00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgX
o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX
00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000;o1U7>00?o0000ofF5gOmUQMd00omUQMd00ol0003oXIoBoj6OdP04oj6OdP03o`00
0?nlZlOo000000Oo_ZW500Co0000ol6^b?o1[/So00001_o2[LD01?l0003o`K7:ol6ab_l00005ol:`
b003o`000?o1/lco`K?<00;o`K?<0_l00003olBdb`03o`000?o1]/oo`KK?00;o`KK?0_l00003olBg
cP03o`000?o1^=7o`KSA00Co`KSA00?o0000ol>idOl000001oo1^m@00ol0003o`[_Co`000007ol:m
e@;o00001oo[`j/00ol0003ob<;Do`000003ooFjR`03o`000?of_Xoom[j?00?om[j?00Go0000oo73
XOoa`j7olL>Qo`000002omjSU@05o`000?oa]HcolKF<oo6eS?l000000_oh_8P01Ol0003on;f9ooRm
ROoh_HWo000000?on;j900Co0000ooVoROoi_hWo00000_oi_hP01?l0003oo/Inook6O_l00002ooS<
GP;o00000_okgGh00ol0003omn:1o`000002ooGWR@03o`000?o[l9Co000000;oZ[kX0ol00002ojVm
j003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01_nY_NP00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0gooooo`03
o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003o
ZKgXojVmj003ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000o`000002o`IAcP?o00000omUQMd00ol0003oXIoBoj6OdP03oj6O
dP;o00002?nnZLD00ol0003o`Jk8o`000007ol:]a@03o`000?o1/L[o000000Oo`[3800Co0000ol6c
c?o1/lco00001_o4]</01?l0003o`KK?ol6fcol00005olBgcP03o`000?o1^=7o`KSA00;o`KSA0_l0
0003ol>id@03o`000?o1^mCo`K_D00;o`K_D0_l00003ol:kd`03o`000?o2_MGo`[gE00?o`[gE00Co
0000ol:neoo2_]Oo00001Oo[`j/01Ol0003ob<;DolS2e?o8`]Co000000;omKZ;00?o0000ooJnSoof
_Xl00_of_Xl00ol0003olL>Qoo73X@03oo73X@03o`000?oNXiGo000000?olKF<00Co0000ooRlR?oh
_8So00000ooh_HT01Ol0003on;j9ooRnROoh_XWo000000;onKn900Ko0000ooVoR?oi_hSo0000ook6
O_l00002ooS<GP03o`000?oSbD_o000000;onmen0_l00002ooGWR@04o`000?o[l9Cojo2Don_`U0;o
00001_nY_NP00ol0003oZKgXo`000002o`000004ojVmj?l0003oZKgXo`0000GoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`00027ooooo000Wooooo`03
o`000?oooooooooo03Sooooo00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;o
ZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY
_NP00onY_NP4o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00Co0000o`IAc_l6
DLko00000_mIOM/4o`0000;oXIoB0ol000000onPW=3o0000okjYa@08okjYa@03o`000?o2[LGo`Zg5
00Oo`Zg500?o0000ol:`b?o2/<P01_o2/<P00ol0003o`K?<o`000007olBdb`03o`000?o1]/oo0000
00Ooa;O>00Co0000ol6hdOo1^=7o00001_o3^M401?l0003o`K_Dol6ke?l00006ol:kd`03o`000?o2
_MGo`[gE00;o00001?o2_]L01Ol0003ojl>[on_3Zoo[`j_o000000Cob<;D00Co0000ooFjRooe^X_o
00001?of_Xl00ol0003olL>Qoo73X@03oo73X@;o00000ooa]H`01Ol0003on;b8ooRlR?oh_8So0000
00?on;f900Co0000ooRnROoh_XWo00000ooi_hT01_l0003onKn8ooVoR?l0003oo/Ino`0000;on<aN
00?o0000on?9Bol000000_okgGh2o`0000;omNN900Ko0000on_`U?o[l9Co0000om7ocOl00006ojVm
j0;o00001OnY_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP5
o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo
ZKgX00?o000000?oZKgXo`000?l000008?ooool002Oooooo00?o0000ooooooooool0>Oooool00ol0
003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001onY_NP00ol0
003oZKgXo`000004o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX
00CoZKgX0_l000000ol6DLko0000oeUmf`03oeUmf`?o00001OnPW=000ol0003o_ZW5okjYa@05okjY
a@;o00002Oo2[LD00ol0003o`[38ol:`b007ol:`b003o`000?o4]<_oa;C;00Ooa;C;00?o0000olBg
c_o4]lh01_o4]lh00ol0003o`KSAo`000007ol>id@03o`000?o1^mCo000000Oo`[_C00?o0000ol:m
eOl000001oo2_]L00ol0003ojl>[o`000006olS2e0;o00001Oof_Xl00ol0003olL>Qoo73X@03oo73
X@;o00000ooa]H`01Ol0003on;b8ooRlR?oh_8So000000?on;f900Co0000ooRnROoh_XWo00000ooi
_hT01_l0003onKn8ooVoR?l0003oo/Ino`0000;on<aN00Wo0000on?9Bol0003onmeno`000?oghX7o
0000ooGWROl000000_o[l9@01Ol0003odOo=om7ocOoAolgo000000;oZKgX0ol000000onY_NSo0000
ojVmj005ojVmj003o`000?nY_NSo000000?o000000?oZKgXo`000?nY_NP01OnY_NP4o`0000?oZKgX
00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
0_l0000Oooooo`009oooool00ol0003oooooooooo`0jooooo`03o`000?nY_NSoZKgX00?o00000_nY
_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j004ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVm
j003ojVmj004o`000?l0?l;o0000o`0000GoFGgK00?o0000oj2Ld?nPW=001?nPW=000ol0003o_ZW5
okjYa@04okjYa@04o`000?o2Zl;o`Z_2o`0000Oo`Zg500?o0000olJ_`ol000001oo2/<P2o`0000So
a;C;0_l00008olBgcP;o00002?o3^M42o`0000So`[_C0_l00008ol:ne`;o00001oo8`]@2o`0000Go
m[j?00?o0000oo73XOoa`j401?oa`j401Ol0003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRm
ROoh_HWo00000ooh_XT01Ol0003onKn9ooVoROoi_hWo000000;onKn800?o0000ook6O_l000000_oh
c5h2o`0000;onmen0_l000001OoeihWo0000on_`U?o[l9Co000000CodOo=0ol00005ojVmj003o`00
0?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol000000onY_NSo0000ojVmj005ojVmj0;o00007oooool002Kooooo00?o0000ooooooooool0??oo
ool2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`000?nY_NSoZKgX00?o0000
00?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o03o200;o00001OmIOM/00ol0003oX9c@
oj2Ld004oj2Ld003o`000?nnZLGo_ZW500;o_ZW500Go0000ol:[`_o2Zl;o`Z_2o`000006ol:]a@04
o`000?o6[l?oaZo3o`0000Ko`[3800Co0000olF`a_o5/<Ko00001_o4]</01?l0003oaKC9olFdbOl0
0006olBgcP03o`000?o5]lgo000000Oo`kWA00?o0000olFjd?l000001oo2^m<00ol0003oa;gCo`00
0007ol:ne`03o`000?o3_mKo000000Oob<;D0_l00004ooJnS`03o`000?oa`j7olL>Q00GolL>Q00Go
0000oo6eS?oa]HcolKF<o`000003ooRlR004o`000?oh_HWon;f9o`0000?on;j900Co0000ooVoROoi
_hWo00000ooi_hP00ol0003oo/Ino`000002ooS<GP;o00000_okgGh2o`000004ooGWROl0003ojo2D
o`0000;odOo=0ol000000onZ_^So0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000CoZKgX
o`000?nY_NSo00001?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00
000Nooooo`009_ooool2o`0003oooooo00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000
ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00Co0000
ojVmj?nY_NSoZKgX1?l00004ojVmj0;o000000?o03o2o`000?l000001?mIOM/00ol0003oX9c@oj2L
d005oj2Ld004o`000?nnZLGo_ZW5o`0000Go`Z_200?o0000ol:]aOo2[LD00_o2[LD00ol0003oaZo3
olJ_``02olJ_``03o`000?o2/<So`[3800;o`[3800?o0000olF`a_o5/<H00_o5/<H00ol0003oa;C;
olBdb`02olBdb`03o`000?o5]<WoaKC900;oaKC900?o0000olBgc_o4]lh00_o4]lh01Ol0003oaKO=
olFgcOo5]lgo000000Go`kWA00Go0000olFjd?o5^]3oaK[@o`000005ol:kd`05o`000?o4_M?oa;gC
olBmdol000001?o2_]L2o`0000?o`koF00?o0000olS2e?o8`]@00oo8`]@01?l0003o`l7Iol?1fOl0
0003ooJnS`03o`000?oa`j7olL>Q00GolL>Q00Go0000oo6eS?oa]HcolKF<o`000003ooRlR004o`00
0?oh_HWon;f9o`0000?on;j900Co0000ooVoROoi_hWo00000_oi_hP02ol0003oo/Inook6O_l0003o
n<aNo`000?oSbD_o0000oo_MO_l0003omn:100Oo00001OnZ_^P01?l0003oZKgXojVmj?nY_NP5o`00
00GoZKgX00?o0000ojVmj?l000000ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ooooooooool07?ooool002Kooooo00?o0000oooooooo
ool0?oooool00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003o
ZKgXo`000003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?l000000_l00003ojVmj003
o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj004o`000?nY_NSoZKgXojVmj0;o00000_l0?l800ol0
003oFGgKoeUmf`03oeUmf`03o`000?nPW=3oX9c@00CoX9c@00?o0000okjYaOl000001oo2Zl801?l0
003o`Zg5ol:]aOl00006olJ_``04o`000?o2/<So`[38o`0000GoaK3600Go0000olBdboo4]<_oa;C;
o`000005olFdb@05o`000?o4]lkoa;O>olBgc_l000001Oo5]ld01Ol0003o`kWAol>idOo3^M7o0000
00GoaK[@00Go0000ol:kdoo2^m?o`[_Co`000005olBmd`04o`000?o2_]Oo`[kGo`0000Ko`koF00?o
0000olS2e?o8`]@00_l00004ol?1f@04o`000?of_Xoom[j?o`0000KolL>Q00?o0000omk9`ol00000
0_oa]H`01?l0003on;b8ooRlR?l00003ooRmR@05o`000?oh_XWon;j9ooRnROl000000_oi_hT01?l0
003onKn8ooVoR?l00002ook6OP04o`000?ohc5ko0000o`0000;onmen0_l000001_oeihWo0000omcB
Eol0003ohMe[o`0000KoZ[kX1?l00004ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003
o`000?nY_NSoZKgX00CoZKgX0_l00006ojVmj004o`000?nY_NSoZKgXojVmj0Go00001OnY_NP00ol0
003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX0_l0000Mooooo`009_ooool00ol0003o
ooooooooo`10ooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000Go
ZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003
o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?l000000ol00002o`0o`P?o00000_mIOM/00ol0003o
X9c@oj2Ld003oj2Ld0?o00002?o2Zl800ol0003o`Zg5o`000007olJ_``03o`000?o2/<So000000Oo
aK3600?o0000olBdbol000001oo5]<T00ol0003oa;O>o`000007olFgc@03o`000?o3^M7o000000Oo
aK[@00?o0000ol:kdol000001_o4_M<00ol0003o`[kGo`000007ol>oeP03o`000?o8`]Co000000Oo
`l7I0_l00006oo73X@04o`000?oNbL?og/W3o`0000;olKF<00Co0000ooRlR?oh_8So00000ooh_HT0
1?l0003on;j9ooRnROl00003ooVoR@04o`000?oi_hSonKn8o`0000;oo/In00Co0000ooS<G_l0003o
00000_okgGh3o`000006omcBEol0003ohMe[o`000?oEi7So00000_nZ_^P3o`000003ojVmj?l0003o
ZKgX00KoZKgX00?o0000ojVmj?l000000_l000001?nY_NSo0000ojVmj?l00005ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0001gooooo000Vooooo`03o`000?oooooo
oooo047ooooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000
ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2
o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000;oZKgX00?o0000o`00Kol000000_l00002
odQ`e`?o00000_nPW=03o`0000;oX9c@00?o0000ol:[`_o2Zl801_o2Zl82o`0000WoaZo300?o0000
olF`a_o5/<H01oo5/<H00ol0003oaKC9olFdb@07olFdb@03o`000?o5]lgoaKO=00KoaKO=0_l00008
olFjd0;o00001oo4_M<2o`0000So`koF0_l00008ol?1f@;o00001Ooa`j400ol0003og/W3omk9``02
omk9``;o00000ooh_8P01Ol0003on;f9ooRmROoh_HWo000000;on;j900Go0000ooVoROoi_hWonKn9
o`000002ooVoR005o`000?onaWkoo/Ino`000?ohc5h00_l000000ookgGko0000ooORP@02o`000004
omcBEol0003ohMe[o`0000;oeNAh0_l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00005ojVm
j003o`000?nY_NSo000000CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000o`00000Looooo`009_ooool00ol0003oooooooooo`12ooooo`03
o`000?nY_NSoZKgX00;oZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0?o00001onY_NP00ol0
003oZKgXo`000002o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVm
j003o`000?nY_NSo000000;o000000?o02Nbo`000?l000001?m8L=L2o`0000KoX9c@00?o0000ol:[
`_o2Zl801?o2Zl800ol0003o`ZNoo`000008olJ_``;o00002?o5/<H2o`0000SoaKC90_l00007olFg
c@03o`000?o7^<co000000OoaK[@00?o0000olNld?l000001_o4_M<00ol0003oa[kCo`000007ol>o
eP03o`000?o4`MOo000000Ko`l7I0_l000000oo3`mWo0000oo73X@04oo73X@03o`000?oNbL?og/W3
00;og/W30_l00003ooRlR005o`000?oh_HWon;f9ooRmROl000000_oh_XT01Ol0003onKn9ooVoROoi
_hWo000000;onKn800?o0000ook6O_l000000_ohc5h2o`000003oo_MO_l0003o000000;o000000?o
g=9Go`000?l000000_oEi7P2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j005ojVmj003o`000?nY_NSo000000?o000000?oZKgXo`000?nY_NP01OnY_NP3o`0000GoZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX0_l0
000:ooooo`Co000000?o410@ooooooooool02_ooool002Gooooo00?o0000ooooooooool0A?ooool5
o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?l000000_l00000
0ol09k;o0000o`000003odQ`e`03o`000?nPW=3oX9c@00GoX9c@00?o0000ol:[`_o2Zl800oo2Zl80
1Ol0003o`ZNool:W_oo2Ykoo000000KoaZo300Co0000olJ/`?o6[<3o00001_o5/<H01?l0003obK?5
olVcaOl00006olFdb@04o`000?o8]<Sob;C8o`0000GoaKO=00Go0000olNhc?o7^<coakS<o`000004
olFjd0;o00000oo7_=000ol0003oa;gColBmd`02olBmd`05o`000?o6_]?oa[kColJndol000001Oo3
_mH01Ol0003oa<7GolC1eoo4`MOo000000Co`l7I00?o0000ol?3fOo3`mT00_o3`mT01Ol0003olL>Q
oo73XOoa`j7o000000Gog/W30_l00003ooRlR004o`000?oh_HWon;f9o`0000?on;j900Co0000ooVo
ROoi_hWo00000ooi_hP01?l0003oo/Ino`000?ohc5h2o`0000;onmen0ol000001_oLdUOo0000on7M
Jol0003oeNAho`0000;od_cP00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00Co0000ojVmj?nY
_NSoZKgX1_l00004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0
003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj005ojVmj0;o00003?ooool00ol0003oooooooooo`0<ooooo`009Oooool00ol0003o
ooooooooo`12ooooo`Co00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00Go
ZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY
_NP00ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1_l000000ol09k;o0000odQ`e`03odQ`e`03
o`000?nPW=3oX9c@00GoX9c@00Go0000ol:[`_o2Zl;o`Z_2o`000004ol:W_`03o`000?o6[l?oaZo3
00?oaZo300?o0000olJ/`?o6[<000_o6[<000ol0003oaK36olF`aP02olF`aP03o`000?o9/lGobK?5
00;obK?500?o0000olFdbOo5]<T00_o5]<T01Ol0003ob;C8olRdb?o8]<So000000CoaKO=00?o0000
olNhc?o7^<`00oo7^<`01?l0003oaK[@olFjd?l00006olNld004o`000?o4_M?oa;gCo`0000Goa[kC
00Go0000ol>oe_o3_mKo`koFo`000005olC1e`04o`000?o3`MWo0000o`0000Ko`l?I00?o0000oo73
XOl000001_oNbL<2o`0000?on;b800Co0000ooRmROoh_HWo00000ooh_XT01?l0003onKn9ooVoROl0
0003ooVoR004o`000?onaWko0000ooS<GP;o000000?onmeno`000?l000000_l000001OoLdUOo0000
o`000?oEi7So000000Cod_cP00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0Co
00000onY_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o
00001OnY_NP01?l0003oZKgXojVmj?nY_NP5o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000o`00000;ooooo`03o`000?oooooooooo00cooooo000Uooooo`03o`000?oooooooooo043o
oooo0_l00004ooooo`03o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXo`000002o`00
00;oZKgX00Co0000ojVmj?l0003o00000_l09k801Ol0003oB73GodQ`eom8L=Oo000000OoX9c@00Co
0000ol:[`_o2Zl;o00001_o2Ykl01Ol0003oaZo3olJ_`oo6[l?o000000GoaZc000Go0000olF`a_o5
/<KoaK36o`000005olVca@05o`000?o5]<WoaKC9olFdbOl000001Oo8]<P01?l0003oaKO=olFgcOl0
0006olNhc003o`000?o5^]3o000000Ooakc@00?o0000olBmdol000001oo6_]<00ol0003o`koFo`00
0006olC1e`;o00002?o3`mT2o`0000Kog/W300?o0000olc8eol000000ooh_8P01?l0003on;f9ooRm
ROl00003ooRnR@04o`000?oi_hWonKn9o`0000;onKn800Go0000ook6O_onaWko0000ooS<GP02o`00
0003oo_MO_l0003omlaM00;o000000Cog=9Go`000?l0003o00000ooBo>05o`0000GoZKgX00?o0000
ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSo000000?o000000?oZKgX
o`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00003
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj0;o00002_ooool00ol0003oooooooooo`0<
ooooo`009Oooool3o`0003gooooo0ol00007ooooo`03o`000?nY_NSo000000;o00000onY_NP00ol0
003oZKgXojVmj003ojVmj003o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003ojVm
j0Co00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP01?l0003oZKgXo`000?l00002
o`0W/P;o00000_m8L=L00ol0003oX9c@oj2Ld004oj2Ld003o`000?o2Zl;o000000Oo`ZNo00Co0000
olJ_`oo6[l?o00001oo6[<000ol0003oaK36o`000007olVca@03o`000?o5]<Wo000000Kob;C800?o
0000olFgcOl000002?o7^<`00ol0003oakc@olNld006olNld0;o00002?o6_]<2o`0000Koa<7G00?o
0000olK3eol000001oo3`mT00ol0003oaLGJo`000005omk9``07o`000?o<b=Ooc<SGolc8eol0003o
n;b8o`000003ooRmR@05o`000?oh_XWon;j9ooRnROl000000_oi_hT01?l0003onKn8ooVoR?l00002
ook6OP03o`000?ohc5ko000000?o000000GomlaMo`000?l0003o0000on7MJ`05o`0000CoZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00Co
0000ojVmj?nY_NSoZKgX1Ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000[ooooo
00?o0000ooooooooool03?ooool002Gooooo00?o0000ooooooooool0>_ooool3o`0000_ooooo0_l0
0006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00CoZKgX
0_l000001Ol01i?o0000o`0W/_l0003o?FSC00;o000000?oB73Go`000?nPW=001?nPW=02o`0000So
`ZNo00?o0000olJ_`ol000002Oo6[<000ol0003obK?5olVca@07olVca@03o`000?o8]<Sob;C800Ko
b;C800?o0000olNhc?o7^<`01_o7^<`2o`0000Ooakc@00?o0000olRmd?l000001oo6_]<00ol0003o
al3Co`000005olC1e`05o`000?o6`mOoa/?GolK3eol000001Oo3`mT01Ol0003oaLGJolG5f_o5aM[o
000000?og/W300?o0000olc8eoo<b=L00oo<b=L2o`0000?on;f900Co0000ooRnROoh_XWo00000ooi
_hT01?l0003onKn8ooVoR?l00002ook6OP09o`000?ohc5ko0000o`000?oja8co0000ooO<GOl0003o
g=9G00?o000000?oa<eAo`000?nY_NP01_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP00onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX0_l00004ojVmj0Co00001?nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP0
1?l0003oZKgXojVmj?nY_NP4o`0000Wooooo00?o0000ooooooooool03?ooool000_ooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01oooool00ol0003oooooooooo`0gooooo`?o00004?ooool00ol0003oZKgXojVmj003ojVm
j0Co00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001OnY_NP00ol0003oZKgXojVmj004ojVm
j0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP7o`000004o`0W/_l0003o?FSCoceXd`;o00000_nP
W=03o`000003oinGc?l0003o`ZNo00So`ZNo00?o0000olJ/`?o6[<002?o6[<000ol0003obK?5olVc
a@06olVca@;o00001oo8]<P2o`0000OoakS<00Co0000olViboo9^L_o00001Oo7_=001Ol0003ob;g@
olRmd?o8_M3o000000Coa[kC0_l00003olO0d`05o`000?o4`MOoa<7GolC1eol000001Oo6`mL01Ol0
003o`l?Iol?3fOo3`mWo000000GoaLGJ00?o0000omk9`ol000001_o<b=L2o`0000?on;f900Co0000
ooRnROoh_XWo00000ooi_hT01?l0003onKn8ooVoR?l00002ook6OP03o`000?ohc5ko000000;on/B<
0ol000001?oLdUOo0000o`000?o4cE43o`0000KoZKgX0_l00006ojVmj004o`000?nY_NSoZKgXojVm
j0Co00001_nY_NP5o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVm
j003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX
00CoZKgX1?l00003ojVmj0;o00002?ooool00ol0003oooooooooo`0<ooooo`003?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0=Oooool3o`0001Cooooo00?o0000ojVmj?l000000_l00000
0onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003
ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00001?nY_NP5
o`0000Co?FSC0_l00005oinGc003o`000?o2Ykoo`ZNo00Ko`ZNo00?o0000olJ/`?o6[<001oo6[<00
0ol0003ob:bmo`000006olVca@04o`000?o9/L;obK72o`0000Gob;C800Co0000olZfa_o:]/Ko0000
1Oo7^<`00ol0003obKW;olVib`02olVib`05o`000?o7_=3oakc@olNld?l000001Oo8_M001?l0003o
a[kColJndol00006olO0d`03o`000?o4`MOo000000Ooa/?G00?o0000ol?3fOl000001_o5aMX2o`00
00Koc<SG00?o0000ol_:fOl000000ooh_HT01?l0003on;j9ooRnROl00003ooVoR@04o`000?oi_hSo
nKn8o`0000;oo/In0ol00002oo[4S0Ko000000?oa<eAo`000?l000000_l00002ojVmj0?o000000?o
ZKgXo`000?nY_NP01OnY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000CoZKgX00?o
0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oooooooooo`04ooooo`03oeEE
EOmVIVKo000000kooooo0009ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo03;ooooo0ol0000Hooooo`03
o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00Co0000ojVmj?nY
_NSoZKgX1?l00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVm
j0Go00000olmJ=<00ol0003oWiO<oinGc004oinGc003o`000?o2Ykoo`ZNo00Go`ZNo00?o0000olJW
^ol000001oo6[<001?l0003ob:bmolR/_Ol00005olVca@05o`000?o9/L;obK72olVa`_l000001?o8
]<P00ol0003ob[K6olZfaP02olZfaP05o`000?o7^<coakS<olNhc?l000001_o9^L/00ol0003oakc@
o`000006olRmd003o`000?o6_]?o000000Ooal3C0_l00008olK3e`;o00001_o5aMX00ol0003oaLOK
o`000005olc8e`07o`000?o;b]Wobl[Iol_:fOl0003on;f9o`000003ooRnR@04o`000?oi_hWonKn9
o`0000?onKn800Co0000ook6O_l0003on<aN0_l000001Ooja8co0000ooO<GOl0003og=9G00[o0000
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP0
0ol000001?nY_NSo0000ojVmj?l00004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY
_NP01OnY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY
_NP00onY_NP2o`0001Kooooo0009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0_
ooooo`?o00007?ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj003ojVmj0Co00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o000000?o00bJo`000?l000000olmJ=<00ol0003oWiO<oinGc004
oinGc003o`000?o2Ykoo`ZNo00?o`ZNo00Co0000olJW^oo6Yk_o00001_o6[<000ol0003ob:bmolR/
_@02olR/_@05o`000?o9/lGobK?5olVcaOl000001Oo9/L801?l0003ob;C8olRdb?l00006olZfaP03
o`000?o7^<co000000OobKW;0_l00007olRmd0;o00001oo7`=<00ol0003ob/?Do`000006olK3e`;o
000000?oalGHo`000?o5aMX01?o5aMX01Ol0003oaLOKolG7foo5am_o000000?oc<SG00?o0000ol_:
fOo;b]T00oo;b]T2o`0000?on;j900Co0000ooVoROoi_hWo00000ooi_hP01?l0003oo/Ino`000?oh
c5h2o`000005oo[4S?l0003omlaMo`000?oLdUL01ol000000on/`NWo0000ojVmj005ojVmj0?o0000
1OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP2o`0000;oZKgX1Ol00005ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVm
j?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP01?l0000Gooooo`002Oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0;?ooool3o`00023ooooo00Co0000ojVmj?nY_NSoZKgX1?l00006
ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo
000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o000000KoZKgX
o`000?l0087o0000o`0<V_l00003oceXd`03o`000?nOUlcoWiO<00CoWiO<00?o0000ol:W_oo2Ykl0
0_o2Ykl00ol0003oaZNkolJW^`02olJW^`03o`000?o6[<3oaZc000;oaZc000?o0000olR/_Oo8[;d0
0oo8[;d01?l0003obK?5olVcaOl00006olVa`P03o`000?o8]<So000000Sob[K600?o0000olViboo9
^L/01Oo9^L/00ol0003oc;_:o`000006olRmd004o`000?o:_loob[o?o`0000Goal3C00Go0000ol[3
e?o:`mCob/?Do`000004olK3e`03o`000?o7aMSoalGH00;oalGH00Go0000olG5f_o5aM[oaLGJo`00
0005olG7f`03o`000?o<b=Oo000000Kobl[I0_l00003ooRnR@04o`000?oi_hWonKn9o`0000;onKn8
00Ko0000ook6O_onaWko0000ooS<G_l00002oo[4S003o`000?ogc5go000000Go00001On/`NT00ol0
003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj005ojVmj0Co00000onY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP5o`0000Cooooo00?o0000
ooooooooool05?ooool000[ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02Wooooo0ol0
000Tooooo`?o00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003oZKgXojVm
j003ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000GoZKgX0_l00002o`0<VP;o0000
0_lmJ=<00ol0003oWiO<oinGc004oinGc004o`000?o2Ykoo`ZNoo`0000KoaZNk00Co0000olJ/`?o6
[<3o00001_o8[;d00ol0003obK?5o`000008olVa`P03o`000?o:]/Kob[K600Oob[K600?o0000olVi
boo9^L/01?o9^L/01Ol0003oc;_:olbkb_o<^l[o000000Cob;g@00?o0000olZocoo:_ll00_o:_ll0
1Ol0003oal3ColO0doo7`=?o000000Gob/?D00Co0000olK3eol0003o00001_o7aMP00ol0003oaLGJ
o`000006olG7f`;o00001_o;b]T00ol0003ob/_Ko`000003ooRnR@04o`000?oi_hWonKn9o`0000;o
nKn800Ko0000ook6O_onaWko0000ooS<G_l00002oo[4S003o`000?ogc5go000000Go00001On/`NT3
o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00005ojVmj003o`000?nY_NSoZKgX00?o000000Co
ZKgXo`000?nY_NSo00001?nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0Co00002Oooool00ol0003ooooo
ooooo`0Dooooo`002_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool09oooool2o`0002So
oooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000Co
ZKgX00?o0000ojVmj?nY_NP00onY_NP2o`000006o`0<V_l0003o85O=o`000?lmJ=?o00001_nOUl`0
0ol0003o`ZNoo`000007olJW^`03o`000?o6[<3o000000Sob:bm00?o0000olVa`_o9/L801oo9/L80
0ol0003ob[K6olZfaP06olZfaP03o`000?o>^LKo000000CobKW;00?o0000olbkb_o<^lX00oo<^lX0
1?l0003ob;g@olRmd?l00006olZoc`03o`000?o7`=?o000000Oob/?D00?o0000olO5f?o7aMP01_o7
aMP2o`0000KoaLOK00?o0000olK8g?l000001Oo;b]T01ol0003ob/_Kol[;foo:bm_o0000ooRnROl0
00000ooi_hT01?l0003onKn8ooVoR?l00002ook6OP?o00000_oja8`00ol0003omlaMo`000003o`00
00;o[/=500?o0000ojc1jOl000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSo000000?oZKgX0ol00005ojVm
j004o`000?nY_NSoZKgXojVmj0Go00001OnY_NP00ol0003oZKgXojVmj003o`0000gooooo00?o0000
ooooooooool05?ooool000_ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00009Oooool3o`0002_ooooo00?o
0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`00
0?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o0000
00KoZKgXo`000?l0003o00bJo`000?lPEld3o`0000GoWiO<0_l00009olJW^`03o`000?o8[;gob:bm
00Oob:bm00?o0000olVa`_o9/L801_o9/L800ol0003oc;;0o`000006olZfaP05o`000?o>^LKoc[W6
oljia_l000000_o9^L/00ol0003oc;_:olbkbP04olbkbP03o`000?o8_M3o000000Oob[o?0_l00007
ol[3e0;o00001oo7aMP00ol0003obLOHo`000005olG7f`05o`000?o6b=coa/SLolK8g?l000000oo;
b]T00ol0003ob/_Kol[;f`03ol[;f`;o00000ooi_hT01?l0003onKn8ooVoR?l00002ook6OP?o0000
0_oja8`6o`0000;o[/=50_l00006ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP0
1_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgX
o`000003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00CoZKgX
0ol0000@ooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo02;ooooo0ol0
000_ooooo`03o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00001?nY
_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001OnY
_NP3o`0000?o85O=00?o0000oinGc?nOUl`00ol000000onNUL[o0000olJW^`08olJW^`03o`000?o8
[;gob:bm00Kob:bm00?o0000omBi_ol000001_o9/L801Ol0003oc;;0olbb`?o<//3o000000Cob[K6
00?o0000oljia_o>^LH00_o>^LH00ol0003obKW;o`000008olbkbP03o`000?o:_loob[o?00Gob[o?
00?o0000olc1d?l000001_o:`m@01?l0003ob/CDol[4e?l00004olO5f0;o00000oo9amP01Ol0003o
aLOKolG7foo5am_o000000Goa/SL00?o0000ol_:fOl000001_o:bm/2o`0000?onKn900Co0000ooVo
R?oi_hSo00000_onaWh3o`0000;on/B<1_l000001?n^`dGo0000om;lgol00006ojVmj0;o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP5o`0000CoZKgX
00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o0000
4oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0Oooooo`?o0000<ooo
ool00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY
_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?l039[o000000?o85O=0_l0
0005oijEbP03o`000?o6Yk_oaZNk00GoaZNk00?o0000on;m`Ol000001_o8[;d01Ol0003oe;VoomBi
_ooD^Koo000000CobK7200?o0000olbb`?o<//000_o<//001Ol0003ob[K6olZfa_o:]/Ko000000Ko
c[W600?o0000olbkb_o<^lX01oo<^lX00ol0003ob[o?olZoc`04olZoc`05o`000?o<`M3oc<7@olc1
d?l000001?o:`m@00ol0003ob/CDol[4e002ol[4e004o`000?o7aMSoalGHo`0000KobLOH00?o0000
olG7fol000001_o6b=`2o`0000Kob/_K00Ko0000ol_=foo;cM_o0000ooVoROl00003ooVoR003o`00
0?onaWkoo/In00?o00000_oja8`2o`000003ooo=Ool0003o000000;o00000ooBo=l00ol0003oZKgX
ojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000
ojVmj005ojVmj0Co00000onY_NP00ol0003oZKgXo`000003ojVmj0?o00001OnY_NP00ol0003oZKgX
ojVmj003ojVmj0?o00005_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003ooooooooo
o`0Looooo`?o0000=oooool00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVm
j003ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000o`000003ob1Gc@03o`000?nNUL[oWYG:00CoWYG:00?o0000olJW^oo6Yk/0
1?o6Yk/01?l0003oh_g1on;m`Ol00005olR/_@03o`000?oD^Kooe;Vo00;oe;Vo00Go0000olVa`_o9
/L;obK72o`000006olbb`003o`000?o:]/Ko000000Ooc[W600?o0000olbkb_o<^lX01_o<^lX00ol0
003oc[g:o`000004olZoc`03o`000?o<`M3oc<7@00?oc<7@00Co0000ol[3e?o:`mCo00001Oo:a=@0
0ol0003oalGHo`000007olW7f0;o00001_o6b=`00ol0003oal_Mo`000005ol[;f`03o`000?o;cM_o
blgK00;oblgK0_l00003ooVoR003o`000?onaWkoo/In00?o000000?on/B<o`000?ogc5d01?l00005
om;lg`?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP5o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000ojVmj005ojVmj0Go00000_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSoZKgX00?o00006Oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0I
ooooo`?o0000>oooool00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP0
0ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000
ojVmj?nY_NP00onY_NP2o`0000CoZKgX0_l00004ob1Gc@03o`000?nNUL[oWYG:00?oWYG:00?o0000
olJW^oo6Yk/00oo6Yk/00ol0003oh_g1on;m`@02on;m`@03o`000?o8[;gob:bm00;ob:bm00?o0000
omBi_ooD^Kl00ooD^Kl00ol0003obK72o`000008olbb`003o`000?o>^LKoc[W600Goc[W600?o0000
oljiaOl000001_o<^lX01Ol0003oc[g:oljmb_o>_L[o000000;ob[o?00?o0000olc1d?o<`M001?o<
`M000ol0003ob/?Do`000006ol[4e0?o00001_o9amP01?l0003ob/WIol[9fOl00003olK8g0;o0000
0oo7bmd01Ol0003ob/_Kol[;foo:bm_o000000GoblgK0_l00002ooVoR003o`000?onaWkoo/In00?o
00000_oja8`00ol0003omlaMo`000004o`000004om;lgol0003o0000o`0000;oZKgX00?o0000ojVm
j?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVm
j?nY_NP00onY_NP3o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX1?l0000Mooooo`03o`000?oooooo
oooo01?ooooo000Sooooo`03o`000?oooooooooo01Kooooo0ol0000oooooo`03o`000?nY_NSoZKgX
00GoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP0
0ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj002
ojVmj0?o00000_lPEld00ol0003oWYG:oijEbP04oijEbP05o`000?o6Yk_oaZNkolJW^ol000001_oR
oL401?l0003ob:bmolR/_Ol00007omBi_`03o`000?o<//3oc;;000Ooc;;000?o0000oljia_o>^LH0
1?o>^LH01Ol0003oc[W5oljiaOo>^LGo000000Coc;_:00?o0000oljmb_o>_LX00_o>_LX00ol0003o
b[o?o`000007olc1d0;o00001_o:a=@01Ol0003oc<OEolc7eOo<amGo000000?obLOH0_l00004ol[9
f@03o`000?o6b=co000000Koal_M00?o0000ol[;fol000001Oo;cM/01_l0003oc<oLolc?g?l0003o
nKn8o`0000;oo/In0ol00002oo[4S003o`000?ogc5go000000Go00001_nY_NP00ol0003oZKgXo`00
0002o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j005ojVmj003o`000?nY_NSoZKgX00?o000000CoZKgXo`000?nY_NSo00001?nY_NP4o`00027ooooo
00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool04oooool3o`0004?ooooo00?o
0000ojVmj?nY_NP01?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00?o
0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l000001?l0?Koo0000
ob1GcOl00006oijEbP04o`000?o6Yk_oaZNko`0000Ooh_g100?o0000olR/_Ol000002?oD^Kl00ol0
003oc;;0olbb`006olbb`003o`000?o?/kko000000Coc[W600?o0000oljiaOo>^LD00_o>^LD01Ol0
003oc;_:olbkb_o<^l[o000000Koc[g:00?o0000olc1d?o<`M001Oo<`M000ol0003oclC?o`000005
ol[4e003o`000?o<amGoc<OE00?oc<OE00?o0000olW7f?l000001_o:bMT2o`0000Ooal_M0_l00005
ol_=f`03o`000?o<cmcoc<oL00;oc<oL0_l00002ook6OP?o00000_oja8`00ol0003omlaMo`000005
o`0000KoZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj004o`000?nY_NSo
ZKgXojVmj0Go00001OnY_NP00ol0003oZKgXo`000003o`0002Gooooo00?o0000ooooooooool04ooo
ool002;ooooo00?o0000ooooooooool04_ooool2o`0004Oooooo00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSo
ZKgX00CoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00000
1onY_NSo0000o`000?l0?Koo0000ob1GcOl000001OnNULX00ol0003oaZNko`00000:o`0000Soe;Vo
00?o0000on;mbol000001_o<//001Ol0003ock>nolnc__o?/kko000000;oc[W600?o0000oljiaOo>
^LD01?o>^LD00ol0003oc;_:o`000007oljmbP;o00001Oo<`M001Ol0003oclC?olo4coo?a<oo0000
00?ob/CD00?o0000olc7eOo<amD01?o<amD2o`0000Kob/WI00?o0000ol_;f_l000001_o7bmd01?l0
003oalgNolO=g_l00003ol_=f`03o`000?o<cmcoc<oL00?oc<oL1Ol000001?oebJ3o0000oo[4S?oj
a8`2o`000003ooo=Ool0003o000000;o000000Co]>R=o`000?nY_NSoZKgX0ol000000onY_NSo0000
ojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co0000
0onY_NP00ol0003oZKgXojVmj004ojVmj0?o0000:?ooool00ol0003oooooooooo`0Cooooo`008_oo
ool3o`0000oooooo0ol0001:ooooo`;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000KoZKgX
00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP01Ol0003o
ZKgXojVmj?nY_NSo000000;o03fo0_l00005oijEbPCo000000ColMNeo`000?okfJ7o00000_old9P3
o`0000Ooe;Vo00Co0000on;mbooRoL_o00001Oo<//000ol0003ock>nolnc_P02olnc_P03o`000?o>
^LKo000000Soc[W500?o0000oljmb_o>_LX01Oo>_LX01?l0003od/;;om;2bol00003olc1d003o`00
0?o?a<ooclC?00?oclC?00?o0000ol[4e?l000001_o<amD00ol0003ocLWFo`000005ol[9f@05o`00
0?o;bm[obl_Jol_;f_l000000oo7bmd2o`0000CoalgN00?o0000ol_=fol000001Oo<cm`00ol0003o
cm7KoloAf`02oloAf`03o`000?oebJ3o000000;on/B<0_l000001OoocGoo0000o`000?l0003o]>R=
00Co00001OnY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l000000_l00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY_NP00ol00003ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool03?ooool3o`00
04oooooo00?o0000ojVmj?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`00
00CoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Go0000ojVmj?nY_NSoZKgXo`000002
o`0m_`03o`000?nNUL[oWYG:00Co000000CoZj3<o`000?oaekGo00000_okfJ401Ol0003oo=2Hooc@
V?l0003oo<V>00;o00001OoD^Kl00ol0003oh_g;on;mb`02on;mb`05o`000?o<//3oc;;0olbb`?l0
00001_o?/kh00ol0003oc[W5oljia@07oljia@03o`000?o>_L[oc[g:00Coc[g:00?o0000om;2booB
`//00_oB`//00ol0003oc<7@o`000007olo4c`03o`000?o<amGoc<OE00Coc<OE00Go0000olg9e_o=
bMKocLWFo`000003ol[9f@03o`000?o;bm[obl_J00?obl_J00?o0000olO;gOl000001_o7cMh2o`00
00Goc<oL00?o0000oloAfoo?dM/00_o?dM/2o`000004ooG9X?l0003on/B<oo[4S0;o000000?ooleo
o`000?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Wooooo0ol0001C
ooooo`03o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXo`000002
o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP00onY_NP6o`0000;o03fo0ol00003oj^Pc004o`000?oaekGolMNeo`0000;onmVQ00Go
0000ooc@V?old9So0000ooc9SP02o`0000Coe;Vo00?o0000on;mbooRoL/00ooRoL/01?l0003oc;;0
olbb`?l00007olnc_P03o`000?o>^LGoc[W500Koc[W500?o0000om6ka?l000001?o>_LX00ol0003o
d/;;om;2b`04om;2b`03o`000?o?a<ooclC?00GoclC?0_l00005olc7e@03o`000?o=bMKocLWF00?o
cLWF00?o0000ol[9fOl000001_o;bmX2o`0000KoalgN00Co0000olS?goo8cmoo00000oo<cm`00ol0
003ocm7KoloAf`02oloAf`05o`000?oSd/Ko0000ooG9X?l000000_oja8`2o`000003ooo=Ool0003o
000000KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000
ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0Co00003?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Kooooo0ol0001Goooo
o`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00Co0000ojVm
j?nY_NSoZKgX0ol00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP01Ol0003oZKgXojVmj?l0
003o03fo00;o00001On[X<`01?l0003olMNeoo7G]Ol00002oo_IX@05o`000?old9Soo=2Ho`000?ol
bHh00ol00002omBi_`03o`000?oRoL_oh_g;00Coh_g;00?o0000olbb`?l000001oo?/kh00ol0003o
hm76o`000006oljia@05o`000?oA^lCodK_4om6ka?l000000_o>_LX00ol0003od/;;om;2b`05om;2
b`03o`000?o?a<ooclC?00CoclC?00Co0000om76d?oAa]3o00000oo<amD00ol0003ocLWFolg9eP05
olg9eP03o`000?o;bm[obl_J00Cobl_J00Co0000olc>foo<c]_o00000oo7cMh2o`0000Cob<oO00?o
0000olc?g?l000001Oo?dM/2o`000003ooG9X?l0003on/B<00;on/B<1_l00005ojVmj0;o00001_nY
_NP01?l0003oZKgXojVmj?nY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0000@ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool00ooo
ool3o`0005_ooooo00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o
0000ojVmj?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co
0000ojVmj?l0003o00001_n[X<`01?l0003olMNeoo7G]Ol00002oo_IX@04o`000?old9Soo=2Ho`00
00;oo<V>00Co0000ooVoQ_l0003oe;Vo2_l00007olnc_P05o`000?oSdLKohm76on?Aa_l000001?o>
^LD00ol0003odK_4om6ka002om6ka003o`000?o>_L[o000000Ood/;;00?o0000om;2bol000001?o?
a<l00ol0003odLK@om76d002om76d003o`000?o<amGo000000OocLWF0_l00005ol_;fP03o`000?o<
c]_oc<kK00;oc<kK00?o0000olO=g_l000001_o8cml2o`0000Gocm7K00Go0000on?Ba_l0003omLVP
o`000002oo[4S003o`000?ogc5go000000Co00000_nY_NP3o`000003ojVmj?l0003oZKgX00GoZKgX
1?l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0000Dooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool04_ooool0027ooooo00Co0000oooooooooooooooo0ol0001Oooooo`04o`00
0?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP00onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000Go
Zj3<00Go0000oo7G]OoaekGolMNeo`000002oo_IX@04o`000?old9Soo=2Ho`0000;oo<V>00?o0000
ooVoQ_oi_hH00_l000000ooi_8?o0000ooRkQ@02ooRkQ@04o`000?of^HOo0000o`0000Oock>n00Go
0000on?Aa_oSdLKohm76o`000003oljia@03o`000?oA^lCodK_400CodK_400?o0000om;2booB`//0
1OoB`//01Ol0003od/;;om;2booB`/_o000000;oclC?00?o0000om76d?oAa]001?oAa]000ol0003o
cLWFolg9eP05olg9eP04o`000?o>c=Ooc/cGo`0000?obl_J00?o0000olc>foo<c]/00oo<c]/2o`00
00Kob<oO00?o0000olS@h?l000001?o?dM/01_l0003ohm;6on?Ba_l0003omLVPo`0000;on/B<00?o
0000ooO<GOl000001_l00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY
_NP00ol0003oZKgXo`000002o`0001Sooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Booooo`008Oooool4o`0006?ooooo0ol00004ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00006
ojVmj004o`000?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX0ol0
0004oj^Pc005o`000?oaekGolMNeoo7G]Ol000000_okfJ401_l0003oo=2Hooc@V?l0003oo<V>o`00
00?onKn600Co0000ooVlPooi_8?o00000ooh^hD00ol0003om[V7ooJiQ`02o`0000Gock>n00?o0000
on?Aa_oSdLH00ooSdLH00ol0003oc[W5o`000007om6ka0;o00001OoB`//00ol0003od/;;om;2b`02
om;2b`03o`000?o?a<oo000000KodLK@00?o0000om;9dOl000001Oo=bMH00ol0003oc/cGolk<e`02
olk<e`03o`000?o;bm[o000000Goc<kK00?o0000olc@g?l000001Oo8cml01Ol0003ob=3PolS@h?o8
d>3o000000?ocm7K00Ko0000on?Ba_oSd/Ko0000ooG9X?l00002oo[4S0;o000000?ooleoo`000?l0
00000onZ_^P00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP4o`00
01_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`008Oooool2o`0006Ko
oooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX0_l00003oj^Pc005
o`000?oaekGolMNeoo7G]Ol000000_okfJ401ol0003oo=2Hooc@V?old9So0000ooc9S_l000000ooi
_hH01?l0003onKb3ooVlPol00003ooRkQ@03o`000?of^HOom[V700?o00000oo?/kh00ol0003ohm76
on?AaP04on?AaP;o00001ooA^l@01?l0003oe;g4omBma?l00003om;2b`03o`000?oB`/_od/;;00Co
d/;;00?o0000om76d?oAa]001?oAa]001Ol0003od/WAom;9dOoBbM7o000000?ocLWF00?o0000olk<
eoo>c=L00oo>c=L2o`0000Goc<kK00Go0000olc@g?o<d=coc=3Lo`000003olS?g`03o`000?o8d>3o
b=3P00?ob=3P00?o0000oloAfol000000_oSd/H01?l0003omLVPooG9X?l00002oo[4S0;o000000?o
oleoo`000?nZ_^P01?nZ_^P00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00GoZKgX1?l0
000Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04_ooool002?ooooo00?o0000
ooooooooool0I?ooool01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l000000_l0
0002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY
_NSoZKgX00CoZKgX0_l00002oj^Pc005o`000?oaekGolMNeoo7G]Ol000000_okfJ401ol0003oo=2H
ooc@V?old9So0000ooc9S_l000000ooi_hH00ol0003onKb3o`000006o`000004ooJiQol0003om;N8
o`0000?ock>n00?o0000on?Aa_oSdLH00ooSdLH00ol0003og_?Mo`000006om6ka003o`000?oD_LCo
e;g400;oe;g400?o0000om;2bol000001_oB`//2o`0000GodLK@00?o0000om;9dOoBbM400ooBbM40
0ol0003ocLWFo`000005olk<e`04o`000?o?cmSocloHo`0000?oc<kK00?o0000olc@g?o<d=`00oo<
d=`00ol0003ob<oOo`000006olS@h0;o00000ooSd/H01?l0003omLVPooG9X?l00002oo[4S0;o0000
00?ooleoo`000?nZ_^P00_nZ_^P4o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0000Uooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000ooooooooool0I?oo
ool3o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX
0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co000000?oZj3<o`000?oaekD00_oaekD01Ol0003o
nmVQoo_IXOokfJ7o000000;oo=2H00?o0000ooc9S_l000001_l000000ooZ_JKo0000onjlWP02onjl
WP04o`000?o`_9Wo0000o`0000;om;N800?o0000olnc__l000001OoSdLH01Ol0003og_?MomkcgOoN
lmgo000000CodK_400?o0000omBma?oD_L@01?oD_L@00ol0003od/;;om;2b`04om;2b`04o`000?oD
aL_oe<G;o`0000?odLK@00?o0000om;9dOoBbM401OoBbM400ol0003oc/cGolk<e`03olk<e`03o`00
0?o?cmSocloH00;ocloH00?o0000olc>fol000001_o<d=`2o`0000Kob=3P00Co0000olSBh_o8d^;o
00000_oSd/H01?l0003omLVPooG9X?l00002oo[4S0;o000000?ooleoo`000?l000000_l00003ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol0000Yooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool04_ooool002Gooooo00?o0000ooooooooool0IOooool00ol0003oZKgXojVmj003ojVmj003
o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00000onY_NP00ol0003o
ZKgXojVmj003ojVmj0Co00000onY_NP00ol0003oZj3<o`000003oo7G]@04o`000?okfJ7onmVQo`00
00?oo=2H0_l000000oo=^/So0000on:m/P02on:m/P04o`000?oZ_JKoj[fVo`0000?ok[bN00Co0000
oo2lVOo`_9Wo00000ood]hP00ol0003ohm76on?AaP03on?AaP03o`000?oNlmgog_?M00?og_?M00Co
0000om6ka?oA^lCo00001ooD_L@00ol0003od/;;om;2b`03om;2b`03o`000?oDaL_oe<G;00;oe<G;
00?o0000om76d?l000001ooBbM400ol0003oe<cBo`000003olk<e`03o`000?o?cmSocloH00?ocloH
0_l00006olc@g004o`000?o=d]kocM;No`0000?ob=3P0_l00004olSBhP;o00000_oebJ001?l0003o
n/B<oo[4S?oja8`2o`000004ooo=Ool0003oZ[kXo`0000GoZKgX00?o0000ojVmj?l000000_l0000/
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04Oooool002Kooooo0_l0001Voooo
o`04o`000?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP3
o`0000;olMNe2?l000000oo=^/So0000on:m/P02on:m/P04o`000?oZ_JKoj[fVo`0000?ok[bN00Go
0000oo2lVOo`_9Wol;bIo`000002ooBgR003o`000?ob]H[o000000?ohm7600?o0000omkcgOoNlmd0
1?oNlmd00ol0003odK_4o`000007omBma003o`000?oH`L;o000000?od/;;00?o0000omC5booDaL/0
1?oDaL/00ol0003od/WAom;9d@05om;9d@07o`000?oDc=;oe<cBomC<d_l0003oc/cGo`000005olo?
f004o`000?o@dM[od=7Jo`0000?oc=3L0_l00004olgBgP03o`000?o8d>3o000000Kob=;R0ol00000
0ooebJ3o0000oo[4S002oo[4S004o`000?oocGoooleoo`0000;oZ[kX00Co0000ojVmj?nY_NSoZKgX
0ol0000`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool002Sooooo00?o
0000ooooooooool0I?ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co
0000ojVmj?nY_NSoZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0Ko00001?n6W^<01Ol0003o
cK[8olfjb?o=^/So000000?oh[fb00Co0000onZmY_oZ_JKo00000oo^_9h01?l0003ol;bIoo2lVOo`
_9T2o`000007ooBgR?l0003ol[F:oo:eR_l0003ohm76o`000007omkcg@;o00001ooD_L@01ol0003o
f<72omS1`_oH`L;o0000om;2bol000001ooDaL/2o`0000God/WA00?o0000omC<d_oDc=800ooDc=80
0ol0003ocloHolo?f003olo?f003o`000?o@dM[od=7J00;od=7J00?o0000olc@g?l000001_o=d]h2
o`0000Kob=;R00Co0000olSDhoo8e>?ob=CS0_l00002oo[4S0;o000000?ooleoo`000?nZ_^P00_nZ
_^P4o`0003Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Aooooo`00:Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00002
ojVmj003o`000?n6W^?oQYkS00CoQYkS00Go0000olfjb?o=^/SocK[8o`000004on:m/P04o`000?oZ
_JKoj[fVo`0000?ok[bN00Co0000oo2lVOo`_9Wo00000_ob_IL2o`0000?ol[F:0ol00003omkcg@?o
000000?oOMoho`000?oD_L@01OoD_L@00ol0003of<72omS1`P03omS1`P03o`000?oDaL_oe<G;00Go
e<G;00Co0000omO9c?oGbLco00000ooBbM400ol0003oe<cBomC<dP03omC<dP03o`000?oFcm?o0000
00?ocloH00?o0000om3Af_o@dMX00oo@dMX2o`0000KocM;N00Co0000olcDh?o<e>3o00000oo8d^82
o`0000Cob=CS0ol000001?oja8co0000o`000?oocGl4o`0003Wooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Aooooo`00:_ooool00ol0003oooooooooo`1Tooooo`04o`000?nY_NSo
ZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY
_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003oQYkSohJN
h`02ohJNh`03o`000?o=^/SocK[800;ocK[800Go0000on:m/_oR_K;oh[fbo`000003onZmYP05o`00
0?o^_9kok[bNonjlW_l000000_o`_9T01Ol0003ol[fGoo:mUoob_IOo000000?ol[F:00?o0000oo6c
R_oa/hX01?l00004oggOn003o`000?oD_LCoe;g400;oe;g400?o0000omS1`_oH`L801?oH`L800ol0
003oe<G;omC5b`04omC5b`03o`000?oGbLcoelW<00;oelW<00?o0000om;9dOl000001OoDc=801ol0
003oe/oComK?dooFcm?o0000olo?f?l000001Oo@dMX01?l0003od=CKom3Dfol00003olgBgP;o0000
1?o<e>000ol0003ob=;Ro`000005olSDh`04o`000?o8e^Cob=KTolSFi0?o000000?ooleoo`000?oo
ool0>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo000[ooooo`;o0000
IOooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSo
ZKgX1?l00006ojVmj004o`000?nY_NSoZKgXojVmj0;o00000_n6W^<00ol0003ocK[8olfjb002olfj
b003o`000?oR_K;oh[fb00;oh[fb00Co0000onZmY_oZ_JKo00000oo^_9h01Ol0003ol;bIoo2lVOo`
_9Wo000000?ol[fG0_l00002oo:eRP05o`000?oa/h[olK>:oo6cR_l000000_o`/HX3o`0000;oOMoh
00Co0000omBma?oD_LCo00001_oH`L800ol0003oflC2o`000004omC5b`03o`000?oGbLcoelW<00?o
elW<0_l00005omC<dP03o`000?oFcm?oe/oC00?oe/oC00?o0000om3Af_o@dMX00oo@dMX00ol0003o
d=CKom3Df`02om3Df`03o`000?o=d]ko000000Koc=CP0_l00005olSDh`03o`000?o8e^Cob=KT00;o
b=KT0_l00002ooo=O`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Aooooo`00;Oooool00ol0003oooooooooo`1Sooooo`03o`000?nY_NSoZKgX00?oZKgX
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003o`00
0?nY_NSoZKgX00?oZKgX1?l000001?nY_NSo0000ohJNhol00005olfjb005o`000?oR_K;oh[fbon:m
/_l000000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Wo0000oo:mUoob_IOol[fGo`00
0?oc_YOo0000oo:eR_l000000ooa/hX01_l0003ol;6:oo2aR_o`/H[o0000oo2aR@?o000000?oe;g4
o`000?oH`L801OoH`L801Ol0003oflC2om_4`_oKa<;o000000;oe<G;00?o0000omO9c?oGbL`00ooG
bL`01?l0003ofLc=omW<cOl00003omC<dP03o`000?oFcm?oe/oC00?oe/oC00?o0000omKCeOl00000
0oo@dMX00ol0003od=CKom3Df`03om3Df`;o00001_o<e>001?l0003oc=KQolcFhOl00003olSDh`03
o`000?o8e^Cob=KT00;ob=KT0ol00002ooo=O`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Aooooo`00;_ooool00ol0003oooooooooo`1Sooooo`04o`00
0?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00Go0000ojVmj?nY_NSoZKgXo`000006olfj
b005o`000?oR_K;oh[fbon:m/_l000000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Co
0000oo:mUoob_IOo00000ooc_YL2o`0000?olK>:00Go0000oo2aR_o`/H[ol;6:o`000003oo2aR@;o
00001ooH`L801ol0003oflC2om_4`_oKa<;o0000omC5bol000001OoGbL`00ol0003ofLc=omW<c@02
omW<c@03o`000?oDc=;o000000Goe/oC00Oo0000omKCeOoFdmGoe]?Eo`000?o@dM[o000000God=CK
00Co0000om3EgOo@eMgo00000oo<e>02o`0000Coc=KQ00?o0000olSDhol000001?o8e^@01?l0003o
cmSOo`000?l00002ooo=O`03o`000?oooooooooo03cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0@ooooo`00;oooool00ol0003oooooooooo`1Sooooo`?o00000onY_NP00ol0003o
ZKgXojVmj003ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00Co0000ojVm
j?nY_NSo00001Oo=^/P00ol0003oh[fbon:m/P02on:m/P05o`000?oZ_JKoj[fVonZmY_l000000oo^
_9h01?l0003ol;bIoo2lVOl00003oo:mU`03o`000?oc_YOolkjG00;olkjG00Go0000oo6cR_oa/h[o
lK>:o`000002oo2aRP03o`000?o`/HWol;6900;ol;690_l00006omS1`P03o`000?oKa<;oflC200?o
flC200?o0000omO9c?oGbL`00ooGbL`00ol0003ofLc=omW<c@04omW<c@03o`000?oFcm?oe/oC00?o
e/oC00?o0000omKCeOoFdmD00ooFdmD00ol0003od=CKom3Df`03om3Df`03o`000?o@eMgod=GM00;o
d=GM00?o0000olcDh?l000001_o<e^43o`0000?ob=KT00Go0000oloHgol0003om=2[o`000002ooo=
O`03o`000?oooooooooo03gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0@oooo
o`00<?ooool00ol0003oooooooooo`1Sooooo`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l0
00000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003o`000?nY_NSoZKgX00?o
ZKgX1Ol00004olfjb005o`000?oR_K;oh[fbon:m/_l000000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko
000000?ol;bI00Go0000oo:mUoob_IOol[fGo`000004oo>nU`05o`000?oa/h[olK>:oo6cR_l00000
0_o`/HX00ol0003ol;69oo2aR@02oo2aR@03o`000?o]/8ko000000Cof<7200?o0000om_4`_oKa<80
1?oKa<82o`0000?oelW<00?o0000omW<cOoIc<d01OoIc<d2o`0000?oe/oC00?o0000omKCeOoFdmD0
0ooFdmD00ol0003oemKGo`000003om3Df`03o`000?o@eMgod=GM00?od=GM0_l00006olcFh@07o`00
0?o;f>?obmSSol_Hhol0003ob=KTo`000002oloHg`03o`000?odd:_o000000;ooleo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo013ooooo000aooooo`;o
0000I?ooool01?l0003oZKgXojVmj?nY_NP3o`0000KoZKgX00?o0000ojVmj?l000000_l00003ojVm
j003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj004o`000?nY_NSoZKgX
o`0000;ocK[800?o0000on:m/_oR_K800_oR_K801Ol0003oj[fVonZmY_oZ_JKo000000?ok[bN00Go
0000oo2lVOo`_9Wol;bIo`000003oo:mU`03o`000?oc_YOolkjG00;olkjG0_l00002oo6cRP04o`00
0?o`/H[ol;6:o`0000Col;6900Co0000onf`S_o]/8ko00000ooH`L800ol0003oflC2om_4`P03om_4
`P06o`000?oNb<?og/S3o`000?oGbLco00001ooIc<d01_l0003of]3?om[@col0003oe/oCo`0000Go
e]?E00Oo0000omOFeooGe]OoemKGo`000?o@e=_o000000God=GM00Co0000om7Ig_oAfMko00000oo<
e^42o`0000CobmSS0_l00002oloHg`06o`000?odd:_om=2[o`000?oocGoo0000@_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo013ooooo000cooooo`03o`000?oooooooooo06;ooooo
0ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00007ojVmj004o`000?nY_NSoZKgXojVmj0?o
00001_nY_NP01_l0003oZKgXojVmj?l0003ocK[8o`0000Coh[fb00Go0000onZmY_oZ_JKoj[fVo`00
0003onjlWP05o`000?o`_9Wol;bIoo2lVOl000000oob_IL02Ol0003olkjGoo>nUooc_YOo0000oo?0
V?l0003olK>:o`000003oo2aRP05o`000?o`/HWol;69oo2aROl000001?o]/8h00ol0003of<72o`00
0005om_4`P03o`000?oNb<?og/S300;og/S300?o0000omW<cOoIc<d01OoIc<d00ol0003of]3?om[@
c`02om[@c`03o`000?oFdmGoe]?E00?oe]?E00?o0000omOFeooGe]L00ooGe]L00ol0003od=GMom3E
g@03om3Eg@03o`000?oAfMkodMWN00;odMWN00?o0000olcFhOl000001Oo;f><00ol0003ob]WTo`00
0002oloHg`06o`000?odd:_om=2[o`000?oocGoo0000@_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo013ooooo000dooooo`03o`000?oooooooooo06;ooooo00?o0000ojVmj?nY_NP0
0onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000?oZKgX
00?o0000ojVmj?nY_NP00onY_NP5o`0000Coh[fb00Go0000onZmY_oZ_JKoj[fVo`000003onjlWP03
o`000?o`_9Wol;bI00;ol;bI00Co0000oo:mUoob_IOo00001?oc_YL00ol0003oll2Hoo?0V002o`00
00?ol;6:00Go0000oo2aROo`/HWol;69o`000005onf`SP03o`000?oKa<;oflC200?oflC200?o0000
omk8`ooNb<<00ooNb<<2o`0000GofLc=00?o0000om[@cooJd<l00ooJd<l2o`0000?oe]?E00?o0000
omOFeooGe]L00ooGe]L00ol0003oemWIo`000003om3Eg@03o`000?oAfMkodMWN00?odMWN0ol00003
ol_Hh`;o00000oo:fN@01Ol0003ocmSOo`000?odd:_o000000;ooleo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo000eooooo`03o`000?oooooo
oooo06;ooooo00Co0000ojVmj?nY_NSoZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00?o00000_nY
_NP00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXo`00
0004on:m/P05o`000?oZ_JKoj[fVonZmY_l000000oo^_9h01Ol0003ol;bIoo2lVOo`_9Wo000000?o
l[fG00?o0000oo>nUooc_YL00_oc_YL00ol0003oll2Hoo?0V002o`0000?ol;6:00Go0000oo2aROo`
/HWol;69o`000005onf`SP03o`000?oKa<;oflC200?oflC200?o0000omk8`ooNb<<00_oNb<<01?l0
003ohLc4on7<a?l00003omW<c@03o`000?oJd<oof]3?00?of]3?00Ko0000omcDd?oLe=3o0000omKC
eOl00005omOFe`07o`000?oGfMWoemWIomOIfOl0003od=GMo`000005om7IgP07o`000?o@fn7od=_Q
om3KhOl0003obmSSo`000005ol[Ii0?o000000?om=2[o`000?oocGl00_l00014ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04?ooool003Kooooo0_l0001Sooooo`?o00001?nY_NP0
0ol0003oZKgXojVmj002ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000KoZKgX00?o
0000ojVmj?l000000_oR_K800ol0003oj[fVonZmYP02onZmYP05o`000?o^_9kok[bNonjlW_l00000
0oo`_9T01Ol0003ol[fGoo:mUoob_IOo000000ColkjG00?o0000oo?0V?oc`9P00_l00003oo2aRP05
o`000?o`/HWol;69oo2aROl000001Oo]/8h2o`0000?oflC200?o0000omk8`ooNb<<00_oNb<<00ol0
003ohLc4on7<a002on7<a003o`000?oIc<go000000Gof]3?00?o0000omcDd?oLe=000_oLe=000ol0
003oemKGomOFe`03omOFe`03o`000?oGfMWoemWI00;oemWI0_l00005om7IgP03o`000?o@fn7od=_Q
00;od=_Q0_l00005ol[Ii004o`000?o:fnKob]_Vol[KiP?o000000?obmcVo`000?ooool0A?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo000hooooo`03o`000?oooooooooo
06;ooooo00?o0000ojVmj?nY_NP00onY_NP01?l0003oZKgXo`000?l00003ojVmj003o`000?nY_NSo
ZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l000001?nY_NSo0000on:m/_l0
0004onZmYP05o`000?o^_9kok[bNonjlW_l000000oo`_9T01Ol0003ol[fGoo:mUoob_IOo000000?o
lkjG00?o0000oo?0V?oc`9P00_oc`9P01Ol0003ol;6:oo2aR_o`/H[o000000?ol;6900?o0000onf`
S_o]/8h00oo]/8h01Ol0003ojK2Go`000?oKa<;o000000Gog/S300?o0000on7<a?oQc<@00ooQc<@0
0ol0003of]3?om[@c`03om[@c`03o`000?oLe=3og=C@00?og=C@0_l00003omOFe`03o`000?oGfMWo
emWI00;oemWI00Co0000omKKg?oFfmco00000ooAfMh00ol0003od=_Qom3Kh@02om3Kh@03o`000?o?
g>;o000000?ob]WT0_l00004ol[KiP;o000000?obmcVo`000?ooool0AOooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00oooooo000iooooo`03o`000?oooooooooo06;ooooo00Co0000
ojVmj?nY_NSoZKgX1?l00005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j003ojVmj003o`000?nY_NSo000000;o00000_nY_NP2o`000003on:m/_l0003oj[fV00;oj[fV00Go
0000onjlW_o^_9kok[bNo`000004oo2lV@05o`000?ob_IOol[fGoo:mUol000000ooc_YL00ol0003o
ll2Hoo?0V002oo?0V005o`000?o`/H[ol;6:oo2aR_l000000oo`/HT00ol0003okK2>onf`SP02onf`
SP05o`000?oY/9OojK2GonV`Uol000001OoNb<<00ol0003ohLc4on7<a004on7<a0;o00000ooJd<l0
0ol0003og=C@omcDd003omcDd006o`000?oLf=;og=SBo`000?oGe]Oo00001?oGfMT00ol0003oe]_L
omKKg002omKKg003o`000?oAfMko000000Cod=_Q00Oo0000oloLh_o?g>;ocmcRo`000?o:fNCo0000
00Gob]_V00?o0000ol_Li_o;g>H00_l00017ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool03oooool003[ooooo00?o0000ooooooooool0H_ooool3o`0000CoZKgX00Co0000ojVmj?nY
_NSoZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001OnY_NP2o`0000Coj[fV00Go0000
onjlW_o^_9kok[bNo`000004oo2lV@04o`000?ob_IOol[fGo`0000ColkjG00?o0000oo?0V?oc`9P0
0_oc`9P2o`0000;ol;6:00Go0000oo2aROo`/HWol;69o`000004onf`SP05o`000?oY/9OojK2GonV`
Uol000001?oNb<<00ol0003ohLc4on7<a004on7<a006o`000?oSd<Gohm35o`000?oJd<oo00001OoL
e=000ol0003og=SBomcHdP02omcHdP;o00000ooGfMT00ol0003oe]_LomKKg003omKKg0?o00000oo@
fn400ol0003ocmcRoloLhP02oloLhP?o00000oo:fnH2o`0000;obmcV0ol00018ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool03oooool003_ooooo0_l0001Sooooo`03o`000?nY_NSo
ZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj004o`000?nY_NSo
ZKgXojVmj0Co00000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Go0000oo:mUoob_IOo
l[fGo`000004oo>nU`09o`000?oc`9Soll2Hoo?0V?l0003oll>Mo`000?o`/H[o000000Col;6900?o
0000onf`S_o]/8h00_o]/8h01?l0003ojK2GonV`UooY/9L2o`0000?og/S300?o0000on7<a?oQc<@0
0ooQc<@00ol0003ohm35on?@a@02on?@a@03o`000?oLe=3og=C@00?og=C@00?o0000omcHd_oLf=80
0_oLf=801_l0003og=SDomcHe?l0003oemWIo`0000Goe]_L00Oo0000omGNg_oEg]koeMkNo`000?o@
fn7o000000CocmcR00Oo0000olkNiOo>g^Goc]kUo`000?o:fnKo000000CobmcV0ol00018ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool003gooooo00?o0000ooooooooool0
HOooool00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgX
o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000;oZKgX00?o0000ojVmj?l00000
0_oZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Go0000oo:mUoob_IOol[fGo`000003oo>n
U`03o`000?oc`9Soll2H00;oll2H00?o0000oo?3WOoc`id00_l00003oo2aR@03o`000?o]/8kokK2>
00?okK2>00Wo0000onV`UooY/9OojK2Go`000?nSO:Wo0000omk8`ol000001OoQc<@00ol0003ohm35
on?@a@03on?@a@;o00000ooLe=000ol0003og=SBomcHdP02omcHdP03o`000?oLf=Cog=SD00;og=SD
00?o0000omKKg?oFfm`00ooFfm`00ol0003oeMkNomGNgP02omGNgP?o00000oo?g>800ol0003oc]kU
olkNi@02olkNi@?o00000oo;g>H01?l0003oj=c8o`000?l00019ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool03oooool003kooooo00?o0000ooooooooool0HOooool00ol0003oZKgX
ojVmj004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`000003
ojVmj?l0003oZKgX00CoZKgX00Co0000ojVmj?l0003o00000oo^_9h00ol0003ol;bIoo2lV@02oo2l
V@05o`000?ob_IOol[fGoo:mUol000000ooc_YL00ol0003oll2Hoo?0V002oo?0V003o`000?oc`igo
ll>M00;o00000oo`/HT00ol0003okK2>onf`SP03onf`SP03o`000?oY/9OojK2G00;ojK2G00Co0000
oj=lZOl0003o00001OoQc<@00ol0003ohm35on?@a@02on?@a@06o`000?oTe<Koi=C6o`000?oLe=3o
00001?oLf=800ol0003og=SDomcHe003omcHe0;o00000ooFfm`00ol0003oeMkNomGNgP02omGNgP07
o`000?oDg]ooe=kOomCNgol0003ocmcRo`000004olkNi@08o`000?o<g^Koc=kVolcNi_l0003obmcV
o`000?oXg<P2o`0004_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`00
?oooool00ol0003oooooooooo`1Qooooo`03o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj003o`00
0?nY_NSoZKgX00?oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?o^
_9h00_o^_9h00ol0003ol;bIoo2lV@02oo2lV@04o`000?ob_IOol[fGo`0000ColkjG00?o0000oo?0
V?oc`9P00_oc`9P00ol0003oll>Moo?3W@02o`0000?ol;6900?o0000onf`S_o]/8h00_o]/8h00ol0
003ojK2GonV`U`03onV`U`03o`000?nSO:Wo000000;o00000ooQc<@00ol0003ohm35on?@a@02on?@
a@03o`000?oTe<Koi=C600;oi=C60_l00003omcHdP03o`000?oLf=Cog=SD00?og=SD00Ko0000omkN
e_oNg]Ko0000omKKg?l00004omGNgP03o`000?oDg]ooe=kO00;oe=kO0_l00003olkNi@;o00001?o<
g^H3o`000003onSLb?l0003o000004cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`00@?ooool2o`0006;ooooo00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSo
ZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj0Co00000onY_NP2
o`0000?ok[bN00?o0000oo2lVOo`_9T00_o`_9T01?l0003ol[fGoo:mUol00003oo>nU`03o`000?oc
`9Soll2H00;oll2H00?o0000oo?3WOoc`id00_oc`id01Ol0003ol;69oo2aROo`/HWo000000CokK2>
00?o0000onV`UooY/9L00ooY/9L2o`0000?oXH2`00?o0000on7<a?l000001?oSd<D00ol0003oi=C6
onCDaP03onCDaP05o`000?oVfLSo0000omcHd_l000001OoLf=@00ol0003og]kFomkNeP02omkNeP;o
00000ooEg]h00ol0003oe=kOomCNg`02omCNg`06o`000?oChN;odn7Ro`000?o>g^Go00001Oo<g^H0
1?l0003obn3Xol_Pj?o;h>P3o`0004cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`00@_ooool00ol0003oooooooooo`1Pooooo`03o`000?nY_NSoZKgX00CoZKgX00Co0000
ojVmj?nY_NSoZKgX1?l00004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j003ojVmj0;o00000_o^_9h01Ol0003ol;bIoo2lVOo`_9Wo000000?ol[fG00Go0000oo>nUooc_YOo
lkjGo`000004oo?0V003o`000?oc`igoll>M00;oll>M00Go0000oo2aROo`/HWol;69o`000004onf`
SP03o`000?oY/9OojK2G00?ojK2G00?o0000oj60/?nQP;000onQP;000ol0003ohm35on?@a@03on?@
a@03o`000?oTe<Koi=C600;oi=C600Go0000onKIb?oVfLSoi]W8o`000005omcHe003o`000?oNg]Ko
g]kF00;og]kF00Ko0000omgQf?oMhMSo0000omGNg_l00004omCNg`04o`000?oChN;odn7Rom?QhP?o
00000oo<g^H2o`0000Cobn3X0_l0001>ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03_ooool004?ooooo00?o0000ooooooooool0H?ooool00ol0003oZKgXojVmj003ojVmj0Co0000
1?nY_NP00ol0003oZKgXojVmj003o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00004oo2lV@05
o`000?ob_IOol[fGoo:mUol000000ooc_YL00ol0003oll2Hoo?0V002oo?0V007o`000?oc`igoll>M
oo?3WOl0003ol/VUo`000002oo2aR@03o`000?o]/8kokK2>00;okK2>00?o0000onV`UooY/9L00ooY
/9L00ol0003oXH2`oj60/003oj60/0;o00000ooSd<D00ol0003oi=C6onCDaP02onCDaP03o`000?oV
fLSoi]W800;oi]W80_l00003omcHe003o`000?oNg]Kog]kF00;og]kF00?o0000omgQf?oMhMP00_oM
hMP2o`0000?oe=kO00Go0000om?Qh_oChN;odn7Ro`000003om7Si003o`000?o<g^Ko000000Gobn3X
0ol0001?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool004Cooooo00?o
0000ooooooooool0H?ooool00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000oo2lVOo`_9T00_o`
_9T01Ol0003ol[fGoo:mUoob_IOo000000?olkjG00?o0000oo?0V?oc`9P00_oc`9P01ol0003oll>M
oo?3WOoc`igo0000oo;9YOl000000_o`/HT00ol0003okK2>onf`SP02onf`SP03o`000?oY/9OojK2G
00;ojK2G00?o0000onB_W_l000001OnQP;02o`000003on?@aOl0003oi=C600?oi=C600?o0000onKI
b?oVfLP00_oVfLP01_l0003oi]g;onKMbol0003og=SDo`0000Cog]kF00?o0000omgQf?oMhMP00_oM
hMP01_l0003og>CKomcTfol0003oe=kOo`0000?odn7R00?o0000om7Si?oAhn@00_oAhn@3o`0000?o
bn3X0_l000000oo;h>So0000o`00001@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03_ooool004Gooooo00?o0000ooooooooool0H?ooool2o`0000GoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgX
ojVmj003ojVmj0;o00000oo`_9T01?l0003ol[fGoo:mUol00003oo>nU`03o`000?oc`9Soll2H00;o
ll2H00?o0000oo?3WOoc`id00_oc`id00ol0003ol/VUo`000002oo2aR@05o`000?o]/8kokK2>onf`
S_l000001OoY/9L00ol0003oi:nNo`000005oj60/003o`000?l0=kgo000000Goi=C600Go0000onKI
b?oVfLSoi]W8o`000004onKMb`;o00000ooNg]H00ol0003ogN7HomgQf002omgQf004o`000?oLi=_o
g>CKomcTf`;o00000ooChN800ol0003odN?Tom7Si002om7Si007o`000?o?hnKocn?VoloSi_l0003o
bn3Xo`000003ol_Pj0;o0000D?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo0016ooooo`;o0000H_ooool01?l0003oZKgXojVmj?nY_NP3o`0000GoZKgX00Co0000ojVmj?nY
_NSoZKgX1?l00005ojVmj003o`000?nY_NSo000000;o00000_nY_NP01?l0003ol;bIoo2lVOl00002
oo:mU`05o`000?oc_YOolkjGoo>nUol000001?oc`9P01Ol0003oll>Moo?3WOoc`igo000000?ol/VU
0_l00004onf`SP03o`000?oY/9OojK2G00?ojK2G00?o0000onB_W_l000001_nQP;000ol0003o03Nm
o`000003onCDaP05o`000?oVfLSoi]W8onKIb?l000001OoVgL/01Ol0003oiN;?o`000?oNg]Ko0000
00CogN7H00Go0000omcTfooLi=_og>CKo`000002omWVgP03o`000?oChN;o000000CodN?T00?o0000
oloSi_o?hnH00_o?hnH3o`0000;obn3X00?o0000ooCK]?l00000DOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo0018ooooo`03o`000?oooooooooo063ooooo0ol00003ojVm
j003o`000?nY_NSoZKgX00;oZKgX1?l00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001_nY_NP2
o`0000?ol[fG00Go0000oo>nUooc_YOolkjGo`000004oo?0V005o`000?oc`igoll>Moo?3WOl00000
0oobbJD2o`0000CokK2>00?o0000onV`UooY/9L00ooY/9L00ol0003oi:nNo`000006oj60/006o`00
0?l0=kgo03Nmo`000?oTe<Ko00001?oVfLP00ol0003oi]g;onKMb`02onKMb`04o`000?oUh/ooiN;?
onGRc`;o00000ooMhMP01Ol0003og>CKomcTfooLi=_o000000CofNKN0_l00003om7Si003o`000?o?
hnKocn?V00;ocn?V00Ko0000olgSj?o=hnSocN?Xo`000?o;h>P2o`0005?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0=ooooo`00BOooool00ol0003oooooooooo`1Pooooo`03o`00
0?nY_NSoZKgX00?oZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co
00000onY_NP00ol0003oZKgXojVmj003ojVmj0;o00000oob_IL01Ol0003olkjGoo>nUooc_YOo0000
00?oll2H00?o0000oo?3WOoc`id00_oc`id01?l0003ol/VUoo;9YOobbJD2o`0000CokK2>00?o0000
onV`UooY/9L00_oY/9L01Ol0003oi:nNonB_W_oT[iko000000GoXH2`1_l00003onKIb003o`000?oV
gL_oi]g;00;oi]g;00?o0000onGRcooUh/l00_oUh/l01Ol0003oi>GBo`000?oMhMSo000000?og>CK
00?o0000omWVg_oIi]h00_oIi]h01_l0003oenOQomOWhOl0003odN?To`0000Cocn?V00?o0000olgS
j?o=hnP00_o=hnP2o`000003ooCK]?l0003ooooo05?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`00B_ooool00ol0003oooooooooo`1Pooooo`04o`000?nY_NSoZKgXojVm
j0?o00001OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0
003oZKgXo`000002o`0000;oZKgX00Co0000oo:mUoob_IOo00000_oc_YL00ol0003oll2Hoo?0V002
oo?0V005o`000?oc`igoll>Moo?3WOl000001OobbJD00ol0003okK2>onf`SP02onf`SP03o`000?oY
/9OojK2G00;ojK2G00Go0000onB_W_oT[ikoi:nNo`000005oj60/0;o00000_mHNMP3o`000003onKI
b?l0003oi]g;00?oi]g;00?o0000onGRcooUh/l00_oUh/l01?l0003oi>GBonCUd_oTiM83o`000003
omcTfol0003ofNKN00?ofNKN00Co0000omOWhOoGin7oenOQ0ol00003oloSiP03o`000?o=hnSocN?X
00;ocN?X00?o0000ol_Tj_o;i>X00_l0001Dooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool004_ooooo0_l0001Qooooo`?o00000onY_NP01?l0003oZKgXojVmj?nY_NP3o`00
00KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00005ojVmj0;o00000ooc_YL00ol0003oll2Hoo?0V002
oo?0V005o`000?oc`igoll>Moo?3WOl000001OobbJD01Ol0003okK2>onf`S_o]/8ko000000GojK2G
00Go0000onB_W_oT[ikoi:nNo`000005oj60/003o`000?l007?o000000CoF7WH0_l00003onKMb`03
o`000?oUh/ooiN;?00;oiN;?00Go0000onCUd_oTiM;oi>GBo`000003on;Ue@;o00000ooIi]h01Ol0
003oenOQomOWhOoGin7o000000?oe>KS00?o0000oloSi_l000000oo=hnP2o`0000?obnCZ0_l0001E
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool004gooooo00?o0000oooo
ooooool0Goooool00ol0003oZKgXojVmj002ojVmj0Co00000onY_NP00ol0003oZKgXojVmj003ojVm
j0Co00001?nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000?olkjG00?o0000oo?0V?oc`9P00_oc`9P0
1Ol0003oll>Moo?3WOoc`igo000000Col/VU00?o0000onoB]?l000000_o]/8h00ol0003ojK2GonV`
U`03onV`U`05o`000?oT[ikoi:nNonB_W_l000001_nQP;02o`0000KoF7WH00?o0000onKMbol00000
1?oUh/l01Ol0003oi>GBonCUd_oTiM;o000000Coh^GE00Go0000on7Zf?l0003ofNKNo`000003omOW
h@03o`000?oDi^?oe>KS00;oe>KS1?l000000oo=hnSo0000ol_TjP03ol_TjP;o0000Eoooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo001>ooooo`03o`000?oooooooooo05oo
oooo00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00000oooool01?l0003olkjGoo>nUol00003
oo?0V005o`000?oc`igoll>Moo?3WOl000001OobbJD00ol0003okm:do`000002onf`SP03o`000?oY
/9OojK2G00;ojK2G00?o0000onB_W_oT[ih00_oT[ih00ol0003oXH2`oj60/003oj60/0Co00001OmH
NMP3o`0000?oiN;?00Go0000onCUd_oTiM;oi>GBo`000004on;Ue@05o`000?oQj]SohN[Hon7Zf?l0
00000ooGin400ol0003oe>KSomCVh`02omCVh`04o`000?oBj>God^SUom;Xi@;o00000oo;i>X3o`00
05Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`00Coooool00ol0003o
ooooooooo`1Oooooo`03o`000?nY_NSoZKgX00?oZKgX00Co0000ojVmj?nY_NSoZKgX1?l00005ojVm
j003o`000?nY_NSo000000;o00002?ooool2o`0000Coll2H00Go0000oo?3WOoc`igoll>Mo`000004
oo;9Y@04o`000?o_d[Cokm:do`0000;okK2>00?o0000onV`UooY/9L00_oY/9L00ol0003oi:nNonB_
WP03onB_WP03o`000?nQP;3o000000;o000000CoXHFfo`000?l007?o00000_mHNMP3o`0000?oXIkB
00?o0000onGRcol000000ooTiM800ol0003oh^GEon;Ue@02on;Ue@09o`000?oQj]SohN[Hon7Zf?l0
003ogncKo`000?oGin7o000000?oe>KS0_l00003om;Xi@06o`000?o?j>SocnSXo`000?o;i>[o0000
0_o@i>H00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool0053ooooo0_l0001Pooooo`03o`000?nY_NSoZKgX00;oZKgX1?l00004ojVmj004o`000?nY
_NSoZKgXojVmj0?o00003?ooool2o`0000?oll2H00Go0000oo?3WOoc`igoll>Mo`000004oo;9Y@07
o`000?o_d[Cokm:donoB]?l0003okK2>o`000004onV`U`03o`000?oT[ikoi:nN00?oi:nN0_l00004
oj65]PGo00001onQW]83o`000003onCUd_l0003oh^GE00?oh^GE00Go0000on7Zf?oQj]SohN[Ho`00
0003omo/f`?o000000?oe>KSo`000?oBj>D00ooBj>D01?l0003ocnSXoloXj?o?j>P3o`0000;od>CV
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
001Booooo`03o`000?oooooooooo05kooooo00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgX
ojVmj003ojVmj0Co00004Oooool01?l0003oll2Hoo?0V?l00002oo?3W@03o`000?obbJGol/VU00;o
l/VU00?o0000onoB]?o_d[@00_o_d[@2o`0000CojK2G00?o0000onB_W_oT[ih01?oT[ih00ol0003o
XHFfoj65]P04oj65]P?o00001onQW]801?l0003odLG>om75c_oAaLh2o`0000?oh^GE00Go0000on7Z
f?oQj]SohN[Ho`000003omo/f`04o`000?oKkMkofngNom_]gP;o00000ooBj>D01Ol0003ocnSXoloX
j?o?j>So000000?oc>OZ0ol0001Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3?ooool005?ooooo00?o0000ooooooooool0G_ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSo000000;o00005_ooool2o`0000?oll>M00?o0000oo;9YOobbJD00_obbJD00ol0003okm:donoB
]002onoB]0;o00001?oY/9L00ol0003oi:nNonB_WP04onB_WP03o`000?nQQKKoXHFf00CoXHFf1?l0
0005oj6NdP03o`000?oAaLkodLG>00;odLG>00Go0000ong[bOl0003oh^GEo`000003on7Zf005o`00
0?oOk=_ogncKomo/fol000000ooKkMh01_l0003oencRomO/h_l0003od^SUo`0000?ocnSX00?o0000
olcWj_o<inX00_o<inX3o`0005_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`00E?ooool00ol0003oooooooooo`1Nooooo`04o`000?nY_NSoZKgXojVmj0?o00006_ooool2
o`0000;oll>M00Go0000oo;9YOobbJGol/VUo`000005onoB]0;o00001?oY/9L00ol0003oi:nNonB_
WP03onB_WP03o`000?oV^:Go000000GoXHFf1?l00004oj6NdP03o`000?oAaLkodLG>00;odLG>00Co
0000ong[bOo]jlWokN_90ol000000ooQj]So0000omo/f`02omo/f`05o`000?oKkMkofngNom_]g_l0
00000ooGk>84o`000003oloXj?l0003oc>OZ00;oc>OZ0ol000000oofh;?o0000ooooo`1Kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool005Gooooo0_l0001Oooooo`?o0000
7oooool2o`0000Col/VU00?o0000onoB]?o_d[@00_o_d[@00ol0003ogN;Ho`000004onV`U`03o`00
0?oT[ikoi:nN00?oi:nN00?o0000onJhYOl000001_nQQKH4o`0000;oXIkB00?o0000om75c_oAaLh0
0_oAaLh00ol0003okN_9ong[b@02ong[b@03o`000?oYkloojNo?00?o000000?ogncKo`000?oKkMh0
0_oKkMh01Ol0003oencRomO/h_oGk>;o000000?oeNgU0ol000000oo<in[o0000o`000002olWWk0;o
0000G_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo001Gooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool08?ooool2o`0000;ol/VU00?o0000onoB]?o_d[@0
0_o_d[@01Ol0003ogN;HomgRf?oMh]So000000;ojK2G00?o0000onB_W_oT[ih01?oT[ih00ol0003o
i[RUo`000006oj65]PCo000000?oXIkBo`000?oAaLh00ooAaLh00ol0003okN_9ong[b@02ong[b@05
o`000?oYkloojNo?onW_col000000_oUlM@3o`000004om_]g_l0003oencRomO/hP;o00000ooEkND0
1?l0003odNgWom7]iooAkNL2o`0000;obNO/00?o0000ooKP/ol00000Goooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo001Hooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool08_ooool00ol0003ol/VUo`000003onoB]003o`000?oMh]SogN;H00;ogN;H00Co0000
onV`UooY/9Oo00001OoT[ih01Ol0003oi[RUonJhYOoV^:Go000000GoXHFf00Go0000o`02T?l0003o
33>co`000005om75cP05o`000?o]jlWokN_9ong[bOl000000ooYkll01?l0003oiO7DonGae?l00003
on;_f@;o000000?oencRo`000?oEkND00_oEkND2o`0000?odNgW00So0000olg[j_o=jn[o0000olWW
k?l0003om^2co`0005oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`00
FOooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02?ooooo0ol000000oo_d[Co0000
omgRf005omgRf003o`000?oY/9Oo000000Goi:nN00Go0000onJhYOoV^:Goi[RUo`000005oj65]P06
o`000?l00Y3o0000o`000?l<<k?o00000ooAaLh01Ol0003okN_9ong[bOo]jlWo000000?ojNo?00Co
0000onGae?oUlMCo00000ooRkmT00ol0003ogo;Komobf`03o`000003omG]iOl0003odNgW00?odNgW
00Co0000olg[j_o=jn[ocN_Z1Ol0001Pooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool005[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Vooooo`;o0000
1_oMh]P00ol0003ojK2Go`000005onB_WP05o`000?oV^:Goi[RUonJhYOl000001_nQQKH00ol0003o
00:@o`000002o``c/`03o`000?oAaLko000000?okN_900Go0000onW_cooYkloojNo?o`000002onGa
e005o`000?oRkmWoh^oIon;_fOl000000ooOl]/00ol0003of_?Po`000002o`0000?odNgW00Go0000
olg[j_o=jn[ocN_Zo`000002ol_[k003o`000?oooooooooo067ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`00Foooool2o`0005Wooooo00?o0000ooooooooool0:?ooool2
o`0000CogN;H0_l00005onB_WP03o`000?oV^:Goi[RU00;oi[RU00?o0000oj65]_nQQKH00onQQKH2
o`000003o`02T?l0003o33>c00;o33>c0ol000000oo]jlWo0000onW_c`02onW_c`04o`000?oUlMCo
iO7Do`0000?oh^oI00Oo0000omobfooOl]_ogo;Ko`000?oJln3o000000?oe_7T00?o0000om7]iol0
00000_o=jnX2o`0000;obn_/0_l0001Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool005gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Zooooo`Ko0000
1OoT[ih00ol0003oi[RUonJhY@03onJhY@03o`000?nQQKKo000000;o000000CoXXZko`000?l00Y3o
00:@2Ol000001OoYkloo0000onGae?oUlMCo000000?oh^oI00Oo0000omobfooOl]_ogo;Ko`000?oJ
ln3o000000Coe_7T0ol000000oo=jn[o0000ol_[k002ol_[k0;o0000IOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo001Nooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0;Oooool00ol0003oDKcjo`000005onB_WP03o`000?oV^:Goi[RU00?oi[RU0_l00005
oj::^`03o`000?l00Y3o000000SoT8[91_l000000ooRkmWo0000omobf`02omobf`03o`000?oJln3o
000000Coe_7T00?o0000om?ai_oClNH01?l000001?o;jnco0000om?bi_l0001Vooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool005oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?mA_?[o000000Coi:nN00?o0000onJhYOoV^:D00ooV^:D0
0ol0003oXXZkoj::^`04oj::^`;o000000?o00:@o`000?n@R/T01_n@R/T01?l0003oiNKAonGVdOl0
0002on_fb@?o000000Cogo;Ko`000?oJln3o00000ooFlN@2o`0000;odo7V00Co0000olk`j_o>l>[o
c_3Z1Ol0001Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0063ooooo
0_l0001Dooooo`03o`000?oooooooooo02oooooo0_l00003onB_WP03o`000?oV^:Goi[RU00?oi[RU
00?o0000ooOR/_l000001OnRR[/2o`000003o`02T?l0003oT8[900GoT8[900Co0000onGVdOoUi]7o
00000oo[m/T00ol0003oiOSBonGhdP05o`000003omKai?l0003odo7V00;odo7V00Go0000olk`j_o>
l>[oc_3Zo`000003ol_]k0;o0000Ioooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00_ooooo001Rooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0<?ooool2o`0000;o
i:nN00?o0000onJhYOoV^:D00ooV^:D00ol0003omn:bo`000006oj::^`?o00001On@R/T01?l0003o
iNKAonGVdOl00003on_fb@04o`000?oUn=;oiOSBo`0000;ohOKI00?o0000omghg?l000000ol00000
1?oClNKo0000olk`j_o>l>X2o`0000?obng/00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo001Sooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0<Oooool2o`000003onB_W_l0003oi[RU00Coi[RU00?o0000ooOR/_l000001_nRR[/0
1?l0003o1BJXo`000?l00003oi2:b@04o`000?oUi]7oiNKAo`0000?ojoK900Co0000onGhd_oUn=;o
00000_oQm]T00ol0003ogOSLo`000003omOfhP?o000000?oc_3Zo`000?o;kN`00_o;kN`2o`0006co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`00I?ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo03;ooooo0_l00005onJhY@05o`000?ogh[;omn:booOR/_l0
00001OnRR[/01?l0003o1BJXo`000?l00002oi2:b@05o`000?oUi]7oiNKAonGVdOl000000_o[m/T0
1?l0003oiOSBonGhd_l00002on7ff@03o`000?oMn=co000000?oeoKR00?o0000om?eiOoCmND01?l0
00001?o;kNco0000olo`jOl0001]ooooo`05o`000?ooooooooooooooool000003?ooool006Gooooo
0_l0001?ooooo`03o`000?oooooooooo03;ooooo0_l00005onJhY@05o`000?ogh[;omn:booOR/_l0
00001_nRR[/01Ol0003o1BJXo`000?n@R/Wo000000?oiNKA00Co0000on_fbOo[m/Wo00000_oUn=80
1_l0003ohOKIon7ffOl0003ogOSLo`0000?oeoKR00Co0000om?eiOoCmNGo00000oo?lnT5o`0006go
oooo00Go0000ooooooooooooooooo`00000<ooooo`00Ioooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo03?ooooo00?o0000onJhYOoV^:D00_oV^:D00ol0003omn:booOR/P02ooOR/P03
o`000?nRR[_oXXZk00?oXXZk1ol000001OoUi]7o0000on_fbOo[m/Wo000000;oiOSB00Ko0000on7f
fOoQm]Wo0000omghg?l00003omOfhP04o`000?oCmNGodoGUo`0000?oco?Y00Co0000ol_`k?o;l>co
bo3/0_l0001^ooooo`04o`000?ooooooooooo`0000cooooo001Xooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0<oooool2o`0000?oi[RU00?o0000ooOR/_ogh[800oogh[800ol0003o
XXZko`000002o`000003ojBC`ol0003oQh7500;oQh754?l000001OoGm^;o0000om?eiOoCmNGo0000
00?oco?Y00Go0000ol_`k?o;l>cobo3/o`00001aooooo`03o`000?oooooo000000cooooo001Yoooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0=?ooool01?l0003oi[RUonJhYOl00005
ooOR/P?o00001OnTTl<00ol0003oQh75ohN1a@05ohN1a@05o`000?oVo<?o0000on3mc?l000000_oK
o=T00ol0003oe_cLomKlg007o`000004olocjOl0003obo3/ol_`k0?o0000LOooool00ol0003ooooo
o`00000<ooooo`00J_ooool2o`0004[ooooo00?o0000ooooooooool0=Oooool00ol0003oi[RUo`00
0002ooOR/P?o000000?oR>cXo`000?nTTl<01OnTTl<00ol0003oQh75ohN1a@04ohN1a@05o`000?oV
o<?o0000on3mc?l000000_oKo=T01?l0003oe_cLomKlg?l00002om3kh`04o`000?o<mnSoc?OXolcg
j0?o000000Cobo3/o`000?o;knco0000Loooool00ol0003oooooo`00000;ooooo`00K?ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03Gooooo00?o0000onJhYOl000001Ol00002ohS/
j003o`000?nTTl?oY9?300?oY9?300?o0000ohN1aOn7PLD00on7PLD01Ol0003oi_c3o`000?oPoLco
000000;ofocI00Go0000omKlg?oFo=co0000om3kh`02o`0000?oc?OX00?o0000olWfjoo9m^/01Ol0
001dooooo`;o00002oooool006gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0g
ooooo`;o00001Oooool00ol0003oR>cXo`000006ojBC``09o`000?n7PLGoQh75ohN1aOl0003oi_c3
o`000?oPoLco000000;ofocI00Ko0000omKlg?oFo=co0000om3khol00003olcgj0;o000000?obOK[
o`000?l000000oo5l^l2o`0007?ooooo0ol0000;ooooo`00K_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo03oooooo00?o0000ohS/j?l000001OnTTl<01Ol0003oQh75ohN1aOl0003o
i_c300go000000Goc?OXo`000?o9m^_obOK[o`000003olGbk`;o0000LOooool4o`0000kooooo001_
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0@?ooool2o`0000GoY9?300?o0000
ohN1aOl000002ol000000omdg_;o0000o`000006o`000004olGbkol0003o0000o`0006kooooo1?l0
000Booooo`00L?ooool2o`0004?ooooo00?o0000ooooooooool0@Oooool2o`0000CoY9?33ol00002
og[PmP?o000000?oPn7jo`000?l000001?l0001[ooooo`?o00005_ooool007;ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`12ooooo`03o`000?nTTl?o000000;o00003Oooool8o`00
00;oN^3e1?l0001Wooooo`Co00006Oooool007?ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo01Gooooo0ol0001Wooooo`Co00007Oooool007Cooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`31ooooo`Co00008Oooool007Gooooo0_l0
000nooooo`03o`000?oooooooooo0;gooooo1?l0000Uooooo`00Moooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;Wooooo1?l0000Yooooo`00N?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo0;Kooooo0ol0000]ooooo`00NOooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo0;;ooooo1?l0000`ooooo`00N_ooool2o`0003Wooooo00?o0000ooooooooool0
[_ooool4o`0003Cooooo001looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Z_oo
ool4o`0003Sooooo001mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Y_ooool4
o`0003cooooo001nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4o`00
043ooooo001oooooo`;o0000=?ooool00ol0003oooooooooo`2Oooooo`?o0000A?ooool0087ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Kooooo`Co0000Aoooool008;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`2Gooooo`Co0000Boooool008?ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`Co0000Coooool008Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`2?ooooo`Co0000Doooool008Gooooo0_l0000^ooooo`03
o`000?oooooooooo08cooooo0ol0001Gooooo`00Qoooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo08Sooooo1?l0001Jooooo`00R?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo08Cooooo1?l0001Nooooo`00ROooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo083ooooo1?l0001Rooooo`00R_ooool2o`0002Wooooo00?o0000ooooooooool0O?ooool4o`00
06Kooooo002<ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0006[o
oooo002=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0MOooool3o`0006kooooo
002>ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool4o`00077ooooo002?
ooooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000MOooool0097ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000NOooool009;ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1Uooooo`Co0000OOooool009?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`1Qooooo`Co0000POooool009Cooooo0_l0000Oooooo`03o`000?oo
oooooooo05kooooo0ol00025ooooo`00U_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo05[ooooo1?l00028ooooo`00Uoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
05Kooooo1?l0002<ooooo`00V?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;o
oooo1?l0002@ooooo`00VOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo
1?l0002Dooooo`00V_ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0009Sooooo002L
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool3o`0009cooooo002Moooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0A?ooool4o`0009oooooo002Nooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0@?ooool4o`000:?ooooo002Oooooo`;o0000
4oooool00ol0003oooooooooo`0looooo`Co0000Yoooool00:7ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0hooooo`Co0000Zoooool00:;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0dooooo`Co0000[oooool00:?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0aooooo`?o0000/oooool00:Cooooo0_l0000>ooooo`03o`000?oooooooooo02go
oooo1?l0002fooooo`00Y_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo
1?l0002jooooo`00Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0
002nooooo`00Z?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l00032
ooooo`00ZOooool2o`0000Wooooo00?o0000ooooooooool07_ooool3o`000<Kooooo002[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool4o`000<Wooooo002/ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000<gooooo002]ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000=7ooooo002^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool4o`000=Gooooo002_ooooo`;o00000oooool00ol0
003oooooooooo`0:ooooo`Co0000fOooool00;7ooooo00Co0000oooooooooooo00002Oooool3o`00
0=gooooo002booooo`03o`000?oooooo000000Gooooo1?l0003Pooooo`00/oooool2o`000003oooo
ool0003o000000;o0000i?ooool00;Cooooo0_l0003Xooooo`00oooooonOooooo`00oooooonOoooo
o`00oooooonOooooo`00oooooonOooooo`00oooooonOooooo`00boooool3o`000=3ooooo003<oooo
o`03o`000?oooooooooo01Wooooo00Co410@o`000?l0003o0000/_ooool00<Gooooo0ol00002oooo
o`?o00002?ooool00omgMgOoIVIVooooo`09ooooo`03o`000?nj^[[ooooo00Gooooo00?o0000oooo
ooooool00oooool00omVIVKoMgMgooooo`2/ooooo`00a?ooool2o`0000?ooooo00Co0000oooooooo
oooo00001oooool00ooMgMgo410@onk^kP0:ooooo`;o<S8b1_ooool00ol0003oooooooooo`03oooo
o`03onk^k_l@413ogMgM0:cooooo002nooooo`03oa0@4?l0003o000000;o000000?o410@o`000?oo
ool00_l000001Ooooooo0000oooooooooooo000000Oooooo00?oEEEEoiRHV?ooool00_ooool2o`00
00;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00Wo0000ogMgMol0003o0000oeEEEOo^
k^koooooohN7QomVIVH0[?ooool00<3ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0ol0
0007ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03
olc<c?l0003o410@00Gooooo00Wo0000oeEEEOo^k^koooooogMgMomEEEGoooooonk^k_l00000[?oo
ool00<3ooooo00?o0000ooooooooool04Oooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o
410@olc<c0_ooooo00?o0000onk^k_ooool00_ooool01?l0003oooooooooool0002/ooooo`00`?oo
ool00ol0003oooooooooo`0Aooooo`03oc8b<_oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^
2oooool00ol0003ok^k^ooooo`02ooooo`04o`000?ooooooooooo`000:cooooo0030ooooo`03o`00
0?oooooooooo017ooooo00?o0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`09
o`000?mEEEGok^k^oooooomgMgOoIVIVooooooo^k^ko00000:cooooo002nooooo`03oa0@4?l0003o
000000?o00004?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000Wooooo00?o410@
o`000?mgMgL00_l000001OmVIVKok^k^oooooomgMgOoEEEE0:cooooo0030ooooo`03o`000?oooooo
oooo017ooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2/ooooo`00`?ooool00ol@
413o^[Zjooooo`0Booooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0[?ooool00<3o
oooo00Co^[Zjoa0@4?l0003o410@f_ooool00?ooooooWoooool00?ooooooWoooool00001\
\>"],
  ImageRangeCache->{{{0, 413.188}, {335, 0}} -> {-0.0868418, 0.0251932, \
0.00323112, 0.00323112}}]
}, Open  ]],

Cell[TextData[{
  "Note the hole in the distribution near the origin, which is also clearly \
visible in the previous animation of the particle positions, Cell ",
  ButtonBox["7.7",
    ButtonData:>"Cell 7.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tIt is interesting that this gas comes to an equilibrium at all, because \
we have not included interactions between the particles that would be needed \
to drive this system to a ",
  StyleBox["thermal",
    FontSlant->"Italic"],
  " equilibrium state.   The equilibrium achieved here is a ",
  StyleBox["partial",
    FontSlant->"Italic"],
  " equilibrium due to phase-mixing alone. Thermal equilibrium corresponds to \
a particular form for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_eq\)(E)\)\(:\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_eq\)(E)\  = \ 
        C\ \[ExponentialE]\^\(\(-E\)/k\_B  T\)\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is the temperature, ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is a constant, and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\)]],
  "is Boltzmann's constant. We will have more to say concerning thermal \
equilibrium in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:11"],

Cell["\<\
\tAnother view of the equilibration process considers only the \
particle positions. In this view,  we extract the positions, neglecting \
momenta:\
\>", "Text"],

Cell[BoxData[
    \(pos[t1_]\  := \ \((a\  = \ particlepos[t1]; \ 
        Table[a[\([n, 1]\)], {n, 1, M}])\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.18"],

Cell[TextData[{
  "Then we plot the particle positions in Cell ",
  ButtonBox["7.19",
    ButtonData:>"Cell 7.19",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(Table[
        ListPlot[pos[t1], PlotRange \[Rule] {\(-1\), 1}], {t1, 0, 
          50,  .4}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.19"],

Cell[TextData[{
  "\tThe phase mixing should be quite clear in this animation. After a few \
bounces, the gas  approaches  equilibrium. The evolution toward equilibrium \
can be seen more directly by evaluating the particle density ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, t)\)]],
  ". It is the integral over the momenta of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ": "
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n(x, 
          t)\  = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(x, p, 
              t)\) \[DifferentialD]p\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.28)"],

Cell[TextData[{
  "\tWe can use the data  generated above to approximately determine ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, t)\)]],
  " for this evolution. The number of particles in the range ",
  Cell[BoxData[
      \(TraditionalForm\`x - \ x + \[DifferentialD]x\)]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`\(n(x, t)\)\ \[DifferentialD]x\)]],
  ". Therefore, we can determine ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, t)\)]],
  " by counting particles that fall in small boxes of size ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]x\)]],
  ". If, at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", the number of particles in the range ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "-", " ", "x", "+", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, t)\)]],
  ", then "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n(x, t) = \(H(x, t)\)/\[CapitalDelta]x\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "This binning can be accomplished using the ",
  StyleBox["Histogram",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " plotting function, available in the graphics add-on  packages:"
}], "Text",
  CellTags->"i:13"],

Cell[BoxData[
    \(<< Graphics`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.20"],

Cell[TextData[{
  StyleBox["Histogram",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes as its primary argument a list of data values that it bins into \
given categories. The ",
  StyleBox["HistogramCategories",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to determined location and size of the bins. Here the bins \
are all of size 0.1, and run from -1 to 1.  We use the ",
  StyleBox["Show ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function in order to actually display the histograms, because this allows \
us more flexibility in choosing the plot range and the axis origin (see Cell \
",
  ButtonBox["7.21",
    ButtonData:>"Cell 7.21",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[BoxData[{
    \(\(\(H[
          t_] := \ \((plt\  = \ 
            Histogram[pos[t], 
              HistogramCategories \[Rule] Table[x, {x, \(-1\), 1,  .1}], 
              DisplayFunction \[Rule] Identity]; 
          Show[plt, PlotRange \[Rule] {{\(-1\), 1}, {0, 300}}, 
            DisplayFunction \[Rule] $DisplayFunction, 
            AxesLabel \[Rule] {"\<x\>", "\<H[x,t]\>"}, 
            AxesOrigin \[Rule] {0, 0}])\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(hist\  = \ Table[H[t], {t, 0, 50,  .4}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.21"],

Cell[TextData[{
  "This method of solving the Boltzmann equation, by following a large \
collection of particles, is called a",
  StyleBox[" particle simulation",
    FontSlant->"Italic"],
  ".  The fluctuations that we see in the density at late times  are due to \
the finite number of particles used in the simulation. We will discuss other \
particle simulation methods in Sec. ",
  ButtonBox["7.3",
    ButtonData:>"c:27",
    ButtonStyle->"Hyperlink"],
  " and in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can also determine the expected equilibrium form of the density using \
Eq. ",
  ButtonBox["(7.1.26)",
    ButtonData:>{"Chapter7.nb", "(7.1.26)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.27)",
    ButtonData:>{"Chapter7.nb", "(7.1.27)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[BoxData[
    \(neq[x_]\  := \ 
      NIntegrate[feq[x, p], {p, \(-2\), 2}, 
        MaxRecursion \[Rule] 25]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.22"],

Cell[TextData[{
  "In Fig. ",
  ButtonBox["7.3",
    ButtonData:>"Fig. 7.3",
    ButtonStyle->"Hyperlink"],
  " we plot the density multiplied by the bin size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", so that we can compare it with the histogram function ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, t)\)]],
  " evaluated at the last time step. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
F
0 g
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
F
0 g
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
F
0 g
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
0 0 m
.0125 0 L
.025 0 L
.0375 0 L
.05 0 L
.0625 0 L
.075 0 L
.0875 0 L
.1 0 L
.1125 0 L
.125 0 L
.1375 0 L
.15 0 L
.1625 0 L
.175 0 L
.1875 0 L
.2 0 L
.2125 0 L
.225 0 L
.2375 0 L
.25 0 L
.2625 0 L
.275 0 L
.2875 0 L
.3 0 L
.3125 0 L
.325 0 L
.3375 0 L
.35 .00218 L
.3625 .04932 L
.375 .08932 L
.3875 .11824 L
.4 .14361 L
.4125 .1671 L
.425 .17855 L
.4375 .17529 L
.45 .15397 L
.4625 .14066 L
.475 .13761 L
.4875 .14066 L
.5 .15397 L
.5125 .17366 L
.525 .17841 L
.5375 .17855 L
.55 .17555 L
.5625 .16941 L
.575 .16035 L
.5875 .15176 L
.6 .14361 L
.6125 .13562 L
Mistroke
.625 .12781 L
.6375 .12014 L
.65 .11256 L
.6625 .10493 L
.675 .09721 L
.6875 .08932 L
.7 .08116 L
.7125 .07252 L
.725 .06314 L
.7375 .0524 L
.75 .03838 L
.7625 .02185 L
.775 .01286 L
.7875 .00651 L
.8 .00218 L
.8125 1e-05 L
.825 0 L
.8375 0 L
.85 0 L
.8625 0 L
.875 0 L
.8875 0 L
.9 0 L
.9125 0 L
.925 0 L
.9375 0 L
.95 0 L
.9625 0 L
.975 0 L
.9875 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00002Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0G?ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A402?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@1Looooo`00O?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00002?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00001Looooo`00
Q?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h08oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h02Oooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo00002Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@1Looooo`00Q?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool08_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00002Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c01Looooo`00
Q?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool08Oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool01oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l000002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool0G_ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV01Nooooo`00Q?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@45cooooo003oooooofWooooo003oooooofWooooo003ooooo
od[ooooo0_l00002ooooo`;o00006Oooool00?ooooooB_ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMgAWooooo003ooooood_ooooo00CogMgMo`000?l@413oc<c<6_ooool001Coooooool0000/o`00
00_ooooo00Cok^k^ob4Q8Ol@413ok^k^6_ooool007cooooo00?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000_oo`000ol00016ooooo`04ob4Q8OmgMgOoMgMg
oc8b<Q[ooooo001looooo`03o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool00008ool000?o000000?oo`00o`000?ooool0AOooool2o`0000;ooooo0_l0000Ioooo
o`00O?ooool00ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00001_oo0002o`0000Coo`0000?o0000ooooooooool0Hoooool007cooooo0_l0000=ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`004?l0001Uooooo`00O?ooool2o`0000goo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo
00000ol0003oooooooooo`03ooooo`03o`000?oooooooooo06cooooo001looooo`;o00003Ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0KOooool0
07cooooo00?o0000ool00?l000003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00005o`000?oooooooooo
ooooool00000L?ooool007cooooo00?o0000ool00?l000003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool0
0005o`000?ooooooooooooooool00000L?ooool007cooooo00?o0000ool00?l000003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00004o`000?ooooooooooo`00077ooooo001looooo`03o`000?oo003o0000
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00002ooo00000ol0003oooooo`00001booooo`00O?ooool01?l0003o
o`00ool00?l0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`000_l0001cooooo`00O?ooool01?l0003o
o`00ool00?l0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ooooooooool0L_ooool007co
oooo00Co0000ool00?oo003o00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oooooooooo
07;ooooo001looooo`05o`000?oo003oo`00ool00?l000002_oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000:ool0
00;o0000M?ooool007cooooo00Go0000ool00?oo003oo`00o`00000:ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00Woo`0000?o0000ool00?l00000M?ooool007cooooo00Go0000ool00?oo003oo`00o`00000:ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000Ooo`000_l00002ool00003o`000?oooooooooo07;ooooo001looooo`03
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo000?o`0007Cooooo001looooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00001ooo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07Sooooo001looooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo
00000ol0003oooooooooo`03ooooo`;o0000Noooool007cooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00006ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000<ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool0
07cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00006ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00005o`000?oooooooooo
ooooool00000O_ooool007cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00006ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0004o`000?oooooo0000o`0007oooooo001looooo`03o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00001Ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool0
0?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool0
0?oo00003?oo0002o`00087ooooo001looooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001Ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00002ooo0002o`0008;ooooo001looooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
1Ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
2_oo00000ol0003oo`00o`000022ooooo`00O?ooool00ol0003oo`00ool00005ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0013o0000P_oo
ool007cooooo00?o0000ool00?oo00001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oooooooooo`07ooooo`;o0000Q_ooool0
07cooooo4?l0000>ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ooooooooool01Oooool2o`00
08Sooooo0025ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000<ool00003o`000?oooooooooo00?ooooo0_l0002:ooooo`00QOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00001?l0003ooooo
ooooooooool2o`0008cooooo0026ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000<ool00004o`000?ooooooooooo`0008kooooo0026ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oooooo000008oooooo0027ooooo`05o`000?ooooooooooooooool000003_oo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool000;o0000T?ooool008Oooooo00Go0000ooooooooooooooooo`00000>ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`000_l0002Aooooo`00R?ooool01?l0003oooooooooool0000>ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000Woo`000_l000000ooo003o0000ooooo`2@ooooo`00R?ooool01?l0003ooooooooo
ool0000>ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000Ooo`000_l00003ool00003o`000?oooooooooo08oooooo
0029ooooo`03o`000?oooooo000000koo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00001Ooo0002o`0000Goo`0000?o
0000ooooooooool0Soooool008Wooooo00?o0000ooooool000003_oo00000ol0003oo`00ool0000<
ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo000@o`00097ooooo0029oooo
o`03o`000?oooooo000000koo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2Ioooo
o`00R_ooool2o`0000koo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000coo`0000?o0000ooooooooool00_l0002Looooo`00R_ooool2o`0000koo`00
00?o0000ool00?oo00000ooo0005o`0000Coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool00003o`000?oooooo000009kooooo002:ooooo`;o00003_oo00001?l0003oo`00ool0
0?oo0002o`0000Goo`0000Go0000ool00?oo003oo`00o`00000>ool00003o`000?oo003oo`0000co
o`000_l0002Oooooo`00Roooool00ol0003oo`00ool0000<ool00004o`000?oo003oo`00o`0000So
o`0000Co0000ool00?oo003o00003_oo00000ol0003oo`00ool0000;ool000;o0000X?ooool008_o
oooo00?o0000ool00?oo00003?oo000@o`0000koo`0000?o0000ool00?oo00002Ooo0002o`000003
ool00?l0003ooooo09oooooo002;ooooo`;o00003Ooo0002o`0000cooooo0_l0000>ool00003o`00
0?oo003oo`0000Ooo`000_l00003ool00003o`000?oooooooooo09kooooo002;oooooa3o00003_oo
ool00ol0003oo`00ool0000<ool00003o`000?oo003oo`0000Koo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Nooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00cooooo00?o0000ool00?oo00003?oo00000ol0003oo`00ool00005ool00003o`000?oo003o
o`0000Coo`0000?o0000ooooooooool0W_ooool008kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`;o00003Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Goo`0000?o0000ooooooooool0W_ooool008kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oo003o000000coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00006ool00003o`000?oooooooooo09kooooo002?ooooo`;o00001oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oo003o000000coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00007ool00003o`000?oooooooooo09kooooo002Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03oooool01?l0003oo`00ool00?l0000;ool0013o0000X?ooool009;ooooo00?o
0000ooooooooool00_l0000Booooo`04o`000?oo003oo`00ool000?o00001_oo0004o`000:kooooo
002Cooooo`;o00005?ooool@o`000:oooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool008oooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0_?ooool0097ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;cooooo002Aoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool3o`000;cooooo002Aooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2looooo`00TOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0_?ooool0097ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo0;cooooo002Aooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`2looooo`00Soooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Soooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo0;cooooo002Aooooo`03o`000?oooooooooo00Kooooo00WoMgMg
oc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00
TOooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool01?ooool3o`000;cooooo002Aooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0_?ooool0097ooooo
00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;cooooo002Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0_?ooool0097ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00Soooool00omEEEGo
IVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00S_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2looooo`00
S_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00Soooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
_?ooool0097ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;cooooo002Booooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool00ol0003oooooooooo`2looooo`00S_ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`2looooo`00S_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002>oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo0;cooooo002>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
0;cooooo002?ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`04ooooo`?o0000_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2loooo
o`00TOooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001_ooool0
0ol0003oooooooooo`2looooo`00S_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0_?oo
ool008kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00S_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`2looooo`00S_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00
T_ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Cooooo0ol0002looooo`00TOooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Gooooo002@oooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000aOooool0097ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4035ooooo`00S_ooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0aOooool008kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Nooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o0000[?ooool009kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000
ooooooooool0Z_ooool009?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`2Zooooo`00U?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000ooooooooool0Z_ooool009Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0:[ooooo002Dooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2Zooooo`00U?ooool5o`0000Gooooo00?o0000ooooooooool00oooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z_oo
ool009Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool0Z_oo
ool009Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00Toooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00;ooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0
002/ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.13909, -24.4154, \
0.00839893, 2.03847}}],

Cell[TextData[{
  "Fig. 7.3 Equilibrium density of particles vs. height ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ": theory (line) and simulation (histogram)."
}], "Caption",
  CellTags->"Fig. 7.3"],

Cell["\<\
The theoretical equilibrium density matches the late-time density \
found in the particle simulation. Note that this density, with a dip near the \
origin,  is far from what one might expect intuitively in an equilibrium gas. \
This is because we are used to thinking of thermal equilibrium states. The \
equilibrium shown above is a partial equilibrium caused by collisionless \
phase mixing of the initial condition. It is what one would see before \
collisions between particles have a chance of acting. In many systems, the \
collisions act so rapidly that partial equilibrium is not observed. However, \
in other systems, collisions occur rarely so that partial equilibrium is \
easily seen.  For instance, a gas can enter this collisionless regime if the \
density is sufficiently low so that atom-atom collisions can be ignored over \
the time range of interest.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.1.3 Nonlinear Waves", "Subsubtitle",
  CellTags->{"i:14", "c:10"}],

Cell[CellGroupData[{

Cell["A First-Order Nonlinear Wave Equation", "Section",
  CellTags->"c:11"],

Cell["\<\
\tWe now consider a nonlinear PDE that describes the evolution of \
shallow-water waves with small but finite amplitude:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z\/\[PartialD]t + \(\(c\_o\)(
              1 + \(3\/2\) z\/h)\) \[PartialD]z\/\[PartialD]x = 0\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.29)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  " is the wave height,  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o = \@\(g\ h\)\)]],
  " is the linear wave speed, ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is the acceleration of gravity, and ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is the equilibrium depth of the water [see Eq. ",
  ButtonBox["(3.1.79)",
    ButtonData:>{"Chapter3.nb", "(3.1.79)"},
    ButtonStyle->"Hyperlink"],
  " ]. The term ",
  Cell[BoxData[
      \(TraditionalForm\`3  z\ c\_o/2\ h\)]],
  " is the lowest-order nonlinear correction to the wave speed  due to finite \
wave height [see ",
  ButtonBox["Whitham (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " for a derivation of this correction]. Simply put, a wave peak increases \
the water depth, resulting in a local increase in wave speed. Without this \
term, solutions merely propagate to the right with speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  ", describing linear shallow water waves [see Eq. ",
  ButtonBox["(7.1.14)",
    ButtonData:>{"Chapter7.nb", "(7.1.14)"},
    ButtonStyle->"Hyperlink"],
  " ]. Equation ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  " neglects dispersion and viscous effects, and allows propagation in only \
one direction. Nevertheless,  its solutions  have much to tell us concerning \
the behavior of real finite-amplitude water waves. "
}], "Text",
  CellTags->"i:17"],

Cell[TextData[{
  "\tWe will first put the equation in a standard format.  This is \
accomplished by making a Galilean transformation to a moving frame, moving at \
speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  ", via the change of variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_ = x - \ \(\(c\_o\) \(t\)\(\ \)\)\)]],
  ". In this frame  Eq. ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z\/\[PartialD]t + \(3\/2\) \(c\_o\) \
\(z\/h\) \[PartialD]z\/\[PartialD]x\&_ = 0\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Next, we scale the wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", defining ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\&_, t) = 3\ c\_o\ z/\((2\ h)\)\)]],
  ".  Using these scaled variables, and dropping the overbar on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for notational convenience, we arrive at "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          f \[PartialD]f\/\[PartialD]x = 0\)]],
  ". "
}], "NumberedEquation",
  CellTags->{"i:85", "(7.1.30)"}],

Cell[TextData[{
  "The simple form of the nonlinearity in Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  appears in many other physical contexts, making the equation a \
paradigmatic nonlinear PDE. It is sometimes referred to as Burgers' equation \
without diffusion. The version with diffusion is discussed in Sec. ",
  ButtonBox["7.2.4",
    ButtonData:>"c:23",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Section",
  CellTags->"c:12"],

Cell[TextData[{
  "\tUsing the method of characteristics we can obtain a complete analytic \
solution to Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " . (This is one of a mere handful of nonlinear PDEs where such a complete \
analytic solution is possible.) \tThe characteristics for Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  are solutions to the equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ 
        f(x, t)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.31)"],

Cell[TextData[{
  "Thus, the velocity along the characteristic ",
  StyleBox["depends on the amplitude of the solution along the \
characteristic",
    FontSlant->"Italic"],
  ". However, this is not as complicated as it sounds, because Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  implies that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\  = \ 0\)]],
  " along the characteristics."
}], "NumberedEquation",
  CellTags->"(7.1.32)"],

Cell[TextData[{
  "Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`f = constant\)]],
  " along each characteristic, retaining its initial value:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x(t, x\_o), t)\  = \ \(f\_o\)(x\_o)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.33)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x) = f(x, 0)\)]],
  ".  Therefore, we can integrate Eq. ",
  ButtonBox["(7.1.31)",
    ButtonData:>{"Chapter7.nb", "(7.1.31)"},
    ButtonStyle->"Hyperlink"],
  "  to obtain an equation for the characteristics:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x = \ x\_o + \(\(f\_o\)(x\_o)\)\ t\)]],
  ". "
}], "NumberedEquation",
  CellTags->{"i:18", "(7.1.34)"}],

Cell[TextData[{
  "Five of these nonlinear characteristics are depicted in Fig. ",
  ButtonBox["7.4",
    ButtonData:>"Fig. 7.4",
    ButtonStyle->"Hyperlink"],
  " They are straight lines in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, t)\)\)]],
  " plane, with slope that depends on ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x\_o)\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9646 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.07848 -0.00533562 1.07848 [
[.21289 .03628 -9.3742 -12 ]
[.21289 .03628 .6258 0 ]
[.84871 .30553 0 -8.01227 ]
[.84871 .30553 10 3.98773 ]
[-0.06055 .34522 -40 -3.77786 ]
[-0.06055 .34522 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .9646 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.51756 0 m
.9781 .59953 L
s
gsave
.84871 .30553 -61 -12.0123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
gsave
-0.06055 .34522 -101 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
.55593 .72459 m
.02975 .1885 L
s
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.55593 .72459 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
0 0 m
1 0 L
1 .9646 L
0 .9646 L
closepath
clip
newpath
.015 w
.55009 .71869 m
.55593 .72462 L
s
.54423 .71274 m
.55009 .71869 L
s
.53833 .70677 m
.54423 .71274 L
s
.5324 .7008 m
.53833 .70677 L
s
.52645 .69483 m
.5324 .7008 L
s
.52046 .68887 m
.52645 .69483 L
s
.51444 .68295 m
.52046 .68887 L
s
.5084 .67709 m
.51444 .68295 L
s
.50232 .67132 m
.5084 .67709 L
s
.49621 .66569 m
.50232 .67132 L
s
.76172 .66366 m
.75626 .65743 L
s
.49006 .66024 m
.49621 .66569 L
s
.75076 .65118 m
.75626 .65743 L
s
.48388 .65505 m
.49006 .66024 L
s
.74524 .64491 m
.75076 .65118 L
s
.47766 .6502 m
.48388 .65505 L
s
.5 Mabswid
.48186 .64913 m
.49024 .64662 L
s
.49024 .64662 m
.49864 .6441 L
s
.015 w
.73969 .63862 m
.74524 .64491 L
s
.5 Mabswid
.49864 .6441 m
.50705 .64159 L
s
.015 w
.4714 .64578 m
.47766 .6502 L
s
.5 Mabswid
.50705 .64159 m
.51548 .63906 L
s
.51548 .63906 m
.52393 .63654 L
s
.015 w
.73411 .63234 m
.73969 .63862 L
s
.5 Mabswid
.52393 .63654 m
.5324 .634 L
s
.015 w
.46509 .6419 m
.4714 .64578 L
s
.5 Mabswid
.5324 .634 m
.54088 .63146 L
s
.015 w
.72851 .62608 m
.73411 .63234 L
s
.5 Mabswid
.54088 .63146 m
.54938 .62892 L
s
.54938 .62892 m
.55789 .62637 L
s
.015 w
.45873 .63869 m
.46509 .6419 L
s
.5 Mabswid
.55789 .62637 m
.56643 .62382 L
s
.015 w
.72288 .61985 m
.72851 .62608 L
s
.5 Mabswid
.56643 .62382 m
.57498 .62126 L
s
.57498 .62126 m
.58355 .6187 L
s
.015 w
.45232 .63627 m
.45873 .63869 L
s
.71722 .61368 m
.72288 .61985 L
s
.5 Mabswid
.58355 .6187 m
.59213 .61613 L
s
.59213 .61613 m
.60073 .61355 L
s
.60073 .61355 m
.60936 .61097 L
s
.015 w
.71154 .60761 m
.71722 .61368 L
s
.5 Mabswid
.60936 .61097 m
.61799 .60839 L
s
.015 w
.44585 .63479 m
.45232 .63627 L
s
.5 Mabswid
.61799 .60839 m
.62665 .6058 L
s
.62665 .6058 m
.63532 .6032 L
s
.015 w
.70584 .6017 m
.71154 .60761 L
s
.5 Mabswid
.63532 .6032 m
.64401 .6006 L
s
.015 w
.43931 .6344 m
.44585 .63479 L
s
.5 Mabswid
.64401 .6006 m
.65272 .598 L
s
.015 w
.70011 .59601 m
.70584 .6017 L
s
.5 Mabswid
.65272 .598 m
.66145 .59538 L
s
.66145 .59538 m
.67019 .59277 L
s
.67019 .59277 m
.67895 .59015 L
s
.015 w
.43269 .63521 m
.43931 .6344 L
s
.69436 .59064 m
.70011 .59601 L
s
.96565 .5834 m
.9719 .5915 L
s
.5 Mabswid
.67895 .59015 m
.68773 .58752 L
s
.68773 .58752 m
.69653 .58488 L
s
.69653 .58488 m
.70535 .58225 L
s
.015 w
.68859 .58573 m
.69436 .59064 L
s
.95937 .57529 m
.96565 .5834 L
s
.5 Mabswid
.70535 .58225 m
.71418 .5796 L
s
.015 w
.42599 .63734 m
.43269 .63521 L
s
.5 Mabswid
.71418 .5796 m
.72304 .57695 L
s
.72304 .57695 m
.73191 .5743 L
s
.015 w
.68281 .58147 m
.68859 .58573 L
s
.95309 .56721 m
.95937 .57529 L
s
.5 Mabswid
.73191 .5743 m
.7408 .57164 L
s
.7408 .57164 m
.7497 .56897 L
s
.015 w
.4192 .64088 m
.42599 .63734 L
s
.5 Mabswid
.7497 .56897 m
.75863 .5663 L
s
0 1 0 r
.40303 .56882 m
.403 .56999 L
s
0 g
.40303 .56882 m
.41275 .56732 L
s
.015 w
.67702 .57814 m
.68281 .58147 L
s
0 1 0 r
.5 Mabswid
.403 .56999 m
.40297 .57117 L
s
.40297 .57117 m
.40294 .57234 L
s
0 g
.41275 .56732 m
.42248 .56582 L
s
0 1 0 r
.40294 .57234 m
.4029 .57352 L
s
0 g
.015 w
.94681 .55919 m
.95309 .56721 L
s
0 1 0 r
.5 Mabswid
.4029 .57352 m
.40287 .5747 L
s
0 g
.75863 .5663 m
.76757 .56363 L
s
.42248 .56582 m
.43222 .56433 L
s
0 1 0 r
.40287 .5747 m
.40284 .57588 L
s
.40284 .57588 m
.40281 .57706 L
s
.40281 .57706 m
.40277 .57823 L
s
0 g
.43222 .56433 m
.44197 .56283 L
s
0 1 0 r
.40277 .57823 m
.40274 .57941 L
s
0 g
.76757 .56363 m
.77654 .56094 L
s
0 1 0 r
.40274 .57941 m
.40271 .58059 L
s
0 g
.44197 .56283 m
.45174 .56132 L
s
0 1 0 r
.40271 .58059 m
.40268 .58178 L
s
.40268 .58178 m
.40264 .58296 L
s
.40264 .58296 m
.40261 .58414 L
s
0 g
.45174 .56132 m
.46151 .55982 L
s
.77654 .56094 m
.78552 .55826 L
s
0 1 0 r
.40261 .58414 m
.40258 .58532 L
s
0 g
.015 w
.67123 .57617 m
.67702 .57814 L
s
0 1 0 r
.5 Mabswid
.40258 .58532 m
.40254 .58651 L
s
0 g
.46151 .55982 m
.4713 .55832 L
s
0 1 0 r
.40254 .58651 m
.40251 .58769 L
s
.40251 .58769 m
.40248 .58887 L
s
0 g
.015 w
.94055 .55131 m
.94681 .55919 L
s
.4123 .64587 m
.4192 .64088 L
s
.5 Mabswid
.4713 .55832 m
.48109 .55681 L
s
0 1 0 r
.40248 .58887 m
.40245 .59006 L
s
0 g
.78552 .55826 m
.79452 .55556 L
s
0 1 0 r
.40245 .59006 m
.40241 .59124 L
s
.40241 .59124 m
.40238 .59243 L
s
0 g
.48109 .55681 m
.4909 .5553 L
s
0 1 0 r
.40238 .59243 m
.40235 .59362 L
s
.40235 .59362 m
.40231 .5948 L
s
0 g
.79452 .55556 m
.80354 .55286 L
s
.4909 .5553 m
.50072 .55379 L
s
0 1 0 r
.40231 .5948 m
.40228 .59599 L
s
.40228 .59599 m
.40225 .59718 L
s
.40225 .59718 m
.40222 .59837 L
s
0 g
.50072 .55379 m
.51055 .55228 L
s
0 1 0 r
.40222 .59837 m
.40218 .59956 L
s
0 g
.80354 .55286 m
.81257 .55016 L
s
0 1 0 r
.40218 .59956 m
.40215 .60075 L
s
0 g
.51055 .55228 m
.52039 .55076 L
s
0 1 0 r
.40215 .60075 m
.40212 .60194 L
s
.40212 .60194 m
.40208 .60313 L
s
0 g
.015 w
.66545 .57627 m
.67123 .57617 L
s
0 1 0 r
.5 Mabswid
.40208 .60313 m
.40205 .60432 L
s
0 g
.52039 .55076 m
.53025 .54925 L
s
.015 w
.93435 .54365 m
.94055 .55131 L
s
.5 Mabswid
.81257 .55016 m
.82163 .54745 L
s
0 1 0 r
.40205 .60432 m
.40202 .60551 L
s
.40202 .60551 m
.40198 .60671 L
s
0 g
.53025 .54925 m
.54011 .54773 L
s
0 1 0 r
.40198 .60671 m
.40195 .6079 L
s
.40195 .6079 m
.40192 .6091 L
s
0 g
.54011 .54773 m
.54999 .54621 L
s
0 1 0 r
.40192 .6091 m
.40188 .61029 L
s
0 g
.82163 .54745 m
.83071 .54473 L
s
0 1 0 r
.40188 .61029 m
.40185 .61149 L
s
.40185 .61149 m
.40182 .61268 L
s
0 g
.54999 .54621 m
.55988 .54469 L
s
0 1 0 r
.40182 .61268 m
.40179 .61388 L
s
0 g
.015 w
.40531 .65229 m
.4123 .64587 L
s
0 1 0 r
.5 Mabswid
.40179 .61388 m
.40175 .61507 L
s
0 g
.83071 .54473 m
.8398 .54201 L
s
.55988 .54469 m
.56978 .54317 L
s
0 1 0 r
.40175 .61507 m
.40172 .61627 L
s
.40172 .61627 m
.40169 .61747 L
s
.40169 .61747 m
.40165 .61867 L
s
0 g
.56978 .54317 m
.57969 .54164 L
s
0 1 0 r
.40165 .61867 m
.40162 .61987 L
s
0 g
.8398 .54201 m
.84891 .53929 L
s
0 1 0 r
.40162 .61987 m
.40159 .62107 L
s
0 g
.015 w
.92826 .53633 m
.93435 .54365 L
s
.5 Mabswid
.57969 .54164 m
.58961 .54011 L
s
0 1 0 r
.40159 .62107 m
.40155 .62227 L
s
.40155 .62227 m
.40152 .62347 L
s
0 g
.015 w
.65971 .57978 m
.66545 .57627 L
s
.5 Mabswid
.58961 .54011 m
.59955 .53859 L
s
0 1 0 r
.40152 .62347 m
.40149 .62467 L
s
.40149 .62467 m
.40145 .62587 L
s
0 g
.84891 .53929 m
.85805 .53655 L
s
0 1 0 r
.40145 .62587 m
.40142 .62708 L
s
0 g
.59955 .53859 m
.6095 .53706 L
s
0 1 0 r
.40142 .62708 m
.40139 .62828 L
s
.40139 .62828 m
.40135 .62948 L
s
0 g
.6095 .53706 m
.61945 .53552 L
s
0 1 0 r
.40135 .62948 m
.40132 .63069 L
s
0 g
.85805 .53655 m
.8672 .53381 L
s
0 1 0 r
.40132 .63069 m
.40129 .63189 L
s
.40129 .63189 m
.40125 .6331 L
s
0 g
.61945 .53552 m
.62942 .53399 L
s
0 1 0 r
.40125 .6331 m
.40122 .63431 L
s
.40122 .63431 m
.40119 .63551 L
s
0 g
.62942 .53399 m
.63941 .53246 L
s
.8672 .53381 m
.87637 .53107 L
s
0 1 0 r
.40119 .63551 m
.40115 .63672 L
s
0 g
.015 w
.92234 .52954 m
.92826 .53633 L
s
0 1 0 r
.5 Mabswid
.40115 .63672 m
.40112 .63793 L
s
.40112 .63793 m
.40109 .63914 L
s
0 g
.63941 .53246 m
.6494 .53092 L
s
.015 w
.3982 .66008 m
.40531 .65229 L
s
0 1 0 r
.5 Mabswid
.40109 .63914 m
.40105 .64035 L
s
.64607 .53143 m
.64609 .53261 L
s
.40105 .64035 m
.40102 .64156 L
s
0 g
.87637 .53107 m
.88556 .52832 L
s
.6494 .53092 m
.6594 .52938 L
s
0 1 0 r
.64609 .53261 m
.64612 .5338 L
s
.40102 .64156 m
.40098 .64277 L
s
.64612 .5338 m
.64614 .53498 L
s
.40098 .64277 m
.40095 .64398 L
s
.64614 .53498 m
.64617 .53617 L
s
0 g
.6594 .52938 m
.66942 .52784 L
s
0 1 0 r
.40095 .64398 m
.40092 .64519 L
s
.64617 .53617 m
.6462 .53735 L
s
.40092 .64519 m
.40088 .6464 L
s
0 g
.88556 .52832 m
.89477 .52556 L
s
0 1 0 r
.6462 .53735 m
.64622 .53854 L
s
0 g
.015 w
.65406 .58951 m
.65971 .57978 L
s
0 1 0 r
.5 Mabswid
.40088 .6464 m
.40085 .64761 L
s
0 g
.66942 .52784 m
.67945 .5263 L
s
0 1 0 r
.64622 .53854 m
.64625 .53973 L
s
.40085 .64761 m
.40082 .64883 L
s
.64625 .53973 m
.64627 .54091 L
s
.40082 .64883 m
.40078 .65004 L
s
.64627 .54091 m
.6463 .5421 L
s
0 g
.67945 .5263 m
.68949 .52475 L
s
0 1 0 r
.40078 .65004 m
.40075 .65125 L
s
.6463 .5421 m
.64633 .54329 L
s
0 g
.89477 .52556 m
.90399 .5228 L
s
0 1 0 r
.40075 .65125 m
.40072 .65247 L
s
0 g
.015 w
.91667 .52348 m
.92234 .52954 L
s
0 1 0 r
.5 Mabswid
.64633 .54329 m
.64635 .54448 L
s
.40072 .65247 m
.40068 .65369 L
s
0 g
.68949 .52475 m
.69954 .52321 L
s
0 1 0 r
.64635 .54448 m
.64638 .54567 L
s
.40068 .65369 m
.40065 .6549 L
s
.64638 .54567 m
.6464 .54686 L
s
.40065 .6549 m
.40061 .65612 L
s
0 g
.69954 .52321 m
.7096 .52166 L
s
0 1 0 r
.6464 .54686 m
.64643 .54805 L
s
.40061 .65612 m
.40058 .65734 L
s
0 g
.90399 .5228 m
.91324 .52004 L
s
0 1 0 r
.64643 .54805 m
.64646 .54924 L
s
.64646 .54924 m
.64648 .55043 L
s
0 g
.7096 .52166 m
.71968 .52011 L
s
0 1 0 r
.64648 .55043 m
.64651 .55162 L
s
.64651 .55162 m
.64653 .55282 L
s
0 g
.71968 .52011 m
.72977 .51856 L
s
.91633 .51911 m
.91324 .52004 L
s
0 1 0 r
.64653 .55282 m
.64656 .55401 L
s
.64656 .55401 m
.64659 .55521 L
s
.64659 .55521 m
.64661 .5564 L
s
0 g
.72977 .51856 m
.73987 .517 L
s
0 1 0 r
.64661 .5564 m
.64664 .5576 L
s
.64664 .5576 m
.64667 .55879 L
s
0 g
.015 w
.39098 .66907 m
.3982 .66008 L
s
.5 Mabswid
.73987 .517 m
.74998 .51545 L
s
.015 w
.91135 .51845 m
.91667 .52348 L
s
0 1 0 r
.5 Mabswid
.64667 .55879 m
.64669 .55999 L
s
.64669 .55999 m
.64672 .56119 L
s
.9139 .51595 m
.91415 .51918 L
s
0 g
.9139 .51595 m
.90993 .51574 L
s
.89802 .51508 m
.90993 .51574 L
s
.74998 .51545 m
.7601 .51389 L
s
0 1 0 r
.64672 .56119 m
.64674 .56238 L
s
0 g
.88609 .51442 m
.89802 .51508 L
s
0 1 0 r
.64674 .56238 m
.64677 .56358 L
s
0 g
.87417 .51377 m
.88609 .51442 L
s
0 1 0 r
.91415 .51918 m
.9144 .52241 L
s
.64677 .56358 m
.6468 .56478 L
s
0 g
.7601 .51389 m
.77024 .51233 L
s
.86223 .51311 m
.87417 .51377 L
s
0 1 0 r
.6468 .56478 m
.64682 .56598 L
s
0 g
.85029 .51245 m
.86223 .51311 L
s
0 1 0 r
.64682 .56598 m
.64685 .56718 L
s
0 g
.83835 .51179 m
.85029 .51245 L
s
0 1 0 r
.9144 .52241 m
.91465 .52565 L
s
0 g
.77024 .51233 m
.78038 .51077 L
s
.015 w
.64867 .61461 m
.65406 .58951 L
s
0 1 0 r
.5 Mabswid
.64685 .56718 m
.64688 .56838 L
s
0 g
.8264 .51113 m
.83835 .51179 L
s
0 1 0 r
.64688 .56838 m
.6469 .56958 L
s
0 g
.81444 .51048 m
.8264 .51113 L
s
0 1 0 r
.6469 .56958 m
.64693 .57078 L
s
0 g
.78038 .51077 m
.79054 .50921 L
s
0 1 0 r
.91465 .52565 m
.9149 .52889 L
s
0 g
.80247 .50982 m
.81444 .51048 L
s
0 1 0 r
.64693 .57078 m
.64695 .57199 L
s
0 g
.7905 .50916 m
.80247 .50982 L
s
0 1 0 r
.64695 .57199 m
.64698 .57319 L
s
0 g
.79054 .50921 m
.80072 .50764 L
s
.77853 .5085 m
.7905 .50916 L
s
0 1 0 r
.64698 .57319 m
.64701 .57439 L
s
.9149 .52889 m
.91515 .53213 L
s
0 g
.76655 .50784 m
.77853 .5085 L
s
.015 w
.90651 .51479 m
.91135 .51845 L
s
0 1 0 r
.5 Mabswid
.64701 .57439 m
.64703 .5756 L
s
0 g
.75456 .50718 m
.76655 .50784 L
s
0 1 0 r
.64703 .5756 m
.64706 .5768 L
s
0 g
.80072 .50764 m
.8109 .50608 L
s
.74257 .50652 m
.75456 .50718 L
s
0 1 0 r
.91515 .53213 m
.9154 .53538 L
s
.64706 .5768 m
.64709 .57801 L
s
0 g
.73057 .50586 m
.74257 .50652 L
s
0 1 0 r
.64709 .57801 m
.64711 .57921 L
s
0 g
.8109 .50608 m
.82109 .50451 L
s
.71856 .50519 m
.73057 .50586 L
s
0 1 0 r
.64711 .57921 m
.64714 .58042 L
s
.9154 .53538 m
.91565 .53863 L
s
0 g
.70655 .50453 m
.71856 .50519 L
s
0 1 0 r
.64714 .58042 m
.64717 .58163 L
s
0 g
.69453 .50387 m
.70655 .50453 L
s
.82109 .50451 m
.8313 .50294 L
s
0 1 0 r
.64717 .58163 m
.64719 .58284 L
s
0 g
.68251 .50321 m
.69453 .50387 L
s
0 1 0 r
.64719 .58284 m
.64722 .58404 L
s
.91565 .53863 m
.9159 .54189 L
s
0 g
.67048 .50255 m
.68251 .50321 L
s
0 1 0 r
.64722 .58404 m
.64725 .58525 L
s
0 g
.8313 .50294 m
.84152 .50136 L
s
.65844 .50188 m
.67048 .50255 L
s
0 1 0 r
.64725 .58525 m
.64727 .58646 L
s
0 g
.015 w
.38365 .67903 m
.39098 .66907 L
s
.5 Mabswid
.6464 .50122 m
.65844 .50188 L
s
0 1 0 r
.9159 .54189 m
.91615 .54515 L
s
.64727 .58646 m
.6473 .58767 L
s
0 g
.84152 .50136 m
.85175 .49979 L
s
.63435 .50056 m
.6464 .50122 L
s
0 1 0 r
.6473 .58767 m
.64732 .58888 L
s
0 g
.6223 .49989 m
.63435 .50056 L
s
0 1 0 r
.64732 .58888 m
.64735 .59009 L
s
0 g
.015 w
.9023 .51289 m
.90651 .51479 L
s
0 1 0 r
.5 Mabswid
.91615 .54515 m
.9164 .54841 L
s
0 g
.61024 .49923 m
.6223 .49989 L
s
0 1 0 r
.64735 .59009 m
.64738 .59131 L
s
0 g
.85175 .49979 m
.862 .49822 L
s
0 1 0 r
.61828 .49967 m
.61833 .50291 L
s
.64738 .59131 m
.6474 .59252 L
s
0 g
.59818 .49856 m
.61024 .49923 L
s
0 1 0 r
.6474 .59252 m
.64743 .59373 L
s
0 g
.5861 .4979 m
.59818 .49856 L
s
0 1 0 r
.9164 .54841 m
.91666 .55168 L
s
0 g
.862 .49822 m
.87225 .49664 L
s
0 1 0 r
.64743 .59373 m
.64746 .59495 L
s
.61833 .50291 m
.61839 .50615 L
s
0 g
.57403 .49723 m
.5861 .4979 L
s
0 1 0 r
.64746 .59495 m
.64748 .59616 L
s
0 g
.56194 .49657 m
.57403 .49723 L
s
.87225 .49664 m
.88252 .49506 L
s
0 1 0 r
.64748 .59616 m
.64751 .59737 L
s
0 g
.54985 .4959 m
.56194 .49657 L
s
0 1 0 r
.91666 .55168 m
.91691 .55496 L
s
.61839 .50615 m
.61844 .50939 L
s
.64751 .59737 m
.64754 .59859 L
s
0 g
.53776 .49524 m
.54985 .4959 L
s
0 1 0 r
.64754 .59859 m
.64756 .59981 L
s
0 g
.52565 .49457 m
.53776 .49524 L
s
.88252 .49506 m
.8928 .49348 L
s
0 1 0 r
.91691 .55496 m
.91716 .55824 L
s
.64756 .59981 m
.64759 .60102 L
s
0 g
.51355 .4939 m
.52565 .49457 L
s
0 1 0 r
.61844 .50939 m
.61849 .51264 L
s
.64759 .60102 m
.64762 .60224 L
s
0 g
.50143 .49324 m
.51355 .4939 L
s
.89623 .49295 m
.8928 .49348 L
s
0 1 0 r
.64762 .60224 m
.64764 .60346 L
s
0 g
.48931 .49257 m
.50143 .49324 L
s
0 1 0 r
.91716 .55824 m
.91741 .56152 L
s
.89623 .49295 m
.89632 .49414 L
s
.64764 .60346 m
.64767 .60468 L
s
0 g
.47719 .4919 m
.48931 .49257 L
s
0 1 0 r
.61849 .51264 m
.61855 .51589 L
s
.89632 .49414 m
.89641 .49533 L
s
0 g
.015 w
.89888 .51319 m
.9023 .51289 L
s
0 1 0 r
.5 Mabswid
.64767 .60468 m
.6477 .6059 L
s
0 g
.46505 .49123 m
.47719 .4919 L
s
0 1 0 r
.89641 .49533 m
.89649 .49652 L
s
.6477 .6059 m
.64772 .60712 L
s
0 g
.45291 .49056 m
.46505 .49123 L
s
0 1 0 r
.91741 .56152 m
.91767 .56481 L
s
.89649 .49652 m
.89658 .49772 L
s
.61855 .51589 m
.6186 .51915 L
s
.64772 .60712 m
.64775 .60834 L
s
0 g
.44077 .48989 m
.45291 .49056 L
s
0 1 0 r
.89658 .49772 m
.89667 .49891 L
s
.64775 .60834 m
.64778 .60956 L
s
0 g
.42862 .48922 m
.44077 .48989 L
s
0 1 0 r
.89667 .49891 m
.89676 .5001 L
s
.91767 .56481 m
.91792 .5681 L
s
.64778 .60956 m
.6478 .61078 L
s
0 g
.41646 .48856 m
.42862 .48922 L
s
0 1 0 r
.89676 .5001 m
.89685 .5013 L
s
.6186 .51915 m
.61865 .52241 L
s
.6478 .61078 m
.64783 .612 L
s
0 g
.4043 .48789 m
.41646 .48856 L
s
0 1 0 r
.89685 .5013 m
.89694 .50249 L
s
0 g
.015 w
.64439 .6978 m
.64867 .61461 L
s
0 1 0 r
.5 Mabswid
.64783 .612 m
.64786 .61322 L
s
0 g
.39213 .48721 m
.4043 .48789 L
s
0 1 0 r
.89694 .50249 m
.89702 .50369 L
s
.91792 .5681 m
.91818 .57139 L
s
.64786 .61322 m
.64788 .61445 L
s
0 g
.37996 .48654 m
.39213 .48721 L
s
0 1 0 r
.61865 .52241 m
.61871 .52568 L
s
.89702 .50369 m
.89711 .50489 L
s
.64788 .61445 m
.64791 .61567 L
s
0 g
.36777 .48587 m
.37996 .48654 L
s
0 1 0 r
.89711 .50489 m
.8972 .50608 L
s
0 g
.015 w
.37621 .68965 m
.38365 .67903 L
s
0 1 0 r
.5 Mabswid
.64791 .61567 m
.64794 .61689 L
s
0 g
.35559 .4852 m
.36777 .48587 L
s
0 1 0 r
.91818 .57139 m
.91843 .57469 L
s
.8972 .50608 m
.89729 .50728 L
s
.64794 .61689 m
.64797 .61812 L
s
.61871 .52568 m
.61876 .52895 L
s
0 g
.34339 .48453 m
.35559 .4852 L
s
0 1 0 r
.89729 .50728 m
.89738 .50848 L
s
.64797 .61812 m
.64799 .61935 L
s
0 g
.33119 .48386 m
.34339 .48453 L
s
0 1 0 r
.89738 .50848 m
.89747 .50968 L
s
0 g
.015 w
.89641 .51614 m
.89888 .51319 L
s
0 1 0 r
.5 Mabswid
.64799 .61935 m
.64802 .62057 L
s
.91843 .57469 m
.91868 .578 L
s
0 g
.31899 .48319 m
.33119 .48386 L
s
0 1 0 r
.89747 .50968 m
.89755 .51088 L
s
.61876 .52895 m
.61881 .53222 L
s
.31899 .48319 m
.31884 .48643 L
s
.89755 .51088 m
.89764 .51208 L
s
.89764 .51208 m
.89773 .51328 L
s
.91868 .578 m
.91894 .58131 L
s
.61881 .53222 m
.61887 .5355 L
s
.89773 .51328 m
.89782 .51448 L
s
.31884 .48643 m
.31869 .48968 L
s
.89782 .51448 m
.89791 .51568 L
s
.91894 .58131 m
.9192 .58462 L
s
.89791 .51568 m
.898 .51688 L
s
.61887 .5355 m
.61892 .53879 L
s
.898 .51688 m
.89809 .51809 L
s
.31869 .48968 m
.31854 .49293 L
s
.89809 .51809 m
.89817 .51929 L
s
.9192 .58462 m
.91945 .58794 L
s
.89817 .51929 m
.89826 .52049 L
s
.61892 .53879 m
.61897 .54207 L
s
.89826 .52049 m
.89835 .5217 L
s
.31854 .49293 m
.31839 .49619 L
s
.89835 .5217 m
.89844 .5229 L
s
.91945 .58794 m
.91971 .59126 L
s
0 g
.015 w
.89506 .5222 m
.89641 .51614 L
s
0 1 0 r
.5 Mabswid
.89844 .5229 m
.89853 .52411 L
s
.61897 .54207 m
.61903 .54537 L
s
.31839 .49619 m
.31825 .49945 L
s
.89853 .52411 m
.89862 .52532 L
s
.89862 .52532 m
.89871 .52652 L
s
.91971 .59126 m
.91996 .59459 L
s
.61903 .54537 m
.61908 .54866 L
s
.89871 .52652 m
.8988 .52773 L
s
.31825 .49945 m
.3181 .50272 L
s
.8988 .52773 m
.89889 .52894 L
s
.91996 .59459 m
.92022 .59792 L
s
.89889 .52894 m
.89898 .53015 L
s
.61908 .54866 m
.61913 .55196 L
s
.89898 .53015 m
.89907 .53136 L
s
.3181 .50272 m
.31795 .50599 L
s
.89907 .53136 m
.89915 .53257 L
s
.92022 .59792 m
.92048 .60126 L
s
.89915 .53257 m
.89924 .53378 L
s
.61913 .55196 m
.61919 .55527 L
s
.31795 .50599 m
.3178 .50927 L
s
.89924 .53378 m
.89933 .53499 L
s
.89933 .53499 m
.89942 .5362 L
s
0 g
.015 w
.36868 .70053 m
.37621 .68965 L
s
0 1 0 r
.5 Mabswid
.92048 .60126 m
.92073 .6046 L
s
0 g
.015 w
.89498 .53173 m
.89506 .5222 L
s
0 1 0 r
.5 Mabswid
.61919 .55527 m
.61924 .55858 L
s
.89942 .5362 m
.89951 .53742 L
s
.3178 .50927 m
.31765 .51255 L
s
.89951 .53742 m
.8996 .53863 L
s
.92073 .6046 m
.92099 .60794 L
s
.8996 .53863 m
.89969 .53984 L
s
.61924 .55858 m
.6193 .5619 L
s
.89969 .53984 m
.89978 .54106 L
s
.31765 .51255 m
.3175 .51583 L
s
.89978 .54106 m
.89987 .54227 L
s
.92099 .60794 m
.92125 .61129 L
s
.89987 .54227 m
.89996 .54349 L
s
.6193 .5619 m
.61935 .56521 L
s
.89996 .54349 m
.90005 .5447 L
s
.3175 .51583 m
.31735 .51912 L
s
.90005 .5447 m
.90014 .54592 L
s
.92125 .61129 m
.92151 .61465 L
s
.90014 .54592 m
.90023 .54714 L
s
.61935 .56521 m
.6194 .56854 L
s
.31735 .51912 m
.3172 .52241 L
s
.90023 .54714 m
.90032 .54836 L
s
.90032 .54836 m
.90041 .54957 L
s
0 g
.015 w
.89624 .54498 m
.89498 .53173 L
s
0 1 0 r
.5 Mabswid
.92151 .61465 m
.92177 .61801 L
s
.6194 .56854 m
.61946 .57187 L
s
.90041 .54957 m
.9005 .55079 L
s
.3172 .52241 m
.31705 .52571 L
s
.9005 .55079 m
.90059 .55201 L
s
.92177 .61801 m
.92203 .62137 L
s
.90059 .55201 m
.90068 .55323 L
s
.61946 .57187 m
.61951 .5752 L
s
.90068 .55323 m
.90077 .55445 L
s
.31705 .52571 m
.3169 .52901 L
s
.90077 .55445 m
.90086 .55568 L
s
.92203 .62137 m
.92229 .62474 L
s
.90086 .55568 m
.90095 .5569 L
s
.61951 .5752 m
.61957 .57854 L
s
.3169 .52901 m
.31675 .53232 L
s
.90095 .5569 m
.90104 .55812 L
s
.90104 .55812 m
.90113 .55935 L
s
.92229 .62474 m
.92255 .62811 L
s
.61957 .57854 m
.61962 .58188 L
s
.90113 .55935 m
.90122 .56057 L
s
.31675 .53232 m
.3166 .53563 L
s
0 g
.015 w
.89889 .56203 m
.89624 .54498 L
s
0 1 0 r
.5 Mabswid
.90122 .56057 m
.90131 .56179 L
s
.92255 .62811 m
.92281 .63149 L
s
.90131 .56179 m
.9014 .56302 L
s
.61962 .58188 m
.61968 .58522 L
s
.9014 .56302 m
.90149 .56425 L
s
.3166 .53563 m
.31644 .53894 L
s
.90149 .56425 m
.90158 .56547 L
s
.92281 .63149 m
.92307 .63487 L
s
0 g
.015 w
.36106 .71118 m
.36868 .70053 L
s
0 1 0 r
.5 Mabswid
.90158 .56547 m
.90167 .5667 L
s
.61968 .58522 m
.61973 .58858 L
s
.90167 .5667 m
.90176 .56793 L
s
.31644 .53894 m
.31629 .54226 L
s
.90176 .56793 m
.90185 .56915 L
s
.92307 .63487 m
.92333 .63826 L
s
.90185 .56915 m
.90194 .57038 L
s
.61973 .58858 m
.61979 .59193 L
s
.31629 .54226 m
.31614 .54559 L
s
.90194 .57038 m
.90204 .57161 L
s
.90204 .57161 m
.90213 .57284 L
s
.92333 .63826 m
.92359 .64165 L
s
0 g
.015 w
.90285 .58271 m
.89889 .56203 L
s
0 1 0 r
.5 Mabswid
.61979 .59193 m
.61984 .59529 L
s
.90213 .57284 m
.90222 .57407 L
s
.31614 .54559 m
.31599 .54892 L
s
.90222 .57407 m
.90231 .57531 L
s
.92359 .64165 m
.92385 .64504 L
s
.90231 .57531 m
.9024 .57654 L
s
.61984 .59529 m
.6199 .59866 L
s
.9024 .57654 m
.90249 .57777 L
s
.31599 .54892 m
.31584 .55225 L
s
.90249 .57777 m
.90258 .579 L
s
.92385 .64504 m
.92411 .64844 L
s
.90258 .579 m
.90267 .58024 L
s
.6199 .59866 m
.61995 .60202 L
s
.31584 .55225 m
.31569 .55559 L
s
.90267 .58024 m
.90276 .58147 L
s
.90276 .58147 m
.90285 .58271 L
s
.92411 .64844 m
.92438 .65185 L
s
.61995 .60202 m
.62001 .6054 L
s
0 g
.015 w
.90797 .60655 m
.90285 .58271 L
s
0 1 0 r
.5 Mabswid
.31569 .55559 m
.31553 .55893 L
s
.92438 .65185 m
.92464 .65526 L
s
.62001 .6054 m
.62006 .60878 L
s
.31553 .55893 m
.31538 .56228 L
s
.92464 .65526 m
.9249 .65867 L
s
.62006 .60878 m
.62012 .61216 L
s
.31538 .56228 m
.31523 .56563 L
s
.9249 .65867 m
.92517 .66209 L
s
.62012 .61216 m
.62017 .61555 L
s
0 g
.015 w
.91396 .6328 m
.90797 .60655 L
s
0 1 0 r
.5 Mabswid
.31523 .56563 m
.31507 .56899 L
s
.92517 .66209 m
.92543 .66551 L
s
0 g
.015 w
.35339 .72109 m
.36106 .71118 L
s
0 1 0 r
.5 Mabswid
.62017 .61555 m
.62023 .61894 L
s
.31507 .56899 m
.31492 .57235 L
s
.92543 .66551 m
.92569 .66894 L
s
.62023 .61894 m
.62028 .62234 L
s
.31492 .57235 m
.31477 .57571 L
s
.92569 .66894 m
.92596 .67238 L
s
0 g
.015 w
.92042 .66037 m
.91396 .6328 L
s
0 1 0 r
.5 Mabswid
.62028 .62234 m
.62034 .62574 L
s
0 g
.015 w
.63916 .74574 m
.64439 .6978 L
s
0 1 0 r
.5 Mabswid
.31477 .57571 m
.31461 .57908 L
s
.92596 .67238 m
.92622 .67581 L
s
.62034 .62574 m
.62039 .62914 L
s
.31461 .57908 m
.31446 .58246 L
s
.92622 .67581 m
.92649 .67926 L
s
.62039 .62914 m
.62045 .63255 L
s
.31446 .58246 m
.31431 .58584 L
s
.92649 .67926 m
.92675 .6827 L
s
0 g
.015 w
.92687 .68794 m
.92042 .66037 L
s
0 1 0 r
.5 Mabswid
.62045 .63255 m
.62051 .63597 L
s
.31431 .58584 m
.31415 .58922 L
s
.92675 .6827 m
.92702 .68615 L
s
.62051 .63597 m
.62056 .63939 L
s
.31415 .58922 m
.314 .59261 L
s
.92702 .68615 m
.92729 .68961 L
s
.62056 .63939 m
.62062 .64282 L
s
.314 .59261 m
.31384 .596 L
s
0 g
.015 w
.93273 .71395 m
.92687 .68794 L
s
0 1 0 r
.5 Mabswid
.92729 .68961 m
.92755 .69307 L
s
.62062 .64282 m
.62067 .64625 L
s
.31384 .596 m
.31369 .5994 L
s
0 g
.015 w
.34567 .72971 m
.35339 .72109 L
s
0 1 0 r
.5 Mabswid
.92755 .69307 m
.92782 .69654 L
s
.62067 .64625 m
.62073 .64968 L
s
.31369 .5994 m
.31353 .60281 L
s
.92782 .69654 m
.92809 .70001 L
s
.62073 .64968 m
.62078 .65312 L
s
.31353 .60281 m
.31338 .60621 L
s
0 g
.015 w
.93739 .73676 m
.93273 .71395 L
s
0 1 0 r
.5 Mabswid
.92809 .70001 m
.92836 .70348 L
s
.62078 .65312 m
.62084 .65656 L
s
.31338 .60621 m
.31322 .60962 L
s
.92836 .70348 m
.92862 .70696 L
s
.62084 .65656 m
.6209 .66001 L
s
.31322 .60962 m
.31306 .61304 L
s
.92862 .70696 m
.92889 .71045 L
s
.6209 .66001 m
.62095 .66346 L
s
.31306 .61304 m
.31291 .61646 L
s
0 g
.015 w
.94026 .75477 m
.93739 .73676 L
s
0 1 0 r
.5 Mabswid
.92889 .71045 m
.92916 .71394 L
s
.62095 .66346 m
.62101 .66692 L
s
.31291 .61646 m
.31275 .61989 L
s
.92916 .71394 m
.92943 .71743 L
s
.62101 .66692 m
.62107 .67039 L
s
.31275 .61989 m
.3126 .62332 L
s
.92943 .71743 m
.9297 .72093 L
s
.62107 .67039 m
.62112 .67385 L
s
.3126 .62332 m
.31244 .62676 L
s
.9297 .72093 m
.92997 .72444 L
s
.62112 .67385 m
.62118 .67733 L
s
0 g
.015 w
.33794 .73647 m
.34567 .72971 L
s
.94079 .76651 m
.94026 .75477 L
s
0 1 0 r
.5 Mabswid
.31244 .62676 m
.31228 .6302 L
s
.92997 .72444 m
.93024 .72795 L
s
.62118 .67733 m
.62124 .6808 L
s
.31228 .6302 m
.31212 .63364 L
s
.93024 .72795 m
.93051 .73146 L
s
.62124 .6808 m
.62129 .68429 L
s
.31212 .63364 m
.31197 .63709 L
s
.93051 .73146 m
.93078 .73498 L
s
.62129 .68429 m
.62135 .68777 L
s
.31197 .63709 m
.31181 .64055 L
s
.93078 .73498 m
.93105 .7385 L
s
0 g
.015 w
.93855 .77081 m
.94079 .76651 L
s
0 1 0 r
.5 Mabswid
.62135 .68777 m
.62141 .69126 L
s
.31181 .64055 m
.31165 .64401 L
s
0 g
.015 w
.63307 .75596 m
.63916 .74574 L
s
0 1 0 r
.5 Mabswid
.93105 .7385 m
.93133 .74203 L
s
.62141 .69126 m
.62146 .69476 L
s
.31165 .64401 m
.31149 .64747 L
s
.93133 .74203 m
.9316 .74557 L
s
.62146 .69476 m
.62152 .69826 L
s
.31149 .64747 m
.31134 .65094 L
s
.22918 .39169 m
.2291 .3929 L
s
0 g
.22918 .39169 m
.23946 .38998 L
s
0 1 0 r
.9316 .74557 m
.93187 .74911 L
s
.2291 .3929 m
.22902 .39411 L
s
.62152 .69826 m
.62158 .70177 L
s
.31134 .65094 m
.31118 .65441 L
s
.22902 .39411 m
.22894 .39532 L
s
0 g
.23946 .38998 m
.24975 .38827 L
s
0 1 0 r
.22894 .39532 m
.22886 .39653 L
s
.93187 .74911 m
.93214 .75265 L
s
0 g
.015 w
.33023 .74085 m
.33794 .73647 L
s
0 1 0 r
.5 Mabswid
.62158 .70177 m
.62164 .70528 L
s
.22886 .39653 m
.22879 .39775 L
s
0 g
.015 w
.93324 .76687 m
.93855 .77081 L
s
0 1 0 r
.5 Mabswid
.31118 .65441 m
.31102 .65789 L
s
0 g
.24975 .38827 m
.26005 .38656 L
s
0 1 0 r
.22879 .39775 m
.22871 .39896 L
s
.93214 .75265 m
.93242 .7562 L
s
.22871 .39896 m
.22863 .40018 L
s
.62164 .70528 m
.62169 .7088 L
s
.22863 .40018 m
.22855 .40139 L
s
.31102 .65789 m
.31086 .66138 L
s
0 g
.26005 .38656 m
.27036 .38485 L
s
0 1 0 r
.22855 .40139 m
.22847 .40261 L
s
.93242 .7562 m
.93269 .75975 L
s
.22847 .40261 m
.22839 .40382 L
s
.62169 .7088 m
.62175 .71232 L
s
0 g
.27036 .38485 m
.28069 .38313 L
s
0 1 0 r
.31086 .66138 m
.3107 .66486 L
s
.22839 .40382 m
.22831 .40504 L
s
.22831 .40504 m
.22823 .40626 L
s
.93269 .75975 m
.93297 .76331 L
s
.22823 .40626 m
.22815 .40748 L
s
.62175 .71232 m
.62181 .71584 L
s
0 g
.28069 .38313 m
.29103 .38142 L
s
0 1 0 r
.3107 .66486 m
.31054 .66836 L
s
.22815 .40748 m
.22807 .40869 L
s
.22807 .40869 m
.22799 .40991 L
s
.93297 .76331 m
.93324 .76687 L
s
0 g
.29103 .38142 m
.30139 .3797 L
s
0 1 0 r
.62181 .71584 m
.62187 .71937 L
s
.22799 .40991 m
.22791 .41113 L
s
.31054 .66836 m
.31038 .67186 L
s
.22791 .41113 m
.22783 .41235 L
s
0 g
.015 w
.92473 .75435 m
.93324 .76687 L
s
.5 Mabswid
.30139 .3797 m
.31175 .37797 L
s
0 1 0 r
.22783 .41235 m
.22775 .41357 L
s
.62187 .71937 m
.62192 .72291 L
s
.22775 .41357 m
.22767 .4148 L
s
.31038 .67186 m
.31022 .67536 L
s
0 g
.015 w
.62671 .75508 m
.63307 .75596 L
s
0 1 0 r
.5 Mabswid
.22767 .4148 m
.22759 .41602 L
s
0 g
.31175 .37797 m
.32213 .37625 L
s
0 1 0 r
.22759 .41602 m
.22751 .41724 L
s
.62192 .72291 m
.62198 .72645 L
s
.31022 .67536 m
.31006 .67887 L
s
.22751 .41724 m
.22743 .41847 L
s
0 g
.32213 .37625 m
.33252 .37453 L
s
0 1 0 r
.22743 .41847 m
.22735 .41969 L
s
0 g
.015 w
.32256 .74239 m
.33023 .74085 L
s
0 1 0 r
.5 Mabswid
.62198 .72645 m
.62204 .73 L
s
.22735 .41969 m
.22727 .42092 L
s
.31006 .67887 m
.3099 .68238 L
s
.22727 .42092 m
.22719 .42214 L
s
0 g
.33252 .37453 m
.34293 .3728 L
s
0 1 0 r
.22719 .42214 m
.22711 .42337 L
s
.62204 .73 m
.6221 .73355 L
s
.22711 .42337 m
.22703 .42459 L
s
.3099 .68238 m
.30974 .6859 L
s
0 g
.34293 .3728 m
.35335 .37107 L
s
0 1 0 r
.22703 .42459 m
.22695 .42582 L
s
.22695 .42582 m
.22687 .42705 L
s
.6221 .73355 m
.62215 .7371 L
s
.30974 .6859 m
.30958 .68942 L
s
.22687 .42705 m
.22679 .42828 L
s
0 g
.35335 .37107 m
.36378 .36933 L
s
0 1 0 r
.22679 .42828 m
.22671 .42951 L
s
0 g
.015 w
.91306 .73341 m
.92473 .75435 L
s
0 1 0 r
.5 Mabswid
.22671 .42951 m
.22663 .43074 L
s
.62215 .7371 m
.62221 .74066 L
s
0 g
.36378 .36933 m
.37422 .3676 L
s
0 1 0 r
.30958 .68942 m
.30942 .69295 L
s
.22663 .43074 m
.22655 .43197 L
s
.22655 .43197 m
.22646 .4332 L
s
.62221 .74066 m
.62227 .74423 L
s
0 g
.37422 .3676 m
.38468 .36586 L
s
0 1 0 r
.22646 .4332 m
.22638 .43443 L
s
0 g
.015 w
.62022 .74899 m
.62671 .75508 L
s
0 1 0 r
.5 Mabswid
.30942 .69295 m
.30926 .69648 L
s
.22638 .43443 m
.2263 .43566 L
s
.2263 .43566 m
.22622 .4369 L
s
0 g
.38468 .36586 m
.39515 .36412 L
s
0 1 0 r
.62227 .74423 m
.62233 .7478 L
s
.22622 .4369 m
.22614 .43813 L
s
.30926 .69648 m
.3091 .70002 L
s
.22614 .43813 m
.22606 .43937 L
s
0 g
.39515 .36412 m
.40563 .36238 L
s
0 1 0 r
.22606 .43937 m
.22598 .4406 L
s
.62233 .7478 m
.62239 .75137 L
s
.3091 .70002 m
.30894 .70356 L
s
.22598 .4406 m
.2259 .44184 L
s
0 g
.015 w
.31497 .74074 m
.32256 .74239 L
s
0 1 0 r
.5 Mabswid
.2259 .44184 m
.22582 .44307 L
s
0 g
.40563 .36238 m
.41613 .36064 L
s
0 1 0 r
.22582 .44307 m
.22574 .44431 L
s
.30894 .70356 m
.30877 .70711 L
s
.22574 .44431 m
.22566 .44555 L
s
0 g
.41613 .36064 m
.42663 .35889 L
s
0 1 0 r
.22566 .44555 m
.22558 .44679 L
s
.22558 .44679 m
.22549 .44803 L
s
.30877 .70711 m
.30861 .71066 L
s
0 g
.015 w
.61365 .73981 m
.62022 .74899 L
s
.5 Mabswid
.42663 .35889 m
.43716 .35715 L
s
0 1 0 r
.22549 .44803 m
.22541 .44926 L
s
0 g
.015 w
.89848 .70465 m
.91306 .73341 L
s
0 1 0 r
.5 Mabswid
.22541 .44926 m
.22533 .45051 L
s
.22533 .45051 m
.22525 .45175 L
s
.30861 .71066 m
.30845 .71422 L
s
0 g
.43716 .35715 m
.44769 .3554 L
s
0 1 0 r
.22525 .45175 m
.22517 .45299 L
s
.22517 .45299 m
.22509 .45423 L
s
.30845 .71422 m
.30829 .71778 L
s
0 g
.44769 .3554 m
.45824 .35365 L
s
0 1 0 r
.22509 .45423 m
.22501 .45547 L
s
.22501 .45547 m
.22493 .45672 L
s
.22493 .45672 m
.22484 .45796 L
s
0 g
.45824 .35365 m
.4688 .35189 L
s
0 1 0 r
.30829 .71778 m
.30812 .72135 L
s
.22484 .45796 m
.22476 .4592 L
s
0 g
.015 w
.60702 .72863 m
.61365 .73981 L
s
.30747 .73567 m
.31497 .74074 L
s
0 1 0 r
.5 Mabswid
.22476 .4592 m
.22468 .46045 L
s
0 g
.4688 .35189 m
.47938 .35013 L
s
0 1 0 r
.22468 .46045 m
.2246 .4617 L
s
.30812 .72135 m
.30796 .72492 L
s
.2246 .4617 m
.22452 .46294 L
s
.22452 .46294 m
.22444 .46419 L
s
0 g
.47938 .35013 m
.48997 .34838 L
s
0 1 0 r
.30796 .72492 m
.3078 .7285 L
s
.22444 .46419 m
.22435 .46544 L
s
.48644 .34896 m
.48642 .35018 L
s
.22435 .46544 m
.22427 .46669 L
s
0 g
.48997 .34838 m
.50057 .34662 L
s
0 1 0 r
.48642 .35018 m
.48641 .3514 L
s
.22427 .46669 m
.22419 .46794 L
s
.3078 .7285 m
.30763 .73208 L
s
.48641 .3514 m
.48639 .35262 L
s
.22419 .46794 m
.22411 .46919 L
s
0 g
.015 w
.60034 .71593 m
.60702 .72863 L
s
0 1 0 r
.5 Mabswid
.48639 .35262 m
.48638 .35384 L
s
0 g
.015 w
.88134 .66913 m
.89848 .70465 L
s
.5 Mabswid
.50057 .34662 m
.51118 .34485 L
s
0 1 0 r
.22411 .46919 m
.22403 .47044 L
s
.48638 .35384 m
.48637 .35506 L
s
.22403 .47044 m
.22395 .47169 L
s
.30763 .73208 m
.30747 .73567 L
s
.48637 .35506 m
.48635 .35628 L
s
.22395 .47169 m
.22386 .47294 L
s
0 g
.51118 .34485 m
.52181 .34309 L
s
0 1 0 r
.48635 .35628 m
.48634 .3575 L
s
.22386 .47294 m
.22378 .47419 L
s
.48634 .3575 m
.48633 .35873 L
s
.22378 .47419 m
.2237 .47545 L
s
0 g
.015 w
.30009 .72707 m
.30747 .73567 L
s
0 1 0 r
.5 Mabswid
.48633 .35873 m
.48631 .35995 L
s
0 g
.52181 .34309 m
.53245 .34132 L
s
0 1 0 r
.2237 .47545 m
.22362 .4767 L
s
0 g
.015 w
.59364 .70217 m
.60034 .71593 L
s
0 1 0 r
.5 Mabswid
.48631 .35995 m
.4863 .36117 L
s
.22362 .4767 m
.22354 .47795 L
s
.4863 .36117 m
.48628 .3624 L
s
.22354 .47795 m
.22345 .47921 L
s
0 g
.53245 .34132 m
.54311 .33955 L
s
0 1 0 r
.48628 .3624 m
.48627 .36362 L
s
.22345 .47921 m
.22337 .48046 L
s
.48627 .36362 m
.48626 .36485 L
s
.22337 .48046 m
.22329 .48172 L
s
0 g
.54311 .33955 m
.55378 .33778 L
s
0 1 0 r
.48626 .36485 m
.48624 .36608 L
s
.22329 .48172 m
.22321 .48298 L
s
0 g
.015 w
.21872 .46816 m
.22544 .4906 L
s
.21191 .44706 m
.21872 .46816 L
s
.20501 .42738 m
.21191 .44706 L
s
0 1 0 r
.5 Mabswid
.48624 .36608 m
.48623 .3673 L
s
0 g
.015 w
.5869 .68757 m
.59364 .70217 L
s
.22544 .4906 m
.23209 .5142 L
s
0 1 0 r
.5 Mabswid
.48623 .3673 m
.48622 .36853 L
s
0 g
.015 w
.19799 .40914 m
.20501 .42738 L
s
.5 Mabswid
.55378 .33778 m
.56446 .336 L
s
0 1 0 r
.48622 .36853 m
.4862 .36976 L
s
0 g
.015 w
.23209 .5142 m
.23869 .53871 L
s
.29284 .71501 m
.30009 .72707 L
s
0 1 0 r
.5 Mabswid
.4862 .36976 m
.48619 .37099 L
s
0 g
.015 w
.19086 .39231 m
.19799 .40914 L
s
.5 Mabswid
.56446 .336 m
.57515 .33423 L
s
0 1 0 r
.48619 .37099 m
.48617 .37222 L
s
.48617 .37222 m
.48616 .37345 L
s
0 g
.015 w
.23869 .53871 m
.24527 .56381 L
s
.58014 .67232 m
.5869 .68757 L
s
0 1 0 r
.5 Mabswid
.48616 .37345 m
.48615 .37468 L
s
0 g
.57515 .33423 m
.58586 .33245 L
s
.015 w
.86217 .62819 m
.88134 .66913 L
s
0 1 0 r
.5 Mabswid
.48615 .37468 m
.48613 .37591 L
s
0 g
.015 w
.18362 .37682 m
.19086 .39231 L
s
0 1 0 r
.5 Mabswid
.48613 .37591 m
.48612 .37714 L
s
0 g
.015 w
.24527 .56381 m
.25185 .58907 L
s
.5 Mabswid
.58586 .33245 m
.59658 .33067 L
s
0 1 0 r
.48612 .37714 m
.4861 .37838 L
s
0 g
.015 w
.28573 .6997 m
.29284 .71501 L
s
0 1 0 r
.5 Mabswid
.4861 .37838 m
.48609 .37961 L
s
0 g
.015 w
.57336 .65657 m
.58014 .67232 L
s
.5 Mabswid
.59658 .33067 m
.60732 .32888 L
s
0 1 0 r
.48609 .37961 m
.48608 .38084 L
s
0 g
.015 w
.25185 .58907 m
.25846 .61401 L
s
.17626 .36254 m
.18362 .37682 L
s
0 1 0 r
.5 Mabswid
.48608 .38084 m
.48606 .38208 L
s
.48606 .38208 m
.48605 .38331 L
s
0 g
.60732 .32888 m
.61807 .3271 L
s
0 1 0 r
.48605 .38331 m
.48603 .38455 L
s
0 g
.015 w
.25846 .61401 m
.26513 .63809 L
s
.56657 .64042 m
.57336 .65657 L
s
.27874 .68147 m
.28573 .6997 L
s
0 1 0 r
.5 Mabswid
.48603 .38455 m
.48602 .38579 L
s
0 g
.61807 .3271 m
.62883 .32531 L
s
0 1 0 r
.48602 .38579 m
.48601 .38702 L
s
0 g
.015 w
.26513 .63809 m
.27188 .66077 L
s
.27188 .66077 m
.27874 .68147 L
s
0 1 0 r
.5 Mabswid
.48601 .38702 m
.48599 .38826 L
s
0 g
.015 w
.16878 .34936 m
.17626 .36254 L
s
0 1 0 r
.5 Mabswid
.48599 .38826 m
.48598 .3895 L
s
0 g
.62883 .32531 m
.63961 .32352 L
s
.015 w
.55976 .62396 m
.56657 .64042 L
s
0 1 0 r
.5 Mabswid
.48598 .3895 m
.48597 .39074 L
s
.48597 .39074 m
.48595 .39198 L
s
0 g
.63961 .32352 m
.6504 .32173 L
s
0 1 0 r
.48595 .39198 m
.48594 .39322 L
s
.48594 .39322 m
.48592 .39446 L
s
0 g
.015 w
.55293 .60725 m
.55976 .62396 L
s
0 1 0 r
.5 Mabswid
.48592 .39446 m
.48591 .39571 L
s
0 g
.6504 .32173 m
.6612 .31994 L
s
0 1 0 r
.48591 .39571 m
.4859 .39695 L
s
0 g
.015 w
.16121 .33713 m
.16878 .34936 L
s
0 1 0 r
.5 Mabswid
.4859 .39695 m
.48588 .39819 L
s
0 g
.015 w
.84153 .58342 m
.86217 .62819 L
s
.5 Mabswid
.6612 .31994 m
.67202 .31814 L
s
.015 w
.5461 .59036 m
.55293 .60725 L
s
0 1 0 r
.5 Mabswid
.48588 .39819 m
.48587 .39944 L
s
.48587 .39944 m
.48585 .40068 L
s
0 g
.67202 .31814 m
.68285 .31634 L
s
0 1 0 r
.48585 .40068 m
.48584 .40193 L
s
.48584 .40193 m
.48583 .40317 L
s
0 g
.015 w
.53925 .57335 m
.5461 .59036 L
s
0 1 0 r
.5 Mabswid
.48583 .40317 m
.48581 .40442 L
s
0 g
.68285 .31634 m
.6937 .31454 L
s
0 1 0 r
.48581 .40442 m
.4858 .40566 L
s
0 g
.015 w
.15353 .32571 m
.16121 .33713 L
s
0 1 0 r
.5 Mabswid
.4858 .40566 m
.48578 .40691 L
s
0 g
.015 w
.53239 .55625 m
.53925 .57335 L
s
.5 Mabswid
.6937 .31454 m
.70456 .31274 L
s
0 1 0 r
.48578 .40691 m
.48577 .40816 L
s
.48577 .40816 m
.48576 .40941 L
s
.48576 .40941 m
.48574 .41066 L
s
0 g
.70456 .31274 m
.71543 .31093 L
s
.015 w
.52551 .53911 m
.53239 .55625 L
s
0 1 0 r
.5 Mabswid
.48574 .41066 m
.48573 .41191 L
s
.48573 .41191 m
.48571 .41316 L
s
0 g
.71543 .31093 m
.72632 .30912 L
s
0 1 0 r
.48571 .41316 m
.4857 .41441 L
s
.4857 .41441 m
.48568 .41567 L
s
0 g
.015 w
.51863 .52197 m
.52551 .53911 L
s
.14575 .31497 m
.15353 .32571 L
s
.5 Mabswid
.72632 .30912 m
.73722 .30731 L
s
0 1 0 r
.48568 .41567 m
.48567 .41692 L
s
.48567 .41692 m
.48566 .41817 L
s
.48566 .41817 m
.48564 .41943 L
s
0 g
.73722 .30731 m
.74813 .3055 L
s
.015 w
.51173 .50487 m
.51863 .52197 L
s
0 1 0 r
.5 Mabswid
.48564 .41943 m
.48563 .42068 L
s
0 g
.015 w
.82004 .53645 m
.84153 .58342 L
s
0 1 0 r
.5 Mabswid
.48563 .42068 m
.48561 .42194 L
s
0 g
.75177 .30489 m
.74813 .3055 L
s
0 1 0 r
.48561 .42194 m
.4856 .42319 L
s
.75177 .30489 m
.75183 .30612 L
s
.4856 .42319 m
.48559 .42445 L
s
0 g
.015 w
.50482 .48783 m
.51173 .50487 L
s
0 1 0 r
.5 Mabswid
.75183 .30612 m
.75188 .30735 L
s
.48559 .42445 m
.48557 .42571 L
s
.75188 .30735 m
.75194 .30857 L
s
.48557 .42571 m
.48556 .42697 L
s
0 g
.015 w
.13789 .30477 m
.14575 .31497 L
s
0 1 0 r
.5 Mabswid
.75194 .30857 m
.752 .3098 L
s
.48556 .42697 m
.48554 .42823 L
s
0 g
.015 w
.49789 .47091 m
.50482 .48783 L
s
0 1 0 r
.5 Mabswid
.752 .3098 m
.75205 .31103 L
s
.48554 .42823 m
.48553 .42949 L
s
.75205 .31103 m
.75211 .31226 L
s
.48553 .42949 m
.48552 .43075 L
s
.75211 .31226 m
.75217 .31349 L
s
.48552 .43075 m
.4855 .43201 L
s
.75217 .31349 m
.75222 .31472 L
s
.4855 .43201 m
.48549 .43327 L
s
0 g
.015 w
.49095 .45412 m
.49789 .47091 L
s
0 1 0 r
.5 Mabswid
.75222 .31472 m
.75228 .31595 L
s
.48549 .43327 m
.48547 .43453 L
s
.75228 .31595 m
.75233 .31718 L
s
.48547 .43453 m
.48546 .4358 L
s
.75233 .31718 m
.75239 .31841 L
s
.48546 .4358 m
.48544 .43706 L
s
.75239 .31841 m
.75245 .31965 L
s
0 g
.015 w
.48399 .43751 m
.49095 .45412 L
s
0 1 0 r
.5 Mabswid
.48544 .43706 m
.48543 .43832 L
s
.75245 .31965 m
.7525 .32088 L
s
0 g
.015 w
.12995 .29501 m
.13789 .30477 L
s
0 1 0 r
.5 Mabswid
.48543 .43832 m
.48542 .43959 L
s
.7525 .32088 m
.75256 .32211 L
s
.48542 .43959 m
.4854 .44085 L
s
.75256 .32211 m
.75262 .32335 L
s
0 g
.133 .2937 m
.14218 .29043 L
s
0 1 0 r
.75262 .32335 m
.75267 .32458 L
s
0 g
.015 w
.47702 .4211 m
.48399 .43751 L
s
0 1 0 r
.5 Mabswid
.75267 .32458 m
.75273 .32582 L
s
.75273 .32582 m
.75279 .32706 L
s
0 g
.015 w
.79828 .48888 m
.82004 .53645 L
s
0 1 0 r
.5 Mabswid
.75279 .32706 m
.75284 .32829 L
s
.75284 .32829 m
.7529 .32953 L
s
0 g
.14218 .29043 m
.15137 .28715 L
s
.015 w
.47002 .40494 m
.47702 .4211 L
s
0 1 0 r
.5 Mabswid
.7529 .32953 m
.75296 .33077 L
s
.75296 .33077 m
.75301 .33201 L
s
0 g
.015 w
.12193 .28559 m
.12995 .29501 L
s
0 1 0 r
.5 Mabswid
.75301 .33201 m
.75307 .33325 L
s
.75307 .33325 m
.75313 .33449 L
s
0 g
.15137 .28715 m
.16058 .28386 L
s
.015 w
.46301 .38906 m
.47002 .40494 L
s
0 1 0 r
.5 Mabswid
.75313 .33449 m
.75318 .33573 L
s
.75318 .33573 m
.75324 .33698 L
s
.75324 .33698 m
.7533 .33822 L
s
.7533 .33822 m
.75335 .33946 L
s
0 g
.16058 .28386 m
.16982 .28057 L
s
0 1 0 r
.75335 .33946 m
.75341 .34071 L
s
0 g
.015 w
.45597 .37348 m
.46301 .38906 L
s
0 1 0 r
.5 Mabswid
.75341 .34071 m
.75347 .34195 L
s
.75347 .34195 m
.75352 .3432 L
s
.75352 .3432 m
.75358 .34444 L
s
0 g
.015 w
.11385 .27643 m
.12193 .28559 L
s
0 1 0 r
.5 Mabswid
.75358 .34444 m
.75364 .34569 L
s
0 g
.16982 .28057 m
.17908 .27727 L
s
0 1 0 r
.75364 .34569 m
.75369 .34694 L
s
0 g
.015 w
.44891 .35826 m
.45597 .37348 L
s
0 1 0 r
.5 Mabswid
.75369 .34694 m
.75375 .34818 L
s
.75375 .34818 m
.75381 .34943 L
s
.75381 .34943 m
.75387 .35068 L
s
0 g
.17908 .27727 m
.18835 .27396 L
s
.015 w
.77679 .44213 m
.79828 .48888 L
s
0 1 0 r
.5 Mabswid
.75387 .35068 m
.75392 .35193 L
s
.75392 .35193 m
.75398 .35318 L
s
0 g
.015 w
.44182 .34341 m
.44891 .35826 L
s
0 1 0 r
.5 Mabswid
.75398 .35318 m
.75404 .35443 L
s
.75404 .35443 m
.75409 .35569 L
s
0 g
.18835 .27396 m
.19765 .27065 L
s
0 1 0 r
.75409 .35569 m
.75415 .35694 L
s
0 g
.015 w
.10569 .26744 m
.11385 .27643 L
s
0 1 0 r
.5 Mabswid
.75415 .35694 m
.75421 .35819 L
s
.75421 .35819 m
.75427 .35945 L
s
0 g
.015 w
.43469 .32897 m
.44182 .34341 L
s
0 1 0 r
.5 Mabswid
.75427 .35945 m
.75432 .3607 L
s
.75432 .3607 m
.75438 .36196 L
s
0 g
.19765 .27065 m
.20697 .26732 L
s
0 1 0 r
.75438 .36196 m
.75444 .36321 L
s
.75444 .36321 m
.7545 .36447 L
s
.7545 .36447 m
.75455 .36573 L
s
.75455 .36573 m
.75461 .36699 L
s
0 g
.20697 .26732 m
.21632 .26399 L
s
.015 w
.42754 .31498 m
.43469 .32897 L
s
0 1 0 r
.5 Mabswid
.75461 .36699 m
.75467 .36824 L
s
.75467 .36824 m
.75473 .3695 L
s
.75473 .3695 m
.75478 .37076 L
s
0 g
.015 w
.09748 .25858 m
.10569 .26744 L
s
0 1 0 r
.5 Mabswid
.75478 .37076 m
.75484 .37202 L
s
0 g
.21632 .26399 m
.22568 .26065 L
s
0 1 0 r
.75484 .37202 m
.7549 .37329 L
s
.7549 .37329 m
.75496 .37455 L
s
0 g
.015 w
.756 .39738 m
.77679 .44213 L
s
.42034 .30144 m
.42754 .31498 L
s
0 1 0 r
.5 Mabswid
.75496 .37455 m
.75501 .37581 L
s
.75501 .37581 m
.75507 .37707 L
s
.75507 .37707 m
.75513 .37834 L
s
0 g
.22568 .26065 m
.23507 .25731 L
s
0 1 0 r
.75513 .37834 m
.75519 .3796 L
s
.75519 .3796 m
.75524 .38087 L
s
.75524 .38087 m
.7553 .38213 L
s
.7553 .38213 m
.75536 .3834 L
s
0 g
.23507 .25731 m
.24447 .25395 L
s
.015 w
.41311 .28839 m
.42034 .30144 L
s
.0892 .24981 m
.09748 .25858 L
s
0 1 0 r
.5 Mabswid
.75536 .3834 m
.75542 .38467 L
s
.75542 .38467 m
.75548 .38594 L
s
.75548 .38594 m
.75553 .38721 L
s
.75553 .38721 m
.75559 .38848 L
s
0 g
.24447 .25395 m
.2539 .25059 L
s
0 1 0 r
.75559 .38848 m
.75565 .38975 L
s
.75565 .38975 m
.75571 .39102 L
s
.75571 .39102 m
.75577 .39229 L
s
0 g
.015 w
.40583 .27583 m
.41311 .28839 L
s
0 1 0 r
.5 Mabswid
.75577 .39229 m
.75582 .39356 L
s
0 g
.2539 .25059 m
.26335 .24722 L
s
0 1 0 r
.75582 .39356 m
.75588 .39483 L
s
.75588 .39483 m
.75594 .39611 L
s
.75594 .39611 m
.756 .39738 L
s
0 g
.015 w
.08087 .24108 m
.0892 .24981 L
s
.73624 .35553 m
.756 .39738 L
s
.5 Mabswid
.26335 .24722 m
.27283 .24384 L
s
.015 w
.39851 .26375 m
.40583 .27583 L
s
.5 Mabswid
.27283 .24384 m
.28232 .24046 L
s
.28232 .24046 m
.29184 .23706 L
s
.015 w
.07248 .23236 m
.08087 .24108 L
s
.39114 .25214 m
.39851 .26375 L
s
.5 Mabswid
.29184 .23706 m
.30138 .23366 L
s
.015 w
.71774 .31715 m
.73624 .35553 L
s
.5 Mabswid
.30138 .23366 m
.31094 .23025 L
s
.015 w
.38372 .24098 m
.39114 .25214 L
s
.06404 .22365 m
.07248 .23236 L
s
.5 Mabswid
.31094 .23025 m
.32052 .22683 L
s
.32052 .22683 m
.33013 .22341 L
s
.015 w
.37625 .23023 m
.38372 .24098 L
s
.5 Mabswid
.33013 .22341 m
.33976 .21998 L
s
.015 w
.05555 .21492 m
.06404 .22365 L
s
.70058 .28251 m
.71774 .31715 L
s
.5 Mabswid
.33976 .21998 m
.34941 .21653 L
s
.015 w
.36872 .21985 m
.37625 .23023 L
s
.5 Mabswid
.34941 .21653 m
.35909 .21308 L
s
.015 w
.047 .20616 m
.05555 .21492 L
s
.5 Mabswid
.35909 .21308 m
.36878 .20963 L
s
.015 w
.36114 .20977 m
.36872 .21985 L
s
.5 Mabswid
.36878 .20963 m
.3785 .20616 L
s
.015 w
.68479 .25163 m
.70058 .28251 L
s
.5 Mabswid
.3785 .20616 m
.38825 .20269 L
s
.015 w
.0384 .19737 m
.047 .20616 L
s
.35351 .19995 m
.36114 .20977 L
s
.5 Mabswid
.38825 .20269 m
.39801 .1992 L
s
.39801 .1992 m
.4078 .19571 L
s
.015 w
.02975 .18853 m
.0384 .19737 L
s
.5 Mabswid
.4078 .19571 m
.41761 .19222 L
s
.015 w
.34582 .19033 m
.35351 .19995 L
s
.67029 .22432 m
.68479 .25163 L
s
.5 Mabswid
.41761 .19222 m
.42745 .18871 L
s
.42745 .18871 m
.43731 .18519 L
s
.02975 .1885 m
.03906 .1849 L
s
.015 w
.33808 .18087 m
.34582 .19033 L
s
.5 Mabswid
.43731 .18519 m
.44719 .18167 L
s
.03906 .1849 m
.04839 .1813 L
s
.44719 .18167 m
.45709 .17814 L
s
.04839 .1813 m
.05775 .17769 L
s
.015 w
.65695 .20024 m
.67029 .22432 L
s
.3303 .17151 m
.33808 .18087 L
s
.5 Mabswid
.45709 .17814 m
.46702 .1746 L
s
.05775 .17769 m
.06712 .17406 L
s
.46702 .1746 m
.47697 .17105 L
s
.06712 .17406 m
.07652 .17043 L
s
.47697 .17105 m
.48695 .16749 L
s
.07652 .17043 m
.08595 .16679 L
s
.015 w
.32245 .16223 m
.3303 .17151 L
s
.64463 .17898 m
.65695 .20024 L
s
.5 Mabswid
.48695 .16749 m
.49695 .16393 L
s
.08595 .16679 m
.09539 .16314 L
s
.49695 .16393 m
.50698 .16035 L
s
.09539 .16314 m
.10486 .15948 L
s
.015 w
.31456 .15298 m
.32245 .16223 L
s
.5 Mabswid
.50698 .16035 m
.51702 .15677 L
s
.10486 .15948 m
.11435 .15582 L
s
.51702 .15677 m
.5271 .15318 L
s
.11435 .15582 m
.12387 .15214 L
s
.015 w
.63315 .16006 m
.64463 .17898 L
s
.5 Mabswid
.5271 .15318 m
.53719 .14958 L
s
.015 w
.30662 .14374 m
.31456 .15298 L
s
.5 Mabswid
.12387 .15214 m
.13341 .14846 L
s
.53719 .14958 m
.54731 .14597 L
s
.13341 .14846 m
.14297 .14476 L
s
.54731 .14597 m
.55746 .14235 L
s
.14297 .14476 m
.15255 .14106 L
s
.015 w
.62234 .14305 m
.63315 .16006 L
s
.29863 .13449 m
.30662 .14374 L
s
.5 Mabswid
.55746 .14235 m
.56763 .13872 L
s
.15255 .14106 m
.16216 .13734 L
s
.56763 .13872 m
.57782 .13509 L
s
.16216 .13734 m
.1718 .13362 L
s
.57782 .13509 m
.58804 .13145 L
s
.015 w
.29058 .12523 m
.29863 .13449 L
s
.5 Mabswid
.1718 .13362 m
.18145 .12989 L
s
.015 w
.61205 .12753 m
.62234 .14305 L
s
.5 Mabswid
.58804 .13145 m
.59828 .12779 L
s
.18145 .12989 m
.19113 .12615 L
s
.59828 .12779 m
.60855 .12413 L
s
.19113 .12615 m
.20084 .1224 L
s
.015 w
.28249 .11593 m
.29058 .12523 L
s
.5 Mabswid
.61198 .12291 m
.60855 .12413 L
s
.20084 .1224 m
.21057 .11864 L
s
.015 w
.60215 .11313 m
.61205 .12753 L
s
.5 Mabswid
.21057 .11864 m
.22032 .11488 L
s
.015 w
.27435 .10659 m
.28249 .11593 L
s
.5 Mabswid
.22032 .11488 m
.2301 .1111 L
s
.2301 .1111 m
.2399 .10731 L
s
.015 w
.59251 .09954 m
.60215 .11313 L
s
.5 Mabswid
.2399 .10731 m
.24972 .10352 L
s
.015 w
.26615 .0972 m
.27435 .10659 L
s
.5 Mabswid
.24972 .10352 m
.25958 .09971 L
s
.25958 .09971 m
.26945 .0959 L
s
.015 w
.58305 .08651 m
.59251 .09954 L
s
.5 Mabswid
.26945 .0959 m
.27935 .09207 L
s
.27935 .09207 m
.28927 .08824 L
s
.28927 .08824 m
.29922 .08439 L
s
.29922 .08439 m
.3092 .08054 L
s
.015 w
.5737 .07387 m
.58305 .08651 L
s
.5 Mabswid
.3092 .08054 m
.3192 .07668 L
s
.3192 .07668 m
.32922 .0728 L
s
.32922 .0728 m
.33927 .06892 L
s
.015 w
.56439 .06145 m
.5737 .07387 L
s
.5 Mabswid
.33927 .06892 m
.34935 .06503 L
s
.34935 .06503 m
.35945 .06113 L
s
.35945 .06113 m
.36957 .05721 L
s
.015 w
.5551 .04916 m
.56439 .06145 L
s
.5 Mabswid
.36957 .05721 m
.37973 .05329 L
s
.37973 .05329 m
.3899 .04936 L
s
.3899 .04936 m
.40011 .04542 L
s
.015 w
.54579 .03692 m
.5551 .04916 L
s
.5 Mabswid
.40011 .04542 m
.41034 .04146 L
s
.41034 .04146 m
.42059 .0375 L
s
.42059 .0375 m
.43087 .03353 L
s
.015 w
.53644 .02468 m
.54579 .03692 L
s
.5 Mabswid
.43087 .03353 m
.44118 .02955 L
s
.44118 .02955 m
.45152 .02556 L
s
.45152 .02556 m
.46188 .02155 L
s
.015 w
.52704 .0124 m
.53644 .02468 L
s
.5 Mabswid
.46188 .02155 m
.47227 .01754 L
s
.47227 .01754 m
.48268 .01352 L
s
.48268 .01352 m
.49312 .00948 L
s
.015 w
.51759 6e-05 m
.52704 .0124 L
s
.5 Mabswid
.49312 .00948 m
.50359 .00544 L
s
.50359 .00544 m
.51408 .00138 L
s
.51759 3e-05 m
.51408 .00138 L
s
.25 Mabswid
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{364.75, 351.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000770001]b000`400?l00000o`00003oooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooool=ooooo`Go0000]_oo
ool00?oooooo3Oooool6o`000;Gooooo003oooooo`gooooo1ol0002dooooo`00ooooool;ooooo`[o
0000/oooool00?oooooo2?ooool3o`0000;ooooo2Ol0002booooo`00Toooool01OnHV9So0000o`00
0?m4A4Co^[Zj06cooooo1?l00005ooooo`So0000/_ooool009?ooooo00Go410@okZj^_o^k^koMgMg
oa0@401Zooooo`?o00002Oooool8o`000;7ooooo002Cooooo`03o`000?oooooooooo06Wooooo0ol0
000<ooooo`Wo0000/?ooool009?ooooo00?o0000ooooooooool0I_ooool4o`0000kooooo00?o0000
ooooool000001_l0002`ooooo`00Toooool00ol0003oooooooooo`1Tooooo`?o00004Oooool00ol0
003oooooo`000007o`000:oooooo002Aooooo`03oa0@4?l0003o000000?o0000H?ooool4o`0001?o
oooo00?o0000ooooooooool01ol0002_ooooo`00Toooool00ol0003oooooooooo`1Nooooo`Co0000
5_ooool01?l0003oooooooooooooool7o`000:kooooo002Cooooo`03o`000?oooooooooo05cooooo
0ol0000Iooooo`04o`000?ooooooooooooooo`So0000[Oooool00>oooooo1?l0000Kooooo`03o`00
0?oooooooooo00;ooooo2?l0002/ooooo`00k?ooool4o`0001kooooo00?o0000ooooooooool00_oo
ool9o`000:_ooooo003Zooooo`Co00008?ooool00ol0003oooooooooo`03ooooo`Wo0000Z_ooool0
0>Oooooo1?l0000Sooooo`03o`000?oooooooooo00Cooooo2Ol0002Yooooo`00i?ooool5o`0002Go
oooo00?o0000ooooooooool01Oooool9o`000:Sooooo003Rooooo`Co0000:?ooool00ol0003ooooo
ooooo`06ooooo`Wo0000Yoooool00=oooooo1?l0000[ooooo`03o`000?oooooooooo00Oooooo2?l0
002Wooooo`00g?ooool5o`0002gooooo00?o0000ooooooooool02?ooool8o`000:Kooooo003Koooo
o`?o0000<?ooool00ol0003oooooooooo`09ooooo`So0000YOooool00=Sooooo1?l0000booooo`03
o`000?oooooooooo00[ooooo1ol0002Uooooo`00eOooool4o`0003Gooooo00?o0000ooooooooool0
2_ooool8o`000:Cooooo003Cooooo`?o0000>?ooool00ol0003oooooooooo`0;ooooo`Oo0000Y?oo
ool00=3ooooo1?l0000jooooo`03o`000?oooooooooo00cooooo1ol0002Sooooo`00cOooool4o`00
03gooooo00?o0000ooooooooool03?ooool8o`000:;ooooo003;ooooo`Co0000?oooool00ol0003o
ooooooooo`0=ooooo`So0000XOooool00<Sooooo1?l00012ooooo`03o`000?oooooooooo00gooooo
2Ol0002Pooooo`00aOooool5o`0004Cooooo00?o0000ooooooooool03_ooool8o`000:3ooooo0033
ooooo`Co0000Aoooool00ol0003oooooooooo`0?ooooo`So0000Woooool00<7ooooo0ol0001:oooo
o`03o`000?oooooooooo013ooooo2?l0002Nooooo`00__ooool4o`0004cooooo00?o0000oooooooo
ool04Oooool7o`0009kooooo002looooo`?o0000Coooool00ol0003oooooooooo`0Aooooo`So0000
WOooool00;Wooooo1?l0001Aooooo`03o`000?oooooooooo01;ooooo1ol0002Mooooo`00]_ooool4
o`0005Cooooo00?o0000ooooooooool04oooool7o`0009cooooo002dooooo`?o0000Eoooool00ol0
003oooooooooo`0Cooooo`So0000Voooool00:cooooo1Ol000001?oooooo0000o`000?l0001Ioooo
o`03o`000?oooooooooo01Cooooo2?l0002Jooooo`00[?ooool6o`0005cooooo00?o0000oooooooo
ool05?ooool9o`0009Wooooo002/ooooo`Oo0000Foooool00ol0003oooooooooo`0Eooooo`So0000
VOooool00:[ooooo2_l0001Jooooo`03o`000?oooooooooo01Kooooo2?l0002Hooooo`00Yoooool4
o`000003ooooool0003o000000Ko0000F_ooool00ol0003oooooooooo`0Gooooo`So0000Uoooool0
0:Gooooo0ol00005ooooo`So0000FOooool00ol0003oooooooooo`0Hooooo`So0000U_ooool00:;o
oooo0ol00009ooooo`So0000F?ooool00ol0003oooooooooo`0Hooooo`Wo0000UOooool009oooooo
1?l0000<ooooo`Wo0000E_ooool00ol0003oooooooooo`0Iooooo`So0000UOooool009cooooo1?l0
000?ooooo`[o0000EOooool00ol0003oooooooooo`0Jooooo`So0000U?ooool009[ooooo1?l0000B
ooooo`[o0000E?ooool00ol0003oooooooooo`0Kooooo`So0000Toooool009Oooooo1?l0000Foooo
o`[o0000Doooool00ol0003oooooooooo`0Looooo`Oo0000Toooool009Cooooo1?l0000Jooooo`Wo
0000Doooool00ol0003oooooooooo`0Looooo`So0000T_ooool009?ooooo0ol0000Nooooo`So0000
D_ooool00ol0003oooooooooo`0Mooooo`Oo0000T_ooool0093ooooo0ol0000Rooooo`So0000DOoo
ool00ol0003oooooooooo`0Kooooo`[o0000TOooool008gooooo1?l0000Uooooo`So0000D?ooool0
0ol0003oooooooooo`0Iooooo`;o00000oooool8o`00093ooooo002;ooooo`?o0000:?ooool9o`00
04oooooo00?o0000ooooooooool05_ooool3o`0000Kooooo1ol0002@ooooo`00ROooool3o`0002_o
oooo2Ol0001>ooooo`03o`000?oooooooooo01?ooooo0ol00009ooooo`So0000Soooool008Gooooo
1?l0000_ooooo`Wo0000COooool00ol0003oooooooooo`0Aooooo`;o00003Oooool8o`0008kooooo
0022ooooo`Co0000<oooool8o`0004gooooo00?o0000ooooooooool03_ooool3o`00013ooooo1ol0
002>ooooo`00P?ooool4o`0003Kooooo2?l0001<ooooo`03o`000?oooooooooo00_ooooo0ol0000C
ooooo`So0000SOooool007kooooo0ol0000jooooo`So0000Boooool00ol0003oooooooooo`08oooo
o`?o00005oooool7o`0008gooooo001kooooo`Co0000?Oooool8o`0004[ooooo00?o0000oooooooo
ool01_ooool2o`0001_ooooo1ol0002<ooooo`00NOooool3o`00043ooooo2?l0001:ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Mooooo`So0000Roooool007Kooooo0ol00014ooooo`So0000BOoo
ool00ol0003oooooo`000003o`00027ooooo1ol0002;ooooo`00Loooool4o`0004Oooooo2?l00017
ooooo`?o00009Oooool8o`0008[ooooo001`ooooo`Co0000Boooool8o`0004Cooooo0_l000000ooo
oooo0000ooooo`0Vooooo`Oo0000R_ooool006kooooo1?l0001=ooooo`Wo0000@?ooool3o`0000?o
oooo00?o0000ooooooooool09_ooool7o`0008Wooooo001[ooooo`Co0000DOooool9o`0003cooooo
0ol00006ooooo`03o`000?oooooooooo02Kooooo2?l00028ooooo`00J?ooool5o`0005Cooooo2Ol0
000jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool8o`0008Oooooo001W
ooooo`?o0000F?ooool8o`0003Oooooo0ol0000:ooooo`03o`000?oooooooooo02Oooooo2?l00027
ooooo`00I?ooool3o`0005cooooo2?l0000booooo`Co00003Oooool00ol0003oooooooooo`0Xoooo
o`So0000Q_ooool0067ooooo1?l0001Oooooo`So0000;_ooool3o`00017ooooo00?o0000oooooooo
ool0:Oooool8o`0008Gooooo001Nooooo`Co0000Hoooool8o`0002_ooooo0_l0000Dooooo`03o`00
0?oooooooooo02[ooooo1ol00025ooooo`00G?ooool4o`0006Gooooo2Ol0000Wooooo`?o00005_oo
ool00ol0003oooooooooo`0Zooooo`So0000Q?ooool005[ooooo0ol0001Yooooo`Wo00008oooool3
o`0001Wooooo00?o0000ooooooooool0:oooool8o`0008?ooooo001Booooo`So0000KOooool9o`00
01oooooo0ol0000Looooo`03o`000?oooooooooo02cooooo2?l00022ooooo`00D_ooool6o`00073o
oooo2?l0000Mooooo`;o00007oooool00ol0003oooooooooo`0/ooooo`So0000P_ooool005;ooooo
1ol0001`ooooo`So00006Oooool3o`00027ooooo00?o0000ooooooooool0;Oooool8o`00087ooooo
001Booooo`Wo0000Koooool8o`0001Cooooo1?l0000Tooooo`03o`000?oooooooooo02gooooo1ol0
00000ooooooo0000ooooo`1oooooo`00D_ooool:o`0006oooooo2?l0000@ooooo`?o0000:?ooool0
0ol0003oooooooooo`0^ooooo`Oo000000?oooooo`000?ooool0O_ooool005?ooooo2_l0001^oooo
o`So00003oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02kooooo1ol00002oooo
o`03o`000?oooooooooo07cooooo001Dooooo`[o0000K_ooool8o`0000_ooooo0ol0000/ooooo`03
o`000?oooooooooo02oooooo1ol000000ooooooo0000ooooo`1mooooo`00E?ooool:o`0006oooooo
2?l00006ooooo`Co0000;oooool00ol0003oooooooooo`0_ooooo`So000000?oooooo`000?ooool0
O?ooool005?ooooo00Co0000oooooooooooooooo2?l0001_ooooo`So00000_ooool3o`0003?ooooo
00?o0000ooooooooool0<?ooool7o`0000;ooooo00?o0000ooooooooool0N_ooool005?ooooo00?o
0000ooooooooool00_ooool8o`0006kooooo2_l0000fooooo`03o`000?oooooooooo033ooooo2?l0
0002ooooo`03o`000?oooooooooo07Wooooo001Cooooo`03o`000?oooooooooo00?ooooo2?l0001^
ooooo`So0000=oooool00ol0003oooooooooo`0aooooo`So000000?oooooo`000?ooool0N_ooool0
05?ooooo00?o0000ooooooooool00oooool9o`0006kooooo1ol0000gooooo`03o`000?oooooooooo
03;ooooo1ol00002ooooo`03o`000?oooooooooo07Sooooo001Cooooo`03o`000?oooooooooo00Co
oooo2Ol0001Zooooo`?o000000?oooooo`000?l000001Ol0000fooooo`03o`000?oooooooooo03;o
oooo2?l00002ooooo`03o`000?oooooooooo07Oooooo001Cooooo`03o`000?oooooooooo00Gooooo
2Ol0001Wooooo`;o00001?ooool8o`0003Gooooo00?o0000ooooooooool0<oooool8o`0000;ooooo
00?o0000ooooooooool0M_ooool005?ooooo00?o0000ooooooooool01_ooool9o`0006Cooooo0_l0
0007ooooo`So0000=?ooool00ol0003oooooooooo`0dooooo`Oo00000_ooool00ol0003ooooooooo
o`1fooooo`00Doooool00ol0003oooooooooo`07ooooo`Wo0000Goooool4o`0000Wooooo2Ol0000c
ooooo`03o`000?oooooooooo03Cooooo2?l00002ooooo`03o`000?oooooooooo07Gooooo001Coooo
o`03o`000?oooooooooo00Sooooo2Ol0001Jooooo`Co00003_ooool8o`0003?ooooo00?o0000oooo
ooooool0=Oooool7o`0000?ooooo00?o0000ooooooooool0M?ooool005;ooooo00?o0000oooooooo
ool02_ooool9o`0005Kooooo0ol0000Cooooo`So0000<_ooool00ol0003oooooooooo`0fooooo`Oo
00000oooool00ol0003oooooooooo`1cooooo`00D_ooool00ol0003oooooooooo`0;ooooo`Wo0000
E?ooool00ol0003oooooooooo`0Eooooo`So0000<Oooool00ol0003oooooooooo`0fooooo`Oo0000
1?ooool00ol0003oooooooooo`1booooo`00D_ooool00ol0003oooooooooo`0<ooooo`Wo0000D?oo
ool3o`0001Wooooo1ol0000aooooo`03o`000?oooooooooo03Oooooo1ol00003ooooo`03o`000?oo
oooooooo07;ooooo001Booooo`03o`000?oooooooooo00gooooo2Ol0001;ooooo`Co00007?ooool8
o`00033ooooo00?o0000ooooooooool0=oooool7o`0000Cooooo00?o0000ooooooooool0LOooool0
05;ooooo00?o0000ooooooooool03_ooool9o`0004Oooooo0ol0000Qooooo`Oo0000<?ooool00ol0
003oooooooooo`0hooooo`Ko00001Oooool00ol0003oooooooooo`1`ooooo`00D_ooool00ol0003o
ooooooooo`0?ooooo`Wo0000AOooool00ol0003oooooooooo`0Sooooo`Oo0000;oooool00ol0003o
ooooooooo`0hooooo`Oo00001Oooool00ol0003oooooooooo`1_ooooo`00D_ooool00ol0003ooooo
ooooo`0@ooooo`Wo0000@Oooool3o`0002Kooooo2?l0000^ooooo`03o`000?oooooooooo03Wooooo
1_l00005ooooo`03o`000?oooooooooo06oooooo001Booooo`03o`000?oooooooooo017ooooo2Ol0
000mooooo`?o0000:_ooool8o`0002gooooo00?o0000ooooooooool0>Oooool7o`0000Gooooo00?o
0000ooooooooool0K_ooool005;ooooo00?o0000ooooooooool04_ooool9o`0003Wooooo0ol0000]
ooooo`So0000;Oooool00ol0003oooooooooo`0iooooo`Oo00001_ooool00ol0003oooooooooo`1]
ooooo`00DOooool00ol0003oooooooooo`0Dooooo`Wo0000=_ooool2o`00037ooooo2?l0000/oooo
o`03o`000?oooooooooo03[ooooo1ol00006ooooo`03o`000?oooooooooo06cooooo001Aooooo`03
o`000?oooooooooo01Gooooo2?l0000cooooo`?o0000=?ooool8o`0002_ooooo00?o0000oooooooo
ool0>_ooool7o`0000Kooooo00?o0000ooooooooool0K?ooool0057ooooo00?o0000ooooooooool0
5_ooool8o`0002oooooo0ol0000hooooo`So0000:_ooool00ol0003oooooooooo`0kooooo`Oo0000
1_ooool00ol0003oooooooooo`1[ooooo`00DOooool00ol0003oooooooooo`0Gooooo`So0000:_oo
ool4o`0003_ooooo2?l0000Zooooo`03o`000?oooooooooo03_ooooo1ol00007ooooo`03o`000?oo
oooooooo06[ooooo001Aooooo`03o`000?oooooooooo01Sooooo2?l0000Vooooo`?o0000@?ooool8
o`0002Wooooo00?o0000ooooooooool0??ooool7o`0000Oooooo00?o0000ooooooooool0JOooool0
057ooooo00?o0000ooooooooool06?ooool9o`0002Cooooo00?o0000ooooooooool0@_ooool8o`00
02Sooooo00?o0000ooooooooool0??ooool8o`0000Oooooo00?o0000ooooooooool0J?ooool0057o
oooo00?o0000ooooooooool06Oooool9o`00023ooooo0ol00016ooooo`Oo0000:?ooool00ol0003o
ooooooooo`0mooooo`Oo00001oooool00ol0003oooooooooo`1Xooooo`00DOooool00ol0003ooooo
ooooo`0Jooooo`Wo00007?ooool3o`0004Wooooo2?l0000Vooooo`;o0000?oooool8o`0000Oooooo
00?o0000ooooooooool0Ioooool0057ooooo00?o0000ooooooooool06oooool8o`0001Sooooo1?l0
001=ooooo`Oo00008oooool3o`000003ooooool0003ooooo03oooooo1ol00008ooooo`03o`000?oo
oooooooo06Kooooo001@ooooo`03o`000?oooooooooo01gooooo2?l0000Dooooo`?o0000D_ooool7
o`0001oooooo0ol00005ooooo`03o`000?oooooooooo03kooooo1ol00008ooooo`03o`000?oooooo
oooo06Gooooo001@ooooo`03o`000?oooooooooo01kooooo2?l0000Aooooo`;o0000EOooool7o`00
01cooooo0ol00009ooooo`03o`000?oooooooooo03gooooo1ol00008ooooo`03o`000?oooooooooo
06Gooooo001@ooooo`03o`000?oooooooooo01oooooo2?l0000>ooooo`;o0000F?ooool6o`0001Wo
oooo0ol0000=ooooo`03o`000?oooooooooo03gooooo1ol00008ooooo`03o`000?oooooooooo06Co
oooo001@ooooo`03o`000?oooooooooo01oooooo2Ol00009ooooo`Co0000F_ooool7o`0001Kooooo
0_l0000Aooooo`03o`000?oooooooooo03cooooo1ol00009ooooo`03o`000?oooooooooo06?ooooo
001@ooooo`03o`000?oooooooooo023ooooo2Ol00005ooooo`?o0000Goooool6o`0001?ooooo0ol0
000Dooooo`03o`000?oooooooooo03cooooo1ol00009ooooo`03o`000?oooooooooo06;ooooo001@
ooooo`03o`000?oooooooooo027ooooo2Ol000001?oooooo0000o`000?l0001Rooooo`Oo00003ooo
ool3o`0001Oooooo00?o0000ooooooooool0??ooool7o`0000[ooooo00?o0000ooooooooool0HOoo
ool0053ooooo00?o0000ooooooooool08_ooool9o`0006Gooooo2?l0000;ooooo`?o00006oooool0
0ol0003oooooooooo`0looooo`Oo00002Oooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2
o`00037ooooo001@ooooo`03o`000?oooooooooo02?ooooo2?l0001Vooooo`Oo00002?ooool3o`00
01oooooo00?o0000ooooooooool0>oooool7o`0000[ooooo00?o0000ooooooooool0:Oooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMgC7ooooo001@ooooo`03o`000?oooooooooo02Cooooo2?l0001U
ooooo`So00001?ooool3o`0002?ooooo00?o0000ooooooooool0>oooool7o`0000[ooooo00?o0000
ooooooooool0:Oooool01?oMgMgo0000oa0@4?o<c<`booooo`00Coooool00ol0003oooooooooo`0V
ooooo`So0000IOooool7o`0000;ooooo0_l0000Wooooo`03o`000?oooooooooo03[ooooo1ol0000;
ooooo`03o`000?oooooooooo02Sooooo00Cok^k^ob4Q8Ol@413ok^k^<_ooool004oooooo00?o0000
ooooooooool09_ooool8o`0006Kooooo2?l0000Zooooo`03o`000?oooooooooo03[ooooo1ol0000:
ooooo`03o`000?oooooooooo02Sooooo00Co8B4QogMgMomgMgOo<S8b<_ooool004oooooo00?o0000
ooooooooool09oooool8o`0006Gooooo2?l0000Zooooo`03o`000?oooooooooo03[ooooo1ol00008
ooooo`Co000000?o0?l0ooooooooool09Oooool2o`0000;ooooo0_l0000aooooo`00Coooool00ol0
003oooooooooo`0Xooooo`So0000Hoooool9o`0002_ooooo00?o0000ooooooooool0>_ooool7o`00
00?ooooo1?l00004ooooo`03o`000?oooooooooo05cooooo001?ooooo`03o`000?oooooooooo02Wo
oooo2?l0001Oooooo`?o00000_ooool8o`0002_ooooo00?o0000ooooooooool0>Oooool:o`0000So
oooo00?o0?l0o`000?ooool0G?ooool004oooooo00?o0000ooooooooool0:Oooool8o`0005gooooo
0_l00006ooooo`Oo0000;?ooool00ol0003oooooooooo`0fooooo`[o00002_ooool00ol0o`3o0000
ooooo`1Looooo`00Coooool00ol0003oooooooooo`0Zooooo`So0000FOooool3o`0000Wooooo1ol0
000/ooooo`03o`000?oooooooooo02cooooo2Ol00003ooooo`Oo00002_ooool00ol0o`3oooooo`00
001Looooo`00Coooool00ol0003oooooooooo`0[ooooo`So0000EOooool3o`0000cooooo2?l0000/
ooooo`03o`000?oooooooooo02Oooooo1?l0000=ooooo`Oo00002Oooool01?l0o`3oooooooooool0
001Kooooo`00Coooool00ol0003oooooooooo`0/ooooo`So0000DOooool3o`00013ooooo1ol0000/
ooooo`03o`000?oooooooooo01oooooo2?l0000Aooooo`Oo00002Oooool01Ol0o`3ooooooooooooo
oooo000005[ooooo001>ooooo`03o`000?oooooooooo02gooooo2Ol0001=ooooo`?o00004oooool8
o`0002cooooo00?o0000ooooooooool06_ooool4o`0001[ooooo1ol00008ooooo`03o`3o0?oooooo
oooo00;ooooo00?o0000ooooooooool0Eoooool004kooooo00?o0000ooooooooool0;_ooool9o`00
04Wooooo0ol0000Gooooo`Oo0000;Oooool00ol0003oooooooooo`0Aooooo`So00007_ooool7o`00
00Sooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`00C_ooool00ol0003o
ooooooooo`0_ooooo`Wo0000A_ooool2o`0001_ooooo1ol0000]ooooo`03o`000?oooooooooo00co
oooo1?l0000Wooooo`Oo00001oooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo05Ko
oooo001>ooooo`03o`000?oooooooooo033ooooo2Ol00012ooooo`?o00007Oooool7o`0002kooooo
00?o0000ooooooooool01_ooool5o`0002_ooooo1ol00007ooooo`03o`3o0?oooooooooo00Cooooo
00?o0000ooooooooool0EOooool004kooooo00?o0000ooooooooool0<?ooool8o`000003ooooool0
003ooooo03gooooo0ol0000Qooooo`Ko0000;oooool8o`00037ooooo1ol00006ooooo`03o`3o0?oo
oooooooo00Gooooo00?o0000ooooooooool0E?ooool004kooooo00?o0000ooooooooool0<Oooool8
o`000003ooooool0003ooooo03Wooooo0ol0000Tooooo`Oo0000:_ooool5o`0003Sooooo1ol00006
ooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0E?ooool000oooooo00?oMgMgofIV
I_ooool02Oooool00ol0003o^[Zjooooo`0;ooooo`03ofIVI_mgMgOooooo02;ooooo00?o0000oooo
ooooool0<_ooool8o`000003ooooool0003ooooo03Gooooo0ol0000Xooooo`Ko00008_ooool8o`00
00Gooooo00?o0000ooooooooool0=_ooool7o`0000Gooooo00?o0?l0ooooooooool01_ooool00ol0
003oooooooooo`1Cooooo`003_ooool00ooMgMgo410@onk^kP0:ooooo`;o<S8b3?ooool00oo^k^ko
410@omgMg@0Rooooo`03o`000?oooooooooo03?ooooo1ol00002ooooo`03o`000?oooooooooo037o
oooo0_l0000[ooooo`Ko00007_ooool4o`0000kooooo00?o0000ooooooooool0=Oooool7o`0000Go
oooo00?o0?l0ooooooooool01oooool00ol0003oooooooooo`1Booooo`000oooool00ol@413o0000
o`000002o`000003oa0@4?oooooooooo00?ooooo00CoEEEEoiRHV?oooooooooo0_l00002ooooo`;o
00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00on7
QhOoIVIVooooo`0Qooooo`03o`000?oooooooooo03?ooooo2?l00002ooooo`03o`000?oooooooooo
02gooooo0ol0000]ooooo`Oo00005Oooool8o`0001?ooooo00?o0000ooooooooool0=Oooool7o`00
00Cooooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`1Aooooo`001Oooool00ol0003o
ooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo
00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?ok^k^o`000?oo
ool08Oooool00ol0003oooooooooo`0dooooo`Oo00000oooool00ol0003oooooooooo`0Yooooo`?o
0000<Oooool7o`00013ooooo1?l0000Looooo`03o`000?oooooooooo03Cooooo1ol00004ooooo`03
o`3o0?oooooooooo00Wooooo00?o0000ooooooooool0D?ooool000Gooooo00?o0000ooooooooool0
1_ooool00olb<S;oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo1ol00003ooooo`03
o`000?oooooooooo02Gooooo0ol0000dooooo`Oo00002?ooool4o`000004o`3o0?l0003o0000o`00
027ooooo00?o0000ooooooooool0=?ooool7o`0000?ooooo00?o0?l0ooooooooool02Oooool00ol0
003oooooooooo`1@ooooo`001Oooool00ol0003oooooooooo`06ooooo`03oc8b<_oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0=_ooool8o`0000?ooooo00?o0000ooooooooool08Oooool3o`00
03Oooooo2?l00003ooooo`Co00001?ooool00ol0o`3oooooooooo`0Sooooo`03o`000?oooooooooo
03?ooooo1ol00003ooooo`;o0?l02oooool00ol0003oooooooooo`1?ooooo`001Oooool00ol0003o
ooooooooo`06ooooo`03o`000?o^k^kooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`05ooooo`03onk^k_l0003ooooo023ooooo00?o0000ooooooooool0=oooool7o`00
00Cooooo00?o0000ooooooooool07_ooool2o`0003_ooooo2_l00008ooooo`03o`3o0?oooooooooo
02?ooooo00?o0000ooooooooool0=?ooool7o`0000?ooooo00?o0?l0ooooooooool02_ooool00ol0
003oooooooooo`1>ooooo`000oooool00ol@413o0000o`000003o`0000Gooooo00CoEEEEogMgMooo
oooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?oMgMgoeEE
EOooool08?ooool00ol0003oooooooooo`0gooooo`So00001?ooool00ol0003oooooooooo`0Joooo
o`?o0000>oooool:o`0000[ooooo00?o0?l0ooooooooool09?ooool00ol0003oooooooooo`0coooo
o`Oo00000oooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooooooo04gooooo0005ooooo`03
o`000?oooooooooo00Kooooo00?ogMgMoa0@4?o^k^h04Oooool00ol0003oooooooooo`04ooooo`03
onk^k_l@413ogMgM027ooooo00?o0000ooooooooool0>?ooool7o`0000Gooooo00?o0000oooooooo
ool05_ooool3o`0003Kooooo2?l00003ooooo`Oo00002_ooool00ol0o`3oooooooooo`0Uooooo`03
o`000?oooooooooo03?ooooo1ol00002ooooo`03o`3o0?oooooooooo00_ooooo00?o0000oooooooo
ool0COooool000Gooooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0@ooooo`03o`00
0?oooooooooo00Cooooo00?oIVIVogMgMoooool08Oooool00ol0003oooooooooo`0iooooo`Oo0000
1Oooool00ol0003oooooooooo`0Booooo`?o0000=?ooool5o`0000cooooo1ol00009ooooo`03o`3o
0?oooooooooo02Kooooo00?o0000ooooooooool0<_ooool7o`0000;ooooo00?o0?l0ooooooooool0
3?ooool00ol0003oooooooooo`1<ooooo`001Oooool01?nj^[[o410@o`000?l@4114ooooo`03o`00
0?oooooooooo03Wooooo2?l00005ooooo`03o`000?oooooooooo00kooooo0ol0000`ooooo`Oo0000
4Oooool7o`0000Wooooo00?o0?l0ooooooooool09oooool00ol0003oooooooooo`0booooo`Ko0000
0_ooool00ol0o`3oooooooooo`0=ooooo`03o`000?oooooooooo04_ooooo001=ooooo`03o`000?oo
oooooooo03[ooooo1ol00006ooooo`03o`000?oooooooooo00[ooooo0ol0000_ooooo`Co00006Ooo
ool7o`0000Sooooo00?o0?l0ooooooooool0:?ooool00ol0003oooooooooo`0aooooo`Oo000000?o
ooooo`3o0?ooool03oooool00ol0003oooooooooo`1:ooooo`00COooool00ol0003oooooooooo`0j
ooooo`So00001Oooool00ol0003oooooooooo`08ooooo`;o0000:_ooool8o`0001gooooo1ol00008
ooooo`03o`3o0?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool6o`000003ooooool0o`3o
oooo00oooooo00?o0000ooooooooool0B_ooool004cooooo00?o0000ooooooooool0??ooool7o`00
00Kooooo00?o0000ooooooooool01?ooool3o`0002Sooooo1?l0000Vooooo`Oo00001oooool00ol0
o`3oooooooooo`0Yooooo`03o`000?oooooooooo037ooooo1ol000000ol0o`3oooooooooo`0?oooo
o`03o`000?oooooooooo04Wooooo001<ooooo`03o`000?oooooooooo03gooooo1ol00006ooooo`03
o`000?oooooooooo00?o00008oooool8o`0002[ooooo1ol00007ooooo`03o`3o0?oooooooooo02[o
oooo00?o0000ooooooooool0<?ooool7o`000003o`3o0?oooooooooo013ooooo00?o0000oooooooo
ool0B?ooool004cooooo00?o0000ooooooooool0?Oooool7o`0000Kooooo0ol0000Rooooo`Co0000
<oooool6o`0000Oooooo00?o0?l0ooooooooool0:oooool00ol0003oooooooooo`0`ooooo`Oo0000
4oooool00ol0003oooooooooo`17ooooo`00C?ooool00ol0003oooooooooo`0nooooo`Ko00000ooo
ool3o`0000;ooooo00?o0000ooooooooool06?ooool8o`0003Oooooo1ol00006ooooo`03o`3o0?oo
oooooooo02cooooo00?o0000ooooooooool0;oooool7o`0001Cooooo00?o0000ooooooooool0A_oo
ool004cooooo00?o0000ooooooooool0?_ooool9o`0000Kooooo00?o0000ooooooooool04oooool4
o`00043ooooo1_l00006ooooo`03o`3o0?oooooooooo02gooooo00?o0000ooooooooool0;oooool6
o`0001Cooooo00?o0000ooooooooool0A_ooool004cooooo00?o0000ooooooooool0?oooool6o`00
00Wooooo00?o0000ooooooooool02_ooool8o`0004Cooooo1_l00006ooooo`03o`3o0?oooooooooo
02gooooo00?o0000ooooooooool0;oooool7o`0001Cooooo00?o0000ooooooooool0AOooool004co
oooo00?o0000ooooooooool0?oooool6o`0000[ooooo00Co0000oooooooooooooooo2?l0001<oooo
o`Oo00001Oooool00ol0o`3oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo1_l0000Eoooo
o`03o`000?oooooooooo04Cooooo001<ooooo`03o`000?oooooooooo03cooooo2_l0000:ooooo`?o
0000EOooool6o`0000Gooooo00?o0?l0ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`Oo
00005Oooool00ol0003oooooooooo`13ooooo`00C?ooool00ol0003oooooooooo`0iooooo`?o0000
1?ooool6o`0000_ooooo00?o0?l0ooooooooool0E?ooool7o`0000Cooooo00?o0?l0ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`Oo00005Oooool00ol0003oooooooooo`13ooooo`00Booo
ool00ol0003oooooooooo`0hooooo`;o00001oooool7o`0000[ooooo00?o0?l0o`000?ooool0E?oo
ool7o`0000Cooooo00?o0?l0ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`Oo00005Ooo
ool00ol0003oooooooooo`12ooooo`00Boooool00ol0003oooooooooo`0eooooo`?o00002Oooool7
o`0000[ooooo00?o0?l0ooooool00000EOooool7o`0000?ooooo00?o0?l0ooooooooool0<_ooool0
0ol0003oooooooooo`0/ooooo`Oo00005_ooool00ol0003oooooooooo`11ooooo`00Boooool00ol0
003oooooooooo`0booooo`?o00003Oooool6o`0000[ooooo00Co0?l0oooooooooooo0000E?ooool7
o`0000?ooooo00?o0?l0ooooooooool0<_ooool00ol0003oooooooooo`0]ooooo`Oo00005_ooool0
0ol0003oooooooooo`10ooooo`00Boooool00ol0003oooooooooo`0_ooooo`?o00004?ooool7o`00
00Wooooo00Go0?l0ooooooooooooooooo`00001Dooooo`Oo00000_ooool00ol0o`3oooooooooo`0c
ooooo`03o`000?oooooooooo02cooooo1ol0000Fooooo`03o`000?oooooooooo043ooooo001;oooo
o`03o`000?oooooooooo02cooooo0ol0000Dooooo`Ko00002Oooool00ol0o`3oooooooooo`02oooo
o`03o`000?oooooooooo057ooooo1ol00002ooooo`03o`3o0?oooooooooo03Cooooo00?o0000oooo
ooooool0;?ooool7o`0001Kooooo00?o0000ooooooooool0?oooool004_ooooo00?o0000oooooooo
ool0:Oooool3o`0001Oooooo1ol00008ooooo`03o`3o0?oooooooooo00?ooooo00?o0000oooooooo
ool0DOooool7o`000003ooooool0o`3ooooo03Kooooo00?o0000ooooooooool0:oooool7o`0001Oo
oooo00?o0000ooooooooool0?_ooool004_ooooo00?o0000ooooooooool09oooool2o`0001[ooooo
1ol00008ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool7o`000003oooo
ool0o`3ooooo03Oooooo00?o0000ooooooooool0:oooool7o`0001Oooooo00?o0000ooooooooool0
?Oooool004_ooooo00?o0000ooooooooool09?ooool3o`0001gooooo1ol00007ooooo`03o`3o0?oo
oooooooo00Gooooo00?o0000ooooooooool0D?ooool7o`000003o`3o0?oooooooooo03Oooooo00?o
0000ooooooooool0:_ooool7o`0001Sooooo00?o0000ooooooooool0??ooool004_ooooo00?o0000
ooooooooool08Oooool3o`00023ooooo1ol00006ooooo`03o`3o0?oooooooooo00Oooooo00?o0000
ooooooooool0Coooool7o`000003o`3o0?oooooooooo03Oooooo00?o0000ooooooooool0:oooool6
o`0001Sooooo00?o0000ooooooooool0??ooool004[ooooo00?o0000ooooooooool07oooool3o`00
02Cooooo1_l00006ooooo`03o`3o0?oooooooooo00Sooooo00?o0000ooooooooool0Coooool6o`00
0003o`3o0?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool7o`0001Sooooo00?o0000oooo
ooooool0>oooool004[ooooo00?o0000ooooooooool07?ooool3o`0002Oooooo1ol00005ooooo`03
o`3o0?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool7o`0003_ooooo00?o0000oooooooo
ool0:_ooool6o`0001Wooooo00?o0000ooooooooool0>_ooool004[ooooo00?o0000ooooooooool0
6_ooool2o`0002_ooooo1_l00005ooooo`03o`3o0?oooooooooo00[ooooo00?o0000ooooooooool0
C_ooool6o`0003cooooo00?o0000ooooooooool0:Oooool7o`0001Wooooo00?o0000ooooooooool0
>Oooool004[ooooo00?o0000ooooooooool05oooool3o`0002gooooo1ol00004ooooo`03o`3o0?oo
oooooooo00_ooooo00?o0000ooooooooool0COooool6o`0003gooooo00?o0000ooooooooool0:?oo
ool7o`0001Wooooo00?o0000ooooooooool0>Oooool004[ooooo00?o0000ooooooooool05?ooool3
o`00033ooooo1ol00004ooooo`03o`3o0?oooooooooo00cooooo00?o0000ooooooooool0C?ooool7
o`0003gooooo00?o0000ooooooooool0:?ooool7o`0001Wooooo00?o0000ooooooooool0>?ooool0
04[ooooo00?o0000ooooooooool04Oooool3o`0003Cooooo1ol00003ooooo`03o`3o0?oooooooooo
00gooooo00?o0000ooooooooool0C?ooool6o`0003gooooo00?o0000ooooooooool0:?ooool7o`00
01[ooooo00?o0000ooooooooool0=oooool004[ooooo00?o0000ooooooooool03_ooool3o`0003Oo
oooo1ol00003ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool0Boooool6o`0003ko
oooo00?o0000ooooooooool0:?ooool7o`0001[ooooo00?o0000ooooooooool0=_ooool004[ooooo
00?o0000ooooooooool02oooool3o`0003_ooooo1_l00003ooooo`03o`3o0?oooooooooo00oooooo
00?o0000ooooooooool0B_ooool7o`0003kooooo00?o0000ooooooooool09oooool7o`0001_ooooo
00?o0000ooooooooool0=Oooool004[ooooo00?o0000ooooooooool02Oooool2o`0003kooooo1ol0
0002ooooo`03o`3o0?oooooooooo013ooooo00?o0000ooooooooool0B_ooool6o`0003oooooo00?o
0000ooooooooool09oooool7o`0001[ooooo00?o0000ooooooooool0=Oooool004Wooooo00?o0000
ooooooooool01oooool3o`00047ooooo1_l00002ooooo`03o`3o0?oooooooooo017ooooo00?o0000
ooooooooool0BOooool7o`0003oooooo00?o0000ooooooooool09_ooool7o`0001_ooooo00?o0000
ooooooooool0=?ooool004Wooooo00?o0000ooooooooool01?ooool3o`0004Cooooo1_l00002oooo
o`03o`3o0?oooooooooo01;ooooo00?o0000ooooooooool0B?ooool7o`00043ooooo00?o0000oooo
ooooool09_ooool7o`0001_ooooo00?o0000ooooooooool0<oooool004Wooooo00Co0000oooooooo
oooooooo0ol00017ooooo`Oo000000?oooooo`3o0?ooool05?ooool00ol0003oooooooooo`18oooo
o`Oo0000?oooool00ol0003oooooooooo`0Vooooo`Oo00007?ooool00ol0003oooooooooo`0boooo
o`00BOooool4o`0004_ooooo1_l000000ooooooo0?l0ooooo`0Eooooo`03o`000?oooooooooo04Oo
oooo1ol00010ooooo`03o`000?oooooooooo02Kooooo1_l0000Looooo`03o`000?oooooooooo03;o
oooo0019ooooo`;o0000COooool6o`000003ooooool0o`3ooooo01Kooooo00?o0000ooooooooool0
Aoooool7o`00043ooooo00?o0000ooooooooool09Oooool7o`0001cooooo00?o0000ooooooooool0
<Oooool004_ooooo00?o0000ooooooooool0B_ooool6o`0000;o0?l06?ooool00ol0003ooooooooo
o`16ooooo`Oo0000@Oooool00ol0003oooooooooo`0Uooooo`Ko00007Oooool00ol0003ooooooooo
o`0`ooooo`00C?ooool00ol0003oooooooooo`1:ooooo`Ko00006_ooool00ol0003oooooooooo`16
ooooo`Oo0000@Oooool00ol0003oooooooooo`0Tooooo`Oo00007Oooool00ol0003oooooooooo`0_
ooooo`00COooool00ol0003oooooooooo`19ooooo`Ko00006oooool00ol0003oooooooooo`15oooo
o`Oo0000@_ooool00ol0003oooooooooo`0Sooooo`Oo00007Oooool00ol0003oooooooooo`0_oooo
o`00C_ooool00ol0003oooooooooo`18ooooo`Ko00007?ooool00ol0003oooooooooo`15ooooo`Oo
0000@Oooool00ol0003oooooooooo`0Tooooo`Oo00007Oooool00ol0003oooooooooo`0^ooooo`00
Coooool00ol0003oooooooooo`17ooooo`Oo00007?ooool00ol0003oooooooooo`14ooooo`Oo0000
@_ooool00ol0003oooooooooo`0Sooooo`Oo00007_ooool00ol0003oooooooooo`0]ooooo`00D?oo
ool00ol0003oooooooooo`17ooooo`Ko00007Oooool00ol0003oooooooooo`14ooooo`Ko0000@ooo
ool00ol0003oooooooooo`0Sooooo`Oo00007_ooool00ol0003oooooooooo`0/ooooo`00DOooool0
0ol0003oooooooooo`16ooooo`Ko00007_ooool00ol0003oooooooooo`13ooooo`Oo0000@oooool0
0ol0003oooooooooo`0Rooooo`Oo00007oooool00ol0003oooooooooo`0[ooooo`00D_ooool00ol0
003oooooooooo`15ooooo`Oo00007_ooool00ol0003oooooooooo`13ooooo`Ko0000A?ooool00ol0
003oooooooooo`0Rooooo`Ko00007oooool00ol0003oooooooooo`0[ooooo`00Doooool00ol0003o
ooooooooo`15ooooo`Ko00007oooool00ol0003oooooooooo`12ooooo`Ko0000AOooool00ol0003o
ooooooooo`0Qooooo`Oo00007oooool00ol0003oooooooooo`0Zooooo`00E?ooool00ol0003ooooo
ooooo`14ooooo`Ko00008?ooool00ol0003oooooooooo`11ooooo`Oo0000A?ooool00ol0003ooooo
ooooo`0Rooooo`Ko00008?ooool00ol0003oooooooooo`0Yooooo`00EOooool2o`0004Cooooo1ol0
000Pooooo`03o`3o0?l0003o000000Ko0000>oooool6o`0004Gooooo00?o0000ooooooooool08Ooo
ool7o`00023ooooo00?o0000ooooooooool0:?ooool005Oooooo00?o0000ooooooooool0@_ooool6
o`00023ooooo00?o0?l0o`000?ooool01_oooolBo`0002Wooooo1_l00016ooooo`03o`000?oooooo
oooo023ooooo1ol0000Pooooo`03o`000?oooooooooo02Sooooo001Hooooo`03o`000?oooooooooo
047ooooo1_l0000Pooooo`03o`3o0?oooooo000001Sooooo4ol0000Fooooo`Oo0000A_ooool00ol0
003oooooooooo`0Pooooo`Oo00008?ooool00ol0003oooooooooo`0Wooooo`00FOooool00ol0003o
ooooooooo`10ooooo`Ko00008?ooool01?l0o`3oooooooooool0000Zoooooa;o00001Oooool6o`00
04Oooooo00?o0000ooooooooool07oooool7o`00027ooooo00?o0000ooooooooool09_ooool005[o
oooo00?o0000ooooooooool0@?ooool6o`0001oooooo00Go0?l0ooooooooooooooooo`00000koooo
oa?o0000@?ooool00ol0003oooooooooo`0Oooooo`Oo00007_ooool4o`0002Oooooo001Kooooo`03
o`000?oooooooooo03oooooo1_l0000Oooooo`03o`3o0?oooooooooo00;ooooo00?o0000oooooooo
ool0?Oooool7o`0000Oooooo4_l0000_ooooo`03o`000?oooooooooo01kooooo1ol0000Fooooo`So
00000oooool00ol0o`3o0000ooooo`0Uooooo`00G?ooool00ol0003oooooooooo`0nooooo`Ko0000
7oooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo03gooooo1ol0000Hooooo`ko0000
00?o0?l0o`000?l000000_l0000Looooo`03o`000?oooooooooo01oooooo1ol0000=ooooo`So0000
2oooool00ol0o`3o0000ooooo`0Uooooo`00GOooool00ol0003oooooooooo`0mooooo`Ko00007ooo
ool00ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo03cooooo1ol0000Vooooo`03o`3o0?oo
oooooooo00;ooooo4_l0000;ooooo`03o`000?oooooooooo01kooooo1ol00009ooooo`Co00004ooo
ool00ol0o`3oooooo`00000Uooooo`00G_ooool00ol0003oooooooooo`0mooooo`Go00007oooool0
0ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo03cooooo1ol0000Uooooo`03o`3o0?oooooo
oooo01Cooooo4ol0000Jooooo`oo00005oooool01?l0o`3oooooooooool0000Tooooo`00Goooool0
0ol0003oooooooooo`0looooo`Ko00007_ooool00ol0o`3oooooooooo`06ooooo`03o`000?oooooo
oooo03_ooooo1ol0000Uooooo`03o`3o0?oooooooooo027ooooo00?o0000ooooooooool00ooooolB
o`0000Oooooo2?l0000Oooooo`03o`3o0?l0003o000000?o00008_ooool0063ooooo00?o0000oooo
ooooool0>oooool6o`0001kooooo00?o0?l0ooooooooool01oooool00ol0003oooooooooo`0koooo
o`Oo00009?ooool00ol0o`3oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo4_l0000Koooo
o`03o`000?l0o`3o000000Go00008Oooool0067ooooo00?o0000ooooooooool0>_ooool6o`0001ko
oooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0jooooo`Oo00009?ooool00ol0o`3o
ooooooooo`0Sooooo`03o`000?oooooooooo00oooooo2?l00005ooooo`Oo00000_oooolBo`0000So
oooo2_l0000Pooooo`00H_ooool2o`0003[ooooo1ol0000Mooooo`03o`3o0?oooooooooo00Wooooo
00?o0000ooooooooool0>_ooool6o`0002Cooooo00?o0?l0ooooooooool08oooool00ol0003ooooo
ooooo`07ooooo`So00003_ooool7o`0001?ooooo5?l0000Nooooo`00I?ooool00ol0003ooooooooo
o`0hooooo`Ko00007Oooool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo1ol0
000Sooooo`03o`3o0?oooooooooo02Cooooo00?o0000ooooooooool00_ooool4o`0001Kooooo1ol0
000Jooooo`ko00007Oooool006Gooooo00?o0000ooooooooool0=oooool6o`0001gooooo00?o0?l0
ooooooooool02oooool00ol0003oooooooooo`0iooooo`Ko00008oooool00ol0o`3oooooooooo`0R
ooooo`Oo00006oooool7o`0001Wooooo3_l0000Mooooo`00I_ooool00ol0003oooooooooo`0foooo
o`Oo00007?ooool00ol0o`3oooooooooo`0<ooooo`03o`000?oooooooooo03Sooooo1ol0000Roooo
o`03o`3o0?oooooooooo01[ooooo2?l00004ooooo`03o`000?oooooooooo01_ooooo1ol0000Ioooo
o`oo00007?ooool006Oooooo00?o0000ooooooooool0=_ooool6o`0001cooooo00?o0?l0oooooooo
ool03Oooool00ol0003oooooooooo`0gooooo`Oo00008_ooool00ol0o`3oooooooooo`0Fooooo`Co
00003Oooool00ol0003oooooooooo`0Kooooo`Oo00006?ooool6o`000003ooooool0003o000000Oo
00006oooool006Sooooo00?o0000ooooooooool0=Oooool6o`0001cooooo00?o0?l0ooooooooool0
3_ooool00ol0003oooooooooo`0gooooo`Ko00008_ooool00ol0o`3oooooooooo`0>ooooo`So0000
4_ooool00ol0003oooooooooo`0Jooooo`Oo00005Oooool8o`0000Cooooo00?o0000o`3o0?l00000
1Ol0000Jooooo`00JOooool00ol0003oooooooooo`0dooooo`Oo00006oooool00ol0o`3ooooooooo
o`0?ooooo`03o`000?oooooooooo03Kooooo1ol0000Qooooo`03o`3o0?oooooooooo00Oooooo00?o
0?l0o`000?l000001?l0000Jooooo`03o`000?oooooooooo01_ooooo1ol0000Aooooo`?o00000ooo
ool5o`0000Cooooo00?o0000o`3o0?l000001_l0000Iooooo`00J_ooool00ol0003oooooooooo`0d
ooooo`Ko00006oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo1_l0000Q
ooooo`03o`3o0?oooooo000000Oo000000?o0?l0ooooooooool07oooool00ol0003oooooooooo`0J
ooooo`Oo00003Oooool4o`0000Kooooo1Ol00005ooooo`03o`3o0?l0003o000000Go00006Oooool0
06_ooooo00?o0000ooooooooool0<oooool6o`0001_ooooo00?o0?l0ooooooooool04Oooool00ol0
003oooooooooo`0eooooo`Ko00007oooool2o`000003o`3o0?l0003ooooo00Oooooo00?o0?l0oooo
ooooool08?ooool00ol0003oooooooooo`0Jooooo`Oo00002Oooool3o`0000[ooooo1_l00004oooo
o`03o`3o0?l0003o000000Ko00006?ooool006cooooo00?o0000ooooooooool0<_ooool6o`0001[o
oooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`0dooooo`Oo00005oooool7o`0000;o
oooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0Qooooo`03o`000?oooooooooo01Wo
oooo1ol00006ooooo`?o00003Oooool6o`0000Cooooo00?o0?l0ooooool000001ol0000Gooooo`00
KOooool00ol0003oooooooooo`0booooo`Ko00006Oooool00ol0o`3oooooooooo`0Dooooo`03o`00
0?oooooooooo03Cooooo1_l0000?ooooo`So00002Oooool00ol0o`3oooooooooo`07ooooo`03o`3o
0?oooooooooo02;ooooo00?o0000ooooooooool06Oooool7o`0000?ooooo0_l0000@ooooo`Ko0000
1?ooool00ol0o`3oooooooooo`08o`0001Kooooo001^ooooo`;o0000<_ooool6o`0001Wooooo00?o
0?l0ooooooooool05Oooool00ol0003oooooooooo`0cooooo`Oo00002_ooool4o`00017ooooo00?o
0?l0ooooooooool01oooool00ol0o`3oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo1ol0
00000ooooooo0000o`00000Booooo`Ko00001?ooool00ol0o`3oooooooooo`09o`0001Gooooo001`
ooooo`03o`000?oooooooooo02oooooo1_l0000Iooooo`03o`3o0?oooooooooo01Kooooo00?o0000
ooooooooool0<_ooool7o`0000?ooooo1ol0000Eooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0
ooooooooool08oooool00ol0003oooooooooo`0Iooooo`Oo00005Oooool5o`0000Cooooo00Co0?l0
oooooooooooooooo2Ol0000Dooooo`00LOooool00ol0003oooooooooo`0^ooooo`Ko00006Oooool0
0ol0o`3oooooooooo`0Fooooo`03o`000?oooooooooo03?ooooo2Ol0000Looooo`03o`3o0?oooooo
oooo00Oooooo00?o0?l0ooooooooool09?ooool00ol0003oooooooooo`0Hooooo`Oo00005Oooool5
o`0000Gooooo00Co0?l0oooooooooooooooo2?l0000Dooooo`00L_ooool00ol0003oooooooooo`0^
ooooo`Go00006Oooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo3Ol0000N
ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool09Oooool00ol0003oooooooooo`0C
ooooo`Co000000?oooooo`000?l000001?l0000Eooooo`Ko00001?ooool00ol0o`3oooooooooo`02
ooooo`So00004oooool007?ooooo00?o0000ooooooooool0;Oooool6o`0001Sooooo00?o0?l0oooo
ooooool06?ooool00ol0003oooooooooo`0Wooooo`Co00001oooool6o`0001kooooo00?o0?l0oooo
ooooool01oooool00ol0o`3oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo0ol00005oooo
o`Oo00005?ooool6o`0000Cooooo00?o0?l0ooooooooool00oooool8o`0001;ooooo001dooooo`03
o`000?oooooooooo02cooooo1_l0000Hooooo`03o`3o0?oooooooooo01Wooooo00?o0000oooooooo
ool07oooool7o`0000_ooooo1ol0000Mooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooooooo
ool09_ooool00ol0003oooooooooo`0;ooooo`?o00002?ooool7o`0001Cooooo1_l00004ooooo`03
o`3o0?oooooooooo00Cooooo2?l0000Aooooo`00MOooool00ol0003oooooooooo`0[ooooo`Ko0000
6?ooool00ol0o`3oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo2?l0000Booooo`Oo0000
7Oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo02Oooooo00?o0000ooooooooool0
1_ooool4o`0000cooooo1ol0000Cooooo`Ko00001?ooool00ol0o`3oooooooooo`04ooooo`Wo0000
4?ooool007Kooooo00?o0000ooooooooool0:_ooool6o`0001Sooooo00?o0?l0ooooooooool06ooo
ool00ol0003oooooooooo`0>ooooo`Oo00006oooool7o`0001cooooo00?o0?l0ooooooooool02?oo
ool00ol0o`3oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo0ol0000@ooooo`Oo00005?oo
ool5o`0000Cooooo00?o0?l0ooooooooool01Oooool9o`0000oooooo001gooooo`03o`000?oooooo
oooo02[ooooo1_l0000Gooooo`03o`3o0?oooooooooo01cooooo00?o0000ooooooooool02Oooool4
o`0002;ooooo1ol0000Looooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool0:?ooool5
o`0001Cooooo1ol0000Cooooo`Go00001?ooool00ol0o`3oooooooooo`06ooooo`So00003oooool0
07Sooooo00?o0000ooooooooool0:Oooool6o`0001Oooooo00?o0?l0ooooooooool07Oooool01?l0
003oooooooooooooool7o`0002Oooooo1ol0000Kooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0
ooooooooool09_ooool4o`0001Oooooo1ol0000Cooooo`Go00001?ooool00ol0o`3oooooooooo`07
ooooo`So00003_ooool007Wooooo00?o0000ooooooooool0:?ooool6o`0001Oooooo00?o0?l0oooo
ooooool07_ooool00ol0o`3o0000o`00000^ooooo`Oo00006oooool00ol0o`3oooooooooo`08oooo
o`03o`3o0?oooooooooo02;ooooo1?l00004ooooo`03o`000?oooooooooo01Gooooo1_l0000Coooo
o`Ko00000oooool00ol0o`3oooooooooo`08ooooo`So00003Oooool007[ooooo00?o0000oooooooo
ool09oooool7o`0001Kooooo00?o0?l0ooooooooool07_ooool00ol0o`3o0000ooooo`0_ooooo`Ko
00006oooool00ol0o`3oooooooooo`08ooooo`04o`3o0?ooooooooooooooo`[o00005?ooool3o`00
00Wooooo00?o0000ooooooooool05?ooool7o`0001;ooooo0ol000000ol0o`3o0000o`000003oooo
o`03o`3o0?oooooooooo00Wooooo1ol0000=ooooo`00Noooool2o`0002Sooooo1_l0000Fooooo`03
o`3o0?oooooooooo01kooooo00?o0?l0ooooool00000;oooool7o`0001[ooooo00?o0?l0oooooooo
ool02?ooool00ol0o`3oooooooooo`0<o`00013ooooo0ol0000=ooooo`03o`000?oooooooooo01Co
oooo1_l0000Booooo`?o000000?o0?l0o`000?l000000oooool00ol0o`3oooooooooo`09ooooo`So
00003?ooool007gooooo00?o0000ooooooooool09Oooool6o`0001Kooooo00?o0?l0ooooooooool0
7_ooool01?l0o`3oooooooooool0000_ooooo`Ko00006_ooool00ol0o`3oooooooooo`08ooooo`03
o`3o0?oooooooooo00oo00002Oooool4o`00013ooooo00?o0000ooooooooool05?ooool7o`00017o
oooo1_l00003ooooo`03o`3o0?oooooooooo00[ooooo2?l0000;ooooo`00O_ooool00ol0003ooooo
ooooo`0Tooooo`Oo00005Oooool00ol0o`3oooooooooo`0Nooooo`05o`3o0?ooooooooooooooool0
0000;_ooool6o`0001[ooooo00?o0?l0ooooooooool02?ooool00ol0o`3oooooo`00000@o`0000Go
oooo0ol0000Eooooo`03o`000?oooooooooo01?ooooo1ol0000Booooo`Go00000oooool00ol0o`3o
ooooooooo`0;ooooo`So00002_ooool007oooooo00?o0000ooooooooool09?ooool6o`0001Gooooo
00?o0?l0ooooooooool07_ooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo
1ol0000Iooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0o`000?l000004Ol000001?oooooo0000
o`000?l0000Iooooo`03o`000?oooooooooo01?ooooo1ol0000Aooooo`Go00000oooool00ol0o`3o
ooooooooo`0;ooooo`Wo00002Oooool0083ooooo00?o0000ooooooooool08oooool6o`0001Gooooo
00?o0?l0ooooooooool07_ooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo
1_l0000Iooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0o`000?l000001Ol00002ooooo`_o0000
7Oooool00ol0003oooooooooo`0Booooo`Oo00004Oooool6o`0000?ooooo00?o0?l0ooooooooool0
2oooool9o`0000Sooooo0021ooooo`03o`000?oooooooooo02;ooooo1_l0000Eooooo`03o`3o0?oo
oooooooo01kooooo00?o0?l0ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`Ko00006Ooo
ool00ol0o`3oooooooooo`08ooooo`03o`3o0?l0003o000000Go00000oooool;o`0001gooooo00?o
0000ooooooooool04_ooool7o`00013ooooo1_l00003ooooo`03o`3o0?oooooooooo00cooooo2?l0
0008ooooo`00P_ooool00ol0003oooooooooo`0Rooooo`Ko00005?ooool00ol0o`3oooooooooo`0N
ooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool7o`0001Sooooo00?o0?l0
ooooooooool02?ooool00ol0o`3o0000o`000004o`0000Cooooo3?l0000Mooooo`03o`000?oooooo
oooo017ooooo1ol0000@ooooo`Ko00000oooool00ol0o`3oooooooooo`0=ooooo`Oo00002?ooool0
08?ooooo00?o0000ooooooooool08Oooool6o`0001Cooooo00?o0?l0ooooooooool07_ooool00ol0
o`3oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo1_l0000Hooooo`03o`3o0?oooooooooo
00Oooooo00?o0000o`3o0?l000001?l000000ooooooo0000o`000002o`0000Cooooo2Ol0000Loooo
o`03o`000?oooooooooo01;ooooo1ol0000?ooooo`Ko00000oooool00ol0o`3oooooooooo`0>oooo
o`Ko00002?ooool008Cooooo00?o0000ooooooooool08?ooool6o`0001?ooooo00?o0?l0oooooooo
ool07oooool00ol0o`3oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo1ol0000Gooooo`03
o`3o0?oooooooooo00Oooooo00?o0000o`3o0?l000001Ol00009ooooo`Wo00007?ooool00ol0003o
ooooooooo`0Aooooo`Oo00004?ooool5o`0000?ooooo00?o0?l0ooooooooool03oooool5o`0000So
oooo0025ooooo`03o`000?oooooooooo01oooooo1_l0000Cooooo`03o`3o0?oooooooooo01oooooo
00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`Oo00005oooool00ol0o`3ooooo
ooooo`07ooooo`03o`000?l0o`3o000000?o00003?ooool8o`0001gooooo00?o0000ooooooooool0
4Oooool7o`0000oooooo1_l00002ooooo`03o`3o0?oooooooooo017ooooo0ol00008ooooo`00Q_oo
ool00ol0003oooooooooo`0Oooooo`Go00004oooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oo
oooooooo00Wooooo00?o0000ooooooooool09oooool7o`0001Kooooo00?o0?l0ooooooooool01Ooo
ool3o`000003o`3o0?l0003o000000;o00003Oooool8o`0001gooooo00?o0000ooooooooool04?oo
ool7o`0000oooooo1_l00002ooooo`03o`3o0?oooooooooo00kooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo0027ooooo`;o00007oooool6o`0001;ooooo00?o0?l0ooooooooool07oooool0
0ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1ol0000Fooooo`03o`3o0?oooooo
oooo00;ooooo0ol00002ooooo`03o`000?l0o`3o000000;o00003oooool8o`0001gooooo00?o0000
ooooooooool04?ooool6o`0000oooooo1_l00002ooooo`03o`3o0?oooooooooo00_ooooo0ol00005
ooooo`03o`000?oooooooooo00Kooooo0029ooooo`03o`000?oooooooooo01cooooo1_l0000Boooo
o`03o`3o0?oooooooooo01oooooo00?o0?l0ooooooooool02oooool00ol0003oooooooooo`0Voooo
o`Ko00005_ooool00ol0o`3oooooo`000002o`0000Cooooo0_l000001?l0o`3o0000o`000?l0000@
ooooo`So00007Oooool00ol0003oooooooooo`0?ooooo`Oo00003_ooool6o`0000;ooooo00?o0?l0
ooooooooool01oooool4o`0000Sooooo00?o0000ooooooooool01_ooool008[ooooo00?o0000oooo
ooooool06oooool6o`0001;ooooo00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0<oooo
o`03o`000?oooooooooo02Gooooo1ol0000Cooooo`;o000000?o0?l0o`000?ooool01_ooool6o`00
013ooooo2_l0000Kooooo`03o`000?oooooooooo013ooooo1_l0000?ooooo`Ko000000?oooooo`3o
0?ooool01Oooool3o`0000cooooo00?o0000ooooooooool01_ooool008_ooooo00?o0000oooooooo
ool06_ooool6o`0001;ooooo00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0=ooooo`03
o`000?oooooooooo02Gooooo1_l0000@ooooo`?o00000_ooool00ol0o`3oooooooooo`06ooooo`;o
000000Co0?l0o`000?l0003o00004Oooool:o`0001_ooooo00?o0000ooooooooool03oooool7o`00
00kooooo1_l000000ooooooo0?l0ooooo`02ooooo`?o00003oooool00ol0003oooooooooo`06oooo
o`00S?ooool00ol0003oooooooooo`0Jooooo`Ko00004Oooool00ol0o`3oooooooooo`0Oooooo`03
o`3o0?oooooooooo00kooooo00?o0000ooooooooool09?ooool6o`0000gooooo0ol00005ooooo`03
o`3o0?oooooooooo00Kooooo0_l000001?l0o`3o0000o`000?l0000Booooo`[o00006oooool00ol0
003oooooooooo`0>ooooo`Oo00003_ooool6o`000003ooooool0o`3o000000;o00004_ooool00ol0
003oooooooooo`06ooooo`00SOooool00ol0003oooooooooo`0Iooooo`Ko00004Oooool00ol0o`3o
ooooooooo`0Oooooo`03o`3o0?oooooooooo00oooooo00?o0000ooooooooool08oooool7o`0000So
oooo1?l00008ooooo`03o`3o0?oooooooooo00Kooooo0_l000000ol0o`3o0000o`00000Dooooo`Wo
00007?ooool00ol0003oooooooooo`0>ooooo`Oo00003Oooool7o`000003o`3o0?oooooooooo01Co
oooo00?o0000ooooooooool01Oooool008kooooo00?o0000ooooooooool06?ooool6o`00017ooooo
00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo
1_l00005ooooo`?o00003?ooool00ol0o`3oooooooooo`06ooooo`;o000000?o0?l0o`000?l00000
5Oooool9o`0001cooooo00?o0000ooooooooool03Oooool7o`0000gooooo1ol000000ooooooo0?l0
ooooo`0Dooooo`03o`000?oooooooooo00Gooooo002?ooooo`03o`000?oooooooooo01Oooooo1ol0
000@ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0ooooooooool04Oooool00ol0003ooooooooo
o`0Rooooo`Ko00000_ooool3o`0000oooooo00?o0?l0ooooooooool01_ooool2o`000003o`3o0?l0
003o000001Oooooo2?l0000Looooo`03o`000?oooooooooo00gooooo1ol00009ooooo`?o000000?o
ooooo`000?l000001?l000000ooooooo0?l0ooooo`0Dooooo`03o`000?oooooooooo00Gooooo002@
ooooo`03o`000?oooooooooo01Oooooo1_l0000@ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0
ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`So00004_ooool00ol0o`3oooooooooo`06
ooooo`Go00006?ooool8o`0001_ooooo00?o0000ooooooooool03Oooool7o`0000Kooooo0ol00004
ooooo`Oo000000?o0?l0ooooooooool04oooool00ol0003oooooooooo`05ooooo`00TOooool00ol0
003oooooooooo`0Fooooo`Ko00004?ooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo
01?ooooo00?o0000ooooooooool08Oooool6o`0001?ooooo00?o0?l0ooooooooool01_ooool5o`00
01Sooooo2Ol0000Kooooo`03o`000?oooooooooo00gooooo1ol000000ooooooo0000o`000002o`00
00Sooooo1_l000000ol0o`3oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo002Booooo`03
o`000?oooooooooo01Gooooo1ol0000?ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0oooooooo
ool01_ooool<o`0000;ooooo00?o0000ooooooooool07Oooool:o`0001;ooooo00?o0?l0oooooooo
ool01_ooool5o`0001Wooooo2Ol0000Kooooo`03o`000?oooooooooo00cooooo2?l0000<ooooo`Ko
000000?o0?l0ooooooooool04oooool00ol0003oooooooooo`05ooooo`00Toooool00ol0003ooooo
ooooo`0Eooooo`Ko00003oooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo00?ooooo
4ol0000Kooooo`?o00000oooool7o`0001?ooooo00?o0?l0ooooooooool01Oooool5o`0001[ooooo
2Ol0000Kooooo`03o`000?oooooooooo00cooooo1ol0000<ooooo`Ko000000?o0?l0ooooooooool0
4oooool00ol0003oooooooooo`05ooooo`00U?ooool2o`0001Gooooo1_l0000?ooooo`03o`3o0?oo
oooooooo01oooooo00Co0?l0oooooooooooooooo5_l0000Gooooo`?o00001oooool7o`0001;ooooo
00?o0?l0ooooooooool01Oooool5o`0001_ooooo2?l0000Looooo`03o`000?oooooooooo00Sooooo
2_l0000=ooooo`Go000000?o0?l0ooooooooool04oooool00ol0003oooooooooo`05ooooo`00U_oo
ool00ol0003oooooooooo`0Booooo`Ko00003oooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oo
oooooooo01[o00004?ooool4o`0000[ooooo1ol0000Booooo`03o`3o0?oooooooooo00Gooooo1Ol0
000Looooo`So00007?ooool00ol0003oooooooooo`04ooooo`?o00001?ooool6o`0000gooooo1_l0
000Eooooo`03o`000?oooooooooo00Gooooo002Gooooo`03o`000?oooooooooo01;ooooo1_l0000>
ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0ooooool000006ol0000<ooooo`?o00003oooool7
o`00017ooooo00?o0?l0ooooooooool01Oooool5o`0001gooooo2?l0000Looooo`03o`000?oooooo
oooo00?o00001oooool7o`0000cooooo1_l0000Eooooo`03o`000?oooooooooo00Gooooo002Hoooo
o`03o`000?oooooooooo017ooooo1_l0000>ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0o`00
0?l000002_l00004ooooo`ko00002?ooool3o`0001;ooooo1ol0000Aooooo`03o`3o0?oooooooooo
00Gooooo1Ol0000Nooooo`So00006_ooool4o`0000_ooooo1_l0000<ooooo`Ko00005Oooool00ol0
003oooooooooo`05ooooo`00VOooool00ol0003oooooooooo`0@ooooo`Ko00003_ooool00ol0o`3o
ooooooooo`0Oooooo`03o`3o0?l0003o000000Oo00002oooool;o`000003ooooool0003o000000Co
00005_ooool7o`00013ooooo00?o0?l0ooooooooool01Oooool5o`0001kooooo2Ol0000Fooooo`?o
00000_ooool00ol0003oooooooooo`0:ooooo`Oo00002oooool6o`0001Gooooo00?o0000oooooooo
ool01Oooool009[ooooo00?o0000ooooooooool03oooool6o`0000kooooo00?o0?l0ooooooooool0
7_ooool00ol0003o0?l0o`000006o`0000kooooo2ol0000Looooo`Oo00004?ooool00ol0o`3ooooo
ooooo`05ooooo`Go00007oooool8o`0001?ooooo0ol00006ooooo`03o`000?oooooooooo00Wooooo
1ol0000<ooooo`Go00005_ooool00ol0003oooooooooo`04ooooo`00Voooool00ol0003ooooooooo
o`0?ooooo`Go00003Oooool00ol0o`3oooooooooo`0Oooooo`03o`000?l0o`3o000000Go00004_oo
ool:o`0001_ooooo1ol0000?ooooo`03o`3o0?oooooooooo00Gooooo1Ol0000Pooooo`So00003_oo
ool4o`0000[ooooo00?o0000ooooooooool02Oooool7o`0000_ooooo1_l0000Eooooo`03o`000?oo
oooooooo00Cooooo002Looooo`03o`000?oooooooooo00kooooo1_l0000<ooooo`03o`3o0?oooooo
oooo01kooooo0_l000000ol0o`3o0000o`000003o`0001Cooooo2_l0000Jooooo`Oo00003oooool0
0ol0o`3oooooooooo`04ooooo`Ko00008Oooool8o`0000[ooooo0ol0000?ooooo`03o`000?oooooo
oooo00Sooooo1ol0000;ooooo`Ko00005Oooool00ol0003oooooooooo`04ooooo`00WOooool00ol0
003oooooooooo`0=ooooo`Ko00003?ooool00ol0o`3oooooooooo`0Mooooo`So00005_ooool:o`00
01[ooooo1ol0000>ooooo`03o`3o0?oooooooooo00Cooooo1_l0000Rooooo`So00001_ooool3o`00
01?ooooo00?o0000ooooooooool02?ooool6o`0000_ooooo1_l0000Eooooo`03o`000?oooooooooo
00Cooooo002Nooooo`03o`000?oooooooooo00cooooo1_l0000<ooooo`03o`3o0?oooooooooo01co
oooo2?l0000Hooooo`[o00006Oooool7o`0000kooooo00?o0?l0ooooooooool01?ooool6o`0002;o
oooo2Ol000000ooooooo0000o`000002o`0001Kooooo00?o0000ooooooooool02?ooool7o`0000[o
oooo1_l0000Eooooo`03o`000?oooooooooo00Cooooo002Oooooo`03o`000?oooooooooo00_ooooo
1ol0000;ooooo`03o`3o0?oooooooooo01_ooooo2Ol0000Iooooo`[o00006Oooool6o`0000kooooo
00?o0?l0ooooooooool01?ooool6o`0002?ooooo2Ol0000Kooooo`03o`000?oooooooooo00Sooooo
1_l0000;ooooo`Go00005Oooool00ol0003oooooooooo`04ooooo`00X?ooool2o`0000cooooo1_l0
000;ooooo`03o`3o0?oooooooooo01[ooooo2Ol0000Looooo`Wo00006?ooool7o`0000gooooo00?o
0?l0ooooooooool01?ooool5o`0002Gooooo1ol0000Mooooo`03o`000?oooooooooo00Oooooo1ol0
000:ooooo`Ko00005?ooool00ol0003oooooooooo`04ooooo`00X_ooool00ol0003oooooooooo`09
ooooo`Ko00002oooool00ol0o`3oooooooooo`0Jooooo`So00007_ooool:o`0001Oooooo1_l0000=
ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Sooooo`Wo00007_ooool00ol0003oooooooooo`06
ooooo`Oo00002_ooool6o`0001Cooooo00?o0000ooooooooool01?ooool00:?ooooo00?o0000oooo
ooooool02?ooool7o`0000[ooooo00?o0?l0ooooooooool06Oooool8o`00023ooooo2_l0000Foooo
o`Ko00003Oooool00ol0o`3oooooooooo`04ooooo`Go00008?ooool3o`0000Cooooo1Ol0000Ooooo
o`03o`000?oooooooooo00Kooooo1ol00009ooooo`Ko00005?ooool00ol0003oooooooooo`04oooo
o`00Y?ooool00ol0003oooooooooo`08ooooo`Ko00002_ooool00ol0o`3oooooooooo`0Hooooo`So
00008_ooool:o`0001Gooooo1ol0000<ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Looooo`Co
0000;?ooool00ol0003oooooooooo`05ooooo`Oo00002Oooool7o`0001?ooooo00?o0000oooooooo
ool01?ooool00:Gooooo00?o0000ooooooooool01oooool6o`0000[ooooo00?o0?l0ooooooooool0
5oooool8o`0002Cooooo2_l0000Eooooo`Ko00003?ooool00ol0o`3oooooooooo`04ooooo`Go0000
6Oooool3o`00033ooooo00?o0000ooooooooool01_ooool7o`0000Wooooo1_l0000Cooooo`03o`00
0?oooooooooo00Cooooo002Vooooo`03o`000?oooooooooo00Kooooo1ol00009ooooo`03o`3o0?oo
oooooooo01Oooooo2?l0000Uooooo`[o00005?ooool7o`0000_ooooo00?o0?l0ooooooooool01?oo
ool5o`0001Kooooo0ol0000dooooo`03o`000?oooooooooo00Gooooo1ol00009ooooo`Ko00004ooo
ool00ol0003oooooooooo`04ooooo`00Yoooool00ol0003oooooooooo`06ooooo`Ko00002Oooool0
0ol0o`3oooooooooo`0Fooooo`So0000:?ooool8o`0001Cooooo1ol0000;ooooo`03o`3o0?oooooo
oooo00Cooooo1Ol0000Booooo`Co0000>?ooool00ol0003oooooooooo`05ooooo`Oo00002?ooool7
o`0001?ooooo00?o0000ooooooooool00oooool00:Sooooo00?o0000ooooooooool01Oooool7o`00
00Sooooo00?o0?l0ooooooooool05Oooool8o`0002[ooooo2?l0000Dooooo`Oo00002_ooool00ol0
o`3oooooooooo`04ooooo`Go00003oooool3o`0003gooooo00?o0000ooooooooool01?ooool7o`00
00Wooooo1_l0000Cooooo`03o`000?oooooooooo00?ooooo002Yooooo`03o`000?oooooooooo00Co
oooo1ol00008ooooo`03o`3o0?oooooooooo01Cooooo2?l0000/ooooo`Wo00004_ooool7o`0000[o
oooo00?o0?l0ooooooooool01?ooool5o`0000cooooo0ol00011ooooo`03o`000?oooooooooo00Co
oooo1ol00008ooooo`Ko00004oooool00ol0003oooooooooo`03ooooo`00Z_ooool00ol0003ooooo
ooooo`04ooooo`Oo00001oooool00ol0o`3oooooooooo`0Dooooo`So0000;Oooool9o`0001;ooooo
1ol00009ooooo`03o`3o0?oooooooooo00Cooooo1Ol00008ooooo`Co0000AOooool00ol0003ooooo
ooooo`03ooooo`Oo00002?ooool6o`0001?ooooo00?o0000ooooooooool00oooool00:_ooooo00?o
0000ooooooooool00oooool7o`0000Oooooo00?o0?l0ooooooooool04oooool8o`0002kooooo2_l0
000Aooooo`Oo00002Oooool00ol0o`3oooooooooo`04ooooo`Go00001Oooool3o`0004Wooooo00?o
0000ooooooooool01?ooool7o`0000Sooooo0_l000001?l0o`3o0000o`000?l0000Booooo`03o`00
0?oooooooooo00?ooooo002/ooooo`03o`000?oooooooooo00?ooooo1_l00007ooooo`03o`3o0?oo
oooooooo01;ooooo2?l0000`ooooo`[o00004Oooool6o`0000Wooooo00?o0?l0ooooooooool01?oo
ool5o`0000;ooooo0ol0001=ooooo`03o`000?oooooooooo00?ooooo1ol00008ooooo`;o000000Co
0?l0o`000?l0003o00004_ooool00ol0003oooooooooo`03ooooo`00[Oooool2o`0000?ooooo1ol0
0006ooooo`03o`3o0?oooooooooo017ooooo2?l0000booooo`[o00004?ooool7o`0000Sooooo00?o
0?l0ooooooooool01?ooool7o`00057ooooo00?o0000ooooooooool00oooool7o`0000Oooooo0_l0
00001?l0o`3o0000o`000?l0000Booooo`03o`000?oooooooooo00?ooooo002_ooooo`04o`000?oo
ooooooooooooo`Ko00001_ooool00ol0o`3oooooooooo`0Aooooo`So0000=?ooool9o`00013ooooo
1_l00008ooooo`03o`3o0?oooooooooo00Cooooo1Ol0001Dooooo`03o`000?oooooooooo00;ooooo
1ol00007ooooo`;o000000Co0?l0o`000?l0003o00004_ooool00ol0003oooooooooo`03ooooo`00
/?ooool00ol0003oooooooooo`07o`0000Gooooo00?o0?l0ooooooooool04?ooool8o`0003Kooooo
2Ol0000?ooooo`Ko00002?ooool01?l0o`3oooooooooooooool8o`0005Gooooo00?o0000oooooooo
ool00_ooool7o`0000Oooooo00?o0000o`3o0?l000000_l0000Booooo`03o`000?oooooooooo00?o
oooo002aooooo`03o`000?oooooo000000Ko00001Oooool00ol0o`3oooooooooo`0?ooooo`So0000
>?ooool8o`0000oooooo1ol00007ooooo`04o`3o0?l0003o0000o`0000?ooooo1Ol0001Fooooo`04
o`000?ooooooooooooooo`Oo00001oooool00ol0003o0?l0o`000003o`00017ooooo00?o0000oooo
ooooool00oooool00;;ooooo00?o0000ooooool000001Ol00005ooooo`03o`3o0?oooooooooo00ko
oooo2?l0000jooooo`So00003oooool7o`0000?ooooo0ol000000ol0o`3oooooooooo`03ooooo`Ko
0000E_ooool00ol0003oooooooooo`02ooooo`Oo00001_ooool00ol0003o0?l0o`000003o`00017o
oooo00?o0000ooooooooool00oooool00;?ooooo2?l00004ooooo`03o`3o0?oooooooooo00kooooo
2?l0000kooooo`Wo00003Oooool:o`0000?ooooo00?o0?l0ooooooooool00oooool6o`0005Oooooo
00Co0000oooooooooooooooo1ol00006ooooo`03o`000?l0o`3o000000?o00004Oooool00ol0003o
ooooooooo`03ooooo`00]?ooool7o`0000?ooooo00?o0?l0ooooooooool03_ooool8o`0003gooooo
2Ol0000<ooooo`So00001Oooool00ol0o`3oooooooooo`03ooooo`Ko0000F?ooool01?l0003ooooo
ooooooooool7o`0000Gooooo00?o0000o`3o0?l000000ol0000Booooo`03o`000?oooooooooo00;o
oooo002eooooo`Ko00000oooool00ol0o`3oooooooooo`0>ooooo`Oo0000?_ooool:o`0000_ooooo
2?l00005ooooo`03o`3o0?oooooooooo00?ooooo1_l0001Iooooo`03o`000?oooooooooo00Oo0000
1_ooool00ol0o`3o0000o`000002o`0001;ooooo00?o0000ooooooooool00_ooool00;Gooooo1ol0
0002ooooo`03o`3o0?oooooooooo00gooooo1ol00010ooooo`[o00001_ooool4o`0000;ooooo1ol0
0004ooooo`03o`3o0?oooooooooo00?ooooo1Ol0001Kooooo`03o`000?oooooooooo00Oo00001Ooo
ool00ol0o`3o0000o`000003o`00017ooooo00?o0000ooooooooool00_ooool00;Kooooo1ol00000
0ooooooo0?l0ooooo`0=ooooo`So0000@Oooool:o`0000;ooooo0ol00006ooooo`Oo00001?ooool0
0ol0o`3oooooooooo`03ooooo`Go0000G?ooool00ol0003oooooo`000006o`0000Gooooo00?o0?l0
o`000?l000000ol0000Aooooo`03o`000?oooooooooo00;ooooo002fooooo`So000000?o0?l0oooo
ooooool02oooool8o`0004Cooooo2_l0000:ooooo`Ko00001?ooool00ol0o`3oooooooooo`03oooo
o`Go0000G?ooool00ol0003oooooooooo`06o`0000Gooooo00?o0000o`3o0?l000000ol0000Aoooo
o`03o`000?oooooooooo00;ooooo002fooooo`Wo00003?ooool9o`0004Gooooo1ol0000<ooooo`Oo
00000oooool00ol0o`3oooooooooo`03ooooo`Go0000GOooool00ol0003oooooo`000006o`0000Co
oooo00?o0000o`3o0?l000000ol0000Aooooo`03o`000?oooooooooo00;ooooo002gooooo`Wo0000
2_ooool9o`0004Oooooo1_l0000=ooooo`Ko00000oooool00ol0o`3oooooooooo`03ooooo`Go0000
G_ooool00ol0003oooooo`000005o`0000Gooooo00?o0?l0o`000?l000000_l0000Aooooo`03o`00
0?oooooooooo00;ooooo002hooooo`[o00001oooool9o`0004Wooooo1Ol0000=ooooo`Oo00000_oo
ool00ol0o`3oooooooooo`02ooooo`Ko0000Goooool8o`0000Cooooo00?o0?l0o`000?l000000ol0
000@ooooo`03o`000?oooooooooo00;ooooo002iooooo`[o00001?ooool:o`0004cooooo00?o0000
ooooooooool03Oooool8o`000003ooooool0o`3ooooo00?ooooo1_l0001Pooooo`Oo00001?ooool0
0ol0o`3o0000o`000003o`00013ooooo00?o0000ooooooooool00_ooool00;[ooooo5_l0001=oooo
o`03o`000?oooooooooo00kooooo2?l000000ol0o`3oooooooooo`02ooooo`Ko0000HOooool7o`00
00?ooooo00?o0?l0o`000?l000000ol0000@ooooo`03o`000?oooooooooo00;ooooo002koooooaCo
0000C_ooool00ol0003oooooooooo`0>ooooo`So000000?o0?l0ooooooooool00_ooool6o`00067o
oooo2?l00002ooooo`03o`3o0?l0003o000000?o00004?ooool00ol0003oooooooooo`02ooooo`00
_?oooolBo`0004oooooo00?o0000ooooooooool03oooool8o`0000Cooooo1Ol0001Sooooo`Oo0000
0_ooool00ol0o`3o0000o`000003o`00017ooooo00?o0000ooooooooool00Oooool00;kooooo3ol0
001@ooooo`03o`000?oooooooooo013ooooo1ol00004ooooo`Go0000Hoooool8o`000003ooooool0
o`3o000000Go00004?ooool00ol0003oooooooooo`01ooooo`00_oooool<o`0005;ooooo00?o0000
ooooooooool04Oooool8o`000003ooooool0003o000000Co0000I?ooool7o`000003ooooool0o`3o
000000Go00004?ooool00ol0003oooooooooo`01ooooo`00`_ooool6o`0005Gooooo00?o0000oooo
ooooool04Oooool?o`0006Gooooo1ol000000ol0o`3o0000o`000004o`00013ooooo00?o0000oooo
ooooool00Oooool00<Cooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Booooo`ko
0000IOooool>o`00013ooooo00?o0000ooooooooool00Oooool00<Gooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Booooo`ko0000I_ooool7o`000003o`3o0?l0003o000000?o0000
4?ooool00ol0003oooooooooo`01ooooo`00a_ooool2o`0005Gooooo00?o0000ooooooooool04ooo
ool<o`0006Oooooo3Ol0000@ooooo`03o`000?oooooooooo007ooooo0038ooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool05Oooool9o`0006Wooooo3?l0000@ooooo`03o`000?oooooo
oooo007ooooo0039ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool05_ooool7o`00
06_ooooo2ol0000@ooooo`03o`000?oooooooooo007ooooo003:ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool0R?ooool;o`00013ooooo00?o0000ooooooooool00Oooool00<_ooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`29ooooo`[o00004?ooool00ol0003ooooo
ooooo`01ooooo`00c?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo08[ooooo2Ol0
000@ooooo`03o`000?oooooooooo007ooooo003=ooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0Roooool8o`00017ooooo0Ol00001ooooo`7ooooo003>ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0S?ooool7o`00017ooooo0Ol00001ooooo`7ooooo003?ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0SOooool5o`0001;ooooo0Ol00001ooooo`7o
oooo003@ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0Aooooo`7o00000Oooool1ooooo`00dOooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo097ooooo00?o0000ooooooooool04?ooool1o`00007ooooo0Oooool00=;ooooo0_l00019
ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool0
0=Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo
00oooooo0Ol00001ooooo`7ooooo003Eooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00e_ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool03Oooool1o`00007ooooo
0Oooool00=Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Eooooo`03o`000?oo
oooooooo00cooooo0Ol00001ooooo`7ooooo003Hooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00fOooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool02_ooool1o`00
007ooooo0Oooool00=[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2Gooooo`03
o`000?oooooooooo00_ooooo0Ol00001ooooo`00foooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo09Sooooo00?o0000ooooooooool02_ooool1o`00007ooooo003Looooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool00=gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`00g_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
09_ooooo00?o0000ooooooooool01oooool1o`00007ooooo003Oooooo`;o0000??ooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00hOooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool01_ooool1o`00007ooooo
003Rooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`05ooooo`7o00000Oooool00>?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00i?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo09oooooo00?o0000ooooooooool00oooool1o`00007ooooo003Uooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`02ooooo`7o
00000Oooool00>Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Qooooo`05o`00
0?ooooooooooooooool000000Oooool00>Oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00;ooooo0Ol000000>Sooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`2Rooooo`04o`000?ooooooooooooooo`7o0000003Yooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`01o`000000j_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0:Cooooo0Ol00001ooooo`7o0000003[oooo
o`;o0000<?ooool00ol0003oooooooooo`2Uooooo`;o0000003]ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0Y?ooool3o`000000k_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo0:3ooooo1?l00003ooooo`00koooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo09gooooo0ol00007ooooo`00l?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo09Wooooo1?l0000:ooooo`00lOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
09Gooooo1?l0000>ooooo`00l_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo097o
oooo1?l0000Booooo`00loooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08kooooo
0ol0000Fooooo`00m?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08[ooooo1?l0
000Iooooo`00mOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Kooooo1?l0000M
ooooo`00m_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08;ooooo1?l0000Qoooo
o`00moooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07oooooo0ol0000Uooooo`00
n?ooool2o`0002?ooooo00?o0000ooooooooool0Noooool4o`0002Sooooo003jooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Moooool4o`0002cooooo003kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Loooool4o`00033ooooo003looooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0L?ooool3o`0003Cooooo003mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0K?ooool4o`0003Oooooo003nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0J?ooool4o`0003_ooooo003oooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0I?ooool4o`0003oooooo003oooooo`7ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Qooooo`?o0000@oooool00?oooooo0_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo05gooooo1?l00016ooooo`00ooooool3ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0FOooool4o`0004[ooooo003oooooo`Cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1Eooooo`Co0000C_ooool00?oooooo1Oooool2o`0001Oooooo00?o
0000ooooooooool0DOooool4o`0005;ooooo003oooooo`Oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1>ooooo`?o0000E_ooool00?oooooo2?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04[ooooo1?l0001Iooooo`00ooooool9ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0A_ooool4o`0005gooooo003oooooo`[ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`12ooooo`Co0000HOooool00?oooooo2oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03oooooo0ol0001Uooooo`00ooooool<ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0>oooool4o`0006Sooooo003oooooo`gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0gooooo`Co0000K?ooool00?oooooo3_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo1?l0001`ooooo`00ooooool?ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0<?ooool3o`0007Cooooo003ooooooa3ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`Co0000Moooool00?oooooo4Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo1?l0001kooooo`00oooooolBoooo
o`;o00002_ooool00ol0003oooooooooo`0Tooooo`Co0000Ooooool00?oooooo5?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo027ooooo0ol00023ooooo`00oooooolEooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07Oooool4o`0008Kooooo003ooooooaKooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`Co0000R_ooool00?oooooo5oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0002>ooooo`00oooooolHoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool3o`0009;ooooo003ooooooaWo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Co0000UOooool00?oooooo
6_ooool01Ol0003ooooooooooooooooo000000cooooo1?l0002Iooooo`00oooooolKooooo`04o`00
0?ooooooooooo`0000Sooooo1?l0002Mooooo`00oooooolLooooo`03o`000?oooooo000000Gooooo
0ol0002Qooooo`00oooooolMooooo`;o000000?oooooo`000?l000000_l0002Tooooo`00oooooolN
ooooo`;o0000Z?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00001\
\>"],
  ImageRangeCache->{{{0, 454.938}, {438.688, 0}} -> {-0.177573, -0.0819158, \
0.00303561, 0.00303561}}],

Cell[TextData[{
  "Fig. 7.4 Solution of Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  at three times, along with five characteristics. "
}], "Caption",
  CellTags->"Fig. 7.4"],

Cell[TextData[{
  " \tIn principle, one could invert Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  "  to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(x\_o\)(x, t)\)]],
  ". Then, using this solution in Eq. ",
  ButtonBox["(7.1.33)",
    ButtonData:>{"Chapter7.nb", "(7.1.33)"},
    ButtonStyle->"Hyperlink"],
  " , one would obtain the solution"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\  = \ \(f\_o\)(\(x\_o\)(x, t))\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "However, as the required inversion usually cannot be accomplished \
analytically, it is often easier to simply determine the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " numerically using Eqs. ",
  ButtonBox["(7.1.33)",
    ButtonData:>{"Chapter7.nb", "(7.1.33)"},
    ButtonStyle->"Hyperlink"],
  "  and Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  " . This can be done as follows. First, we choose  an initial condition:"
}], "Text"],

Cell[BoxData[
    \(\(f0[x_]\  = \ Exp[\(-x^2\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.23"],

Cell[TextData[{
  "Next, define a table of values taken from the initial condition, and call \
it ",
  StyleBox["fval[0]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(fval[0] = Table[{x0, f0[x0]}, {x0, \(-3\), 3,  .1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.24"],

Cell[TextData[{
  "This table is a discrete representation of the continuous initial \
condition. It can be plotted using a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or an interpolation could be taken to reproduce ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNext, we use Eqs. ",
  ButtonBox["(7.1.27)",
    ButtonData:>{"Chapter7.nb", "(7.1.27)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.28)",
    ButtonData:>{"Chapter7.nb", "(7.1.28)"},
    ButtonStyle->"Hyperlink"],
  "  to follow the evolution of each data point in the table. The positions \
of the points satisfy Eq. ",
  ButtonBox["(7.1.28)",
    ButtonData:>{"Chapter7.nb", "(7.1.28)"},
    ButtonStyle->"Hyperlink"],
  " , and the values of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " remain fixed in time:"
}], "Text",
  CellTags->"i:87"],

Cell[BoxData[{
    \(\(x[t_, x0_] = \ x0\  + \ f0[x0]\ t;\)\), "\n", 
    \(\(\(f[t_, x0_]\  = \ f0[x0];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(fval[t_]\  := \ 
      Table[{x[t, x0], f[t, x0]}, {x0, \(-3\), 3,  .1}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.25"],

Cell[TextData[{
  "The table ",
  StyleBox["fval[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " provides us with a discretized solution to the problem at all times ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". In Cell ",
  ButtonBox["7.26",
    ButtonData:>"Cell 7.26",
    ButtonStyle->"Hyperlink"],
  " we plot this solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[fval[t], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{\(-3\), 4}, {0, 1}}, 
          PlotLabel -> "\<t=\>" <> ToString[t]], {t, 0, 
          2.4,  .2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.26"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -11 0 ]
[.5 .63053 11 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 8e-05 m
.01429 .00014 L
.02857 .00024 L
.04286 .00042 L
.05714 .00072 L
.07143 .00119 L
.08571 .00195 L
.1 .00312 L
.11429 .00489 L
.12857 .00751 L
.14286 .01132 L
.15714 .01672 L
.17143 .0242 L
.18571 .03435 L
.2 .04778 L
.21429 .06514 L
.22857 .08706 L
.24286 .11404 L
.25714 .14643 L
.27143 .1843 L
.28571 .22736 L
.3 .27494 L
.31429 .32588 L
.32857 .37862 L
.34286 .43119 L
.35714 .48133 L
.37143 .52665 L
.38571 .56484 L
.4 .5938 L
.41429 .61188 L
.42857 .61803 L
.44286 .61188 L
.45714 .5938 L
.47143 .56484 L
.48571 .52665 L
.5 .48133 L
.51429 .43119 L
.52857 .37862 L
.54286 .32588 L
.55714 .27494 L
.57143 .22736 L
.58571 .1843 L
.6 .14643 L
.61429 .11404 L
.62857 .08706 L
.64286 .06514 L
.65714 .04778 L
.67143 .03435 L
.68571 .0242 L
.7 .01672 L
Mistroke
.71429 .01132 L
.72857 .00751 L
.74286 .00489 L
.75714 .00312 L
.77143 .00195 L
.78571 .00119 L
.8 .00072 L
.81429 .00042 L
.82857 .00024 L
.84286 .00014 L
.85714 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool2o`0006oooooo0019ooooo`?o
0000Doooool00ol0003oooooooooo`1Booooo`?o0000LOooool004cooooo0ol0001@ooooo`03o`00
0?oooooooooo04oooooo0ol0001dooooo`00Coooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo04gooooo0_l0001gooooo`00D?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0Moooool0057ooooo0_l0001<ooooo`03o`000?oooooooooo
04[ooooo0_l0001jooooo`00Doooool2o`0004[ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1jooooo`00EOooool00ol0003oooooooooo`17ooooo`;o0000BOooool00ol0003ooooo
ooooo`1kooooo`00E_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0O?ooool005Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo07gooooo001Hooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`1nooooo`00FOooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool005[ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo001Jooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Foooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool0
05cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
08?ooooo001Mooooo`03o`000?oooooooooo03oooooo0_l00010ooooo`03o`000?oooooooooo08Co
oooo001Nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`25ooooo`00G_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0QOooool005oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo08Kooooo001Pooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`26ooooo`00HOooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool0067ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo001Rooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Hoooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool0
06?ooooo00?o0000ooooooooool0>Oooool2o`0003_ooooo00?o0000ooooooooool0ROooool006Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08[o
oooo001Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`2:ooooo`00IOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0Roooool006Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo08_ooooo001Vooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`2<ooooo`00I_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool006Oooooo00?o0000ooooooooool0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo08gooooo001Wooooo`03o`000?oooooooooo01[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=ooooo`00J?ooool00ol0003o
ooooooooo`0Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool006Sooooo00?o0000oooooooo
ool06Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
03Gooooo00?o0000ooooooooool0S_ooool006Sooooo00?o0000ooooooooool06Oooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo08oooooo001Yooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`2?ooooo`00JOooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2@ooooo`00J_ooool00ol0003oooooooooo`0Gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`2@ooooo`00J_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0TOooool006[ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001[ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00Joooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool006cooooo00?o
0000ooooooooool0<?ooool2o`00037ooooo00?o0000ooooooooool0Toooool006cooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo001]oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Coooo
o`00KOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0U?ooool006kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo09Cooooo001^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`2Dooooo`00K_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0UOooool006oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo001_ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Eooooo`00L?ooool00ol0003ooooo
ooooo`0/ooooo`;o0000;_ooool00ol0003oooooooooo`2Fooooo`00L?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0U_ooool0073ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Goooo
o`00LOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0Uoooool0077ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo09Oooooo001booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`2Hooooo`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0V?ooool007;ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo001cooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Iooooo`00Loooool00ol0003ooooo
ooooo`0Yooooo`;o0000:oooool00ol0003oooooooooo`2Iooooo`00Loooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0VOooool007Cooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo001doooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Joooo
o`00M?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0V_ooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo09_ooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`2Kooooo`00MOooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0Voooool007Gooooo00?o0000ooooooooool03?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00MOooool00ol0003oooooooooo`0<
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000Wooooo`03o`000?oo
oooooooo09cooooo001fooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`2Looooo`00M_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0WOooool007Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo09go
oooo001gooooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Mooooo`00
Moooool00ol0003oooooooooo`0:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0W_ooool007Oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo09kooooo
001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`2Nooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0Woooool007Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo09oooooo001hooooo`03o`000?oooooooooo02Cooooo0_l0000Uooooo`03
o`000?oooooooooo09oooooo001iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`2Oooooo`00NOooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0X?ooool007Wooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0:3ooooo001jooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Pooooo`00N_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0X?ooool007[ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0:7ooooo
001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2Qooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0XOooool007_ooooo00?o0000ooooooooool08Oooool2o`0002;ooooo00?o0000oooo
ooooool0X_ooool007cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo0:;ooooo001looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`2Rooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0X_ooool007gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo001mooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Sooooo`00OOooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Xoooool007gooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo
001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`2Tooooo`00O_ooool00ol0003oooooooooo`0Nooooo`;o00008?ooool00ol0003oooooooooo`2T
ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Y?ooool007kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo0:Cooooo001oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`2Uooooo`00Ooooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0YOooool007oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0:Gooooo001oooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Uooooo`00P?ooool02Ol0003o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Vooooo`00P?oo
ool02Ol0003oooooooooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2V
ooooo`00P?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`2Vooooo`00P?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Mooooo`03o`000?oooooooooo0:Kooooo
0021ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Wooooo`00
POooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:Oooooo0021ooooo`08o`00
0?ooooooooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`2Wooooo`00POooool02?l0003oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0Yoooool008;ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo0:Sooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`2Xooooo`00P_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Z?ooool008;ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:Wooooo0023ooooo`03
o`000?oooooooooo01Wooooo0_l0000Kooooo`03o`000?oooooooooo0:Wooooo0023ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Yooooo`00Pooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Z_oo
ool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo0:[ooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`2Zooooo`00Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0Zoooool008Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0:_ooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`2[ooooo`00QOooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0[?ooool008Gooooo00?o0000oooo
ooooool05oooool2o`0001Sooooo00?o0000ooooooooool0[?ooool008Gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0:cooooo0026ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2/ooooo`00Q_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0[Ooo
ool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo0:gooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`2]ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0[Oooool008Oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0:kooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`00R?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0[_ooool008Sooooo00?o0000oooo
ooooool05?ooool2o`0001Gooooo00?o0000ooooooooool0[oooool008Wooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:oooooo0029ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2_ooooo`00ROoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0[ooo
ool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0;3ooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`2`ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0/?ooool008Cooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo0000
00?ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0;3ooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool0
0ol0003oooooooooo`02ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0/Oooool008Cooooo00Go410@oooooooooooooooooa0@
4002ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
4_ooool00ol0003oooooooooo`2aooooo`00Q?ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`2aooooo`00Q?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`2booooo`00Q?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o0000ooooooooool01Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2booooo`00Q?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00?o0000ooooooooool01Oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`2booooo`00Q?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?o0000ooooooooool01Oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`2booooo`00SOooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0/oooool008gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;?ooooo002=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2coooo
o`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0]?ooool008kooooo00?o0000ooooooooool03_ooool2o`00013ooooo00?o0000ooooooooool0
]?ooool008kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;Cooooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2eooooo`00Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0]Oooool008oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0;Gooooo002@ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`2fooooo`00T?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0]_ooool0093ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;Oooooo002Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2goooo
o`00TOooool00ol0003oooooooooo`0;ooooo`;o00003?ooool00ol0003oooooooooo`2hooooo`00
TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
^?ooool009;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0;Sooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2iooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0^Oooool009?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo002Dooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`2jooooo`00U?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0^oooool009Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;_ooooo002Eoooo
o`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`000?oooooooooo0;cooooo002Fooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2looooo`00
Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_Oooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;gooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2nooooo`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0_oooool009Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0;oooooo002Eooooo`Co000000?o410@o`000?ooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<3ooooo002Gooooo`04o`000?oo
ooooooooooooo`;o00000_ooool01?l0003oooooooooooooool2o`000<?ooooo002Gooooo`03o`00
0?oooooooooo00?ooooo1_l00035ooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000a_oo
ool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Oo
oooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEEofIVI_l00000d?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0ZOooool00:cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?oo
ool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Yooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`05oa0@4?ooooooooooooooool@4100ZOooool00:cooooo00?o0000ooooooooool00ooo
ool6o`0000;ooooo00Go0000ooooooooooooooooo`00002Yooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool00000ZOooool00:[ooooo00?o410@o`000?l000000ol0
000:ooooo`05oa0@4?ooooooooooooooool@4100ZOooool00:cooooo00?o0000ooooooooool02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg0:Wooooo002/ooooo`03o`000?oooooooooo00_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP2Yooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 8e-05 m
.01429 .00014 L
.02858 .00024 L
.04288 .00042 L
.05718 .00072 L
.07148 .00119 L
.0858 .00195 L
.10014 .00312 L
.11451 .00489 L
.12892 .00751 L
.14338 .01132 L
.15792 .01672 L
.17255 .0242 L
.1873 .03435 L
.20221 .04778 L
.2173 .06514 L
.2326 .08706 L
.24813 .11404 L
.26391 .14643 L
.27995 .1843 L
.29623 .22736 L
.31271 .27494 L
.32935 .32588 L
.34608 .37862 L
.36279 .43119 L
.37939 .48133 L
.39578 .52665 L
.41183 .56484 L
.42745 .5938 L
.44257 .61188 L
.45714 .61803 L
.47114 .61188 L
.48459 .5938 L
.49754 .56484 L
.51006 .52665 L
.52225 .48133 L
.53422 .43119 L
.54608 .37862 L
.55792 .32588 L
.56985 .27494 L
.58194 .22736 L
.59423 .1843 L
.60677 .14643 L
.61956 .11404 L
.6326 .08706 L
.64587 .06514 L
.65935 .04778 L
.67302 .03435 L
.68683 .0242 L
.70077 .01672 L
Mistroke
.71481 .01132 L
.72892 .00751 L
.74308 .00489 L
.75729 .00312 L
.77152 .00195 L
.78577 .00119 L
.80003 .00072 L
.81431 .00042 L
.82858 .00024 L
.84286 .00014 L
.85715 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool2o`0006oooooo0019ooooo`?o
0000Doooool00ol0003oooooooooo`1Booooo`?o0000LOooool004cooooo0ol0001@ooooo`03o`00
0?oooooooooo04oooooo0ol0001dooooo`00Coooool2o`0004kooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1eooooo`00DOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0M_ooool005;ooooo0_l0001;ooooo`03o`000?oooooooooo
04_ooooo0_l0001iooooo`00E?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Wo
oooo0_l0001kooooo`00EOooool00ol0003oooooooooo`17ooooo`;o0000BOooool00ol0003ooooo
ooooo`1kooooo`00E_ooool2o`0004Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`1looooo`00F?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0OOooool005Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo07kooooo001Jooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`1oooooo`00Foooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool005_ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo001Looooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00GOooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool005ko
oooo00?o0000ooooooooool0?_ooool2o`00047ooooo00?o0000ooooooooool0Poooool005oooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo
001Oooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`24ooooo`00H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0QOooool0067ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo08Gooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`26ooooo`00H_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0Qoooool006?ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo001Tooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00I?ooool00ol0
003oooooooooo`0hooooo`;o0000??ooool00ol0003oooooooooo`28ooooo`00IOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool006Gooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08Wooooo
001Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`2:ooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0R_ooool006Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo08_ooooo001Wooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`2;ooooo`00J?ooool00ol0003oooooooooo`0Iooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0S?ooool006Sooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001Yooooo`03o`000?oooooooooo01So
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`2=ooooo`00JOooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000=_ooool00ol0
003oooooooooo`2=ooooo`00J_ooool00ol0003oooooooooo`0Gooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0SOooool006[ooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
08kooooo001[ooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo08kooooo001[ooooo`03o`000?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo08oooooo001/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`2?ooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0Soooool006gooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo093ooooo001]ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`2@ooooo`00K_ooool00ol0003ooooooooo
o`0^ooooo`;o0000<oooool00ol0003oooooooooo`2Aooooo`00K_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool006oooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001_ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00
L?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
T_ooool0073ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo09;ooooo001`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`2Cooooo`00LOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0Toooool0077ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo001booooo`03o`000?oooooooooo02[ooooo
0_l0000`ooooo`03o`000?oooooooooo09Cooooo001booooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`00Loooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool007?ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo001cooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Eooooo`00
M?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
UOooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo09Gooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`2Fooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0U_ooool007Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo001fooooo`03o`000?oooooooooo02Kooooo
0_l0000^ooooo`03o`000?oooooooooo09Kooooo001fooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`2Fooooo`00M_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Uoooool007Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo09Oooooo001gooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Gooooo`00
N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
Uoooool007Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo09Sooooo001hooooo`03o`000?oooooooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`2Hooooo`00NOooool00ol0003oooooooooo`08ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo09Sooooo001iooooo`03o`000?oooooooooo00Sooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0002_ooooo00?o0000ooooooooool0V?oo
ool007Wooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Wooooo
001jooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Iooooo`00
N_ooool00ol0003oooooooooo`07ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`000007ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0VOooool007[ooooo
00?o0000ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo001kooooo`03o`00
0?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Jooooo`00Noooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V_ooool007_ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo001l
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2K
ooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0Voooool007cooooo00?o0000ooooooooool08?ooool2o`0002Wooooo00?o0000oooooooo
ool0Voooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo09_ooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2Looooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0W?ooool007kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo001nooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00O_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0WOooool007oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo09gooooo001o
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2M
ooooo`00Ooooool00ol0003oooooooooo`0Mooooo`;o00009_ooool00ol0003oooooooooo`2Noooo
o`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0W_ooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo09kooooo0020ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`2Nooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo09oooooo0021ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Oooooo`00POooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Woooool008;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09oooooo0022
ooooo`03o`000?oooooooooo01[ooooo0_l0000Tooooo`03o`000?oooooooooo0:3ooooo0022oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Poooo
o`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0X?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo0:3ooooo0023ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`2Pooooo`00Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0XOooool008Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo0:7ooooo0024ooooo`05o`000?lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0XOooool008Cooooo00GoMgMgo`000?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`2Qooooo`00Q?ooool01Ol@413o0000oooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
XOooool008Cooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00008Oooool00ol0003oooooooooo`2Rooooo`00Q?ooool01Ol0003oooooo`00
0?oooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0X_ooool008Cooooo00Go410@ooooool0003ooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Rooooo`00
Q?ooool01OmgMgOoV9RHo`000?nHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo0:;ooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0X_ooool008Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0:?ooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2Sooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Xoooool008Sooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo0028ooooo`03o`000?oooooooooo
01Cooooo0_l0000Pooooo`03o`000?oooooooooo0:Cooooo0028ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Tooooo`00ROooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Y?ooool008Wooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0:Cooooo0029
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2U
ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0YOooool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo0:Gooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`2Uooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Y_ooool008_ooooo00?o0000ooooooooool04Oooool2
o`0001kooooo00?o0000ooooooooool0Y_ooool008_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo0:Kooooo002<ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Vooooo`00S?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Yoooool008cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:Oooooo002=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2W
ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0Yoooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo0:Oooooo002>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`2Xooooo`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0Z?ooool008kooooo00?o0000ooooooooool03_ooool2
o`0001cooooo00?o0000ooooooooool0Z?ooool008oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo0:Sooooo002?ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Xooooo`00Soooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0ZOooool0093ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:Wooooo002@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Y
ooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0ZOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00Woooooo`00
0?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0:Wooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09oooo
ool0003ooooooooooolQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`2Zooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`?o00006Oooool00ol0003ooooooooo
o`2Zooooo`00Q?ooool01Ol0003ooooooooooooooooo000000Wooooo00Oo0000oooooolb<S;oV9RH
oooooonHV9So<S8b00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Zooooo`00
Q?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooo<c<`00ol000000oo<c<co
ooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Zoooool008Cooooo
00Go410@oooooooooooooooooa0@4009ooooo`07o`000?oooooo410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Zoooool008Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`;o000000Co^[Zjoooooonj^[[o00001_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo0:_ooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool01_l0003oZJVYoa0@4?l0003o410@ojVYZ@Kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`2[ooooo`00Toooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0[?ooool009Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo0:cooooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`2/ooooo`00U?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0[Oooool009Gooooo00?o0000oooooooo
ool01oooool2o`0001Oooooo00?o0000ooooooooool0[Oooool009Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:gooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`00U_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0[_ooool0
09Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0:kooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`2_ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0[oooool009Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo0:oooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`2`ooooo`00VOooool00ol0003oooooooooo`03oooo
o`;o00005?ooool00ol0003oooooooooo`2`ooooo`00VOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0/?ooool009Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;7ooooo002Jooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2aooooo`00V_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0/Oooool0
09_ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo0;;ooooo002Loooo
o`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0/_ooool009cooooo00Co0000oooo
oooooooo00004_ooool00ol0003oooooooooo`2cooooo`00WOooool00ol0003oooooo`00000Boooo
o`03o`000?oooooooooo0;?ooooo002Mooooo`04o`000?oooooo0000o`00013ooooo00?o0000oooo
ooooool0]?ooool009kooooo0_l0000Aooooo`03o`000?oooooooooo0;Cooooo002Oooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0]Oooool009oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2eooooo`00Woooool2o`0000kooooo00?o0000ooooooooool0]_ooool0
09oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`2gooooo`00Woooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo0;Oooooo002Eooooo`Co000000?o410@ooooooooool0
0oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo0;Sooooo002Gooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00006ooooo`;o0000^oooool009Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?l00000
_Oooool009Oooooo00?o0000ooooooooool01Oooool3o`0000Kooooo00?o0000ooooooooool0_Ooo
ool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Oo
oooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEEofIVI_l00000d?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0002Qooooo`00Y?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0XOooool00:Cooooo00?o0000ooooooooool0
2oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0X_ooool00:Cooooo
00?o0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP2Qooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`2Pooooo`00X_ooool00ol@413o0000o`00
0003o`0000[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo09oooooo
002Tooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@4100XOooool00:Cooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Qooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1e-05 8e-05 m
.0143 .00014 L
.02859 .00024 L
.0429 .00042 L
.05721 .00072 L
.07154 .00119 L
.08589 .00195 L
.10029 .00312 L
.11474 .00489 L
.12927 .00751 L
.1439 .01132 L
.15869 .01672 L
.17367 .0242 L
.18889 .03435 L
.20442 .04778 L
.22031 .06514 L
.23662 .08706 L
.2534 .11404 L
.27068 .14643 L
.28847 .1843 L
.30674 .22736 L
.32542 .27494 L
.34442 .32588 L
.36358 .37862 L
.38272 .43119 L
.40165 .48133 L
.42012 .52665 L
.43794 .56484 L
.4549 .5938 L
.47086 .61188 L
.48571 .61803 L
.49943 .61188 L
.51205 .5938 L
.52365 .56484 L
.53441 .52665 L
.5445 .48133 L
.55415 .43119 L
.56358 .37862 L
.57299 .32588 L
.58256 .27494 L
.59245 .22736 L
.60275 .1843 L
.61354 .14643 L
.62483 .11404 L
.63662 .08706 L
.64888 .06514 L
.66156 .04778 L
.6746 .03435 L
.68795 .0242 L
.70155 .01672 L
Mistroke
.71533 .01132 L
.72927 .00751 L
.74331 .00489 L
.75743 .00312 L
.77161 .00195 L
.78582 .00119 L
.80007 .00072 L
.81432 .00042 L
.82859 .00024 L
.84287 .00014 L
.85715 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool2o`0006oooooo0019ooooo`?o
0000Doooool00ol0003oooooooooo`1Booooo`?o0000LOooool004cooooo0ol0001@ooooo`03o`00
0?oooooooooo04oooooo0ol0001dooooo`00Coooool2o`0004kooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1eooooo`00DOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0M_ooool005;ooooo0_l0001;ooooo`03o`000?oooooooooo
04_ooooo0_l0001iooooo`00E?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0NOooool005Gooooo00?o0000ooooooooool0Aoooool2o`0004[ooooo
00?o0000ooooooooool0N_ooool005Kooooo0_l00017ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0Noooool005Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo07cooooo001Iooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00F_ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool005_ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001Looooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00GOooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool0
05kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
087ooooo001Oooooo`03o`000?oooooooooo03gooooo0_l00012ooooo`03o`000?oooooooooo08;o
oooo001Pooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`23ooooo`00H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0Poooool0067ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00Hoooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0QOooool006?ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Kooooo001Tooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26ooooo`00IOooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool0
06Gooooo00?o0000ooooooooool0=oooool2o`0003gooooo00?o0000ooooooooool0Qoooool006Ko
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08So
oooo001Wooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`28ooooo`00Ioooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0R?ooool006Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo08Wooooo001Xooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`29ooooo`00JOooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool006[ooooo00?o0000ooooooooool0
5oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo08[ooooo001Zooooo`03o`000?oooooooooo01Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2:ooooo`00Joooool00ol0003o
ooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Roooool006_ooooo00?o0000oooooooo
ool05_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
03Sooooo00?o0000ooooooooool0Roooool006cooooo00?o0000ooooooooool05Oooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo08_ooooo001/ooooo`03o`000?oooooooooo01Gooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`2<ooooo`00KOooool00ol0003oooooooooo`0Dooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`2<ooooo`00KOooool00ol0003oooooooooo`0Dooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2=ooooo`00K_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0SOooool006kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo001_ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00Koooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool0073ooooo00?o
0000ooooooooool0;?ooool2o`0003Kooooo00?o0000ooooooooool0S_ooool0073ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?oooo
o`00LOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0Soooool007;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo093ooooo001cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`2@ooooo`00Loooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0T?ooool007Cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo093ooooo001dooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Aooooo`00MOooool00ol0003ooooo
ooooo`0Wooooo`;o0000<oooool00ol0003oooooooooo`2Aooooo`00MOooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool007Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001foooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Boooo
o`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0T_ooool007Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo09;ooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`2Booooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0Toooool007Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo001hooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Cooooo`00NOooool00ol0003ooooo
ooooo`0Sooooo`;o0000<Oooool00ol0003oooooooooo`2Cooooo`00NOooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Toooool007Wooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Cooooo001joooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Doooo
o`00N_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0U?ooool007_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo09Cooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`2Eooooo`00Noooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0UOooool007cooooo00?o0000ooooooooool01Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`2Eooooo`00O?ooool00ol0003oooooooooo`05
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000^ooooo`03o`000?oo
oooooooo09Gooooo001mooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`2Eooooo`00OOooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0U_ooool007gooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Ko
oooo001nooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Fooooo`00
O_ooool00ol0003oooooooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0U_ooool007oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo
001oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`2Gooooo`00Ooooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0Uoooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo09Oooooo0020ooooo`03o`000?oooooooooo01cooooo0_l0000]ooooo`03
o`000?oooooooooo09Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2Gooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0V?ooool0087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo0022ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Hooooo`00P_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0V?ooool008?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo
0023ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`2Iooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0VOooool008Cooooo00?o0000ooooooooool06?ooool2o`0002_ooooo00?o0000oooo
ooooool0VOooool008Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo09Wooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`2Iooooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0V_ooool008Gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo0026ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Jooooo`00Q_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V_ooool008Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo
0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2Jooooo`00Qoooool00ol0003oooooooooo`0Eooooo`;o0000:Oooool00ol0003oooooooooo`2K
ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0Voooool008Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo09_ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`2Kooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0Voooool008Wooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0029ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00Q?ooool01_o^k^ko
<S8bo`000?lb<S;ok^k^o`0000Cooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0024ooooo`07ogMgMonHV9So
oooooiRHV?mgMgOoooooo`000003ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00Q?ooool01ol@413ooooo
oooooooooooo410@ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`2Looooo`00Q?ooool01ol0003ooooooooooooooooo
0000ooooool000002Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Vooooo`03o`00
0?oooooooooo09gooooo0024ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`06ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo09gooooo0024ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003o
ooooooooo`06ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`2Mooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooooooo
ool01_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0WOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00Ko
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
09gooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`2Mooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0W_ooool008gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo09kooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`2Nooooo`00SOooool00ol0003oooooooooo`0?oooo
o`;o00009_ooool00ol0003oooooooooo`2Nooooo`00S_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0W_ooool008kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09oooooo002?ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Oooooo`00Soooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Woooool0
08oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
09oooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`2Oooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0X?ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo0:3ooooo002Aooooo`03o`000?oooooooooo00_ooooo0_l0000T
ooooo`03o`000?oooooooooo0:3ooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`2Pooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0X?ooool009;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0:7ooooo002Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Qooooo`00Toooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0XOooool0
09?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
0:7ooooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`2Qooooo`00U?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0X_ooool009Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo0:;ooooo002Eooooo`03o`000?oooooooooo00Oooooo0_l0000R
ooooo`03o`000?oooooooooo0:;ooooo002Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2Rooooo`00U_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0X_ooool009Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Sooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Xoooool0
09Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
0:?ooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qo`000006ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Xoooool0
08Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So000000Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Tooooo`00Q?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Co0000oooooooooooooooo0_l00005ooooo`?o0000
7oooool00ol0003oooooooooo`2Tooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Ko<S8boiRHV?ooooooV9RHoc8b<_l00005ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Y?ooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`06olc<c?l0003o0000
o`000?o<c<co00001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0:Cooooo0024
ooooo`05oa0@4?ooooooooooooooool@41002oooool01ol@413o^[Zjoooooonj^[[o410@ooooool0
00001?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0:Cooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01ol0003o^[Zjoooooonj^[[o0000ooooool000001?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0:Gooooo0024ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Go0000oooooooooooooooo
o`00000Pooooo`03o`000?oooooooooo0:Gooooo002Kooooo`05o`000?ooooooooooooooool00000
8?ooool00ol0003oooooooooo`2Uooooo`00W?ooool01?l0003oooooooooool0000Pooooo`03o`00
0?oooooooooo0:Gooooo002Looooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool0
YOooool009cooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`2Vooooo`00WOoo
ool01?l0003oooooo`000?l0000Nooooo`03o`000?oooooooooo0:Kooooo002Mooooo`03o`000?oo
oooo000001oooooo00?o0000ooooooooool0Y_ooool009kooooo0_l0000Oooooo`03o`000?oooooo
oooo0:Kooooo002Nooooo`;o00007_ooool00ol0003oooooooooo`2Wooooo`00W_ooool2o`0001ko
oooo00?o0000ooooooooool0Yoooool009oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`2Wooooo`00Woooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:Oooooo002O
ooooo`;o00007?ooool00ol0003oooooooooo`2Xooooo`00Woooool2o`0001cooooo00?o0000oooo
ooooool0Z?ooool009oooooo0ol0000Kooooo`03o`000?oooooooooo0:Sooooo002Oooooo`03o`00
0?oooooo000001_ooooo00?o0000ooooooooool0Z?ooool009oooooo00?o0000ooooool000006_oo
ool00ol0003oooooooooo`2Yooooo`00Woooool01?l0003oooooooooool0000Iooooo`03o`000?oo
oooooooo0:Wooooo002Oooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool0ZOoo
ool009oooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo0:[ooooo002O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Z
ooooo`00Woooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0Z_ooool009oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:_ooooo002Oooooo`;o00001?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo0:_ooooo002Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`2[ooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0[?ooool009oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0:cooooo002Oooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2]ooooo`00Woooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0[_ooool009oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:kooooo002E
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0[oooool009Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`;o00001_ooool2o`000;;ooooo002Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03?ooool3o`000003ooooool0003o00000;Cooooo002Gooooo`03o`00
0?oooooooooo00Gooooo0ol0000?ooooo`03o`000?oooooooooo0;Cooooo002Gooooo`03o`000?oo
oooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo
0<kooooo002Eooooo`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0Woooool00:Cooooo00Go410@
okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1oooool00ol0003oooooooooo`2Pooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`000:7ooooo002Tooooo`03o`000?oooooooooo00Cooooo
1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo
0000X_ooool00:Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo0000X_ooool00:;ooooo00?o410@o`000?l000000ol0000:ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00002Rooooo`00Y?ooool00ol0003o
ooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00002Roooo
o`00Y?ooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`2Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1e-05 8e-05 m
.0143 .00014 L
.02861 .00024 L
.04292 .00042 L
.05724 .00072 L
.07159 .00119 L
.08598 .00195 L
.10043 .00312 L
.11496 .00489 L
.12961 .00751 L
.14443 .01132 L
.15946 .01672 L
.17479 .0242 L
.19048 .03435 L
.20663 .04778 L
.22332 .06514 L
.24065 .08706 L
.25867 .11404 L
.27745 .14643 L
.29699 .1843 L
.31725 .22736 L
.33813 .27494 L
.35948 .32588 L
.38108 .37862 L
.40266 .43119 L
.4239 .48133 L
.44447 .52665 L
.46405 .56484 L
.48235 .5938 L
.49915 .61188 L
.51429 .61803 L
.52772 .61188 L
.5395 .5938 L
.54977 .56484 L
.55876 .52665 L
.56675 .48133 L
.57409 .43119 L
.58108 .37862 L
.58805 .32588 L
.59527 .27494 L
.60296 .22736 L
.61127 .1843 L
.62031 .14643 L
.6301 .11404 L
.64065 .08706 L
.65189 .06514 L
.66377 .04778 L
.67619 .03435 L
.68907 .0242 L
.70232 .01672 L
Mistroke
.71586 .01132 L
.72961 .00751 L
.74353 .00489 L
.75758 .00312 L
.7717 .00195 L
.78588 .00119 L
.8001 .00072 L
.81434 .00042 L
.82861 .00024 L
.84288 .00014 L
.85715 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool3o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Booooo`?o0000LOooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo04oooooo0ol0001dooooo`00D?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0MOooool0057ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo001Booooo`;o0000Boooool0
0ol0003oooooooooo`1;ooooo`;o0000NOooool005Cooooo0_l00019ooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0NOooool005Kooooo00?o0000ooooooooool0A_ooool2o`0004[o
oooo00?o0000ooooooooool0N_ooool005Oooooo0_l00016ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0Noooool005Wooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo001Jooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00Foooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool005cooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Mooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00G_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Oooo
ool005oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo083ooooo001Pooooo`03o`000?oooooooooo03cooooo0_l00013ooooo`03o`000?oooooooooo
087ooooo001Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`22ooooo`00HOooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0P_ooool006;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo08?ooooo001Sooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`23ooooo`00I?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo001Uooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00I_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0QOoo
ool006Kooooo00?o0000ooooooooool0=_ooool2o`0003oooooo00?o0000ooooooooool0QOooool0
06Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
08Kooooo001Xooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`26ooooo`00JOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0Qoooool006Wooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo08Oooooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Joooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool006cooooo00?o0000oooooooo
ool05Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo08Wooooo001/ooooo`03o`000?oooooooooo01Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`29ooooo`00KOooool00ol0
003oooooooooo`0Dooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool006gooooo00?o0000oooo
ooooool05?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0003Wooooo00?o0000ooooooooool0R_ooool006kooooo00?o0000ooooooooool04oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo08[ooooo001^ooooo`03o`000?oooooooooo01?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2:ooooo`00Koooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`2;ooooo`00Koooool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`2;ooooo`00L?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0Roooool0073ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001aooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00LOooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool007;ooooo
00?o0000ooooooooool0:_ooool2o`0003Sooooo00?o0000ooooooooool0S?ooool007;ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001c
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=
ooooo`00Loooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0SOooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo08gooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`2=ooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0SOooool007Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo08kooooo001fooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00Moooool00ol0003o
ooooooooo`0Uooooo`;o0000=_ooool00ol0003oooooooooo`2>ooooo`00Moooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool007Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08kooooo001h
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?
ooooo`00NOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0Soooool007Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo08oooooo001jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`2?ooooo`00N_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0T?ooool007[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo093ooooo001kooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2@ooooo`00Noooool00ol0003o
ooooooooo`0Qooooo`;o0000=?ooool00ol0003oooooooooo`2@ooooo`00O?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0T?ooool007cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001m
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2A
ooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0TOooool007kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo097ooooo001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`2Aooooo`00Ooooool00ol0003oooooooooo`02ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0TOooool007oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00P?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0000aooooo`03o`00
0?oooooooooo09;ooooo0020ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2Booooo`00POooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Wo
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
09;ooooo0021ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool02_ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool0087o
oooo00So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo0022ooooo`07o`000?oooooo
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2Booooo`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0Toooool008?ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo0023ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Cooooo`00Q?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Toooool008Cooooo
00?o0000ooooooooool06?ooool2o`00037ooooo00?o0000ooooooooool0Toooool008Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo0025
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2C
ooooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0Toooool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo09Cooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`2Dooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0U?ooool008Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Cooooo0027ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`00R?ooool00ol0003o
ooooooooo`0Dooooo`;o0000<?ooool00ol0003oooooooooo`2Dooooo`00R?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool008Wooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo0029
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2E
ooooo`00ROooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0UOooool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo09Gooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`2Eooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0UOooool008_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo002<ooooo`03o`000?oooooooooo
013ooooo0_l0000^ooooo`03o`000?oooooooooo09Kooooo002<ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Fooooo`00S?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0U_ooool008gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo002=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2F
ooooo`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0Uoooool008kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo09Oooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o
0000ooooo`03ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo09Oooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00olQ
8B7o0000ooooo`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo09Oooooo0024ooooo`05oa0@4?ooooooooooooooool@41001_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo09Oooooo0024ooooo`05o`000?ooooooooooooooool000001ooo
ool02Ol0003ooooooooooooooooo0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000:oooool00ol0
003oooooooooo`2Hooooo`00Q?ooool01Ol0003ooooooooooooooooo000000Oooooo00Wo0000oooo
ooooooooooooo`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo09Sooooo0024ooooo`05oa0@4?ooooooooooooooool@41002?ooool01Ol0003ooooo
oooooomEEEGoQhN700Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Hooooo`00
Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00Ko0000oooooooooooogMgMoa0@4?nHV9P8
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0V?ooool008Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`07o`000?ooooooooooolc<c?m4A4Co0000oa0@4006ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0V?ooool009;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo002Booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Hooooo`00Toooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0VOooool009?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Wo
oooo002Cooooo`03o`000?oooooooooo00Wooooo0_l0000[ooooo`03o`000?oooooooooo09Wooooo
002Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`2Iooooo`00U?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0VOooool009Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo09Wooooo002Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`2Iooooo`00UOooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0VOooool009Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo002Fooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Jooooo`00U_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V_ooool009Oo
oooo00?o0000ooooooooool01Oooool2o`0002[ooooo00?o0000ooooooooool0V_ooool009Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo
002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2Jooooo`00V?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0V_ooool009Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo09[ooooo002Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`2Kooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0Voooool009[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09_ooooo002Kooooo`05o`000?oooooo
ooooooooool00000:_ooool00ol0003oooooooooo`2Kooooo`00Voooool01Ol0003ooooooooooooo
oooo000002[ooooo00?o0000ooooooooool0Voooool009_ooooo00Co0000oooooooooooooooo0_l0
000Yooooo`03o`000?oooooooooo09_ooooo002Looooo`04o`000?ooooooooooo`0002[ooooo00?o
0000ooooooooool0Voooool009cooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooooooo
o`2Looooo`00WOooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo09cooooo002Moooo
o`03o`000?oooooo000002Wooooo00?o0000ooooooooool0W?ooool009kooooo0_l0000Yooooo`03
o`000?oooooooooo09cooooo002Nooooo`;o0000:Oooool00ol0003oooooooooo`2Looooo`00Q?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0W?ooool008Cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0002Kooooo00?o0000
ooooooooool0WOooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool2o`0002Oooooo00?o0000ooooooooool0WOooool008Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool2o`0002Oooooo
00?o0000ooooooooool0WOooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooo`00000Vooooo`03o`000?oooooooooo09go
oooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`2Mooooo`00Q?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`04o`000?oooooo
ooooo`0002Gooooo00?o0000ooooooooool0WOooool009oooooo00Co0000oooooooooooo00009Ooo
ool00ol0003oooooooooo`2Mooooo`00Woooool01Ol0003ooooooooooooooooo000002?ooooo00?o
0000ooooooooool0W_ooool009oooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oo
oooooooo09kooooo002Oooooo`05o`000?ooooooooooooooool000008oooool00ol0003ooooooooo
o`2Nooooo`00Woooool2o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2N
ooooo`00Woooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0W_ooool009oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo09kooooo002Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`2Oooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Woooool009oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09oooooo002Oooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Oooooo`00Woooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0X?ooool009oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:3ooooo
002Oooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:3ooooo002O
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2P
ooooo`00Woooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0XOooool009oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0:7ooooo002Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`2Qooooo`00Woooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0X_ooool009oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:;ooooo002Oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Rooooo`00Woooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Xoooool009oooooo
0_l0000=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Xoooool009oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:?ooooo002O
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2T
ooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0Y?ooool009oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0:Gooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`2Vooooo`00Woooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0Y_ooool009Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2W
ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo0_l00005oooo
o`;o0000Z_ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`;o
000000?oooooo`000?l00000[?ooool009Oooooo00?o0000ooooooooool01Oooool3o`0001Oooooo
00?o0000ooooooooool0[?ooool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo00?o0000
ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEEofIVI_l0
0000d?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c02Qooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo
1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B40XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`00002Qooooo`00Y?ooool00ol0003oooooooooo`04
ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9So
oooooiRHV?lQ8B40XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c02Qooooo`00X_ooool00ol@413o0000o`00
0003o`0000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo0:?ooooo
002Tooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH0:?ooooo002Tooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@4:7ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1e-05 8e-05 m
.01431 .00014 L
.02862 .00024 L
.04294 .00042 L
.05728 .00072 L
.07165 .00119 L
.08607 .00195 L
.10058 .00312 L
.11519 .00489 L
.12996 .00751 L
.14495 .01132 L
.16023 .01672 L
.1759 .0242 L
.19207 .03435 L
.20883 .04778 L
.22633 .06514 L
.24467 .08706 L
.26395 .11404 L
.28422 .14643 L
.30551 .1843 L
.32776 .22736 L
.35084 .27494 L
.37455 .32588 L
.39859 .37862 L
.42259 .43119 L
.44615 .48133 L
.46882 .52665 L
.49016 .56484 L
.5098 .5938 L
.52743 .61188 L
.54286 .61803 L
.55601 .61188 L
.56695 .5938 L
.57588 .56484 L
.5831 .52665 L
.58901 .48133 L
.59402 .43119 L
.59859 .37862 L
.60312 .32588 L
.60798 .27494 L
.61347 .22736 L
.61979 .1843 L
.62708 .14643 L
.63537 .11404 L
.64467 .08706 L
.6549 .06514 L
.66598 .04778 L
.67778 .03435 L
.69019 .0242 L
.70309 .01672 L
Mistroke
.71638 .01132 L
.72996 .00751 L
.74376 .00489 L
.75772 .00312 L
.77179 .00195 L
.78593 .00119 L
.80013 .00072 L
.81436 .00042 L
.82862 .00024 L
.84288 .00014 L
.85716 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool2o`0005Kooooo00?o0000ooooooooool0E_ooool2o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo053ooooo0ol0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1dooooo`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0MOooool005?ooooo0_l0001:ooooo`03o`000?oooooo
oooo04cooooo0_l0001hooooo`00EOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0N?ooool005Kooooo00?o0000ooooooooool0A_ooool2o`0004_o
oooo00?o0000ooooooooool0NOooool005Oooooo0_l00016ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0N_ooool005Wooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo001Jooooo`;o0000@oooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo07cooooo001Looooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00GOooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool005kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Oooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00H?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool0
067ooooo00?o0000ooooooooool0>oooool2o`0004Cooooo00?o0000ooooooooool0P?ooool006;o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087o
oooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`21ooooo`00Hoooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0P_ooool006Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo08;ooooo001Uooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`23ooooo`00IOooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0Poooool006Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001Wooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Ioooool0
0ol0003oooooooooo`0eooooo`;o0000@?ooool00ol0003oooooooooo`24ooooo`00J?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0QOooool006Wo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo08Go
oooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`25ooooo`00J_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0Q_ooool006_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo08Kooooo001/ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`26ooooo`00KOooool00ol0003oooooooooo`0Dooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0Qoooool006gooooo00?o0000ooooooooool05?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo001^ooooo`03o`000?oooooooooo
01?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Koooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000>oooool0
0ol0003oooooooooo`28ooooo`00Koooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0R?ooool0073ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo08Sooooo001`ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo08Wooooo001aooooo`03o`000?oooooooooo013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo08Wooooo001booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`29ooooo`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0R_ooool007?ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo08[ooooo001cooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2:ooooo`00M?ooool00ol0003ooooo
ooooo`0Xooooo`;o0000>_ooool00ol0003oooooooooo`2:ooooo`00MOooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0R_ooool007Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08_ooooo001foooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;oooo
o`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0Roooool007Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo08_ooooo001hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`2;ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0S?ooool007Wooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001jooooo`03o`000?oooooooooo02;o
oooo0_l0000hooooo`03o`000?oooooooooo08cooooo001jooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00Noooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool007_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001loooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=oooo
o`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0SOooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo08gooooo001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2=ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0SOooool007oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo001oooooo`03o`000?oooooooooo01go
oooo0_l0000gooooo`03o`000?oooooooooo08gooooo0020ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00P?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool0087ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08kooooo0021oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>oooo
o`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0S_ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo08kooooo0023ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0S_ooool008?ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool008Co
oooo00Go0000oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0003Gooooo00?o0000oooo
ooooool0S_ooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00Q?ooool2o`00
00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0Soooool008Cooooo00Go410@o`000?oooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?
ooooo`00Q?ooool01OmgMgOo0000oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo0024ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0Soooool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo08oooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`2?ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0Soooool008Sooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo0028ooooo`03o`000?oooooo
oooo01Cooooo0_l0000eooooo`03o`000?oooooooooo08oooooo0029ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?ooooo`00ROooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Soooool008[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo
002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`2@ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0T?ooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo093ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`2@ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0T?ooool008cooooo00?o0000ooooooooool04?oo
ool2o`0003Cooooo00?o0000ooooooooool0T?ooool008gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo093ooooo002=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Aooooo`00S_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool008kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo
002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`2Aooooo`00Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0TOooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo097ooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`2Aooooo`00TOooool00ol0003oooooooooo`0;ooooo`;o0000
<oooool00ol0003oooooooooo`2Aooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0TOooool0097ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo002Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Aooooo`00T_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool009?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo
002Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2Booooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05o`000?lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo
0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go0000ogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool008Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo0024ooooo`05o`000?oooooooooooooo
ool000002oooool2o`000003oooooonHV9So8B4Q00Kooooo0ol0000aooooo`03o`000?oooooooooo
09;ooooo0024ooooo`05o`000?ooooooooooooooool000002oooool3o`000003oa0@4?o<c<cooooo
00Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00Q?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qol000002?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo09;ooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@o`000008ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool008Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00Uoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool009Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo002Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Cooooo`00V?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Tooo
ool009Wooooo00?o0000ooooooooool00oooool2o`00037ooooo00?o0000ooooooooool0Toooool0
09Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
09?ooooo002Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`2Cooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0Toooool009_ooooo00Go0000ooooooooooooooooo`00000booooo`03o`00
0?oooooooooo09?ooooo002Kooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003ooooo
ooooo`2Cooooo`00Voooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0
U?ooool009cooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`2Dooooo`00W?oo
ool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo09Cooooo002Mooooo`04o`000?oo
oooo0000o`00033ooooo00?o0000ooooooooool0U?ooool009gooooo00?o0000ooooool00000<Ooo
ool00ol0003oooooooooo`2Dooooo`00W_ooool2o`00037ooooo00?o0000ooooooooool0U?ooool0
09kooooo0_l0000aooooo`03o`000?oooooooooo09Cooooo002Oooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0U?ooool009oooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2Dooooo`00Woooool2o`00033ooooo00?o0000ooooooooool0U?ooool009oooooo0_l0000`
ooooo`03o`000?oooooooooo09Cooooo002Oooooo`03o`000?oooooo000002kooooo00?o0000oooo
ooooool0UOooool009oooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`2Eoooo
o`00Woooool2o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool0UOooool009oooooo
00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooooooo09Gooooo002Oooooo`05o`00
0?ooooooooooooooool00000;?ooool00ol0003oooooooooo`2Eooooo`00Woooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0UOooool009oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09Gooooo002O
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2E
ooooo`00Woooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0UOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo09Gooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`2Eooooo`00Q?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo09Kooooo0024ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo09Kooooo0024ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo09Kooooo0024ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09Kooooo0024ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09Kooooo0024ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo09Kooooo002Oooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Fooooo`00Woooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Uoooool0
09oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
09Oooooo002Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`2Gooooo`00Woooool2o`0000[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`2Gooooo`00Woooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0Uoooool009oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo09Oooooo002Oooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`2Gooooo`00Woooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0V?ooool009oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo09Sooooo002Oooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Hooooo`00Woooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0V?ooool0
09oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
09Sooooo002Oooooo`;o00003oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09So
oooo002Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`2Iooooo`00Woooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0VOooool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo09Wooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`2Iooooo`00Woooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool009oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09[ooooo002Oooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Jooooo`00Woooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Voooool0
09oooooo0_l0000Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Voooool009oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09_o
oooo002Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`2Looooo`00Woooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0W?ooool009oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo09gooooo002Oooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2Mooooo`00Woooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0W_ooool009Gooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`2Nooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo0_l0
0006ooooo`;o0000XOooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0M
ooooo`?o000000?oooooo`000?l00000Xoooool009Oooooo00?o0000ooooooooool01Oooool3o`00
023ooooo00?o0000ooooooooool0Xoooool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo
00?o0000ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEE
ofIVI_l00000d?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Qooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00;ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`00002Qooooo`00Y?ooool00ol0003ooooo
ooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S80XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c02Qooooo`00X_ooool00ol@413o
0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100XOooool00:Cooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00002Qooooo`00Y?ooool00ol0003oooooooooo`0;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY0:7ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
2e-05 8e-05 m
.01432 .00014 L
.02863 .00024 L
.04295 .00042 L
.05731 .00072 L
.0717 .00119 L
.08616 .00195 L
.10072 .00312 L
.11542 .00489 L
.13031 .00751 L
.14547 .01132 L
.16101 .01672 L
.17702 .0242 L
.19365 .03435 L
.21104 .04778 L
.22934 .06514 L
.24869 .08706 L
.26922 .11404 L
.29099 .14643 L
.31403 .1843 L
.33827 .22736 L
.36355 .27494 L
.38961 .32588 L
.41609 .37862 L
.44253 .43119 L
.4684 .48133 L
.49316 .52665 L
.51628 .56484 L
.53726 .5938 L
.55572 .61188 L
.57143 .61803 L
.58429 .61188 L
.5944 .5938 L
.60199 .56484 L
.60745 .52665 L
.61126 .48133 L
.61395 .43119 L
.61609 .37862 L
.61818 .32588 L
.62069 .27494 L
.62398 .22736 L
.62831 .1843 L
.63385 .14643 L
.64065 .11404 L
.64869 .08706 L
.65791 .06514 L
.66819 .04778 L
.67937 .03435 L
.69131 .0242 L
.70386 .01672 L
Mistroke
.7169 .01132 L
.73031 .00751 L
.74399 .00489 L
.75786 .00312 L
.77188 .00195 L
.78599 .00119 L
.80017 .00072 L
.81438 .00042 L
.82863 .00024 L
.84289 .00014 L
.85716 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool2o`0005Kooooo00?o0000ooooooooool0E_ooool2o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo053ooooo0ol0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1dooooo`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0MOooool005?ooooo0_l0001:ooooo`03o`000?oooooo
oooo04cooooo0_l0001hooooo`00EOooool2o`0004Sooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1hooooo`00Eoooool00ol0003oooooooooo`15ooooo`;o0000Boooool00ol0003o
ooooooooo`1iooooo`00F?ooool2o`0004Gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1jooooo`00F_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0N_ooool005_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo07_ooooo001Looooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1looooo`00GOooool2o`00043ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1mooooo`00Goooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0OOooool0063ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Qooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00H_ooool00ol0
003oooooooooo`0jooooo`;o0000AOooool00ol0003oooooooooo`1oooooo`00Hoooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool006?ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo
001Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`21ooooo`00IOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0POooool006Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo08;ooooo001Wooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`22ooooo`00J?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0P_ooool006Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001Yooooo`03o`000?oooooo
oooo03?ooooo0_l00011ooooo`03o`000?oooooooooo08?ooooo001Zooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`23ooooo`00Joooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool006cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo
001/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`24ooooo`00KOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Q?ooool006kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo08Gooooo001_ooooo`03o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`25ooooo`00Koooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0QOooool0073ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo08Gooooo001aooooo`03o`000?oooooooooo013ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000mooooo`03o`000?oooooo
oooo08Kooooo001aooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26
ooooo`00L_ooool00ol0003oooooooooo`0?ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool0
07;ooooo00?o0000ooooooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qooo
ool007?ooooo00?o0000ooooooooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Qoooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo08Oooooo001dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`28ooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0R?ooool007Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo08Sooooo001fooooo`03o`000?oooooooooo02Kooooo
0_l0000looooo`03o`000?oooooooooo08Sooooo001gooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Moooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool007Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo001iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`29ooooo`00
NOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
ROooool007[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo08Wooooo001jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`29ooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0ROooool007cooooo00?o0000ooooooooool08?ooool2o`0003_o
oooo00?o0000ooooooooool0ROooool007cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo08Wooooo001mooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`29ooooo`00O_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool007kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08[ooooo001oooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2:ooooo`00
Ooooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
R_ooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo08[ooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2:ooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0R_ooool008;ooooo00?o0000ooooooooool06_ooool2o`0003[o
oooo00?o0000ooooooooool0R_ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo08_ooooo0023ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00Q?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Roooool008Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08_ooooo0025ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00
QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
Roooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00Q?oo
ool01OmgMgOoV9RHo`000?nHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00Q?ooool01Ol@413ooooooooo
ool0003o410@00_ooooo1Ol00006ooooo`?o0000>?ooool00ol0003oooooooooo`2;ooooo`00Q?oo
ool00ol0003oooooooooo`02o`0000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo08_ooooo0024ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0S?ooool008Cooooo00Go410@ooooooooooooooooo`00000<ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00Q?ooool01OmgMgOoV9RH
oooooonHV9So000000cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo08cooooo0024ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00003?ooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool008Wo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08co
oooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2<ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0S?ooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo08cooooo002;ooooo`03o`000?oooooooooo017ooooo0_l0000hoooo
o`03o`000?oooooooooo08cooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2<ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool008gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo002=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00S_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool008ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08co
oooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2<ooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0S?ooool0093ooooo00?o0000ooooooooool03?ooool2o`0003Sooooo00?o0000
ooooooooool0S?ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo08cooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2<ooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool009;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo002Cooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00Toooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool009Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08co
oooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2<ooooo`00UOooool00ol0003oooooooooo`07ooooo`;o0000>?ooool00ol0003ooooooooo
o`2<ooooo`00UOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0S?ooool009Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo08cooooo002Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2<ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool009Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo002Hooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=ooooo`00Q?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?l000001_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo0024ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00KoEEEEogMgMoooooooV9RHob4Q8Ol00005ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0SOooool008Cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`04o`000?ooooooooooooooo`;o00001Oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo08gooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01ol0
003oV9RHoooooonHV9So8B4Qooooool000001?ooool3o`0003Kooooo00?o0000ooooooooool0SOoo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`07o`000?mEEEGo0000oa0@4?o<c<co
ooooo`000004ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0SOooool008Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Cooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo08gooooo0024ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ooMgMgo410@oiRHV004ooooo`05o`000?ooooooooooooooool00000>?ooool0
0ol0003oooooooooo`2=ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@0oooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo08gooooo
002Looooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0SOooool009gooooo00?o
0000ooooool00000>?ooool00ol0003oooooooooo`2=ooooo`00WOooool00ol0003oooooo`00000h
ooooo`03o`000?oooooooooo08gooooo002Nooooo`;o0000>?ooool00ol0003oooooooooo`2=oooo
o`00W_ooool3o`0003Oooooo00?o0000ooooooooool0SOooool009oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`2=ooooo`00Woooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo08kooooo002Oooooo`;o0000=_ooool00ol0003oooooooooo`2>ooooo`00Woooool2o`00
03Kooooo00?o0000ooooooooool0S_ooool009oooooo00?o0000ooooool00000=Oooool00ol0003o
ooooooooo`2>ooooo`00Woooool00ol0003oooooo`00000eooooo`03o`000?oooooooooo08kooooo
002Oooooo`04o`000?ooooooooooo`0003Cooooo00?o0000ooooooooool0S_ooool009oooooo00Co
0000oooooooooooo0000=?ooool00ol0003oooooooooo`2>ooooo`00Woooool2o`0000;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`2>ooooo`00Woooool01Ol0003ooooooooooooo
oooo000003?ooooo00?o0000ooooooooool0S_ooool009oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo08kooooo002Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2>ooooo`00Woooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0S_ooool009oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08kooooo
002Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`2>ooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0S_ooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo08kooooo002Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`2>ooooo`00Woooool2o`0000Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2>ooooo`00Woooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0S_ooool009oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08kooooo002Oooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2>ooooo`00Woooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0S_ooool009oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08kooooo
002Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2>ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0S_ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo08kooooo0024ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0Soooool008Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0Soooool008Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0Soooool008Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0Soooool008Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Soooool008Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Soooool009oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08oooooo002Oooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2@ooooo`00Wooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0T?oo
ool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo093ooooo002Oooooo`;o00004_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
093ooooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`2@ooooo`00Woooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0T?ooool009oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo093ooooo002Oooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`2@ooooo`00Woooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0T?ooool009oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo093ooooo002Oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Aooooo`00Wooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0TOoo
ool009oooooo0_l0000Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0TOooool0
09oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
097ooooo002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`2Aooooo`00Woooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0TOooool009oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo097ooooo002Oooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`2Aooooo`00Woooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0T_ooool009oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09;ooooo002Oooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Booooo`00Wooo
ool2o`0001gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Booooo`00Woooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Toooool0
09oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
09?ooooo002Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2Cooooo`00Woooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0U?ooool009oooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo09Gooooo002Oooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2Eooooo`00UOooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
09Kooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool2o`0000Go
oooo0_l0002Iooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo
0ol000000ooooooo0000ooooo`2Jooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000:Ooo
ool00ol0003oooooooooo`2Jooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00Uoooool00ol0
003oooooooooo`3>ooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00UOooool00omEEEGoIVIV
o`00003@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4QY_ooool00:So
oooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2
ob4Q8JKooooo002Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0[?ooool00:So
oooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0[?ooool00:Sooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`2/ooooo`00Y_ooool00ol@413o0000o`00
0003o`0000gooooo00?o0000ooooooooool0[?ooool00:Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2/ooooo`00Z?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo0000
0:kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
2e-05 8e-05 m
.01432 .00014 L
.02864 .00024 L
.04297 .00042 L
.05734 .00072 L
.07176 .00119 L
.08625 .00195 L
.10086 .00312 L
.11564 .00489 L
.13066 .00751 L
.146 .01132 L
.16178 .01672 L
.17814 .0242 L
.19524 .03435 L
.21325 .04778 L
.23235 .06514 L
.25272 .08706 L
.27449 .11404 L
.29776 .14643 L
.32255 .1843 L
.34878 .22736 L
.37626 .27494 L
.40468 .32588 L
.43359 .37862 L
.46246 .43119 L
.49065 .48133 L
.51751 .52665 L
.54239 .56484 L
.56471 .5938 L
.58401 .61188 L
.6 .61803 L
.61258 .61188 L
.62185 .5938 L
.6281 .56484 L
.6318 .52665 L
.63351 .48133 L
.63389 .43119 L
.63359 .37862 L
.63325 .32588 L
.6334 .27494 L
.63449 .22736 L
.63683 .1843 L
.64062 .14643 L
.64592 .11404 L
.65272 .08706 L
.66093 .06514 L
.6704 .04778 L
.68096 .03435 L
.69243 .0242 L
.70464 .01672 L
Mistroke
.71743 .01132 L
.73066 .00751 L
.74421 .00489 L
.75801 .00312 L
.77197 .00195 L
.78605 .00119 L
.8002 .00072 L
.8144 .00042 L
.82864 .00024 L
.8429 .00014 L
.85716 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool2o`0005Kooooo00?o0000ooooooooool0E_ooool2o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo053ooooo0ol0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1dooooo`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0MOooool005?ooooo0_l0001:ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0M_ooool005Gooooo0_l00018ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0Moooool005Oooooo00?o0000ooooooooool0AOooool2o`0004co
oooo00?o0000ooooooooool0N?ooool005Sooooo0_l00015ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0NOooool005[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo07Wooooo001Kooooo`;o0000@_ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo07[ooooo001Mooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1kooooo`00G_ooool2o`0003oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`1looooo`00H?ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool0067ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001Rooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00Hoooool00ol0
003oooooooooo`0iooooo`;o0000A_ooool00ol0003oooooooooo`1nooooo`00I?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool006Cooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo
001Uooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`20ooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0P?ooool006Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo087ooooo001Xooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`21ooooo`00JOooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0POooool006[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo08;ooooo001Zooooo`03o`000?oooooo
oooo03;ooooo0_l00012ooooo`03o`000?oooooooooo08;ooooo001[ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`22ooooo`00K?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Poooool006gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo
001]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`23ooooo`00K_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0Poooool006oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo08Cooooo001`ooooo`03o`000?oooooooooo017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`24ooooo`00L?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0Q?ooool0077ooooo00?o0000ooooooooool04?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo001booooo`03o`000?oooooooooo00oooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000oooooo`03o`000?oooooo
oooo08Cooooo001cooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24
ooooo`00M?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
07Cooooo00?o0000ooooooooool03Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0QOoo
ool007Gooooo00?o0000ooooooooool03?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
QOooool007Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo08Gooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`25ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0QOooool007Sooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo08Gooooo001iooooo`03o`000?oooooooooo02?ooooo
0_l0000oooooo`03o`000?oooooooooo08Gooooo001jooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`25ooooo`00N_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool007_ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Kooooo001looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26ooooo`00
O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
Q_ooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo08Kooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`27ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0Qoooool007oooooo00?o0000ooooooooool07Oooool2o`0003go
oooo00?o0000ooooooooool0Qoooool007oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo08Oooooo0020ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00POooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool0087ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo0022ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00
P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Qoooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo08Oooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`27ooooo`00Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0Qoooool008Gooooo00?o0000ooooooooool05oooool2o`0003go
oooo00?o0000ooooooooool0Qoooool008Gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo08Oooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Qoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool008Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo0028ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00
R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Qoooool008Cooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00
Q?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Cooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Q?ooool01ol@413o
oooooooooooooooo410@ooooool000002Oooool5o`0000Kooooo0ol0000looooo`03o`000?oooooo
oooo08Oooooo0024ooooo`07o`000?ooooooooooooooool0003oooooo`000009ooooo`04odA4A?oM
gMgoooooo`0000Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Q?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool008Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Kooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`06ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Q?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool01_ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool008gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo002>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00S_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool0
08oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
08Sooooo002?ooooo`03o`000?oooooooooo00gooooo0_l0000looooo`03o`000?oooooooooo08So
oooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`28ooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0R?ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo08Sooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`28ooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool009?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo002Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00U?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool0
09Gooooo00?o0000ooooooooool01oooool2o`0003cooooo00?o0000ooooooooool0R?ooool009Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08So
oooo002Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`28ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0R?ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo08Sooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`28ooooo`00V?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool009Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo002Iooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00V_ooool0
0ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`28ooooo`00Voooool01Ol0
003ooooooooooooooooo000003gooooo00?o0000ooooooooool0R?ooool009_ooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo08Sooooo002Looooo`04o`000?oooooooooo
o`0003gooooo00?o0000ooooooooool0R?ooool009cooooo00Co0000oooooooooooo0000?Oooool0
0ol0003oooooooooo`28ooooo`00WOooool00ol0003oooooo`00000mooooo`03o`000?oooooooooo
08Sooooo002Mooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0R?ooool008Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Gooooo0_l0000mooooo`03o`000?oooooooooo08Sooooo0024ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`;o0000?Oooool0
0ol0003oooooooooo`28ooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?oo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0003_ooooo00?o0000ooooooooool0R?ooool008Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool2o`0003cooooo00?o0000oooooooo
ool0R?ooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooool00000>oooool00ol0003oooooooooo`28ooooo`00Q?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooo`00000kooooo`03
o`000?oooooooooo08Sooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4106ooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0R?ooool0
09oooooo00Co0000oooooooooooo0000>_ooool00ol0003oooooooooo`28ooooo`00Woooool01Ol0
003ooooooooooooooooo000003Wooooo00?o0000ooooooooool0R?ooool009oooooo00Go0000oooo
ooooooooooooo`00000iooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`28ooooo`00Woooool2o`0000?o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`28ooooo`00Woooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0R?ooool009oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08Oooooo002O
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`27
ooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0Qoooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo08Oooooo002Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`27ooooo`00Woooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0Qoooool009oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo08Oooooo002Oooooo`;o00002?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo08Oooooo002Oooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`27ooooo`00Woooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Qoooool009oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo08Oooooo002O
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`27
ooooo`00Woooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0Qoooool009oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo08Oooooo002Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`27ooooo`00Woooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0R?ooool009oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08Sooooo002Oooooo`;o00003_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`28ooooo`00Woooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0R?ooool009oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08Sooooo002O
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`28
ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0R?ooool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo08Sooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`28ooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0R?ooool008Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001;ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`28ooooo`00Q?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`28ooooo`00Q?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`28ooooo`00Q?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`28ooooo`00Q?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`28ooooo`00Q?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`28ooooo`00Woooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0R?ooool0
09oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
08Sooooo002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`28ooooo`00Woooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0R?ooool009oooooo0_l0000Iooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0R?ooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`28ooooo`00Woooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0R?ooool009oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`28ooooo`00Woooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0R?ooool0
09oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
08Wooooo002Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`29ooooo`00Woooool2o`0001oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`29ooooo`00Woooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0ROooool009oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo08Wooooo002Oooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`29ooooo`00Woooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0ROooool009oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Wooooo002Oooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2:ooooo`00Woooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0R_ooool0
09oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
08[ooooo002Oooooo`;o00009_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08[o
oooo002Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2;ooooo`00Woooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Roooool009oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo08_ooooo002Oooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`2<ooooo`00Woooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0S?ooool009oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08gooooo002Eooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0SOooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/
ooooo`;o00001_ooool2o`00093ooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0;_ooool3o`000003ooooool0003o000009;ooooo002Gooooo`03o`000?oooooooooo00Go
oooo0ol0000aooooo`03o`000?oooooooooo09;ooooo002Gooooo`03o`000?oooooooooo0<kooooo
002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Eoooo
o`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B44ooooo`Go0000XOooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00001?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A40:7ooooo
002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP2Rooooo`00Y?ooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`0<
ooooo`03oiRHV?lQ8B7ok^k^0:7ooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00omgMgOoIVIVooooo`2Pooooo`00X_ooool00ol@413o0000o`000003o`0000go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`00Y?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@402Qooooo`00
Y?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c02Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
2e-05 8e-05 m
.01433 .00014 L
.02865 .00024 L
.04299 .00042 L
.05737 .00072 L
.07181 .00119 L
.08634 .00195 L
.10101 .00312 L
.11587 .00489 L
.131 .00751 L
.14652 .01132 L
.16255 .01672 L
.17926 .0242 L
.19683 .03435 L
.21546 .04778 L
.23537 .06514 L
.25674 .08706 L
.27976 .11404 L
.30453 .14643 L
.33107 .1843 L
.35929 .22736 L
.38897 .27494 L
.41974 .32588 L
.4511 .37862 L
.48239 .43119 L
.5129 .48133 L
.54186 .52665 L
.5685 .56484 L
.59216 .5938 L
.6123 .61188 L
.62857 .61803 L
.64087 .61188 L
.6493 .5938 L
.65421 .56484 L
.65614 .52665 L
.65576 .48133 L
.65382 .43119 L
.6511 .37862 L
.64832 .32588 L
.64611 .27494 L
.645 .22736 L
.64535 .1843 L
.64739 .14643 L
.65119 .11404 L
.65674 .08706 L
.66394 .06514 L
.6726 .04778 L
.68254 .03435 L
.69355 .0242 L
.70541 .01672 L
Mistroke
.71795 .01132 L
.731 .00751 L
.74444 .00489 L
.75815 .00312 L
.77206 .00195 L
.7861 .00119 L
.80023 .00072 L
.81442 .00042 L
.82865 .00024 L
.8429 .00014 L
.85717 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool3o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:oooo
o`?o0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo057ooooo0_l0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1cooooo`00D_ooool2o`0004_ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`1dooooo`00E?ooool2o`0004Wooooo00?o0000ooooooooool0COooool2
o`0007Oooooo001Fooooo`;o0000Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
07Oooooo001Hooooo`03o`000?oooooooooo04Cooooo0_l0001<ooooo`03o`000?oooooooooo07So
oooo001Iooooo`;o0000A?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wooooo
001Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`1iooooo`00G?ooool2o`00047ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1j
ooooo`00G_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0Noooool005oooooo0_l0000nooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool0067ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`1mooooo`00Hoooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0OOooool006Cooooo00?o0000ooooooooool0>?ooool2o`00
04Oooooo00?o0000ooooooooool0OOooool006Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00I_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool006Oooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001Xoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`20oooo
o`00JOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0P?ooool006[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo083ooooo001[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`21ooooo`00Joooool00ol0003oooooooooo`0aooooo`;o0000@oooool0
0ol0003oooooooooo`21ooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool006gooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo087ooooo001^ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Koooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool0073ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo08;ooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`22oooo
o`00L_ooool00ol0003oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool007;o
oooo00?o0000ooooooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo08;ooooo001cooooo`03o`000?oooooooooo00kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`22
ooooo`00M?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000@Oooool00ol0003oooooooooo`22ooooo`00MOooool00ol0
003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool007Kooooo00?o0000oooo
ooooool02oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo08;ooooo001fooooo`03o`000?oooooooooo
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001gooooo`03o`000?oooooo
oooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001hooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`23ooooo`00NOooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Poooool0
07[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
08?ooooo001jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`23ooooo`00Noooool00ol0003oooooooooo`0Qooooo`;o0000@Oooool00ol0003ooooo
ooooo`23ooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0Poooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo08?ooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`23ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool007oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo001oooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00P?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo0022ooooo`03o`000?oooooooooo01[ooooo0_l00010ooooo`03o`000?oooooooooo08Co
oooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`24ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0Q?ooool008Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo0026ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Qoooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
08Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo0028ooooo`03o`000?oooooooooo01Cooooo0_l00010ooooo`03o`000?oooooooooo08Co
oooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`24ooooo`00ROooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0Q?ooool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool008cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo0024ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01?l0003oooooob4Q8OlQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool00ol0003o8B4Qob4Q8@07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Q?ooool01Ol@413ooooo
oooooooooooo410@00Cooooo00?o0000ooooooooool01?ooool5o`0000Kooooo0ol0000oooooo`03
o`000?oooooooooo08Cooooo0024ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`03ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`24ooooo`00Q?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Q?ooool008Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo00?ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo08Cooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003oooooooooo`02
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24
ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool00oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`24ooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0Q?ooool009?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo08Cooooo002Cooooo`03o`000?oooooooooo00Wooooo0_l00010
ooooo`03o`000?oooooooooo08Cooooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00UOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool009Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
09Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`23ooooo`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0Poooool009Wooooo00?o0000ooooooooool00oooool2o`00047ooooo00?o
0000ooooooooool0Poooool009[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo08?ooooo002Kooooo`05o`000?ooooooooooooooool00000@_ooool0
0ol0003oooooooooo`23ooooo`00Voooool01Ol0003ooooooooooooooooo000004;ooooo00?o0000
ooooooooool0Poooool009cooooo00Co0000oooooooooooo0000@_ooool00ol0003oooooooooo`23
ooooo`00WOooool00ol0003oooooo`000012ooooo`03o`000?oooooooooo08?ooooo002Mooooo`03
o`000?oooooo000004;ooooo00?o0000ooooooooool0Poooool009kooooo0_l00012ooooo`03o`00
0?oooooooooo08?ooooo002Nooooo`;o0000@_ooool00ol0003oooooooooo`23ooooo`00Woooool2
o`00047ooooo00?o0000ooooooooool0Poooool009oooooo0_l00011ooooo`03o`000?oooooooooo
08?ooooo002Oooooo`;o0000@Oooool00ol0003oooooooooo`23ooooo`00Woooool00ol0003ooooo
o`000010ooooo`03o`000?oooooooooo08?ooooo002Oooooo`03o`000?oooooo0000043ooooo00?o
0000ooooooooool0Poooool009oooooo00Co0000oooooooooooo0000@?ooool00ol0003ooooooooo
o`22ooooo`00Woooool01?l0003oooooooooool00010ooooo`03o`000?oooooooooo08;ooooo0024
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`22ooooo`00
Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool01Ol0003ooooooooooooooooo000003oooooo00?o0000ooooooooool0P_ooool0
08Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0P_oo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0000?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`22ooooo`00Q?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`22ooooo`00
Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0P_ooool008Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08;ooooo0024ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`22ooooo`00Woooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0P_ooool009oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08;ooooo
002Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`22ooooo`00Woooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0P_ooool009oooooo0_l00009ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0P_ooool009oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo08;ooooo002Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0POooool009oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo087ooooo
002Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`21ooooo`00Woooool2o`0000oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`21
ooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0POooool009oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0POooool009oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo087ooooo
002Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`21ooooo`00Woooool2o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`21
ooooo`00Woooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0POooool009oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`21ooooo`00Q?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0POooool0
08Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo087ooooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0000Iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
POooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0POooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0POooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0POooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0POooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0POooool009oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo087ooooo002Oooooo`;o0000
8Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`21ooooo`00Woooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0POooool0
09oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
087ooooo002Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0POooool009oooooo0_l0000Wooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`21ooooo`00Woooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0POooool0
09oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
087ooooo002Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0P_ooool009oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo08;ooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`22ooooo`00Woooool2o`0002kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`22ooooo`00Woooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Poooool009oooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08?ooooo002Oooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`23ooooo`00Woooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Q?ooool0
09oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
08Cooooo002Oooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`24ooooo`00UOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Gooooo002Gooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=Oooool2o`0000Kooooo0_l00027ooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo0ol000000ooooooo0000o`000029
ooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000>_ooool00ol0003oooooooooo`29oooo
o`00Uoooool00ol0003oooooooooo`3>ooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00Uooo
ool00ol0003oooooooooo`3>ooooo`00UOooool00omEEEGoIVIVo`00003@ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo09oooooo
002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Oooooo00?o0000ooooooooool0X?ooool00:Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`Go0000XOooool00:Cooooo00?o0000ooooooooool01?ooool6
o`0000Cooooo00?o0000ooooooooool02_ooool01?m4A4CogMgMooooool0002Rooooo`00Y?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo0000X_oo
ool00:;ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00_ooooo00?oMgMg
olc<c?l00000X_ooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;oooo
o`03onk^k_m4A4Co00000:;ooooo002Tooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l0
00003_ooool00omgMgOo0000ooooo`2Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
3e-05 8e-05 m
.01434 .00014 L
.02866 .00024 L
.04301 .00042 L
.05741 .00072 L
.07187 .00119 L
.08643 .00195 L
.10115 .00312 L
.11609 .00489 L
.13135 .00751 L
.14704 .01132 L
.16333 .01672 L
.18038 .0242 L
.19842 .03435 L
.21767 .04778 L
.23838 .06514 L
.26077 .08706 L
.28503 .11404 L
.3113 .14643 L
.33959 .1843 L
.3698 .22736 L
.40168 .27494 L
.43481 .32588 L
.4686 .37862 L
.50233 .43119 L
.53515 .48133 L
.5662 .52665 L
.59461 .56484 L
.61961 .5938 L
.64058 .61188 L
.65714 .61803 L
.66915 .61188 L
.67675 .5938 L
.68033 .56484 L
.68049 .52665 L
.67801 .48133 L
.67375 .43119 L
.6686 .37862 L
.66338 .32588 L
.65882 .27494 L
.65552 .22736 L
.65387 .1843 L
.65415 .14643 L
.65646 .11404 L
.66077 .08706 L
.66695 .06514 L
.67481 .04778 L
.68413 .03435 L
.69467 .0242 L
.70618 .01672 L
Mistroke
.71847 .01132 L
.73135 .00751 L
.74466 .00489 L
.7583 .00312 L
.77215 .00195 L
.78616 .00119 L
.80026 .00072 L
.81444 .00042 L
.82866 .00024 L
.84291 .00014 L
.85717 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool3o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:oooo
o`Co0000DOooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004kooooo0ol0001>ooooo`03
o`000?oooooooooo057ooooo0_l0001cooooo`00DOooool2o`0004cooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1cooooo`00Doooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool0M?ooool005Cooooo0_l00019ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0MOooool005Kooooo0_l00017ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0M_ooool005Sooooo00?o0000ooooooooool0A?ooool2o`0004go
oooo00?o0000ooooooooool0Moooool005Wooooo0_l00014ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool0N?ooool005_ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo07Sooooo001Looooo`;o0000@Oooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo07Wooooo001Nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1jooooo`00Goooool2o`0003kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1kooooo`00HOooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0Noooool006;ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001Sooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00I?ooool00ol0
003oooooooooo`0hooooo`;o0000B?ooool00ol0003oooooooooo`1looooo`00IOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool006Kooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo
001Wooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`1mooooo`00J?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0O_ooool006Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo07kooooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`1nooooo`00Joooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool006cooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001]ooooo`03o`000?oooooo
oooo02oooooo0_l00015ooooo`03o`000?oooooooooo07oooooo001^ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00Koooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool0073ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo
001aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`20ooooo`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0P?ooool007?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo087ooooo001dooooo`03o`000?oooooooooo00gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`21ooooo`00M?ooool00ol0003oooooooooo`0=ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool0POooool007Gooooo00?o0000ooooooooool03?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo087ooooo001fooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00012ooooo`03o`000?oooooo
oooo087ooooo001gooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21
ooooo`00N?ooool00ol0003oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool0
07Sooooo00?o0000ooooooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POoo
ool007Wooooo00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool007[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo087ooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`21ooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool007cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo087ooooo001mooooo`03o`000?oooooooooo01oooooo
0_l00013ooooo`03o`000?oooooooooo087ooooo001nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Ooooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool007oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087ooooo0020ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00
POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo087ooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`21ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool008Cooooo00?o0000ooooooooool06?ooool2o`0004?o
oooo00?o0000ooooooooool0POooool008Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo087ooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Q_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool008Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087ooooo0027ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00
R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo087ooooo0029ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`21ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool008_ooooo00?o0000ooooooooool04Oooool2o`0004?o
oooo00?o0000ooooooooool0POooool008_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo087ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00SOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool008gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087ooooo002>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00
Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003ooooo00Gooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00Go0000
1_ooool3o`0004;ooooo00?o0000ooooooooool0POooool008Cooooo00Go0000oooooooooooooooo
o`000008ooooo`07o`000?ooooooooooodA4A?oMgMgoooooo`000007ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool008Cooooo00Go0000ooooooooooooooooo`000009oooo
o`06o`000?oooooogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo083ooooo0024ooooo`05oa0@4?ooooooooooooooool@41002_ooool01Ol0003oooooogMg
Moo<c<co000000Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`20ooooo`00Q?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00Go0000ooooooo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool008Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`04o`000?ooooooMgMgo`0000Oooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`20ooooo`00UOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool0P?ooool009Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo083ooooo002Fooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`20ooooo`00Uoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool009Oooooo00?o0000oooo
ooooool01Oooool2o`0004Cooooo00?o0000ooooooooool0P?ooool009Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo002Iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`20ooooo`00VOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?oo
ool009[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo083ooooo002Kooooo`05o`000?ooooooooooooooool00000AOooool00ol0003oooooooooo`20
ooooo`00Voooool01Ol0003ooooooooooooooooo000004Gooooo00?o0000ooooooooool0P?ooool0
09cooooo00Co0000oooooooooooo0000A_ooool00ol0003oooooooooo`1oooooo`00WOooool00ol0
003oooooo`000016ooooo`03o`000?oooooooooo07oooooo002Mooooo`04o`000?oooooo0000o`00
04Gooooo00?o0000ooooooooool0Ooooool009kooooo0_l00016ooooo`03o`000?oooooooooo07oo
oooo002Oooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool009oooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00Woooool2o`0004Gooooo00?o0000
ooooooooool0Ooooool009oooooo00?o0000ooooool00000A?ooool00ol0003oooooooooo`1ooooo
o`00Woooool00ol0003oooooo`000014ooooo`03o`000?oooooooooo07oooooo002Oooooo`04o`00
0?ooooooooooo`0004?ooooo00?o0000ooooooooool0Ooooool009oooooo00Go0000oooooooooooo
ooooo`000012ooooo`03o`000?oooooooooo07oooooo002Oooooo`;o00000_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo07oooooo002Oooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`1nooooo`00Woooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0O_ooool009oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo07kooooo002Oooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1nooooo`00
Woooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
O_ooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo07kooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0O_ooool008Cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0OOooool008Cooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0000Oooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`1mooooo`00Q?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`1mooooo`00Q?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0OOooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo07gooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`1mooooo`00Woooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0OOooool009oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo07gooooo002Oooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1looooo`00Woooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0O?ooool009oooooo
0_l0000>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0O?ooool009oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07cooooo002O
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1l
ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0O?ooool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo07cooooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1looooo`00Woooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0Noooool009oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo07_ooooo002Oooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1kooooo`00Woooool2o`0001Go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1kooooo`00Woooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Noooool009oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07_ooooo002O
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1k
ooooo`00Woooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0Noooool009oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo07_ooooo002Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1kooooo`00Woooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0Noooool009oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1jooooo`00Woooool2o`0001_o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1jooooo`00Woooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0N_ooool009oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo07[ooooo002O
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1j
ooooo`00Woooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0N_ooool009oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1jooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0N_ooool008Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07[ooooo0024ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000P
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N_ooool008Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0N_ooool008Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool008Cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool008Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0NOooool008Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0NOooool0
09oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
07Wooooo002Oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo07Wooooo002Oooooo`;o0000:?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1iooooo`00Woooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool0
09oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
07Wooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0NOooool009oooooo0_l0000^ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0NOooool009oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1iooooo`00Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0NOooool0
09oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
07Wooooo002Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1jooooo`00Woooool2o`0003Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1jooooo`00Woooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0N_ooool009oooooo00?o0000ooooooooool0=oooool2o`00013ooooo00?o0000
ooooooooool0N_ooool009oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1kooooo`00Woooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0Noooool009oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07cooooo002Eooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0O?ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0noooo
o`;o00001Oooool2o`0007oooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0@?ooool3o`000003ooooool0003ooooo083ooooo002Gooooo`03o`000?oooooooooo00Gooooo
0ol00013ooooo`03o`000?oooooooooo083ooooo002Gooooo`03o`000?oooooooooo0<kooooo002G
ooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Eooooo`03
oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Toooo
o`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0XOooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@
4002ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q0:7ooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo00000:7ooooo002Tooooo`03o`000?oooooooooo00Cooooo1_l0
0004ooooo`03o`000?oooooooooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2Qooooo`00Y?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go0000oeEEEOl0003o410@
olc<c02Qooooo`00X_ooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool02_oo
ool00omEEEGoQhN7ooooo`2Sooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00[ooooo00?ogMgMoa0@4?nHV9P0Xoooool00:Cooooo00?o0000ooooooooool03?ooool00omE
EEGoIVIVo`00000=ooooo`04olc<c?m4A4Co0000oa0@4:7ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
3e-05 8e-05 m
.01434 .00014 L
.02867 .00024 L
.04303 .00042 L
.05744 .00072 L
.07192 .00119 L
.08652 .00195 L
.1013 .00312 L
.11632 .00489 L
.1317 .00751 L
.14757 .01132 L
.1641 .01672 L
.1815 .0242 L
.20001 .03435 L
.21988 .04778 L
.24139 .06514 L
.26479 .08706 L
.29031 .11404 L
.31807 .14643 L
.34811 .1843 L
.38031 .22736 L
.41439 .27494 L
.44988 .32588 L
.4861 .37862 L
.52226 .43119 L
.55741 .48133 L
.59055 .52665 L
.62073 .56484 L
.64706 .5938 L
.66887 .61188 L
.68571 .61803 L
.69744 .61188 L
.7042 .5938 L
.70644 .56484 L
.70484 .52665 L
.70026 .48133 L
.69369 .43119 L
.6861 .37862 L
.67845 .32588 L
.67153 .27494 L
.66603 .22736 L
.66239 .1843 L
.66092 .14643 L
.66173 .11404 L
.66479 .08706 L
.66996 .06514 L
.67702 .04778 L
.68572 .03435 L
.69579 .0242 L
.70696 .01672 L
Mistroke
.719 .01132 L
.7317 .00751 L
.74489 .00489 L
.75844 .00312 L
.77224 .00195 L
.78621 .00119 L
.8003 .00072 L
.81446 .00042 L
.82867 .00024 L
.84291 .00014 L
.85717 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool3o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:oooo
o`Co0000DOooool00ol0003oooooooooo`1Dooooo`;o0000L?ooool004kooooo0ol0001>ooooo`03
o`000?oooooooooo057ooooo0ol0001booooo`00DOooool2o`0004cooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1cooooo`00Doooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool0M?ooool005Cooooo0_l00019ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0MOooool005Kooooo0_l00017ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0M_ooool005Sooooo0_l00015ooooo`;o0000COooool00ol0003o
ooooooooo`1gooooo`00F_ooool2o`0004?ooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1hooooo`00G?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0N?ooool005gooooo0_l00010ooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0NOooool005oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo07Wooooo001Pooooo`;o0000?Oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo07[ooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`1jooooo`00Hoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0Noooool006Cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001Uooooo`03o`000?oooooooooo
03Oooooo0_l00018ooooo`03o`000?oooooooooo07cooooo001Vooooo`;o0000=oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo07gooooo001Xooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00JOooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool006[ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001[oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1noooo
o`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0O_ooool006gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo07kooooo001^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`1nooooo`00K_ooool00ol0003oooooooooo`0^ooooo`;o0000A_ooool0
0ol0003oooooooooo`1nooooo`00Koooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0O_ooool0073ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo07kooooo001aooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00L_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool007?ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001doooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1ooooo
o`00MOooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool007Go
oooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo07oooooo001fooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1o
ooooo`00Moooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000A?ooool00ol0003oooooooooo`1oooooo`00N?ooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool007Wooooo00?o0000oooo
ooooool02?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001jooooo`03o`000?oooooooooo
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001kooooo`03o`000?oooooo
oooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001looooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00OOooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool0
07kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
07oooooo001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`1oooooo`00Ooooool00ol0003oooooooooo`0Mooooo`;o0000AOooool00ol0003ooooo
ooooo`1oooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0Ooooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo07oooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1oooooo`00Poooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool008?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo0024ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00QOooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool0
08Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
07oooooo0027ooooo`03o`000?oooooooooo01Gooooo0_l00015ooooo`03o`000?oooooooooo07oo
oooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1oooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0Ooooool008Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo07oooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1oooooo`00R_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool008_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo002<ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00SOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool0
08kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
07kooooo002>ooooo`03o`000?oooooooooo00kooooo0_l00016ooooo`03o`000?oooooooooo07ko
oooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`1nooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0O_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo07kooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`1nooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool009?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo0024ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo00?o0000ooooooooool00_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool008Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool008Cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`0004Kooooo00?o0000ooooooooool0OOooool008Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?l0003oooooo`0000Oooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00Q?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOl0003o00001oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo07gooooo0024ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool008Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`1mooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?l000001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo002Ioooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1loooo
o`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool009[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo002Kooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooo
ooooo`1looooo`00Voooool01?l0003oooooooooooooool2o`0004Sooooo00?o0000ooooooooool0
O?ooool009cooooo00Co0000oooooooooooo0000BOooool00ol0003oooooooooo`1looooo`00WOoo
ool00ol0003oooooo`000019ooooo`03o`000?oooooooooo07cooooo002Nooooo`;o0000BOooool0
0ol0003oooooooooo`1looooo`00W_ooool2o`0004[ooooo00?o0000ooooooooool0Noooool009oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00Woooool2o`0004Wooooo
00?o0000ooooooooool0Noooool009oooooo00?o0000ooooool00000B?ooool00ol0003ooooooooo
o`1kooooo`00Woooool00ol0003oooooo`000018ooooo`03o`000?oooooooooo07_ooooo002Ooooo
o`;o000000?oooooo`000?ooool0A_ooool00ol0003oooooooooo`1kooooo`00Woooool01Ol0003o
oooooooooooooooo000004Kooooo00?o0000ooooooooool0Noooool009oooooo00Go0000oooooooo
ooooooooo`000017ooooo`03o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1jooooo`00Woooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0N_ooool009oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07[ooooo002O
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1j
ooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0N_ooool009oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo07[ooooo002Oooooo`;o00001oooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1iooooo`00Woooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1iooooo`00Woooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0NOooool009oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo07Wooooo0024
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`1iooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0NOooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0N?ooool008Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0000gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`1hooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`1hooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0N?ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo07Sooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1hooooo`00Woooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0N?ooool009oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo07Oooooo002Oooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`1gooooo`00Woooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0Moooool009oooooo0_l0000Dooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0Moooool009oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Oooooo002Oooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1fooooo`00Woooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0M_ooool009oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07Ko
oooo002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`1fooooo`00Woooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0M_ooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo07Gooooo002Oooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`1eooooo`00Woooool2o`0001_ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`1eooooo`00Woooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0MOooool009oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07Gooooo002Oooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1eooooo`00Woooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0MOooool009oo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07Co
oooo002Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1dooooo`00Woooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0M?ooool009oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo07Cooooo002Oooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1dooooo`00Woooool2o`00027ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`1dooooo`00Woooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0M?ooool009oooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1cooooo`00Woooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Loooool009oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07?o
oooo002Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1cooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0Loooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo07?ooooo0024ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Wooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0Loooool008Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Loooool008Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0Loooool008Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Loooool008Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0L_ooool008Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L_ooool009oooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07;ooooo002Oooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1booooo`00
Woooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
L_ooool009oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo07;ooooo002Oooooo`;o0000;oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo07;ooooo002Oooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0L_ooool009oooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo07;ooooo002Oooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0L_ooool009oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07;ooooo002Oooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1aooooo`00
Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
LOooool009oooooo0_l0000fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0LOoo
ool009oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo077ooooo002Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1aooooo`00Woooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0LOooool009oooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo077ooooo002Oooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1aooooo`00Woooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0LOooool009oooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo077ooooo002Oooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1booooo`00
Woooool2o`0003oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1booooo`00Wooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_oo
ool009oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo07;ooooo002Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Loooool009oooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1cooooo`00UOooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07Cooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A_ooool2o`00
00Kooooo0_l0001fooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04So
oooo0ol000000ooooooo0000o`00001hooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000
Boooool00ol0003oooooooooo`1hooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00Uoooool0
0ol0003oooooooooo`3>ooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00UOooool00omEEEGo
IVIVo`00003@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnH
V9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<0:7ooooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_oo
ool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@2Qooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00002Qooooo`00Y?ooool00ol0003oooooooooo`04ooooo`Ko00001?oo
ool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80XOooool00:Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05olc<c?l0003o0000o`000?o<c<`0
XOooool00:;ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00[ooooo00Go
410@okZj^_oooooo^[Zjoa0@402Qooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00Go0000okZj^_oooooo^[Zjo`00002Qooooo`00Y?ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Qooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
4e-05 8e-05 m
.01435 .00014 L
.02868 .00024 L
.04305 .00042 L
.05747 .00072 L
.07198 .00119 L
.08661 .00195 L
.10144 .00312 L
.11654 .00489 L
.13204 .00751 L
.14809 .01132 L
.16487 .01672 L
.18262 .0242 L
.20159 .03435 L
.22209 .04778 L
.2444 .06514 L
.26882 .08706 L
.29558 .11404 L
.32484 .14643 L
.35663 .1843 L
.39082 .22736 L
.4271 .27494 L
.46494 .32588 L
.50361 .37862 L
.54219 .43119 L
.57966 .48133 L
.6149 .52665 L
.64684 .56484 L
.67451 .5938 L
.69716 .61188 L
.71429 .61803 L
.72573 .61188 L
.73165 .5938 L
.73255 .56484 L
.72918 .52665 L
.72251 .48133 L
.71362 .43119 L
.70361 .37862 L
.69351 .32588 L
.68425 .27494 L
.67654 .22736 L
.67091 .1843 L
.66769 .14643 L
.66701 .11404 L
.66882 .08706 L
.67297 .06514 L
.67923 .04778 L
.68731 .03435 L
.6969 .0242 L
.70773 .01672 L
Mistroke
.71952 .01132 L
.73204 .00751 L
.74512 .00489 L
.75858 .00312 L
.77233 .00195 L
.78627 .00119 L
.80033 .00072 L
.81448 .00042 L
.82868 .00024 L
.84292 .00014 L
.85718 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool?o`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000003?l0
0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool001gooooo00?o0000
ooooooooool08?ooool7o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooooooo
ool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`00Aoooool3
o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:ooooo`Co0000DOooool00ol0
003oooooooooo`1Dooooo`;o0000L?ooool004kooooo0ol0001>ooooo`03o`000?oooooooooo05;o
oooo0_l0001booooo`00DOooool2o`0004cooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1booooo`00Doooool2o`0004[ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1cooooo`00EOooool2o`0004Sooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1d
ooooo`00Eoooool2o`0004Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1eoooo
o`00FOooool00ol0003oooooooooo`13ooooo`;o0000C_ooool00ol0003oooooooooo`1fooooo`00
F_ooool2o`0004?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00G?oo
ool2o`00047ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00G_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool0
05oooooo0_l0000nooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool0067o
oooo0_l0000looooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool006?ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo
001Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`1kooooo`00IOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0Noooool006Kooooo00?o0000ooooooooool0=_ooool2o`0004Wooooo00?o0000oooo
ooooool0Noooool006Oooooo0_l0000fooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool006Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`1looooo`00Joooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0O?ooool006cooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001]ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00K_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool006oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001`
ooooo`03o`000?oooooooooo02cooooo0_l00017ooooo`03o`000?oooooooooo07gooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1moooo
o`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0OOooool007?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo07gooooo001dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`1mooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0OOooool007Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001gooooo`03o`000?oooooooooo00[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00Moooool00ol0003oooooooooo`0:ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool007Sooooo00?o0000oooo
ooooool02Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001iooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00016
ooooo`03o`000?oooooooooo07gooooo001jooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`1mooooo`00Noooool00ol0003oooooooooo`06ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0OOooool007cooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0OOooool007gooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0OOooool007kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo07gooooo001oooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00P?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool0083ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo0021ooooo`03o`00
0?oooooooooo01_ooooo0_l00017ooooo`03o`000?oooooooooo07gooooo0022ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00Poooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool0
08Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
07gooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`1looooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0O?ooool008Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo07cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00R?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool008Wooooo00?o0000oooooooo
ool04oooool2o`0004Sooooo00?o0000ooooooooool0O?ooool008Wooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo002:ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00Roooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool0
08cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
07cooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`1looooo`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0O?ooool008oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00T?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool0097ooooo00?o0000oooooooo
ool02oooool2o`0004Wooooo00?o0000ooooooooool0Noooool009;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo07_ooooo002Cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00U?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool0
09Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
07_ooooo002Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`1kooooo`00U_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0N_ooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1jooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00Q?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000BOooool00ol0003ooooo
ooooo`1jooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00KoA4A4omgMgOoooooo
0000ooooool00005ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool008Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wooooo0024oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1iooooo`00Q?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000000oooool01Ol0003ooooooooooooo
oooo000004cooooo00?o0000ooooooooool0NOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00?ooooo00Co0000oooooooooooo0000C?ooool00ol0003ooooo
ooooo`1iooooo`00W?ooool01?l0003oooooooooool0001<ooooo`03o`000?oooooooooo07Wooooo
002Mooooo`03o`000?oooooo000004gooooo00?o0000ooooooooool0N?ooool009kooooo0_l0001=
ooooo`03o`000?oooooooooo07Sooooo002Oooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0N?ooool009oooooo0_l0001<ooooo`03o`000?oooooooooo07Sooooo002Oooooo`;o0000
C?ooool00ol0003oooooooooo`1hooooo`00Woooool00ol0003oooooo`00001<ooooo`03o`000?oo
oooooooo07Oooooo002Oooooo`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool0Mooo
ool009oooooo00Co0000oooooooooooo0000Boooool00ol0003oooooooooo`1gooooo`00Woooool0
1Ol0003ooooooooooooooooo000004[ooooo00?o0000ooooooooool0Moooool009oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07Oooooo002Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1foooo
o`00Woooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0M_ooool009oooooo0_l00005ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
M_ooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo07Kooooo002Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`1fooooo`00Woooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0MOooool009oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo07Gooooo002Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`1eooooo`00Woooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0MOooool009oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07Gooooo002Ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1eoooo
o`00Woooool2o`0000cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1dooooo`00
Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
M?ooool009oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo07Cooooo002Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`1dooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0M?ooool009oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1cooooo`00Q?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Loooool008Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
07?ooooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo07?ooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0000Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0L_oo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
L_ooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo07;ooooo
0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1booooo`00Q?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0L_ooool009oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo07;ooooo
002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1aooooo`00Woooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0LOooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo077ooooo002Oooooo`;o00006_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo077ooooo002Oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`1aooooo`00Woooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0L?ooool009oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo073ooooo002Oooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1`ooooo`00Woooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0L?ooool009oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo073ooooo
002Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`1_ooooo`00Woooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0Koooool009oooooo0_l0000Qooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0Koooool009oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo06oooooo002Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1_ooooo`00Woooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0Koooool009oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06oooooo002Oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1^ooooo`00Woooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0K_ooool009oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06kooooo
002Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1^ooooo`00Woooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0K_ooool009oooooo0_l0000Xooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0K_ooool009oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06kooooo002Oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1]ooooo`00Woooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0KOooool009oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06gooooo002Oooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1]ooooo`00Woooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0KOooool008Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
06gooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1]ooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000;_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo06cooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06cooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06cooooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06cooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo06cooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo06cooooo002Oooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1/ooooo`00Woooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool009oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06_ooooo002Oooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1[ooooo`00Wooo
ool2o`0003Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1[ooooo`00Woooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Joooool0
09oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
06_ooooo002Oooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1[ooooo`00Woooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0Joooool009oooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo06_ooooo002Oooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1[ooooo`00Woooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0J_ooool009oooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06[ooooo002Oooooo`;o0000
?Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Zooooo`00Woooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0J_ooool0
09oooooo00?o0000ooooooooool0?oooool2o`0001Sooooo00?o0000ooooooooool0J_ooool009oo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06[o
oooo002Oooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Zooooo`00Woooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Zooooo`00Woooool2o`0004Oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Zooooo`00Woooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool0B?oo
ool2o`0000oooooo00?o0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`00Woooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Joooool009oooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06_ooooo
002Eooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0K?ooool009Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1?ooooo`;o00001Oooool2o`0006kooooo002Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0DOooool3o`000003ooooool0003ooooo06oooooo002Gooooo`03
o`000?oooooooooo00Gooooo0ol0001Dooooo`03o`000?oooooooooo06oooooo002Gooooo`03o`00
0?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooo
oooo0<kooooo002Eooooo`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Xooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Gooooo0_lQ
8B6Vooooo`00Z?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo0_lQ8B6Vooooo`00Z?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^0:kooooo002Xooooo`03o`000?oooooooooo00?ooooo1_l00004ooooo`03oiRHV?lQ
8B7ok^k^0:gooooo002Xooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool0[?ooool0
0:Kooooo00?o410@o`000?l000000ol0000>ooooo`03o`000?oooooooooo0:_ooooo002Xooooo`03
o`000?oooooooooo00_ooooo00Go0000okZj^_ooooooV9RHoa0@402]ooooo`00Z?ooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0[Oooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
4e-05 8e-05 m
.01436 .00014 L
.0287 .00024 L
.04307 .00042 L
.05751 .00072 L
.07204 .00119 L
.0867 .00195 L
.10158 .00312 L
.11677 .00489 L
.13239 .00751 L
.14861 .01132 L
.16564 .01672 L
.18374 .0242 L
.20318 .03435 L
.2243 .04778 L
.24741 .06514 L
.27284 .08706 L
.30085 .11404 L
.33161 .14643 L
.36515 .1843 L
.40133 .22736 L
.43981 .27494 L
.48001 .32588 L
.52111 .37862 L
.56213 .43119 L
.60191 .48133 L
.63925 .52665 L
.67295 .56484 L
.70196 .5938 L
.72544 .61188 L
.74286 .61803 L
.75402 .61188 L
.75911 .5938 L
.75866 .56484 L
.75353 .52665 L
.74477 .48133 L
.73356 .43119 L
.72111 .37862 L
.70858 .32588 L
.69696 .27494 L
.68705 .22736 L
.67943 .1843 L
.67446 .14643 L
.67228 .11404 L
.67284 .08706 L
.67598 .06514 L
.68144 .04778 L
.6889 .03435 L
.69802 .0242 L
.7085 .01672 L
Mistroke
.72004 .01132 L
.73239 .00751 L
.74534 .00489 L
.75873 .00312 L
.77242 .00195 L
.78632 .00119 L
.80036 .00072 L
.8145 .00042 L
.8287 .00024 L
.84293 .00014 L
.85718 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool?o`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000003?l0
0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool001gooooo00?o0000
ooooooooool08?ooool7o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooooooo
ool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`00Aoooool3
o`0005Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1/ooooo`00B_ooool4o`00
057ooooo00?o0000ooooooooool0E?ooool3o`0006oooooo001>ooooo`?o0000C_ooool00ol0003o
ooooooooo`1Booooo`;o0000L_ooool0057ooooo0_l0001<ooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0L_ooool005?ooooo0_l0001:ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0Loooool005Gooooo0_l00018ooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool0M?ooool005Oooooo0_l00016ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0MOooool005Wooooo0_l00014ooooo`;o0000C_ooool00ol0003oooooooooo`1fooooo`00
Foooool2o`0004;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00GOoo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Mooo
ool005kooooo0_l0000oooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool0
063ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07Sooooo001Qooooo`;o0000??ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wo
oooo001Sooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`1iooooo`00I?ooool2o`0003Wooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1jooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0N_ooool006Oooooo00?o0000ooooooooool0=Oooool2o`0004[ooooo00?o0000oooo
ooooool0N_ooool006Sooooo0_l0000eooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0Noooool006[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo07_ooooo001[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`1kooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0Noooool006gooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00Koooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool0073ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001a
ooooo`03o`000?oooooooooo02_ooooo0_l00018ooooo`03o`000?oooooooooo07cooooo001boooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1loooo
o`00Loooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`1looooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0O?ooool007Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001hooooo`03o`000?oooooooooo00Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1looooo`00NOooool00ol0003oooooooooo`08ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool007[ooooo00?o0000oooo
ooooool01oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001kooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00017
ooooo`03o`000?oooooooooo07cooooo001looooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0O?ooool007kooooo00?o0000ooooooooool00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0Noooool007oooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0Noooool0083ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00P_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool008;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo07_ooooo0023ooooo`03o`00
0?oooooooooo01Wooooo0_l00019ooooo`03o`000?oooooooooo07_ooooo0024ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00QOooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool0
08Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
07_ooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1jooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0N_ooool008Wooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo07[ooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00Roooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool008cooooo00?o0000oooooooo
ool04?ooool2o`0004[ooooo00?o0000ooooooooool0N_ooool008cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo002=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00S_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool0
08oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
07Wooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`1iooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0NOooool009;ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo07Sooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`1hooooo`00Toooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool009Cooooo00?o0000oooooooo
ool02?ooool2o`0004cooooo00?o0000ooooooooool0N?ooool009Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo07Sooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Moooool0
09Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
07Oooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`1gooooo`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0M_ooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooo000000Cooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1fooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Ko
oooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000;ooooo00Co0000oooooooo
oooooooo0ol0001=ooooo`03o`000?oooooooooo07Kooooo0024ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00004ooooo`04o`000?ooooooooooo`0004oooooo00?o
0000ooooooooool0M_ooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0000Gooooo00?o0000ooooool00000D?ooool00ol0003oooooooooo`1eooooo`00Q?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`00053ooooo
00?o0000ooooooooool0MOooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1eooooo`00Q?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo07Gooooo002Oooooo`;o0000Coooool00ol0003ooooooooo
o`1eooooo`00Woooool00ol0003oooooo`00001?ooooo`03o`000?oooooooooo07Cooooo002Ooooo
o`04o`000?ooooooooooo`0004kooooo00?o0000ooooooooool0M?ooool009oooooo00Go0000oooo
ooooooooooooo`00001=ooooo`03o`000?oooooooooo07Cooooo002Oooooo`;o00000_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo07Cooooo002Oooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1dooooo`00Woooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Loooool009oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07?ooooo002O
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1c
ooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0Loooool009oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool0L_ooool009oooooo0_l0000:ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0L_ooool009oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo07;ooooo002Oooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1booooo`00Woooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0LOooool009oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo077ooooo002O
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1a
ooooo`00Woooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0LOooool009oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo077ooooo002Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`1`ooooo`00Woooool2o`00017ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1`ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool0L?ooool009oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo073ooooo002Oooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1_ooooo`00Woooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Koooool009oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06oooooo002O
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1_
ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0K_ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo06kooooo0024ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo06kooooo0024ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Gooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0K_ooool008Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0KOooool008Cooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo06gooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`1]ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0KOooool009oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo06cooooo002Oooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1/ooooo`00Woooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0K?ooool009oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06cooooo002Oooooo`;o00007ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06_ooooo002Oooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1[ooooo`00Woooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Joooool009oo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06_o
oooo002Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`1Zooooo`00Woooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`1Zooooo`00Woooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0JOooool009oooooo0_l0000Wooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0JOooool009oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06Wooooo002Oooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Yooooo`00Woooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0J?ooool009oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo06So
oooo002Oooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Xooooo`00Woooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0J?ooool009oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo06Sooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`1Wooooo`00Woooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Ioooool009oooooo0_l0000_ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0Ioooool009oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06Oooooo002Oooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Wooooo`00Woooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I_ooool009oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Ko
oooo002Oooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1Vooooo`00Woooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0I_ooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo06Kooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Uooooo`00Q?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000=Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo06Gooooo0024ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Gooooo0024ooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Gooooo0024ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Gooooo0024ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Cooooo0024ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Cooooo002Oooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Tooooo`00
Woooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
I?ooool009oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo06Cooooo002Oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Sooooo`00Woooool2o`0003kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Sooooo`00Woooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0Hoooool009oooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo06?ooooo002Oooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Sooooo`00Woooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Hoooool009oooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06?ooooo002Oooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`00
Woooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
H_ooool009oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo06;ooooo002Oooooo`;o0000AOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo06;ooooo002Oooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1Rooooo`00Woooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0H_ooool009oooooo00?o0000ooooooooool0Aoooool2o`0001Sooooo
00?o0000ooooooooool0H_ooool009oooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo06;ooooo002Oooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Rooooo`00Woooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0H_ooool009oooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06;ooooo002Oooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Qooooo`00Wooo
ool2o`0004oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Qooooo`00Woooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0HOooool0
09oooooo00?o0000ooooooooool0D?ooool2o`00013ooooo00?o0000ooooooooool0HOooool009oo
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo067o
oooo002Oooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1Rooooo`00Woooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0H_ooool009oooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo06;ooooo002Eooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool009Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`?o00001Oooool2o`0006Go
oooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool3o`000003oooo
ool0003ooooo06Kooooo002Gooooo`03o`000?oooooooooo00Gooooo0ol0001Mooooo`03o`000?oo
oooooooo06Kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo
0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Eooooo`03oeEEEOmVIVKo00000=3ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool5o`0000Gooooo0_lQ8B44ooooo`Go0000XOooool00:Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4002ooooo`Ko000000KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A40:7ooooo002Tooooo`03o`000?oooooooooo00cooooo00?o
V9RHob4Q8Oo^k^h03Oooool00onHV9So8B4Qonk^kP2Rooooo`00Y?ooool00ol0003oooooooooo`04
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ8B7ok^k^0:7ooooo002Toooo
o`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool03Oooool00omgMgOoIVIVooooo`2Poooo
o`00X_ooool00ol@413o0000o`000003o`0000kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`2Oooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41002oooool01Ol0003o^[ZjoooooonHV9So410@0:7ooooo002Tooooo`03o`000?oooooooooo00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0XOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
4e-05 8e-05 m
.01436 .00014 L
.02871 .00024 L
.04309 .00042 L
.05754 .00072 L
.07209 .00119 L
.08679 .00195 L
.10173 .00312 L
.117 .00489 L
.13274 .00751 L
.14914 .01132 L
.16642 .01672 L
.18486 .0242 L
.20477 .03435 L
.2265 .04778 L
.25042 .06514 L
.27687 .08706 L
.30612 .11404 L
.33838 .14643 L
.37367 .1843 L
.41184 .22736 L
.45252 .27494 L
.49507 .32588 L
.53861 .37862 L
.58206 .43119 L
.62416 .48133 L
.66359 .52665 L
.69906 .56484 L
.72941 .5938 L
.75373 .61188 L
.77143 .61803 L
.7823 .61188 L
.78656 .5938 L
.78478 .56484 L
.77788 .52665 L
.76702 .48133 L
.75349 .43119 L
.73861 .37862 L
.72364 .32588 L
.70967 .27494 L
.69756 .22736 L
.68795 .1843 L
.68123 .14643 L
.67755 .11404 L
.67687 .08706 L
.67899 .06514 L
.68365 .04778 L
.69048 .03435 L
.69914 .0242 L
.70927 .01672 L
Mistroke
.72057 .01132 L
.73274 .00751 L
.74557 .00489 L
.75887 .00312 L
.77251 .00195 L
.78638 .00119 L
.8004 .00072 L
.81452 .00042 L
.82871 .00024 L
.84293 .00014 L
.85719 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool?o`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000003?l0
0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool001gooooo00?o0000
ooooooooool08?ooool7o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
ooooo`Ko00008?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Sooooo0017oooo
o`?o0000EOooool00ol0003oooooooooo`1Gooooo`;o0000KOooool004[ooooo1?l0001Aooooo`03
o`000?oooooooooo05Cooooo0ol0001_ooooo`00C_ooool4o`0004gooooo00?o0000ooooooooool0
D_ooool2o`0007;ooooo001Booooo`;o0000Boooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo07;ooooo001Dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`1cooooo`00EOooool2o`0004Sooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`1dooooo`00Eoooool2o`0004Kooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`1dooooo`00FOooool2o`0004Cooooo0_l0001?ooooo`03o`000?oooooooooo07Gooooo
001Kooooo`;o0000@_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo001M
ooooo`;o0000@?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo001Ooooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1goooo
o`00H?ooool2o`0003gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00
H_ooool2o`0003_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1hooooo`00I?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?oo
ool006Gooooo0_l0000hooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool0
06Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
07Wooooo001Xooooo`03o`000?oooooooooo03Cooooo0_l0001;ooooo`03o`000?oooooooooo07Wo
oooo001Yooooo`;o0000=?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo
001[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1jooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0N_ooool006gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo07[ooooo001^ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`1jooooo`00Koooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool0073ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo001aooooo`;o0000;?ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo001cooooo`03o`000?oooooooooo
02Wooooo0_l0001:ooooo`03o`000?oooooooooo07[ooooo001dooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00MOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool007Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo001g
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1j
ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0N_ooool007Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo07[ooooo001jooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1jooooo`00Noooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0N_ooool007cooooo00?o0000ooooooooool01Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo07[ooooo001mooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00019ooooo`03o`000?oooooooooo
07[ooooo001nooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1joooo
o`00Ooooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool0083o
oooo00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1iooooo`00POoo
ool02?l0003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1iooooo`00P_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool008?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wo
oooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`1iooooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0NOooool008Kooooo00?o0000ooooooooool05_ooool2o`0004_ooooo00?o0000
ooooooooool0NOooool008Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo07Wooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`1hooooo`00ROooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool008[ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo07Sooooo002;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1hooooo`00S?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool008go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo07Oo
oooo002>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1gooooo`00Soooool00ol0003oooooooooo`0=ooooo`;o0000COooool00ol0003ooooooooo
o`1gooooo`00Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0Moooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo07Oooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`1fooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0M_ooool009?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo002Dooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1fooooo`00UOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0MOooool009Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07Go
oooo002Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`1eooooo`00Uoooool00ol0003oooooooooo`05ooooo`;o0000Coooool00ol0003ooooooooo
o`1eooooo`00V?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0MOooool009Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo07Cooooo002Jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`1dooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool0M?ooool009_ooooo00Go0000oooooooooooooooo
o`00001Aooooo`03o`000?oooooooooo07Cooooo002Looooo`04o`000?ooooooooooo`0005;ooooo
00?o0000ooooooooool0Loooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooool00000D_ooool00ol0003ooooo
ooooo`1cooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Cooooo0_l0001Booooo`03o`000?oooooooooo07?ooooo0024ooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Gooooo1?l0001@ooooo`03o`000?oooooooooo07?ooooo
0024ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0Loooool008Cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo0_l0001Booooo`03o`000?oooooooooo
07;ooooo0024ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooo0000057ooooo00?o0000ooooooooool0L_ooool008Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00Co0000oooooooooooo0000D?ooool0
0ol0003oooooooooo`1booooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool01?l0003oooooooooool0001@ooooo`03o`000?oooooooooo07;ooooo002O
ooooo`05o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`1booooo`00Woooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0LOooool0
09oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
077ooooo002Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`1aooooo`00Woooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1aooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0L?ooool009oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo073ooooo002Oooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1`ooooo`00Woooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0Koooool009oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06oooooo002Oooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1_ooooo`00Woooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0K_ooool0
09oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
06kooooo002Oooooo`;o00003Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo06ko
oooo002Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`1]ooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0KOooool009oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo06gooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1/ooooo`00Woooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0K?ooool009oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06cooooo002Oooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1/ooooo`00Woooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Joooool0
09oooooo0_l0000Eooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Joooool009oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo06_o
oooo002Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`1[ooooo`00Woooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`1Zooooo`00Woooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0J_ooool008Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo06Wooooo0024ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Y
ooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`1Yooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00007Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo06Wooooo
0024ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo06So
oooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1Xooooo`00
Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0J?ooool008Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo06Sooooo002Oooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Wooooo`00
Woooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
Ioooool009oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo06Oooooo002Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1Vooooo`00Woooool2o`0002Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1Vooooo`00Woooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0I_ooool009oooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo06Gooooo002Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`1Uooooo`00Woooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0IOooool009oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06Cooooo002Oooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Tooooo`00
Woooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
I?ooool009oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo06?ooooo002Oooooo`;o0000;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo06?ooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`1Sooooo`00Woooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0Hoooool009oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo06;ooooo002Oooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1Rooooo`00Woooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H_ooool009oooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo002Oooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Qooooo`00
Woooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
HOooool009oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo067ooooo002Oooooo`;o0000=Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo063ooooo002Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`1Pooooo`00Woooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0H?ooool009oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo063ooooo002Oooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Oooooo`00Woooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Goooool009oooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05oooooo0024ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1O
ooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0G_ooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0003cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1Nooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Nooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1Nooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Nooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Mooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Mooooo`00Woooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0GOooool009oooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05gooooo002Oooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Mooooo`00Woooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool009oooooo
0_l00016ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0G?ooool009oooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05cooooo002O
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1L
ooooo`00Woooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0G?ooool009oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05_ooooo002Oooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Kooooo`00Woooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0Foooool009oooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05_ooooo002Oooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Kooooo`00Woooool2o`0004go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Kooooo`00Woooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F_ooool009oooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05[ooooo002O
ooooo`03o`000?oooooooooo04oooooo0_l0000Hooooo`03o`000?oooooooooo05[ooooo002Ooooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Joooo
o`00Woooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0F_ooool009oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo05[ooooo002Oooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Jooooo`00Woooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0FOooool009oooooo0_l0001Gooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0FOooool009oooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Wooooo002Oooooo`03o`000?oooooooooo05Sooooo
0_l0000@ooooo`03o`000?oooooooooo05Wooooo002Oooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`00Woooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0FOooool009oooooo00?o0000oooo
ooooool0G?ooool2o`0000cooooo00?o0000ooooooooool0FOooool009oooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05[ooooo002Eooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0F_ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Pooooo`;o00001_ooool2o`0005cooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0H_ooool3o`000003ooooool0003o000005kooooo002Gooooo`03o`000?oooooooooo
00Gooooo0ol0001Uooooo`03o`000?oooooooooo05kooooo002Gooooo`03o`000?oooooooooo0<ko
oooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002E
ooooo`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool0Woooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko0000
00KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q1oooool00ol0003oooooooooo`2Poooo
o`00Y?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00cooooo1Ol0002Qooooo`00
Y?ooool00ol0003oooooooooo`04ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0;ooooo`04odA4
A?oMgMgoooooo`000:;ooooo002Tooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool0
2_ooool01?oMgMgoEEEEooooool0002Rooooo`00X_ooool00ol@413o0000o`000003o`0000kooooo
00?o0000ooooooooool02_ooool00omgMgOoc<c<o`00002Rooooo`00Y?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00oo^k^koA4A4o`00002Rooooo`00Y?oo
ool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03Oooool00omgMgOo0000
ooooo`2Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The bottom of the pulse does not move, because the wave amplitude is zero \
there. (Recall that this pulse is a wave as seen in a frame that moves with \
the linear wave speed. Linear waves would not evolve at all in this moving \
frame.) The peak of the pulse moves the fastest because wave speed increases \
with increasing amplitude.  Eventually",
  ",",
  " the peak overtakes the rest of the pulse. This solution exhibits ",
  StyleBox["wavebreaking",
    FontSlant->"Italic"],
  ": the solution becomes double-valued at around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ". This phenomenon is familiar to anyone who has enjoyed watching waves \
curl and collapse on the beach. Our nonlinear wave equation cannot describe \
the collapse of the wave, which occurs because the wave crest is no longer \
supported by the fluid below it. However, it has captured the essential \
behavior of a breaking wave up to the point where the solution becomes \
double-valued.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wavebreaking Time", "Section",
  CellTags->{"i:16", "c:13"}],

Cell[TextData[{
  "\tThe wavebreaking can also be understood by examining the characteristics \
. One can see from Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  "  or Fig. ",
  ButtonBox["7.4",
    ButtonData:>"Fig. 7.4",
    ButtonStyle->"Hyperlink"],
  " that there are places where the characteristics cross. At such points \
values of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " that were initially separated in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " come to the same position, implying that the solution has become \
double-valued in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAlthough different characteristics cross at different places and times, \
it is evident that there is a  time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " when the crossing of characteristics first occurs. At this instant, the \
",
  StyleBox["wavebreaking time",
    FontSlant->"Italic"],
  ", the solution goes from being a single-valued function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to being double-valued. "
}], "Text"],

Cell[TextData[{
  "\t\tIn order to determine the wavebreaking time, let us consider two \
characteristics that arise from initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(o\ 1\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_\(o\ 2\)\), "=", 
          RowBox[{\(x\_\(o\ 1\)\), "+", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " . These characteristics cross when ",
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_\(o\ 1\)) = x(t, x\_\(o\ 2\))\)]],
  ". Applying Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  "  then yields a crossing time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(\ \)\)\)]],
  " given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_\(o\ 1\)\  + \ \(\(f\_o\)(x\_\(o\ 1\))\)\ t\  = \ 
        x\_\(o\ 2\) + \ \(\(f\_o\)(x\_\(o\ 2\))\)\ t\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Solving for  ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"t", "=", 
        RowBox[{\(-\(\(x\_\(o\ 1\) - x\_\(o\ 2\)\)\/\(f(x\_\(o\ 1\)) - 
                  f(x\_\(o\ 2\))\)\)\), "=", 
          RowBox[{
            FractionBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], 
              RowBox[{\(f(x\_\(o\ 1\))\), "-", 
                RowBox[{"f", "(", 
                  RowBox[{\(x\_\(\(o\)\(\ \)\(1\)\(\ \)\)\), "+", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]]}], ")"}]}]], "."}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(7.1.35)"],

Cell[TextData[{
  "Assuming for the moment that ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is small, we Taylor expand ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{\(x\_\(o\ 1\)\), "+", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}], ")"}], TraditionalForm]]],
  " to first",
  "-order",
  " in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and so obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t = \(-\(1\/\(\[DifferentialD]f\_o/\[DifferentialD]x\
\_\(o\ 1\)\)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.36)"],

Cell[TextData[{
  "To find the wavebreaking time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ", we find the minimum (positive) value for ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t\_o = 
        min\ \((\(-\(1\/\(\[DifferentialD]f\_o/\[DifferentialD]x\_\(o\ \
1\)\)\)\)\ )\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.37)"],

Cell[TextData[{
  "That is, we look for the maximum value of ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ \
1\)\)]],
  ". This maximum will occur at the inflection point in ",
  Cell[BoxData[
      \(TraditionalForm\`f\_o\)]],
  ", where"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ \
1\)\^2 = 0\)]]], "NumberedEquation",
  CellTags->"(7.1.38)"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\^3 > 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.39)"],

Cell[TextData[{
  "For our Gaussian initial condition, there is only one inflection point \
with ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ \
1\) > 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\^2 = 0\)]],
  ". It may be found easily using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " : "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[D[f0[x0], {x0, 2}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.27"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(-x0\^2\)\ \((\(-1\) + 2\ x0\^2)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, the inflection point happens at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(0\ 1\) = \ 1/\@2\)]],
  ". At this point -",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\_o/\[DifferentialD]x\_\(o\ \
1\)\)]],
  " is given by "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(-\(f0'\)[1/Sqrt[2]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.28"],

Cell[BoxData[
    \(\@\(2\/\[ExponentialE]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Therefore, the wavebreaking time for our Gaussian initial condition is ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o = \(\@\(\[ExponentialE]/2\) = 0.858 ... \)\)]],
  ". This agrees with the results of the previous  animation. "
}], "Text"],

Cell[TextData[{
  "\tWe found the wavebreaking time by assuming that nearby characteristics \
were the first to cross, so that a first-order Taylor expansion of Eq. ",
  ButtonBox["(7.1.35)",
    ButtonData:>{"Chapter7.nb", "(7.1.35)"},
    ButtonStyle->"Hyperlink"],
  "  was allowed. We must now show that the minimum wavebreaking time really \
does occur for nearby characteristics. To do so, we keep up to third-order \
terms in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " in Eq. ",
  ButtonBox["(7.1.35)",
    ButtonData:>{"Chapter7.nb", "(7.1.35)"},
    ButtonStyle->"Hyperlink"],
  " , and vary with respect to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ".  Equation(7.1.36) is then replaced by"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"t", "=", 
        RowBox[{"-", 
          RowBox[{
            FractionBox["1", 
              
              RowBox[{\(\[DifferentialD]f\_o/\[DifferentialD]x\_\(o\ 1\)\), 
                "+", " ", 
                RowBox[{
                  FractionBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], 
                    "2"], \(\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ \
1\)\%\(\(\ \)\(2\)\)\)}], "+", 
                RowBox[{
                  FractionBox[
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"], 
                    "6"], \(\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ \
1\)\%\(\(\ \)\(3\)\)\)}]}]], "."}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(7.1.40)"],

Cell[TextData[{
  "However, at the inflection point",
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\%\(\(\ \)\(2\)\) = 0\)]],
  " and this expression becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"t", "=", 
        RowBox[{
          FractionBox["1", 
            
            RowBox[{\(\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ 1\)\),
               "-", 
              RowBox[{
                FractionBox[
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], 
                  "6"], \(\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ \
1\)\%\(\(\ \)\(3\)\)\)}]}]], "."}]}], TraditionalForm]]]], "NumberedEquation",\

  CellTags->"(7.1.41)"],

Cell[TextData[{
  "Since both ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ \
1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\%\(\(\ \)\(3\)\)\)]],
  " are greater than zero, the minimum value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " occurs at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "\[Rule]", "0"}], 
        TraditionalForm]]],
  ", proving that the minimum wavebreaking time happens for closely separated \
characteristics, and is given by Eq. ",
  ButtonBox["(7.1.37)",
    ButtonData:>{"Chapter7.nb", "(7.1.37)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 7.1", "Subsubtitle",
  CellTags->"c:14"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " For the following PDEs,"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " find the characteristics, and plot them for ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\  = \(-1\), 0, \ and\ 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "; "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " solve the PDEs  for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "(i) ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \[ExponentialE]\^\(-x\)\
\ \ \[PartialD]f\/\[PartialD]x = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = \ \[ExponentialE]\^\(-x\^2\)\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) < x < 3\)]],
  "."
}], "Text"],

Cell[TextData[{
  "(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          6 \[PartialD]f\/\[PartialD]x = \(-f\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = sin\ x\)]],
  ". Animate for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "  on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) \[Pi] < x < 2  \[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "(iii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t - 
          x\ \[PartialD]f\/\[PartialD]x = \ log(x\^2)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = 0\)]],
  ". Animate for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(7.1.24)",
    ButtonData:>{"Chapter7.nb", "(7.1.24)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " A radio wave packet with central frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " travels in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(+x\)\)]],
  " direction through a nonuniform plasma. The dispersion relation for the \
waves is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ \[Alpha]\^2\ x\^2\  + \ 
          c\^2\ k\^2\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the speed of light and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is a constant. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using the equations of geometrical optics, Eqs. ",
  ButtonBox["(5.2.48)",
    ButtonData:>{"Chapter5.nb", "(5.2.48)"},
    ButtonStyle->"Hyperlink"],
  " , show that the local wavenumber satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^\(\(2\)\(\ \)\)\) \(\(k\^2\)(
            x)\) = \[Omega]\_o\%2 - \ \[Alpha]\^2\ x\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the characteristics for the energy equation ",
  ButtonBox["(5.2.59)",
    ButtonData:>{"Chapter5.nb", "(5.2.59)"},
    ButtonStyle->"Hyperlink"],
  " . In particular, show that ",
  Cell[BoxData[
      \(TraditionalForm\`x(
          t)\  = \ \(\[Omega]\_o\/\[Alpha]\) \(sin(\ \ \(\(c\ \[Alpha]\)\/\
\[Omega]\_o\) t + a)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is a constant of integration."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the method of characteristics to solve the energy equation. Show that \
for a given initial energy density ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_o\)(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon](x, t)\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon](x, 
          t)\  = \ \(\(\[Epsilon]\_o\)(
            x\_o)\)\ \(cos(
              a)\)/\(cos(\(\(c\ \[Alpha]\)\/\[Omega]\_o\) t + a)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(sin\^\(-1\)\)(\[Alpha]\ x/\[Omega]\_o)\  - \ 
          c\ \[Alpha]\ t/\[Omega]\_o\)]],
  ", and where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(\[Omega]\_\(\(o\)\(\ \)\)\) \(sin(
              a)\)/\[Alpha]\)]],
  " is the initial condition. Animate this result on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 10\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1.5\)]],
  ", assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_o\)(
          x\_o) = \[ExponentialE]\^\(-x\_o\^2\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c = \(\[Alpha] = 1\)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = 10\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  "  The dispersion relation for the waves in a time-dependent inhomogeneous  \
2D system  is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ x\ k\_x\  + \ t\ y\ k\_y\)]],
  ". A wave packet initially has wave action ",
  Cell[BoxData[
      \(TraditionalForm\`N(x, y, 
          t = 0) = \[ExponentialE]\^\(\(-2\) \((x\^2 + y\^2)\)\)\)]],
  ". Solve Eq. ",
  ButtonBox["(5.3.23)",
    ButtonData:>{"Chapter5.nb", "(5.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  for the wave action ",
  Cell[BoxData[
      \(TraditionalForm\`N(x, y, t)\)]],
  " using the method of characteristics. Animate the result using a series of \
",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "commands in the time interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " In the Galerkin method, it is often rather difficult to find basis \
functions that satisfy von Neumann boundary conditions in two- or \
three-dimensional domains. The method of characteristics can be used to \
determine the basis functions in this case. Take, for example, a \
2-dimensional domain with a surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " determined by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y)\  = \ 0\)]],
  ". We wish to find basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  "that satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              "\[CenterDot]", \(\[Del]\(\(v\_\(i\ j\)\)(x, 
                  y)\)\)}], \( | \_S\)}], "=", "0"}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is any normal vector to the surface ; for example, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["n",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[\(\[Del]\(z(x, y)\)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". \t"
}], "Text",
  CellTags->"i:21"],

Cell["\tConsider the following first-order PDE:", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["n",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            "\[CenterDot]", \(\[Del]\(\(v\_\(i\ j\)\)(x, y)\)\)}], 
          "=", \(\(z(x, y)\)\ x\^i\ y\^j\)}], TraditionalForm]]]
}], "NumberedEquation",
  CellTags->"(7.1.42)"],

Cell[TextData[{
  "If we solve this PDE inside the domain, then by construction we will have \
found functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  " that satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              "\[CenterDot]", \(\[Del]\(\(v\_\(i\ j\)\)(x, 
                  y)\)\)}], \( | \_S\)}], "=", "0"}], TraditionalForm]]],
  "because ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y) = 0\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ".  \n\tFor instance, consider the elliptical domain specified by ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y) = x\^2/a\^2 + y\^2/b\^2 - 1\)]],
  ". A normal vector to this domain is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["n",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((1, y\ a\^2/x\ b\^2)\)}], 
        TraditionalForm]]],
  ". Using this normal vector in Eq. ",
  ButtonBox["(7.1.42)",
    ButtonData:>{"Chapter7.nb", "(7.1.42)"},
    ButtonStyle->"Hyperlink"],
  " , and applying the method of characteristics, show that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          RowBox[{\(\(v\_\(i\ j\)\)(x, y)\), "=", 
            RowBox[{\(x\^\(\(\ \)\(i\)\)\), 
              RowBox[{\(y\^j\), "   ", 
                StyleBox["[",
                  FontSize->16], 
                " ", \(\((\(b\^2\) i\  + \ \(a\^2\) 
                          j)\) \((x\^2\/\(\(a\^2\)(2\ b\^2 + \(b\^2\) i\  + \ \
\(a\^2\) j)\) + 
                        y\^2\/\(\(\(b\^2\)(2\ a\^2 + \ \(b\^2\) i\  + \ \
\(a\^2\) j)\)\(\ \)\)\ )\) - 1\), 
                StyleBox["]",
                  FontSize->16]}]}]}],
          "TraditionalForm"], ",", 
        RowBox[{
          FormBox[\(i, j \[GreaterEqual] \ 0\),
            "TraditionalForm"], "."}]}], TraditionalForm]]]], "UNNEQ"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Particles in an ideal gas are confined in a harmonic well of the form ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ m\ \(\[Omega]\_o\^2\) x\^2/2\)]],
  ". Initially, the particles are distributed in phase space according to ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, p, t = 0) = \ 
        N\ \(\[Delta](p)\)/a, \ \(\(|\)\(x\)\(|\)\(\(<\)\(a\)\)\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  " otherwise. Find the phase-mixed equilibrium solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " for this initial condition. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Simulate this problem, for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\ \[Pi]/\[Omega]\_o\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(=\)\(100\)\(\ \)\)\)]],
  "particles. Show from the movie of the particle phase space orbits that \
phase mixing ",
  StyleBox["does not",
    FontSlant->"Italic"],
  " occur, and explain why, in a few words. "
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Find the wavebreaking time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " for the following initial condition in Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " : ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = A\ sin\ k\ x\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`k = \(A = 1\)\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) \[Pi] < x < 2  \[Pi]\)]],
  " for  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\ t\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Find the solution to the following nonlinear first-order partial \
differential equation using the method of characteristics on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < x < \[Infinity]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(f(x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{\(\(f\^2\)(x, t)\), 
              FractionBox[\(\[PartialD]\(f(x, t)\)\), \(\[PartialD]x\),
                MultilineFunction->None]}]}], "=", "0"}], TraditionalForm]]],
  "  [initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = sin(2\ x)\)]],
  "]."
}], "Text"],

Cell[TextData[{
  "Find the time to the formation of a singularity in the solution (the \
wavebreaking time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  "). Make an animation of the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f(x, t)\)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < \[Pi]\)]],
  " and for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2  t\_o\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(9)(a)",
    FontWeight->"Bold"],
  " Find the solution to the following nonlinear PDE using the method of \
characteristics on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < x < \[Infinity]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  StyleBox[" ", "UNNEQ"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(u(x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{\(u(x, t)\), 
              FractionBox[\(\[PartialD]\(u(x, t)\)\), \(\[PartialD]x\),
                MultilineFunction->None]}]}], "=", \(-\ u\)}], 
        TraditionalForm]], "UNNEQ"], "UNNEQ"],
  StyleBox["  [initial condition ", "UNNEQ"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u(x, 0) = a\ \(exp(\(-2\)\ x\^2)\)\)], "UNNEQ"], 
    "UNNEQ"],
  StyleBox["].", "UNNEQ"]
}], "UNNEQ",
  CellTags->"i:22"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " For this initial condition, with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\  = \ 1\)\(,\)\)\)]],
  " find the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  "to the formation of a singularity in the solution."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Make an animation of the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(u(x, t)\)\)\)]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5\)]],
  " and for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2  t\_o\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Find the value of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " below which no singularity forms, because the solution decays away before \
wave breaking can occur.  (Answer: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\)\(=\)\(0.824631 ... \)\(\ \)\)\)]],
  ") "
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Consider the following simple model for the flow of traffic in a freeway. \
 The cars are modelled as a fluid of density ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  ". Cars move to the right with a speed that depends on this density. At low \
densities, the cars move at the speed limit ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". But at higher traffic density, their speed is reduced. In our simple \
model, we assume that the speed depends on density as ",
  Cell[BoxData[
      \(TraditionalForm\`c - f\)]],
  ".  According to the Boltzmann equation, the density will then obey"
}], "Text",
  CellTags->"i:23"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \((c - 
              f)\) \[PartialD]f\/\[PartialD]x = \(\(s\)\(.\)\)\)]]], \
"NumberedEquation",
  CellTags->"(7.1.43)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " is a source of cars (such as an on ramp). "
}], "Text"],

Cell[TextData[{
  "Show that for ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and for any nonuniform initial condition with regions of positive slope \
(i.e., traffic density increasing in the direction of flow)  the slope \
increases until the solution becomes double-valued, after which it is no \
longer valid. These regions of increasing slope propagate along the freeway \
(the phenomenon of sudden traffic slowdowns for no apparent reason, familiar \
to any freeway driver). Illustrate this by means of an animation, taking ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1, s = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = \ 0.2\  + \ 0.5\ \(sin\^2\) x\)]],
  ".  See the exercises in Sec. ",
  ButtonBox["7.2",
    ButtonData:>"c:26",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["Whitham (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "  for other freeway models."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 The KdV equation ", "Subtitle",
  CellTags->{"i:24", "c:15"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["7.2.1 Shallow Water Waves with Dispersion", "Subsubtitle",
  CellTags->"c:16"],

Cell["", "Text"],

Cell["\<\
\tIn the previous discussion of nonlinear shallow water waves, \
dispersion was neglected: the wave speed was independent of wavenumber \
(although it depended on amplitude). In this section we will see that adding \
dispersion has an important effect : it suppresses the wavebreaking.  The \
basic reason is easy to understand: dispersion causes waves to spread, and \
this acts against the steepening effect of the nonlinearity.\
\>", "Text"],

Cell["\<\
\tFor linear water waves without surface tension, we have \
previously seen that the dispersion relation is \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = \@\(g\ k\ \ tanh\ k\ h\)\)]],
  " "
}], "NE2",
  CellTags->"(7.2.1)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is the depth [see Exercise (3), Sec. ",
  ButtonBox["5.1",
    ButtonData:>{"Chapter5.nb", "c:18"},
    ButtonStyle->"Hyperlink"],
  "]. For long wavelengths where ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h << 1\)]],
  ", this returns to the shallow-water result, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = \(\(c\_o\) k\  = \@\(g\ h\)\ k\)\)]],
  ".  When small nonlinearity is added the resulting wave equation is Eq. ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  " . However, if ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h\)]],
  " is not infinitesimally small, then we need to keep dispersion in the \
equation. If we expand ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " in small ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h\)]],
  ", we obtain a correction to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Sqrt[\ g\ k\ Tanh[k\ h]], {k, 0, 3}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.29"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(\@\(g\ h\)\ k\), "-", \(1\/6\ \((h\^2\ \@\(g\ h\))\)\ k\^3\), 
        "+", 
        InterpretationBox[\(O[k]\^4\),
          SeriesData[ k, 0, {}, 1, 4, 1]]}],
      SeriesData[ k, 0, {
        Power[ 
          Times[ g, h], 
          Rational[ 1, 2]], 0, 
        Times[ 
          Rational[ -1, 6], 
          Power[ h, 2], 
          Power[ 
            Times[ g, h], 
            Rational[ 1, 2]]]}, 1, 4, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, the lowest",
  "-order",
  " correction to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](
          k) = \ \(\(c\_o\) \(k(\ 
            1\  - \(1\/6\) \(k\^2\) h\^2)\)\(\ \)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.2)"],

Cell[TextData[{
  "This correction can be added to Eq. ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  "  by appending a term:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z\/\[PartialD]t + \(\(c\_o\)(
              1 + \(3\/2\) z\/h)\) \[PartialD]z\/\[PartialD]x\  + \(1\/6\) 
            c\_o\ \(h\^2\) \[PartialD]\^3 z\/\[PartialD]x\^3\  = 0\)]],
  "."
}], "NE2",
  CellTags->"(7.2.3)"],

Cell["\<\
If we neglect the nonlinear term (assuming small amplitude \
disturbances), and Fourier transform this equation in time and space, we \
obtain\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((\(-\[ImaginaryI]\)\ \[Omega]\  + \ \
\[ImaginaryI]\ c\_o\ k\  + \ \[ImaginaryI]\ \(1\/6\) c\_o\ \(h\^2\) 
                k\^3)\) \(\(z\&~\)(k, \[Omega])\)\)\(=\)\(0\)\(\ \)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "This yields the linear dispersion relation of Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  " . "
}], "Text"],

Cell[TextData[{
  "\tWe can put Eq. ",
  ButtonBox["(7.2.3)",
    ButtonData:>{"Chapter7.nb", "(7.2.3)"},
    ButtonStyle->"Hyperlink"],
  "  into a standard format using the same transformations as we used for Eq. \
",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " : ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_ = x - \(c\_\(\(o\)\(\ \)\)\) t\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\&_, t) = 3\ c\_o\ z/\((2\ h)\)\)]],
  ". The result is the ",
  StyleBox[ButtonBox["Korteweg",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Korteweg.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["-de Vries",
    FontSlant->"Italic"],
  " (",
  StyleBox["KdV) equation",
    FontSlant->"Italic"],
  ":"
}], "Text",
  CellTags->"i:25"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          f \[PartialD]f\/\[PartialD]x + \[Alpha]\ \[PartialD]\^3 f\/\
\[PartialD]x\^3 = 0\)]],
  ", "
}], "NE2",
  CellTags->"(7.2.4)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \ c\_o\ h\^2/6\)]],
  ", and where we have dropped the overbar on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for convenience.  "
}], "Text"],

Cell["\<\
\tBecause the KdV equation is not first-order, we can no longer \
apply the method of characteristics. However, analytic solutions of the \
equation can be found using advanced inverse-scattering methods that are \
beyond the scope of this book. Here, for general initial conditions, we will \
content ourselves with a purely numerical solution to the problem. \
\>", \
"Text"],

Cell[TextData[{
  "\tHowever, there is one type of analytic solution that can be derived with \
relative ease:  steady solutions, where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is time-independent when observed in a comoving frame. These solutions \
will be the subject of the next subsection."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2.2 Steady Solutions: Cnoidal Waves and Solitons", "Subsubtitle",
  CellTags->{"i:26", "c:17"}],

Cell[TextData[{
  "\tThe ",
  "KdV",
  " equation admits steady solutions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x - v\ t)\)]],
  ". In a frame moving with speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ", such solutions are time-independent. These solutions occur because \
nonlinear steepening of the waves is in balance with dispersive broadening, \
allowing an equilibrium as viewed in the moving frame."
}], "Text"],

Cell[TextData[{
  "\tIn order to find the form of these steady solutions, we define the \
variable ",
  Cell[BoxData[
      \(TraditionalForm\`s = x - \ v\ t\)]],
  ". Then we assume ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(s)\)]],
  ",so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]x = \[DifferentialD]f/\
\[DifferentialD]s\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]t = \(-v\) \
\[DifferentialD]f/\[DifferentialD]s\)]],
  ". The ",
  "KdV",
  " equation then becomes the following ODE:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(-v\) \[DifferentialD]f\/\[DifferentialD]s + 
          f \[DifferentialD]f\/\[DifferentialD]s + \[Alpha]\ \[DifferentialD]\
\^3 f\/\[DifferentialD]s\^3 = 0\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Writing ",
  Cell[BoxData[
      \(TraditionalForm\`f\ \[DifferentialD]f/\[DifferentialD]s = \(1\/2\) \(\
\[DifferentialD]\/\[DifferentialD]s\) f\^2\)]],
  " allows us to integrate this third-order ODE once, yielding the following \
second",
  "-order",
  " ODE:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(-v\)\ f + \(1\/2\) 
            f\^2 + \[Alpha]\ \[DifferentialD]\^2 f\/\[DifferentialD]s\^2 = 
        A\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " is a constant of integration. If we now rearrange terms, writing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\ \[DifferentialD]\^2 \
f\/\[DifferentialD]s\^2 = A + v\ f\  - \ \(1\/2\) f\^2\)]],
  ", we can see that this equation is of the same form as Newton's second \
law, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 x\/\[DifferentialD]t\^2 = 
        F(x)\)]],
  ", where the mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " replaces ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", the position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " replaces ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " replaces ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ",  and the force ",
  Cell[BoxData[
      \(TraditionalForm\`F(x)\)]],
  " replaces the ",
  "right-hand",
  " side. Equations of this type have a constant of integration: the energy \
",
  Cell[BoxData[
      \(TraditionalForm\`E\  = \ \(1\/2\) 
            m\ \((\[DifferentialD]x\/\[DifferentialD]t)\)\^2 + \ V(x)\)]],
  ", where the potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`F\  = \ \
\(-\[DifferentialD]V\)/\[DifferentialD]x\)]],
  ". If we now translate back to our variables, we find a constant \"energy\" \
given by"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`E\  = \(\(\(1\/2\) \[Alpha]\ \((\[DifferentialD]f\/\
\[DifferentialD]s)\)\^2\)\(+\)\(\ \)\(V(f)\)\(\ \)\)\)]]], "NE2",
  CellTags->"(7.2.5)"],

Cell[TextData[{
  "where the \"potential\" ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(V(f)\)\(\ \)\)\)]],
  "is"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`V(
          f)\  = \ \(-A\)\ f\  - \ \(1\/2\) v\ f\^2 + \(1\/6\) f\^3\)]]
}], "NE2",
  CellTags->"(7.2.6)"],

Cell[TextData[{
  "This potential is a cubic function of \"position\" ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", and the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as a function of \"time\" ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " can be determined by examining this potential function.The function ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " can have one of two basic forms, as shown in Cell ",
  ButtonBox["7.30",
    ButtonData:>"Cell 7.30",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Graphics`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(V[f_]\  = \ \(-A\)\ f\  - \ 1/2\ v\ f^2\  + \ 1/6\ f^3;\)\), "\n", 
    \(\(Plot[
        Evaluate[{\((V[f] /. {A \[Rule] 1, v \[Rule] 1})\), 
            V[f] /. {A \[Rule] \ \(-1\), v \[Rule] 1}}], {f, \(-6\), 6}, \ 
        PlotStyle \[Rule] {{Red, Dashing[{0.05, 0.03}]}, Blue}, 
        PlotLabel -> "\<V(f)\>", 
        AxesLabel \[Rule] {"\<f\>", "\<\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.30"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.356269 0.0394172 [
[.02381 .34377 -6 -9 ]
[.02381 .34377 6 0 ]
[.18254 .34377 -6 -9 ]
[.18254 .34377 6 0 ]
[.34127 .34377 -6 -9 ]
[.34127 .34377 6 0 ]
[.65873 .34377 -3 -9 ]
[.65873 .34377 3 0 ]
[.81746 .34377 -3 -9 ]
[.81746 .34377 3 0 ]
[.97619 .34377 -3 -9 ]
[.97619 .34377 3 0 ]
[1.025 .35627 0 -6 ]
[1.025 .35627 10 6 ]
[.4875 .04093 -12 -4.5 ]
[.4875 .04093 0 4.5 ]
[.4875 .11977 -12 -4.5 ]
[.4875 .11977 0 4.5 ]
[.4875 .1986 -12 -4.5 ]
[.4875 .1986 0 4.5 ]
[.4875 .27743 -12 -4.5 ]
[.4875 .27743 0 4.5 ]
[.4875 .4351 -6 -4.5 ]
[.4875 .4351 0 4.5 ]
[.4875 .51394 -6 -4.5 ]
[.4875 .51394 0 4.5 ]
[.4875 .59277 -6 -4.5 ]
[.4875 .59277 0 4.5 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .35627 m
.02381 .36252 L
s
[(-6)] .02381 .34377 0 1 Mshowa
.18254 .35627 m
.18254 .36252 L
s
[(-4)] .18254 .34377 0 1 Mshowa
.34127 .35627 m
.34127 .36252 L
s
[(-2)] .34127 .34377 0 1 Mshowa
.65873 .35627 m
.65873 .36252 L
s
[(2)] .65873 .34377 0 1 Mshowa
.81746 .35627 m
.81746 .36252 L
s
[(4)] .81746 .34377 0 1 Mshowa
.97619 .35627 m
.97619 .36252 L
s
[(6)] .97619 .34377 0 1 Mshowa
.125 Mabswid
.06349 .35627 m
.06349 .36002 L
s
.10317 .35627 m
.10317 .36002 L
s
.14286 .35627 m
.14286 .36002 L
s
.22222 .35627 m
.22222 .36002 L
s
.2619 .35627 m
.2619 .36002 L
s
.30159 .35627 m
.30159 .36002 L
s
.38095 .35627 m
.38095 .36002 L
s
.42063 .35627 m
.42063 .36002 L
s
.46032 .35627 m
.46032 .36002 L
s
.53968 .35627 m
.53968 .36002 L
s
.57937 .35627 m
.57937 .36002 L
s
.61905 .35627 m
.61905 .36002 L
s
.69841 .35627 m
.69841 .36002 L
s
.7381 .35627 m
.7381 .36002 L
s
.77778 .35627 m
.77778 .36002 L
s
.85714 .35627 m
.85714 .36002 L
s
.89683 .35627 m
.89683 .36002 L
s
.93651 .35627 m
.93651 .36002 L
s
.25 Mabswid
0 .35627 m
1 .35627 L
s
gsave
1.025 .35627 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04093 m
.50625 .04093 L
s
[(-8)] .4875 .04093 1 0 Mshowa
.5 .11977 m
.50625 .11977 L
s
[(-6)] .4875 .11977 1 0 Mshowa
.5 .1986 m
.50625 .1986 L
s
[(-4)] .4875 .1986 1 0 Mshowa
.5 .27743 m
.50625 .27743 L
s
[(-2)] .4875 .27743 1 0 Mshowa
.5 .4351 m
.50625 .4351 L
s
[(2)] .4875 .4351 1 0 Mshowa
.5 .51394 m
.50625 .51394 L
s
[(4)] .4875 .51394 1 0 Mshowa
.5 .59277 m
.50625 .59277 L
s
[(6)] .4875 .59277 1 0 Mshowa
.125 Mabswid
.5 .06064 m
.50375 .06064 L
s
.5 .08035 m
.50375 .08035 L
s
.5 .10006 m
.50375 .10006 L
s
.5 .13947 m
.50375 .13947 L
s
.5 .15918 m
.50375 .15918 L
s
.5 .17889 m
.50375 .17889 L
s
.5 .21831 m
.50375 .21831 L
s
.5 .23802 m
.50375 .23802 L
s
.5 .25773 m
.50375 .25773 L
s
.5 .29714 m
.50375 .29714 L
s
.5 .31685 m
.50375 .31685 L
s
.5 .33656 m
.50375 .33656 L
s
.5 .37598 m
.50375 .37598 L
s
.5 .39569 m
.50375 .39569 L
s
.5 .41539 m
.50375 .41539 L
s
.5 .45481 m
.50375 .45481 L
s
.5 .47452 m
.50375 .47452 L
s
.5 .49423 m
.50375 .49423 L
s
.5 .53365 m
.50375 .53365 L
s
.5 .55335 m
.50375 .55335 L
s
.5 .57306 m
.50375 .57306 L
s
.5 .02122 m
.50375 .02122 L
s
.5 .00151 m
.50375 .00151 L
s
.5 .61248 m
.50375 .61248 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .03 ] 0 setdash
.22987 0 m
.26171 .11914 L
.28158 .17855 L
.30316 .23256 L
.32216 .27171 L
.34309 .30639 L
.36292 .33171 L
.3739 .3428 L
.38395 .35123 L
.39323 .35763 L
.40336 .36318 L
.40891 .36562 L
.41406 .3675 L
.41936 .36908 L
.42424 .37022 L
.42932 .3711 L
.43199 .37144 L
.43335 .37158 L
.43481 .37171 L
.43609 .3718 L
.43726 .37187 L
.43844 .37192 L
.43955 .37195 L
.44085 .37198 L
.44205 .37198 L
.44336 .37197 L
.44403 .37196 L
.44476 .37194 L
.44594 .3719 L
.44717 .37184 L
.44938 .37169 L
.45176 .37147 L
.45436 .37117 L
.45903 .37046 L
.46337 .36962 L
.47389 .36687 L
.48383 .36343 L
.50241 .35505 L
.54088 .33163 L
.5818 .3019 L
.6212 .27351 L
.65909 .25098 L
.67854 .24265 L
.68945 .23923 L
.69429 .23804 L
.69943 .23701 L
.7021 .23657 L
.70461 .23623 L
.70705 .23595 L
.7093 .23574 L
Mistroke
.71144 .2356 L
.71252 .23554 L
.7137 .23549 L
.71489 .23546 L
.71616 .23544 L
.71736 .23544 L
.71845 .23545 L
.71974 .23549 L
.72039 .23551 L
.72111 .23554 L
.72356 .23569 L
.72494 .2358 L
.72642 .23595 L
.72911 .23628 L
.73437 .23718 L
.73919 .2383 L
.74902 .24149 L
.75815 .24562 L
.76817 .25151 L
.77887 .25943 L
.80025 .28079 L
.82042 .3082 L
.85893 .38259 L
.87885 .4336 L
.89991 .49772 L
Mfstroke
.89991 .49772 m
.93153 .61803 L
s
0 0 1 r
[ ] 0 setdash
.29323 0 m
.30316 .03703 L
.34309 .15052 L
.3815 .23161 L
.40095 .2636 L
.42237 .2927 L
.46172 .33193 L
.48113 .34569 L
.502 .35725 L
.52314 .36625 L
.54323 .37295 L
.58142 .38306 L
.60274 .38852 L
.62207 .39417 L
.64245 .40151 L
.6612 .41007 L
.68044 .42122 L
.70126 .43662 L
.72168 .45577 L
.74075 .47786 L
.77872 .53617 L
s
.77872 .53617 m
.81696 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oD?ooool0
0ooo003oooooooooo`0Booooo`03o`00oooooooooooo047ooooo00?o0000ooooooooool0_?ooool0
053ooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`11ooooo`;o0000_Oooool0053o
oooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo0;co
oooo001Aooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0@?ooool00ol0003ooooo
ooooo`2looooo`00DOooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo043ooooo00?o
0000ooooooooool0_?ooool006Kooooo00?o003oooooooooool0@?ooool00ol0003oooooooooo`2l
ooooo`00I_ooool00ol00?ooooooooooo`10ooooo`03o`000?oooooooooo0;cooooo001Wooooo`03
o`00oooooooooooo03oooooo0_l0002mooooo`00Ioooool00ol00?ooooooooooo`0oooooo`03o`00
0?oooooooooo0;cooooo001Wooooo`03o`00oooooooooooo03oooooo00?o0000ooooooooool0_?oo
ool006Oooooo00?o003oooooooooool0?oooool00ol0003oooooooooo`2looooo`00J?ooool00ol0
0?ooooooooooo`0cooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2l
ooooo`00J?ooool00ol00?ooooooooooo`0cooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2looooo`00J?ooool00ol00?ooooooooooo`0[ooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0_?ooool005Cooooo00?oo`00oooo
ooooool04_ooool00ol00?ooooooooooo`0booooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`000;cooooo001Dooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0<_ooool01Oo<
c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0_?ooool005Cooooo00?oo`00oooo
ooooool04_ooool00ol00?ooooooooooo`0booooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`2looooo`00EOooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo
037ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;cooooo001Eoooo
o`03ool00?oooooooooo01;ooooo00?o003oooooooooool0<Oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0_?ooool005Gooooo00?oo`00ooooooooool04_ooool00ol0
0?ooooooooooo`0looooo`03o`000?oooooooooo0;cooooo001Eooooo`03ool00?oooooooooo01?o
oooo00?o003oooooooooool0>oooool2o`000;gooooo001Fooooo`03ool00?oooooooooo01;ooooo
00?o003oooooooooool0>oooool00ol0003oooooooooo`2looooo`00E_ooool00ooo003ooooooooo
o`0Booooo`03o`00oooooooooooo03_ooooo00?o0000ooooooooool0_?ooool005Kooooo00?oo`00
ooooooooool04oooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo0;cooooo001Foooo
o`03ool00?oooooooooo01?ooooo00?o003oooooooooool0>_ooool00ol0003oooooooooo`2loooo
o`00Eoooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo03[ooooo00?o0000oooooooo
ool0_?ooool005Oooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`0iooooo`;o0000
_Oooool005Oooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`0iooooo`03o`000?oo
oooooooo0;cooooo001Gooooo`03ool00?oooooooooo01?ooooo00?o003oooooooooool0>Oooool0
0ol0003oooooooooo`2looooo`00F?ooool00ooo003oooooooooo`0Cooooo`03o`00oooooooooooo
03Sooooo00?o0000ooooooooool0_?ooool005Sooooo00?oo`00ooooooooool04oooool00ol00?oo
ooooooooo`0hooooo`03o`000?oooooooooo0;cooooo001_ooooo`03o`00oooooooooooo03Oooooo
00?o0000ooooooooool0_?ooool006oooooo00?o003oooooooooool0=oooool00ol0003ooooooooo
o`2looooo`00Koooool00ol00?ooooooooooo`0gooooo`;o0000_Oooool0073ooooo00?o003ooooo
ooooool0=_ooool00ol0003oooooooooo`2looooo`00L?ooool00ol00?ooooooooooo`0fooooo`03
o`000?oooooooooo0;cooooo001`ooooo`03o`00oooooooooooo03Kooooo00?o0000ooooooooool0
_?ooool0077ooooo00?o003oooooooooool0:_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0_?ooool0077ooooo00?o003oooooooooool0:_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0_?ooool005_ooooo00?oo`00ooooooooool04ooo
ool00ol00?ooooooooooo`0Rooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0002looooo`00Foooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo02Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;cooooo001Kooooo`03ool00?oo
oooooooo01Cooooo00?o003oooooooooool0:Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0_?ooool005cooooo00?oo`00ooooooooool04oooool00ol00?oooooooooo
o`0Yooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0_?ooool005cooooo00?oo`00
ooooooooool05?ooool00ol00?ooooooooooo`0Xooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0_?ooool005cooooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`0Yoooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0_?ooool005gooooo00?oo`00oooo
ooooool04oooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo0;cooooo001Mooooo`03
ool00?oooooooooo01Cooooo00?o003oooooooooool0<_ooool2o`000;gooooo001Mooooo`03ool0
0?oooooooooo01Cooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`2looooo`00G_oo
ool00ooo003oooooooooo`0Cooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0_?oo
ool005kooooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`0aooooo`03o`000?oooooo
oooo0;cooooo001Nooooo`03ool00?oooooooooo01Cooooo00?o003oooooooooool0<Oooool00ol0
003oooooooooo`2looooo`00Goooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo033o
oooo00?o0000ooooooooool0_?ooool005oooooo00?oo`00ooooooooool05?ooool00ol00?oooooo
ooooo`0`ooooo`;o0000_Oooool005oooooo00?oo`00ooooooooool05Oooool00ol00?oooooooooo
o`0_ooooo`03o`000?oooooooooo0;cooooo001Pooooo`03ool00?oooooooooo01Cooooo00?o003o
ooooooooool0;oooool00ol0003oooooooooo`2looooo`00H?ooool00ooo003oooooooooo`0Eoooo
o`03o`00oooooooooooo02kooooo00?o0000ooooooooool0_?ooool007Sooooo00?o003ooooooooo
ool0;_ooool00ol0003oooooooooo`2looooo`00NOooool00ol00?ooooooooooo`0]ooooo`03o`00
0?oooooooooo0;cooooo001iooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0_?oo
ool007[ooooo00?o003oooooooooool0;?ooool2o`000;gooooo001jooooo`03o`00oooooooooooo
02cooooo00?o0000ooooooooool0_?ooool007_ooooo00?o003oooooooooool0:oooool00ol0003o
ooooooooo`2looooo`00Noooool00ol00?ooooooooooo`0[ooooo`03o`000?oooooooooo0;cooooo
001looooo`03o`00oooooooooooo027ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo0;cooooo001Sooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool08_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;cooooo001Sooooo`03ool00?oooooooooo
01Kooooo00?o003oooooooooool05oooool6o`0000;ooooo1Ol00006ooooo`?o0000_?ooool006Co
oooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0Nooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool0_?ooool006Cooooo00?oo`00ooooooooool05_ooool00ol00?oo
ooooooooo`0Nooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0_?ooool006Co
oooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`0Nooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0_?ooool006Gooooo00?oo`00ooooooooool05_ooool00ol00?oooooo
ooooo`0Nooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0_?ooool006Gooooo00?o
o`00ooooooooool05oooool00ol00?ooooooooooo`0Nooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0_?ooool006Kooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0W
ooooo`03o`000?oooooooooo0;cooooo001Vooooo`03ool00?oooooooooo01Oooooo00?o003ooooo
ooooool09_ooool2o`000;gooooo001Wooooo`03ool00?oooooooooo01Kooooo00?o003ooooooooo
ool09_ooool00ol0003oooooooooo`2looooo`00Ioooool00ooo003oooooooooo`0Gooooo`03o`00
oooooooooooo02Gooooo00?o0000ooooooooool0_?ooool006Oooooo00?oo`00ooooooooool05ooo
ool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo001Xooooo`03ool00?oooooo
oooo01Oooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`2looooo`00J?ooool00ooo
003oooooooooo`0Gooooo`03o`00oooooooooooo02Cooooo00?o0000ooooooooool0@Oooool6ool0
07Gooooo001Yooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool08oooool2o`000;go
oooo001Zooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool08_ooool00ol0003ooooo
ooooo`0iooooo`;oo`00POooool008Cooooo00?o003oooooooooool08_ooool00ol0003ooooooooo
o`0fooooo`?oo`005_ooool2ool006_ooooo0025ooooo`03o`00oooooooooooo027ooooo00?o0000
ooooooooool0<oooool3ool001_ooooo0ooo001Xooooo`00QOooool00ol00?ooooooooooo`0Qoooo
o`03o`000?oooooooooo033ooooo0ooo000Qooooo`;oo`00I_ooool008Kooooo00?o003ooooooooo
ool08?ooool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo02Cooooo00?oo`00oooooooo
ool0Hoooool008Oooooo00?o003oooooooooool07oooool2o`0002kooooo0_oo000Xooooo`03ool0
0?oooooooooo06;ooooo0027ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool0;?oo
ool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo067ooooo0028ooooo`03o`00oooooooo
oooo01kooooo00?o0000ooooooooool0:oooool00ooo003oooooooooo`0[ooooo`03ool00?oooooo
oooo063ooooo0028ooooo`03o`00oooooooooooo01kooooo00?o0000ooooooooool0F_ooool00ooo
003oooooooooo`1Oooooo`00K_ooool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo01;o
oooo1Ol00006ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0G_ooool006kooooo
00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo05gooooo001^ooooo`03ool0
0?oooooooooo01Wooooo00?o003oooooooooool02Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`2looooo`00Koooool00ooo003oooooooooo`0Iooooo`03o`00oooo
oooooooo01;ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002;ooooo0_oo002Hooooo`00L?ooool0
0ooo003oooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`0Qooooo`03ool00?oooooooooo09Sooooo001`ooooo`03ool00?oooooooooo
01[ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo0_oo002Kooooo`00LOooool00ooo003oooooooooo`0Iooooo`03o`00oooooooooooo00ko
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01kooooo00?oo`00oooo
ooooool0Voooool007;ooooo00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`0=ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Looooo`;oo`00W_ooool007;o
oooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01_o
oooo00?oo`00ooooooooool0W_ooool007?ooooo00?oo`00ooooooooool06_ooool00ol00?oooooo
ooooo`0Fooooo`;o00006_ooool2ool004Oooooo00?oo`00ooooooooool0Eoooool007?ooooo00?o
o`00ooooooooool06oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o
o`00ooooooooool0B?ooool00ooo003oooooooooo`1Fooooo`00M?ooool00ooo003oooooooooo`0K
ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool05_ooool2ool004cooooo00?oo`00
ooooooooool0EOooool007Gooooo00?oo`00ooooooooool06oooool00ol00?ooooooooooo`0Coooo
o`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0COooool00ooo003oooooooooo`1Doooo
o`00MOooool00ooo003oooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o0000oooooooo
ool0I_ooool00ooo003oooooooooo`1Cooooo`00M_ooool00ooo003oooooooooo`0Looooo`03o`00
oooooooooooo017ooooo00?o0000ooooooooool0I_ooool00ooo003oooooooooo`1Cooooo`00U_oo
ool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo06Oooooo00?oo`00ooooooooool0D_oo
ool000kooooo00Gok^k^oc8b<_l0003o410@olc<c00aooooo`;o000000?o410@ooooooooool0;Ooo
ool5o`0001cooooo00?o003oooooooooool03oooool2o`0002oooooo1Ol0000aooooo`;o000000?o
410@ool00?ooool0;Oooool01Oo^k^ko<S8bo`000?l@413oc<c<027ooooo000>ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40<_ooool00ol0003oooooooooo`0^ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@07Oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo02kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00booooo`04o`000?ooooooooooool002gooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0Qooooo`001_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000Wooooo`Ko00000_oo
ool5o`0002Oooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo00?o003oooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`;oo`008?ooool00onHV9So8B4Qonk^kP0`ooooo`Go000000?o
ooooool00?ooool0;?ooool01Ol0003ooooooooooooooooo0000027ooooo000>ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;oooool01?m4A4CogMgMooooool0000booooo`03oiRHV?lQ8B7ok^k^01oo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo027o
oooo00?oV9RHob4Q8Oo^k^h0;oooool01?m4A4CogMgMooooool00003ooooo`03ool00?oooooooooo
02[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Qooooo`003_ooool01Ol0003oEEEEo`000?l@413o
c<c<02oooooo00CogMgMoeEEEOoooooo0000<oooool00omgMgOoIVIVooooo`0Oooooo`03o`00oooo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0Sooooo`03ogMgMomV
IVKooooo02kooooo00CogMgMoeEEEOoooooo00000oooool00ooo003oooooooooo`0Zooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`08Oooool000kooooo00?oEEEEohN7Qoooool0<_ooool00omgMgOoc<c<
o`00000dooooo`03o`000?ooooooo`0001oooooo0_l00?l;ooooo`03o`000?oooooooooo00Wooooo
0_oo000Wooooo`03o`000?oooooooooo02kooooo00?oMgMgolc<c?l000001?ooool00ooo003ooooo
ooooo`0Yooooo`03oeEEEOn7QhOooooo02?ooooo000>ooooo`03omgMgOl@413oV9RH03;ooooo00?o
k^k^odA4A?l00000<?ooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo00?oo`00ooooooooool0
7_ooool00ol00?ooooooooooo`08ooooo`;o00002?ooool2ool002Gooooo00Go0000okZj^_oooooo
V9RHoa0@400`ooooo`03onk^k_m4A4Co000000Cooooo00?oo`00ooooooooool0:Oooool00ooMgMgo
410@oiRHV00Sooooo`003oooool01?o<c<coA4A4o`000?l@410aooooo`03ogMgMol0003ooooo02oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`03ool00?oooooooooo01kooooo0_l00?l8oooo
o`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool01OnHV9So410@o`000?lQ8B7o
c<c<037ooooo00?oMgMgo`000?ooool01?ooool00ooo003oooooooooo`0Yooooo`04olc<c?m4A4Co
0000oa0@427ooooo001oooooo`;oo`008?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo0_oo002fooooo`00POooool00ooo003oooooooooo`0Nooooo`;o003o1Oooool00ol0
003oooooooooo`02ooooo`;oo`00^?ooool008;ooooo00?oo`00ooooooooool07oooool2o`00o`?o
oooo00Go0000ooooooooooooooooool0002Zooooo`03oa0@4?l0003o000000;o000000?o410@oooo
ooooool02?ooool008?ooooo0_oo000Qooooo`04o`00ooooooooooooo`0000;ooooo00?oo`00oooo
ooooool0Zoooool00ol0003oooooooooo`0;ooooo`00QOooool00ooo003oooooooooo`0Oooooo`;o
003o00?o0000ooooooooool0[_ooool00ol0003oooooooooo`0;ooooo`001Ooooon1o`0000;oo`00
8Ol00002o`00oj;o00003Oooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooo003o00;o003o2?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`003Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool2
ool001Oooooo0_oo0005ooooo`03o`000?oooooooooo00;ooooo0_l00?l]ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o
000000?o00002_ooool009oooooo0ooo0007ooooo`03o`000?oooooooooo00Cooooo0ol00?mXoooo
o`03ool00?oooooooooo03cooooo00?o0000ooooooooool02oooool009_ooooo1?oo000:ooooo`03
o`000?oooooooooo00Oooooo0ol00?mUooooo`03ool00?oooooooooo03cooooo00?o410@okZj^_oo
ool02oooool009?ooooo2?oo000>ooooo`03o`000?oooooooooo00[ooooo1?l00?mRooooo`03ool0
0?oooooooooo03_ooooo00Co^[Zjoa0@4?l0003o410@2_ooool00:Wooooo0_l0000?ooooo`Co003o
Goooool00ooo003oooooooooo`18ooooo`00ZOooool00ol0003oooooooooo`0Booooo`Co003oFooo
ool00ooo003oooooooooo`18ooooo`00ZOooool00ol0003oooooooooo`0Fooooo`Co003oF?ooool0
0ooo003oooooooooo`17ooooo`00ZOooool00ol0003oooooooooo`0Jooooo`?o003oEOooool00ooo
003oooooooooo`17ooooo`00ZOooool00ol0003oooooooooo`0Mooooo`Co003oD_ooool00ooo003o
ooooooooo`16ooooo`00ZOooool00ol0003oooooooooo`0Qooooo`?o003oCoooool00ooo003ooooo
ooooo`16ooooo`00ZOooool00ol0003oooooooooo`0Tooooo`?o003oC?ooool00ooo003ooooooooo
o`16ooooo`00ZOooool2o`0002Sooooo0_l00?m;ooooo`03ool00?oooooooooo04Gooooo002Yoooo
o`03o`000?oooooooooo02Wooooo0_l00?m9ooooo`03ool00?oooooooooo04Gooooo002Yooooo`03
o`000?oooooooooo02_ooooo0ol00?m7ooooo`03ool00?oooooooooo04Cooooo002Yooooo`03o`00
0?oooooooooo02kooooo0ol00?m4ooooo`03ool00?oooooooooo04Cooooo002Yooooo`03o`000?oo
oooooooo037ooooo0_l00?m2ooooo`03ool00?oooooooooo04Cooooo002Yooooo`03o`000?oooooo
oooo03?ooooo0_l00?m1ooooo`03ool00?oooooooooo04?ooooo002Yooooo`;o0000=_ooool00ol0
0?ooooooooooo`24ooooo`00ZOooool00ol0003oooooooooo`0fooooo`;o003oQ?ooool00:Wooooo
00?o0000ooooooooool0>?ooool2o`00oh;ooooo002Yooooo`03o`000?oooooooooo03[ooooo00?o
003oooooooooool0Ooooool009kooooo1Ol00006ooooo`03o`000?oooooooooo03_ooooo0_l00?mo
ooooo`00W_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0?Oooool0
0ol00?ooooooooooo`1looooo`00Woooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
03kooooo00?o003oooooooooool0Noooool00:3ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0003oo
oooo00?o003oooooooooool0N_ooool00:7ooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`10ooooo`03o`00oooooooooooo03Kooooo00?oo`00ooooooooool0@?ooool00:;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`03o`00oooooooooooo03Gooooo00?o
o`00ooooooooool0@?ooool009kooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo04;ooooo00?o003oooooooooool0=Oooool00ooo003oooooooooo`0oooooo`00W_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0@oooool00ol00?oooooooooo
o`0dooooo`03ool00?oooooooooo03oooooo002Yooooo`03o`000?oooooooooo04Cooooo00?o003o
ooooooooool0<oooool00ooo003oooooooooo`0oooooo`00ZOooool2o`0004Kooooo00?o003ooooo
ooooool0<oooool00ooo003oooooooooo`0nooooo`00ZOooool00ol0003oooooooooo`15ooooo`03
o`00oooooooooooo03?ooooo00?oo`00ooooooooool0?_ooool00:Wooooo00?o0000ooooooooool0
A_ooool00ol00?ooooooooooo`0booooo`03ool00?oooooooooo03kooooo002Yooooo`03o`000?oo
oooooooo04Oooooo00?o003oooooooooool0<_ooool00ooo003oooooooooo`0mooooo`00ZOooool0
0ol0003oooooooooo`18ooooo`03o`00oooooooooooo037ooooo00?oo`00ooooooooool0?Oooool0
0:Wooooo00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`0aooooo`03ool00?oooooooooo
03gooooo002Yooooo`;o0000B_ooool00ol00?ooooooooooo`0aooooo`03ool00?oooooooooo03co
oooo002Yooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0<?ooool00ooo003ooooo
ooooo`0looooo`00ZOooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo02oooooo00?o
o`00ooooooooool0??ooool00:Wooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0`
ooooo`03ool00?oooooooooo03_ooooo002Yooooo`03o`000?oooooooooo04cooooo00?o003ooooo
ooooool0;oooool00ooo003oooooooooo`0kooooo`00ZOooool00ol0003oooooooooo`1=ooooo`03
o`00oooooooooooo06cooooo002Yooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool0
K?ooool00:Wooooo0_l0001?ooooo`03o`00oooooooooooo06_ooooo002Yooooo`03o`000?oooooo
oooo04oooooo00?o003oooooooooool0;_ooool00ooo003oooooooooo`0iooooo`00ZOooool00ol0
003oooooooooo`1?ooooo`03o`00oooooooooooo02kooooo00?oo`00ooooooooool0>Oooool00:Wo
oooo00?o0000ooooooooool0D?ooool00ol00?ooooooooooo`0]ooooo`03ool00?oooooooooo03Wo
oooo002Pooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`00
oooooooooooo02gooooo00?oo`00ooooooooool0>?ooool00:7ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo02cooooo00?oo`00ooooooooool0>?oo
ool009kooooo1Ol00006ooooo`?o0000D_ooool00ol00?ooooooooooo`0/ooooo`03ool00?oooooo
oooo03Sooooo002Nooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0Doooool0
0ol00?ooooooooooo`0[ooooo`03ool00?oooooooooo03Sooooo002Nooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0E?ooool00ol00?ooooooooooo`0[ooooo`03ool00?oooooo
oooo03Oooooo002Oooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0E?ooool00ol0
0?ooooooooooo`0[ooooo`03ool00?oooooooooo03Oooooo002Oooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0EOooool00ol00?ooooooooooo`0Zooooo`03ool00?oooooooooo03Oo
oooo002Pooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0E_ooool00ol00?oooooo
ooooo`0Yooooo`03ool00?oooooooooo03Oooooo002Yooooo`03o`000?oooooooooo05Kooooo00?o
003oooooooooool0:_ooool00ooo003oooooooooo`0fooooo`00ZOooool2o`0005Sooooo00?o003o
ooooooooool0:Oooool00ooo003oooooooooo`0fooooo`00ZOooool00ol0003oooooooooo`1Hoooo
o`03o`00oooooooooooo02Sooooo00?oo`00ooooooooool0=_ooool00:Wooooo00?o0000oooooooo
ool0F?ooool00ol00?ooooooooooo`0Xooooo`03ool00?oooooooooo03Kooooo002Yooooo`03o`00
0?oooooooooo05Wooooo00?o003oooooooooool0:?ooool00ooo003oooooooooo`0eooooo`00ZOoo
ool00ol0003oooooooooo`1Iooooo`03o`00oooooooooooo02Sooooo00?oo`00ooooooooool0=Ooo
ool00:Wooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`1Oooooo`00ZOooool2o`00
05_ooooo00?o003oooooooooool0Goooool00:Wooooo00?o0000ooooooooool0Foooool00ol00?oo
ooooooooo`1Nooooo`00ZOooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo05kooooo
002Yooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool0G_ooool00:Wooooo00?o0000
ooooooooool0G?ooool00ol00?ooooooooooo`1Mooooo`00ZOooool00ol0003oooooooooo`1Loooo
o`03o`00oooooooooooo05gooooo002Yooooo`03o`000?oooooooooo05gooooo00?o003ooooooooo
ool0G?ooool00:Wooooo0_l0001Nooooo`03o`00oooooooooooo02Kooooo00?oo`00ooooooooool0
<oooool00:Wooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`0Uooooo`03ool00?oo
oooooooo03?ooooo002Yooooo`03o`000?oooooooooo05kooooo00?o003oooooooooool09Oooool0
0ooo003oooooooooo`0cooooo`00ZOooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo
02Gooooo00?oo`00ooooooooool0<_ooool009kooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo05oooooo00?o003oooooooooool09Oooool00ooo003oooooooooo`0boooo
o`00W_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0H?ooool00ol0
0?ooooooooooo`0Tooooo`03ool00?oooooooooo03;ooooo002Nooooo`05o`000?oooooooooooooo
ool000001_ooool3o`00063ooooo00?o003oooooooooool09Oooool00ooo003oooooooooo`0aoooo
o`00W_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0HOooool00ol0
0?ooooooooooo`0Tooooo`03ool00?oooooooooo037ooooo002Nooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo02Cooooo00?oo`00oooo
ooooool0<Oooool009kooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Qooooo`03
o`00oooooooooooo02Cooooo00?oo`00ooooooooool0<Oooool009kooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`1Rooooo`03o`00oooooooooooo02Cooooo00?oo`00ooooooooool0
<?ooool009oooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Rooooo`03o`00
oooooooooooo02Cooooo00?oo`00ooooooooool0<?ooool00:Wooooo00?o0000ooooooooool0Hooo
ool00ol00?ooooooooooo`0Sooooo`03ool00?oooooooooo033ooooo002Yooooo`;o0000I?ooool0
0ol00?ooooooooooo`0Tooooo`03ool00?oooooooooo02oooooo002Yooooo`03o`000?oooooooooo
06Cooooo00?o003oooooooooool08oooool00ooo003oooooooooo`0_ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Y_ooool00omgMgOoIVIVooooo`08ooooo`03ofIVI_mgMgOooooo0;Cooooo002Uooooo`03omgMgOl@
413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd0]?ooool009gooooo0_lb<S86ooooo`03oeEEEOnHV9So
oooo00;ooooo00?o410@o`000?l000000_l000001Ol@413ooooooooooon7QhOoIVIV0;Cooooo002L
ooooo`04omgMgOl@413o410@olc<c0Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03onk^k_l0003ooooo0;?ooooo002Looooo`;oIVIV00?oMgMgofIVI_ooool01?ooool0
0olb<S;oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool0
09cooooo00Co0000omgMgOoMgMgo00001Oooool00olb<S;oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00KoV9RHoc8b<_oooooooooooc8b<_nH
V9P4ooooo`03o`000?o^k^kooooo00Cooooo00?o0000ooooooooool00oooool00oo^k^ko0000oooo
o`2cooooo`00Voooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00?oEEEEogMgMoooool0
0_ooool00ol@413o0000o`000003o`0000;ooooo00?oMgMgoeEEEOooool0/oooool009[ooooo00?o
gMgMo`000?ooool00oooool00ol0003ogMgMooooo`02ooooo`03omgMgOl@413ok^k^00Cooooo00?o
0000ooooooooool00_ooool00oo^k^ko410@omgMg@2dooooo`00V_ooool3o`0000;ooooo0ol00004
ooooo`03ogMgMomVIVKooooo00?ooooo00?o410@okZj^_ooool00_ooool00omVIVKoMgMgooooo`2d
ooooo`00[?ooool01?nj^[[o410@o`000?l@412hooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.51205, -9.0385, \
0.0481209, 0.0968896}}]
}, Open  ]],

Cell[TextData[{
  "Solutions with ",
  Cell[BoxData[
      \(TraditionalForm\`A < \(-v\^2\)/2\)]],
  " (the solid curve) proceed monotonically from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(+\[Infinity]\)\)]],
  ". This can be seen analytically by solving for local extrema:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[\(V'\)[f] \[Equal] 0, f]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.31"],

Cell[BoxData[
    \({{f \[Rule] v - \@\(2\ A + v\^2\)}, {f \[Rule] 
          v + \@\(2\ A + v\^2\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, for ",
  Cell[BoxData[
      \(TraditionalForm\`A < \(-v\^2\)/2\)]],
  " \"particles\" will slide down the potential hill as \"time\" ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(s\)\)\)]],
  " increases, and this implies ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] \ \(-\[Infinity]\)\)]],
  " for large ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". Such unbounded solutions are not of physical interest. On the other \
hand, for ",
  Cell[BoxData[
      \(TraditionalForm\`A > \(-v\^2\)/2\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " is ",
  "no longer",
  " monotonic (the red curve), because there are now two real local extrema, \
a maximum and a minimum. In this regime, \"particles\" can get trapped in the \
potential well, resulting in periodic oscillations of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as a function of \"time\" ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe form of these periodic nonlinear wavetrains depends on the value of \
",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and of the \"energy\" ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ", and may be found by solving Eq. ",
  ButtonBox["(7.2.5)",
    ButtonData:>{"Chapter7.nb", "(7.2.5)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]s\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]s = \@\(\(2\/\
\[Alpha]\) \((E - V(f))\)\)\)]],
  ". "
}], "NE2",
  CellTags->"(7.2.7)"],

Cell["This is an ODE that can be reduced to quadratures:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SuperscriptBox["\[Integral]", 
                StyleBox["f",
                  FontSize->10]],
              
              FontSize->
                9], \(\[DifferentialD]f\&_\/\@\(\(2\/\[Alpha]\) \((E - \
V(f\&_))\)\)\)}], "=", \(s + B\)}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(7.2.8)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " is another constant of integration, which we will set to zero in what \
follows, as it merely corresponds to a change in the origin of ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". The integral involves the square root of a cubic polynomial, which makes \
it rather unpleasant, but it can nevertheless be carried out analytically in \
terms of special functions called ",
  StyleBox["elliptic functions: ",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt[\[Alpha]/2]\ Integrate[1/Sqrt[e\  - \ V[f]], f\ ]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.32"],

Cell[BoxData[
    \(\((\@2\ \@\[Alpha]\ EllipticF[
            ArcSin[\[Sqrt]\((\((\(-f\) + 
                        Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                          3])\)/\((\(-Root[\(-6\)\ e - 6\ A\ #1 - 
                                3\ v\ #1\^2 + #1\^3 &, 2]\) + 
                        Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                          3])\))\)], \((Root[\(-6\)\ e - 6\ A\ #1 - 
                        3\ v\ #1\^2 + #1\^3 &, 2] - 
                  Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                    3])\)/\((Root[\(-6\)\ e - 6\ A\ #1 - 
                        3\ v\ #1\^2 + #1\^3 &, 1] - 
                  Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                    3])\)]\ \((f - 
              Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                3])\)\ \[Sqrt]\((\((f - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      1])\)/\((\(-Root[\(-6\)\ e - 6\ A\ #1 - 
                            3\ v\ #1\^2 + #1\^3 &, 1]\) + 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\))\)\ \[Sqrt]\((\((f - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      2])\)/\((\(-Root[\(-6\)\ e - 6\ A\ #1 - 
                            3\ v\ #1\^2 + #1\^3 &, 2]\) + 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\))\))\)/\((\@\(e + A\ f - f\^3\/6 + \(f\^2\ \
v\)\/2\)\ \[Sqrt]\((\((f - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\)/\((Root[\(-6\)\ e - 6\ A\ #1 - 
                          3\ v\ #1\^2 + #1\^3 &, 2] - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\))\))\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This mess can be simplified somewhat if one notices that the ",
  StyleBox["Root",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions in the above expression are simply placeholders for the roots \
of the cubic polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`E\  - \ V(f)\)]],
  ". That is, if we write"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`E\  - \ 
          V(f) = \(-\(1\/6\)\) \((f - a)\) \((f - b)\) \((f - c)\)\)]],
  " "
}], "NE2",
  CellTags->"(7.2.9)"],

Cell[TextData[{
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`a \[GreaterEqual] \ b \[GreaterEqual] \ c\)]],
  ", then we can substitute for these roots and obtain "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[% /. {Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
              1] \[Rule] c, 
          Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 2] \[Rule] b, 
          Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 3] \[Rule] a, \ 
          e \[Rule] V[f] - \(1\/6\) \((f - a)\) \((f - b)\) \((f - c)\)\ }, \ 
      c < b < a\ ]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.33"],

Cell[BoxData[
    \(\(-\(\((2\ \@3\ \@\(\((a - b)\)\ \((a - f)\)\)\ \@\(\(b - f\)\/\(\(-a\) \
+ b\)\)\ \@\(\(c - f\)\/\(\(-a\) + c\)\)\ \@\[Alpha]\ EllipticF[
              ArcSin[\@\(\(a - f\)\/\(a - b\)\)], \(a - b\)\/\(a - \
c\)])\)/\((\@\(\((a - f)\)\ \((\(-b\) + f)\)\ \((\(-c\) + f)\)\))\)\)\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "The special function ",
  StyleBox["EllipticF[\[Theta],m]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an incomplete elliptic integral of the first kind, referred to as ",
  Cell[BoxData[
      \(TraditionalForm\`F(\[Theta] | m)\)]],
  " in most textbooks. The definition of this function is"
}], "Text",
  CellTags->"i:27"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`F(\[Theta] | 
            m)\  \[Congruent] \ \
\[Integral]\_0\%\[Theta]\[DifferentialD]\[Phi]\/\@\(1 - m\ \ \(sin\^2\) \
\[Phi]\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "\tThe next step is most easily done by hand: the square roots involving ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " all cancel, leaving us with"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(\(-2\)\(\ \)\(\@\(3  \[Alpha]\)\)\(\ \)\)\/\@\(a - c\)\), 
          
          RowBox[{"F", "(", 
            RowBox[{
              RowBox[{"arcsin", 
                StyleBox["[",
                  FontSize->16], \(\@\(\(a - f\)\/\(a - b\)\)\), 
                StyleBox["]",
                  FontSize->16]}], "|", "m"}], ")"}]}], "=", "s"}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(7.2.10)"],

Cell["where", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(a - b\)\/\(a - c\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.11)"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`c \[LessEqual] \ b \[LessEqual] \ a\)]],
  ",",
  " it is worthwhile to note for future reference that ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ m \[LessEqual] \ 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(7.2.10)",
    ButtonData:>{"Chapter7.nb", "(7.2.10)"},
    ButtonStyle->"Hyperlink"],
  "  can be inverted to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`f(s)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(a - f(s)\)\/\(a - b\) = \
\(Sin\^2\)[\(F\^\(-1\)\)(\(\@\(\(a - c\)\/\(12\ \[Alpha]\)\)\) s | \ m)]\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "The ",
  "right-hand",
  " side can, in turn, be expressed as another special function, a ",
  StyleBox["Jacobian elliptic function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`sn(\[Theta] | m)\)]],
  ",  defined by ",
  Cell[BoxData[
      \(TraditionalForm\`sn(\[Theta] | m) \[Congruent] 
        sin\ \(\(F\^\(-1\)\)(\[Theta] | \ m)\)\)]],
  ".  In other words, if ",
  Cell[BoxData[
      \(TraditionalForm\`u = \ F(\[Theta] | m)\)]],
  " then ",
  Cell[BoxData[
      \(TraditionalForm\`sn\ \((u)\)\  \[Congruent] sin\ \[Theta]\)]],
  ". Thus, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(s)\  = \ 
        a\  - \ \((a - 
                b)\)\ \(\(sn\^2\)(\(\@\(\(a - c\)\/\(12\ \[Alpha]\)\)\) s | \ 
                m)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.12)"],

Cell[TextData[{
  "The function sn is a nonlinear version of  the sin function. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " it is referred to as ",
  StyleBox["JacobiSN[\[Theta]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",",
  StyleBox["m]",
    FontWeight->"Bold"],
  ".  There is  second function, cn, which is analogous to the cosine \
function, and is defined by the identity ",
  Cell[BoxData[
      \(TraditionalForm\`sn\^2\  + cn\^2 = 1\)]],
  ". Our periodic solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is often called a ",
  StyleBox["cnoidal wave ",
    FontSlant->"Italic"],
  " (because it is often expressed in terms of cn rather than sn). The \
function sn is plotted in Cell ",
  ButtonBox["7.34",
    ButtonData:>"Cell 7.34",
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1/2\)]],
  "."
}], "Text",
  CellTags->"i:28"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[JacobiSN[\[Theta], 1/2], {\[Theta], \(-10\), 10}, 
        PlotLabel \[Rule] \ "\<sn(\[Theta]|m), m=1/2\>", 
        AxesLabel \[Rule] {"\<\[Theta]\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.34"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.309017 0.294302 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.4875 .01471 -12 -4.5 ]
[.4875 .01471 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .63053 -44.125 0 ]
[.5 .63053 44.125 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-10)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .01471 m
.50625 .01471 L
s
[(-1)] .4875 .01471 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sn) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.000 moveto
(\\310) show
93.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.125 13.000 moveto
(L) show
105.125 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.125 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
123.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.250 13.000 moveto
(\\220) show
141.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
147.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05627 m
.02846 .04548 L
.03279 .03701 L
.03793 .02882 L
.04262 .02307 L
.04498 .02075 L
.04754 .01868 L
.04996 .01712 L
.0522 .01603 L
.05342 .01557 L
.05456 .01523 L
.05582 .01496 L
.05653 .01485 L
.05717 .01478 L
.05846 .01472 L
.0592 .01473 L
.05987 .01477 L
.06112 .01493 L
.06181 .01506 L
.06244 .01521 L
.0637 .01558 L
.06508 .0161 L
.06787 .01755 L
.07046 .01935 L
.07287 .02144 L
.07831 .02764 L
.08414 .03669 L
.09483 .06023 L
.10458 .09022 L
.11449 .12958 L
.12366 .17374 L
.14443 .29408 L
.16468 .41552 L
.1746 .46722 L
.18369 .50743 L
.19237 .5388 L
.20186 .56537 L
.2114 .5845 L
.2166 .59197 L
.22144 .59718 L
.22407 .59932 L
.22649 .60089 L
.22915 .60216 L
.23049 .60262 L
.23125 .60283 L
.23196 .60299 L
.23326 .6032 L
.23444 .6033 L
.23571 .60331 L
.23643 .60326 L
Mistroke
.2371 .60319 L
.23832 .60299 L
.23942 .60272 L
.2407 .60231 L
.2419 .60183 L
.24417 .60066 L
.24656 .59905 L
.25083 .59521 L
.25544 .58964 L
.26049 .58175 L
.27072 .55962 L
.28004 .5317 L
.29079 .4897 L
.30096 .44054 L
.33935 .21327 L
.35916 .11512 L
.36916 .07856 L
.37453 .06265 L
.38018 .04862 L
.38502 .0387 L
.3903 .02995 L
.3951 .0238 L
.39957 .01954 L
.40229 .01761 L
.40363 .01684 L
.40486 .01624 L
.40596 .01579 L
.40717 .01539 L
.40838 .01508 L
.40966 .01485 L
.41038 .01477 L
.41107 .01473 L
.41235 .01473 L
.41307 .01477 L
.41373 .01485 L
.41446 .01496 L
.41523 .01512 L
.41651 .01546 L
.4177 .01588 L
.42044 .01719 L
.42286 .01878 L
.42512 .02061 L
.43025 .02607 L
.43525 .03322 L
.44059 .04295 L
.45028 .06652 L
.45909 .09507 L
.47825 .18123 L
.49904 .30308 L
.5185 .41922 L
Mistroke
.52883 .47233 L
.53993 .51935 L
.55055 .55384 L
.56026 .57678 L
.56493 .5851 L
.57002 .5923 L
.57235 .59496 L
.57483 .59739 L
.57696 .59913 L
.5793 .60068 L
.58191 .60199 L
.58333 .60252 L
.58401 .60273 L
.58466 .60289 L
.58591 .60313 L
.58704 .60327 L
.58826 .60332 L
.58895 .6033 L
.58959 .60326 L
.59023 .6032 L
.59092 .60309 L
.59216 .60283 L
.59364 .60239 L
.59499 .60186 L
.59778 .60038 L
.60072 .59826 L
.60572 .5933 L
.61036 .5871 L
.61546 .57844 L
.6209 .56694 L
.63115 .53848 L
.64226 .49698 L
.66242 .39465 L
.68192 .27613 L
.70336 .15557 L
.71318 .1116 L
.72373 .07412 L
.72884 .05957 L
.73369 .04784 L
.74278 .03096 L
.74783 .02428 L
.7524 .0198 L
.75494 .01793 L
.75627 .01712 L
.75768 .0164 L
.75891 .01587 L
.76026 .0154 L
.76149 .01508 L
.76264 .01488 L
.76379 .01475 L
Mistroke
.76503 .01472 L
.76621 .01477 L
.76729 .01491 L
.76827 .01509 L
.76935 .01537 L
.77153 .01616 L
.7739 .01737 L
.77644 .01909 L
.78104 .02333 L
.78628 .02996 L
.79114 .03793 L
.80217 .06298 L
.81189 .09377 L
.82226 .13607 L
.86383 .37414 L
.87397 .43179 L
.88468 .48479 L
.89461 .52493 L
.90388 .55433 L
.91274 .57544 L
.91772 .5845 L
.92225 .59112 L
.92721 .59667 L
.93001 .59905 L
.9326 .60077 L
.93487 .60191 L
.93615 .60241 L
.93736 .60278 L
.93863 .60306 L
.9398 .60323 L
.94107 .60331 L
.94172 .60332 L
.94242 .60329 L
.94352 .60318 L
.94453 .60301 L
.94564 .60275 L
.94682 .60238 L
.94879 .60156 L
.95097 .60036 L
.95499 .59731 L
.95874 .59345 L
.96314 .58767 L
.96715 .58113 L
.97619 .56177 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00Z_ooool00ol0003oooooooooo`2kooooo`00Z_ooool00ol0003oooooooooo`2kooooo`00
X?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^oooool00:;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`00Uoooool6o`0000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2kooooo`006?ooool6o`0006gooooo1_l0000Aoooo
o`03o`000?oooooooooo00Gooooo0ol0001Aooooo`Ko0000I?ooool001Oooooo0_l00005ooooo`03
o`000?oooooooooo06Wooooo0_l00004ooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo053ooooo0_l00005ooooo`;o0000H_ooool001Gooooo0_l00008ooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool01_ooool2o`0000kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
H?ooool001Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Oooooo`005?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo000Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
05gooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05gooooo000Booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05cooooo
000Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05cooooo000Aooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo0ol0001;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool0017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Foooool0017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0F_ooool0013ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
F_ooool000oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0FOooool002Gooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo000Vooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Hooooo`009_ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0F?ooool002Oooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Sooooo
000Wooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Gooooo`00:?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03?ooool3o`0004Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1G
ooooo`00:?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Eoooool002Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05Kooooo000Yooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Fooooo`00:Oooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0E_ooool002[ooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Kooooo000Zooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`00:_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0EOooool002_ooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Gooooo
000[ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1Eooooo`00:oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02Oooool3o`0004Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1D
ooooo`00:oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0E?ooool002cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Dooooo`00;?ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0Doooool002cooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05?ooooo000/ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Cooooo`00;Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Doooool002gooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05?ooooo
000]ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`08ooooo`?o0000@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05;ooooo000]
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1B
ooooo`00;_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0D_ooool002kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo05;ooooo000^ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Booooo`00;_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0DOooool002kooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo057ooooo000_ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0DOooool002oooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00Co
0000oooooomgMgOo<S8b1Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0DOooool002oooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0:ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0DOooool002oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Booooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oMgMgoc8b<P05ooooo`?o0000@?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo053ooooo000_ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1@ooooo`00<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo053ooooo000`ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0D?ooool0033ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo053ooooo000`ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1@ooooo`00
<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
Coooool0033ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo04oooooo000aooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`1?ooooo`00<Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01?ooool3o`0003kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1?ooooo`00<Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0Coooool0037ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo04kooooo000aooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1>ooooo`00<_ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0C_ooool003;ooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04kooooo000booooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1>ooooo`00
<_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
C_ooool003;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo04gooooo000booooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`1=ooooo`00<oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00_ooool3o`0003cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`1=ooooo`00<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0COooool003?ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0^ooooo`05o`000?ooooooooooooooool00000?_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo04gooooo000cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
;_ooool01Ol0003ooooooooooooooooo000003kooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`1=ooooo`00<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02kooooo
00Go0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0C?ooool003Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0^ooooo`05o`00
0?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04co
oooo000dooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0;_ooool01Ol0003ooooo
oooooooooooo000003gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1<ooooo`00
=?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02oooooo00Go0000oooooooooooo
ooooo`00000mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0C?ooool003Cooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1<ooooo`00=?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo0000?Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo04_ooooo000dooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`03o`0003_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1;ooooo`00=Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo033ooooo00Co0000oooooooooooo0000??ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo04_ooooo000eooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0<?oo
ool01?l0003oooooooooool0000looooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
Boooool003Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0`ooooo`04o`000?oo
ooooooooo`0003cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1;ooooo`00=Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool00000??oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000eooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00000looooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0B_ooool000gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^7?ooool00ol0003oooooooooo`0Wooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool00ol0003oooooooooo`0booooo`03o`000?oooooo000003_ooooo00?o0000oooooooo
ool03Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo00?o0000ooooooooool08_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hLooooo`003oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool00ol0003oooooooooo`0Yooooo`03ogMg
Molb<S;ooooo00kooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00000kooooo`03o`00
0?oooooooooo013ooooo00?oMgMgoc8b<_ooool07oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`001?ooool6o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01gooooo00?o0000oooooooo
ool07Oooool6o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooo000003_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01cooooo000?ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Moooo
o`03o`000?oooooooooo02Wooooo00?oMgMgoc8b<_ooool03_ooool00ol0003oooooooooo`0coooo
o`Co0000>Oooool00ol0003oooooooooo`0@ooooo`03ogMgMolb<S;ooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool0
00oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o0000
ooooooooool09_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00kooooo00?o0000ooooooooool0=?oo
ool2o`0003_ooooo00?o0000ooooooooool03Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<027ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007?ooool000oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Co
oooo0_l0000kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Loooo
o`003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool2o`00
03[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo000=oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooo
oooo02Gooooo1?l0000?ooooo`03o`000?oooooooooo03Cooooo0_l0000jooooo`03o`000?oooooo
oooo00kooooo1?l0000Rooooo`03o`000?oooooooooo027ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo000gooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0=?ooool2o`0003[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`19
ooooo`00=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Wooooo000gooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0>Oooool01_o^k^ko<S8bo`000?l0003oEEEE
onk^kPWooooo000gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool01omE
EEGoMgMgooooooo^k^koQhN7ob4Q8Oo^k^h02?ooool003Sooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?oQhN7ogMgMoooool01oooool0
00Ooooooool00018o`0000_ooooo00?o0000ooooooooool00oooool00olQ8B7oooooooooo`06oooo
o`003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0@ooooo`03ob4Q8Ol0003o000000Co00002?ooool000oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0=_ooool2o`0003Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00onHV9SoQhN7
ooooo`03ooooo`03o`000?oooooooooo00Kooooo000hooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=oooool2o`0003Sooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0iooooo`06oc8b<_n7QhOok^k^oooooon7QhOo<S8b2?ooool003Sooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0gooooo`;o0000=oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo03Wooooo00Kok^k^ogMgMol0003o0000oc8b<_o<c<`8ooooo`00>?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo03Oooooo0_l0000gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0Aoooool003Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0gooooo`;o0000=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04Oooooo
000iooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=oooool2o`0003Oooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`17ooooo`00>Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000=_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo04Kooooo000iooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=oooool3o`0003Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`16oooo
o`00>Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool0
0000=Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo04Kooooo000iooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`00000eooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0A_ooool003[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooo000003Gooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`16ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooool00000=Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo04Kooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooo`00000eooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0AOooool003[o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`00
03?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`15ooooo`00>_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo03Wooooo00Co0000oooooooooooo0000<oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo04Gooooo000jooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0>Oooool01?l0003oooooooooool0000cooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0AOooool003[ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0iooooo`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`15ooooo`00>oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Wo
oooo1?l0000cooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0A?ooool003_ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`0003?o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`14ooooo`00>oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000aooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0A?ooool003_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo04Cooooo000kooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`14ooooo`00>oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo03[ooooo00Go0000ooooooooooooooooo`00000aooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0A?ooool003cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0jooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo04?ooooo000looooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
>_ooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`13ooooo`00??ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0@oooool003cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0kooooo`?o00000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0@oooool003cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo04?ooooo000looooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`13ooooo`00??ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0@_ooool003gooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo000mooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`12ooooo`00?Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool0
03gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
04;ooooo000mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`12ooooo`00?Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0@_ooool003kooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0looooo`?o00000oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0@Oooool003kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo047ooooo000nooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`11ooooo`00?_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0@Oooool003kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo047ooooo000oooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`00?oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0@?ooool0
03oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Rooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo043ooooo000oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0@?ooool003oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0S
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo03oooooo000oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03oooooo0010
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03oooooo
0010ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0oooooo`00@?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0?oooool0043ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0?_ooool0043ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03kooooo0011ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0nooooo`00@Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0?_ooool0047o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03go
oooo0011ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@?ooool3o`0000Sooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03gooooo
0012ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0mooooo`00@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0?Oooool004;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo03cooooo0012ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`0looooo`00@_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0??ooool004?ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03cooooo0013ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0kooooo`00@oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0>oooool004?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo03_o
oooo0014ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool3o`0000[ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03_ooooo
0014ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0kooooo`00A?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool0>_ooool004Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo03[ooooo0015ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`0jooooo`00AOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0>_ooool004Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03Wooooo0016ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0iooooo`00A_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0>Oooool004Ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`?o00003Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0>?ooool004Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03Sooooo
0017ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0hooooo`00Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool0=oooool004Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo03Oooooo0018ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`0gooooo`00B?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`00BOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Oooooo`00BOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Pooooo`00B_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Pooooo`00B_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Wo
oooo0ol0000@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo
001;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02;ooooo001<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo001<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02?ooooo001=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo001>ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0I?ooool2o`0000[ooooo00?o0000ooooooooool0
9Oooool004oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`14ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo001@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo0_l00006ooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool01?ooool2o`0002Sooooo001Aooooo`?o000000Coooooo`000?l0003o0000B_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo0ol000001?oooooo0000o`000?l0
001/ooooo`?o00000_ooool2o`0002[ooooo001Cooooo`?o0000C?ooool00ol0003oooooooooo`05
ooooo`?o00006Oooool3o`00073ooooo0ol0000/ooooo`00X_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;_ooooo002Rooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0^oooool00:;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`00X?oo
ool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;_ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002:oooo
o`03ogMgMomVIVKooooo00_ooooo00?o0000ooooooooool02Oooool00omVIVKoMgMgooooo`05oooo
o`03o`000?nj^[[ooooo0;Wooooo0029ooooo`03omgMgOl@413ok^k^00cooooo00?o0000oooooooo
ool02Oooool00oo^k^ko410@omgMg@05ooooo`;o<S8b9?ooool00olQ8B7ogMgMooooo`2Cooooo`00
Moooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Co410@o`000?l0003ooooo0_l00000
1_l@413oooooooooooooooooEEEEoiRHV0;ooooo00Kok^k^oc8b<_l0003o0000oeEEEOo^k^h5oooo
o`03o`000?oooooooooo00;o00000_ooool02?l0003oooooooooool0003o410@oooooon7QhOoIVIV
1Oooool00on7QhOo0000okZj^P0:ooooo`;o00000_ooool01Ol0003oooooooooool0003o410@00Wo
oooo1?l000001Ol@413ooooooooooonHV9SoEEEE00Gooooo1Ol0002:ooooo`00Moooool01_l0003o
ZJVYoooooooooooo^[Zjo`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`0;o`000?oo
oooooooooooooomEEEGoMgMgooooooo^k^koQhN7ob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool00oo^k^ko0000ooooo`04ooooo`03olc<
c?l0003o410@00_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003ogMgMooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@0R_ooool007Sooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4003ooooo`05o`000?oooooooooo
ooooool000001?ooool01Olb<S;ooooooooooooooooo000000Cooooo00?oQhN7ogMgMoooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`;oMgMg1Oooool00onHV9So8B4Qonk^kP2;ooooo`00Moooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000004ooooo`05oc8b<_oo
ooooooooooooool000001Oooool00olQ8B7oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo017ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000005o`0000Gooooo00?o0000ooooooooool00oooool0
0oo^k^ko410@onk^kP05ooooo`03oiRHV?lQ8B7ok^k^08[ooooo001gooooo`06o`000?nj^[[ooooo
onk^k_mgMgOo00000oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00Go0000onk^k_oooooo
ooooob4Q8@06o`0000Cooooo00Go0000ooooooooooooooooo`000002olc<c004o`000?nYZJWogMgM
ob4Q8@;ooooo00?ok^k^o`000?ooool04_ooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B40
3?ooool00ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00Gooooo00?oMgMgofIVI_ooool0
ROooool007Oooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool00_ooool01_mEEEGoMgMgooooooooooooV9RHohN7Q`Cooooo00?o0000
ooooooooool00_ooool02ol0003oooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY
00;ooooo00?oMgMgoeEEEOooool04Oooool02?l@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY
3?ooool00ol0003oooooooooo`04ooooo`03omgMgOl@413ooooo00Kooooo00?o0000ooooooooool0
R?ooool008Wooooo00?ogMgMoa0@4?o^k^h00_ooool01_lb<S;oQhN7onk^k_ooooooQhN7oc8b<PCo
oooo00?o0000ooooooooool02Oooool00oo^k^ko410@omgMg@0Vooooo`03o`000?oooooooooo00Go
oooo00WoEEEEoiRHV?ooooooooooo`000?nj^[[ooooooiRHV?l@4100R_ooool008[ooooo00KoMgMg
ofIVI_ooooooooooonk^k_mgMgL2o`000003oc8b<_o<c<cooooo00?ooooo00?o0000ooooooooool0
2Oooool00omVIVKoMgMgooooo`0Tooooo`03oeEEEOmVIVKo000000Oooooo00Wo^[ZjodA4A?oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`0R_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-11.0106, -1.05866, \
0.0805251, 0.0130292}}]
}, Open  ]],

Cell[TextData[{
  "\tSince the sn function, like the sine function, is zero at the origin and \
runs from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ", we see from Eq. ",
  ButtonBox["(7.2.12)",
    ButtonData:>{"Chapter7.nb", "(7.2.12)"},
    ButtonStyle->"Hyperlink"],
  "  that the maximum and minimum of the wave is ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " respectively. This makes sense, since these are the turning points in the \
motion of the \"particle\" in the \"potential well\" ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tHowever, unlike the sine function, the period ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\)]],
  " of the sn function is not fixed, but rather varies, depending on ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". As ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " increases away from zero, the period ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\)]],
  " of the sn function increases. In fact, one can show that"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\  = 4\ \(K(m)\)\)]],
  ", "
}], "NE2",
  CellTags->"(7.2.13)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`K(m)\)]],
  " is another special function, the complete elliptic function of the  first \
kind (called ",
  StyleBox["EllipticK[m]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "). This function is related to ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`K(m)\  = \ F(\[Pi]/2 | m)\)]],
  ".   The period of sn is plotted in Cell ",
  ButtonBox["7.35",
    ButtonData:>"Cell 7.35",
    ButtonStyle->"Hyperlink"],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < m < 1\)]],
  "."
}], "Text",
  CellTags->"i:29"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[4\ EllipticK[m], {m, 0, 1}, 
        PlotLabel -> "\<Period of sn(\[Theta]|m)\>", 
        AxesLabel \[Rule] {"\<m\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.35"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.167589 0.0290146 [
[.21429 .08104 -9 -9 ]
[.21429 .08104 9 0 ]
[.40476 .08104 -9 -9 ]
[.40476 .08104 9 0 ]
[.59524 .08104 -9 -9 ]
[.59524 .08104 9 0 ]
[.78571 .08104 -9 -9 ]
[.78571 .08104 9 0 ]
[.97619 .08104 -3 -9 ]
[.97619 .08104 3 0 ]
[1.025 .09354 0 -6 ]
[1.025 .09354 10.125 6 ]
[.01131 .12256 -12 -4.5 ]
[.01131 .12256 0 4.5 ]
[.01131 .26763 -12 -4.5 ]
[.01131 .26763 0 4.5 ]
[.01131 .4127 -12 -4.5 ]
[.01131 .4127 0 4.5 ]
[.01131 .55778 -12 -4.5 ]
[.01131 .55778 0 4.5 ]
[.5 .63053 -53.0625 0 ]
[.5 .63053 53.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .09354 m
.21429 .09979 L
s
[(0.2)] .21429 .08104 0 1 Mshowa
.40476 .09354 m
.40476 .09979 L
s
[(0.4)] .40476 .08104 0 1 Mshowa
.59524 .09354 m
.59524 .09979 L
s
[(0.6)] .59524 .08104 0 1 Mshowa
.78571 .09354 m
.78571 .09979 L
s
[(0.8)] .78571 .08104 0 1 Mshowa
.97619 .09354 m
.97619 .09979 L
s
[(1)] .97619 .08104 0 1 Mshowa
.125 Mabswid
.07143 .09354 m
.07143 .09729 L
s
.11905 .09354 m
.11905 .09729 L
s
.16667 .09354 m
.16667 .09729 L
s
.2619 .09354 m
.2619 .09729 L
s
.30952 .09354 m
.30952 .09729 L
s
.35714 .09354 m
.35714 .09729 L
s
.45238 .09354 m
.45238 .09729 L
s
.5 .09354 m
.5 .09729 L
s
.54762 .09354 m
.54762 .09729 L
s
.64286 .09354 m
.64286 .09729 L
s
.69048 .09354 m
.69048 .09729 L
s
.7381 .09354 m
.7381 .09729 L
s
.83333 .09354 m
.83333 .09729 L
s
.88095 .09354 m
.88095 .09729 L
s
.92857 .09354 m
.92857 .09729 L
s
.25 Mabswid
0 .09354 m
1 .09354 L
s
gsave
1.025 .09354 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12256 m
.03006 .12256 L
s
[(10)] .01131 .12256 1 0 Mshowa
.02381 .26763 m
.03006 .26763 L
s
[(15)] .01131 .26763 1 0 Mshowa
.02381 .4127 m
.03006 .4127 L
s
[(20)] .01131 .4127 1 0 Mshowa
.02381 .55778 m
.03006 .55778 L
s
[(25)] .01131 .55778 1 0 Mshowa
.125 Mabswid
.02381 .15157 m
.02756 .15157 L
s
.02381 .18059 m
.02756 .18059 L
s
.02381 .2096 m
.02756 .2096 L
s
.02381 .23862 m
.02756 .23862 L
s
.02381 .29664 m
.02756 .29664 L
s
.02381 .32566 m
.02756 .32566 L
s
.02381 .35467 m
.02756 .35467 L
s
.02381 .38369 m
.02756 .38369 L
s
.02381 .44172 m
.02756 .44172 L
s
.02381 .47073 m
.02756 .47073 L
s
.02381 .49975 m
.02756 .49975 L
s
.02381 .52876 m
.02756 .52876 L
s
.02381 .06453 m
.02756 .06453 L
s
.02381 .03551 m
.02756 .03551 L
s
.02381 .0065 m
.02756 .0065 L
s
.02381 .58679 m
.02756 .58679 L
s
.02381 .6158 m
.02756 .6158 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -114.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Period) show
105.000 13.000 moveto
(of) show
123.000 13.000 moveto
(sn) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 13.000 moveto
(H) show
141.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.000 13.000 moveto
(\\310) show
153.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
159.125 13.000 moveto
(L) show
165.125 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01661 L
.10458 .01878 L
.14415 .02092 L
.18221 .0231 L
.22272 .02555 L
.26171 .02804 L
.30316 .03087 L
.34309 .03378 L
.3815 .03678 L
.42237 .04022 L
.46172 .0438 L
.49955 .04755 L
.53984 .0519 L
.57861 .05654 L
.61984 .06203 L
.65954 .06802 L
.69774 .0746 L
.73838 .08276 L
.77751 .09216 L
.81909 .1046 L
.83996 .11223 L
.85916 .12042 L
.8791 .13057 L
.89771 .14223 L
.91654 .15739 L
.92651 .16758 L
.9372 .18115 L
.94679 .19706 L
.95221 .20859 L
.95722 .22192 L
.96159 .23687 L
.96642 .25985 L
.96884 .27624 L
.97021 .28806 L
.97146 .30157 L
.97256 .31685 L
.97376 .34013 L
.97502 .38237 L
s
.97502 .38237 m
.97548 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o4oooool0
0ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?o
oooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o
0000ooooooooool0oooooomCooooo`004oooool7o`000?ooooooCoooool001?ooooo00?o0000oooo
ooooool01?oooolKo`000?oooooo=?ooool001?ooooo00?o0000ooooooooool07oooool<o`000?oo
oooo:?ooool001?ooooo00?o0000ooooooooool0:oooool=o`000?oooooo6oooool001?ooooo00?o
0000ooooooooool0>?oooolJo`000?oooooo0Oooool001?ooooo00?o0000ooooooooool0D_ooool>
o`000?;ooooo000Cooooo`03o`000?oooooooooo063ooooo3Ol0003Uooooo`004oooool2o`0006ko
oooo3Ol0003Hooooo`004oooool00ol0003oooooooooo`1jooooo`Wo0000coooool001?ooooo00?o
0000ooooooooool0Poooool7o`000<Sooooo000Cooooo`03o`000?oooooooooo08[ooooo2Ol0002o
ooooo`004oooool00ol0003oooooooooo`2Cooooo`go0000/_ooool001?ooooo00?o0000oooooooo
ool0X?ooool9o`000:Wooooo000Cooooo`03o`000?oooooooooo033ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Cooooo1ol000000oo^k^koooooooooo`03oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<03;ooooo1?l000000ol@413ooooo
ooooo`0Iooooo`004oooool00ol0003oooooooooo`0`ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:?ooool01?mgMgOoV9RHoooooonHV9P6
o`0000;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Cooooo00?o0000oooooooo
ool06oooool001?ooooo00?o0000ooooooooool0<?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h0:_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Yoooo
o`05oa0@4?ooooooooooooooool@41001Oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000dooooo`03o`00
0?oooooooooo01_ooooo000Cooooo`;o0000<Oooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h0:Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo0000:_ooool01Ol0003ooooooooooooooooo000000_ooooo2ol0000Tooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03Cooooo00?o0000ooooooooool0
6oooool001?ooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000:_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`So00007?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c00dooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo033ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Oooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000002[ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo013ooooo1Ol0000Gooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@03Cooooo00?o0000ooooooooool06oooool001?ooooo00?o
0000ooooooooool0<?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@400Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Zoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Eooooo`Co00004oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000dooooo`03o`00
0?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo033ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool0:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@5oooool5o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0<_ooool00omEEEGoIVIVo`00000Mooooo`004oooool00ol0003ooooo
ooooo`3Mooooo`Oo0000K_ooool001?ooooo00?o0000ooooooooool0i?ooool5o`0006Wooooo000C
ooooo`03o`000?oooooooooo0>Wooooo1Ol0001Hooooo`;o00000_ooool01Ol0003oooooooooool0
003o410@00?ooooo000Cooooo`03o`000?oooooooooo0>kooooo1?l0001Eooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool001?ooooo00?o0000ooooooooool0l_ooool4
o`00057ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`002ooooooo
o`0004Wo00002_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo000C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?l00008ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo013ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q00Cooooo000Cooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool01?ooool3o`0003Cooooo00?o0000ooooooooool03ooo
ool02?l@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY1?ooool001?ooooo00?o0000oooooooo
ool0ooooool1ooooo`?o0000Coooool001?ooooo00?o0000ooooooooool0ooooool4ooooo`;o0000
COooool001?ooooo00?o0000ooooooooool0ooooool6ooooo`;o0000Boooool001?ooooo00?o0000
ooooooooool0ooooool8ooooo`;o0000BOooool00003ooooool0003o000000;o000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0ooooool:ooooo`?o0000
A_ooool000?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0ooooool=ooooo`;o0000A?ooool000?ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003oooooo`oooooo0_l00012ooooo`000ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3ooooooa7ooooo0_l00010ooooo`000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooa?ooooo0_l0000nooooo`000ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`3ooooooaGooooo0_l0000looooo`000oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0
>Oooool00004oooooomEEEGoIVIVo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo0?oooooo6?ooool2o`0003Wooooo000Cooooo`03o`000?oooooooooo0?oooooo
6_ooool00ol0003oooooooooo`0fooooo`004oooool00ol0003oooooooooo`3ooooooa_ooooo0_l0
000fooooo`004oooool00ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0<oooool0
01?ooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo03;ooooo000Cooooo`;o
0000oooooolPooooo`03o`000?oooooooooo037ooooo000Cooooo`03o`000?oooooooooo0?oooooo
8?ooool00ol0003oooooooooo`0`ooooo`004oooool00ol0003oooooooooo`3oooooob7ooooo0_l0
000`ooooo`004oooool00ol0003oooooooooo`3oooooob?ooooo00?o0000ooooooooool0;Oooool0
01?ooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo02cooooo000Cooooo`03
o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0[ooooo`004oooool00ol0003ooooo
ooooo`3oooooobGooooo00?o0000ooooooooool0:oooool001?ooooo00?o0000ooooooooool0oooo
oolVooooo`03o`000?oooooooooo02[ooooo000Cooooo`03o`000?oooooooooo0?oooooo9oooool0
0ol0003oooooooooo`0Yooooo`004oooool2o`000?oooooo:Oooool00ol0003oooooooooo`0Xoooo
o`004oooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool0:?ooool001?ooooo
00?o0000ooooooooool0oooooolYooooo`03o`000?oooooooooo02Oooooo000Cooooo`03o`000?oo
oooooooo0?oooooo:Oooool00ol0003oooooooooo`0Wooooo`004oooool00ol0003oooooooooo`3o
ooooob[ooooo00?o0000ooooooooool09_ooool001?ooooo00?o0000ooooooooool0oooooolZoooo
o`03o`000?oooooooooo02Kooooo000Cooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003o
ooooooooo`0Uooooo`004oooool00ol0003oooooooooo`3oooooob_ooooo00?o0000ooooooooool0
9Oooool001?ooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo02Cooooo000C
ooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Sooooo`004oooool2o`00
0?oooooo;_ooool00ol0003oooooooooo`0Sooooo`004oooool00ol0003oooooooooo`3oooooobko
oooo00?o0000ooooooooool08_ooool001?ooooo00?o0000ooooooooool0ooooool^ooooo`03o`00
0?oooooooooo02;ooooo000Cooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003ooooooooo
o`0Rooooo`004oooool00ol0003oooooooooo`3ooooooboooooo00?o0000ooooooooool08Oooool0
01?ooooo00?o0000ooooooooool0ooooool_ooooo`03o`000?oooooooooo027ooooo000Cooooo`03
o`000?oooooooooo0?oooooo;oooool00ol0003oooooooooo`0Qooooo`004oooool00ol0003ooooo
ooooo`3ooooooc3ooooo00?o0000ooooooooool08?ooool001?ooooo00?o0000ooooooooool0oooo
ool`ooooo`03o`000?oooooooooo023ooooo000Cooooo`;o0000oooooolaooooo`03o`000?oooooo
oooo023ooooo000Cooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Poooo
o`004oooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool08?ooool001?ooooo
00?o0000ooooooooool0oooooolaooooo`03o`000?oooooooooo01oooooo000Cooooo`03o`000?oo
oooooooo0?oooooo<Oooool00ol0003oooooooooo`0Oooooo`004oooool00ol0003oooooooooo`3o
oooooc7ooooo00?o0000ooooooooool07oooool001?ooooo00?o0000ooooooooool0oooooolboooo
o`03o`000?oooooooooo01kooooo00000ooooooo0000o`000002o`000005oa0@4?oooooooooooooo
oom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0
003oooooooooo`0Nooooo`000oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo01kooooo0003ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooc;ooooo
00?o0000ooooooooool07_ooool000?ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`?o0000oooooolbooooo`03o`000?oooooooooo01kooooo0003ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo<_oo
ool00ol0003oooooooooo`0Nooooo`000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo01kooooo0003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
oc;ooooo00?o0000ooooooooool07_ooool00004oooooomEEEGoIVIVo`0000Gooooo1?l00006oooo
o`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`0Nooooo`004oooool00ol0003o
ooooooooo`3ooooooc?ooooo00?o0000ooooooooool07Oooool001?ooooo00?o0000ooooooooool0
oooooolcooooo`03o`000?oooooooooo01gooooo000Cooooo`03o`000?oooooooooo0?oooooo<ooo
ool00ol0003oooooooooo`0Mooooo`004oooool00ol0003oooooooooo`3ooooooc?ooooo00?o0000
ooooooooool07Oooool001?ooooo0_l0003oooooocCooooo00?o0000ooooooooool07Oooool001?o
oooo00?o0000ooooooooool0oooooolcooooo`03o`000?oooooooooo01gooooo000Cooooo`03o`00
0?oooooooooo0?oooooo<oooool00ol0003oooooooooo`0Mooooo`004oooool00ol0003ooooooooo
o`3ooooooc?ooooo00?o0000ooooooooool07Oooool001?ooooo00?o0000ooooooooool0oooooolc
ooooo`03o`000?oooooooooo01gooooo000Cooooo`03o`000?oooooooooo0?oooooo=?ooool00ol0
003oooooooooo`0Looooo`004oooool00ol0003oooooooooo`3oooooocCooooo00?o0000oooooooo
ool07?ooool001?ooooo00?o0000ooooooooool0ooooooldooooo`03o`000?oooooooooo01cooooo
000Cooooo`03o`000?oooooooooo0?oooooo=?ooool00ol0003oooooooooo`0Looooo`004oooool0
0ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool07?ooool001?ooooo0_l0003ooooo
ocGooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0ooooooldooooo`03
o`000?oooooooooo01cooooo000Cooooo`03o`000?oooooooooo0?oooooo=?ooool00ol0003ooooo
ooooo`0Looooo`004oooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool07?oo
ool001?ooooo00?o0000ooooooooool0ooooooldooooo`03o`000?oooooooooo01cooooo000Coooo
o`03o`000?oooooooooo0?oooooo=?ooool00ol0003oooooooooo`0Looooo`004oooool00ol0003o
ooooooooo`3oooooocCooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0
ooooooldooooo`03o`000?oooooooooo01cooooo000Cooooo`03o`000?oooooooooo0?oooooo=?oo
ool00ol0003oooooooooo`0Looooo`004oooool2o`000?oooooo=Oooool00ol0003oooooooooo`0L
ooooo`004oooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool07?ooool001?o
oooo00?o0000ooooooooool0ooooooldooooo`03o`000?oooooooooo01cooooo000Cooooo`03o`00
0?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003ooooooooo
o`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0oooooole
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0
003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000oooooooo
ool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo
000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool2
o`000?oooooo=_ooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03
o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Coooo
o`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`001Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000oooo
ooooool06oooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo00001?oo
ooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo=Ooo
ool00ol0003oooooooooo`0Kooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo0004ooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo=Ooo
ool00ol0003oooooooooo`0Kooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool0
6oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`00
0?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003ooooooooo
o`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0oooooole
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0
003oooooooooo`0Kooooo`004oooool2o`000?oooooo=_ooool00ol0003oooooooooo`0Kooooo`00
4oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o
0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooo
oooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03
o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Coooo
o`;o0000oooooolfooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo
00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oo
oooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0K
ooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?o
oooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`00
0?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003ooooooooo
o`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0oooooole
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`;o0000oooooolfooooo`03o`000?oooooooooo
01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`00
4oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o
0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooo
oooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03
o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo0_l0003oooooocKooooo00?o0000ooooooooool06oooool001?ooooo00?o0000oooo
ooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo
00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oo
oooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0K
ooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool000Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ooooooleoooo
o`03o`000?oooooooooo01_ooooo00001OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool00004
oooooonHV9So8B4Qonk^kPWooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool000;ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o0000ooooooleooooo`03o`000?oooooooooo01_ooooo0003ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo
00001Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocGooooo00?o0000ooooooooool06oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo
000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool0
0ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000oooo
ooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool2o`000?oooooo=_ooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Coooo
o`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003o
ooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0
ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Ooo
ool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000
ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo
01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`00
4oooool2o`000?oooooo=_ooool00ol0003oooooooooo`0Kooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00cOooool0
0omgMgOoIVIVooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?oIVIVogMgMoooool0OOooool0
0<cooooo00?ogMgMoa0@4?o^k^h03?ooool00ol0003oooooooooo`0:ooooo`03onk^k_l@413ogMgM
07gooooo001_ooooo`?o000000?o410@ooooooooool00_ooool02?o^k^koEEEEo`000?l0003oA4A4
okZj^_oooooo410@1Ol00004ooooo`Go00000_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;o
oooo00Ook^k^oeEEEOl0003o0000oiRHV?l0003o410@00Kooooo00Kok^k^oeEEEOl0003o0000oeEE
EOo^k^h2ooooo`03oa0@4?l0003o000000;o000000?o410@ooooooooool01_ooool01_l@413o<S8b
o`000?l0003o410@ojVYZ@;ooooo00Co410@o`000?l0003ooooo0_l000001_l@413ooooooooooooo
ooooEEEEoiRHV0?ooooo00Kok^k^oc8b<_l0003o0000oeEEEOo^k^h4ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool02?l0003oooooooooool0003o410@oooooon7QhOoIVIVOOooool0073ooooo
00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_oo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Oooooo00KoEEEEogMgMoooooooooooogMgMomEEED4
ooooo`03o`000?oooooooooo00Wooooo00Ko0000ojVYZOoooooooooookZj^_l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`07oeEEEOmgMgOoooooonk^
k_n7QhOo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003oooooooooooo^k^ko000007gooooo001`ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003ooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00Go^[ZjohN7QomVIVKoIVIVoa0@4003ooooo`05o`000?ooooooooooooooool000001?ooool00olb
<S;oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?oQhN7ogMgMoooool00_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
001mooooo`00L?ooool3o`000004ob4Q8Oo<c<coooooooooo`Ko00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h3oooo
o`05o`000?ooooooooooooooool000001?ooool00olb<S;oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go8B4Qooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`00001mooooo`00L?ooool01Ol0003ooooooooooon7QhOo410@00;o
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Oooooo00?o0000
ooooooooool00_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoIVIVogMgMooooooo
k^k^oeEEEOl00007ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003ooooooooo
o`09ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000oooool01Ol0003oQhN7oooooonYZJWo0000
00Cooooo00?o0000onk^k_ooool00_ooool00olQ8B7o0000o`000004o`0000?ooooo00?o0000oooo
ooooool00_ooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B400_ooool00oo^k^ko0000oooo
o`1looooo`00L?ooool01Ol0003ooooooooooooooooo000000;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000004oooo
o`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01_o^k^koEEEEo`000?l@413oc<c<o`0000Oo
oooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003o000000?o00002?ooool0
1_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`02ooooo`03oeEEEOmgMgOooooo00;ooooo00?oV9RHohN7Qoooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZ@;ooooo00?o
MgMgoeEEEOooool0O?ooool0073ooooo00Go0000ooooooooooooQhN7oa0@400Wooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06oooool00ooMgMgo410@onk^kP03ooooo`06oc8b<_n7
QhOok^k^oooooon7QhOo<S8b0oooool00ol0003oooooooooo`0:ooooo`03onk^k_l@413ogMgM07go
oooo001_ooooo`Co000000?o8B4Qolc<c?ooool05?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00oooooo00?o410@okZj^_ooool07?ooool00omgMgOoIVIVooooo`02ooooo`06onk^
k_mgMgOo0000o`000?lb<S;oc<c<0oooool00ol0003oooooooooo`0:ooooo`03ofIVI_mgMgOooooo
07gooooo002:ooooo`03oa0@4?oooooooooo00kooooo0_l0000Aooooo`04okZj^_l@413o0000oa0@
4;Kooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0613147, 5.76145, \
0.00401541, 0.131803}}]
}, Open  ]],

Cell[TextData[{
  " For ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] 0\)]],
  ", corresponding to ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ a\)]],
  ", the period of sn is ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ", and in fact, ",
  Cell[BoxData[
      \(TraditionalForm\`sn(\[Theta], 0) = sin\ \[Theta]\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(JacobiSN[\[Theta], 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.36"],

Cell[BoxData[
    \(Sin[\[Theta]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This low-amplitude limit of the cnoidal waves  [",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  "implies that ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] a\)]],
  " in Eq. ",
  ButtonBox["(7.2.12)",
    ButtonData:>{"Chapter7.nb", "(7.2.12)"},
    ButtonStyle->"Hyperlink"],
  " ] corresponds to the limit of linear waves. "
}], "Text"],

Cell[TextData[{
  "\tSince ",
  Cell[BoxData[
      \(TraditionalForm\`sn\^2\)]],
  " has a period half that of sn, Eq. ",
  ButtonBox["(7.2.12)",
    ButtonData:>{"Chapter7.nb", "(7.2.12)"},
    ButtonStyle->"Hyperlink"],
  "  implies that the wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, b, c)\)]],
  " of the ",
  "cnoidal",
  " waves is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, b, 
          c)\  = \(\(1\/2\) \(\@\(\(12\ \[Alpha]\)\/\(a - c\)\)\)\(\ \)\(P(
            m)\)\(\ \)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.14)"],

Cell[TextData[{
  "In the linear limit ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ a\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] \ 0\)]],
  ") this becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, a, 
          c)\  = \@\(\(12\ \[Alpha]\)\/\(a - c\)\)\ \ \[Pi]\)]],
  "."
}], "NE2",
  CellTags->"(7.2.15)"],

Cell[TextData[{
  "Some examples of cnoidal waves for increasing amplitude are shown in Cell \
",
  ButtonBox["7.37",
    ButtonData:>"Cell 7.37",
    ButtonStyle->"Hyperlink"],
  ", keeping the wave height constant and increasing the depth of the troughs \
(",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " decreasing away from ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " toward ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f[s_, a_, b_, 
          c_] = \ \ a\  - \ \((a - b)\)\ JacobiSN[Sqrt[\((a - c)\)/12] s, 
                  m]^2 /. m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        Plot[f[s, 1, b, 0], {s, \(-20\), 20}, 
          PlotLabel \[Rule] "\<m =\>" <> 
              ToString[\((a - b)\)/\((a - c)\) /. {a \[Rule] 1, 
                    c \[Rule] 0}], 
          AxesLabel \[Rule] \ {"\<s/\!\(\@\[Alpha]\)\>", "\<\>"}, 
          PlotRange \[Rule] {\(-1\), 1}\ ], {b,  .9, 
          0. , \(- .2\)\ }];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.37"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60607 m
.04262 .59926 L
.06244 .59287 L
.07286 .59028 L
.07784 .58928 L
.08255 .58851 L
.08523 .58814 L
.08813 .58781 L
.09054 .58758 L
.0932 .58738 L
.09468 .5873 L
.09607 .58723 L
.09754 .58718 L
.09836 .58716 L
.09912 .58715 L
.09981 .58714 L
.10045 .58713 L
.10116 .58713 L
.10192 .58714 L
.10264 .58714 L
.10331 .58715 L
.10458 .58718 L
.10574 .58722 L
.10699 .58728 L
.10923 .58741 L
.11191 .58761 L
.11434 .58785 L
.11964 .58853 L
.12466 .58937 L
.13351 .59127 L
.14313 .59388 L
.16252 .60036 L
.18391 .60807 L
.19366 .61126 L
.20417 .61418 L
.209 .61528 L
.21408 .61627 L
.21843 .61694 L
.22318 .6175 L
.22571 .61772 L
.22705 .61781 L
.22846 .61789 L
.2297 .61795 L
.23036 .61797 L
.23106 .61799 L
.2323 .61802 L
.23345 .61803 L
.23465 .61803 L
.23596 .61802 L
.23719 .61799 L
Mistroke
.23833 .61795 L
.23947 .6179 L
.24049 .61784 L
.24279 .61769 L
.24549 .61744 L
.24798 .61716 L
.25358 .61633 L
.26374 .61421 L
.2735 .61152 L
.2826 .60859 L
.30328 .60117 L
.32195 .59478 L
.3318 .59196 L
.34224 .58958 L
.3475 .58866 L
.35029 .58826 L
.3533 .58789 L
.35605 .58762 L
.35858 .58742 L
.36099 .58728 L
.3622 .58723 L
.36352 .58718 L
.36417 .58717 L
.36488 .58715 L
.36617 .58714 L
.36742 .58713 L
.36857 .58714 L
.36982 .58716 L
.37053 .58718 L
.37119 .5872 L
.37252 .58726 L
.37396 .58733 L
.37656 .5875 L
.37903 .58772 L
.38365 .58825 L
.38823 .58894 L
.39329 .58988 L
.40354 .5923 L
.42195 .59804 L
.4429 .6056 L
.46212 .612 L
.47187 .61459 L
.48094 .61642 L
.48552 .61709 L
.48787 .61737 L
.49041 .61762 L
.49186 .61773 L
.4932 .61782 L
.49446 .61789 L
.49584 .61796 L
Mistroke
.49708 .618 L
.49824 .61802 L
.49946 .61803 L
.50078 .61803 L
.50146 .61802 L
.50211 .61801 L
.50332 .61798 L
.50462 .61794 L
.50602 .61787 L
.50856 .6177 L
.51089 .6175 L
.51626 .61685 L
.52193 .61591 L
.53151 .61376 L
.54202 .61074 L
.56318 .60339 L
.58247 .59654 L
.59205 .59354 L
.60246 .5908 L
.60723 .58977 L
.6123 .58885 L
.61673 .5882 L
.62139 .58768 L
.62373 .58748 L
.62497 .58739 L
.62629 .58732 L
.62751 .58726 L
.62861 .58721 L
.62972 .58718 L
.63077 .58715 L
.632 .58714 L
.6333 .58713 L
.63441 .58714 L
.63562 .58716 L
.63693 .5872 L
.63834 .58725 L
.63967 .58731 L
.64088 .58739 L
.64537 .58775 L
.64791 .58803 L
.65026 .58834 L
.65916 .58986 L
.66977 .59237 L
.67974 .59531 L
.69837 .60177 L
.7168 .60838 L
.72725 .61175 L
.73699 .61438 L
.74665 .61637 L
.74943 .61681 L
Mistroke
.75206 .61716 L
.7544 .61743 L
.75698 .61767 L
.75953 .61785 L
.76093 .61792 L
.76224 .61797 L
.76346 .618 L
.76457 .61802 L
.76586 .61803 L
.76709 .61803 L
.76841 .61801 L
.76914 .61799 L
.76981 .61797 L
.77111 .61791 L
.77234 .61785 L
.77509 .61766 L
.77806 .61738 L
.78298 .61674 L
.78756 .61597 L
.79799 .61363 L
.81906 .60703 L
.83768 .60029 L
.85795 .59356 L
.86898 .59068 L
.87383 .58965 L
.87918 .58871 L
.88421 .58802 L
.88894 .58754 L
.89154 .58736 L
.89392 .58724 L
.89517 .58719 L
.89589 .58717 L
.89654 .58716 L
.89723 .58714 L
.89797 .58714 L
.89865 .58713 L
.8993 .58713 L
.90045 .58714 L
.90169 .58716 L
.90286 .58719 L
.90393 .58723 L
.90654 .58737 L
.90902 .58754 L
.91394 .58804 L
.9193 .58879 L
.92888 .59066 L
.93775 .59292 L
.97619 .60607 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<So
oooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002M
ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00P_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00P_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038
ooooo`00P_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOoo
ool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009go
oooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l0
0039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0<Sooooo001jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001jooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`38ooooo`00N_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0<Sooooo001jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`38ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oo
oooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo
0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool002;ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Vooooo`;o00009oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04kooooo000Ioooooa?o0000?ooooolDo`0001kooooo00?o0000oooooooo
ool07OoooolDo`0003kooooo4Ol00018ooooo`005_ooool3o`0001?ooooo0ol0000iooooo`?o0000
5?ooool3o`0001_ooooo00?o0000ooooooooool06?ooool5o`0001Cooooo0ol0000fooooo`Go0000
4Oooool6o`0004;ooooo000Cooooo`?o00006Oooool3o`0003?ooooo0ol0000Jooooo`?o00006?oo
ool00ol0003oooooooooo`0Eooooo`?o00007?ooool3o`00033ooooo0ol0000Looooo`?o0000?ooo
ool0013ooooo0ol0000Oooooo`?o0000;Oooool3o`00023ooooo0ol0000Eooooo`03o`000?oooooo
oooo01;ooooo0ol0000Rooooo`?o0000:oooool2o`0002;ooooo0ol0000looooo`003Oooool3o`00
02Gooooo0ol0000Wooooo`?o00009_ooool3o`0001;ooooo0_l0000@ooooo`?o0000:?ooool2o`00
02Oooooo0_l0000Wooooo`?o0000>Oooool000_ooooo0_l0000[ooooo`?o00008Oooool3o`0002co
oooo0ol0000?ooooo`03o`000?oooooooooo00gooooo0_l0000]ooooo`?o00008Oooool3o`0002co
oooo00?o0000ooooooooool0=_ooool003_ooooo1?l0000Jooooo`?o0000<_ooool3o`0000;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0000booooo`?o0000
6oooool3o`0006Sooooo000oooooo`?o00005?ooool3o`0003Sooooo0ol000000ooooooo0000oooo
o`06ooooo`03o`000?oooooooooo00Sooooo0ol0000gooooo`?o00005Oooool3o`0006_ooooo0012
ooooo`Co00002oooool5o`0003kooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo1Ol0000m
ooooo`Co00003?ooool5o`0006kooooo0016ooooo`_o0000A?ooool00ol0003oooooooooo`0;o`00
04Kooooo3?l0001cooooo`00UOooool00ol0003oooooooooo`3@ooooo`00UOooool00ol0003ooooo
ooooo`3@ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00Toooool00omEEEGoIVIVo`00003B
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Q_ooool2
o`0000;ooooo00Go0000oooooooooooo0000oa0@400?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`2booooo`00Qoooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Kooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0]?ooool008Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`2dooooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Kooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`2d
ooooo`00Qoooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B404?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool0]?ooool008Kooooo00So410@o`000?lQ8B7o0000
ogMgMol@413o0000ojVYZA3ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo0;Cooooo002Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`2d
ooooo`00W_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000]_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54972 m
.03279 .54239 L
.04262 .53567 L
.04758 .53287 L
.05288 .53034 L
.05785 .52842 L
.06244 .52706 L
.06508 .52645 L
.06788 .52594 L
.06924 .52575 L
.07069 .52559 L
.07153 .52551 L
.07229 .52545 L
.07301 .52541 L
.07379 .52537 L
.0745 .52535 L
.07515 .52533 L
.07641 .52533 L
.07712 .52534 L
.07789 .52537 L
.07862 .5254 L
.07928 .52544 L
.08049 .52553 L
.08182 .52566 L
.08451 .52603 L
.08713 .52652 L
.08952 .52709 L
.09489 .52874 L
.09987 .53073 L
.10458 .53303 L
.12449 .5467 L
.14291 .56381 L
.16316 .58468 L
.17308 .59445 L
.18218 .60249 L
.19085 .60893 L
.19544 .61173 L
.20034 .61419 L
.20293 .61526 L
.20528 .61609 L
.20768 .61678 L
.20988 .61729 L
.21106 .61751 L
.21236 .6177 L
.21367 .61786 L
.21438 .61792 L
.21505 .61797 L
.21628 .61802 L
.2174 .61803 L
.2187 .61801 L
Mistroke
.21993 .61794 L
.22118 .61783 L
.22253 .61766 L
.22497 .61723 L
.22735 .61666 L
.22954 .61601 L
.23452 .61406 L
.23977 .61136 L
.24855 .6055 L
.25817 .5975 L
.27936 .57647 L
.29865 .55694 L
.30824 .54824 L
.31867 .54007 L
.32844 .53387 L
.33761 .52951 L
.34215 .52791 L
.34703 .52661 L
.34968 .52609 L
.35112 .52587 L
.35246 .52569 L
.3537 .52556 L
.35483 .52547 L
.35608 .52539 L
.35677 .52536 L
.35742 .52534 L
.35864 .52533 L
.35933 .52533 L
.35998 .52535 L
.36128 .5254 L
.36201 .52544 L
.36268 .52548 L
.36387 .52559 L
.36516 .52573 L
.36752 .52608 L
.37027 .52661 L
.37319 .52734 L
.37844 .52904 L
.3878 .5333 L
.39789 .53956 L
.41616 .55461 L
.43579 .57424 L
.45727 .59582 L
.46718 .60431 L
.47262 .60829 L
.47777 .61151 L
.48257 .61397 L
.48509 .61505 L
.48777 .61601 L
.49002 .61669 L
Mistroke
.4925 .61727 L
.49358 .61747 L
.49475 .61766 L
.49584 .6178 L
.49686 .6179 L
.4975 .61795 L
.49819 .61799 L
.4994 .61803 L
.50009 .61803 L
.50081 .61803 L
.50211 .61797 L
.50331 .61788 L
.50443 .61777 L
.50566 .6176 L
.50698 .61737 L
.50994 .6167 L
.51275 .61584 L
.51801 .6137 L
.52301 .61105 L
.52764 .60811 L
.53811 .59996 L
.57739 .5608 L
.5971 .54325 L
.60573 .53712 L
.61516 .53179 L
.61972 .52975 L
.6246 .52799 L
.62729 .52721 L
.62974 .52661 L
.63206 .52615 L
.63452 .52577 L
.6358 .52562 L
.6372 .52549 L
.63848 .52541 L
.63968 .52536 L
.6404 .52534 L
.64108 .52533 L
.64237 .52534 L
.64308 .52536 L
.64375 .52538 L
.64448 .52542 L
.64526 .52547 L
.64657 .52559 L
.648 .52575 L
.65057 .52614 L
.65308 .52664 L
.65539 .5272 L
.66011 .52866 L
.66516 .53067 L
.67426 .53543 L
Mistroke
.68509 .54284 L
.69494 .55102 L
.7157 .57133 L
.73486 .59094 L
.7535 .60701 L
.7629 .61281 L
.76825 .61522 L
.77085 .61613 L
.77326 .61682 L
.77566 .61736 L
.77701 .61759 L
.77822 .61776 L
.77956 .6179 L
.78032 .61796 L
.78101 .61799 L
.78229 .61803 L
.78293 .61803 L
.78364 .61802 L
.78492 .61797 L
.7861 .61788 L
.78675 .61781 L
.78745 .61773 L
.78874 .61754 L
.79121 .61706 L
.7935 .61646 L
.79777 .61499 L
.80248 .61284 L
.81202 .60695 L
.83136 .59017 L
.85221 .56877 L
.87185 .54982 L
.88224 .54142 L
.89334 .53417 L
.89887 .53131 L
.90409 .52911 L
.90878 .52755 L
.9112 .52691 L
.91386 .52632 L
.91635 .5259 L
.91868 .52561 L
.91997 .52549 L
.92115 .52541 L
.9218 .52538 L
.9225 .52535 L
.92379 .52533 L
.925 .52534 L
.92609 .52537 L
.92736 .52543 L
.92855 .52552 L
.92965 .52562 L
Mistroke
.93066 .52574 L
.93295 .52608 L
.93542 .52655 L
.93766 .52708 L
.94271 .52862 L
.94738 .53045 L
.95181 .53255 L
.96171 .53845 L
.97248 .54657 L
.97619 .54972 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<So
oooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002M
ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00P_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00P_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038
ooooo`00P_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOoo
ool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009go
oooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool001Gooooo3?l0
001;ooooo`co00009Oooool2o`0002Cooooo2ol0001<ooooo`_o0000@oooool001?ooooo0_l0000<
ooooo`?o0000A_ooool2o`0000cooooo0_l0000Sooooo`03o`000?oooooooooo027ooooo0_l0000;
ooooo`?o0000AOooool4o`0000_ooooo0_l00011ooooo`004_ooool00ol0003oooooooooo`0?oooo
o`;o0000@Oooool3o`00013ooooo0ol000000olb<S;ok^k^ooooo`04ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0O
ooooo`;o00004?ooool00ol0003oooooooooo`10ooooo`;o00004Oooool2o`0003oooooo000@oooo
o`;o00005?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?l0003oV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool07Oooool2o`0001?ooooo0_l0000oooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0??ooool000oooooo00?o0000ooooooooool05Oooool2o`00
03cooooo00?o0000ooooooooool04_ooool00ol@413oooooooooo`02o`0000gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o00007?ooool00ol0003oooooooooo`0Eoooo
o`;o0000??ooool00ol0003oooooooooo`0Eooooo`;o0000??ooool000gooooo0_l0000Jooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool2o`00
00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01[ooooo0_l0000Jooooo`;o0000>Oooool00ol0003oooooooooo`0Hooooo`;o0000>_ooool000co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Co
oooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0gooooo`002oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03?ooooo0_l0000G
ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`09ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03Kooooo000/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Gooooo`00;Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP04ooooo`03o`000?oooooooooo00Cooooo1Ol00004ooooo`Co00001_ooool2o`0001Oooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05Sooooo
000^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Cooooo0_l0000Uooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0FOooool002oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0F_ooool002oooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Foooool0033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02Oooooo0_l0001Nooooo`00<Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool04_ooool2o`00017ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05kooooo000booooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0;Oooool2o`0001;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Gooo
ool003?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0H?ooool003Cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool003Go
oooo0_l0000Pooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03Oooool2o`0000go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06;o
oooo000gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo06?ooooo000hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>?ooool2o`0001[ooooo00?o0000ooooooooool0I?ooool003Wooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0IOooool003[ooooo00?o0000ooooooooool05Oooool2o`0003gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Vooooo`00>oooool2o`0001Cooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0Ioooool003gooooo00?o0000ooooooooool0
3oooool2o`0004;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Xooooo`00?_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@oooool2o`0000kooooo0_l0
001[ooooo`00?oooool2o`0000_ooooo0_l00017ooooo`;o00001_ooool00ol0003oooooooooo`03
ooooo`;o0000B?ooool2o`0000[ooooo0_l0001]ooooo`00@Oooool2o`0000Oooooo0_l00019oooo
o`03o`000?oooooo000000;o00000oooool01?l0003oooooooooooooool2o`0004cooooo0_l00006
ooooo`;o0000Koooool004?ooooo1ol0001;ooooo`03o`000?oooooooooo00;ooooo1ol0001@oooo
o`Ko0000LOooool009Gooooo00?o0000ooooooooool0d?ooool009Gooooo00?o0000ooooooooool0
d?ooool009Gooooo00?o0000ooooooooool0d?ooool009?ooooo00?oEEEEofIVI_l00000d_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008Kooooo0_l00002
ooooo`05o`000?ooooooooooo`000?l@41003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0]Oooool008Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`06ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S80]Oooool008Oooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`2cooooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Kooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@
ooooo`2dooooo`00Qoooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B404?ooool01Ol0003o
oooooooooooooooo000000gooooo00?o410@o`000?nj^[X0]Oooool008Kooooo00So410@o`000?lQ
8B7o0000ogMgMol@413o0000ojVYZA3ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj
^_lQ8B7ooooo0;Cooooo002Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o00000;Gooooo002Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY0;Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .46697 m
.02605 .46614 L
.02846 .46538 L
.03053 .46483 L
.03279 .46434 L
.03416 .46409 L
.03543 .46391 L
.03662 .46377 L
.03793 .46365 L
.03911 .46358 L
.04021 .46354 L
.04137 .46353 L
.04262 .46355 L
.04393 .46361 L
.04516 .4637 L
.0465 .46384 L
.04793 .46403 L
.05057 .46452 L
.05297 .46509 L
.05785 .46666 L
.06244 .46863 L
.07299 .47496 L
.08269 .48297 L
.10458 .50831 L
.14407 .5702 L
.15427 .58576 L
.16393 .5986 L
.1726 .60783 L
.1775 .61186 L
.17984 .61345 L
.18204 .61473 L
.18438 .61588 L
.18654 .61672 L
.18892 .61741 L
.19018 .61767 L
.1915 .61787 L
.1927 .61799 L
.19399 .61803 L
.1952 .61801 L
.1963 .61793 L
.19759 .61777 L
.19833 .61764 L
.199 .6175 L
.20155 .6168 L
.20405 .61583 L
.20639 .61467 L
.21171 .61119 L
.21689 .60673 L
.22246 .60086 L
.24364 .57116 L
Mistroke
.26374 .53843 L
.28381 .5082 L
.30199 .48651 L
.31214 .47736 L
.3217 .47084 L
.32695 .46812 L
.33178 .46618 L
.33453 .46531 L
.33709 .46466 L
.33976 .46413 L
.34117 .46392 L
.34268 .46374 L
.34391 .46364 L
.3446 .4636 L
.34525 .46356 L
.34657 .46353 L
.34731 .46353 L
.34798 .46353 L
.34913 .46357 L
.35037 .46365 L
.35167 .46377 L
.35288 .46391 L
.35569 .46437 L
.35824 .46494 L
.36396 .46676 L
.36894 .46895 L
.37433 .47195 L
.3841 .47906 L
.39359 .48796 L
.40401 .49992 L
.42507 .52991 L
.44619 .56421 L
.46546 .59316 L
.47501 .60448 L
.48005 .60926 L
.48541 .61328 L
.49008 .61582 L
.49136 .61635 L
.49274 .61684 L
.49393 .6172 L
.49524 .61752 L
.49643 .61775 L
.49755 .6179 L
.49872 .618 L
.49998 .61803 L
.50115 .618 L
.50226 .61792 L
.50326 .61779 L
.50434 .61761 L
.50556 .61733 L
Mistroke
.50669 .61702 L
.50922 .61612 L
.51156 .61503 L
.51378 .61378 L
.51876 .61024 L
.52419 .6053 L
.5351 .59242 L
.54522 .57781 L
.58437 .51564 L
.59467 .50159 L
.6058 .48861 L
.61542 .47946 L
.62051 .47544 L
.62597 .47177 L
.63137 .4688 L
.6363 .46666 L
.63867 .46583 L
.64124 .46507 L
.64366 .4645 L
.64593 .46408 L
.64724 .46389 L
.64845 .46375 L
.64979 .46364 L
.6505 .46359 L
.65124 .46356 L
.65191 .46354 L
.65263 .46353 L
.65393 .46354 L
.65472 .46356 L
.65547 .4636 L
.65615 .46364 L
.65687 .4637 L
.65809 .46383 L
.65943 .46401 L
.66214 .46449 L
.66465 .46509 L
.667 .46578 L
.67198 .46765 L
.67741 .47034 L
.6873 .47693 L
.69692 .48542 L
.70584 .49506 L
.74504 .55277 L
.76507 .58448 L
.7756 .59858 L
.78134 .60498 L
.7867 .60993 L
.79152 .61344 L
.79399 .61488 L
.79668 .61614 L
Mistroke
.79821 .61672 L
.79962 .61716 L
.80098 .6175 L
.80167 .61764 L
.80241 .61777 L
.80369 .61793 L
.80489 .61801 L
.80562 .61803 L
.80631 .61803 L
.80762 .61796 L
.80883 .61783 L
.80992 .61766 L
.81119 .61739 L
.81238 .61707 L
.81451 .61634 L
.81681 .61533 L
.82203 .6122 L
.82684 .60834 L
.83656 .59801 L
.84565 .58587 L
.86631 .55332 L
.88494 .52348 L
.90521 .49581 L
.91623 .484 L
.92644 .47538 L
.93619 .46931 L
.94112 .46706 L
.94371 .4661 L
.94656 .46522 L
.95018 .46436 L
.95215 .46402 L
.9531 .46389 L
.95399 .46378 L
.95482 .4637 L
.95572 .46363 L
.95654 .46358 L
.95729 .46355 L
.95811 .46353 L
.959 .46353 L
.95994 .46354 L
.96081 .46357 L
.96176 .46363 L
.9628 .46371 L
.96469 .46392 L
.96652 .46421 L
.96823 .46454 L
.97208 .46554 L
.97619 .46697 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<So
oooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002M
ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00P_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00P_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b?ooool0
00_ooooo2_l0001Dooooo`[o00003oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0002Oooooo2ol0001Cooooo`[o0000>Oooool000_ooooo00?o0000oooo
ooooool01oooool4o`0004kooooo0_l0000:ooooo`?o00003?ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo1?l0
000:ooooo`03o`000?oooooooooo04gooooo0ol0000:ooooo`03o`000?oooooooooo03Kooooo000I
ooooo`03o`000?oooooooooo04Wooooo0_l0000?ooooo`;o00002_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00gooooo0_l0001<ooooo`03o`000?oooooooooo04Cooooo000Jooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo0_l0
000Booooo`03o`000?oooooooooo04Oooooo0_l00017ooooo`006oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00006ooooo`;o00008Oooool00ol0003oooooooooo`0Cooooo`;o0000A_oo
ool00ol0003oooooooooo`17ooooo`007?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`18ooooo`007Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`19ooooo`007_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1:ooooo`007oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`1;ooooo`008?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool2o`0001gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo04cooooo000Roooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo04gooooo000Sooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04kooooo000Tooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04kooooo000Tooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Iooooo`;o00006Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0Coooool002Gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0D?ooool0
02Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0D?ooool002Kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0DOooool002Oooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0D_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01Gooooo0_l0000Fooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`1Booooo`00:?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1C
ooooo`00:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q00?o0000ooooooooool00oooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Dooooo`00:Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q00?oooooo`000?ooool00oooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0E?ooool002[ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Sooooo`05oa0@4?ooooooooooooooool@41002Oooool01_l0003ooooooooo
ooooooooZJVYoeEEE@Wooooo00?o0000ooooooooool00oooool3o`0001?ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Gooooo000[ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Wo
oooo00?o0000ooooooooool00_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0E_ooool002_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Tooooo`05o`000?ooooooooooooooool000002_ooool01_l0003oooooooooooooooooEEEE
olc<c0Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo000/
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09Oooool01Ol@413ooooooooooooo
oooo410@00[ooooo00Ko0000ooooooooooooooooojVYZOmgMgL4ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0Eoooool002gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Hooooo`00;Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo0_l0000Aooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`1Hooooo`00;_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Iooooo`00
;_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Jooooo`00;oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Jooooo`00<?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1Kooooo`00<?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool03?ooool2o`0000kooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo05_ooooo000aooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05co
oooo000booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo05gooooo000booooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05gooooo000c
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0:
ooooo`;o00002oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0G_ooool003?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0G_ooool003Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Goooool003Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0H?ooool003Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0HOoo
ool003Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00Kooooo0_l00006ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1Rooooo`00=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
04_ooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool2o`00
00gooooo00?o0000ooooooooool0Hoooool003Sooooo0_l0000;ooooo`;o0000C?ooool5o`0000Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0I?ooool003[ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool2o`00057ooooo
00?o0000ooooooooool01oooool2o`0006Oooooo000kooooo`;o00001Oooool2o`00057ooooo00?o
0000ooooooooool00ol00002ooooo`03o`000?oooooooooo00;o0000E?ooool3o`0000Cooooo0_l0
001Yooooo`00?Oooool5o`0005?ooooo00?o0000ooooooooool00oooool5o`0005Sooooo1_l0001Z
ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00
UOooool00ol0003oooooooooo`3@ooooo`00Toooool00omEEEGoIVIVo`00003Booooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Q_ooool2o`0000;ooooo00Go
0000oooooooooooo0000oa0@400?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@2dooooo`00Qoooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Kooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool0/oooool008Oooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`2booooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo1_l0
0002ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`2cooooo`00Qooo
ool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B404?ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c02dooooo`00Q_ooool02?l@413o0000ob4Q8Ol0003o
MgMgoa0@4?l0003oZJVY4?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool0]_ooool009kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo0;Ko
oooo002Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`000;Gooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41536 m
.03279 .42296 L
.04262 .4334 L
.06244 .4614 L
.10458 .546 L
.11548 .56893 L
.12579 .5883 L
.13504 .60245 L
.14027 .60866 L
.14259 .61095 L
.14509 .61308 L
.14752 .61479 L
.14974 .61605 L
.15081 .61655 L
.15197 .61701 L
.15307 .61737 L
.1541 .61763 L
.1554 .61787 L
.15659 .618 L
.15786 .61803 L
.15858 .61801 L
.15924 .61795 L
.16035 .6178 L
.16156 .61755 L
.16283 .61718 L
.16402 .61675 L
.16662 .6155 L
.16908 .61393 L
.1737 .61002 L
.17867 .60449 L
.18408 .59706 L
.20386 .56065 L
.22486 .51531 L
.24456 .47585 L
.26261 .44646 L
.28196 .4235 L
.29212 .4149 L
.29773 .41112 L
.30282 .40826 L
.3074 .40614 L
.31236 .40432 L
.31509 .40353 L
.31761 .40293 L
.32001 .40246 L
.32134 .40226 L
.32256 .4021 L
.3236 .40198 L
.32474 .40188 L
.32594 .4018 L
.32708 .40175 L
Mistroke
.32814 .40173 L
.32927 .40172 L
.33034 .40174 L
.33131 .40178 L
.33255 .40185 L
.33369 .40195 L
.33494 .40208 L
.33626 .40225 L
.33849 .40261 L
.34093 .40312 L
.34618 .40461 L
.35116 .40652 L
.36047 .41146 L
.37051 .41882 L
.3814 .42936 L
.40122 .45566 L
.42224 .49338 L
.46004 .57333 L
.46949 .59059 L
.47942 .60503 L
.48463 .61067 L
.48738 .61304 L
.49032 .61508 L
.49171 .61586 L
.49303 .6165 L
.49431 .61701 L
.49549 .61739 L
.49661 .61767 L
.4978 .61788 L
.49899 .618 L
.50029 .61803 L
.50159 .61795 L
.5028 .61779 L
.50412 .61749 L
.50552 .61707 L
.50788 .61607 L
.51048 .61457 L
.51528 .61075 L
.51978 .60599 L
.52984 .5917 L
.54069 .5719 L
.58179 .48545 L
.6023 .45032 L
.61229 .43671 L
.62139 .4264 L
.63021 .41822 L
.63979 .41129 L
.64505 .40832 L
.6499 .40607 L
.65455 .40437 L
Mistroke
.65946 .40303 L
.66199 .40253 L
.66438 .40216 L
.66654 .40193 L
.66775 .40183 L
.66888 .40177 L
.66952 .40175 L
.67021 .40173 L
.67146 .40172 L
.67267 .40174 L
.67379 .40179 L
.675 .40186 L
.67633 .40198 L
.67772 .40213 L
.67901 .40231 L
.68139 .40272 L
.68364 .40321 L
.68785 .40439 L
.69239 .40605 L
.69732 .40833 L
.70673 .41406 L
.71711 .42261 L
.72795 .43415 L
.73812 .4475 L
.77683 .51894 L
.79649 .56137 L
.80689 .5819 L
.8126 .59185 L
.81799 .60006 L
.82315 .60667 L
.82587 .6096 L
.82875 .61225 L
.83118 .61411 L
.83384 .61575 L
.83501 .61633 L
.83626 .61686 L
.83736 .61725 L
.83853 .61757 L
.8398 .61783 L
.84098 .61797 L
.8417 .61802 L
.84238 .61803 L
.84365 .61798 L
.84487 .61783 L
.84599 .61761 L
.84722 .61728 L
.84851 .61683 L
.85077 .61579 L
.85286 .61455 L
.85763 .61075 L
Mistroke
.86266 .60535 L
.86812 .59803 L
.87804 .58147 L
.89661 .54341 L
.91605 .50164 L
.93747 .46155 L
.9471 .44676 L
.95746 .43331 L
.97619 .41536 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool006?ooooo2ol0000_ooooo`;o0000;Oooool<o`00093ooooo001Qooooo`;o
00002oooool3o`0002cooooo00?o0000ooooooooool0:_ooool2o`0000cooooo00?o0000oooooooo
ool0SOooool0063ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool03Oooool3o`0008cooooo001Nooooo`;o00004_oo
ool2o`0002Wooooo00?o0000ooooooooool09oooool2o`0001?ooooo00?o0000ooooooooool0ROoo
ool000_ooooo0_l0001?ooooo`;o00005_ooool00ol0003oooooooooo`0Vooooo`;o00009oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04kooooo0_l0000hooooo`003Oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Tooooo`;o00006?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
03Sooooo000>ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo03Wooooo000?ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03[ooooo
000@ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo03_ooooo000Aooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Rooooo`;o00008Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0??ooool0017ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0??ooool001;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0?Oooool001?ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
?_ooool001?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?oooool001Cooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0_l0000Nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`005Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`10ooooo`005Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Wo
oooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo047ooooo000Fooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooooMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
047ooooo000Gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`12ooooo`005oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02co
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`12ooooo`006?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02go
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`13ooooo`006?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02oooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0@oooool001Wooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0`ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo04Cooooo000Iooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<Oooool01Ol0003o<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`;o00006?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0AOooool001[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0AOooool001[ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
A_ooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0A_ooool001_ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Aoooool0
01cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
01Gooooo0_l0000Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`18ooooo`007Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`19ooooo`007Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`19ooooo`007_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:
ooooo`007_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool04oooool2o`0001?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo04[ooooo000Oooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo000Oooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo000Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo000Pooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo04cooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0@ooooo`;o00004Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0COooool002;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo0_l000000oo^k^koooooooooo`03ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1=ooooo`008_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1Oooool00ol0
003oEEEEojVYZ@08ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0C_ooool002?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0booooo`05oa0@4?oooooooooooooo
ool@41003Oooool00ol0003oEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000>oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1>oooo
o`008oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?lQ8B7ooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1?ooooo`009?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03?o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?o<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04oooooo000Tooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0=?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo053ooooo000Uoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0D?ooool002Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0d
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00003Ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0D?oo
ool002Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0DOooool002Kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOooool002Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0D_ooool002Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0D_ooool002Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wooooo0_l0
000:ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1Cooooo`00:?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Cooooo`00:?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Coooo
o`00:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1Dooooo`00:Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool02?ooool2o`0000Sooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Cooooo000Zooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo05Gooooo000Zooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Kooooo000[ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
05Kooooo000/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo05Oooooo000]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool002gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0FOooool002kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1F
ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Jooooo`00;oooool2o`0000Oooooo0_l0001Koooo
o`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo0000063ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`00<Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003o
oooo00;o0000HOooool3o`0000?ooooo0_l0001Nooooo`00<_ooool5o`0005kooooo00?o0000oooo
ooooool00oooool5o`0006Cooooo1Ol0001Oooooo`00UOooool00ol0003oooooooooo`3@ooooo`00
UOooool00ol0003oooooooooo`3@ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00Toooool0
0omEEEGoIVIVo`00003Booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Q_ooool2o`0000;ooooo00Go0000oooooooooooo0000oa0@400?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0]Oooool008Oooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`Ko00000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo0;Gooooo0027ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool03_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool0]Oooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`06ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool0]?ooool008Oooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q013ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo0;Cooooo0026ooooo`08oa0@4?l0
003o8B4Qo`000?mgMgOo410@o`000?nYZJT@ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`2dooooo`00W_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P2eooooo`00W_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
002eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .53323 m
.03279 .55645 L
.04262 .57963 L
.04758 .58986 L
.05288 .59936 L
.05785 .6067 L
.06244 .61195 L
.06508 .61427 L
.06788 .61613 L
.06933 .61685 L
.07069 .61737 L
.07147 .6176 L
.07218 .61777 L
.073 .61791 L
.07379 .618 L
.07507 .61803 L
.07579 .61799 L
.07644 .61791 L
.07771 .61767 L
.07891 .61732 L
.08031 .61676 L
.0816 .61611 L
.08451 .61416 L
.08691 .61204 L
.08916 .60968 L
.09427 .60296 L
.10458 .58442 L
.14349 .48624 L
.1633 .43979 L
.17375 .41928 L
.18485 .40076 L
.19469 .38705 L
.20555 .37461 L
.22469 .35849 L
.23479 .35246 L
.24404 .34816 L
.2542 .34461 L
.25931 .34324 L
.2649 .34202 L
.27018 .34114 L
.27278 .3408 L
.27517 .34053 L
.27731 .34033 L
.27965 .34016 L
.28201 .34004 L
.2833 .33999 L
.28451 .33995 L
.2858 .33993 L
.28654 .33992 L
.28722 .33992 L
Mistroke
.28846 .33992 L
.28916 .33993 L
.28979 .33994 L
.29098 .33997 L
.29227 .34002 L
.29349 .34007 L
.29461 .34013 L
.29713 .34031 L
.29989 .34056 L
.30546 .34127 L
.31072 .3422 L
.31569 .3433 L
.32501 .34604 L
.33504 .35005 L
.34594 .35586 L
.35536 .36231 L
.36575 .37121 L
.37672 .38297 L
.38677 .39617 L
.40615 .42907 L
.42702 .47566 L
.44759 .52927 L
.45761 .55532 L
.4667 .577 L
.47557 .59492 L
.48023 .60262 L
.48516 .60922 L
.48768 .61191 L
.49044 .61433 L
.49296 .61601 L
.49408 .61661 L
.4953 .61713 L
.49654 .61755 L
.49771 .61782 L
.49886 .61798 L
.49991 .61803 L
.50105 .61799 L
.50231 .61782 L
.50363 .6175 L
.50486 .61707 L
.50603 .61655 L
.50729 .61587 L
.50955 .61434 L
.51468 .6094 L
.52009 .60213 L
.52502 .59386 L
.54352 .55247 L
.56429 .49779 L
.58347 .45088 L
.60332 .41172 L
Mistroke
.6219 .38463 L
.63093 .37449 L
.64064 .3655 L
.65134 .35758 L
.66127 .35184 L
.67139 .34734 L
.67718 .34532 L
.68242 .34379 L
.6871 .34265 L
.69215 .34166 L
.69493 .34122 L
.69749 .34087 L
.70012 .34056 L
.70252 .34034 L
.70493 .34016 L
.70722 .34004 L
.70848 .33999 L
.70964 .33996 L
.71091 .33993 L
.71155 .33992 L
.71226 .33992 L
.71344 .33992 L
.71452 .33993 L
.71571 .33996 L
.71695 .33999 L
.71804 .34004 L
.71906 .34009 L
.72135 .34023 L
.72405 .34045 L
.72659 .34072 L
.73135 .34137 L
.73647 .34229 L
.74202 .34357 L
.7515 .34646 L
.76191 .3508 L
.77279 .35684 L
.78296 .36413 L
.79338 .37352 L
.80326 .3845 L
.82181 .41146 L
.84167 .45056 L
.86007 .49542 L
.87892 .54518 L
.88883 .5698 L
.89927 .59204 L
.90461 .60125 L
.91046 .60925 L
.91303 .61199 L
.91578 .61438 L
.91712 .61533 L
Mistroke
.91838 .6161 L
.9196 .61672 L
.92074 .61719 L
.9219 .61757 L
.92318 .61786 L
.92443 .618 L
.92513 .61803 L
.92577 .61802 L
.92691 .61792 L
.92815 .6177 L
.92933 .61736 L
.93042 .61695 L
.93309 .61555 L
.9355 .6138 L
.94093 .60824 L
.94522 .60236 L
.94975 .59485 L
.95786 .57857 L
.97619 .53323 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00E?ooool@o`0003Wooooo0_l0000h
oooooa3o0000POooool0053ooooo1?l0000@ooooo`?o0000=_ooool00ol0003oooooooooo`0boooo
o`Go00004?ooool3o`0007kooooo001=ooooo`?o00005oooool3o`0003?ooooo00?o0000oooooooo
ool0<?ooool2o`0001Sooooo0ol0001kooooo`00C?ooool00ol0003oooooooooo`0Kooooo`;o0000
<Oooool00ol0003oooooooooo`0]ooooo`?o00007Oooool2o`0007Wooooo001:ooooo`;o00008?oo
ool2o`0002oooooo0_l0000]ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0M_oo
ool004Oooooo0ol0000Tooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Rooooo`;o0000M_ooool004Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09Oooool2o`00
07Cooooo0015ooooo`03o`000?oooooooooo02Sooooo0_l0000[ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1aooooo`00A?ooool00ol0003ooooo
ooooo`0[ooooo`;o0000:Oooool00ol0003oooooooooo`0Wooooo`;o0000;?ooool00ol0003ooooo
ooooo`1`ooooo`00@oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Kooooo0_l0
000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Koooool004;ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`1^ooooo`00@_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`1]ooooo`00@Oooool00ol0003oooooooooo`0b
ooooo`09o`000?oooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1/ooooo`00@?ooool00ol0003o
ooooooooo`0dooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool02_ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo06_ooooo000oooooo`03o`000?oooooooooo03Go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002;ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`1[ooooo`00?oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0J_ooool003kooooo00?o0000ooooooooool0>?ooool00ol0003o410@ooooo`02ooooo`03
oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Zooooo`00
?Oooool00ol0003oooooooooo`0jooooo`05o`000?nHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0JOooool003cooooo00?o0000oooooooo
ool0>oooool01Ol0003o<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0J?ooool003cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Ooooo
o`;o00007oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo06Sooooo000kooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0Ioooool003_ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`1Wooooo`00>_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo06Kooooo000jooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool2
o`0001gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Vooooo`00>Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo06Gooooo000iooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0IOooool003Sooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1Tooooo`00>?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06?ooooo000g
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06_ooool2o`0001[ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1Sooooo`00=oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo06;ooooo000fooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0H_ooool003Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Qooooo`00=Ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo063ooooo000eooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool06?ooool2o`0001Sooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`1Pooooo`00=?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
05oooooo000dooooo`03o`000?oooooooooo04_ooooo00Gok^k^o`000?l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05oooooo000cooooo`03o`000?oooooooooo
04cooooo00GoMgMgoiRHV?l0003oV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1N
ooooo`00<oooool00ol0003oooooooooo`1<ooooo`05oa0@4?oooooo0000ooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`1Nooooo`00<_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00;o00003oooool00omgMgOo<S8booooo`04ooooo`?o00005Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo05kooooo000booooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool00_l0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0GOooool003;ooooo00?o0000oooooooo
ool0COooool01Ol@413oooooooooool0003o410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0GOooool0037o
oooo00?o0000ooooooooool0C_ooool01OmgMgOoV9RHoooooonHV9So000000cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0G?ooool0037ooooo00?o0000ooooooooool0C_ooool01Oo^k^ko<S8bo`000?lb<S;o0000
00cooooo1?l00006ooooo`;o00005?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
05cooooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0G?ooool0033ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Kooooo`00;oooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo05_ooooo000_ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0Foooool002kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Boooo
o`;o00004oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05[ooooo000^ooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0F_ooool002kooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo05Wooooo000]ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0FOooool0
02gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0@ooooo`;o00004Oooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo05Sooooo000/ooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0F?ooool002cooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`1Hooooo`00;?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05Oooooo000[
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0Eoooool002_ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`0>ooooo`;o00003_ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo05Kooooo000Zooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0E_ooool000_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00005ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0fooooo`002oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo04gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0=_ooool000co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1>ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEo`000008ooooo`03o`000?oooooooooo00?ooooo0ol0000<oooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0goooo
o`003?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ol0003ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0gooooo`003Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co000000?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo000=ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0Coooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMol000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo000=oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Coooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Ko410@oooooooooooooooooc8b<_l00003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0>?ooool000kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`000004ooooool0003oooooooooo`Co
00001_ooool2o`0000_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03Wooooo000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Wooooo000?ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo03[ooooo000?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo000@ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03_ooooo000@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0>oooool0013ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>oooool0017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0??ooool0017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool001;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo0_l00007oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0moooo
o`004_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0mooooo`004_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0mooooo`004ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0nooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`005?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
043ooooo000Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo043ooooo000Fooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0LOooool4o`000003oa0@4?l0003ooooo00?ooooo00Go0000oooooooooooo
ooooo`00001iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000007Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`12ooooo`005oooool2o`0000?ooooo0_l0001gooooo`03o`000?oooooooooo00;o
oooo0_l000000ooooooo0000ooooo`02o`0007_ooooo0_l00004ooooo`03o`000?oooooooooo04?o
oooo000Iooooo`Co0000N?ooool00ol0003oooooooooo`03ooooo`Go0000OOooool5o`0004Kooooo
002Eooooo`03o`000?oooooooooo0=3ooooo002Eooooo`03o`000?oooooooooo0=3ooooo002Eoooo
o`03o`000?oooooooooo0=3ooooo002Cooooo`03oeEEEOmVIVKo00000=;ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0026ooooo`;o00000_ooool01Ol0003o
ooooooooool0003o410@00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1?l@413o0000odA4A?o<c<bfooooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Kooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oV9RHoa0@4?oMgMd0]Oooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0>ooooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`2dooooo`00
Qoooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo1_l00002ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co8B4Qo`000?mEEEGo00000;Gooooo0027oooo
o`07o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8@0@ooooo`05o`000?ooooooooooooooool00000
2oooool01OlQ8B7oQhN7oooooonHV9So00000;Gooooo0026ooooo`08oa0@4?l0003o8B4Qo`000?mg
MgOo410@o`000?nYZJT@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo00000;Gooooo002Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RH
oooooomgMgOoEEEE0;Gooooo002Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo<c<co
410@o`000?lb<S;ok^k^0;Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Different values of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a \[GreaterEqual] 0 \[GreaterEqual] c\)]],
  ", lead to the same basic behavior, but with different values for the peak \
height and trough depth.  (The reader is encouraged to vary the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " to verify this.) Note how, for finite wave amplitude, the troughs of the \
wave broaden and the peaks narrow. This corresponds qualitatively to the \
peaking of real water waves, shown in Fig. ",
  ButtonBox["7.5",
    ButtonData:>"Fig. 7.5",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49783 
%%ImageSize: 920 458 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0010352 0.011853 0.0010352 [
[ 0 0 0 0 ]
[ 1 .49783 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49783 L
0 .49783 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01185 translate
.95238 .47412 scale
920 string
920 458 8 [920 0 0 458 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6B6C6C6A676463636162726B696565616363605A57595957615F5D5D5D5D5C5B56565B5B
55565C5D5A59575C56525B5A585755545556585A5E595B5C55525454505351575259585C
5551555A585759595453525152545758565450525754505354525152514D4C4D59585554
4D564D4E515353515052525053544B5153584E4E4F4E4F4D524A57595B555050484E4851
4C4D4C4A4A4D4F4D4F4D4645484544494C484744494B49544D484A48494D4A4C4E514F4F
53504A4A4D52524B45474E534A4A474F4A4D494E4E4B484B4F4F4A454C47564A51414C43
484C4E4B46434549494A4D4B46494C474C4E44494A50484A4846424644454C4742484E4D
6C648E8AABB4BDC4C7C2B5A9978A7B645C51534F4B4F4547443F49464547404145484E49
48464443444544434449484646434247424B49554A554B5D545F4E58515D4E5857495645
5048504B514A4B53544A44454748464140464B4D4B4B513B41474345404343454B4C515C
525355494B45474244474444474540403F4947444846454F5051535556585B5E595F5B65
584F4D524C504B506764706767594A4A4C4348484B3E3F5F5E4E5A777879718C759D705D
4942424345413D4D3F424A4B423F41403D40474D495A687F8D6F5A574C4F4546423E3F3D
434D4B4A403740545D45454649426051665F6153606379738982938F9E9DA49AA09A999F
9CA89FAC92937B695E474A47424D515B787A928FAB968159634D42403B3E423B3C41403D
3E3B3B403D3F3D3E3F3A383E3D3C3A3B3D3F4040403C3C3E3C393E473D3C3B3C3D3D3B3A
3A3B3B3A3A3B3E4042403D3A38393A3B393A3B3B3A3A3C3E3F3E3B383B40403D3A3E393D
413A3C3E3D3D3D3F42423F3B3A3B3D4041403B383B3D3E3E3D3C3C3D393A3B3B3B3B3B3B
3C3B3F3A41563C393E3E3B37383B3B38383A3C3C3A383737383C3C393738383637393B3C
3A37353438393A3B3D3D3D3D3738393B3B3A3938383B3B3837383734373A3A38383B3B39
393A3B3C3C3C3C3C3D39383A3B39393A3C3A3D3D393A3D3C3C3C3C3C3B3A3A393C3B3A3A
393A3A3A3B3A39393A3A3836383A3A37373A3B393A3B3C3B39383A3D3939393939393939
39393938363637383937393835383B3636383A39383635353939393939383736393A3A3B
3B3A3A3939393A38373738393838393B3D3C3A3837393A3B3A3A3B3B3D39373939373637
3939393735343536383737373737373838383737383736343938373736373737373A3B38
383A3C3C37383838383736363833363B38383A3A
5153545454535354574F584F53565954545756545253514D5452504F50504F4E4F4D5155
54555550545250534C474F4E4C4D4E4F4F4F4E4D524D50524D4B4D4D4B4F4C524E555358
524C4C4E4B4B4F504A4B4D4E4F4F4F4E4C4B484B514F4C4F504C4A4A4A494B4F504F4C4B
444D44454D4F4F4C4C4E4E4B494E494E4D514B504A4B4D4D50464F4F514D4B4E484D454C
4749484545494A494E4E4A4A4D49444845454A4B4F4E464D48444745474D4A4D4C514F4A
4844444A484C4E4B494745414B47414B4B4F48484948474748494B4C48484A4C43464849
44444444444444444746484542474D4B3C444147454841474447464842414B4A4955558B
719E738B7B8098B0BBC0B69F826A584A4D43474852474841434B42464849424245474B46
4545454747464340464642414645414252474E43574C4A49544F47444D45444F544B4946
4049494B4945484F4D45474F4245454241454848474B614F4949443F4446434244434650
524D514C4E4347484848434144444144494542404144464743444444434345464247434E
4440434B474F609098AF9CB699A88E9771795D5457494C4F6E65736A929BA68BA188AE81
6F5C5348404240404341434542434643413E45425D80749F9AB4999082726B66575A5E52
46433E413D413C748F4A3B403D4040615D55514C445F566D58817F8E859C8C8E95859D8D
9B97AB97B39FB59DA083807A767E7D8086A6ABB39593664B3E4445403C3C3B3A363D3F3E
3F3A373B393D3F4345403C403D3C3A3B3D3F4040403C3C3E3C393E473F3E3D3D3C3B3937
373A3C3E3D3D3D3D42403D3A38393A3B393A3B3B3A3A3C3E363B3E3C393A3C3B3A3E393D
413A3C3E3B3A3A3D3F3F3C3938393B3E3F3D3936393B3C3C3B3A3A3B3C3C3D3D3E3E3D3D
3A393D3A42583E3C3C3C3935353939363A3C3E3E3C3A393935393B3938393A3937393B3C
3A373534363738393A3B3B3B3C3B3A3A3A3B3D3E36383937383A39373537383636383936
3738393A3A3A3A3A3B373638393736383A383A3B36373B3A3F3E3E3C3B39373639393939
3A3B3C3D3838373738373634363837353538393737393A393736383B3737373737373737
3B3C3B3A3838393A3937393835383B3636383A39383635353B3C3C3C3B3A393937373838
383837373737373635343637363637393A3A383535363839383838393834333637363638
3B3B3B39373737393B3936343436393B383738393B3B3A39393837373637373735383936
36383A3937383838383736363734393E3B383734
565757575655555655525658555657535157534F53544F4E5352515152514F4D4C4F514F
4C4B4C4E544F4D4C484A4F4E4A514F4B4F504C4D5150504F4E4D4B4A495651514F485055
4E504C4E4E4C5252494D50504F4E4E4F4B4846474A4D4E4E4B4F4F4B4A4C4E4D4C514A4B
4C4A4E464E4946494F504C464A47464A4D4E4A4749535B595453535353514E4A4A4B4B4B
49504E4A4B494545484F4E4D504B4447484245474E524845434D4B424448474741464B4C
49464546414C4A4C4D44403D4441414546423F414950514843444644474A4A47484C4C48
42464A48444040413F4142424346494A453F414244464A453C4046454845524A6A637261
4F525355544E4D799FA79A70594D494943434C54444E48484448434A3D49483C3A3F4346
493D423D46424A433F41454F4C46484246454B4E494B485144474D504C46484E4E474240
47413A516357423F42424947474848424146494A46474A4B47413F413D3C454C46444849
5D5C7865716B5F5752524144454A463F424141413F3F454C4C41413D3E43424B3F403E46
3F413E433F3F7E9EC0C4D4CDD4C2C7A2B19AAD989084706B5B58545C69969BBBA6AC95B6
969A847052504E4043403E4236446E6E5D59637A7C74727D9199A3AAA89790A09CA6958C
816657545B4A434D564A3B3C3B40484B574B44414048524C585E636C6A6B706A655C5667
5C676679638584978A8F93949C8F8C79767F7E715F4B40433C3D3D3E3E3E3D3D3D3C3B3A
393A3C3D3E3D3B3A393939393A3938393B3D3D3D363B3E383C3F393D3C3938393B3D3C3B
3E373B423E3B3B38383D403D3B3C3C3A3B38383A39373A3F373A3E3E3A3737383D3B3B3E
40403C383E3A383A3B383637393C3C393A3C3C39373B3B38383B3A36383636393A373535
363C3F3C393B3C3B37373A3C3A37383E3735373733343939383B3A373639393538383738
393937363A3534373A3B3B3C3D35373D3C3B3B37343536393C3D3C3A3C3B363C3C363A35
3339363A3D39333E3D38373D3F393738383B3C414042483E3D3E3F3E3B38373632333538
3939393937383F3F353235333536363738383939383B3A393C3B383B39383637393A3B3A
3D3D3D3C3C3B3A39373C3F3D3936383C393A3B3A3A393838383A3A373434373A3537393A
3B3B3A393838383737373736383535393936373A3536363738393A3A3837363636373839
36373838373738393A3A383736363637343434373A3B393834373836363939363939393A
3A393939393332383935363D3736353537393B3D
5050504E4C4B49484E4C4F504B4B4C484C504D494D4E4A494D4D4E4F515252524E4D4B4A
4A4B4D4E514D4D4D494A4D4B464B4A47494A49484647474848494A4C4B544F4E4D474E53
50514A4C4D494B47474746454546484A4946444749494C4F474A4B4746484A49474D4849
49474942454445474A4B4A4944474948484948454A51555451504D494844444749474646
444C4C48494845474348494A4A4744464B494E4B4949424349504C45454543443D414445
434140403F47434648434549454343444544454644494A46454A4A464647484747494846
44434142444443414341424443404145474342433F4347473D434E515650574A494A4C49
36464C4D4544445F76808977594F4D4E47444A4F444B4649464B403D3D4544404344403F
3F404449454B4D4A514E4A4B433F494A47424E494F4A4C514F4F5153524D4B4D4C4B4948
4C4C546D675A484242475761424E4C4140494B3F42444647433F434A423F4448423F4140
414856606784858D828774727A6F5A4E4F4A4645454344464B403F3F4348444944454249
42454248433D4E7C82ACB1B9B6AF99AA96AAA1A6A8A59EA29083757864698E7E9C7E928D
A5AAA598827A7467635E4440453B5889959995B6A19978797F78798D9891939FA9A6B09B
AF8A918B82807A736F6E6A685B514E4D594B44433F3D443345434D564C555B534B454246
433B3E41424F576064666A69706762544A4D473F3C3A3C4538393A3C3D3D3E3E3C3B3A39
3A3B3C3C393939393A3A3B3B403F3E3D3E3E3E3D3C3E3E35373C3A413C3B3A3B3C3C3D3C
3F3A3B3C3A3D3E38363B3D3C3B3C3C3A3B393A3C3D3B3C3F393A3B3A38383A3D3A383638
3C3E3D3C3E3A383A3B393839373A3B38383A3A3742413D39393C3E3F3E3B393C3E3D3C3C
363C3F3D3B3B3A3838383A3C3937393E3634393B38383A373537383737393A393C3A3838
393939383635373939383C414339383B3A3B3D3B353537393C3D3C3A3638353C3D383D3B
373534363D3D3F434132383E45413E4A4447494E4D4C4E413B3C3C3A3837373838383838
383838383D3E44443C393B3936373737383839393A3D39373A39373B39383737393A3A3A
3A3A393939393939363A3D3C3836383B393A3B3B3A3938373B3C3B393737393C36353434
34343435383837373737373638363637373637383334353738393A3A3736363636373838
36373837363637383837353434353535373737393A39383736383937383A3A383939393A
3A3A3A3A3737393D3E3B3A3A3736353536383A3B
5656555453504E4C565457564F4D4F4D4B4E4D4C505251504C4D4D4D4D4D4D4E4E4B4848
494A4B4B4D4A4C4D49494B484A4A4C4B494B4C484C4C4C4A4747484B5257504D4A464A4D
4F504A4E5251524A4A4846454648494A4A46454749484A4C484B4C4B494A4B4A444A4848
47444540474A4D4C4947484A474E524E49494846494C4E4C49484746494342484C4A4849
454D4C4746434143444448494645464443444B49484A474C444745414241404241424344
4443424146494446443C40444344424040434646424444424447453F4545464747454445
4B47444346484745423E3E44433D3F46414140473F4B505649484A484942483C3E3E4A42
464352464E54525C5E5E6B66665D5C5B524B4B4B4749454A48544A3D46453F3F45464140
404350454B4450484547484E49444C4B4C4E4D554A52464F554E4845423F3C3B3F3E393B
3B3A42484D4543424248576B6C7C705D575E60494F49433F3C3C404543404244413E3F3D
423F4A424D576B6A9C94A9A4C4B6C9AFAB98827369625D5C656165625E55494645454147
4145444A50393C464F6272738E7884768C7A92959594919A919296A79F968C8E8E999791
9F9CA7ACB0B0A89A99996B4E55494863969399A2ABA5A1A0A68C737C85878F8A8B8D8599
878F7C8A978F8898A49F94998F7B71707C706E6F5F5A49423E463D4A4E626E685C595C54
574737493847363F3E3C413D43413B3441403A3739393A3E3838393A3B3B3B3B3B3A393A
3C3D3C3B39393A3A3A3A3A3A3F3E3D3B393737383F404136353A3A413E3E3E3D3C3C3D3E
3F3D3B38383F4038373A3C3B3A3A3A393A39393C3D3C3C3C3A3A3A39393A3B3C3C3A3939
3B3B39373D3A383A3A3A3A3B4142413F3D3E3D3A3D3B3A3B3C3B3B3D463F383837353232
383B3D3C3B3B383639393A3A3837393E3B383B3D39393935353637393837383C3C3A3737
373838383C39393A3937383B413A393B3A3B3C3A3636383A3C3C3B3A373A393D3D363738
363641353C333D393C4A5451537C7C855C5B55544F4A473B383938373636383A3C3B3938
38393A3B37373B3B3735353338383838383838383C3D39363837363A383737383A3B3A39
3C3B39373534343434383A3A3736373A3A3A3B3B3A3937363C3B3A393938393B3A3A3938
373636353837373737373636373837353536373638383838373533323535363737373736
37373736353537393836343436373634393A3A3A39383737363838363739393738383939
393A3A3A37383836373A3B393736363535373839
4D4D4D4D4D4C4A4849494E4E49494E4D4D4D4C4B4E4F4E4D4B4C4C4B4847484A4C4C4B4A
494848484B484A4B48484A474744484945474A44494C4E4D4B4B4D504D4E4B4847454748
4E50494A4A4849424745454749494643434341414448453E4346474746454545454A4A48
4545454347494946403D3D3E3E44494A47464749464848444142474B49433F4145474645
444D4D4644414043444145464040444048454947484B45474342414142404143403F3F3F
4141403E4545414545424D55444645403F4446453B404243454949454543454847424144
474645423F3E3F41423F3F40403E41464E424B546E6D6954413B3B3B4344524B4B4F5163
555D4F4B40444146454147434C46484B454142404444434C5067685E4E473D3B41403F43
404D454D3A4E484C454648514E494E49474455474C3F42414E473F3B3A3C3F42403F3B40
3E3E47404E4345414047546C7C86746A676A73636E5A4339383A3C3E4442424342413E3C
453F493A43384F435A7C6A8F96BCB5CFD5C3AE9F97918F8FA09EB69DA7858D8473757379
6E685B5A59454C4548434E4749405047514A61726A6A6B77747F8FA8AEA6ACA3BEC2D1C9
CEBDC3C2CED1CEC9C2C19F8882817D6679857D8A8AA3A1A8948879878F908B66705A6F60
6E5A5E62867E6B839FA09094928581819193A1AB9B8983686F574B44475E7078757C8B82
73504644453C383B3F393E3A3F433D3D36373738393835343B3B3B3B3A3938373C3A393B
3E3F3E3B3E3E3E3D3B3937363F403F3D3A393A3B3C3F443D383A383C3E40413F3C3B3D40
3E3D3B393B3F3E383B3C3D3C3A3A38373A3837383A3A38373A3B3C3D3D3B39373C3D3E3F
3F3D38343A39383839393B3C3D3D3C3B3B3D3F4044414043413D3B3E463D363638383737
393A3A3A3B3A39373A3A3A3937373A3D433D3B3A363637333837383A3834363B37363536
37383837423A36383C3B37343836383A3B3A38363738393A3B3B3B3A3B3A373D44403936
3C3D323D373E3D4E7090B78E9A9B997966605049433D3C3338383837363638393A393838
393C404239393A3A3938373538383838383838383A3C383638373639373737393B3B3A38
3D3B383533333333353739393837383A3B3A3939393937363A373637383737393B3D3F41
403C38353737373736363636383A393534383936393939383533302E3435363737373635
363636363536383A39373536393A393638393A3937363738343434343435353537373737
3738393937373636363738393737363535363637
545352535353514E595758554C494B4A54504D4C4B4A4947474848484747494B4E4F4F4B
4745474A4A47494A46484A474944484B46474A4645494C4C494747494A494C4D4D4E4F4F
494F4A4744424844484646484B4B4742484D4C4A525C5544434445464543434446484945
434545464948484747464646454446494842414447454343434446474544403E43484641
3F484945454545493F3C41423D3E434043414645474B47494B4847474544444442413F40
4243414045443F43444758604245454243474947454A4D4A454444434543444745404145
46484845413F3F414647443D3B3F424249534D7E6E8354424B49515A696C7B747B5E5E49
4B3D3F434140393A3E3F4240443F424542414240414549565C79848353545254554B4448
474E534C53585F5C5C514444403D423D424C4F5540483C45484845403D3E44494A4B4A4B
444758555C5150494241414F515143484945514E493F393C41413D394142414142413D39
454B474E4341443B3F3F4E515F688783908C898781776F6B708572916B897A8D7A8590A3
9F97847E6C6E637C62705E5B54605B6B5574708C7D7D797C70737A8B98A6AEBBB5C3C3C5
D0C3CFCED3D2D7DCD6CCBBBAA18D9686748681828392847B6D6861707678754E5042464C
41493C4E59695D68778B82707476807D868EA5B0BAB7B0BBABAA8374444C566A7A8EA39F
815A4A40423C444E3F393B393A403A3E393B3E3E3C3C3F403C3C3C3C3B3A39383D3B3A3B
3F403F3C4040403E3C3A38363A3B3C3B3A3A3C3E3A3D453F393B383A3E4042403C3B3D40
3C3A3A3F413E39383C3C3B3C3C3B3B3B3D3B383637383836393A3C3D3E3D3B3938393B3E
3F3E3B383738383737393A3A383736373B40464A5048423F3B37383D453C353639393A3B
3A383838393A3B3D3B3B3A3837383A3B423C3A39343536313937383B3936373B35353639
3B3C3A393C3533383E3E3B393436383A3C3C39373838393A3A3A3A3A3936343A47463B3A
333B4C4A59476A9CAECFC8D5ACBB8E7C554F3E3A39363835393A3B3A3837373739383738
3A3E41443C3C3B3A3B3B39393838383838383737373A38363A383639373737393B3B3A38
383736353638393B37383A3A3A3A3A3A3D3A383738393837393636383937373936383B3D
3D3A36343737373736363636393B3A3636393A3735353636363535343435363737373635
353636363636393A39373536393A38363537383736353738353433333333343536353535
3536373736353A42423A36373736363535353535
53514E4E4E4E4C4A4C4B4E4E494A4E4D514C4B4D4B4B4D4C4A4949484748494A52514E48
4444484D4946494A47484A474C494B4D4B4A4B4A484B4D4C484442414E4B51504D4F4D4D
444D4B4845464F4E4B4947484B4B49463F4647454E5A5241464647484745454845454741
404645464A484442403F3D3B4D4C4C4C48434142484443474B49433F4242414145494742
424A4945454444483F3F43454345484842434B4844444147474545454346474445444344
4546454341424144424048443B3C3D3E424546443D424645414042454243444442404145
4A4A4949494846454347443B3A424744474D7071816B6E5D5F5A5B5C5F54584C4D3F3E46
3D47384842433E3C3E3D3E40433E3E3F3B3A3A364246454B4653575B63707D85816E5D5B
546454634C5E4A4F48423D4649494E485252604F50444748434A4E49413D3E4047454547
42444B484744474746433F424541384242383E41484441403E3D3F433A3E3D3C4143403F
3D4243454A4347403A4B3A3D44453C434E535D65655D555353574D4F444746454F586277
797B706E6A6A6D858B97968E979BA7A3AFC2C7D1CBD0CCC9B2A3908B968492777F6B7F6F
8F87939FA8AEB7BCCCD0C3BDA6898D908786866E89868E847868585953535B4C453B3F3E
383E374B46514E6362716F5962728C8E91919E9EA59CB5BEC7C1AD8C5C4F4754697D8885
715B4A53495A5B6B45413E403D403B3F393A3D3C3535393B393A3B3C3C3D3C3C3D3B3A3B
3D3E3E3C3D3D3D3D3D3C3C3B3636373838393B3D3C3C433D373B3B3C3C3E403E3B3A3D40
3A3A3B41443C36393B39393C3E3E3E3F3F3F3C39383A3B3939393A3A3B3D3F403A393837
373839393538393837393A393F3C39393B3E444944403C3A3837383B453D373739383839
3A38373838393D413A3B3A3837393A393936383A37373733373636393B3B3C3D36373A3D
3F3F3D3B3736373A3A38383B383C3A383C3D3C3D3839393938383839343A3E3A39353342
50607C79AFA3B3BFDBD3DAA8B990885841403435393537363A3B3C3C393736363A393939
3A3C3E3F38393634363533343737373737373737363938373B393739383737383A3B3A39
38383737383A3B3C3A3A3A3B3C3C3B3A3C393636383939373B37383C3C38383D37373737
373737373737363636363635383A3A383839393737363636363636363535363737373736
363738383737373836353435373735333435353535363739393635353534353736353433
3334353637333740403733373636363636363535
53504C4C4E4F4D4C4B494B4C494B4E4D4A43444947494D4C4E4D4B4A4A4B4C4C514D4947
4749494948464A4C49494A46474746484A46444846484A4C4C4B4A4A4A454D4A44464445
454D494643444A45464646474948444143484B4B4E514D45434242444340414545434742
434A47484343434446484A4B424B4D46404345444444474B4A464445473E3B3F413E4045
474D4A4443423F41424647474847474A3B3D4746454644493E3D3F3E3E4549423E3E3E3F
40403F3D393F4144414143353D39383C414241403E4041403D3C3C3E3F4243403D3F4244
44454545434141413D41403D3E4448484D59496A47634C524C4647494C41483F423B443C
423C393A3D43454445434045403C3E403E40413C4144404643494A5353626D726E5E504E
44514E544A4E464E48484C57564F4F4751514D4A414B4347404A514F4A47474645404448
4C4F4B4850514A45413E413E3E3E3D41424043453F414446423F434A4044403D41444244
42414738503B423C3B3845384A3949393E3F444B4D4A47484C4F4E4B4F474B4146444048
4345404248404F4C6A5F75657F859195A4BFBCC7CBD2D1D4CFD5CCC7B897946D785E6F5E
74665D69707B83838694948A8B8A8C9E8F8772646769748991877E78685C5950524F4E43
41413D506158425B55524E4C515D7B87908F96908F82899C8FAA9B7E584B3F3C48524F4F
473A4746565A626145453F4742434042424043423A393C3A38383A3B3C3D3D3D3B3A3939
393A3B3B3A3A3A3B3C3D3E3E3D3C3C3C3E3F40403C39403B363C3D3D3A3C3D3C3A3A3C3E
383D3D3E403C373A3C38383B3D3C3C3D3C3E3D3A393B3C3B3B3C3D3C3B3B3D403C3B3836
35363739353A3C3A393A3A39403B37373635383C3C3E3E3C3D3E3F3E403B393C3F404143
3B39393A39383C413A3C3B38383A3A373534383B38383A37373737383B3F3E3C38383A3C
3D3D3B3939383A3B39343437393F3D393C3D3B3C3839393837363739373D413D41464B63
75A4ACB6BCD1C2C5A5AD9294768958413A3C34373C3534353A3B3B3A3836363639393939
3A3A3A3A393B3734363432363535363637373738383B38373A38363939383737393A3A3A
3A3A3A3A3A3A3A3A3C3A3A3B3C3C3A38383736383A3B39363937393D3C37383E39393837
37383939373636363636353536363739393736373B3A3836353535363736363636373838
393B3C3B38363434363636363636343336363535363738383A3635363534353839373634
3434353638343436363334373636363637363636
534F4C4D505353524E4A4C4D4B4D504E554C4C4F4B4B4E4C4C4A494B4E5254554C484649
4E4F484146454B4E4B4B4A45484A47494D49454B4A494A4A4A4A49484A454F4D484E4E51
444C49494B4F534A47494D51514E4742494B4F4F4A444346474545474543454947444A45
48504A4A47484845413F41444D5D5E4A3C41433E3D444C4C433E475459473E43423B4151
454B4742434240414046444244403C404642464545463D3B4040423F3D46483E3E3F4041
41403F3E484A454340464D3F4A423E4346454241403F3E40434445453C41423C3A3E4243
43484B473E393C423F3F40404040434545413E433E43423E413C4145483D42393E44403E
3D4547473F43433F403E3A40454143444142413B4042383E3E424150545A5A56544F4C50
495B515F48554A5E4948484C454048464A42413A444F4F4E464D504D484746444A454B49
4A4C4A5349514C494441464043494A43444E5251505359606160626752544B4141413E40
3F443C3B4542373C3B4B3D44383F383F403B3A3D40403F403A40463F4B42524A42413D46
454B484D3F44404A45474C474952535F597764767580838F99B1B1ADB2B4A6A99E9B8D95
908D8595949A9C97A396937C6D676282A5999C7D8153657D88888B8681878C8B80857971
666B6279707A565E5B544546443E4C566365706F7458585A527781663F4242393D423B42
3F3E3E4A4455484450544C5A5555555559504B453B393A3639393A3B3B3B3A3A3A393837
3637383A393838393A3B3D3E3E3D3B3B3D3D3D3C39363F3C383E3D3B393A3B3A393A3C3D
38413F393B3C3A3C403B393B3B393738363A3C39383B3C3A3C3F42413D3938383738393A
3A3B3C3D363C3F3D3B3C3B393D3A383A3A393B3F3F3F3B3332373A393D3A383A3A38383A
3B3A3B3C3A373A40393C3B39393B3A363937393934363B3B3A3B39373B403E3838373738
39383735383535393B393737363E3E3B3D3B353438393938363536383E36333E627D8192
A8A09D7FACA8AD96916C624B4E423D45373A33373C3636393A3A3A383635363836373839
3A393938393C38333532303534343536363737383B3D39363837363A39383637393A3B3A
3637383A3B3C3C3C3C3A393A3B3B3937363536393D3D39353634373C3A34353D36373839
383735343736363636353535343234393A363436393837363637393B3837363636373839
3C3D3E3D393532313839393938373635393735353739393838343234333132363B393735
3435353636383939393937353536363737373737
4E4D4D4F52514C484A4A4B4C4E4D4A474C4B4A4B4D4F4F4F46474A4D50504D4B45474744
46494945504A4C504A464746464B49484B474244484A494745454647444650554D4A4F52
484847454444464847464A5458514640424A4F4B474748484240414142484C46403F3F42
4546433F454749443B3D45454E6059474A4C46473F42474949484848534A403D41464849
454544434241414142444644403E3E403D4C473F3E3F413C4143423F3F42413C393A4048
484240423B42433F424B4A423842484E4539404640403B3F403E474B3841464444474640
433B3E46454444413F41464A4A4846463F473F43473F3D3C3E473D45473A3E3B3A3F4645
3E3F4341404846403F3D3B3F3C41423E44363E383A443C53434F5A4F53525752554B4A45
48464E4A474B484E4D544C4C4F4D545959484545484947534D5F595B4E5545454A474644
4550554C4841424A474B5549495156534E4C4C4D515E586158636172615F5A535A565C52
423C3843393F3E3E3A3B453E4344423E3B4440403D3B433F383E3E3D48423F484644434F
5164655F6447475D6A7779826D6E5A634F5C4F544E4549565C5E61605F6B6E71677F6E82
697C7B878AA1A1ABB5C7CDC7A5A6856275738AB19A9582A1888A857D7C879193AAAFB4A0
A794A398A598999698846B4C43483F414B4D50504D4740443C505F493947464145423C40
39424F3F4C4A4F5B695A5E5F5F74746C6B69635149423F4C4F634C53484B3B3F3D3A3539
3B383B3C373B37363C3C3A3F424242403D3C3D3E3E3E3D3C3B3C40443E3D3D41413F3F42
3E4447454344423F3D3D383C3F3D3F383939393A3B3D4041373D3B393C3B3A41383C3C3D
403F3B3D3C3D3E3C38373839393B3936383B3C3C3B39383836363C43393A413C40393D3C
373A3A35333738373A393838373737383D39383A3936363A3B36363B3E3D3A3A3B3C3D3B
38383A3D3939393A3B3C3D3E333B3D3C3F3D3C423B37383D3E38383C393E444D5D707C80
887A68646C6D727E585141393E3C343438383737373738383A38363537393A3A3A3E3C3A
3C3A373C37343B373538333837363537393A3938353637393A3A393938393735373C3B38
38393B3C3C3C3B3A363A3A383739373234393B3835363838373737373738383936373839
3A3A3A3A393B3E40413F3C3A3838383736353535363738353132383D373434393B393738
3D3A37363635333137383A3B3B3A39383534333537383736353536363635343438393938
3636383A38393938373638393233343537393B3C
514F4E4F52514E4B4B4B4C4E4F4E4D4C4C4B4B4C4E50515049494A4D4F4F4E4C47474747
494B4B494D47474946494D4D484A4643484A4D544B4B4C4D4B49494B4843454844454B4D
4E4D4C4A494A4E514846484C4D4A4747474B4C4A494B4A4848464747464B4E4842414246
4B4D4C4A494B514F484748433E48464145474548454648494848484844413F414546423E
42474A484340434744464846413F3F403E464140403B3E403D3D3D3E42454542393D4143
434343423D3E40434647454239403E403E3D44453C3E3C43433F45463D4446414043433E
413D3E4041444543424142434747433D3A433F41413D41403B433B44473C3F3B3F414343
40444E4C444A47414243444943453E3F3B3B4342464E4D69626D675346464E4C534E514E
4F4B4C46454B4D554D544D4E504C4E4F4C4444404349464A455046473C463C413D404343
454B49403B3C3F46434654513C404341404344443A4541453E423F4A454747475457635E
5547493C4439454341414D3D534643413F484544413F474546473C4741473E4743493C53
80A29EA59D8B827E93A4BEC4B7A9AD8F977C8377726560615A5048413C404A4C4C4B4349
41474D4C585A636A697DBCC1E1C9BF8C6850577A90999BA6918C7D6B6264707B859F9BB1
A6BCB2ACA29FACB5BDAE987C6E674E424445443D4645575855465B5357667781827B7D86
82856C7A647A6B7F5A62607A6E858484775F6754675B61556B6E6D637E7274634A444842
3D3D38413E3B37383E3B39403D3D3C3A39393C3F3A3B3B3A3A3A3C3D3D3B3C3E3F3D3C3F
3C4042414041403D3B3E3A3C3A363A383A3A39393B3D4042393C3B3A3C3A393B383C3B3B
403F3C3F393A3A3A393A3C3E393B3A37373A3A3937383C3F3D393A3E36353A353B373C3C
373B3D3D3C3C3B3A3A393838373738383435383D3E3B39393C38383B3E3C3B3B3A3C3D3C
39383A3D393838383A3C3F403C403D393A39393E423B37393835373E3E3F3F3F454D5150
524A3F3D423F3D433A3A373537393B3F3736363637383737373737393A3A3836393D3B39
3B39383D38363A363538353A333435383C3E3F40373737373839393937393A393B3F3F3D
3A3C3D3B38383C4035393C3D3D3D3B3830363A39383A3A39333435363738393A37383839
39393838393A3B3B3C3C3B3B39383837363635353636363535363739333132373A3A393A
3A383535373939393637393A3A3938363737363637373736323334353637373736373837
3636373937383837363638393434343536373839
4D4B49494B4B4947474849494949494A484746464849494846454445474848484D4A4A4B
4C4B4A4B4F4946433F4244404B4C49444342424649484A4E4C4645484F46434646474A49
4848484746464849454546464543464B43434242454948464644464644494B4646444343
454644424847494845484A443E3F414344434345424243444443413F4643404043454441
43484C4A443F404244464745413E3E3F3F403B4142393D4546423F4042403E3C3B40423E
3E4344423F3B3E4748423E41474A423E3F42453E393C3C43433E43434246453F3C3F403E
48484440414444444341403D4447443C434847433B3A403D3F453C44483F3F3C3F403C3E
3D414D473B42423F3F3F3E3F493F493F4C445E5758575360555D5348444349464D484B49
4947494442423E3F3E444043463F3E3A3D3F413B3E4844403F453E443C42393E38404241
43433E39444441454541433C4343413E3E4243423E434342403D3B3E4243403E43424B48
4545404243484B534D624B765D87627A606B6E6F665A554D5A4B4543423E434747523F45
668898B9B7B8A0ACB3CBD1D0DADCD2D4C2C3B6B69C9291948B7D70675853494E47434747
444337443A403B4A455B6CA5AACBAB90604E3B54505F5E6869675A4A434044504F5A7F6C
9481997E706E7B8792918C7E84795A474749483C4F53577C6E79849E98A5BAC6C0BABFC7
CDB3B790AA76817174617161717A7C877C766F7B6A765A4D5559465E678C8F917B8D8E93
836A6D686C614D3E3A3A3A3B3D3C3A3736383B3E39393A3A3B3A39373C3A3A3C3C39393B
393B3C3B3C3E3D3B393C383C3D3C403E3B3A39393B3D40423E3C3D3E3C3C3C3840423E3B
3D3B383B3D3B3A3A3B3B3B3B3A3B3B3937393A363B3C3E403D38383B3A373B383F3C403D
3A3A3B3B393636373A39383838383838353739393A3D3D3C413E3C3C3B393838393B3D3C
3A393A3B3F3D3A3837383A3B3E3F3C393938373A413B37373634373D3D3D3A3737383836
3C3C38383B3A36383C3B3D3B37373B3B3B3A393A3D3E3C3A383838393A393735383B3A38
3939393D393739363538373C3A3A3B3A393839393A393837373738393A3D3D3B3A3B3B3A
3E40413C3533383D3A3A3B3B383332343A3C3B39373736343A3A39393736353438383839
383837363938373737383A3A393838373736363637363637393936343735353738373636
3A383635373A3C3E34363839393836343838393837373737363636363635343435363737
3636363635363736363638393635353434353536
51504E4E4F4F4D4B4D4E4F4D4C4C4D4F4F4D4B4A4B4B4A494B4A48484A4C4E4F534E4C4E
4D4946484C4A4A49494F50484B4D4D4C4B4A4B4D4845484E4C434044494443484946423F
45484A4A484645454445464644434446524F4B47464645434B494A49474D514C4E4B4846
4645434249454444454D514B4742444743434541444446484947423E4A47413C3E424544
4243444545433F3C41434443403E3E3F3F403A40433A3F4847413D4042403D3D3D40413F
3E414343413C3E46463E3C3F3E413B3C3F404138414340464642494A4244423D3B3E403F
3B3D3B3B404242444241433F4C505147464748443C41494347493F4448403F3D3E3F393D
3C3C453A3E4243403F403F3F49474D5D57676F6E51515353464C424647454842453E413E
3C3E444747453F3C3A3E3C4245403D36393E3F3B3D44413A3D3F3A443E3F373B3F47443E
41403D3E48483F424642423C4244433E3C3D3E3C3F3F413D403B3C3B42443E3C3A363D3B
39423A423B40353E48454E55585D5B6352595D5E5C5A5C5D696C5B745B6857664B4F4847
414C536073768594BDBBC8C8D3CFE3D0E3C9D4C9C5BCB9B9AFA7A7A895927C826D615E4C
4E43374A444741505C61746E7D72745648434B4A473F4547484A413B4446403E39474551
43544D484C4647494C5257545F615146484F544A4F465F6E95899DA3B5C0C8C9C9CFD8DD
D9E6B2CD9AA4757D737B596F5C6A606B9295B0828D6869534C41404851607276767A9087
7F85879E9E9073524347483E42403D3A39393B3D3C3B3A3B3C3B39363D3A393B3A373739
383837383A3C3B3A3E3B33393F3E3C333C3B3A393B3D4042433C3D403D3F403944443F3A
3B39373A3D3B3A3B3D3E3B383A3A3C3B383B3C373A3A3C3F3F3C3C403D3A3D39403A3933
39393B403E3836393A393938383839393B3D3B37373B3C3A3E3D3C3B3939393A393B3D3C
3B39393A3F3E3B393737373838393A3A3B3A38373A37373A3A38383B38383838383A3A3A
3A3B3A38393B3B3C3D37393A36393B363C3A393B3E3F3D3A3B3937363738383836393939
3939393B393839373638393C38393938363536373B3A3938373737373A3B3B3937373839
393C3E3C383637393D3B3A3A38363B4346423B35323234343838393A3A3B3A3A37373838
38383737373737373738383838383837373736363A3A3A3A3A3836343A39383837363535
3B3938373738393A34353738383634333637383836363739383837373634333235363738
3837363634353636353638393736363535353636
4B4A4A4A4A4947454A4B4A484645474947454444454645444444434344474A4D524D4B4D
4C47454641404243444C4E464443444444474D504C494B504E44414545464A4E4D46403F
3E404242414142434746454546464543454442413F404346464444403D4247443D3C3C3E
414445463F3B3C3E4046473F444043444043474145444546484744413F41413E3F41413E
3E3F40434646434140414343424242433F443D3F423F434647413D40423F3D3F403F4042
413F404441404041403E3D3E44454248484243413739363C3C383E3F3F41413E3D3F4142
3F3E3F43454240404441494E656662514A4444413E45484248473D3F433F3D3F3E3F3B3E
3D40463D4645423E3E4750537163776A73647162544F4D4B484D3E43423F433D423D403E
414140404140414040413E444643433B4242403F3E3C3B3846423E453F3F3C414147433E
414142484448414142414A4D383F44413C3B3B3B4641443E443F44403E413B3E3A383E3F
393D433844393C3D444242453A3E394440424749494B4D5162645F5C5E575B6D7B7E7978
675E504C4D4C4453566F7CA2A9B5B5C7BBC5B8BBB5B3BAC0BAB9C4CDCBC0C6A8BE9AB28D
946B56414A3A4C5661766E776571635045505E7A6E846A6A7472635F758576605544473D
46404941403C3D403C3F413E4351534F4E56635E4C4D3E59618889999CA5A0989DA4ADBA
D1CFD598B67F917F8476836265564B5C7094A1A68EACA2A76F4B373B3D404140484E4147
4C54747B887C6B544345443842403E3D3C3C3C3C3D3B39393A3A38373E3B3A3B3A37373A
393736383A3B3B3B403F3B444D4D4D443C3B3A3A3B3D3F41423A3A3D3B3F403A3D3F3B38
3C3C3B3F3737383C41423F3B3B393D3D393D403A3D3C3C3E3D3A3A3D3D393C39423D3E39
383A414847413D3E393938383839393A383D3E3C3B3C393336373838393C3E3F393A3C3C
3B393939373839393A3A3A3A3636383A3A3A39373737383C3C393838373738393939393A
3B3A3936333536363E37383A383B3D3837343334373937343A3837373839383835373A3B
3A3939393739393A3937393A39393937353435373A3A3A39383735343636363737393D41
36363637393A3A3A3C3A393A38373D45413D37343335393C37373839393A3A3A35363738
383838383436383A3B39373537373737373737373C3E403D3835353737383938383A3A3A
383939383736353535353636363534333234363636363839333435363737373737373839
3939373734353535353537393737363637373839
50515151504E4C4A51504F4E4C4C4D4E494847494B4E4E4E494A4A4A4A4C4F514C494849
4A4847474F4A4846444749444D4B4D4E4C4C4D4B4948494D4A444245494C4D4F4F484447
48484746474B51554A484542444848464C4A48464342454A4D4A4A453F4347444D4C4947
464544444B47454342474A4443414546424447424443403F404243443C41444142454642
43454846434142434142444546474747414942404241444245413F40403F3F40423F4044
433E3F444143423D3B3D3F3D43433F433F363A3D3A3E3E45453F42423F40413F3F404244
3F3D444D5155554F49424D5A7A75684F4B41403D3E423E3C413F38393F3D3C403D3B3E3D
3D454A48434345474B576263696264665B605A5650443D43555C46423D3B403C433E4341
4848413F3C393C3B413F3B40403E41393A3A383F424045464744454B454240403B3F403F
4243444842444246464449443D454B47403D3D3E423B3C373B383F3B3F423B403A363839
3F403F3A3F42474A4A4F4C4B4B4D435159575F656F7B828B84917A7E656754677385858E
93938998867773544F4246504D575669606C62665D5C667278869FB2B5C7B4CEBAD9C9C1
AAA17D9A718164709C9DA18AA598A7847C74B596C6A3B29BB1ACA09EB6CAB38B6746453B
473F433838383B433D403C38354347443C404F4E4443523F4F49524C50585452595A637A
88B39FB8A0C8B1BDB2C3ACBB9E9C868A7572947A97A7D1C4B4806A4C4E373F3E433A4242
4F5D4F4D4B3D3F443B3840413D3C3B3B3C3D3D3C3C3A3836363737373F3B3A3B3A38383B
3A38383A3B3A3A3C383C3A3E3F3B3D383B3A3A3A3B3C3E3F3D3837393A3C3C383B3D3A39
3C3B3A3E39393A3E41423E3A3B393D3D383D423B3F3A37393E454F585A524E43453C3A34
3E3E3E3E3B3737383939383839393A3B393B3B3A3A3B3937393A3938393C3C3B3A3A3B3B
3A3939393737393A3A3A39383A38383835363A393C3B3A3A393837383A39393A3937383A
3D3B3D3F3C3A3B39403D3E3D3A393A3838363434353736353536383A3C3B383536373B3C
39393A38373B393B393639373C3B3A38373637383A3A3A3A393735333A383738393A3D42
3F3A34333537383739393A3A383536393836363838383A3D3A3937363534343435363738
393939393336393C3C3A373536363636363636363C3F403D37343639393B3B39383A3B3A
343638383736353537363635353434343133343536373839343536373737373739383838
3939383734353636353537393737373738393A3A
4F4F4E4D4B4A49494C4B4A4A4B4B4B4B46454546494B4C4B454748474646474948494847
484A494748434446424345434845494D4C4C4A4346464748474646484748454649444145
4444434344474C504648474343474B4B45413F4143434649464647443E41454141414243
4547494A4C48453F3B4046434543484E4B45444646454443424345464449484240464948
48484845413F40424142434446464646444B43414340413E3B3D3E3D3F43474843424342
414041434143423D3A3C3E3E3E413F42413D43433B3E3E44443E4242444342413F3F4143
4240484C4C5C614E4C424E5974665B4840393B3C41423C443D3C393A3F3D3B41423F4B45
414B4A4C454750565A636864675B65545C52544F4D4841485A573F393E3D423D433E423F
40454346443F4441413E3B403F3F453E44443E413F383C3B3B3C4347403D3B373A3B3F41
404041403E3B3B454545483A414648443F3E3D3D47404240404248454447404943404041
3843496268888E9684977B9C7CA07384686266676A6B64675E605A4C4B45464A575A525A
62727B8E9A9487806D6B594F45444543464344424540444B494A525970739D8FBEB2BEAE
AB9AA495A193A9A9AFC6ACC4ACC0B0A683989ABC9DC2A9B2BCB8B8BFCFDBC190563F3A3F
3C47413D403E3E4641494744404443423B3E494544444144394C4C584245444446434551
47568179ABBDDCCED9D0D8C8CDD1C8CCBBA4959290BFD8DFD0C2AA98614D333F383E3C4C
5D6263545D4B545F4A37393B3F3C3A393B3C3D3C3B3A3938373738393E3B393A3937383B
3A39393C3B39393C3639373A3A383C3A39393A3B3B3C3C3D3B3B3A3A3E3C37363A3D3B3A
3C3A36393E3D3D3E3F3F3C393D383C3C353B41393A3A4150657C92A1B0A49981735B4E41
4646433C3837373739393838393A3A3B3C3938383838393C3D3D3C3A3C3E3C373B3A3A39
393939393A3A3A39383736353A383A3934353A393D3C3B39383839393A38393B3A383B3F
3732373E3C383836353635373D3D39383D3B3837373738393335373A3C3C39363A383B3B
37373B39393D383A3834393636353536383B3D3E3B3A3A39383635353D39383A3B39383A
433F393534343536373A3D3D3D3E3D3C3636383A3836373B3A3837353536383937373839
39393939353638393A3938373535353636363636393B3B3A383637383A3D3D3836383938
353638373635363739383635343435363434343537383938363637373736363539373636
3838383736363736353536383737363637383939
5352504E4C4C4D4E4C4B4B4C4F50504F4D4B4A4A4B4C4C4B47494B4A48464647494B4A46
474A49444743484F4C484847524B4A4B494C4D4647494A4A4A4C4F50494844454C484346
42444545454445463E45494644474B4D4E464042464644454345494945484B4742434445
4647484947474A47424346413F3C44505043414A3D404444423F3E3D464C4A423E414341
44403C3D414445453F3F404142434242464B4343443E3D3C3E42423E3C40434342464540
3E4244424242413F3C3B3D3F3A413F3E3E3C3E363F403D41413D4446494744413E3D3F42
43444D4B4C6771564B424E50604C4B44413D4040443F37453F3F3F3F423F3A414F4C5F56
4D52494C47484E5253595D585850534749463D3E41433B39423F3B473F3D433F453F4240
3A413E413E383E3B3B39373E3D3F48423E423D3F3E393F3B3F3E43433C3C403E413D4042
3D3C3E39433D3B3E3536433C43444340414546454D484A4C4B50565351544E5953514F50
4E546D7A8D96A198A192AC8EB295967A6F5D5347444540463E4242424045413B453C4450
3C444E4C49484A51525056495149483D443D43404940434D50515455535351555C7D788F
7884889F92A9B0BFC7CBC7C0C7ABAA8FA092A793BAA9BEA7ADA8B1BBC2C7AF816C57604C
4842463E3F3E404F5163676846423E4343474F4758424440403D3A3D41414142464B4941
3F3F4B5D71B4CDCDCAD3D1D4C8D4D0D5CCB0AC9EAFBAD1D9DDCFD7B8AE81624A3C3C3F3F
47565D6175697A86684B423B44413C3A3B3C3D3D3B3C3D3C3A393B3C3D3A38393937383B
3A393A3D3B37383C3F3D35373937393338393A3B3C3C3B3B3C413F3F433F36373539393A
3E3C383A3C3B3B3C3E3F3F3F3E383B3A33383F36464F64819EB6C8D4D4CBC1AA98796655
474F5453514F4A4339393839393A3B3B3A37393D3C373537383A3A3B3F44423D3C3B3938
3939393A393838373738383934343B3D37373A3838393A3B3B3B3B3A3836373939373A3F
3F3639403C3635343A393339494B3F393C3B38353435363836353537393B3B3A3D393B3A
34363C3A3B3E3739363239373A373534353637363C3B393736363636363334393B393737
3A3B3C3A3837393B3C3E3C3736383733363536383634393F44413D393736363739393939
3939383737373636363738393535353535353636363636383939383635393A3636393C3B
38393937353435373B3936343334363737363536383A39383132343638393A3A39373535
3637373637373736353536383737363636363737
5055535053514F535050504F4D4C4C4C4C4B4A4B4C4C4B4A474948494A45444C4C4D4D4B
49494A4C444D504A474A4A45594F46464849494A46464747484848484C46434548464443
42464745474C4D4A45464D454247454A3F4446433F4041413D4644404546444743444647
4746454443424141434444423D3E40424342414042403F41424041433F44443D383B4042
41454441403E414B4B3D47473C3E40434045434144423F423B3C4140393D434042424140
4346423C3D43433D3D434541453F3A3B3E41474D4A4846423E4348454D44493D463B4A4F
42484842434A4A443B4647413F3C3B413D3D3B3C4040434D46413B3D403B455E626F635A
4F4A3D444440424B4F4B494B47444741443E423F3D413D41403A403E3B4043403D3F4244
383841463E3B3E3D4041434342403E3C42404043423F3E3F353A3E3E3C3B3D403E3F3E3D
4045433E40373F3C393F3B3A3B3E413F3D3D414548404F54948B965D666475657C78816A
6A7E79928997998B7676738F869F98A1939B84816D6A58514D535255545E4A4942473E42
484545423B3E4C3D3B3C43453D3E4040414345464037435F8BAFB1B0BDA3967565668890
91A4BAA8BAB9C1CFD3D0CDD3C2B69BBAB6C2A7B2A4C0BCB89B989A949F9C978A8D819B89
A88287725E654E5855635C56503F45474354484D434748534C4B444A45403F4B4F4F5550
4B45404B7672A09AA29DADB9BFB0AFAC9D9491888DA2B8D2DAD8CFD2C6C59C704A503D43
433E524C717592847E6F5C5A495545483C403B41433E3D3A3D3A3937363940383C474344
3B3D413E3D3E3A3635393E3E3B39393B33363D3D383A3D393638393B3A393736353A3D3C
3735393D383C3E3D3E403F3C393A3B3B393A444E464D6C8B9194958C817D756A60585351
505B777E6F5843473F3E363B403F413B323E4240403D38373738343843423A3838383737
383A3B3C3B3C39353537383637383939393838373634363D413F3D3E38383C413F39383A
35383D413C35353A3538383F474138393633373A37393D393A363234393E3E3C38393736
393E3C373A3938393A39383630323435353536383436393631353B383F3B37383B3C3834
36373838363636383235373633353C4336393B3935353A3F373737373738383935343332
333536373537393B3B393735343333363735353734363835393B3B34353B4143403B3736
353535353637373733333839343438383334373838363432343835343837353834343536
393A38363733313536343435363637383839393A
494D4C4C4E4A474C4747464648494A4B4B4A49494A4A4947454847484A45434A4C4A4744
44464A4D4548474447535E62554D45454747474742434445454443434743424547444241
424244464746454644454C46444A474A4146474441424444404545414242414143444546
464544433F3F3F41444647463E3F404142424242423F3F41403E3D403E40414142423F3B
3D464540414344474A3F4243464B454443464341444340443B3C41403D43494743434241
4244413C3C414442424545413E3B3D444A4E5256494646454650585759586155584A5355
4F4B44404143423F39403F3B3D3E3F423B3D3C3E413F3F46414241424447505E4E58504B
44443D43443E3D424441434840414840413A4042444842423E3A3D3A3C4143403D3F4041
3A373A3E3E3D40423C3D3F43444342424240414343403F413D3E3F3F3E3E3F413C434845
403F3E3D3F373E3D3C4240403D3D3D3F3F3D3C3C4652649CA9A473484556526D577D6D71
7C7E927E8E6B8976776D85778B85918382867782858A7D75778775957CA188957A816D6F
544C383C383B443C443F3B3F4342403F3F4142423F3942527398ACBAC6C8B4C09BB4B5C4
C3C6D4C8CFD1D8DCD9DADCDACFCFBCD0C9C0C6A3B3929D7F7C757167696365616872708F
829B8E9D989D909E95988D896E6978847C7E604B4E3843495B515C554C49475052535B56
535F5B62585A6975666D8197ABA6927C787E8575727C97B8B5B4C3CADACEBFA48C816255
4A3F4946505E6F8E869A8998939484726A584F443839393F3C433A3D3D3C40383843413F
393C3D393638393A373B3E3E3B393838383A3F3E38383B363B3B3C3B3A38373734373A3A
39393B3D3D40403D3C3C3B373E3E3F3F3C3B3F4645414A5454555854484644424140403F
4F5261615342353B3A3A34393D3D413C363E3E39393836383E43403C41423C393A393838
393B3E3F3A3B3A37373A3B393637393A393938393635373C3F3D3B3C3A3A3B3D3C393839
3636383B3C3B3B3C383634373C3A383B3734383936373B393838383838393A3A3B3C3936
37393834373635373B3E3F3E353637363637393B3B393A3835393C36363738393B3B3B3C
3B3B3B393737383A3C3E3F3C38373A3E373A3B393635383B383838373736363638383737
3637383A3B3A3A39393A3A3B363333363737393D2E383C46424C4C5155534E453D383636
373738383737383936333638363739353536383939383635353835323534313532343739
3835353736343438393635363737373838393939
4F505153544E4C514D4A4848494B4B4A504E4D4D4D4D4C4A4D504F50534F4C50524F4B48
48494B4C4C4B49484A4F5458514A454647464444494B4D4E4E4C4A484746474B4B474546
4845484D4D47454749494C48464844434447484442454748454648464343454242434445
454443424241414344444343424241414142424347454445454241434745464848443F3D
3B474740424745434244453F3E4241454443403E404040433D3D3F3F3E44494740424341
4142413E3D3F4143454645443E3D3F44494A4B4D494442403F4549454F50574C50444842
4C433C3E424341404044423F434441404446444346434248414546403A3D413E3C413D3C
383D3C3E413D3C3F3E3B3D434645494040383D3D404643403E3F433F3C4043403E3E3F3D
47423C3C3E3D3C40403E3F43433F3D3F46434242413D3C3D413F3D3D3D3E3F413D434745
40404244443E41403E42403F413E3E4141404246706CA1AAC8916F3E45404C474A4D473F
46504C5748454E5151504A594460535452544A5257544E4B59556B5D7C6A8379867E7F6A
6B4F443F3C3D4344574B3E4547434141424241403C3B40434A565D668F899F879F8BA7A6
A6A0A9A8A3ABB4B4CACED5CAC9D3CDD1CED3C1CEADB096888373665B5B534C454745444E
4B616273757974867F8280889BA8BBCECACBAA88704637434249524F4E4A424449597175
80676C415846574F4E575D6A7A8A7D68657783685F647C928992ACC1D9D1CDC9CEC0A380
6A65625D5C546B729692AAB1BDC2C1ADAF96907B6F6261454A3E3F373B383F3D3B44443C
4144403A383737353A3B3D3D3C3A38363A3B403E37383B363F3F3F3D3A3838393B3B3C3B
3938393A3F403F3C3A3A3836403F4042413D3D3F46403D3E3C3A39383B3A3B3D41444544
403F46443E39353C373934383A393D3A3D423F3A3A39393C3B423F36363A38363637393B
3C3C3B3A383A3B393A3D3E3C35383B3B3A3939393637393C3B39383A3C3C3B3938393835
3B3936373B3E3C373E383739383A3E403836383834353838373A3D3B3734353837393937
3638393A3E3A37373A3D3D3C3838383736373A3C403B3939383B3B3431363B3B3A393C40
3E3D3B3936363839393A3B3A3736373838393A3936363638393939383735333238393A39
373638393A3A393838393A3A3835333637393D413E475F5F675961625852483D36333436
393A3B3B3938393A39343437373A39333435363737373737343735353839383B3837383A
3935363B37363738373434363737383838383838
4D4B4C4F4F49494E54504D4D4E4F4D4A4B4A484848484645464A494A4E4B464847464545
464645434343444747464444474343474B4B4B4C4547494B4B4845424040424544414143
44424447474341423F404345484A47464447474443464849444247494344484342424343
434242413E3D3F4345454648464542414040424243403F403F3D3E40423F3F3F3B373B41
3F474641444643413F444743444C4E4B433F3B3A3B3B3D41403F3D3B3C40423F3D404240
3F424342403E3D3F414446484542403F403F3E3E433E3F41414545404844433A44424237
3E3B3A3F444543423F4447474847423D4445413E41403F4445474B463D40423940424241
3F4343403D3D4144413C3C404943423C444145423B41413C3C4347443B3F413F3E3F3E3C
4E4D4440423D3A40433F3F43413B393B3F3C3D3F4140424541403F3E3D3E434949443E3C
40454747464242404041403F383A404543404650647C7CAD90AF857F5C4B50434644433F
3F3D3E3B453D4A4445383A433747414746484044463D3E413E453C51434A43404447494A
4B51454A4541464A5C4B3C464A454245484744423D3E424445433C393B4B4053475E596D
56535B635660696D7E808B7D838E908A9D8FB1A0C7ADC9B4BAAE9E918C806E5D5F4E5440
4C46484651564B514F575E75A1BFCAD6D5D6C3AA8E613E49445553504C4A41414A648894
A8917A4F434545474A5C66624E5A615E595E6756535261646A838DADB1BEB1B9C5C6BC9C
96A696818176616E7484929EA5B4BDB6B9ACAA9A9194817665634C3539323739353D4035
383D37373D3C39333B3B3B3B3C3B393638393D3B373A3D39383A3A38363536373E3F3F3C
38383B3E3C3C3C3A3A3A3A393D3C3D41423F3D3D3F3E3C3D403E39373B39383A3E403E3C
3F3E403F3C383536393B363838353937363B393738363437353B3D3C3C3C383436363737
38373737373A3C3A3A3C3D3C36393C3C3A38383936393B3B393636383D3E3B3737393732
373736353A403F3A3833373934373C39373738363434383A393B3D3B3633343634383B3A
38383A3D423E39383A3A383638383836353537393D3838393638393434383C3C3A383A3D
3B3B3A383534343537373636353534343838383838373636383939393835333134373938
3533343634363738383736343936353738393C41404E546553534952423E393432323435
393B3D3B3837383B39353639373839343232323334343535353636353635343439333033
34313337333435363536383B3838383737373737
524F4F514E4C4E514E4B4A4B4E4F4D4A514F4E4D4E4D4C4A484B49494E4D48474646484A
4D4E4D4B494746474848494B4C494A4C4C49484946474A4B4B494643474648494845464A
484B4B49494C4B494444454B4E4E4C4A4446454242454747434045484342454242424242
4241404046434344433F3E4149474441403F40414845434545444548474240403F3F464F
4547434144433F42443D3B3D44545745443D393B3B3B3D4041413D3A3B3E3D3A3E424340
3E3F41403F3D3C3D3F414447444341404041403F403B3D4244484B484944413A4445453C
3B3F414040414140373D4445434343404043403E41413E40414145443C3C3F3A3A3B3D3B
3B3C3B363A3D4245423E3E405048453C413D413E3D42423A3940413F3A3D3E3E3F41403C
44484644443F3D463F3D3F43444141444A464343413F3F42404042423F3E475253473B39
3F44444241413E3E40414242383D464B4945474D5B57825C8D6F977B8E7D7E655C4E5455
504D50445B576457685451473D44404A43443D4347404042453F42424E3C4136404D5049
404B444C453E45485447424E534A44464949484845433F3F40403F3D393F413941393B41
3C4141493E42424643424B41494C4F494B524B7061847A848084827D7B7F7A7274736672
6170575848554C4C56667291B1D9D9D8D2CEC4BDAC8A766B7C70675556564F4B4853686B
8787825D473C3C3E3B567575473E45474A434F5149435253506968797790878E94948F7C
8FB5AE98A69B7976707A8182868E868A858F908A7F7D7761796C7550483D3B3A33394136
37403839403C3B353A39393A3C3C3A3837373B3A363A3E3A38393A3A3A3A3B3D3A3D3F3C
393A42493A39393A3A3A3A3B3D39393D3F3E3C3C3E3D39383B3C39373C3A393B3E403E3C
393D3E3F3F3D3B36393C383938353A38373A38373A38363B3D3735383A39393A3C3A3734
33353739373B3C3A383A3B39393B3C3C3A383737373A3D3B373536373D3E3C38383A3732
383C3C38383B3A373734383935373B37363736353536383B3B3A393837373636383B3E3E
3A3737393A3836373A3B3937383939393737373838363A3B36363A3938393A3A3A3A3939
393A3B3A37353434403E3B39383737363736363738393837373738393837353334363837
343234363536373737373635393636383938393B3D3741373F303B3E3938363535353636
383A3C3A3736373A37363A3B353537363232323233343536353536373736363537363739
363234382E32373A3C3E40413837373737373737
4E4C4C4B47494D4D4E4C4A4A4C4C4B494B4A484849484746454845454B4B454347464444
444545454747464342434444504E4E4F4B454243414243444443414043424243423F4145
424646424347484442423F44443F3E3A434544414144454448474A4C4845454542424241
41404040423E3F42423F41464746444241404040413E3E41413F404247413B3C3F414242
4746424043403E434140434547607F80473E3C40403F404140433F3C3F413E3D4144443F
3C3D3E3D3B3E40403F4042423E4041414244423E443C3B3D3D4146454242433F413F413E
3F4444403D3F42433F4145423D4045443F44444347453F3D4B494A473F3A3B3C3E424541
4643423E3B3C3E3E3C3C3E424341443C3E3A43463E3F423B393E3C3D3B3D3D3D3F43413D
3B3F4243413C3D453E404143454748484B474445444345493B3C3E403B39414D4A433D3E
4141414142443D3D403E4040454342434445454344514C5D4C605F61666F677E65756A70
5C5D6B5779758D8596898B68645A4A4A484F464A453F3C3F49423D3E4B4042443F495042
4546484A4640443D443E42515C4F44434545464A545854534E4748463C3F4139423B3E42
454D434946463F3E403E423D4541423F403F42474A534F534E514C4B49545657545D5368
627A737865706C677077788FAACCC8C5C0C2C4CDC5C5BDB6BAAA9A9B9999938C807B8380
918FA583936F735A4748585E443B3F3D4341424741454B403A4648464E5F6B707473685E
6E8C968EABA098849486978A9082606560797E7C726C524F54575743484340423D3D4239
3D483B3A3F393A373A39393A3C3C3B393A393B3A373C403C3C3B3A3A3B3D3E3F3B3E403E
3A3A41483B39393B3B39393A3F3A373A3C3A39393E3D3C3B3B3C3A353C3A393A3C3D3C3B
3A403D3B39383932363A36393A383D3C3F3F3B3B3E3D3E4442353339393637393B3B3C3D
3C3A3837373B3C39363739383B3A3A3A39383736373B3D3B373738383D3D3C3A393A3836
383C3D3A373739393C3B3A39383C3E3C363735343738373A3C3A3737393A393739393B3D
3C39383A3535363739393938393B3C3C3B3A3A3A38373C3F39383C3D3A3836383B3D3C3A
393B3D3D3B3938383E3D3B3A3A3A3B3B3737363738393939373738393838373637393A39
373637393B3938363638393B3937383A3A3736373C3B31392F39343B3938373636363839
373839393636373837373B3B3433363535353535353637373633353635363937383E4442
3A353639383D424342413D3A3737373737373737
515153504B50544F504E4B4A4A4B4C4D4E4D4C4C4D4D4C4B4C4F4A4950524C494C4C4B4A
484747474A50524E4C4E4E4C4444474B4A47474A48484747474848494746464847434346
45474848484848464446434A4C464946434544424244444247494A4C4D47454843434241
4040404045403F42403B3D44424343434342414042424448484441414845424144474540
4246423E414140433D4749453B496D7C483E3E44434141413F44423E42423F3E4143423E
3C3E3E3D3C4245403D3F42413E3F3F3D3E413F3C443D3E413F40454541414241403D4044
4543434342414245484645423D4145413E43403D41413B393D42423D3936373C3A41433C
474241423C3C3C3A383A3E414243484040393F413C3B403C3B3F3C403E3E3D3C3F43413C
3F3C3E403D3B3E403E424340404444404B47434342404246403C3C3E3C383B43403E3E41
413F3F4145483E3D403C3E3D4243403D414746404539523E53455751595C6360634E523E
404F415146656071728885977D9157644E584C524F595D6571745B6858614C665162536D
596B5A6651514C384443485A564B4344444141453F4A4F56534B4E4A4144393F353F3941
414A41414143423E3E413E3C443E3C3F353C3E424A564D574A463E413A3B393F3B3B3D39
50485A4C5F5B5C5A5856505C62706E75737D8690879A97A69F9E95B0BBBBBBC0BBBBC7C9
C8D0D2D4CAC5AFA37D67574D453B3D3E48504349434A47424645495251586675767E716F
737981728488798F889F9FA9907453535B6B757068525B556B52524A44443E403D3B403C
3A43333A4B4949403B3A3A3A3B3B3A393A393B3B394045413F3A3533343739393E3F3F3E
3C3C3C3C3A393A3C3C39383A3F3A37393B39383838373D3F3B3E3F364442403E3E3E3E3D
323C39373638403A363835383A393E3C3B3B37383C39383E3A373F47433D3934373A3E41
413E3936383C3C3835373A3A3B383637393A3938373C3D3A38393A3A3E3C3B3B3A393A3D
35353638393A3E42393A3734373B3938383935353A3A36373A39393A3B3B393839353539
3B3A3A3B37373837363637383A3B3B3B3A3A3B3C3935393E3B3A3C3C3A383737393B3C3C
383A3C3C3B3A3A3B3637383838393A3A393938373738393A39393938383837373A3A3939
38393A3C3B3A383636383A3B3A38393B3B3736373A383B343A353833363737363535373A
36373737373738383936393934343532353636363636363638333435343A4141484B4840
3D3E3C384A4A47413D3B38333536363637373838
484B4F4A444B4E4649484645464B50544B4A494A4B4B4A4946484340484B46413F43484A
4A494949484E4E443F424440444547494641414444434141414345464543444746424041
434143484842404241423E45453E424043454543434544413C41414448433F4643434241
40404040423D3C403F3C40483E404244444442413E3F444948423C3A383C3E3C3E444645
3C45443C3F44434240474142413F4542463B3D444340403E3F45433F42403B3B3D3F3F3C
3D4142414047473D393E434443433E3A3B414342423E4246413C3B39423C393C3D3E4147
4B4443494A423D40433E3E3E3D42443C484A423C3F4240403E4948403E3D3D4339424339
474141443C3D3D3B393A3D3F41404642474144413F3B413E3D3F393F41403D3C3F42403B
443B3B3E3B3E4342393F3F3A3A40403A3F3C3A3C3E4044494C444144443F3D40433F3E40
403C3A3B42473B3D423E42423C495355575B564C4F4D4D56425C495146524E5249425047
464145364943525A8085988B9884606A535843525F808B938F9383857C7C6B8C7385839C
908C899896967D525449404E4942414748423E3F3E44414646434B494341433D403B3E3C
3D49433E3A3C46423C433C3A433F3C423E41473448423D423A3C404D3F3634443A40414D
665C60444D393F423B383840413D3D4A444C4B4A4B4B5054624E4E6071737885888A999D
A8AAC9BCCFC2C9C4B5AA977763413942537578805D48578A686462866A706E8B92977A79
83888D6C6B606467797E94A2A1867B7D9599ABA28A646A6A786C708A5C58453F3D3C494D
4E513D4C69695F4B3C3C3B3B3A39393838373A3B3C454B484D463C38393C3E3F3B39393C
40403C373837393D3E3B3A3C3D39373A3B3A393A3D393F403940483F3C3B393736363738
3844403B37363D36383A353839383C393839393D403A353836363B3A34353A393B3A3838
393B3D3E383C3D3835383B3C3A363334393C3B3A383C3D3A393B3C3B403C3A3B3A383C43
453E393837343538393F3B383F413A383A3B36353C3A3435383A3C3D3C3A38383E373335
383736373637383635363A3D393938373637393C3A32343A3A3939363B3B393837383A3D
3537383838383A3B38393B3A383635353B3B3A383636383A3A3A3938383838383A393737
38393B3C36373737373737363B39393B3B383839363936343137373636393B3A37343536
37373737383939383B3636373636352F3434343534343333353137404858696E6C625146
4B545145504C4137343738373535363637383838
4B4E514F4C4A4C4F50494D4B4A4C48514F4B494B4C4B4B4D4D4A4847484848474D4E4849
49464B494F4D4649474348494B4D4D48474846424545484C4A474A504B49444D484B4447
4243434345494B4B4245474848494A4C4247444147494644403F3E414446444140424444
424040413D3E4041414140403E3D42444143494941484544403E444244413C4142454B44
40424044423B42453E3C45423E3F3D48413F3E4241473C4942443F3D41413F443B3B3E42
433F3C3D3B3F4446423E3E3F43454241423F404A464349433C3B3A453B40464846454546
424345464645413D443B3B3B3E413E433E44403C41423E3E3B3F4445423F41453E3D4141
3B3E45483A3F4445423E3A3D3C4340393A3D3F423C3E3F3E3D3C3D3D45403E40403E3C3D
40383D3D40423D43413D3B3C41444340363C3F3C3B3E4140413D3D4244413D3B3942433F
3D38373F394D43464A404A54475D687C7B6862524C44484A504241414443454744404248
3F4443424240475869798789808786908275636572829598947D7F656C4E59535A535E58
72788A9CC3C8B6764E424B4A4A444042444240403E40393E42493C3F41443D333A3D4045
445B4E5D50535A66554B5254585440495045453E42413D3B35414546413D413B442F464A
5D565E524951413A383C3741433E3F3C344041404241393F4745497596969896909A8D8D
7F86817677767A837E81857C6756403C43618F93B7908695BE9798A6A67B8394AAA28986
979D9191765C4971504D647D78937487A0B3C5CEB78FA79BAF919B7E96626B56463A4142
463D44616F6D624340423D3838383C44333C413C36383F433D373A3E3C3C403F38393C40
3F3B3B3F383B3C39393C3E3E3D37373836393B373B403B3D3B3A45473B393A3E3F3C3939
3B3E3F3E3A393C3F3B3C35343F423C383838393939393A3A3B3938393B3B383536383B3C
3C3B3B3B3C3D3D3A36363A3E3D3834363C403F3D3C3D3A3534383A393A3B3D3F40403D3A
3E3B3A3C3B39393B363937373C3A3638383B3E3E3C3A3A3B38393B3A3937373732343636
3535363838383836343537383536373736373A3C3634343737363A3F41413A3539383639
383838393A3A3B3C3235383A3A39383734373B3A332F3640373838393A3B3C3C36383A3A
383737383838383939383838313435343538393635353535363637373737373737373737
39373433353637363533383338333837363D383439342D32333950606D9088896759504C
494B4A423C3A3734333334343536363637373838
4C4E504F4D4B4C4D524A4B4A4B4D484C56524E4E4D4946474D4B4847474848484D4D4646
46454C4B4A49434746424747454A4D4B4645474940414344424042464645424A46474143
43414347474341434745434040434A4E42443F3D43454343404243444443434348474643
413F3F3F414040403F3F40403B3C4245434549473F4748494743453F403E3C41403F443C
383E3F4440393B393F3D454341413F483E3F3D403E44394340423E3F45443D3D3C3C3E41
413E3D3F42484B473F3C3F42403F3B3E4545444A4841454649473C3B3B3F4242403E3F40
4643403D3B3C404443404644413F3C423940403C3C3C3B3C3B3F43423F3E4042403F4445
3F3F403D3F4243433F3D403E3E423F3B3C3D3E42434443403E3D3E3F43414040403E3C39
3B363B3B3D3E3A3F3D3B3B3D40403C373C3D3E3F41444441403C3C4143413D3C3E413F40
4646434646524C4F4B4553546B7C7C7F6F56514546404443473C3C3B444545433D38393D
3B3F3D3B3D4047545C5B6E6067636C6B61605B61686D77777C767C53593E504D63687273
7F7E828B8F8A7C594F47463F4A4745423E3B3D4240403D413B403C3C4043444743474645
4A5D52645D5F616653505A5E6A7178A08C9687986E7A525740434A5553566564715B695C
6553595249575355525142443E3842363E3E423E4544403E41475C8EA9A9ADB6BCCDC6C8
BCB6C3AAB098A396938884685D4E4845434154739DC6B8D1C7C7C5BFA3A19DB1ACA08088
ADABB0999F72563A614A3B52516268788990ADC1B0B2A6C8BCD3B4BB9AA474645F654F44
3D3B414E4F47433C3B3D39373B3A383B383B3C3A393B3E3F3C383C403C3B3D3D3E3E4045
45413F4034383A393A3E40403B37383A393D413F3B3E393B3B3A43443C39393D3E3C3A3B
3B3C3D3C3A393A3C383C38353A3B37373939393A3A3A3A3A3235383A393837373D3C3A38
36373B3E373A3D3D3A3837373C3836383D3F3D3A393A383536393B3A3B3B3C3D3E3D3B38
363536393A38383A363835353B3B393B383A3B3C3B3A393938393B3B3A38383934353636
36363737373738373636383A343638383838393B3634353839383C413C3D383538373539
323437393B3B3B3A35363738393939393A39393A37333539363737373738383837383939
393837373838373636373838333536353538393634353535363738383737373737373737
3332323437393938303037363B3536333139353238383843515A7F8392877F6A5046403E
3C3E3E3739383736353434333636363737383838
53535352504D4A4958504E4D50524C4D4E4A4849484644454D4B4847474849484A4F4D52
524E504B47474347474348484A4B4D4C4844444745484845424345464848474D4A4A4545
413D3F47494343494D4B48464545484B4C4B46454A48434442454746424142454B494542
404041414543403E3E3F40413F3F4548454445413F47474A4946463F44434144403E433C
39414246433F413C423F4444434341474448454441483E434746414248453D383E3D3E40
3F3C3E4240494B443E40474D403E3C3E45464447493E3C3E44463C3A404243413E3C3D3F
4643403F3C393D4446444A46423F3A3F3F4246433D3E4242404546424144454243404345
42413F3842443F403B3F4C423F413E3D403E3D424041403F3E3F42444442403D3D3D3B3A
39373B3B3B3C393E3D3C3C3D3E3C38343F3B3B4046474440413E3F424543403F43464545
4748484B4B5051554C4E5F56696959534A3F443F4341453F413A3C39444849443F3F4143
46463F39393C3F434F4A434636484143484C484B4E50595A75877A5B464D566473807E7E
71675B59655D555160564A3D443F3D3F4140404145434346393A3D3A4439443A3F384944
374439494649474747454542494A5788C6BCCDB1B78F7C6259544D5150505F666E6D6B77
656C5C65526468747B837B808177916980585E4F615B6051524552686669708491ABB4C3
C4DDD3DDD8DDC4CEC3C4BCBBABB29F9D8B7D63526D98CCD6DCCFE4BAA499CBB4A0928A8E
92AEA0A98B724D47487D6D876E7C688B747192A1A196B5AAC8C9DBCECEACBC827B738654
423F3D3A3A3A3A413D3D38373C3B35353D3836393C3D3C3B3A393D413D393B3B3E3C3D41
43403B393A3E3E3B393A3A383B383A3A36383C3A393A363838393F3F3E3A393B3C3B3B3D
3B3B3B3A39383838363C3C37353534363A3A3A3B3B3B3B3B3A3F434039343335403E3A36
34363B3F3A3A3A39383838383A39383B3E3F3B373839393737393A393B3A3A3A3B3A3837
363434373938393C39393635393A393C3939393A3B3B393738393B3B3A39393A37363636
37373736353739393838393A3436383939393939363637393A3A3E423739373537363538
3D3F4142413D39363837363637383A3A3D3835393B393534373737373636363639393839
393837363937363535363739353737363638393734353536363737383838383838383838
3937363536373737323338373B36353231383533393D43517079818776624F3D403A3939
383A3A3636373838383634333737373738383838
4E4E505356565452504C4A4A4B4B49494F4B494B4D4C4D4F4C4A4847484949494A4C484B
4B4A4F4D4849454A4A454948484343494D4C4A4B45494842404345444444454746464443
4440404345464C52514F4D4C49454445454644474C494345444545434141434647444141
424445444543403F3F41424244424649464645404247424343434742484744453F3D4541
3E45434344454C484541414243424347454C45433F463E404A47444346464240403E3E3F
3D3B3F443C45464040454B504445444342404043453F3B3B3B3C3D414747464340404144
49444244433F3F43494344403F413B3D48454847404248464247474141464741443E3E41
4244433C40423B3F3B4357463F3F3E41443F3B403A3B3B3B3C3D404346403C3C3B3A3C40
3E3D3E3D3C3C3E4142403D3C3B3B3A3A3D3939414644403F44434142413F3B384B4C4B4B
4B4C4D4F484C4F524A4E5B4F4F4C3E3D3D3A403B4546493F413D413D3E43443F3C404547
44433E3A3E4547444338413D3E41433D424841434D57676E88958B564D3D45474F5B4B4F
3F494E546F6D6766725D4C3F3E3B3B4045423D3A393C3E44404148463B3941463F3D3F3C
3E4337413D41403F46403C383B383751637575907A91767D61614C434337353D3F463F52
3D4C36443E4A4A52566260676E847F957E9177887D9078A976A37E978B9094998C89848E
A19DC6BDE0D1EAD7E3D7D8C0C9C4C5BCA8B6A2B67A738FBEC5DDD2E69CA7CEC3A9B3A599
8D74A5A29E6649394C7DB0B0B8969795A19AA8A893AC9D9EA0D1C5DACCD0C1C79CAD7F85
4F46443A3A403D3F43423B383A3936383F38353A3D3C393938393D3F3C383A3D3F3B393C
3F3F3935383C3E3D3C3D3E3C3B3A3E3D363537353C3B38393B3C3E3E413C393A3B3A3A3D
3D3B3A3A3A3A3836373D3D39353536373B3B3B3B3C3C3C3C3A3E403F3A3637393B3B3A39
38393B3E3B3A3838393A3B3A3A393A3B3D3D3A373B3B3A39383736353A39383839393837
3D39373838393C413C3B3938393938383B3938393C3C3A37363839393938393A39383637
3839373636383B3B3A393939363738393939393A37383939393A3C3F3538383736353638
37393C3F3F3C39373938373738393A3A3B3532363B3A373639393939383838383A393838
393937353938373636373839383838383839393936363737373636363838383838383838
403D3935343537383A38373536353635393D3A3A41454A536F6B5D6149463C3A3B3A3B3C
3C3B3B3935363738383735343838383838383838
5352525354524E4B4A4D4D4C4A494B4C4E494545454445484B4A4848494A4949494B4648
49484E4D494A464B4A4447464E4744494D4A464546494843424647464445454444444645
494A47403E44494A4F4A47474542424546484545484642444744403F4144454541404042
444646454342404042444443464244474648494441443E3E3F404743434442453F3D4440
3F44403E3F424A4746423E3F4040434649504544404642444041434443444647413E3D3E
3D3C3F444046433F434543444545464442424342444341413E3C41474645434140404244
4C454042444342434441444041443F4049403F403D4145423E42423C3C42423C433C3D41
4346453E3F413B403D4457453D3E3D4348413B3D3A3C3D3C3B3B3B3C443B3A4141393B44
4243403D3B3C4042413F3D3D3D3D3D3D3B3A3D42433F3E413E3F4245494C4D4C524B474B
5256544F44494A4945444640414340403E3D43454244473C3F3D423E4345433B393D4142
3D3D3C3D434C4D48483E463F3F414748475555596470818C8D9C85775F5A3F3E3A463A41
333E434550534F4B524341383B3C414544414042383F3B3D423C3F3D403D4640473F4643
40423B40393C3E3E4039393A3E423D3D3D414947474E4A4C49564E4D55514D4E4E444A3D
463D3D3E3A423E403D4541464847544A5B5354575A596A6B747B878D929CA0ABA09E9EA7
9AB4A9BEC5DAC8D9D9DBD3D4C1C4A8A2B0A2C2A9BDA6A19DC3CFCCC1E5C4CAA9A09CA398
78939EC1A47A5254596F89B2AAAD8FADADB4C5BDA894B68296A7D6C1D1C5DACBD1A1AA75
544041413C3F3E3F3F423F3B3B38373C3E3A3A3D3C39383B38393B3D3C393B4145413D3D
4143403B3B3F403E3D3F3F3D3B3C42433C3B3D3B3F3C3C3B3E403F3E443E3B3B3B39393B
3E3C3B3B3C3C39363B3C3D3A393B3C393B3B3B3B3C3C3C3C3B3A37363535343436373939
3A3B3E4038383A3D403F3B383B3A3A3A3B3A3A393B3B3A3B3A38373638373637383A3A3A
3E3A393B3B3B3E423C3A3A3B3A3A39363D3A383A3D3E3B38363738383737383A3A393738
393A3837393B3D3D3B38373739383838393A3A3B383A3A393838393A38393A3A37363737
37383A3B3B3B3A39393838393A3B3A38393532353736363838383838393939393A393737
3839383639393939393939393A3938383839393B38383838373634343838383838383838
39383735353638393A38353636383838404242464F5352545B47483C41373E3C373A3B3B
3A37353536373737373737363838383838383838
4E4D4E4F51504D4B4C5353524E4C5252554F4B4B4B494A4D4A49494A4B4B4A48474B484C
4D4A4E4B4747434848424544454445494B4B4B4C474847454547484847484A4447464A49
454B4A413E42433F4744454A4B474446484D49424446464A484440404346464541414345
4646454443414042454644434D474546444646403D423F3F3F4046424043454A45424741
42464141403F444046433C3F3F3D43454B5246484549474A3D3F4446403E3F3E413E3D3E
3F3E3F424145414148453D3E443F3E40444A4B4447443D3E3D3B42463E3D3C3C3C3D3E3F
444240424545413C3C424C4944454143483F3B3D3F41413F3E41413E3E42413D403C4045
4646433B41423D413E424D413D3E3D4147433B3A3A3C3E3E3E3D3E3F3E3A3D47473D3C43
44463F3C3A3A403E3C3C3D3F42413E3C3B3E4244413E3F4345474847494B4B494B454346
484B4A453C424241423D3B3D3F3F3D3D3D3E41423C3C3F363B3A403C4544403C3B3E4040
423F3F41434747404144424C42514D5C64787A7A80859099A69A9578815D50413F424045
3F444644494A433E433E4D4549444242413E3D3F343D373943393F3D393C3F3F3E403E39
3F4040433C3E403F443F403E3B41413A403D3F383C433E393C424042444950484B40483E
4640413D444841413C4444474A43494D5E5F55515349574854484B454F54515F606A7279
9489A290ACA1BDB0BDB8C4BBC7C3C7C7C0B8B1B5ABA79FB7B2CDB8AF99B286885E666064
6C689FA0A6727574B3A3837D8E8A97869EA9BFC6A2A19D8B7FABB1BEA3C4A1AB9BC2AEAB
744A3A3E3A383D41373E3F3D3E3B393E3D3E403F3B37383B383A3A3B3D3A3B4243423E3D
3F4343413F42433F3D3D3D3B3D3D42423C3A3D3B3D393B3A3B3E3A3B433F3C3D3C393839
3E3D3C3D3E3D3A373C3B3C3B3A3E3F393A3A3A3B3B3B3B3B423D37343536343237373737
383B40433C3B3B3C3E3E3C3A3B3B3A3939393A3B3938383B3C3A3A3C383736373A3B3C3B
3635383C3E3D3D403937393C3B3D3D393D3B393A3D3E3C3937383837363638393A393939
3A3A3A393A3C3D3D3A3836363B393838393A3B3B383B3B38363737363A393B3C38393A38
403F3D3B3A3939393A39383A3C3C39363B38363634323438363636363737373739383737
3838393839393A3A3A3A39393B38383939393A3C38393939383634333838383838383838
33353738373635353536373E3F423D3B5050505153504A4650403D3938363431363A3A38
3835323438373736363637383838383837373737
5251504F4E4C4A484A514E4E4C494F4B4D4947494A49494B48484A4C4D4C494747484244
45444A49464642474742464648494848494B494644424243434242434243484044424745
41474945424242404341464F514A44443F4B4A4243484B4D464646464746454442444647
4847474745434142454644424D4543444345443D3D444242414148454345454946444A45
48484346443F434144443E42413C434442493E4644444347444145453F3D3D39413D3C3F
42403F403D4140464E463D44433D3C3E414A4C4446443B3D3D3941433B3B3B3C3C3D3D3D
3B4144434344413B3C434E4944443F4145423F42454340423F414242434343423F3D4246
4444433D41413F403F40433F3E403C3C43443D3A3A3C3D3E3E3F42433D3E424645414041
4548403E3C3A3F393F3E3E414546433F3C4042403E3D3E3F3B3E3F3E3F424341413E4041
3D3D3F3B3A3C3E40413C3C454542414242403A353B393C363E3C42403F3B3A3C3E3E3D3D
3F3A3E444447494747495A5160504D52475C616D828B8F90917E7260624E494139333E42
4846453E464443474B475E566C625854534E4A4741494544473C4B4855676C866B775744
4944454641444644454645413B393B3A37423E47384E404544403C3E393E4B474A474752
415044444A4E4B504F60676E816E8A7BA28D9888A194A58797716A59474C424842444340
44534B525B6B69776972849A9EABAAB9BFD5CEC7CABBCAB8C2BBB6836F665C4C43414343
3A494A585F54577D99D1C1C0ADAA8C858999A99D9E6F9972857FACA8AA96B0917581A08B
926A49443F383C3D3C403F3E413F3C3F3D4143403B3A3A3A3A3B3A3C3F3C3A403B3D3C3A
3B3F4140393D3E3C3C3F41413F3D3F3E38393D3C413D423F3F423D3F403D3C3E3F3B3939
3B3B3C3D3D3C3A383A3A3C3B383B3E383939393A3A3A3A3A3D3A36373A3D3D3C3A3A3937
37393D41423F3B3838393A3B393A3B3A38383A3C3937383B3D3B3C3F3939383A3C3D3C3B
3836373A3C3C3D403A36393C3A3D3F3B3C3A39393B3C3B39393A3A393737393A39393A3A
3A3A3B3C3A3B3C3C3A3837373B3A38393A3B3B3A383B3C38363737363B37393B393B3D3A
3A3937353537393A3B39383A3C3D3A363B38373837343538383838373737373637373737
37383A3B39393938383939393A37373939393B3E36373839393736353737373737373737
36383A3A3A3A3B3C3B40414C4C4F454240444A4E4E4D4C4B47453642323B3939373B3A38
3A38353939383737363637373838383737363636
50505051515151514E534D4E4E4C4F474F4C4B4E4F4C4B4B47484A4D4E4D49464549484C
4D494B464747434849454A4A494743444B514D434A4646494945444743464C4449454B47
46484A494542424547414148494340424F5F5F514B4B464245494D4D4945444442444749
49494A4B4845424244454441423C3C4044494A444147444341424B4B46433E403D3E4946
49463F43433E434442443F45433D434240473D4A49464549474040413F434642413D3C40
43423F3E3D43444B51453D484340413F3C4246414046454B473D41403E3E3F404141403F
3D45463E3A4045454243484240433D3C3F43424448413C423C3D404242404041403D4043
404346443F3E3E3E40403E423F413B3840443F3B3F3F3E3D3B3C3E403F4546403E434441
474B4241403D3F3647434042474A48463B3F3F3B3A3C3C393D4142404145464440393A3F
4145443C423D4043413B3D484342423D3A3B3E443E3B3E3B4542484646403F4548454140
40393E4646484D4E474D48484B4B4050505F5F6F8A8D7C6A6D565C42573E50484F394137
433F4441423F454E483A4E434A47464644424245474E5052514A65628E7CA67A99708858
685C595653595B58585D5B5A5549454946484D4C535E575149484448453F4546433B4244
384447473F4441443F4B4C4F524D50625D72717A728B7CA581A586A37C82706956524F4A
47464A3B443D4643413C45444649586E799292B0A5C1C5D0BFD7B7A5734E3F403C423E42
433A413C373E4952859ABFABBBADA084858A95876F504F624C696B8F7A9495B08C675B62
7B735D534C4448464A48413D42423F413F4444403C3D3C393A3D3B3D423D383D363B3D3B
3A3E41413C3F3E3B393C3D3D3F3C3D3E3B4048494E4A504D4C4F494C3D3A3B3F403D3A3A
393A3C3D3D3B3A3937383D3B34363B373838393939393A3A3B3A3837383838383B3B3C3B
3938393B403F3E3C3937353337393B3B39383A3C3D3A393C3D3A3B3E3B3A3A3B3D3D3C3B
413C383838393E433E383A3B383B3E3A3B3938383A3A3A393C3C3B3A38383A3B383A3B3B
3A3A3C3E393A3B3B393838393A39393A3C3C3A38373B3C39373939373A35373A393C3F3B
43413D3A383738383C3A38393C3D3A373A37373A3B3938393C3C3B3A3938383736373837
37383A3D3A3937363637393A3A3736393A393B3F34353739393937373737373737373737
3839393A3C41494E4A4D4D5855584D493B414848423E3F413D3E3736362C4137363A3836
3A39383C38383838373636363838373736363635
4A4D4F4E4B494A4D494B47464D4B44444B4B4B4A4A48474742464A4A484442414D4C4A48
454443433F4246494A474441454344474846474A4744444645413F424344454543424243
47484848464546473D4143403F4143423E464747494542473E42454744424243424D4244
3E474B443C404245473F3B433C3E43474644464B484A4742414648464B4745403A414642
4545423E404648453C3C3A3E423C3D48494A433F42414045403E3F42444241423F404140
3D3C3E40384441444946464441363C41464740473D42484945403E3E3E44403D43444040
3C3B3D41413D3B3D3D3D413F393D413D3B41414143403C3D3F3D373E413D3F3D3D454A46
414142413C3A3E403B3C403D373A3D3F404040413C3D3D3B3A3B3E413C44494845464747
423D3A3C3E3F40433B3D3E3D3E41403C3D403D403B3A42393841423C3C464842433F3D3B
3E4B50473F3936383A3B3E43373A41423D3E42413A3E404145494742413E3D464743453D
41413F424B473B3B3D443F40404545494F5F72808A7B7A6C656D5150413E454B554D4A4F
504B4A4E4C474344484B4A48624F47444D464848424D4C4C4B4C5654555D606555504544
45424943463D44485847625B75596E678B85938CB0B1B2908D75676068767B888A757755
553F3B473C48373F42464A44413F4041483E48464645504E535766647370817C7E82946B
6D4A6046424A394D4045423C453C434840473E51656A958CBACDD1CCBD8D5C5C424C4A42
453B47473D3F4A57596D758B77887C7869686C715D5C4F504846494C6D7E90908F726465
525F6459554A5C67625B5C584246403D3A4545433E3D4341433C4548413E3B3F3B38423D
3D3B3A3E3E403D3B454135413A4B4A5555606E768E8B908C7B6E614D433A3C423D383D42
3838393B3A38393D3A35323E3C3038433A3B3937393D3D3A3D39383A3A38393D3C3D3837
3F3F3B3C3F3F3D3A38393C3F3536393A3B3A3A39383A3A3734353A3F39373B383E383934
3A39393939393A3A3D3B3740433E3E3B35373A3B3A3A3B3C3A3A37383B37343939373737
393B3B3A3B413F3C3C37353A383B3C39383A3C3B3636353738393837393939393A3B3D3E
3A3B3C3B39373636353536373534383F39383838393A3C3D3C3E3D393738373435373A3C
3B3B3C3D3B3B3A393737393B373734353938373E3C3634373937363838343C3B39383239
38394248414C715B6D595E54524A443D403E3C3A39393A3B353637383837363539353739
37383B383A363436363334383838373738383939
50525353514F50514E4E4C4C4F4F4C4C514F4D4B4A4B4C4D4F4F4F4C4A48494B4E4D4B4A
4A4A4A4A484849494948474645434447484646484A49494B4B49494A4B4B49474445484B
4C4C4C4A47444343494A4946464B4E4F41454748494745474347494642414243444C4248
444643413E45454445423F424041434644424449403F3E3F40404143424144423C404747
424444434445423D3E3F3D3F413C3A423A41413F4040434B44413F4243403D3D383B3F42
434241403C454041444243414C42423E4145424643454644413F404140423E3B3F444546
403D3C3E3E3D3E413D4046453E3D3D3741423F4044423C3E413E363A3C3A3F3F3C3E4040
3C38393C3A3A40433F3E3E3A3E3F40403E3D3D3D3D3E3F3F3F3F4040404447494A4B4A48
44403D3E3F3E3E403F41403B393B3D3C40413C3D3A3C443C3640423B393F3F3A3B393A39
3C464A4139383B404241424544414445404045463F3D3B3D424645413D3A39424240453F
353E45423E41474A3E3E44384748484D59717A8A8C7580725E5757527764796E88817D7C
79726E6F6F65574E494845434C42403E433B3E404540403F3F44484B3C47474D3B3F3A43
44494350434E4854554F627587858D8E889AA3ACA5BDBFB6969390909AA5ADBAC2BFBFB4
9F82605E4958494D454145464341414450516368818089838177736565606A5E5B5D7B6B
8F6A7E766B68504C3D3940433F3D394545404540454348465F8E91BFC4BFA29171797264
5F4F525046454F54555E5F685B6E6C70625859617D7F8B70826970536D839895918F908A
6671828889808D8B8A8D948C6C685A505E686D72695B5A586055624B54454B45433B4238
414A40423A3D3E3B444D53666B8899A39FB3C6CFDACAC8B37D5B534637343B413C383B3D
3B3A3B3C3A37373B38373C50513E3836393A3937393D3E3C3B3A3A3C3C3B3B3C37383536
3D3F3D3E3A3A39383737393A3737383839393939393A3B3938393D4036363C363832393A
3B3B3B3A393837363637343C413F423E35383A3B3A393A3B363736393E3A373B3A383738
393B3B3A353A3A393B3A393E3A3A39383B3F3F3C373636383B3D3D3D3C3C3B3B3C3D3E3F
3A39393A3C3C3A383534363838383C423C3B3B3A3938373733383B383536393A36383A3B
3B3B3B3B393B3B3A39373738383834353B3A3A403C3B3A393837363638353C3C3C3E3D45
454D51665359544B493C413C3F3B37353435363738373736363737373737373638333537
3331343436353537373535363637383939393838
4D4E4E4E4E4D4C4C4B484949484A4C4A4C4B4A494848494A4D4C4946434344464A474544
464848474646464544434342454344474745444547484746464748474145494845424142
4D4E4E4B4844424140403E3B3D404242444244444343423E444A4C4641424546474A3D45
43413B3F3E4646414447464444434445423F414545414145433E3D40494341403D3D4041
464543403F40403D3E414040413D3B3D4243404043423F3F423D3C4043423F3E403F3E3F
404142423E443E3D40404341454345414347413F45454442404141403F3C3C3C3E444947
403E3D3E3F3F40423D4147453F3D3D3846423C3E44403A3C3E3D373B3C393F3E43414347
453E3D413B3A3C3D3B3D42424141413F3D3B3B3C41424344454543423D3D3F4447474542
4A474546454241423F454946413F3E3D3C3C393A393C40393A3C3B3A404742374241403D
3C43464045403C3F434444433F3A3F46423E3E3C433E3B3F4445423F43403D423E393E39
4143453E3846555146494B3D44585E7B7A7F85756455585F75856B876D7662695A575452
504B484649443E3C3E403F3D403D3F3D3D373D43513F40403E413F424245454B4E55565B
585C646F79828D959D8FA6A4C1AFBFB7C3B5C396A69EC0ABA19F969CAEB9BAB5ABB1A5B7
A1A68E98899385897A6D6A6D726C6A7B9BAEC4C6D1CDD0C9CCC7C7BCBFB8BCAEA0837A5F
705D728C979C8B7A755141493E4A393C433D453A3C3D3A423F545C729AA1B6ACB9C2BCAC
A08C857E7C73756F727B838495A2A6AFA4908588A9B1A99D9C988B6C7B8F9A9089A5B3A4
7C86A4B5AA9FADA7B8C1C9BD9F9D8A7A909EAAAD946D5E5B5D5F635A5B5F58544439453D
5B6F676B464D5855545B616DA3B8D2DFD5DDD3C7BB947F704F3E413D3B3D45453C383938
3C3A3B3C3B37383B3F3B3C4D52423A34383A3A39393C3D3D383A3C3C3C3D3C3A3B3B3736
3A3A3737363737393939383638373737373838383636363738393B3C443D3B353C383B38
39393A3B3A383634393B36393B3B3D37343638393A3A3B3C3C3C3A3A3E3933353B3A3838
3A3B3A3A3B3D3B393A3937393E3C39383D413F39383736373A3C3D3E3939383838383939
3A3735373B3D3A363D3A3839383536393C3C3B3B393736353B41433E3836383B3838393B
3C3C3A39383A3C3C3A3735343A38333438363439393B3A3635373A3A3C3B414241414047
5053605057494336363236333B39373A333436383838373638373736363737383D38393B
3635373737373634343738373536383A3A393736
4F4E4E4E4F4F4D4C4B474B4D484A4D494B4D4F50504E4B494B4C4C4C4A4846464F4C4949
4B4C4A4747484A4B4A4845434644454747444244494B4A45444747434547484642404245
494A4B4A4845444445454545464644414F4949484446473E434A4D4743464A4A4C4D3E40
41443D45454745424244444244434444423E3F42403F4145464545475D4E424246454240
46433F3C3C3E40413F4242414141403F474440414646423E413C3A3E4343413F44413E3E
404242413D413C3D3F4146424844403D3C3D3B3B404141414243413D3B383C403F444843
3D3D3F424342403F3F42433F3C3D3F3F43403B3D413B363B383D3C42413C3E3A3E3E4146
45403C3B4542403C3737393A3D3E3F3E3D3C3C3D403F3F414342403E4141434849474645
42404042423E3C3D3C454C49434141423E4040434546443C3D3B383A424943393A3B3A37
384046464C433B3C4346423E40383D4746403E3C423F414647423E3D403F3E433E39403D
44403B3938424D443E494C60779787937080707A7664776B80746C4D5F424F403D3E3F3E
3E3F3D3B45434243464643404140403C3A3A4249493C3F413C3F3D3B544A64528370887E
8D8D8F8D95909B9A8E9187A097ACA6B2BDB68F95709D8E827B858A9AA8B0B09E9C8A9172
8B70888499A2A2BBC5C6C5C9C9C7C0C4CCCED7D4D9D4D2C7CBC9CDC8D4D0D3D1DACBBCA6
B5AEA4B2BEBDB29EB195727244453E4049473D3E423D3F3D45423D42506A7598B0C3CDCE
CFC7BFB9B1B1BCB9C1C5CDC7D2D7D7DAD5C0A99F9D967878717A6E61638EA99B798D9F9C
737693A89897B0ADB9C1C6BFB3C3B8A9ABB6B7A77D5146473E4340454556494B4547394A
496A52614E525E55484948486A759CC0C1C3A58E6F514042433F3D3A3A3F454138383B39
3A38393C3C3A3B3D423B333C40393938383A3B3A393A3B3D373B3C393A3D3D3938373636
393B3A3A37383A3C3E3D3A37373636363839383836363537393939383433383238353C3C
363738393A393838383C3737393A3E383B3B3B3A383736363A3B38393E3C38393C3B3939
3A3B3A393A3A3A3A3C3C3C3D413F3C393B3D3B363A383636373939393737373636353535
393735363738363339353336373636373939393939393939373A3C3A3635383A3838383A
3C3C3B39383A3C3C39363433393833353936333638393B3B3B3A393734363E4344414043
494F463D383F343236383633393633383A3938363535363637373737373737373B373635
363B3C343D3D383130373B3B3536383939383737
504E4D4E50504E4C4B484D504A4A4B454A4C4E4F4F4E4B4A4C4D4E4F4F4E4B4A49474647
494946424748494A494846454645454747434244484A4945444646424547484643424345
454748484645454644434244464645444D49494642464940444A4D4A46484A4A4D4F4343
434C45494D484544413D3C3E4141424543403F413C3F403E3F4242404C40373B43423C39
3E3E3E3F3F4041434544444241424341464545434040414246403C3F42413E3C3B3B3D43
4748443F3E413D3F414247413F3B393F3F3A3B3E3C3E3E3D3F43413C3D383B403E414440
3E3F40424344413E4042403B3B3E3F403F414141413A373D383F40454540403A393C3D3D
3E3F3D39383B3E3F3E3B39393A3B3D3D3D3C3D3D3C3A38383A3B3A39393D40413E3B3C3E
3C3C3E42423E3D3F3E43453F393A3F433F4143434749433E3B3E3F3C3A393A3A3D3F3E3B
3B3E3F403F3E3E414444403B483B3A40403E3F3F3E3F4346433C3B3E3E3D3E433E383F3C
4A4D46453D38403E495D8B8BB69D9C8E97938C7C685A4C4A474C363F3D4F3F373D3F4142
434444433F3C3B3C3F42424242413D3A393E41433D3F40413C3F47413F4B48595C6D6975
7079677A6B7A767A827C87778B7E9293A398B194AD9BAC896D84999E8F8E9D9497907375
5B67626C879098BBCFD8D7DED7DAD1CCBEAFA69CA3A2A299A5AEC0C7D4D8DDD8E3E1DDD8
CFDBD5D7DBCDBE9E8B937D99766A60484540393D3E3C3B3D3D3F3F3C42453F667994AEBE
C9CDC2BDBDC8D6D6DEDADED8DDE1E0DBDACEB9AD987B6A4C5F48523F5A81A3A88E8F8D85
76686C76666E8883939B9F9FA2C0C1BCBCC4B89D785B534E4E4143384746464242423E3E
423F3E4547434A443C4446434443586A6064544B423F41443F3C3E3F3A3E433F37393D38
3B39393C3D3B3B3E3B39343A3B353938393A3B3B3A38393A373A3936363A3B3939383838
393B3C3B38393A3D3F3E3B38353536383A3B39383D3B3A3B3D3D3B3936363C373C353937
3737373838393A3A40443C39373638313939383839393A393B3D39373B3B393B3C3B3939
3A3B3A393B393939393A3C3B3E403E3A373838363C393736373939393A3A3A3939383837
373839383636373939353336383736373938373637393B3C3A3938383837363537373739
3C3C3B39393A3B3A38363536363735383D3B373C3A3635393D3F42454C4C4D4E4A423F3E
3E3C343B363734343C413A3636333033393836353333323236373839393837363B393632
3846463540403A3231373B3B3737373737373838
4F4E4D4E4F4F4D4C4A4A4D4F4D4B48444A4948484848494A4A494747484949494D4D4D4E
51514F4D4746444242434546484545464643434544464746464746444144474948454341
46474746454444464946434447494D514244443F3D434845494B4C4B4946474843444244
404C444448414144403D40433F3E404444403F404145443E3B3D3B36424444484D494341
3F3D3D3E3E3F43474C46454541414240474342403C3D3F3E46403D40434241403F3E3E41
4445433F42433F424142453C3B393A46463C3B3D3D3F3C393B41423F423C3B3D3C3E4242
43423F3E4043423F3F43413E40403C3A3D444543413D3C413D4240434342443E4143413B
3B4244423C403F3D3D3A383A3C3D3E3D3C3B3C3D3F3D3B3A3A3B3D3D3E4548433F3F4142
3E3F4246464342444044453F3A3A3D3F3F3F403B40443E3E3F3F403F3D3B3D40363C3F41
454543443B4245423D3A3B3C483D3B403F3D3D3A3D3E3F3E3A373A3F3F3E3E433D363B38
424742494A4C6169648E91B898AD96A585855D574738473E3C43433C454748423B3C3F41
424344473C3C3D3F4141403E41433D3D3D45413D3F49433F3B3C48474544473A4E454D50
48524457556469696D76727A76817F887B908FA68EA6999B9EA5A794716060556F5C674B
5E4E6461758390AEBCC8CDDCDAE2DFE4DDD5CBC0C9C4B9A19F9BA4AAAFBBC8C6CED2D1D5
CED4D5CAC8C3CDB69B9664716660634D6260766B4D453544404D4632493546565F7FA2BD
CFDED3D0D2DDD8D3D7D1D4D8D8DDE3D9DDDCD6D3C5B7A79397857D635453627A7F878983
7A6B5C553F475A58535C666F76939AA1A5AEA59A939393878F807D7A736E5B4C40414741
483848463F3A42434248433D4544454539474847403B4040383F484238393D3C383B3D38
3F3C3B3D3D3B3A3B393C3A3E3E393D3C3939393B3A38373939393836363839383E3B3B3B
383839373838393A3B3A39383736373A3C3D3A373C3B3A3A3B3B393738353B3A4542433D
3A39393838383838393C37393A3A3F3B393837383A3B3C3B3F423D37383836383B3A3838
3A3B3A3A3D3A3A39343537353A3D3D3937383A393B3A39393B3D3E3E3839393938373736
35393C3B39393D423E3A383A3B3836373C3A37353537393B433E3A3B3C3936343737383A
3B3B3A3938393A3938373839373836363A36353A39404B5760666A6D69635751493D3A37
363038333C323C3140453C3B373736363436383A3A3836343637383A3A3837363D3B3834
3A4A4A393C3D3B38373838373737363636373838
53525253535351504E4F4E4F53514C4A4D4C4B494A4B4D4E4D4B484648494A4A4A494848
494A4A4A4D4B484545464749494644464544454849494B4D4D4B49494A494848494A4B4B
4748474644444648484441424244494F454D4C4443484D504D49484B4945454A40393F46
3C464142403D41433F4147483F3E3F4242403F413D3F41424242413F3C4446474B484140
43403E3E3D3D42484C4343474340403F423B3B3E3E43464244403E424444444647433E3C
3D40414143423F414041463B47463E413E363A393E41403A3B41423D44413D3D40404045
4443403D3F43413D3F43414046463E3A3B43423D3E40404141443F404243464044423F3C
3B3D40413E403C393C3D3F4541413F3D3B3C3F42444342403F3F41433D43443C3A3F413D
3D3D4043413D3D3F3E42454341413E3B444547404348414545403E4246454342383C3C3C
403D393A434747403A393A3A423E41464646423B3E3E3C3A393C3E3E3D3C3C43403E4643
4749465152596D657F728C7DA3959F8A7E6B4D49474D453D45484A4A4D463D3C3F3D3F44
4543454B393B3E424545444142453F3F3D48433D3E453F393A393D46484A413D4749484F
6168616A757A8982867F89677D5E64565E5C715A746480828F93958F887C66574F4A514E
43473E40515F69797E8B96ADBFCED1DAD6DADDDED8DAD9CCD1C9C9C7C6C1C0B2A69A8E92
8F9BB8B7C6C2D3CBD1D2AF997C513F3A4E567D85686763746C795C4A4756637A95AFC6D2
D5DCC6BFCAD7C5C4CBC2BBC5C5C6CEC6D1D4D7DFDCE5D5DCD0D4BCA76F4A47504A4B626B
757460533E3F44424143474F4E5A565F656E6A6E829DB0AC999BA4C0B1C09C836D756673
54695F5B463D3F3F4145403F3A403C433D423D37433C44515A635E4A4B433E3A383D403C
403C3B3D3E3B3A3B3E3F3A3B3C3B413F3735363A3B3938393B393839383636383936383A
373A3E3B39393837363738393C3A393A3D3D3A37373736363636363536373D373A333939
39393939393939383A3B373B3A373B3A44413D3A39373533373E3C3738393A3D3A383738
393B3B3A3735393A36383F3E3C3D3C39393B3B383B3A3A3B3D3E3E3D3636373737363535
3638393A393B3E413634353A3D3C3D3F3C3B383635363839373535383A39393B393A3B3B
3A3837373637393939393B3C3A3B383739383A444C6C8B96948E8173564F403F3C353733
343633372A3D3434393D343932373B353336393C3D3C3A39373738393938373738353432
323B3D3538373739393736373636363737373737
4D4E4E4E4E4D4C4C484B47474F4D474847474848494848484D4B4848494948464D4B4846
4445474849484746444342414A464445454446494846484C4B4541434242434649494542
474746454546494C49464545434043494754514543464A514E4643494A46474E4939404B
3D45454B414347433C414743413E3E40413F3F413C3B3F4546403D3F3C42403F484C4643
40404346443E3D40483D404845404140434246453D3E44444844424444424244413F3E3E
3F424343413F3C3F3E42483D373E3A3E3F3D433E3D4344403F42403942433F4147433F45
4142414042443F383F423E3E484A434038403C353A41403D40443E3F4244463E44414142
403A3A3E4145423F403E3C4044423F3C3B3E44484242413F3D3D3F414147443C3D474840
41414345423D3B3E3B3D3D3C3D403F3D4145494346483E4244414245443F3C3E3E403B39
3E3E3C404243434244443D353936383C3E43443E40403E3C4045423C4743414744414947
535B626E625D63444D4E5F747593898A6A6C54594E494A424E48444747403C48443F4044
423D3F46403E3C3B3C3F414241453C3A3644423F3C3F403E47463F514E60576763777389
8997809991A6A7A6A1989779886E6A594C51544D544E586677899A9FAEAC989B8385818F
6C846A75474E4B4B444C546B69767990A1BBCBD0CED0D1CBD9D7D7D5D9D2D4C4A47D5C5A
4F52685E7D809FB4BDBDB9A399683E423E393C5853658487ACA4A4706D71788E9CB3C5CB
CBD2BBB6B9C7B1B8C5BDB0BDC3BABFBBCBCDD0DCDCDBE1D3E2CECDB3AE66525F625F695A
58615354545D585147414351555C525948535459698298989DA1C3D7DEE8D2A8B3A8B79B
A4A6B195957B62493E3E404B42443944403F4146404C6384A2ADA59B88735E4E4342423D
3D3A393C3F3D3D3E3E3E3637393A3F3B353233383B3A393A3C39393C3B3735373C383A3A
35363A373C3C3A373536393C413E3A3A3C3C3A3738373737373838393B36373138353A38
3536393B3C3C3B3A3737343B3B363B3C3D3B39393B3C3C3B38413F393736353839373737
393B3B3A3D3B3E3E383A414142403C393B3E3B353B3A3A3A3B3A393739393A3B3B3A3939
383635353739393A363536393A39393B3A393837373738393B3B3C3F3D3A3C403A3C3D3C
393635353436383A3A3B3C3E3C3E3C3C41454E5C7199B4A992816A52464134383B363934
3D313C323737313A3639313A323B4139343435363737383838383837373838383B363737
31313638373333363634363A3435373838383635
4D4F5153545351504E4C4A494A4B4C4C4C4B4E4A4C514C4C494F514A45474C4D4B4B5C5A
4E4A474E564E494A4B48454546474C514F49464748464B56554B45464C4A494B4B48484B
44464746484B49444547494C4D4D4C4A4A484645434349504E4745494D4A464643454441
444B4E4D3E40464642454742403C434242423D463F4245444140414344454A4C453C414C
46474140464540414244414348444148424042423E4046454544433F3B3B3E423E424240
40413F3D3C3E3F3F3E3C3C3D414345474644413F41434646403A3C423C4040414747474B
50473C393C41413F3E43433F414747413D35373F3F4146453F434244434044433F404141
3F3E3E3F423C3A39373B3F3E423E3D404041464E3F3A3C3A3F48413C4241463E42434536
44494642403C3A404045433D3F46453D3E3E45444446434744453E404447483F3C3F4346
443C393C3B3A3F433F3F413C3C3C36393B3B413F3F434145423A3F403A433E3F403B3F41
699693615958606A5A757A77736B69615B4E4848413E4042434646413E3F403E393E403E
3F4244433E383C3B423B3E3D3E403F3B3A3E414041403E4341485A5B82867F797C81848A
8397929398A8A3A8AAB8B39C988C8F896C7863755D70667F80848C959CA5ADAFAD8E7985
92A8AA854E4B4A4A493F42443D44434D5B64726E7A757D809AA4B6B8C0C9CABDB28B8976
7A6F886B7B5D6661546A5954544F3E3D3A45433E473F577289AFA49183918992878CA8B3
C0BFC6B9BFB2CFC6DFCAD4CBD6D1D0CDCDC4BDCCC4C6D1DBCFDDC3CDB4AC96A898A8A2A5
968D79705446715A504A686A8C92AFACB6A7A89A9C958C88808EA3D4D4E1D2D1BBD5CABC
B7D2CCC4C2B19F8F7060614F4535433E404049627C99B5BACDC5CDC9BCBFBCB5926C5442
3C3D3F3C3C3943383F3A383B3D3C3B3E393534383A3A3B3E403E3B3A3B3C3D3C3B3A3B3D
3D3B3D423B3736393937383B373B38373C3C3A3F383A3C3B3A3A3B3D363B3C3836383835
363A3A3836383A393A3939393939383846463D383C3B393E3A363C393A3F3A3F38393B3C
3D3C3C3B383B3A393B393B443D373B383637343D36393C3D3C3A393A3B3A3A3939383737
32363837383B3C3A33363735363B3C3A373A3A363436383835373B3D3A35373D3A324136
373D323832393B3B373B3E415A627376807D86899A96987F615448443736343536373736
343937353837363C3637383837363739343435373838383835373C403D38373A34373938
3535383C343234393935333535363342382E5064
4B4B4A4A4A4B4C4D4E4C4A494948464446464B494B504A484A4D4D49444446484F49514E
46494E584F4A4648484644454A4746474543444748464546464444454442434645424042
414446464748433E4545444343444547414143454342464C494544484B49464447454342
43444749433C3E434240413F433D43423F403E4441424343414041423D3D404546454A53
42433F3F45443F403D3D3D4146454549403C3D3F3E41423E404244423F3D3D3E4242403C
3C3F3F3D3D3E3E3E3D3D3E3F3E4042444544424147484949433D3E423C41414247464548
423F3C3E42433F3A3D403F3C3F4646413B393E413D3D4142393F3E41413D413F3F3F4041
41434547403A3A3B393C403E373B3F41424343433A373B3B424C47453D3A3F393E3F453B
3F44424143403D413B3E3E3A3B40423F4540423E3E4342473C403B3E414141373F3F4042
403D3D413C404A4D4541413D3E423E3F3D3B43443C3F3D41403B4245403F403B3B3D3F4D
82AFB48E908D867F62695B50504E4A3F454345444142423B454543414244433E3C3D3B37
3940464838363F41484144433E4043454648474548454146474A524D655D5F485E535E59
585D655E7770787B82959E949184877F847E82809082796B585B5D5F626466696A544D49
58535F4C444E3E483F404846404846484341494B474D45564C605D67687178868582868C
889F9EC19DB9A1B98B855F5252544C4E443E3E424D49484D4D738F909E9698A3A6AEB2B8
B9C8D0D6CBDFD1DAD4D1B1C1BBB3B0AAA3988C93A49CB4B0CCB6C3BFD7BFC8B4C9BFC8BB
B7B5ABA693757350575559857BBAD3E0D9D3DAD1D1C6B8AF988AA7AED6C8DCD3D3CED7AD
C3BFD1B5B7BEC3C2B7B1AE9F7A685D5F5D7F90B6AFBCBBB2A3A8A8B1BCB5C2BFC29C937B
4D413E4336493F453736393C3E3F3F3C3D39383B3D3D3D3F44423F3D3C3C3B3A38353539
3B3A3A3B3836373938353537393C38373B3A393D3B3A3938383A3C3E3E3F3F3D3C3D3E3D
36393B3A3A3D3E3D39383838393B3C3D3C3C38373A3B3A3C3C373B38393D393C3A3A3A3A
3A3B3B3C3A3937393A3537433D373B3B3D3E363637383A3B3A3939383A39383737373738
38393836383C3D3B333739393A3B3A37373E423E3938393A3937383A3A38393C3F40393F
36363834393539395368848DABBED1CCCDC7C2B498897D62494139373836353536373736
373A3836373635393637383837373738343536373738373734363A3E3C37363835373837
3636383A34333438393636383634333C434E6366
5150504F4F505151504F4E4E4E4C494749484D4A4C524E4D504F4F4E4B4747494A434948
4345474B4C4B4B4C4C4A494A4D4A494A49474646494A4845464947434747494C4B474443
4B4D4D4D4C4C484443444443403F4042484644423D3C434B434444444648454249434143
423E40464D4341454444423D403940423E42454643434342414041414744434445454343
4243404146464242494444474747474646403F424244423A3D404343403D3C3D42413E3B
3C3F403B3F3E3D3D3E3F40414142424342403F3E42424345434040433D41414246454244
4B46413F4041403E3B3D3B3A3F45453F3E434A483F3E4344393E3D42413C3E3A42403E3C
3C3D3E3F3F3B3C3D3B3D3F3B4044433D3B3F403E403E403E444B454540393C373B3B4441
3B3D3D3E42413D3D3E3F403E3C3D41444A42403A3B414043383D3B3F403C3C343B3B3F44
43403F3F3A3B40403B393B3A3E3F3A3E42454A4642433F42403C4447484045393D4D5877
9FB1A5808073635752503F3A434C4D453F42433D3A43443842403D3E4245413C3B3B3A39
3B3F4140403B3E3C443F44423E3E3F434644413E42413F444442443C464746404644433F
434D4848515A5556646E756A61515850584E60566E58573F4246423F4341404850463946
4E4F4A464848544245454644494F49493D3B404644444245434644454344405045504C5C
61667E92A9B5BFC9C2B79B9EA3AAA7A8A07F675144433D403C565E8181908EAEB5C2C6B7
C5C3C8CAD8CEE0BDC67B6E5B594F514F4F514E4F5D555978759689A7A2BCA6CEAEBEBAB7
B0AB9F9EA99D8C728D6F826B8781B8B8D9D5DBD9DFD5BFAF8C8F87B6ADCCBECAC3C6ACBF
9BC7B3A5A0B5C0BDC8D3CFCCC4B2C9ABC5ABB0A7ACA1A7786E555E5966716D9C91ABA6AE
8D5B56393F423B363C3B3F3E37383A353F3C3B3D3F3E3E3F38373637383A3A393D3A393D
40403E3D3C3C3E3F3C38383A3B3C39373939393C3C3937383B3D3D3B3937353636363738
36393A3A3C3F3E3B3E3C3A39393A3B3C3E3A3A3A383837333D393936383B38393D3B3938
37393B3C3935353C403B3E4E3F393A3B404339343B3A3A3A3B3B3A3A3A38373535363839
3E3D3935373C3D3B383A3B3A3A3A3937363F433F38373B3E3D3936383A3A3A3B3F403F3F
38333C3A3B49557A93BECEDADCE4E9DFDACEBDA6826D5B483C3A38393938363636373635
393B393637353437383737373838373736363737373736363435383B3B38363737373737
37373839353435373938393A32445A544D555148
4A4C4E4F4F4E4C4A474647484A4A484647444641434A48484B474749474241434B464B50
4E4C49464446484948464546454444454645423F454543414244423F434344464644403E
494845434243444443474B4C484442424645444340414A54414444414145443F45424141
403F42473E3D3F3E3F484A41423C42443E4044414343434443434140454646464746423E
4342404043434241443D4043424548434A444343414140393E4042403D3C3D40403F4041
4144433A3F3E3D3D40414141404141424241404041404041434241413D41404145433F40
43424141434444433B3C3B3C4146433C3E464B47404145453F434145433D3E393A393839
3B3D3E3F413D3F403D3E3D384A4A443C393C40414543444044474043483E403C3E394343
3C3A393B3F403C3943434546434248504C43413C3D423D3E3D413F41403C3D383A393E42
4140403C413D3B3C3F41413F3C3C353A42474A4341423E42413D4446423C423E51707E97
8D81684D50413B3E3E403B3A414748434144443C3A44473C403F3D3E4143403D3E3D3D3D
3E3E3C3948403F3B4541433E433F3E41444341413C424448454043403D4545474550565E
6C776B6A60634B4248474A44403B4C474542464441434943414742414D515667688375A3
78947D9788A087987F7E7C72736D6E585C494B3D404044404340464843443C423C43444B
494447505C656F79838A8CA5B2C6D1D3D5C0A8845D473D413F3E3D475354596A81A0929A
97AA95A0A6A7907D635D4F444F4D5349404E5D68685A7B69A86E9C8298868C838F95A1A4
A1A1959096969895A1C1B8B57D696B99A9BBC9C8CABB916B665F8874A487A394A592A586
9884987D80999F99B5CFCBD0C9CFCCD1C1BD918485979EAE877E584643465F54675C8283
AB988E7958513F3C3F3A3E413A3A3E3B3E3C3B3C3D3D3C3C3D3C3B3B3B3B39383B3A3A3B
3C3C3A3A373A3C3B383536383B3A383738393A3C3A38383C41423C373A3636393A373739
383A3A393A3C39353E3D3C3B3A3B3B3C3B363A3D3B3D3F393D3A3938393B39393E3C3937
3738393A3E3C3A3D3F3A3B46423D39363B3F3C38403E3C3C3D3E3E3D3938373737383939
403E3935373B3B383F3D3A3737383A3A373B3C3733363C403B3A39393A3A3B3B3B32412E
343A4258818EAFBBDADCE9E4E3D4C9C5BC9E7A6157483D39383837393B39373637373635
3A3A38373636353639373637383837363737373737363535363637393A39373739373636
37383837373636373838393B48617F6141413837
4D4F51525351504E4C4B4B4D4F5151504C4B4E494A4F4B4A4E4A4A4D4D4A494B4A44454C
4D4E504C42454848454443434C4B49484A4C4C4B504A45454546484B4848474748484643
494846454545474A454A50514E49474647484B4C484243474446443F3F42423E3F42423F
4045494A444648423D43443C3F3E40444143464142434546464442404244454544454646
44413F3E3D3E403F433E40413E41443F444041403A3B3E3C3D3F41403E3D3E40403E4245
4448483E3E3D3D3F4142413F393B3D4144464748494745444443403C3D403F4044423D3D
4443413F3D3B39373D3D3E40444641393A40413D3C40424341444245443F403C3C3C3C3D
3E3E3E3E3F3C3F413F3F3F3A41404244433F3F424140403E454842484A404340413A4141
3E3B3A3C4042423F4141444746454C574D45423C3D413D3F43454042403C403F423C3C3A
373C413F39393A3D41403C393B413C3C3D3E443F393B394142404647414341465D71726D
574B4038443C3F47414142403D3D3B383D3E414242474841414141414140404143403D3C
3D3D3D3D3F4048464B44433D3E3C3C3F424445453A424145443F434247495D5468657B7A
818089838A6C5A484A4748474948564E4D41413A3B3C4844474A413F484A52658A85AA9D
C0A3AF9CB1ABB4A6A4A09B9E98A595A18BA1857C5D594C4B42474243484F4B4146404D41
494845463E3B4453475356687390A5AAA6A89A8264453F41403F3A3B41454343495F5D49
59595F6A6461768AB47F6D7A9BA4AC927987A5BBA59A8C968AA999AC8F9A7A8A5F59636C
7E858591989C9D93B9CFDCBCB06F6258698490949B967553455353575665615F5E695E6C
577171807D8B81718FAFADB5C0B1BF90AD827F647A8DB2BFC7998758657179685D525F57
5F809AB9B39D7A50503D35393C3D403F3A393838393A38363D3C3C3C3D3C3A383A3C3C3A
3837383936393A383535383A39383838383A3D3D3B393A3E43433D383C393B3F3E3A393B
393A3A393A3C39343637393C3D3F3F3F3C363A3D3A3E413C3B3B393B3C3C3C3A3D3C3A39
38383838393D3A37393735383F3E393737383B3B413E3C3B3C3D3D3C38393A3A3B3A3939
3E3C3835373A3935403D3A383737393B3A3A383333373A3A373B3D3C3938393B3F3D3540
4672739FB2C4CDE3DCE4D2CEB8947268605245433F3B383B3C3735373B39373637373635
39373737363738373938363738383735373738373736353437383839393A39383A373536
3738383639393836363738383440553F2D38363C
4C4C4B4C4C4D4F4F4A4948494A4B4A4945454B48494C4340464545464746474847424048
47464B4645494B4947474645434546464849484545424143424041454645434143464542
4242444746444446494B4D4C4A494A4B4142454847444649484744414143413F3E43443F
3F464C4C4A484A4842444846414541424342443F4042444645444241484744403D3E4349
4844444340414342464544413D3F403E403E40403B3D4343393E4244423F3E3E433F4243
40474A423D3E3F404141403F393B3E41444546464544414041423F3A3C3E3C3D43423D3D
3E3E3E3E3F3F3F3E3F3F40434645403A3C3F3D3C3F42434540423E41423F423F4041423F
3C3938383D3A3D414042433F3C3B3F45443D3B3F403E3C3B4649424A463C413F423B413F
3E3B3D4142474A4841404143413F43494C45423B3A3F3F4545453E403F3B4041423D3E3D
363B423D3D424342413D3C403C423D3D3F41453E3F413F4647434646414D44444948493E
3D3D413C454143424940413F3D403E3D423D3D3F3E4144423D3C3D3D3B393B3F3E3C3C3F
4040404138404C45443C40403D4243413F4041403F41393B403D3F3C3D3E4C4D59575B51
4C4E54595F574C42444545434C4D584F56475A465F475B5150524F515A5D677A7D9C9EC6
9CB698A88D9774856D737677827E9575918596879987A0789F7FA39AADB2A282785D6246
4B453F4F524C4541555A4D4E4B5A605B575850484D3F454140483C48384D42424F707580
7F99A2BBB7BBB3CFCBDCBCC5CCD5D3B0959BA5AB9A86906E9A78A190987A8C829A8A7865
585D6A8FACC3C3B1ABCABBD19EAB8C765652485F73705E58615F664A625862516265644D
514C60727E816F627D9AA0A7AFAB87745E645458627E7CAA9E9C846C666B7D71857E9280
72807C84A7A7BBA19B774F3D3C3D3B3938383837383938353636383A3C3D3B393A3D3F3D
3B3B3B3A393C3C3A383A3D3E3937393B393C3E3D3D3B3A3B3E403E3C36373A3C3A363435
393B3C3B3C3F3E3A36373A3C3D3D3D3C3D39393938393A383A3C393C3C3A3E3C3C3B3B3B
3A393838353B3935383B39393A3B393C3A34383A3C3B393838393939383A3B3C3C3B3938
3A3A3835373938343A393A3C3B3837373B3C3A3838393732353B3F3D3837393A3B354048
8890B6C0C9C7CEBEBCA18F795B504445403D37383B3F3C3E3F39393A3938363636373635
3835353736383A383938373737373635373737373736353537393A3838393A393A383636
37383736393938353537373638363F3B363B3938
50505051525355564F4F4F50504F4D4B4A4A4F4C4D504947494B4A49494B4D4D4A49474F
4C464B45424647454546454343494D4E4D4D494544484B4B494949484B4B49474A4E4D49
47474A4D4D49494C4C4B49474647494B4A46444443414347494543454745424044454542
404246494A4644413E4449474B524540433E3D3A3D4042424140424345403C3D3D3D424B
4643464743434542383E3D3A3B3E4043423E4042404246433A3E424442403F40413D4243
3D42473E3E3F40403F3F3F3F3E3F414342413F3D3B3C3C3B3E413F3A3B3C3A3B42423E3E
3E40424647443F3A3F3F40424444413E404342424543424944443D3E3F3E423F3E41423F
3B393B3E413C3E403E414440403F403F3E3C3D3F43403C3B47494049433B403E413D423C
3A3A3F43414449484341403F3E3D3D3E4541433C393D3F4743433D41413C3F3F3E3D4444
3B3E433B383E3D393835363E3A3F393A4046493F474844494840413F39463E403D354045
494B50454640433D463B3F3F3C3E3A3A453E3C3B383D42413D3937393B3A3C3F3B3A3C41
413F40423C404840423F4645495252463D3F424144463B3A3F3E404045433D413A45423D
3D423840394B43423B4341383F3E48413D36473E533D4D5042454B555B5C64718780A98C
B88C9790908D80716160544F4A5146523E5D5568647873896F8B8FABB1BBB5AAA8A9B2A8
A288958DBC9195745C62555A595F5A545A4E555062565642463B3F3E434146413547656A
7A7F959BAF8CB2A6C1BACABFCED9D4B29E967D696453454D41655A7555635A867CB2ABB6
AAAAB1BABDD0CDCDCBBDBEA9C5BED3A38E74484B575B5E6D7F82837984807C74878D7F6E
6159556060645D6173848D8DA3A3A07A7D5C584F55656C7A836B624B4E5B5678759AA2AB
ADC2A4998A98A9C2CDB27E5448433C3B393B3B3A3B3D3C383E3E3E3F403E3A37383A3C3D
40423E38383B3B3837393A383A373B3D3A3C3E3B3A3A3A3A3A3B3C3D383D403D39373737
393C3D3B3B3D3E3C3A3B3B3B3B393837353634353A3C3B3D3B3F393A38353D3D3C3C3B3B
3A3A39393D3F3B37393A383B3A3A37403F33373A3A3A393837363637393A3B3B3B393837
38393836363939373736383C3B383637383B3C3938383734373B3D393738393840443F70
7D9E9EA475766A665755453E3B3E3A3A3339393C343C35363A3739393836353536373736
3834353736393B373939393837363636363737373736363535393A373537393939383736
3737373636383734343737353936343934303735
46484B4E4F4F4E4D4B4C4D4F504F4C494C494B45474E4B4C474A4A4645494C4A4746444C
48444D4A464A4B49494C4B4845494A4644464846464E4E45434A4F4E45454342454A4844
42414143424042474D4B4947474748494744444748464546494443494C4843404B474645
413C3F464342403B41545D55424D3D3A454446493C3E3F3E3C3D4145443C3A3F403C3C41
3C3A3F423E3E403B3B44423C3E3F4046433D3C3F3F4140393E4041403E3F42453D3A4244
3C3F41363F40403E3D3D3F413C3E404242403D3B3F403F3D3F413F3A3A3B383941423F3F
3F3C3A3B3F4344443F3E3F40424242423F444445453F3D464C4B413F3E3C403D4A4C4B45
3E3A3C40464140403D3F413D3C40413E3E434544433F3A3A494B414B463F423E423F433B
37383F423D3E4341403F3E3F424444423C3D443F3B3D3D4442423E45453E403D413F4544
3A3F4740383F3F4044413C3E36403E3C3B3D433E41413D41403A3B3941423A45493F474F
5B55564B463B3E3B3D3745484240393B3A3A3C3D3D43453F453D393D42444546413D3B3B
3A3A40473D3F46465354564E4852503D323941423D433A3738353B40443C45373E38473F
41393B3A433D4342384A4B3E433C413A403F31434049455B5D6272838A8B939C849F88B1
879D6D998798868A7374604C493E483E443D424C454A4C5E687E87909AA19A9D93A7A8AE
949F94C7BCCDBCC2B0B09C9B938E8789866E7F768C8E9C8DA08264675251474A413D4544
41424B454E4A5661688F83959CB9C7B7AEA6856C5A47494747423B453F496D5F68879CAD
C2BEC0AE9CA79CABB1C09EA898AAACB09199725B5A728691B5BAC3C1CCC2C2C4C8CFCABE
B4A39089858174726D6A706B76939CA0947D5F575A6F6E81786B524A4E466253705B898C
AFC3CDC1C8B6A5AEA7AA895E4E453C3B3C3E3F3D3F42403C3636393B3D3C3A373F3F4146
4E524A3E3D40403D3D3E3D393B383D3F3B3C3D3934373B3C3A3939393940423C37363838
3A3D3D39373839383939393939393939383B38373D3B36393D41393834313B3D3C3C3B3A
3A3A3B3B3735313238393B443F3A34404034383B3A3B3B3A373637383A3A3A3938383737
3739393636393B3A383535383836373A323739353335393B3B3B3936373A3A3640284244
4B504D4C4044453C38363A3A3439383D373C3739364036353B3A3C383736343536373736
3934353836393B3638393A38363535363636373737373636333839353335383939393837
363637373336363434373735373A333F392D3A35
4E5154524E4E5257514B494B4C49494B47504A434A4A4446444645464B504E4943454849
4847484943444547484A4B4B424447474341434443455448454549484B41424643434544
4245454B4942484B4A4C48413E4245453F41403F43494843494942474B494B4344474949
4948423B45424545404550524A4B434045444043424646413E3E3E3D423D3E3D393C413E
403F40434542414544404044433D3E4643443F4442393F403C3C403C3F45403E393E4140
41454541373F423E3A3A3C3C40403F3C3A3A3C3F3D3E453F3F454144403E3E3F3D3B3D41
41423D42403940403B3C3E3F3F41424444494746494540434749433E403F3E4347474644
413F3F3F4B44443C3B3F3C4242403F3E3F3F3E3C374548434547423D3D3E4540443E4240
3D3741463C3F453F3D40413F414647453B40413E3D40403F393C3F403F404448403D4341
4041393B3D3F3F3C3A3B3D3F353F46473E3D4B4A48484C4541434044443A3C4B5171765F
5C483F3D484245453A3B3C3C3B3A3B3C383D42423F3D3E42433E423E4249413F3C414441
3F43464747525D636D7A7D785F5F473A3B3C41403A4A4844413A3C3D46423A37403C443D
423E3D3B42444A4A4B453F3E43443E373F424743454B5368697685928F8A8777866A8E70
845D72677F74888A9B91957D6F5E57474650635D50655D867B907480717D6E635B5E7068
7970827D9B94A6A1A7A18B846E635D5D5A5A5E6F618D84AA9BB8C0C8B2BC805851374240
4136484238413E434547565B6D838D878B9591836D54584F5A4F504A495763716A707886
9794857A716D767A91849279816E856E7A7A7B6D636975888DA8BBD0D3D3D6D6DCD9C6E0
E0DCD6DFD5D0CAC7AC9D8677727A979AB0B37F655672868E7D766B6D6162605B56545A63
5E878DB2BACFC1C3B4A4877469686858554839453C3942393E3B38403A43434361667476
919D8F61493E3C443B3F3B3F3E3B3A3B3B38383A37383A3D40403F3D36383A3B3A373533
3637393A3B3A3938383B3B3735373836323336383A3C3C3D383B3B3635393C3C383C3935
3635373E3436383838393A3C3536363737383837383A3C3C3B3B3C3D3D3B3A3B3C3D3C3B
383C3D39383A3A39393938383838393934383936373A3A36393939383736363635353637
37373738373738393A3B3B3C39393A3A3A393939353535383B3C3C3C363636363638393A
383634343638383832323B3735373339403A373A3C39363639393937363536373738393A
3938383736363535353637373336383633333537
515150504F4E4E4D524E4B4C4D4D4D4E485F604F4846474D434546464A4E4D4943454748
48474848464646464848484744464A4A47464749454A53464743464D4B44454745444642
4346434644414A4D494948454446474740424446494A464242444345444243413B404241
40444747413F403E3C3F454841403F454A4842423F41403D3E40403C3D3B3F403C3E413E
3F3E3F42444546493F3C3C3F3F3E42483B3F3D43423D42423D3D413D3E443F3F44423E3A
393C3D3D3C3F413F3F414241444443413F3E3F4038393F3A393E3A3C3D3D3E41403D3D40
3B3D3A41413C42433D3B393D434747444649464345413D4040423F3E42413E4141403F3E
3F403F3E403D423F3E423D403C3C3E42464846433D423D383D4447493E3E4440453F4340
423E42443C3A3B3436383A3B3D4142413B3F3F3C3B3D3E3D36383A3A393B3F43413E4341
40423C3E3B39383A3C3E3F413F4344443D3B423C3F3D45454241414A4460668C6F825947
3F3A3B353B384246393B3C3C3A3A3C3E37393C3E3E3E3E3F3D393D3A3E46403E383F4342
4040403F5860696E6E6A61595453433D3D3C434245483E3F494A48414245474344484847
404648524C4E4443443F3C3D40424140474445414343404A3C43484F4D4C5045453F454E
41464A4F5F6A87928D86887F67565A53554F594F5257546365655555494E464D4A44565C
5A5A505E56686D7E868F8A896D57494760526A505C5159637F89A1A3C3CABB9F66454442
4B41493C393E3C3D3D3B46474A4E4F4F5D7272615A4D5A52574A4A46384045627C939094
8C8B85806D574F465C61596656696D757C7D837D75726C6F64698586968EA4B2BFCFD3D2
DFDCE8E3DEDCD9DFD8D4C3B6ADB3B39C8A926E62475461726B6A6C7B71716C635D585048
3E506A69888FA4AEBAAA969399A4A89486605842403B3F3C3F3C3C4A50697B889CACBDD0
CAC8C4BC6D594746403D3A3A3937383C3D3C3B3C3838393B3C3C3B3A3B3A383838383837
353638393A3B3A3A3A3D3C38363839393537393B3C3B3A393B3C3C393838393834383B3B
3B393739373737393B3C3B393435383B3D3E3F4038393A3B3A3939393A3A393A3A3A3A39
363838353437383636363535353637373638393838393837313539383533343639393938
383838383C3C3B3A3938373738383939393838383A383737383939383737363636373838
393837373838393936353C39363734393C3836393A383737383939373635363738383737
3736373736363636353535353536363533333538
524F4D4E51514D484C4B4947484B4B4A5983845B49535349494A4A484849484645454647
48484847484646464849484745484847454242444B4C4A3D4C44404F49484A4A47484741
454A45454342494845444447484747483F3F41444543403F4741404044463F3B47484643
42434444494A474445454649443D3C42454544403F3E3D3D4044433F3F3E41423F3F4344
404145464646454242403E3D3D3E4246414644423F3B3C363F3E423D3D413E404C453E3A
3939393B41403E3C3E403E3A414141403F3E3F3F3E3E423E3D403C3D3B3C3F43423F3E40
40413E403E393C3C413E3B3D414342404647423F403F3D3F3C3E3D4045454141413E3C3C
3E3F3E3C3A3A404040413C3D49433C3A3B3D3E3D42433E3C40403F42494649434740403C
3E3D3E414545403A3C3B3D41424242433D3F3E3C3A3C3E3E40403F3D3B3C404349464741
3E3E3A3B443C383B3D3A393B45464242403F4036443E45474443485A80858768644A4235
3C3E44393A363F413B3D3E3C39393B3E3E3C3C3E3F3F3D3A413F3F3A3A3E39383B3D3C39
393F464A44424142403D3C3E43413D3F3B394143514F444C5C615E5370637E65795E6C6F
82808778745B5245443F3C3E3E3C3E42413E3F3D41413A4143454345444449433F465167
66778385978E9F91947E877975687D808B777F7789958BA794A2898D7E8184937F4F4040
48414A445247575F6472737964564E4E5254565A4D554D595C66627D829D888D553B3B3E
4E4A51493D3F3E3E3E3B423F4D49494749595F55473E4B41453F43403D433F5671848390
A5A4A3A18768574648404742585F7E97A5A7B0AB9D8A7166786468545853697E80AFC3DB
D1E8DBDADBDAD1D0CDCDC4C2C9D6D6BB998E694D56453B4A47474C606767605552565246
3D41544E595F6C7C8D8A8B959DB4CBC4BBB182855B4B46393D3B3B43486892B0C4CCD9D8
CFAA9C847B554750403B4F363E3B3A3D3E3A37363939393A3A3B3C3D3C3A38383A3B3A39
38383939393939393C3D3C3937393B3B3637383A3B3C3C3C3837393A3D3A3A393B393736
34373B3D3B38373A3E3F3B3638393A3B3C3C3C3B3E3D3D3C3C3A38363738383838373838
3B3B3A39393C3C3B3838383839393A3B3A39393A3A3837373A3E413E373335393D3C3A39
39393A3A3E3E3C3B3937363538373737373837373C393635363737373837363635363636
393A3A3A3939393938383D3A373835393836363838373638373838373635373839383635
3535363637363636353534343736353433343638
52504E505354514E4D50504D4E51514E485153504C4546504E4E4D4A4746474849484748
4A4B4A49494747494C4E4D4C4E514E4B4B49494D4C4E4D4C69594047474A4C4B494B4842
464D4948464547414440404547454445484545484845464A454146424348444844413F42
4A4D4841494B46434846424549414041434B4E444141414143454443474442403E3E4449
4242454644464642454542403F4244463D4343403F42423B413F433E3C3F3D414B444042
43403D3D42403E3C3D3D3D3B3F3F3F3E3F404142404042403E3E3C3C3D3D4043423E3E40
3B3C3C3D3D3C40423F40403E3B3B3D3F45433F3C3E3F41423F3E3E41464846444544413F
3E3D3D3D43403E3A3A3C3D40504B44403F3E3B3740413F404240414A4D4849434942413C
3A434441413D38393E3C3D41403C3A3C3D3E3E3C3B3D3F413C3C3B39393C42464B4A473F
3B3B3A3A48413F43433E3E44424540434445473E433C3D3B3C475971677050533648343E
3D3B3F3A403B3F3C3E40403D38373A3E4241404142413F3D3E3E3F3C3D41403F423F3A36
373F4A514242413F3C3A3A3B3F393E453E3A4246434A4D58605E5B5360746C9A789A8098
858370705A5C4B4A453F3C3F3F3C3D414240413E3F3E3A44383B393F414248444E685792
76A8989F9A9898ABA5B0AAA8A494A2959B83918EA39FB6ACC1B1BFB7BFC7CDD5B471493F
3D4032493D493D4D444941494445444345444841443E454750494E4B615153584F444743
46393E3E3D3B414147464F4C5452585547484F483F353E363C3E413C4046414A4A4B4D63
66686B6E6258584A4D4840474A595E84A1ADC4CBC5B69E959D968F8C7B7C6C68656E8B98
AECACBD6D5DED9CFC8C5C6D0C6D2DEDAD3CFB8948B66484F4846434D4C4D4D484447463D
3D44445946574C5A595F696E6A7FA1A5C1ADB6A4A3766448413D3C3B3540586987B2BDDB
C8BF844E5B3B3E35434433383A38383C3F3D3B3B3A3A3A3A3B3E41443A39393B3E3E3B37
3D3C3B39383736363A3C3C3A39393A3A3736353535373A3B3A35393A413A3B3A3937393A
373737343A39383B3E3D39353B3A3837363535353D3B3837383836353638393837363739
393938383A3B3A383A3A3A3A3A3B3C3D3D39393C3B3735383D3E3C38323134383E3C3A39
393A3B3B3C3B3B3A39393838393837373838383739373535363737373636363636363636
383A3C3C3A38373838393B39383737393637373736343537363737363536373939383636
3636363538373636353637373835343536353537
4D4D4C4B4B4C4C4D454A4C4A4A4C4A46504A4851564D4951504F4D4A47474A4D44434242
444544434443434446484847494C47434646464C494B4A4C6A593F46444A4C4A4B4C4946
474D494948484A434742414446434244423F3E424240424645414642444B4A504845454D
575A565046484341474540423C3E434348585A4A42444645424042454945403F3D3B3E45
423E3F413F454C4B3F404141434547464045453E3F45443E423F433F3D3F3C4247424146
484541403E3E404040414447464442414243454643434142423F3F3E41404042403C3D40
403F3F3C3A3C3D3F3D3F403E3C3D414446423E3C3D404242433F3D3E4145464544464541
3C3A3C3F3B3F4245443F3B3646423E3D404344443D43484A4840404B433E413D47434540
44575C51463D3C474644454847423F413B3A3B3B3B3C3F4248464441404144474346423C
3A3C4140403E424949464B553D44414243424744434348423C3D3C444240423F413F3F38
42393B3C453C3C3A3D3E3E3C3A3A3D403F414242414041423D3F3E3E404344414040403F
3E3E3F413D4447423E3F3C36443C434A433F444A4146474C4B4D5B617E84A684A7819372
74625A454F444941423C3A3E43434242423F413E42423E474A4B434445444A4B4E546270
8B909C8BAAA7B3ACAC9BA19E9683836D7C758C8993908D9C9AB0B5B6B5C0BEB3986C5148
4F584E6558604D5B51544C595C65645F615B6D5974617B747D7375676B4643444B464B4B
4A3F4243423A423E434148434D474F544E4F5046453E47424445443E3D4341463E403A3D
464A494641454D424D40484049423D5465769AB7CEDCDBDDDBE2D9DBC8CBB69CA4848471
6D7E768FA7BECDCCCAC3C0C6C8D2C7DFCEE9DCD2DAB8978C71604D46534B4A494443433C
444354505B45524E4A4B49463C465A5570757DB0B0B17D614F4440404346443B3F6183A0
CED9C1896F4C3F434646553F3B38383B3D3C3C3D3C3B3A3A3B3E41433B3A393B3E3E3B38
3D3C3B393837363637383A3B393837383838393A3C3E4042413A3E3B42383A393F3E3D3D
3C3D3D3C37393B3C3B3937363938363536393C3E403E3D3E42474A4B38393A3A3837393A
3A393A3C3E3D3A38383737373738393A3D3A3A3C3B3735383937363537393A3B3B393737
393B3B3B39393939393939393A3937373839393837363636373736353434353636373737
36383B3B3937363636373738373638393638393734333435363637363535373839383738
393937353937363536383A3C3734353838353436
57585855515051544A4E50504F4E4D4B444F4F474B5653455553504D484546494C4B4A4A
4B4C4C4B4E4E4E4E4D4D4D4D53564F494C49464C4845433C4D433D4C434949484A4A4849
494B444548494E4A4B48464646444445444345484A484748504945414346434344414043
45454545494947464A4946464447453D3E49473840434645403C3F4643403D3E403B393F
3F393F46424246433F3E3F414342403F3E40433E404A4845433E42403F403C4145424143
444340403C3D3F40403F424648464341414141414343404445404240444140403D3B3C40
3F3F433E3C3F3D3E4542403F4042434348423F3E3D3F413E433D3B3B3B3F43413F41413E
39383C4041423D3E3E3D4140423E3936393F45493D403F3D3F4250643D393B38413D403B
3A484A423E3C3C423D3C3D3F3F3D3C3C3837383939383B3F42413F3C3B3A3A3B4247413B
393B43413C3E4346413C40483C46423F3D3A41424140423A373A383B403A3C3F363A403F
42393C3E4437393B393A3B3C3D3F4244434444423E3B3B3C3E413D3E4040413A3A3B3E42
413D39383D44443C393F423E433B4044413E3D4444433F43444F69757B8E73805F6F5447
4C4737403B473D3B423E3B3E4345433E403B3B3E47494043464841464F5566718C9897B3
B2C2B0A49E97828E7A85787F786B6D63818896899C808F77917E8F726E8287817F797373
82899485896C69695D64606D707B7E7C767F85949DADB5BACBD6CCC68F684945493C3D41
4341423B463B473E423E463F423E454E52585B534F49504A44424244454B47464351483A
414A4745474B50495946795C79585C58585C718BADCDDBE5ECECE9E1E0E0EAD5D5C1B7AD
899061655D6B7B8396A3B1B7B5B0C1AFC9C2E0DBE1D8CECBB2AA9E958C796F6A60584E40
516956754B513A454F514B4743464B4044444D6A93808C6F7D74716C71716852494A405F
81B8C0C5A6955B43443A49473E3C3B3C3B39393C403D3937393B3C3C3E3B3837393B3C3B
38383939393939393637383A393636383C3D3D3D3C3B3A3A3E39403B453C413E3E4A5358
5A50413C36393B3C3A3837383D3B3A3A3B3E42453F3D3938383A3B3C3A3A3B3A3A393A3A
3F3D3E41413E3C3C3A393938383939393C3B3A3B3A3836373938383B3E3F3C393A373536
383A3A393A3A3939383737363C393636383A3A3838373737383735333334353637383838
35373939393736353537343637353938373A3A3734343434363737363535363738373739
3B3B38363837363536393C3D3634363A3A353336
4F4F4E4C4A48484949494B4B4A4747494443454A4A47454752504F4F4B46444544444443
4242434546474947454445474D524C474B463F444B474D444840414C454846464846444B
4B48414548474B494A4B4A474545454342424243454644404C4E4B47403A3D3E46424042
4342434646434445434444423C3F3C39404645413F40434542404248403D3A3F45413D44
4137404B443D3D39443F3F43433E3A3B4644474040463F3D433D414141413C4142434342
4242403E3F3C3C3E3F3D3C3D4241404142413F3E3D3E3940413C403D42403F3F3D3A3C40
43444A433F3F37364644413F3F3F4040463F3E3F3D3F403B3F3B3C3E3B3E413E3E3D3B3A
3A3B3D3F3D403B3E3F3D434043424241404143444245423F40404651413C3E383E393B37
3E44413B3B3F403E404141404041403F3A393A3C3B38393D3A3B3D3F41434444444B433D
393B44403E4043423C3735373C46403C3B3A41453E383B3B3E413E41423D3F4636373635
363238383F393D3E39393A3C3F414343474543413F3D3B3A393D393E4243443B39383A3F
403D3B3D3E4445413C3C3B393D383B3C3F3E373E3A3C414D4E4F5A5B59544B454342403B
3D393D3B453F3E373E403F3B3D43433E433E3C3D46483F44475258697C889CABABA9ADA8
A89E90858B776262605E53506263707797A0A4958C828C918F8D866B647B868A969C9DA5
A3B3A49D827A656E59615A6363717A7C888E919A9EAEAFB2C2CBE5D0C394967E6E5B554F
413F433B4236483E413D443D383B404244494E4E51464A47403E3F45434A4240404C443F
3F4741444B464648444879908AACA6B3A9A3A9B0C1D4D9DFDFD2DAE4E4DBDCD3D5CCD5CE
D4CFB6999B8B79616167736E80877D848AADB4BEBBBBC0C7B9C1C2BDB0ABB3BBB6B1A28A
747786697146473F40484241444547404D423A413F575B73636F868FA2ADAE9B6C554B33
46597591BFA0A26F3C43374336373A3D3D3B3E42433E39373A3B3B393E3C393737383A3B
353638393A3B3A3A383737393835373B403D3A38393C40434C4D59536059605B8BA5B4B9
B38E635339393A3A3B3B3A393E3D3C3B3B3B3D3D363638393B3E42443B3A3A3A3B3B3A3A
3C3A3A3B3A3636393D3C3C3B3A3A3A3A3A3B3B393939383637363636373736353A373536
393A393739393838373636353B3835353739393738373636373838373536373838383737
36373738393938363739343737343A37373A3A3735373735373737363434353638363436
393B3937363636363738393A3634363B39333339
504F4F5050504E4C4E4B4B4C4A46484D48494C4E4E4D4C4A4545494E4F4B494A494A4A48
4646484A474A4D4D4A494C4F434C4A4A524E474B52484F4645414548474845454742414B
4B4842484B444441454A4A4542434340494844404348474345484246464145404E464246
49474341454043443F40433F3D414349514D4647413F41454746484C433F393F4947464E
473639433C383F42443E3E4546413E41403E444042484040433C404143433D403E444745
4445423D413C3A404544413F3F3F41454848454340413B4446414543403E3E3F3D3B3D40
373B474544483F3E3B3E3F3D393A3F44413B3C3E3D40413B3D3B40433F40423E423D3838
3D403F3C3A3F3C41413C403B3C3C3B3A3A3E454B46484440413F3B3D423E403B413C3F3C
3841443C353B43464144423E3D3F3E3B403E3F403F3B3B3E3F404041403E3C3A4049423E
3B3D48453B3E4244454443403A443D3B3E3F474C4A3B393A3D3C373D3E363B3E3E3A3E3C
433F413C4441433E3D3B3B3D4041403E44403E40454745423F433D41444242363F3D3E42
413D3A3B3C3F4344413C3B3C3D3B3D3C45463A4046484C544C42443D4142413F3C494040
3E40414542423E3D353C3E38394248463A383A3B434A4B59616E747F847C7E8475786572
58746376636356665A686779838A99A2B9C0C5BFBBAFC1ADA0827D5B5D686B6B767C8191
A8B2BEA5B499978F878F8A969CB0BDC2BEC1BDC2BDD0CAD0D1D6D5E3DAE3DFC5C4B1A48B
5F4F56547D6E7D6C67595A4F41464643454748494B3D434948453E3E393F384349483B44
4A4D41464F423F4B746286776B93AEC1D6D9E6EAEAE8DCDABEA19FC7C0C8BBC9ADBFBBC6
BCD1D9D1CCC2C0B2B1ADA993A59388617E7D7D696360657577909D9D9EA9C1D1D3D9D4BF
9DAC8A976B7B4A5A4C5346424B4C49433A3F3B404136484E54647F8AA4B7BFAB99837048
4348424D658E9F985A3C453E383A3E403D393A3E443E39393D403F3C3A3A3A3A39383737
3637393A3B3A39383B3836373635383E3A38383F4E637885AEB2C1B9C6BEC5BECAD3C0A6
9169443F3D3A38393D3F3C3937373737373635353E3F403F3C3B3B3C3B3A39393B3B3A39
403D3C3B3936383D3B3A393837363636383B3C38383A39353939373534373D423B393738
3A3A383537373737373737373A3733333638383636343334373A3C3C3737383838373635
373737383A3B3937393C353737343A363739393736393936373838363433343637343233
373A393833343637373736353734363A3832333B
494E4F4C4B4E4F4E494B4C4C494847474646464747464748404A48464C4842494B424750
4C4543424144484A4946454441464A4A454142453F464A47444443414045434349484649
434545434548464140464A494847454144444443434241404446413D403E3C403C3D3D3E
4244413C4842434141403A3F413E44443C464D42393F3F474349484C3F3F3E3E43494740
3C3B3A3F433B3A46404443454C483E3D423F4244414243403F3B38404744454E3E3D3D3F
4142424048443E44454145463D433C444A4141413D423F42413E42403F433E3E47423A41
463E3A3E42403E3D4040403E3D3D3F403B40413E4148463D4340454A453B3B42443D4141
3E3C3B4745443F3A3B40413E3A3D4041414041414743423F3C434842453B3B403D3A3F43
3D3E3B43453E403C404D403A3B463F433E3A393E42413F3F474239413E433E403E3C433E
3F47474F423E4046453D3C42453C3F413A3F4641463C373D46484745383D4048423E453E
3F413C42454449443D42433F3F43454441413D3F3F444D46453E45473D3E41383C3D4040
3B37383E3D3B3E44433C3A3F4443403F3E3E3F3F44464744444545433C3C41403B3F4643
3943444142403E423C37373D3F3A3B4041463F4E566A7B848D8C9690897670645A625965
5C6E616F5B6E6671858EA0A6A5AAA79974817285757E7C74606A6F6F6766676B76879AA6
B1AFA9949496A09E949AA1A8B2BDC4C6C9D1CAD3D4DBD4DCDAD4E3D0E6D8EDE9DCE3D3CC
A4A49FAEAFC4BEC79FB191A68B8E6D78685F5C5F47494452474141413E544A4D45493B4A
4C87987A764B54496DB3B5CDA7BFA0B4BEC8DEE3EAE9EBDED2AEA98C8A8784859E8C8F81
A3AFC5C3D2D7D4E1DAE1D0DAC8D7BABBA0B8A2A676724F4A434D545F6A668598C2C2D1C7
C6A2886C7C76807A847A766C625D47443E3A45373E3A3D43414C5871818A9EA6B1ACA182
5A424E45434855616C4C393D3C3B3E3C3E3E3A4642403D3B3C3C3C3C3A393736373A3D3F
3B383A3B383A3C393734353B3C37383E46556A89AFC4CBD0D2D8D2D8D1C9B5B39B997057
4835393C3A3D3E3A38393A3834373A3C3B3A3A3A37383B3D3C38373A36383A3D3D3B3836
363A3D37383B363A3A3F393843423B403A3837383635394039393839393A3B3B3D3A3635
3738363435353636373737383636383C3D393738363435383938383B3633373F403A383C
3535383A3C3C39373535373839393938303133353738393A313335363536383B3A393737
3839393834363737363637383236393936353639
4E51514F4E51514F4A4B4B4B4A49484745474A4B4C4E4F4E454E4C4A504B464C564D4B4B
433F434641454A4C4B49474745494D4D4B4A4B4E43454544454746413C41414348474446
47494A47474845413C4246464545433F42424241414040404345413F42413E4040444440
3F454A4B4A4445434445424852524F463F413F35434744463D4142494644414043464440
41413F41443F3E4641413F3F44454344403D3F413F42464545423E404442414943403D3C
3D40414142433C3E3F4045423E423C43494242413E424042413C403D373D3D414A443A3F
3E3C3C3E3F4043463E3F403F3E3E3F40403F3C3A3F45443D3A3E424545413E4044404545
42403D463E3E3D3B3C403F3C3C3D3F4040404041383A40413E4245403E393A3D3A3C403F
3A3D414B4D46413C3841393A3D423B41433E3D3F4241414342413E4540413C3F3C3B413F
3E3F393B393B3E42424143463E383E423C3F443E3F3C3B3B3A3B40473F42444C4A474B42
3D403D42434145414142423F3D3E3F3E3B4243433C3E4C4C433D3F403A3A3C373836363A
3D3D3E40413C3B3F3E3B3D434A453F3D3E3F3D3B383B3C3B3C3E3E3B373B4140393C4241
3C44443F403F3D403A373A40424041444655597789A1B8C1BBB6BBB1AA9992868281837C
7D7F777E6E8174848E9598999B847F60534B5550575561726F879A9D8F8A868B99AAB7BE
BFBAB7AAAEADB7B8B8B7B2AFB2BBC2C4BBC4BBCAC2D5CED8CFCFC9D1CCD3D0D3CAC8C6BE
BEB3ACA7A6A8BCA7B2A2AAA7A8A7939B91989AAB9EA0929E88634C5A8CB3A5B39FA98CA1
A2C9D4C6CEB3AFA3AFC6DCE1E6DEDAD8D6DFE6DBE2E2E4D9C6C8B2C68FAA90AA8E9A797E
6879868CADB8C1D7D9E6DAE5E1E0DAC8D1CCC7BBB7AA9A716E474C40453F495A7692B1BC
B9AE708C5D8153586E6E8690A7A487664F40424346453E3F42423B42484C617082A7B8C2
9A794F3F3E3B434F573D333D3B3938393F403A383C3B3A3B3C3E3D3D3A39393838393A3A
3A36383A38393B383D3A3A39373C516691A2B2BCC0B9AFAFB3B2B198987C6E5E4C533E39
3B32383B3B3E3E39363737353B3B3A3939393B3C3838393C3A37373A3738393A3A3A3938
35393B32353B3637303A3E495B5A4E4C3B3837383735373C3938373738393938423F3A39
3939363336373737383838393A3635363635373B39363639393737393236425051453A37
373737383A3938363738393A3A3A3A39343435373738383833353636363638393A383636
3738373734353636353536373336383835343638
4C4D4C4B4B4D4C4A4C4A494A4B4B49464E504F4B4A4E4E4B454C4A484C4842474A494C4B
4646494A46494B4A4846484A48494A49474546474B4845454A4E4A45474A484748464344
474A4C4B4A48454240444644444647464141403F3F3F404042434140444340404146453E
3D454B4B544B4B46424341474D534D434549443E404240423E44464B4642404144454647
4343403F41403F414642403F3D4043424742413F3B3D41404042403E4243444A44423E3D
3D3E3F3F4247403E40444B4542433D414641403E4247444745404340393D3A3D44413C42
3E4346413B3B40453D3E40403F3F40414C443B393D3F3C373840414047463F3D3E3E4543
403F3B3F3C3D3B39393B3B393F3E3E3E3F404040393D43433E3D3E3A3F3D3E3D3B414643
423F41424546444643453D4144423B42413D3A3A3A3B3D403E404147413F3C3F42404647
47463E3E404445403C3B3B3B3D393E403B3D403A40403F3C3633383F3939394143414239
393D3B3E3D3B3E3C41403F3F3C393A3C404443433D3F4A4746413E3C3B3C3D3B3E3A383A
3B3A393B433D3A3D3E3C3E4447413B3B4042403D3E403F3B3A3A3734343A403E393A3E3D
3E44443F3E3E3D3E3B3A3A3B3B3B3C3D4B657196A2AAB3B0AC9B907D7A77807C7D85838A
6E82697F73887A928B8D777078627766886D80657261606A5F6269685F5A56565D636667
676265636E6D777B8380797273787B7B85829584978B9D93A99DA3969F88887F78746E64
6C6057515355524D4A4C51515F6F5A757A87AABCC7C7D7E1CEA9A19ED3D4E5C8C1ACBAAE
CDD3CDCBDBE0E0E3E4E5DDE9DAD7CAD1C8D7DCCED7D4CCBFAC9FAA9291747F7E7D849586
9A86988774818EA4AAB9B0BCB7B9A3A89BAA9B9D9099898A6F6652504A483F453F576570
7E68746182676D584D525E8096C0C0BB9F7D69524A47473F45443A3B413F454F4A628689
936E4D363D3A44556456463D3D393534363B3D3A3939393A3C3D3C3B3A3A3A3A3A383736
3B36383938393A3636383A3A373C516679858C887D6F66676266594B42433B34363F3437
3C34353436393938373839393E3C3A39393A3B3B3A3838393836383B383837373738393A
2F363C36393E36373C546D818973503F3B3836373736363739373535363736353D3A3838
3A3B393838383838383939393A363334333335393B39383A393636373533363C3D373536
383736363737363538383939393938383737373837373636353637373636373839373535
3636353534353635343334353537383734343537
51504E4E4F504E4C4E4B48494C4D4A474B4E4B44454E524E4A4E4C4B4D4A454843484C4C
4B4B48425151504B47474C504C4B4947464545454D4946474B4C4944504F4B4746454547
43474A4B4A4846454546454141464C4D4342403F3E3F4041414140414444413F43484741
444C4C45504648443F42444A474D4841454C484141414042434442414A464344433F3F42
4445423F41444441433F42443F40433F443F3F3E3B3E43424147453F3F3F3D3F40404040
403F3D3B3F423C3B3D3F474347443F4042403E3B41464447454043403F3F3C3C413E3C42
42494C443C3A3D3E3D3E3F3F3F3F4143453E3A3D414140414146413F47463E3D3D3E4440
3D3F3B3E4946423D3B3C3E3F413E3C3C3E3F3F3F3C3E40414043454645403E3D3B404848
433C3F3C3E43404447463E3E413F3A3F44413F3D3C3D3F4241404044413F3D3F433F4043
4544403F3E40413F3B3A3B3E433E3E3D38393C3942403E3D3D3C3A3A3B3A3A3C3E3E3E3A
3C3E3F3E3B393C3D3E3C3C3E3D393A3F474641413F41483F48433C383B3D3D3E3C3B3C3C
3A373B41413E3D4142403E3F403D3B3D4042413F393A3936373A3A37373A3C3B3A3C3D3A
3F43434040403E3D393A3A3A3D444A4E586B697D777070686558534A535A67648383A17B
6D524C5650685E837D9181868E77785C7A55594453494245433E3B3E3F4042413F3C3A3A
403C403D47454A484543403E434B4F4F515A6066575D5750534B4C4C524B4D4E404C4449
434A45534B50554A4E494D4F43474B5050646E8D97C2BDDBD2DBBACDC7E5D2D3B0AA7B79
908D91AAC3DCDCE6E8E6ECDDDEAE917D9DA8B3B2C4C8C9C2BFC2ACB0928C766D6456595D
6B9292A7A9B4BABDAEA38786726E675E5C585C5F4D4D4B474846494A3B4143463B434240
464440494A5151575455707A929FCAD8D9C6BFA08E7C715245483E3A424441413F3D4148
4D54413D393A44576F766447403A3E3B3536373B3E3C3B3B3B3A3937393A3A3A3A383736
3E39393A38393A353B3A3B3C3935363A3F41403F3D3B3B3C3B443C4037443C3B3B413739
3C3634323637383838393A3A3A3A393B3C3C3A383B3836373736383C3938383635363839
34373B353436364277889391816143373937353638383634393735353637363436343435
37393837383838383838383837353537373433343C39393A393636383733323434323337
363534353636353436363636363535353737373736353434353536363636363738363434
3435343334353535333233333737373634333537
514F4E4E4F4F4E4D4E4B49494C4D4B494A4D4A44464E504B4A4C4B4A4C49464747484643
474C49434A4B4A474444484B474544444547484848474647474543414746464545464747
42444748474444444244433F3F4448494645434140404142403F41434343413E3E444442
444B4C474F4346443F424447464644414147473E3E40444342404040403E3F4343414246
3E3F3E3B3D42433E3D3A404542454945433F40403C3E413F3D45443E3E3D3A393D3E4041
403F3E3D403F3A3E3F3C43454541403F3F413F3C3A3E3D403F3B3E3C3D3E3F42443F3C3F
3F4548444141403E3F3F3F3E3E3F4244403E4045444141464746403F43403C3F42424741
3F4341454946423F3C3B3C3E413E3B3B3D3E3F3F42403E3F4447484A453C3C403D3B3F43
433D3F393A403D413F413F3C414241404241403E3E3F404147403D3D413F4040423E3C41
43403D3B3B393B403F3A3D45433F3F3D3A3A3C3A403D3A3B4043423E4142413E3D3E3F43
434445413D3D3E433E3B3C3E3D3A3C41434542423E3F4741433F3835383B3B3C3F3D3D3E
3C3A3D434240414444413D3C3E4041413F3D3C3C3C3B3836383C3E3C3E3D39373C403D39
3D3F41414143423D3D3F3F3E3F43484B4851464E4543484745434F556975817B75797E75
506056757586778B6F73595C5C514A414B433F434141414245424141383B404345454546
3B3D423A4242443B41403D3D4450595C7D769378896978626E635C514F464B4E4B5E6779
809095A5A0B592A0688E698C6E7F6D74685B6A6F9D9DC4BCD3C7D8C5CAC2E4D7DDC0BE92
7865607D9BBFCDD7D7E4D8E9CFC891785F5961687C8CA4AAB6CAD1D3D5CAC7B5B7999A86
8A8C8B9CACB6BEC4C5CCC4CCBEC8B2CDAAC1ACB98C83776D61594C454241484143424840
43474551474A414546565D7D778DA8BCCED7D3E1C0C8AE987E7E694B434746453F3B393C
3C453B3F393B3E495C747A7447393E3E3E3E353C423F3C3A3A3A39383A39393939393939
413C3D3D393A3A35393534373B3B3A3A3A373637393A383539363E363E333933373A3537
3A3838363D3C3A3A39373636383737383B3B3A383C3836373736383B393A3A3836353637
3D39393638415374938F7E654E3D373B37353435393A38343A3836363737373636363535
3535343337373737373736363635373A3A3634343A38383A3A3737393836353736353536
333334353737363536363535353535353435353535343333333333343536363637353333
3434343334353535333233333838373634343537
4E4B4B4C4D4B4B4C4C4C4B4B4B4C4C4C4C4F4E4B4C4F4B44474746464848464547484340
474C49464143464747464545454544434445464649494A4B494544454544484A48484744
474646464441414242464846454747464746454343434343424144454140403D3D434745
444951565144484842444241423E3F40404445413D414843403B424743424242413E3D3D
3C3D3F3E3E434540403E3F4141454847474243423C3C3D39373F3F3B3E3F3C3B3E3E3E3E
3D3E3F4142413D43433D4448403D413E3D43413F393D3B3E3D3A3E3C3E3D3E40413F3F43
3F4143444444423F3F40403F3E3F414341434648433C3C41434141423E3B3D4241404543
4143424841414344423E3D3D3F3D3B3B3C3E3F3F4343404246464447443C4048443C3C3D
44413F393A3F3F403B3F433F444445423D3E3E3C3D40403E4A403C3A413F4141403F3F4A
4E464340423D3D424039393F3B3B3E403F3E3D3B42413E3A3A3D3F404141423C3A3C3C44
4341443F3B3C3B40403F3F3F3D3B3B3E41413D403F424941413D3A3A3B3E3F3E453F3B3E
41413F3F43424040403F3F3F3B3E42413E3C3C3D43413C383A3E3E3C413F38363E423D39
3B3B3E3F4044443D3C3E4143413F3F41494A3F413B434B527176878B928D87756C5F7C5C
66566063575E505942483D474044434E41483C413E3E45413E3C3E333E3B393B41454442
363C42394142453B40424241444B51526168677569726C6E6073649178A08A99908B9796
AEACB5AFBBAC9F6C5D5353647376817D7A7E758483A18EAF9ECCACBBA3B69DB9ABC9AEBA
AAABA79D7E6F8993B4A5BBA3B59FAA889C88827870646B6A7EA6A3CEC1E6DAE0CFD5C2DF
CAD1C9D5D2D7D9D5D4D8D0D6E4D6E4D2E7D5E4D8E2D5DDCAC8AB998276696451514B5652
595458565D504D454B4B44455D5E7D789FA2C2CAE0CDDBC9C6C7B88E706C68656058594A
59473F3B3B3E3D4244587595765D4536393C353D413E3B3A3B3C3D3C3A393838383A3B3C
403D3E3E3A3A3B383D3A383838393B3D3A373839383A3B383A36393938353A3A393B3B3C
3E3C3A393D3A393A3A3837383937353436393B3D3B3836383938383A393A3C3A37363638
3C383B3D434E6285686050413936383B36353435383B3935393838373737373836373738
3838383737373736363636363A38373939373739383637393A38383A3835333131323537
333334363838373538383737373838393333343434333332333232343536363636343333
3435353434353635343334353737373636363637
504E4F51514E4F524B4D4E4C4A494C4F4949494B4F504E4A4A49494B4D4E4D4C474C4A47
4946414248494A4C4D4C49474A4A4A49484849494A48484A494747494B484A4B47474844
4C48454545434346474B4C4948494846454545454545464645444848413F413E44464949
474A535D483B44494649474244423F41443F3D4346464B45463F41404142413F3F41403F
4342474946494C4844433F3E41424142423F40413E3F423F3E413D3B3D3C393A3D3E3F3E
3D3D3F413C3F3C3F3E3B40403F3C433F3B42403F3E423E403E3B413F423F3C3C3B3B3F45
43414143444240413E404142414040403C3D3F403E3D40433C414C4B3E3D42413D3B4447
46433F474445484B494341423C3C3C3C3C3D3F403C404143484649524540444945403F3D
3C403F3F40403F393B393E3C423F474B40414040434747444740403C423D41403B3D3E4C
5045433F413E3E41423E3C3D383A3C3F403F3D3C4044453F3B3B3D3E4140413C3F423D45
403E433E3B3C383C4042413E3B3B3B3B41403D3F3F41473E403C3F423F4245403F3A393E
444544433F3F3E3D3D3D3F403B3C3D3E3E3E3F403A393736393E3E3B3E413C383E403B3A
3C393A3B3B42433C48464748433B393D484540444559616F817E7F6E65595343423C4542
3E4340403D3F3C443B3F3B423C42393F373E4042403D4440423F403545413D3C3E3F3C39
3F42473F423E403A3C414341404143424140464956545C63787BA197BEA3A588806A6A5C
675F67565B4C5240454A5554515C5961686A73767F6A8270786D7A6870695D5F54687A8B
9498A0B3B69596645D5255645760625D5957636A76747D808C92ADA2CABCD6D2DBDCDFD8
E7CEE5DBD8D8D7D0D4DEDEE6E9E5E2E4E1E8E9E5E2E2DCECD6E5CCCCCCC0B2A693909092
A9A2ADA6B19B96896F744F514D4A4F4D596E6E998DABB8D2CFD3DFD2C3C8CAC6ADA99394
7C6C4E44393E3A403C40507394936C4C3F3132373D3C3A3B3C3D3E3D3B3A3939393A3C3C
3B3A3E3E39393D3C37393A3A393A3C3D38343637363A3F3E32373542323D363535363A3B
3B3B3A3A383535383B3A393B3B39373635373B3D3A37373A3C393838383A3C3B38383A3C
3B3C403D3F424452423E3938393B3C3B37383635373A3935363738373635373A3536383A
3B3C3C3C38383837373636363B3837383837383C383636393937373A3636363636373636
3635353637383837383737373738393A3434353534333232363534353737373535343334
3537373634353636353536373737373838383837
4C4B4C4F4E4B4C51494D504D49484C51514B4747494A4949484647494B4D4E4C41484A48
4946464E4B4844434343413F414244454546484A45403D4043434345494343423F434A48
4E4844454646484C4A4B494441444646424244454647474748474B4A413F423F3F3B3A3E
3F3E4249483A43494547413941423D4149413D4C443F4446534E4A3E4647433E3D403F3B
3C3B4145404143413F413D3D45443F41484343413C3C3F3C3C3D39383E3F3E423A3D4142
403E3D3C3D45424140404540413E4741393F3C3B3F423D3E3C393E3D403E3F403C393A3C
423F3F42424042463C3F434443403E3D3F3D3A38393B3D3E3A4658544041483E3D3B484F
4F494249414041423F39383B3A3B3C3C3C3C3F414147484645424858434041403C3E403C
3E413838393B433E41383D3E464456643E3E3C3C40474744423F4440443B3F404344424D
4D403F3B4141414041413D393B3C3B3B3C3C3C3D383F45454545433F3D3B3C3840443B41
4442494543443C403E41413C3A3C3D3B3D454744393642403B363E443D40453D42404142
413D3D3F383B3D3D3D3D3E3F43403C3B3C3D3C3B42423F3D3F413D383A413F3B3E3D393A
3D373636373F423B3D393A3F3E3A3F493C3C4246434E434948494E42403D43393F354739
4439433B47403F3F3E3C3A3D3C4A3C3A453A3F373E3D3D3948403C383A3D4041403E3C3C
3C3B413D41393D3C3D40403B383B404347504F717A9293AB8FA191AD8C955B4350434144
3B454C456A4E6B5A7F7393727E7B79747A8180877B6565826B6B5E725974637C4F5A3F5A
535D6A849C8DB68B9A79545E44473D484043443E49464C52596D6D908AA09DB5ACB8B1B6
A1B7B3C1BBC0C5C3CED8D7DDDBE0E3E7DBE0DFDBE7DBE9DEE3E1E5E2DFDFD4E0C5D0CBD7
D2D1D4D9DBD8D8D9D7D7A88E785465737A88847869688AA3CDC4D3D5D0DCE1DED0CDD3CC
AB7D674840443A41423E33416FA0927A5D3A3E3E3C3B3B3B3D3D3C3A3C3B3B3A3A3B3B3B
37373C3D38393E3F3F3E3D3B3B3B3A393C363638363838313B3A41343537423937363A39
363738393935343839373638393A3B3A3938393A3A37383C3D3B3837383A3B3A39393D40
3F44453D3F4137373B3B3D3D3A383837393A383536393834333638373434373A38393A3B
3A39383739393938383737373836373A3A38383A39363638383636383435353434353636
3A38363536373837353535353537383936363636353332313A3836373838373535343334
3638383834363737363637383636373839393838
4C51515256534E514E55534F4D4949514D4B4D4D484A4F4E4D4C504D484C524D4E4E5153
504B48494B4D47454C4D48474547494B4B4A4948434B4A4546494B504C4A49484748494A
41474A47464A5053524D45444845454B454847434347494648464B45464B42403F474943
3F4344413C3E434745403E413E41423E3E42454542444959635643414644403F40424140
3D42464A423E4541423D3F413C3C414341434043413C40403B3A3C41423E3E403C3B4544
3E4143473C4041463D3A47463F373A423E3A3C3F3B3D40403E3D3D3F39454B454143433F
47444345454242463D403E3E43423E3F393B3D3D3C3E4246414048433F3F393D433A404C
4A41414539453D383B3E42413C3D3E4042424140374043413C4B46473F3D3E3F3C3F403B
3E3C383D3D404B423C383C4D4A40494D3E3F42403D44453A3C3F40403F3F4143373B4245
4241413F3F453D3C3A394039434045494340464B433E474B495B4B493A36404141413B41
3E3E4043413C3B3D413F3E3E3F403F3D383D3E3B383A3D3D383E3D3D423F3E443E3A3A42
4847413D3939403A3A413C3D4041413E3B3B3F433C3D393C3E444B41373D3A3E3E34373E
3938393B3D3E3D3C3D3F3C42433F42404F47433E36383D3C353D3D3B3C3A3A4136363738
3A3B3C3C3B3F373D3F373B3D3F483D3C403E43423837403840403E38373A3A3D393B433A
3D393B4237453D3F3C423C3F404B51616C729190BFA6B4A39B928E848579716756515A5C
6260666271656E83819782997A7D6E7473726F746D6B5A685D5C4F4C494C54556355524C
4C574E5059666474698A6A8279587044423D3E434049404442465147736A7B7FA7A59D99
858878887E86838B8B9195A89FB1ABBEB2BBB2C2BFBAB7B3C3D6D6DEDCDBDBD6E1D5E1DA
DEDCDEE4DDDCE1E2DFE2DBE2C8978B88A4B5C39B9474878C9FBCBBC3CAD4CEE0DBDCD5D7
BBAD8A725353463E39413B373D6C9BA096805D5B42413E35393F433E3B3D3F3F3E3B3836
3837393E3E3C3D40383C433D40333A433D3D353E3E40373D3B3D41323B3B403635413B32
40383A3A34373A3A383838383B3C3C3B3938393A373839393838393A362F3B44415A8887
A38E895C3C383A3A393C3C39383A393637383A3C3D3D3D3D363838373534363837373736
353537393A3B3C3A38373838363738373636373936363737383838393835353737343436
363636343334373A36353536383836343135333235333238333334353637383834353635
3536383B37353536333235383535363738393939
4B4E4B4A4D4C4A4E454A48454645464D4D4B4D4C47484C4B4B4B4D4B46494D4943444649
48444446464943414D554F473E44494946464A4F404745404345464A4D4A484646494D50
3D444948474A4E50464643444846434645454341414446454A474B464648403F41474742
40434747403E3F44454342443F43444240413F3C3E3C3C4146423F43474340404244423F
3E4142453E3D47453F3A444B4340413A4745434D4E4442403A393A3D3F404143403C423E
373C4045414341433D3B443F41393B3F3D3B3E3F3C3A393A3D3F403F3D41423F3F42413D
434140414243464A3E403F3F4445434741413F3C3A3C4146403C403C3C403D413D3B4146
4443433F3F49423C3E4045443B3B3B3B3D3F42443E3D3C3B353F3B4440393B4141424444
3C3E3B403E3C43403F3C3C49494446413F4144403C4246403A3B3D3D3E3F41433E42413F
4144454543463F3E3C3A3F3A3B3B404240434642423C44454252464639363D3E3F413E45
413C393B3D3C3D3F45423F3E40403F3D3D403F3B38393A3A3B3E3E3C3C3D3D403E3C3D42
44423F3F333339373A4241443B3D3E3D3C3C3F413A3B3A4141414338343C37393D3B3E3E
3938383A3F4447484846434A483D3E403D393B3D3B3F4341393D3B3B3F3E3B3D3F3F3F3F
3F41434543453C3E40393C3F3E42403C3F3F3C3E40403E393E3A3E3B353A3D424141453A
3E364539444848504D61676F7589909AA5B5A4C3B4C6AFB29FA5A0AEA7B2A8A99790918B
9191948791748E6988626E68666A5E6568717C8A7889749279917B7A6F6B78606A54636C
7D8B83837E7C706F69505A547A6F8C7F5E6E4948423742453F3C393948495571799991AD
AFB8AFA39590807E7678707374757F737F7C878C94918E858C9693999D9F96ABB6CDD8DD
DCD2E3D6DCD2DDD2D4D7E0E2DED4C7C2A0BCCDCEC4BBB1AD9B9F9D96B8C4D3DCD6D2DFDF
D9C7B89E9B8685544C43413F3A40657696AF979373785D473B413B42403B37393B3B3B3C
39383A3D3E3D40443E403B3E42403A404140353A3D423D423A413E463B40393C363E3939
443E3C373938383939393B3D3C3D3E3D3A373636343535353536383A3643538D89C5CDD3
D4C1A8824B4C3A3B35393C3B3B3C3A36353536373738383836393B3D3D3D3E3F37383838
37363839393B3C3A3837373937373737363636373434343435353535333233373837383A
363636353536383A3C3A3837383736343439373436353336333435363737373734353637
3737383930323943443933373535343535363838
4E504E4C4E4E4C4E4C4E4C4B4D4F52574C4A4C4C47474A474B4B4C4A46484A474E4D4E4F
4D49484B484E494249504A3F464A4C4B47464B504B4F4C494D4E4D504C4B4948484A4C4E
505456514A464442434847474C4D4A4A46444343434344464F4B4D4B4A48424344454542
4144484B4A454141434241403E4041414142403D414143423D3E42434544434444434344
4A4C4A4B433F4745473B434A4040453C47403D4B4E413E3C3A3B3B3B3C404242413C423C
35383B3F3F403D3D3D404640433C3B3D3C3E403E3E3E3E40424445463D3B3A3D41423F3A
40403E3C3E4347494547434042403F434745413E3C3D3F41423D3D393A3D3A3C393A4042
3F42423B424C4641404045443C3D3E3D3D3E4145403B3A3D353D4154493C3B43423E3F40
46453E3D3B343B4247443C3D3D3E45403F3F3F3B383E423D3C3B3A3B3C3E3F3F3C403A37
404340414A4842413E383A393E3E403F3F46483F413A3F3E394640413F3C3F3D3C3D3B41
4A423B3C3F3F3D3D43403C3C3E3F3E3D3D3E3D3A393C3D3D3B3D3E3B383D403E3C3B3D40
403D3C3F3F3A3B39393A373B393A3B3C3C3C3C3C3F3C383E3D3A3E38384139363C3D3D38
3D3B3A3A3B3D3D3D403E3D4845383A40484442424041403C3D3D3B3C42423C3A3A3A3A38
37383C4040433C3E423E3F423B393F3B3D3E353B393F393C413C40433F3E3A3D3E424A44
5458606A6C8A7B9391A5ACB2B0BAB9BDBDACB58AAB7C8F7B817F877C8373756E675E584A
4F51503C433F3F403F413F4340463F4542434C564548504A5B5668607C72897B94828B95
B6CCCED7CECCC7BDA46B574F4968657C6D916A6B674C4841493F474343403F47595F7071
A6B5C6C7D1C9BDBFB9BAA8999C90969393989BA6A5ABB1ADAFB2AEB2A59C988E9F9CACA6
B7B9CFD7D3DDD4CCD4C7D0CDD4E1D4D4CDD2E1DCE5E0DBC7B2A0896E7D88A3B2BDBDBBDC
D1E5CFC2C8C2B89B6B87605C4444434B5B6E7D7C7F7E6F48483B3D3C3F3A363D3F403C3C
3B3739393C3939383D473845414A37403A3E3837373C393D43433D473A3B39463A3F3940
3A383839413B3A3E3F3A36353B3D3E3E3B38363636373737383A3D40555C9BB0DCDBDFC9
D0B6AC7659433E343B3D3D3B3938363236353534343434343235383B3B3C3C3C38393A3A
39383839383A3C3A3736373938373636363635343434343333333333323234373938393A
36363637383939393C3A373636363535343A3935383A3734343435363737373634343537
383837363735384A584B38373534333233343638
4A4C4D4E4F4C494847474646484A4C4E4A474A4B474749454C4C4C4B494A4A494A484747
45404043424B4D4745474642464443434344444444464341464643444A4B4C4D4C4A4746
4B4E4F4B453F3C3B4147454146494747484545494945444746424244433E3B3E43434444
444346494B484441403F3F4041403D3D3F4142413B3C42423B3E423C3B3D414444444B52
484C4A4A443D3F3C4A3E3F423C3F4643443F3841423A3B3A3D3F3E3A3A3F403D3E3B4441
3A3B393A3B3E3D3B3C424642433E3D3D3C40423C343B42423E3B3C3F3C383A4044413D3B
4042403B3B4043413E42413F41403F4445444342403E3B3A3C3C3D3C3B3A38373B383D43
403F3F3D41494644413E42403F424544413F3F4144434343363C42574C3F3C413F3C3B39
42403A3C413D404D3E413E403C383F3E43423E3A3B40403B413E3B3B3C3D3C3B3A3C3539
4743393E423F3D40403D3F423F3C3C39363B3F3A413B3F3B373E3C3E4140403D3B3A3A3C
3A3635393E3E3E3E3D3A37373A3D3E3E3E3F3D3A3A3D3F3D3A3A3F3E3A41463F3A393A3E
3F3D3B3C3F3A3A3C3D3A393C3A3A3A3A3A3A3939423C383E3C373D393E443C393B393B38
3F3F404242413D3A3A3C3D46453B4044443F3A383A3E403F3E3E3D3F42413D3A3A3B3B3A
37383C403C3F3D3E433F3C3D453E3F39383B363D383D393E3E3A343E4949454E5B697A7C
9A8DA38CADA6B2B5B8BAB3B2A29B8F8E7F7C675D564C46434043424945484242463D3C34
3D414435393F383F3140363B393F4047453F41433D413D46403A3A3B3E3C4C4F57616E91
AED1DCE0BBA39C8C9E6C634547425558607B7B848981665B6D648D777C6D6A4F5E574B5A
6E989BC2D2D0CFD6CDCEBBA6A3798C7690809CABC1CCD7D9DBDEE0E3DADDD5D5CBCFCBCB
C6BAC8BAC0C4CAD5E0D5D4CDD0DBD0C6C9D5E0E9D9E8E0DECCBFA1885F585E757A79939B
BFBECDC3CEC8E1A6ACAEAB816D524F3C415240464D534B51424C44463D3D383A383F3D3E
413C3D3A403E42413846414043433B453F4A4E4F56636E7870605B5057546A796B735F7C
535A40403E3430373C39383B383A3C3C3B3A39393A3A3A39393B3F4254768BC0AFC49E9D
6F655D4E383D37373A39383636393B3C3A39373534343434333536373736353538393B3B
3A393939373A3C3A3735373A383635353636343236363535353434343535373838373636
35353537393A3937353434333434353531383835383E3C35353535353535353635343435
3737353436342F3B4E4735353534333333343637
4D4E5052514F4D4A4F4E4E4F4F504F4E4845484947484A464A4A4A4A4B4A494A4B494A4B
4A48494D44464A4A4541424440404143464746444A4B47474B4A454747494B4C4B494644
4A4C4E4E4A47464743494843464744444645474C4B464344484645494843444740424446
46434343404345434040424546423F3E3E3E3E3D434143413F474C45403D3D3F403F4348
42484547443E413F403D3D404342404242453F3E3D3B403E3C3F3F3C3C3F3F3C3D3B4645
3F403C3B3D41423C3B3E3F42423E3E3F3E41413A3E444A48423D3D3F3E3B3C41423E3E41
3F42413D3C3F3F3C3D42414042403F43424241413F3D3B3934393C3D3B3A3C3E3D393E43
4140413F3F464648433F413C3F424544413F3F403C3F403E3642424B453E3D3F4043443D
44413F454D453A404144424948404448474A49454343424143403C3C3E3F3D3A44403A45
53493D4645403F403E3A383B403C40413A383D3F423C413E3A3B3C3C3C3E3E3E3D3C3E3E
3C3A3B3D3D3B3C3F3D3B3938393B3D3E4444413C3A3B3B383D3C41423F44463E3C383940
45443F3C3C3A3A40423F3E3F3A3939393A3B3C3C3D3B3C45433C3E383D423D3F3F373C41
42424242423F3B383C434244413C403D554F453F3F3E3D3D3C3E4142403E3E3D3D3F4140
3D3D40434344403D3F3E3838413E41403F3F3D3E403F404546554E636C706F7C89919A9B
928E82918CA2A2A69289797464615653484A3E3E413E3F3E3C3B37404149434140383C3A
4140464041414B3D3F403E3D3C3C3C434541474545433F4447454F5249515169546E638C
AAC9CDC08560594B544D564D514D5C50626C7984838F81757C7AA89CA99EA7A18AA17D9D
8AA4A0B5CDD3DAE1D6DAD3CAC699A6889E8EABB9CCD4DADCDBDDE1E0DBE1E2E4E1E5DFDC
D5D4C0CEA8BA9DC0CCDAD9D5D1D4CFAFAEABD3CAE2D7E5DAE2E0D9D09E7E6F7A81968F98
89A2AAC6BCD0BCBD9DC8BFA793865A4642394044413D4940463744484451504F41453C38
3A3E494650516269819C7F9B7AA18AA4A7AFB1AFB6BBBEC0C5BCBDB4BDB5BAB7BAA2AD9A
AF8992746552413C3936373D393A3B3B3A393A3C3A3A393736373A3D394653545A484A47
3F3E3D3E37413E3F403D3A37353536373B3A3837353535353A3A39383838373637393A3B
3938383936393A3936353739373635353636333136363535353434343738383736363533
3434343638393735333434353434333331363735363C3B33363534323233343536343232
34353433313933313A39343A3535353636363636
54525354515254524C4A4C4D4B4A4A474945474947494B47474746474B49464948464647
454243474B44454A4743424143474C4D4B494949484946464A4641434546474748494A4A
4748494945403E3F444B4C4B4D4A44444344464A4945414041434145454146463F424445
454543413E45494641404244413F404243403E3E4844403D3D43423B473D383B3F3C3A3A
474B4443433F43453B3D3C3F45413D423E4542403E3D433E3A3C3D3D3E414241403C4443
3E4240413B3D413E3E3F3D46423D3E413F3F3F3B42413E3C3A393736413E3D3D3B3A3F47
3C3E3F3F3F3F3E3C4246454345413E4040403F3D3C3C3C3D383D3C3D3B393F403C3D4243
4043443E3F44454A4641433C3C3D3E3D3C3C3F42373B3B3B3B4E4642423E3F4142474841
433C3E434B493F413D3C353E443E3F42424A4E4945404046403D3C3D4142403D49413C47
5249424B3F3B3E3D3D3D3A3D403E474D46404347423C4241403B3E3B3B403F403F3D3F3C
3E3D3E404142484F4343413E3B3A3C3D4042413E3C3D3D3B4140424443413F3B3F3B3B43
4A49433E42423F43443E3D38393A3B3B3C3E40423E3E3E46433F433D4045404442383C44
43403D3B3A3A38373C4542403E3C403A45443F3C3D3B38373A3D43433D3B3E3F3B3D3E3E
3D3D3F41474540393D413C3F4843413C3B454C4D716664655D7B758E8D8D82827F74706C
6E66736E81738574615D4F49424F4D464244403C483F4542433B40394B454A42463E4340
413A3E3A3C4046403B463D3F47423F41433D45403F415D59867E998B7F785D7766866B81
8C948D8A6C605E55616760674F6E5C626976798C7D7D84706C636E73786D6B83859D9598
8CA09D9FA4B3C1CEC8D1D4D8D5CFD7CEC6C0B6B4C6CDD3DBDCD8D5C7D1C7D4C2DAD2D6C8
AC99878072717294A6BBC2CECCCDD7BE947D7A859DC2D0DFE6DFE6DED6B6B0ADBFC5C89B
9C91B3C1CCCFD7C3C7ACC6AFB9A78B5B484C58857F8677776A7177979AAAA9A28274594D
4F6C9AACBEB8C1C0CDCBCDB5C7C0CEC8D3CDC4BCC7C7C6C3BDBEB3B6ADB4A7A17A6C6465
6B697064716252474039373A3C3D3C3B3938393A3D3D3B393837393B3D45353F373A3B43
3C363F333B323832373637393A39393B39383736353535343B393838393A3A3936373938
373637383737383837363738353536363636343234343433333333333537363535363635
34343536373736343738393937343333353738363337372F383635333233343537363433
33333434353C3731373A383A3636373737373636
4F4C4E4F4C4E504D4C4A4D4E4A4B4D4A4C47484947494B47484946484C4944484B494949
4642414447434549484A4C4944474A4B484443434A4A48494C46404345464648494A4C4C
47484B4F4E4946473F4446494B46424544464847464643404349464848464D4A41444441
42474845444A4C48434242403D3C3F43444141434F4F4A464745403D3E39394144424245
43483F3E3F3B3E413F3E3D3E3F3E40453E423D3F403E423E3C3B3B3D3F404346403B4240
3C4041423A383D3E43433D48443C3D413E3B3D3D46423F3D3D3D3C3A3F3D3B3A39393D41
3C3C3E41413F3E3E3D403F3F454543463D3F403E3C3C3D3F3E413B3F403D403C3F3D4144
424244413E3F3F464340433B3C3B3B3B3B3D3F41404443403D4C413C423D3F434241413D
493E3F3C3C413D3E3E45424A514A46423E44454445423F443D3C3C3F4142403D423E3C41
46444245403E423C3B3E383A3C3B414440404241413B4141423B3F3A3C4340413F3C403A
403C3B3D3E3E3F42454646423C393A3D383D403F3E414242413F3D41433C383A3F3C3D43
4745413F3F423D414341423A3C3E414140404142414240434040474041484344453E4042
3E3C3B3B3E4143443F434041413F43403B3F3E3E42413D3E3A3B41423B3B3F3F3C3D3D3D
3D3F4142413F3E373D443E41413D46434E7080899D8F847F6277676E706E5E5854484748
49585B71666C62615C5B534F4653534D4D4E443F423A3D3B40423A463F4B41433D393E3A
3E3C423B3C3F423D3F414340423E3F40423B4743405C77ACC7DCD1C1A69C888E8D968A90
8C8E8C9A9699938F9284846960594E585971718C84797B6A665B58585A4D4A5657576166
5D75666D636F75817F858792A2B4D0C9D0BEB1A099A0ABBFC9C8C1AA99949795A7B9B9B4
9C88808370645A5F697183939298A5A28C71615C657F93B9D4D3D6CDD9D2D4CDC3CECAB8
9FADBABCB6BDBDD6C2BEB8C5BBB39893989AB2C3CAC9BEA8AFADBED0E5ECE4E5CAC4B2B3
B5C1DCDEEBDFE0D6CAD6CAE0D2F3E3DFC5AF91746F646365494F4A514A5248453E403A3E
3A3C3F3B3E3E3F40403F3E3F3B3C3C3C3A3838393E3F3E3C3A3A3B3C3B3C333A363B383E
3A3F3640353F383D3937383B3A3736373738383837373636373635363838373635363635
343435373736363637383737343537373735343434343434353535353436353232363736
363738373635353538393938363434353836383732333531393838373636353438383837
3534343534333031363935323737363636363636
4C4A50545050514C4E4B4F504C4E53514F49484946484A474C4C494A4F4A45494A494A4C
4B47484B4B4C504C44464B46454545484B4C48444C4D4B4C4E47424545474A4C4D4C4A48
45464B504F484444434546494C484851474A4A47464847433E47434342424A454346433D
3F494D4A45494A484748464343414041403D40454648423F43413E4440434A4E473F414B
3D45404246434446413D3F423D3D414346423A4044414543413D3B3E3F3E41463D39403F
3C3F3E3E41393C3F47443943453C3C413D393C403B3D3F3E3B39393A39393A3A3B3B3937
403D3E42423D3C3E40413D3C41413F41393E4243403D3C3D3B3D38424946453A43393D48
463E40453B3939403F3D42393D3D3E3F403F3D3C3A4346433A4540443F363A42403B3A3B
3F363E3A363F3E3E384643414341423F44423C3F4B4C44423D3D3E40403F3C3A3B3C3E40
4043433E3A3A413B3C443F3F43403F3C3A41443E40393E3F433A403A38413D40403F4640
3E3A393F44423F3C414446423B373A3D383E42413F4042413E3B373C4139343C3B3A3C3F
3F3C3B3D3F443D3F4141443A41444746423F3E3F3C4244474343463B3C45404148494A45
3B3A3A3B3C3D3B3A3C3B363B3B363A3B353A39393D3C393D3B393E3F3A3C403E3A393838
393C3F403B3B3E383E4338383E476F7684A097947D7871775565504842433A3C42404850
5B6A777B7B7B7884726E6A6A575753524D4F413F3E3D3F42403F433F423B3C393C3A3F37
3D42483B394435423741403F3F3B3E3D3D394D4F848194AAD6D5E0D3D4CDCEBDCCB7B9B2
A5AFB8C4BDC0C1D0C5CAB0B6826E435352656578807A6A686A66775C605266536E57747A
98626E58595A4F52525758686E8A8A9C909B8B917E8087A0B4BDBCA59185967D9C9BAAA2
B193A69CA88A987F86859C978B938E8B85877D967584668C98B0B1B5B2BFB1ABAAA6AA81
686B887B9C8C97979B9394ABA8A2A6B6C3CDD8E2E2E1D7D1D4E5EAE7EBE9E1F0E1E1D9E5
E3D7D5C4D0C2BBA6BBBED8D5E7E3E5C8BEAE9878674C47494440453B41383E3C3F44383B
373D3D39373B3E3D3B38363536393B3C3C3B3A3B3A3B3B3A38373839363234373339343F
3C3B3B363B353C3C393635373837393D38393A3A3B3A3939373737383A39363434353533
323234363836353638393736323538383735353536363737383838393637353131343635
38393A393635363735353634333335373734373832323635393A3B3B3A383634383A3B3A
3836353635323439383637393837353434343637
4D4D4E4F4F4F4F4E474B4D4B4B4D4D4A464A4B48494C4D4B46484B4D4C4A4644484B4946
474443474345494D4C484648424342464A45434944464847444345474E4D494F494B474B
434444434243474B4A434A4C4753563E48434748414043413D414040454340433D424441
41464D5047464547494A4A4B47474645454543404C47423E3C3B3E42363C3B3D3A384244
423D484A443E3B4A443D3B3F3E3A3B42403C3F3D3F433E3F3C40413F3E3F3D3A3E403F3A
393C3E3D363A404649463F39383E3E3A3A383840383A3C3B39393E433E3F3B37393F413F
3A383B4245423D3B3C3E404140404142374B414D47504741383B3F41414040413D3F4040
3E3D3D3E3A4B4A3D3B41403E3F43433F3D4042403C3B3E3F3B4045433D3F41403E3D3D3D
3E3B3B3E3F3D3D3F393C3E3D3E3F3E3B3C3F3E4047453D3B3C3E3F3A393D3F3F363B3B3E
47453E3E45403B3A3D404242403D413C3F463F3F3B3D413E393B3E38373E4446423E3A38
373E44423E3D3B383838413B3638353D3A3F423F3E40413E353C3E3A3A40403938393D41
413C3B3D3D3A3A3E403E3D3F40414446423D3D41403D4047443C3C43403E484944434450
3B3B3D424646423D393B3A3C363A43323A3D423D35393C3538393D42413C3B3E3E383C41
3C3B4143403F3E3C3B3D404344699B938A7676625B5247474A413B42403C424851486D68
8084858483837F79636662575251493D3D3F403F3B393A3B413F4341423E333C3A3A433B
3A3B453E4141473B3D443A4243535C6174838A99A3A88E94A19F9495999090979AAAA6AF
B1B0B3BCBEB5AFAB847B827B64564A4B46534B4F504F52585D616964656B6D70616C6B79
7B7B575855554B4C5A5165596D6885647B6364665F4C5684A0B6C8C5A7ABA19D929B839D
88A198B4AABCA2AF9CABB1ADA5A7A999A586A392AC91AB8E8F887E7470868F6E6B687252
4E3F4A4D535C626665655A5E66738A9AB3BBC0D7E3DCDFC6D8D6E6F0E3D0CDC8E0CEDAE1
DCCFB2B8A7B8A4B6ADCDD4E1E0D7CECEB4A5A6A8A38F6A5A4843413D3F3D3C3B423D3738
3E3D3B3F3E3B3938383939393737383A3C3C3937393735363839393838373637393A3938
3A3535393B3937393C41423D383838373536353637393B383536353B443F383C31393635
36353538353A333C313B34383B37363A3C373232303337363434383C3439342F34363232
34353636363534343334353536363636343434343435363634383A38373737353A3A3936
3232363933373633383732373334343A2F402B3D
4D4E4F504F4E4C4A4E4F4E4A494C4C4A484B4C4C4C4D4D4B4748494A49484645494D4B48
494745494C4B4C4E4C474445464846474A484549494A4A494746484A4A4A474F494C484B
4B4D4B4643454645504643485D7D785144454746424245443D3D3D4247443F3F4B4A4542
454D54554246484846444341434141434546474743414346453E3B3D42433D4042424745
3F414A4641413E4647424142413D3E44423B3C3C41463F3E383C3F4041423F3A3B404342
40403E3B45423E3C3D3E3E3E3C3F3C3A3D3C3A3E3B3E403F3C3B3D3F3F3F3E3D3D3D3B38
3C393B4043413D3C404141403E3C3B3A3946353B35403B3A3B3D3F3F3D3D3E4043413D39
37373A3C3842444040403F413F3C3B3C3E3F3F3E3A3A40413E4144403B3C3D3D3D3E4042
403E3D3F3E3C3D413B3F41404041413F3B3F42484F4B42403B3F3F4041413F383D404142
45444243403D3A3B3F434545393D4341484B3F3D404347433A3A3C39393D41423F3D3C3D
3D41413C3A3D41423C3D46434246454D3A3D3E3D3C3C3D3C4042403C3D4243403D3D3F42
413C3B3D3836373B3E3D3E40383A4045454244493F3A393D3F3D3F43433E413A3A3E3C47
46423F3E4041403E3339414B494D5341363A3F3D394045403C3E4348463F3B3B3A363A3E
3C3D403F3B3C3D3D3D3F41444E5D725E58484A3C3F41434747413E443D38434C5D586C5E
6666645F5C5B57524848443E3D41403C40403F3C3A393C3E44464847463F383F3E393E3C
423F45423E413F4E4B666A8C8FA6B2B2BDC8C6C5B6A1A67F8A7C92799D98B1ACCFC1CCC7
C4A68F8174706D605B5E565F51655863677264756464656B66646B5A61507065766D766F
817C6B614C4C474A4D52585963867D997892678C4D4C446A6E93A4AEB29FA68DA5889E7F
9286987EAA8FA29A9BA0AAB3AAA2B3BEAAB4ADCDB7D2C4BB96908476686B78725A565B4A
4843444557659772957986767B827F7F83969CB8CDDBD7D5CAE3DDE6DDC7A4ACACB2C6D3
CCD2CFBCCABFC4A8B8C5D2CEDEBFBCB6BEB3B2AEAAA59B9E988B6E594544383F3B3B3F3C
3B3E3A3837373738383837373939393B3C3C3937363636373A3C3D3D3938383839393A39
393736393B3A3939373C3E3B393A3B3B3B3B383A3C3A393938465F7A8879594233383333
3133363F38373C363A343B3C3A38373634323538363637393B3C3936303838353636363C
3435353535353434333435363636363635353535353535343739383535383A3938393B3A
38373839363938383E3C36373434412F3C353C40
4A4B4C4C4B484543494A4947464747454645474A4A484646434242434344454544474543
454341444340404344434345444845424444424348474645444344454E4A42453E434248
4A4A47424245454250534E4243534F3840484842404141424540424A4D4A45415049403C
40464743444B4D4741403F3D433E3C40413F40444E484548453E3C403B3E3C414341433F
3C444B423D43414145444442403E4043433B3B3B4248403D3B3C3D3E41423F3B4242403C
3B3D414246433F3C3B3C3C3C40403C3B3F3E3C3C40434544413E3D3D4242444747423D3A
3E3A3A3E413F3D3C3D3C3C3D3E3D3C3B515742423A423E3F3D3F3F3D3A393C3F47433E3A
393B3D3F3A3B3D42443D3B414D443F42443F3B3B3E3C3E413E3F43443E3D3D3C3C3E4144
41403F3F3D3C3F433F4344413F3F3E3C3D3C3A3F45423E4239403A3C3B39413D44424343
40414545413F3E40434647464446474346463C3C45464A473D3A3E3C40403F3D3B3A3C40
414343403D3F42434040443F3C3D3D433F3E3E3E3D3B3B3E43403D3C3D3E3E3D41414142
3F3C3B3C3D3C3C3C3B3A3A3C3E4045494946474B47423D3C404446473F3B413E4C533E3C
49443E3B3B3C3C3B3D3C3D40404B574E3B3D3F3D3B40433E3D3F434746413D3D3B393B3E
3F43433D3C3D3D3D3D3F43464646493B4540433C414243443C3D3D3F45404E505C575C4A
4948444040403F3B413F3C3C3D4042433F3F3E3D3C3B3C3D41433F41423D3D3E413C3F3D
44383A3F686A8B84A69BBCCED9DBD7D5D8D4C6B9BAA8949C8FADA8C2BCC8B1C7AAAC8A8D
8B828487878D897B97829E888D84997E786D676A64596D6B7A756C75596C605E625E5261
5481717B6D736E6A7862857B7F6B8A7991736C58515452484F4C5852596A6280728D7591
7E8D72987292788D848D8F8E8F9DB0ADBEC9CCCCD6D0D9D2CFC6B7B4B2ACAFAB9B878167
6757514A435963826C8C789B97ADC6B7B9A69E9BC8D1DDCECCD6D8D2DEA79F71676E7D9D
9DAEA7D6C7E3CBCFBFD2C1D5CAD8C1C1C3C5CDCDCACACAD1D4C8BE9683614F4740353E3F
3D44413B3D3E3D3C3A3836353B3A3A3B3C3B39373B3B3A38373636373B3A3A393838393B
373839393A3D3C3A383B3D3B383838383E3932323A3A39436083B5D4CBA47049373C393F
3A3C3A494352536A565C4C545C5D574A3D36363736343335383937353839353636373235
353534343333343434343536363636353636373736353433373836333437383638393938
363534343D3B3635393A3C3D393E313C5673807E
51525252514E4C4B4B4C4D4E4F4F4D4A4D4A4A4E4E4B494B4E4D4C4B4A4A4B4B474B4948
4A4846494C47454749494A4C4B514C46484947474D4D4C4B4B4A4848504F4A50494A464A
4B47434345454544464C4D484343464944504D4342434041434244464445443E47454243
494F4C454A5251443C3E4343464040484B48494F54494243413B3C433D45464A453D3C38
3C4448403D41413E3F41423F3D3D3F3F433D3E3D41453F3E423F3C3C3E403E3B3F3F3E3C
3A3C3E403F3F3F40403F3E3D403F3E3D3D3D3C3D4445464543413F3E4340424849433F3F
3E3B3A3E403E3C3B403F3D3D3E3D3A3844473A3D3B423D403E3E3E3C39383B3E42403E3E
404141413F3C3C42423A373C423D3A3D403F3E3E3B353943423939404342403E3D3D3E40
3F40403E3C3C40453C40423F3C3C3D3B45413C3D423F3D44414A3F3F3B3F5C67453E3F3F
3C4045414240404042434240414246454042454647444747413E413F47443F3C38373A3F
45474644413F3F404242423F3C3C3D4046424142413D3E42413D3C3F3F3B373742424140
3D3B3B3D3F3E3E3E3D3D3E3F3D3E4143423E3D3F44433F3A3A3F4240413F494D66724F41
403E3C3C3C3B3A383C3A3A3A3A4249443E40403D3B3C3A35393A3C3E3F4041423A393838
3C4240383C3B3A3938393C3F393C4345584E443B44413F423B4748434B49584D4B46463E
3F3D3A393B3D3D3B42404043433F3D3E3B3D4041403E3C3B3C44414441393E3E48526063
695958607EA5AECABCD0C3CBC7C8C2BDB19E92896C555E52646E6874646B5E6566636369
7F98B4BFC7C9C0BDB9CBC6D2BECEBEC39F917E93809FABB3B9BCBCB2C29ABDA0B3979655
50414C4B464C5C6B708893AB9EAE8698758C648A6C8A78947E8C6762685E8A716F575556
62575D5B665F6766636B645D657D86707EA499C9B8C8B1C3BBBBBAC8D1D3D4CBD1BFC4B3
BFADA69A77625D535259495C6792A9BBB4C1B4B7B0B4AABEA6CBC2CDB8B47A864C4A4753
54579388BDD0D2D4D7CACDB5D6C2CDC0CBD2DEE3E1DEDCDFE0E1D1D2B4A786726343413E
343A40433B3B3A39383738393B3A393A3A39373534353635343436383A3A3A383636383A
363A3B393A3E3D3A383A3B3A383737373A3D3F39383B4D70A9C5E1D39D6A493339383338
364148627A85959C8D75635F5C605E5348413D3A333333323234383C3C39313736393435
363534333333343435353636363636353536373838363534343635343536332E3A383635
353535363034383D3B3738343C455C70BAB3B17A
4C4B4B4A494949484A4847484A4948474A454346474544474F4E4C494643414040444242
4544414344403F43484B4F54464B474142434141454646474644424048463E433F45474E
544A454A4C474649484645484842414A4A55524848494646434848403D4244403D3F4042
464946404A5150443D40464747414146463E3B3E443E3D42443F3E413C434347453F413D
3F4242413F3D3F3E3B3E3F3E3D3E3E3E403F433F3E3F3C40413E3C3D403F3D3B3D3D3E3F
3E3D3D3F41403E3D3D3F42453D3E403E3A393C3F4645434242424141413C3B3F403C3B3C
3D3A3A3E403E3B3A3B3B3B3D4041414041413B40434840453D3D3D3C3A3A3C3D3B3A3B3D
3F41403F403D3D3E3D3B3939393C3D3B3C4042413C3742575741374045444341403E3D3C
3B3E3F3D3C3D4144393D3E3D3D3F403F393937393D3834383B443B3F40486D7D453C3B3E
3E43443D3F3E3D3D3E3D3C3B3B3C474B3F3E48474B4241454341413F48433F3D3A383B40
494745423F3F4043474743413F3E3F3F48444244433F3F4245414044443E3B3C40413F3D
3A3A3C3D4141413F3F3F3E3E3B3B3D40403D3D3F3D43453E3B3D403F3B383C394D5C483F
3D3D3D3E3E3D3B393A393D3E3F4444403A3D3E3D3E3E3A37373738393C3F42423F3E3A38
3E43403A3C3E40413F3E3E3E3D3D3F414F463D3A40413F463F4E4C45424250423D3C3C3D
423E3B3B3C3B3937413F4043413A37393B3D4041403E3E3E4548403E3F4C6D7D98A1A8A1
A4969497B0B6B9919F94A79D969D969CACB3B1A48246516B5D69708F80958FAEA4ADA1A9
B0C1D0CCD3DFDEE6ECD4F2D7D7B9D5B8B09C9E9199B4D5DDE1DBB5BEA9C0A8B2A2A79081
5971617675808A8C9E85A8A4BC98AC80956C816C697777788B7C71696295909E8B8A6A6B
54514A514849444649423F494944494741545F5F6E5759606A7283979DA8C1C8CDCDC9D8
D4E5D6D9BEA97755406946424058787D9B9DA59899747D6B887FA0A8B69B997E76604448
433F4848589696C4CCBEA0C0B6C8B6CACBD1D8DCDBDAE1E9E6E0E2DBD9BCB992977C7C77
5E4F43363C3C3C3C3B3A39383B3938383837353335363636343436383839393735353638
363A3B39393C3D393335373939393A3C35363E4250698BB7D8D1BC8C53393B3E403A3636
344047636F777F7E6B554643393D3F3E3D3E3B353839393735363A3E3C3C373B30363337
383735343333343435363637363635353435373838383736343636353739373236363637
393A3B3B3939373831374E53719F9DC5ADA26A45
4F4E4D4C4B4C4D4E58524C4A4B4B4D4E4F4B47494B4B4C4C4D4D4D4C4A49474645484747
4C4A47484D49464748484A4D4B4E4B474948454748494B4B494846454546444C484A464A
4E4541474B48484C4D4C494A4B494849464C4B4545474645444D4A404044454646484745
4546444041484C4743434443444142484945424342404045474542414241393D41424642
41413D41403A3D3E3E3E3F4141403F3F3E3E45403C3D3B413B3A3C4144413D3B3E3E4143
43403F4142413F3C3C3D41443B3C414039393E4045423F3E4042424244403C3B3B3A3B3C
3C39393D403E3B3B424141403F3E3C3A46403B3C3F40383F3F3D3B3B3C3D3E3D41403D3C
3D3F41413D3C3D3D3B3D3F3B3C42433D3B3F413F423F47595A453C454141414242413E3C
393D3F3E3D3F41413F41413E3E403F3C3D403E3D41413F4241433B3D3A38464B453F3D40
4346443E4140404041424344413F44483D3B48474D403E45433F3F3E443F3C3E3E3C3E44
424142444441404145453F3F3E3B3D3A45424141413F3E3F47434142403D3E413E3F3E3B
393A3C3C3E3F3F3F4244434042404042424040433A4347433E3F42434445443B3B464847
4241403F3E3E3E3D433D3E3A3B4141433A3F3F3F413F3C3C393B3B3C3E403F3C3E3F3A39
3E403E3E393E44484743403D3F3B38373D3D424846494144374340413937413A3A3C393A
433E3A3C3E3C38363E3B3B3D3C393B3F3F3F3F3C3A3C4145404145556A869FA6BAB5B3A9
ADA19B948BA0839670916D76738E99B0C4BEB8B07C7CB1A2B7B2C1ADB5B8D0CFE2D1E0DD
DDD5D7CED3E3DFDCCED7BCC2A9A385847882808B87B5C6DCDBC1917D9F91AA9DAAA7BA9D
B3A0ABA4A3A3B2B6ADAFA3B0A8B8999B7881687E6A8161785D654350504D85809686936C
48504F51474948504D4646514D434A4D596A5D5F4E584A56544B4953545E7983A096AC9A
BDBBD1CEC2A8954E5150565351646E94AAC4BDB39A755D5A555B6379799175A1978F857F
68584F4644424A699378827C9C8C9A9EB7BFC6CFCAC0C8D2CFD1C7DDD4D9CCAF7F7E92A7
A39575453C3B3A3B3B3B38363A393737373735343C3B3B39373737383637373736363636
36393A3939393A393636373A3A39393B3C3C556F8EABB7C79F86634536373E3F3B373E39
3B3C3B4D404E49573F45363B37353434373936313A393838383837373638333A313D3836
39383736363535353636373737363535343536373838373736383736383D3F3E33353738
38373636393B3E4C526C9DACC7D3C8A57F54453C
4A4A494949494949544C47474847474849474544474A4A47444445454646464541444243
494844454240404142414347454744444743404443444544424142444646414741444044
41403F4044484A4A49464442454D4E4745434444424444413F453F3D48453E453E3E3C3C
3F43423E3C41474A494743404140404243403E3C47454341434644404E4A3F3F4140443F
41413B403F393D3C433E3E4344403C3D3C3C413E3C3E3C413C3B3C41423F3D3E383C434A
49423D3C3D3E3F3E3D3D3E403D3C3F403B3D4141433F3B3B3E4141404543403C3D3F403E
3D38373B3E3D3C3D3C3D3E3F3F3F404049403D3D43433B44443F3A393C3F3F3E4644423F
3E3F42443B393D403D3E413E393938383A3C3D3C3E3E3E42443C39413E3E3E3F41403E3C
3A3F424141413F3C42423F3C3D3F3D393B413D373A3E3F403A3C3C403F393A3B44444241
444341414443424243464A4C4140383E44444C4F493E3F46423D4044433D3C3F403E4147
3B3C404647413D3C3E403B40434146424141403F3F403E3B3F3F3E3D3A393B3F3E403F3B
383A3C3B3C3E4043494F4D4844403D3D3C3A3A3D3A3E403D3A3A3D3F3F43464337384441
41403F3E3D3D3D3E423D3F3B3B3D37393B403F3D3F3C3A3F3D3E3C3A3C3E3D3936383637
3C3A393E393C3F41403D3B393B3B3F413F3E41424547393D34403A413B3638383C3B3637
413B383B3F3E3B3A3938373737383D424041403B383A434A404D7094AEB7A68FA2969797
9C8E867B5D60555D516856646E98A1A3977F92B3B7D2D5D7CACABABBB6BCC5D9C8D4D0D7
D1C9CEC8CFD9C9C4CBCDD6CDCCB1A98B798275728598B4C7E0D8BCC2B8D0C2D5D4D3C9D2
C7C8BCB0A09EA5A4B09CABA9B9AACEB8DDB5B98A6E8480877F6F5A58554B4A7169926772
4F5846443B49454F44464141434C5952534D74587B6879707366514B49494E494251546B
6C948E958B9B92A183A49EC29E968F94ADB7CCCBCBAD9C7979666A70564D67617B7C8B99
9D9D8C6D4447434041413C4B48625C676E7786A1AAA3ABB2B6AEADABC3C9C2B09299A6C1
CECCB88848413834353839393B3A383838383736373737393B3D3E3E3636373839393736
3738393A383636383B39393B3B3837394B598A9F9E9B8A845A4C3B373D3E38353837483D
46403A42333941393B3738323D3A383A3D3C3A39393836343335393C373C384541564D42
3A3A3A39383736353737373737363535363636363636363637393937383C3F3F36383938
37383B3E475A79A3B1C3E3DED6C5A08C6C654B52
4F4F4F4F4E4D4C4C4E49484C4E4B4847484948464A4F4D484C4B4A484746454543464446
4B4B4647494848494845474B464645474A45424745464643404144484547454F4A4B4547
4347453F414A4B4547494C48424852534D4647494546474141433B43564C3E4A46444242
474B463E3D40454B4D49444140414243464848463B3D3C3A3E43423B3A3D393C3D3D4443
40433B3E3E3A3E39453D3C43443D38393C393D3C3D413E41433F3D3D3C3A3C413D3C3D40
3F3D3E423B3B3C3B3A3C3F42403B3D403E414440413D393A3D3F3F3D3D3F3E3B3C41413E
3E3836383C3D3D3F393B3E3F3E3F40414F4341404441353E484139383C40403E4040403E
3D3D3F413B373E44403D3F3F473F3A3C3E3A37363C44413B3E3E3D3F3E3D3C3D3E3E3C39
3C41444443433F39393937383C41413C3944443D3F413D383D3F44453F39383E41474541
423E3C4242413F3D3E4146494246373F504A4444423B3F48423C434C463F3C40413E4046
403E3E41413D3B3D40423B40413E413B4042413F4042403A383C403F3C3A3B3C3F42413B
393B3C3A52524E4C4D4D453B45403D3D3D3C3D4144423F3D3C3C3E3F383B3F463A39473B
383A3C3D3D3C3B3B3E3A3F3B3C3E3638373C3A383B393A423F3D3935363B3D3B3C3F4044
4844434C494846423F3F41433A383D3E37393F3E4244333D3C4534363E3936393B39373B
403935383C3B39383D3E3E3C3B3D41443D40413E393A424A647093A9B5BDAFA2AA8E8175
6953514C566B5E8A6CA27C966B836D6B8191B5D8CEBCC7AAAD87A594C1ADCCAFB69DB2AA
ACAFB3A7AFB7ABBAB0D4D2DCD5D1B9AC81977A8EA0A1A1A6ACB9CADDE1DDDADBCBB6AEA3
A18E977E7A6D6E6C72727782809894BBB9E3D6D9CBDAB8B58D825D5864504C414C415250
52645D4F4A4D4C56494640414451666972605F61546C697A657973676462615B51545E52
5E66665C68769A84AAAACBCED9D6CAD0CAC8D3D9CAD0BFBAACBFB3BE9F877E6A645B6567
9395B7B78788645E4B4044393C3E424844424666797781877B8E9D959AA8A0B4BCC3C4D3
D2CCD0B67A68513F38383A3A3C3B3939393A39383A383737393A3A39363637393B3B3836
3837383A383333373936373B3D3B3B3D545D837F615445413B3E3A393B3635404E526E5F
66513C35384139392D3B3331363335393A353334393A39332F34424E515C5B6151605447
3B3B3B3B3A3836353737373737363535373736363535353535393B39383838363B3B3A3A
3C444F58A0AEC7E8E7E3EDD6CFADA47D7A5F5158
514B494B4B4B4C4C504E4C4C4B4A47444948494B4B494B4F44464747474A505545444648
4644454944474844434648484544474A443B3F493D42454240434546434447484442464D
49414441404545504A4B46474F514D4E3E444A4A474443453F4B48434A473E4240404148
4F4A4243404043474947413C3D4245444343403B3E3D4147453D3A3E3C393D3F3B3E4544
3D3F404140414243383A3C3E3F3E3C3A363D413F3D3E3F3E3B3742493E3B4240373E413F
3E40403D474343423F424239373C3C3B3D3A373B3F413F3B3A3D3D3A3C3A3C41413C3A3B
403A3A3C3A3F43403A3C3E3F4143464844413C3938393B3D3A383D3C3D3F3B3D3940393A
3C4641433C3F403C3B3C3E3D3E3D3B3B3D3F4041383B3E3D3C3C40433E3D3D3E403F3D3A
3C414B48423F3A3E413D4044434547424443413E3B3C3F43374147433C3B3E4041464747
41434D47444141413E3A3C413C3A3B3E3F40454B4B424949403E3F45423E3B3B3E414241
3A373D414041413B3C39393B3B393C4139403F3D403E3D43373838393E44443F46494539
3C4553747C6657473C3F404340423A3C3B38403E4440443C373A373E3A393E44423C404B
3F3B3A3E424242433B4141404039373F3D3F33373C373F433B3830414239443E454C5A6A
90635C484B453E3B3C3E3F3F393D403F3D3C3E413E3C3E3B42453A3D423E42423B3C403E
34383B3A3634383D35373C443D433F3F3F433A383E5D76946D5B66697A9B88938288938A
837063545B4663515D56615C635D558FC3C6C9B99D8E82787774717F7997879165726277
676D807D848895A1BFC5D3D3DAB9975D5344485356525365686789BFC8DBDAC98F7E5F52
49534A4246443F474B4A50506A5F8688C4CDDCD7DED8C6AB917E6F666769715F76647979
81A39E8B929A9E958E8272667170979197897F6B5F60596F697A8466595E685751736466
5C6A6163595351616583859898A6B8D4E1DFE5E8E2DDDDD5D9D7DBDBDCD3D3C4B79F8F78
618EAAD8CFDACBA692817B523A4142493A48453B484A544B5B557B6590828AA6BCCFCBC7
C1B1BEC0C19E95734E3642343636393A402F393B363834383A393D393B4246413B383736
34373A3B39373535353536383B3C3C3B3D39444D453C3B3A3B38383D48495C9384998465
51403B373738393938363636333537363333373B363A3937383C495C6968645B50453F3C
38343B3F37353C4135363736343232333637373636353637303A3937343B433238394047
5C9EBABBE2DEEBEAE0E1DACFADA0876A58565A5C
4951524B494B4C4D484848484949484744434548484545484647484747484C504646494D
4C49484B46484744454A4D4D4B46454747474D553F454845434344434441404243434548
4441484745444046414342454E504D4F41444748474543423F4545434546434241434346
4B474040434345474846413D404344434243423F3B393D44453F3E413E3D424440424645
4041414040404143393A3B3C3D3E3E3E3D40413E3C3D3E3F3D415359483D3C383B3E4141
3F3E3C393F4044444042443E393E3F3F423E3A3C383B3B393A3D3D3B3E3E3F403E3B3B3D
3D38393A393D423F3B3A3A3C3E40403F45423F3C3B3D4042403C3F3B3B3F3C3F3A413B3E
3E4540444043433E3B3C3C3B41403F3E3E3F3F3F34383D3F3F4045493C3B39393C404446
3E3E433F3C3E3C41424043454244464341434443403E3D3D424544403F44484A3D404043
3F404A453E4144444444454841424343403E444C755647413D3F4047393B3E3F4043484C
3C383A3C3C3F4340403F4144423D3A3B3B3F3D3D42413F423B3C3B3B3E41403C3A403D4B
6C838B926D55493F383B414B41443F42434247444442423C393B3B403A3C3F43433F3D3E
3B38383B3D3D3E4137393B3E403C3A3D384039383D3D413E434B57726D5350474F6B6491
7C744D4B43403C3C3E40403F4E4F4E4A443F3D3D42403C393F4340453F3D3E3D3A393B39
3737383A3C3C3B3A3C3B3F433A3C3E41433C404069789F8A886D7D7080756C6C6D737770
6857483E4C3E4A59556868746D6A638BADA7A1917F71665F615D51544E584F54454E414A
49536D748391A4B4C9DBDDE3C9B7947270686D73767571787F749FADB89D9C7B705D533D
4942483E383F4149464045474A595E807FA29EAEA1A3A19C9A9EA3A5A4B5B9CAC4C5C2C7
BACBDDCEDFD6E6D5D8C8BBB1B5A9BFBABCC3BAA7A1999AA8989B9B8581838B82716E6453
544F574855434343414D4C474F6998B8CEE1E7EDE4ECE6EFD8DBD1DCE2DDE1DDDFDBDDD3
ACB0BCC9D3DBE5D8DDC6B1977E8878764D4D473C423B4345383C485150716D8E99AFB2A0
998BADBBCAC9CABA7C54423B3F394634353D37373537353638363432393D3F3C3A393632
38393A3937363637363636383A3B3A3933343D3F3D3F3C3A393F3F5892B5B5BCBD986243
3C3939393738393735343537353738373535383B343635373D424A57514E49423C393838
3736393934323639393938363535363633353838343435343B372C374A5252463B5783AB
BEDDE7E9E5E2EDE9DCD2B697736E625249494C4C
516565554F504F50494A4C4C4C4C4C4D4C4B4C50504D4B4C4C4B4A474544444443424448
4B4D515648484543454A4D4D4B46414144494C4D464A4D4B4847464549433F4348494848
4B4A4F4C48464449464745454846403F45444546474643403D3D414242474945474C4B49
4B494342434344454543403E3D3E3C3B3B3D3E3D3E3B3D42433F3D3F3D3D414240404240
41424241404041433B3B3A3A3B3D404146423F3D3C3B3E41453E414239383D3B3D3D3E41
413E3A393E4147453F3E3F3C383C3C3C3F3B3535393B3B393A3D3D3C3C3F413F3D3D3F40
403C3C3E3E4145433F3E3D3E41413E3B4846423F3E3F4142433F423E3D3F3B3E3C403D44
41443E44444645403C3B3A383C3C3C3C3B3B3B3B3A3E42423F3E42453B3C3D3E3F414344
4541423D3C3F3C3E3D3D3F3F3A3B3E3E41424444413E3C3B3F4142414144474743423F44
423F47443D4142403F414447404244423C383F487251403E40403D443F4143413F3E4043
423E3D3D3B3C3D3B423F3E3E3D3B3B3C3D3D3B3C4343403F4242413D3B3B3A3743525570
969F8B6C58423D3B37383E4B3E3F3C414342433F4646403E3B393D3D3D3F3F3E3F403B34
38383C41423C38363E38383C3B3A393736403C3837363C4054667B9082655C515C596F53
5E3440383E3C3C3D40413F3C42424342403F3D3C3B3E3A3A3C3A3B3C3C3D3B3A3C3B393A
3A3938393B3C3B3A35373E423B363B3D423E35524E857E7A7E8A9ABDA9B0857A51545564
7474625982627F688062706A65635A656E615347514B48454C4C3F3F3B3D454243484653
687998A2ABB3BFCDD9D9E9CDD6BCCEBBC5C1C1B9B5B1A199998E80946B71594E48444044
4546403E403F3739393A45493C40484C4F4C535460605D5856595D5F707C829C99A6B1BC
D2D4D3E7DDE9E5D9D1B5A2918D838F94B9D4DACEDCC6D0D1D3CDCAC5D0CCCDCBC5ACA190
97858263654C543E4D434D3E3F4D73839AC5D8E3F4ECEBE7E7D0C0B0C5CED9D4D4D7DDD6
DCCFC8BBBCBFC9D1D4BDC0B3C2C3C2B9A1958A6F614A403F503148324D47637586A3989B
86909BA7B2B5D6CBC3886E4F3941384336343B2D373A38363C3C383B393A39393A3B3733
3C3C3A38363637393837373839393837373D43383439373E3D7498B5DAE0C7B38A5E3E35
36383637363839363332353838383837373738393838373C4547494F3F3C373534363839
383C3A35333231323A383634353536373334393A353A3F3B303B3836393B485789ADCFE5
E3E8EAE8E4E2E3CCAC97795D494A484340404040
4C615F4D4A49464B47494A49474545464B48484B4D4A48484A4947464442403F4343474C
4C48464749464341434545454243414042464541474A4B4A47464646484342464A4A4948
46474946413F4044434343434443403F4646474747464442464546444243413B48504F49
4A4945444141414140403F3F41403E3D3E404242423E3E4143403D3E3E3E3F403F3F3F3E
3F414242424142433E3D3C3B3B3D3F4149423E3E3D3C3E43473D3A39383E44423D3A3A3F
413E3D3E3F4143423E3C3B39383B3B3C43423E3F42413E3C3B3C3D3D393D3E3D3F444541
413E3E3F404345443F404141413F3D3C4B4844403E3D3D3D3E3E44424040393A3D403F49
43433D444344433F3D3C3B3837393A3B3B3B3C3D424445423D3A3D403C3E404141404142
464143424548403E404143413C3B3E414241403E3D3D3E3F3B414645413F414348443F44
45404545423F3D3B393B42493D3E3F3E3A383D454D414142413F3C433C3C3C3E40403F3D
40404142413E3A35423F3C3A3A3A3A3B3D3D3C3D40403D3C41413F3C3A3A3C3D50646C78
8C8B6E4945393C3E3939383F3C3B393B3E3D3B3742443D3F3E3A3F3C3F3F3D3A3A3C3A37
3A383B4145423D3B4239393B35363A39353A3B3D3E3D4C6263727A7A685A594E464A4D4A
3A403F4A3D3C3C3F41413D3A42403E3D3D3E3D3C4046404240393C393C3F3B3B42413C3F
3C3C3B3836373A3D403E40433D373D3B414B64628E70A897BAABC9B6C9B5B7A296938283
8382737562524B5041483E444244403F43413D3E4142433E40413A3D45444F4A4A5A637D
98A6BEC3C4C6CAD5CCD1BECDB2CABEBFC0BAB5A79E9682757B606350523E483745453C47
3C41393F40423E43454246444E42624966465E52605F5D5D5F61605F61555C5662597676
9A9AAFC7D1D7DBCFD4B8A28876665C5D6C8A88A0A5AEAEB3B3AEB0B8D3D5D9DDD9D3D1D5
DCD8CAB790907B8D81917F8A6B6A685A5E8EC8E6E2EDE6EDD4C8AEA3A3B6BFB1ABB7C4C4
C3D0C9D1C3CDBDC6CAC8C3D2CAD6CDD4D3CDCBAE9D897A74775F4143344037565E829A9A
9F969F9BA4B2B8D8CBCB9E84653B403742323E3C3F3F3A353B3C363D3A3A3A3A3C3C3A38
3E3D3A3836363739393837383838363439373C393E40394587B6D2E6E6B87F5A4A3D3D39
373A383C36393A38343235393938373738383837353533363C3B383C3A3837383B3C3937
3B433D343637333138353332333434333835383732363A333D3536454C5589C9CAE8E9DD
DAE6ECDED2C5B48B614F433D3B3C3C3A38373838
4B57524A4E4D4B534F5051504D4B4B4C4E4B494C4D4B4A4B4B4B4B4C4C4C4B4A49464445
454445484F4D4B4B4C4B4A49444B4E4C4C4F4F4C45444443424243454141434747444344
44494C4C494646453F3F41424243454545484B4A46444445414545444747433F41494944
44444142414140404041424343403F3F414343433F3D3D41444342434343414041414142
3C3E42434443434441403F3E3D3E3E3F46403E3F3F3D3F43444243413C3D4141403B393D
3F3E3E403C3B3A3C3F3F3D3C3F403D3C40403D3F46433E3B393A3C3E3B3C3B3D4348453C
3C3B3A3A3D3E3E3F383C3F3F3C393A3C4644413E3C3A3A3A3A3B42403F3E383B3E3F404A
42423E423E40403D3D3E3C393B3D3F403F3F40424041403D3B3C3F423E3E3E3D3D404549
3E3A3F424A4F4845414343403E3D3E42403E3B3A3A3D3F413B3D3E3D3B393C4045423B40
433F4343433C393C3D3D444E423F3D3D3D3C3F433F4349403A3D3E4840404040403D3A37
3A3C3F4345433E3B40414241403E3B393B3C3F3F3C3A3A3A393939393A3D4348575E5B49
484E40323C38413F3B3D39373E3B3A3A3D3F3C3B393D393F403D423E3D3C3B3C3A383A3E
4F4339383C3E3D3D3C373C3F38373E403A39393D4245506561645F544541443C413F4340
373F36393B3A3A3D4143424047433F3C3C3D3D3C474841413C38403E3E413D3D43413C3F
3A3B3C3D3D3E3F404B45393B383B45405268789C92B8B5D2B1A399AC91A4838C706D5953
4B4B42464239453C4841453C3D414038393D3D444143453E3F403B41433F424B4D727A94
A1A0A5A7AAB2B1B6C5AEB499AD9AA491968A83786E64524B46413E48404F565C65626B64
6753534E545E636867636866777084818282878E8A8B919FAEB7B9B7BCA28F756D58665D
5E6269747D9CBBD3D5CFCEC3B4A3817562575C5A716C7B777D828B95B2B8BDBFC9CDD4CA
C5BCB7ADB9B5B7C8DBD5D0D3CFCFB6A69391B0B1C7D9D7E3D3C29C7B6B797F7D7D8B99A2
9AA89EB0AEC4C9DFDADAE4DDE3CDD6D6D9D6E0D1CECAC9CBACA678654F4B354C51787F95
8CA7ABB8B3BBD5C7D2C4C6A99563444439413B3E3F403B393D3D3B3E393A3B3B3A393A3C
3E3D3B3938383737393838383838363436363C3B35355288CDDEDED7B26F44343D3D3E36
363B363B363A3C3B3734363938373636383837353435333435312F35363535383C3B3733
3A433D33373A363335343333353534323935373A3738383231363E4A6FACD7E3E5F5EEE1
E2E2D6B79077624C3C38373D383939393837383A
4B4C47464C49474F48494A4A494949494946454747464648464646454342414141404349
4C4A4849474545474846454641474A4542434545484544454545474A4143464947424244
3E4341424241454245444545403F424242474B4A464243464448464548463F3B3F454543
454341434342414142444647433F3D3F41414141414040424242404042423F3D40403E40
3A3D41434343444544434241403F3E3E403F3F3F3F3E3F41413F3D39383B3C3B423F3D3E
3E3D3D3E3F3C383A3F3E3A3B40413C393C3C3A3D423E3A3838383C403F3D3B3E43463F37
3D3E3B3A3E3E3C3E383C40403C3B3D403E3D3C3B3B3A3A3B3B3A3F3B393B393E3E3E3E46
3E423F403B3D3E3D3E403E3A3E3F413F3D3C3E3F403E3C3B3C3E40414040404040404142
3F393B3C434A45453E403E3D3F3E3D403C3B3A3B3D3F3F3E3D3B3B3F43423F3D4C4B4141
423D3E3E403A393D3F3E3E42433E3A3B3C3B3B3E4046473A383F3E443C414645403D3E40
3B3E3D3E42413E3F383C3E3E3E3F41413A3B40403A383A393B39393A3A3B40464B4B4A39
374340413C3A413D3A413E393B3738373A3F3D3F3B3E3D3F3E3C3D3C3A3A3D403E3A3A3E
4F44393739393A3B383A41443E393A3D403C3A3942474247423B3B3F3E3D3F3D403D3C3C
3B443A3E46433F3E3E3D3A38413E3A38393B3C3C3F4040413C3A3F3D3F403F3E3F3D3939
39393B434C4E48413F42354243545E557876907FA88DAF94987678525E4B48463F3E3A3B
3C423E38434041393C3E3F393B403F3A3C3F3E424140413D41443F474851617982A7AAB7
B6ABA7ADB7C3B7B3A7A18B977581605D4F46474645433D423E3E3F424862849DBBB7B2A5
98867D7972808C9AA09C99909C89969598A1A3AAA7A7ADB9C5CCCFD1D1CBACB19AA69F9E
828B79856F8E88A2A3AEBDCFD6DFC7C1B497A18DA28F9B909C9B9686898380787C728873
80727C6B858386B1C6DAE0E6E4EADBE4E1CBC6B0A7A8AEB6D4C5B68B776E5F5F616D7D93
9596918B867988A0B3C6C7E1DDDAD3D5DCD5DBD1CFCBD8E0DCD5C89699636266919B9C85
86869AA3AFC9CDDBBFCCB19F89815555353F423B3A3D393E3E3A3D3739393A3A3835373B
3D3C3A393939383739383738393937353E383842485A96D8DDCCB495643A384435353635
39383233363A3D3C383636383736353638383735363938373733333A3634333538393735
373C3A333439373336353536373736353634363B3B37383D3C4975A2C4E0E9E8E8E3E0DA
CEAD91754B3834383B3B39403939393A3937383B
54514E4F504D4B4E4A4A4A4C4D4D4D4C4B494B4D4D4B4B4E4F504F4D494747484B464446
474645464E4C4D4E4E4B4B4E494C4D49464445464A4746484947484B4746474947434345
4548424244464D4842424647404044434043474846434242414042444447463E40444445
4844414544413F3F414444444A4441434545454641424342403D3B3B3E3F3C3A3F3E3A3C
3D3E40404142434545444342414040413C3F403E3C3D3F3F3E3D3C3C40423D363F41413F
3E3E3E3D40403D3E413C373B3A3E3D3D4244454B3F3B393A3B3A3D41403D3C3F413F3B39
41423E3D41403D3F3E3E3F3F404141413A3B3B3B3B3B3B3C3B3A3E3A373A393F3D3D3B41
3942413E3D3F3F3E3F403E393C3D3E3C39393B3E413F3D3D3F403E3C3F40434544413D3A
423C3D3A3D423D3E41423F3F464642433C3C3C3D3F403F3E444142494D4A433F4E514540
413D3D3C3C3C3A393C403D373F3B393A39393B3F4042423A3E433B3C42474A473F3A393C
3D3F3B3A3E3D3A3D373C3D3A393E43463B393E403C3C3D393D3C3C3D3C39393C3A3B3C3C
3E413F3D3F393E3D3C413E3B37343835373D3A3E403F413E3B3C3B3E3E3F3F3E3E3E3C39
3A383A3D3D3C3E433C3F4042413A373A3F3B3E40494C42454338373D3D3A373435373A37
403C373D3B39383A3E41424144423F3D3B3B3A393F3D45474343413D3C3C3F403C3B3C39
3A393B444E504A424152475A54696A5C636A808788916C684B5042453C4A353D3F40453D
383F4942393E3E4341423D3A3F433D3D41403D3C4541403E42464A5C7A90B1BEC7D4DCD8
D5CFCDD2D1D3BDB5A7908B7165514942403D42403F3F3D433D3C3F3C4A5B798C8F9DA0B2
AAB4A8A78A9CAEC3CABDA68B8E6C7C667B67746775787F89929EAFBECADBCFE3D7E6D7D5
C0B09D9697A19DA9969B9BB1BCD1C9D3C5CACBDBD1DED1D6DFD6C9ACA299988B9B858D79
8674716465686D819BAEC9D1E3E6E0DBDDD7CFD2CCC9ACA59A9FB6C1AFA69187786F6B78
8B93AAAFA4846B685C6E7C98BBBDD0CCD0D0D5CDC7BFCDCCBEC4B7C0A08D7B7A94ABB3AC
94877B8097AABEC1C9BAA38B948C9B66563C3A383E3F38423E3947393F3B383A3A38373A
3D3B383839393837383737383A3A39373F3436679BBCD8DBBE81564538383C3A39393A3C
3734383538393A3937363638363637383939383734363434363231373836343537383735
35373835323638343536363535353637343635383A364360799FCFDEE3EDEBEAEDDDD7B8
8B5D49403B34393B3935323C3A3735353434383E
4847494A4848484748474748494A48464242464948454548424547464444474A45424246
484644444A474646433F40443F4042444443424145424245454342454844414242403F41
3E45414648474A4042424849413F43413F4042454645413E473F43453E4346383E3F3F43
46403C41423F3B3B3E40403E4A423E3F424141433C3F41413F3D3C3C3F413E3E43413C3E
40403F3E3E40434646454341414143443B40423D3A3C3E3D3C41423E3C3C3A38393F4341
4041413E393E4042443D3B423D41403D3F3D3C41403D3C3F3F3D3E413D3B3C3F3E3A3B3F
3F413D3B3F3D393C3F3B383A3F413F3B3C3C3C3C3C3B3B3B3939403D3A3A373C3D3C3A3D
3642423D4041413F40413D383C3E3F3D3B3C40443F3D3C3E4344403C3E3E3E4042434241
403C3F3C3E413C3D3D3E393B4546403F413F3D3D3F40403F413D3C3D3B38383B41483E3A
3D3D403F3B403D363C4A4A3D3D3D3E3F3D3C42494845423E4445393C3C3E404141403F3E
363A37383E3E3B3D3F474A453F3E3F3F3C383C403F41413A38373A3F3F3C3A3C423F383C
3D393E3B42373D403F3F3A393A363C38383D383D3B3A403C3B414149454640383A424036
3C3F42413A363B433E3E393A403D3A403F39404447413848453B39393A41423E39453A40
383A31443E3C3A3A3C3D3C3A3F3F3E3D3C3A3938413A42403B3F3C3B39383E423D3E423E
3C3C3D41454746445469555F4858523F526182728158404441443E3B47393B463E394239
3A424A353D3D3E41433A3A3A4444393A413F3C383C3B3E3E44506484B8C6E3D6DFD5E5D6
DBD9D2C6AC9D827D6F655F614B4D3B3F3E4046403B3B373B3E3E3B3F444C4B4D505A6E74
8585877F838B8988817468585D4A554D533F4C414047535F6C82A4C0C7D8DED8E4DEE2DA
C2B297A593A891A097917D8A868E828E93A1C4B7D5C5D8D5DCD8DBCBBFAEA08785807C80
8B8F89A07C9A7E8E74908EA6C4C9D5C5C6C2A1A9ACB5C4C3C49AA8A3B5C2BAAF9C968F96
9D9EA9BEB8BF8A785E644E576267767794A5B3ACA8A2AD9D8B86A9A4B397A97D93A6C1BF
BD9B7D6A618391A8ACAD99A08EA5A2B3866A484641433D5051567466463E393B3E3D3A39
3D3A373638393938373737383A3B3A393347629CC7DBE1C27044404437373C3F38393A3E
3435413539393837353536373637383A3A3A3A393A3936373B373337353535353635322F
3735393832363B3633343332313134373238383E485072A6C3D9ECE3E4ECE8EDE5DEDC9F
5D393A3C3D3A3C3634373C4A423C38383A3E4852
4E50534E494D4E47484A4C4C4C4B4B4C4345494B4B4A474648484A4B494A525C5248484E
4A4545464544434446474644494A49474444454742494D4A47464543494C484547454245
43434B4F4A4A4B464A47494944474C4C4745434346484744484949454142464A3B414443
4446433D3F3E3E3F404141403F41444543403F403C3D3F41424241413C3F413B40453F42
42403E3E3F4245483C413E413F3C403F403E3B3C3F4242423A40433F3D3F4140453F403D
3F423F41373F3C3F403F443D3B3A3A3D4142403D37373E3E3E403E423B3F413F3F41403C
4548443E3E3C3E454342424243413F3D3A3B494E3F383C3A35383C3C3B3B3F42383B3E3D
3C3D404239383C3E3C3D3F3C413F3C3C3E3F3F3F3A3A3C3F403F3E3E3A3C3F4242413E3C
3B3A42403F413B4039393A3D404242413F41434342403F3F403F3E3D3C3D3E3E3E3E4041
3E39383B434243433F393A3F42454444453F3B414E3F383E403A3A413D3D3E3E3D3C3A39
34393C3A393E44463B3A3D42433F3C3E3A3A3D41403B3B3F363B3D3B3C3F3D383F3D3B3C
3F4141403D3D423D3E44414141393A3D3A3A3E3C3C3F3B3E403F4645413F3C393C403E39
3C3E3F3D3C3E42443D3C3D3F434648483F3D3B3A3A3B3C3D393A3A3B3E413E38373A3E40
3F3C3B3B393F413D3A3B3D3C3C37363A3E3D3B3C333A3B3E373741373C37423E3D453F3E
3C4242565849515148585853495554515058524542403B3A3E453E4243373739413E3B3A
3A3C3C3D373E453F42393E45413C3F3E3C3C3C4540403D4F6681AAC0CFDEE2D6E1DCD8D5
CBB598806C5B5352483F3F403A3B3E3C413B3E3B41393E403D494A46645B7254584D4C4C
4E424A544D5A4C5F635F6E8879837E9C7E9D7D92738B6F7C7B8E9199A7B8CFCCD7C2C1AC
9B9FA898949D8CA5A5B2ADAAA4ACA5A597A0928C7F7A84749296BCBFCAC6C9B9BCBABBB6
B5AAB38C7C7F869BA596A895A9A5B2A4B2C0BEC1A7BFADA19CAEA7AE9DA998A57A708182
B8ADBBB3B4B8C4A3A78D8E77917E977773685852585A565558656B8978A2899989A7B3C7
C6AE9B98838E9D8F8E6B7983A78394B3BA84757B8F88A9BCBAB9AAA074443C413736373A
3C3C393C3E3E3C38353C3B32383C353B408EB1BDD9D4AC6B4D5B3D3A3E3C373937393A3A
38373839353739393838393B363333383C3B383833373938393B3A373938373635343332
35333335353335393231373433342F373539364B82A39D93AEA0B7A2C4DDDDD9DCDEB37A
503A3B3A393637393735383B34393A3C3E3F4E61
54474145494C4B4444464747454444444445474847464442434345464443484E47404248
48474A494A474341424546473F40414345484B4E42484B48454444424346434144444448
4C494A4A45464A484643444542444948484342484C4A4949494A4947434142443E3E3D3E
3F3F3F413A3A3B3E41413F3D40424443413F3F3F3D3E4041424241413F42433C3F423B3D
383C4145484845413E423F41403E43424041403F3F3F41423B40413D3A3B3D3D423C3E3B
3C3F3B3D3C423E403F3E423C3A3B3C3D3E3F4143434145403C3D383C3B40433F3B3C3E3E
3D413F3C3E3E404740403F3F3E3D3C3B3B39454B3F3B3F3D32373C3E3E3E3E3F393B3D3D
3C3D3E403B383B3D3B3C3F3C393A3C3E3F3F3D3B3C3E4040403F3D3B44423E3B393A3C3E
393A423E3D3F3A3E3D3E3F41434442413F41434342403F3F403F3E3D3C3A3A3944413F40
3E3B3D4039393C404140434846443E3D413E3D4255473F42443F3C3E3F40403F3D3C3B3B
393C3D3A3B3F43433D3C3C3E3F3D3B3B37393C3E3E3C3C3E373C3F3D3B3B3C3D3F3E3D3D
3D3E3E3D3739414143464141403C3F3F38363C3E3D3F3B3F41414746393A39393C3F3E3A
3B3D41423D393F483C41494F514F4A47433E3A393B3D3B3938393A3B3F43423E383D413E
3A383B3D373C3F3E3C3F42423D39373C3F3F3E3F383B383C3B3B40393C383E3E3E45433E
3F46495E605155545258535042443E3F3C423E3A424845423A3F393C3F383C403F3D3A39
3A3C3C3C393C3C373E3D40433F3A3E3D3D3F3C404052637B93ABCBD9D5DBD8CACEBEAEA4
817463554B433F3E3E393A403F3D3D3D3A3B423E413F4E57627F81989392867B686C4F56
4F4E4B59606B60717D80848D8C8DB5BAD5CAD4CEC5C9BAB3AFAEAAA396A19CA3A0AAADAC
B0C4BFC2B8C6BBC9C7D2D3D8D8DDD8DDDBD5D6B2BBA4BBA3AFA7B9AAA59BA19BAACBC2DD
D6E8E1DDAFC192AC7F8C828EB9A9AEA4A3A8AEC0C2CDD0C3CAC2C8C0B7ADB6A9A797A7A4
9C8E8C8A95B6ACC6A8AD8DB29CC6C0C0BBA98768503E42575A606A64575A62759099A0A1
B39C9486959C98918D5E576F5E5E82A997928BB6BECCC8BFBEAE865F4C3136413C393739
383C3C39383A3D3C3F3A36363F39354C8DCCD4D6BA97613B414C3835383A323A37383838
3838393A3134363838383A3B393534383B39363532363837383A39363334343637383939
333436373533343736383531383A343932383E4F6A716762565956638CB9CABC9C937052
3F3539373636373B3D3A393C384039545F565B43
83644F4D4C4B4C4D4A4B4C4B494747474B4B4B4B4A4847464847484A494546494B46484B
4A4B4D4A504D48454547494A4B4A484848494A4A4A4E4F4C494849484447434142414249
48464645444850524B46474745484C4A484140484A444245474747474542403F423F4248
484341434643414243433F3B424342403E3E3E3F3F3F4041414141413C3F423D40423B3F
3F4243424446433D40433F41403E43423F4142403D3B3D3F3E41413D39393B3B3F3C3E3A
3A3D38393F423F40403F413D3D3E3F3D3B3C40454844453E3A3A36393B41433F39383B3F
3B3E3D3B3C3B3D4240403E3C3B3B3C3D453F42443A383C3B3E3E3D3C3B3C3D3D3B3B3C3D
3C3C3D3E3C393B3D3A3C3F3C3D3F41413E3B38373C4142403F413F3A3E3E3D3C3C3B3B3C
3B3F46424043404042424244454543413F41434341403F404343434241403F3E403C393B
3B3A3A3D414040413F3D3D3F42403C3F43403C3D4F453D3D3F3D3936404141403D3C3D3E
3E3E3D3B3D41413F3C3C3B3A3B3D3C393B3D3E3D3B3A39383D3F42413B35393F3D3E3E3D
3B3A393A3A373C3B3D413E433F3C3D3F3B393C3F3F403B3F424247443B3D3E3C3C3D3B38
3E3B3E44413A3E484D5053514C45403E47403A393C3D3A363C3E3F3D3D403F3D454B4B42
39373B3D3A3E3F3E3C3D3F40403C3A3B3D3D3C3C3D3D373B403C3C3A3D4042484A4C4F44
4A4E4E5D5D4D4F4D484742473D3B363B3E423E393D3F3A3640413A3A3A35393C3C3A3939
3A3B3C3B3E423E373A3D3D3F3E3C3F3D4149474974899DB3C4CBCCC2C9C5B9ABAA947E72
504C453F3E41424045403D404038363D3B40494B5863767F868C767D6667535846553D48
4D4F5464646C656C7F97A6B2AFB8C1DBD8E2E0DFDDD7E0D7E0DDDDD0CAC7BDB4B4AEB5B0
CBDBDADEE6D9DFDBDFE5E4E9E7E6E2EADAE5D6DDC9E3DCD6DAD1E4DCD4C2C5C4CACFB7A2
C7C3CFD0DAD0D8C8CDB3D4B9AF8B7C70616D8AB4A3BBAFCEBCD3C5D0D2D7C7D3D0CCD7CF
D9C7D4B5BC8D866A6A6B7C7CA49EC4B9BFBAACA49A888EADB5CCBFCE9480626B707F7D9B
999B745A6F666C669161594F4F4D9194967D7C98C1B6B8927A897D6E544342423D3B3B40
3B3D4038363436363C38383C3F354780CBDAD4AA904E41383D473E393639314039383736
3738383835363838373535353B3736393A36333232353736363838353737373737373737
333637363535373837353643473B35363B38383B393843534E68676D847A875A5B4C3B39
37353B3B383D3A36353033414A5C77746B604438
69544B4E4C494E534B4C4C4B494848494A4948474645454549474749494544454A484948
4546484348474543424141414745434345474747494B4B4846454546424443444745474F
4A49484645474B4E4D4644434145484645414145474544453F3D3D3F403D3B3B3F3F4247
474340404E4944424343413E4444413D3B3D3F3E3F3F3F3F3F3F40403C3F423E41433C41
3F403C393C45484641433F41403C403D3E3F3F3E3D3B3B3B414242403D3B3C3C3F3E413C
3B3F3A3A3D3F3F41424242404342413E3B3B3D40403C3F3B3A3C393C3B3E403E3A393B3D
3C3D3D3C3B3A3B3D42413F3C3B3B3D3F4C413E3C36353A3A43403D3C3D3E3E3E3D3B3C3D
3C3A3B3D3C393B3D3B3D3E3A3D3F403F3E3E4042393F403C3D43433D393B3D3F3F3D3A38
3A4146424144434143424242434342413F414242413F3F403C3C3C3C3C3D3E3E413D3D41
44413E3D4240403F3F3E3D3D3E3C3D41423F3C3C3A3837373A3D3D3C3D3F41403E3D3D3F
3F3E3C3A3D42403C383A3A383B40403B3B3F3F3C3A3C3B3737373C42403B3F483B3D3F3E
3A3737383E383937373A393F3E38373D41413F3D41413A3E4140433F3F42433F3D3D3C3A
423B3A4144403F41484948443E3C3E4148433D3B3B3B39363D40423F3D3D3C3A4A4E4B41
39393B3B3B3D3E3C3B3B3C3D3C3A38383A3B3A3A3E3E383B423E3C424B595C5F5249534C
4F4E484F4D4144453D3B363F3A3C383D3A41423D3A3939393B3D3B3A3A393C3E3A393838
3A3B3B3A39403E3D42453E3A4440413F4F6F889AA9B1BBC6CDC9BAAA8D8373686452413B
44443F3B3C43454342403B3C3F3D465A6C78848686827C7467614D53454F4C4E596B5881
6983778A8F9EADB8C5D5DEE5E0DCE6DDE4D5D5CDCFCDD8D8E1E1E2DBE0E4D6E3D5D7CCC9
C0C3B3D2C9D0C7D1CBD1D2D3D6D8D9E0DEC3D092B2A0C3B1B9ADBBBBBCB5BDC6C3CEA57C
6863779894B39CC2C4DDCACACFB2A18F614F4A58596273668C8595A0B5AAC0A4C0B5C7C8
D0D9C8D8AA8F664A53645E757787939A9D9FA1B2C2B8B4C7DADBE3C0BB7FA6B2BEADA991
A79FA8917E6A585D68655E4D455268A0809A7FA5ADA5957F545C9FB87671695E544B4443
483E3F3A3F3C3B3C3B3C3A373A3B5FA9CBD9B6A66C4E36463E443A3934383A493C3A3735
3637363639383837363535353B3837393935323233363736363838353A3B3A3835333232
363736343537383739426489764C3F3535343F4642465C6F607D5964474549373D33343C
39373C3D363E3934393C4B6679A2A48A68453839
504A4B4E4946494A4B4C4D4C4B4B4C4D49484646464648484B4847494947464845444748
45484B474646444341403F3F434140414447484849484847454444454547464749444249
4A4A47444446494E514946434043474541434443474E5150474240434442404244464542
41444544454240414343423F4545423C3B3E403E3F3F3E3D3D3E3F404243464141403940
42423F3B3C3F3F3C44474244423E3F3B413E3C3D40413F3B3F3F40403F3D3C3D3D3D423C
3B403C3C3E3D3F4143433F3E44413F3D3E3E3D3B3C393D3B3C3F3C3E3B3A3B3D3E3D3B3A
3A3A3C3D3C3D3E3F42403D3B3A3B3D3E433C3A3B39383A3A37393D434747433F3D3B3C3E
3D393A3D3C393B3E3D3E3E38434343403C3B3B3C3A3F3E393A41433E44413E3B39393A3A
373C3E3D3D3F413E413F3D3D3F40414040414241403F3F404342414040424446423E3D42
4543403F3D3D3E3E3F4040403F3D3D3E3C3C40444244443E393838393A3C3E3F3F3E3E3E
3D3C3A393D41403B383B3C3B3D41403B373B3C3B3D42433F3F3B3D44433B3A3F393C3E3D
393738393A383D3C3C3D37393B38373D44423E3D41413A3D3F3D3F393C40403D3C3E4040
3F3D3C3F4243403D3A3D41413E3D3E3F4544413D3A39393A373C403F3D3E3E3C3F403C38
383C3C393A3B3B3C3D3E404338383737393D3F3F3B3C393A42454B5A657470694F3D4C48
47433E41413B3E414040393C373E383733383E3D3B3C40413B3C3F3E3C3C3B3A39383839
3B3C3B393A3D3C3B4445403B3F506D7F92A7B1B9C5C3C3BCA98C7062504A434445413C40
3F41403C3D41413D3E413E3E4145556F76889799908B858387768F74977EAC97AB8FB6AE
C8AEBFACCDC9CDCED1D3D6D8D3D6C9D3C1D7BDCBB5BCB8C2C1C5C3C8CCC6D1BCC89E9F88
8271808C9F9E9FA5AAB4B7B2B7B9B8B5A396796D567C7A8467596061656163687D725A4B
4C4A4D4A5C5C6E738A93B39F9A969C9B7C715F5444584A615D907FA0839F6F815E6A7F87
A59CAD859C614C4D4F6195A0CFB9CBBEC7C4BBC0CFD1D2E0D6DFBDC49F98AAD1D3CEB2AF
96AFACB7C8B5BBA09C7E9484765E5D6682829796AEACAD8F756C77A5A3B4BBB3A0877266
7357524D574A3F3D47473F394D6484B6DFDED6A9A27B7F786F6543413A3A41453B383635
363838373736353537393B3D393636393935333335383836363838363536373635343536
36353434363735334072B1CB9E675140494B585C524F53523E413937392F3B3439343B3D
363538363639374564798699A7A88D6E5337333F
514F51524E4F504C4B4C4D4D4C4D4E504A494848494A4C4D4C49484A4A49494B4845494B
48494D4C4C4B4845444446484A484644444444444A484849484646484545434649433F45
4848444143464B52534C4A474345484641464540424C4F4C504946484844434645494945
45494844424345474744403D4446423D3D41423E403F3E3D3D3F41424141444041403B44
3D3D3C3C3D3E4143494A45464540423D45403D3F4447443F3C3B3C3D3D3B3A3C393B403A
39403E3E423D404041413A3B403D3B3D40413F3C433F423F3F413B3D3C39393D403E3B39
3D3B3D3E3B3C3E3D3F3D3A39393A3A393B3A3D413F3A3736383A3D424545423F3D3B3D40
3D3839403D393B3D3C3E3E38393A3C3D3D3D3C3C3E403E39393E3F3C43413E3B3A3B3D3F
3D3E3A3D3F3E403D3E3C3B3B3D3F3F3F404141413F3E3F4043403D3A393A3C3E423C393C
3F3F3E3F3E40403E3D3E3E3D3E3C3F423F3E42453E4244403B3A3E413B3B3C3E3F3F3F3E
3A3C3B3A3C3F3F3C3D3F403E3E3D3C3A3B3C3C3C3E4141403E3A3C43443E3B3F393C3E3C
3938393B3C3C413D3D433E3F3A3C3D3F403B3A3F40413B3D3E3A3C373C3F3F3A383A3C3B
3A3F42403F3F3F3E41434444433F3C3A4142423E3A393B3F383D403E3C3D3D3B403B3738
3B3D3C3A413F3E3F3F3F40433F3F3D3A3A3D3E3D39373938404D5A6C726F5C554840483B
403D3B3F3F3A393A3D413A3B38433F3A3B3A3B3C3A3B3C393E3D44403B3C38353A393A3B
3C3C3B393A3C3E333D4056677F8DA5AFB3B6B2B3AE9986725F4E3E3D3D3D3B403D3B363A
3C3F42424343403D4547464342444F5E6B6F6C685E606368748380ADA3C6CBCDB4A1A3CC
B5D2AFA28F8184929C9591829587856F7071666860655D6B686E6D767D7C71675D52524C
554C4B5A4E6C6472717D848089878076836E906B96809B8B8D868B898C887F7B757A767C
5D5C54565A7F627A638579947A756D5E4B4E4B3F453A483D64737D7E798A928876635F52
4A5E586863716C7E6C7A6F9E84B49EB4A4A49E9BA1AEBFD0D6D1DCCED9A6AFB3CEC5CAAA
A792A3B1C6D6D3D3B8B2A5987C927387546C778D869E9BABAF988A7190B2CDDAD6CDCCC8
D4B4B4ABB39C847A7679787895B7CADFDCE3C7C6BFD2BAAC9F824F4A413D3E3736363536
37393B3B3937363637393B3B363535383936343636383836363838363234363635353739
3433343637383C426FB5E1CB977160544F4C4B453C3C3C3435352D40333E2E383C373A36
333735353A363A5D92AEAFAD8B5F513D323A3F5C
4B4A4F534F4C48414647484747484A4C464545454547484A47454547474445484943464A
44414445464646444243454742424141414244454543434545434345423F3E444C48464C
4B4D4843444242484744464540404240464846403F42434149423F42413C3B3F3F414444
4442403D47494A4946423F3D4346443F3F44443E42413F3E3F4144463D3D403E3F3F3D49
46413E3E3B383D45494942424240433F44413E3F424443413F3C3A3B3B393B3E383B413A
3A444344453C3E3D3E3F393C3C3C3C3D3E3F3F3F4742423E3E403C3D3D3A3A3D3E3B3A3B
3F3B3D3D3A3B3E3B3F3C393A3C3C39363B3D4143403936383F3E3D3D3D3D3D3C3C3B3E41
3D373A42403A3A3B3A3D3E3A3D3D3C3C3B3B3A393E3F3F3D3D3E3E3D3B3D41434442403E
48433A40423D403E3C3C3C3D3F3F3E3D404141403F3E3F404644413F3D3E3F40443F3C3E
403F3F413A3E403E3C3F40403F3A3E45464645414140403F3C3A3C3F413E3C3C3E403F3E
3A3E3F3D3C3E3E3D3F3F403F3C393A3C433F3D3E3E3C3A3A414041434039383B3C3D3E3C
39383A3B3E4043393A43413F3B3E3D3C3C3839423E403C3E3E3A3D393F413F3B38393836
3A3C4143403C3C3E434241434646423F40403F3D3C3D3F413F41403D3B3D3D3B463E3A3C
3E3B3B3E44403E3E3D3B3B3E4343403B393B3C3B37343B3A3E4D53595C53404040424535
3D3B3C3F403D3838393D383A384542403D3A3C3D393B3D3B39363F3C383F3E3C3B3B3C3D
3E3D3B383538453F555A829EA1A5B2B3AB9B857E6452473D3D4139393C3E3D4541433C3C
3C3B3C3F3F3E3E3F444242414044484641413D444045434748507488B0ADBDBDBCAAC2B5
D1BEAD896457566167627065706A6A76688177746A5A5D5D605E5C5D64665D59637899A7
B7A38C715656717A7A838E91A2A19C949491999A8F826E61606877777B7B6B5F7F6E7463
7560665A7B7D9382998CABA3AEA5967F6D5D544749493F7599CDC8CCBEC9AAAD8C82785A
51606959605888707F61715D6B6A6F6F6565676766707F89859291AB9CA393B5BBC9D0D5
B49A8096BBD1D4D4D5C6A786686A6F6B69606357606D86A0BBC9BDAAB8CBD8DED8D4DAD5
E1CBD2C3CDC1B5B2CBCED2CDD3E1E2E5DEDEDED0E3D5B890795E3E433C3B393436373838
38393A3B3B3938373837363435343538383535363638373535373735353739383635373A
35333538383F5770B9D1C89469524340403E3B3633353632363137343731333939363834
373A343939323348636C645B4A39303D455E8995
545052534D4B50524B4C4C4B4A4B4D4F4949484848494B4C4B4A4B4D4C49494C4C44484D
4843464A4245494A49474646434445454446494B484545494A474749534C45484C453F44
42484746494642464343484944434440494847454341414147414044443F3F4447424143
43404044454544413E3D3F42424645404147453E44424140414346493F3E403C3D3B3945
443F3F433F393D4846453C3C3D3C424041403E3D3D3E4040453F3B3B3B3A3D413A3E433C
3D48484A44393A393C403A403C3E3F3E3B3B3E40443E3E3A3B403D403E3D3D3E3B37393D
3A36393B393E4240413D3B3D40403B363B3D3F403E3B3E45393A3C3E3E3C3A383B3B3F42
3D363A44433B3939383C3F3B413E3A383A3D40413C3C3E4142403F403E41444746433E3B
4C43363E41383B393C3D3F4142413E3B404141403E3E3F4041403E3D3D3D3E3E3C393A3D
3E3B39393C41423E3B3C3E3E483B394045494A43453F3C3F403F3F4147423C3B3D40403F
3B40423F3C3C3E3E3E3D3D3E3A373A41433E3B3D3E3A383A3B3E42423C393C423E3F3E3C
39393A3B383F453B3A433B343E3D37363C3C3C443D403C3F3F3B3F3C3C3F3F3D3D3E3D3A
3E393B43443D3A3D3F3D3E444949423B403E3B3B3E4141413E3F3E3B3B404342423A373B
3B373B443E3A383A3A393A3D3A3D3B38383D404038333F3E3E4640383B3F3E3E36353E38
3836393C40413E3F40413A3C373E3A393B3C4242393941433D383F38333C3C3C3C3C3D3E
3F3E3B38413F565C827D949E9F91887B6C5A45403B3A3F393B433D3C3D3E3B4340463E3B
433D393938383D43453E3C3B3B424032373C3E483F3F3C43434C52646C7F86B3A5C1B0C1
B2BE867467758D9F9E92A89FB997B997B8A1CEACC6A4BAB1C1BBBDB5A9BDAABDA8CBD0DF
E1DCBAB38A87B1C2BFBDBFBECAC0B8B2C9BBCDB5B27A6B4E3E464B40445454524F5E5C64
5E656681747D687F85A49DA79D9DA1A2A799989671695687CBE0DFD6DBCFD5C4C4A78C55
4D728C8D908F8A888A6B6B67566A515555484548474E575666646C76797D6C88ABB2C5C4
B8907E989CA694A09395828161606C7C6D70585A5B77707D9DA3B7D7D6D8D2D0C4B7B19D
A28F93757F8796A2CFCED9DBDBDFDBDBDFE2D4BFA6916D5943353341383835383A3B3C3A
3836363736363638393835333534353838353436353736333336363434373A3A38383A3D
383536383848739FA585674D423D353C3435373737363637343732373434353531333938
3A372E3A37383C3F3B383A3E3A374C5679B5CDD4
6B6D6B63564C4747444A45444E4C454A49464A454348464C434748444245474741424344
45454443414043484946464848433E3E414444434B484242433E404D513B3D464A4A4545
48414045484340403E41454644413F3F3D40413F3D3C3D413F4446444343403B42413F40
464B48403B4050403F40413E3C5356463E3E3F423B444A4640404345393A3C3E3D3B3F45
47473E3D3D3C44443D3E3D3D3E3E3D3E414243413F3F4042433B3C3F3A393D3D3B3B3B3E
414444444039383A3B3F403A3C3C3B3B3B3D3E3F45413C3A3A3D3F3F3E41423E3D3E3C38
3B3B3F3F383A403E393D41413F3D3E403F3B41433E3F3E3A3D3D3E3E3D3C3B3A393D464A
444347473641403B3F403A373D3E4244413C3C403B3F413E3D3F3F3D3A40404045423C3E
403941483F3E433F3D3A3B444946403D3E3E3D3E3E3F40403F40403F3D3D3E403C3D3F41
41413F3E3C3D3E3E3E3F41433F3F3E424844414640403F3F3F3F3E3D38393B3D3E3D3D3C
39403A363D3B373D35383B3C3D3E40423E3C3B3B3C3E3F3F3E3C3F3B3E3C34403E3F4040
3F3E40424444413E3D3F3F3B3B3C3D3E40414141363B3D3B3A3E403F3F4038363C383643
40423E414340433F3438383A3F3E3C403B3F403F414444424346453E393B3D3E3F3F3E3D
3C3B3A39393D3F3E3A373A3F3D3C3B3938383A3B31373C3C3C3D3D3B353339383A3D3A3C
3A3F403B383A3E403B37393C3B3E3F3A363E3D3B404240423A3B3C3936363B3F3B41433F
3B3C404249535C6D6C706D72585C514A433E41393E393B414037363C413A413F3A3F3F3F
3E3A37373B3D3D3C3E3F3F3E39363C45403A423C42414552586270689D7FA98599768178
835D5B788BAFB0A29F948F9485827C7E7E9592B2B6C9D2D6CEC2B7B8AFB5CCCBDADFE5E7
EBE7DACFD1D3D8CBCFC6B1B3C0BFC2C5B5B699AD7A85584C4C4F47524942434D4D494D4C
575258577964716B7C8090767D7F92A3919988967B9387A4B1D2D2DDD0C9C8BBAD9A7967
678DC8CAD2CAD5CBD4C4BB985C585D605F55585E5F636463787683786E7F7082788F888C
7F81788D9680716A635E6961636D69656A6A70867F9E9092A199AAC5C3BAA8AB8B846F66
515D503E4B50596D92B8CBD5CECDBDC5AA807E6664493E3E3E3E3F3C3A414033343E343C
3A3C383A3B3E3D3D37443639383638323A393C363934343038383B38353C393B37313736
3E2E3E313245476B4E473D363436393B3A393837363637373C3935333334343430313335
3737373736363C36363F393C3B658FA2C2D5D8CA
4E545B5D59534F4E52564F4A4F4B454A45414645484E4B4E494C4D4947494A4947474849
4A4A4949494646494A4747484647484746464849474A494949474D5C785A4C4A4B4B4443
414245494E4E49434143464747454444464849484646484A4042413E3F4345443A3D4042
474C4D4A49626B4840403D3C40484E494144443C4646433F3F4243403D3C3D3E3D3C3F44
44443D414343464243424141424445463E4041413F3E3F40413B3C3E3A393B3B3D3C3B3D
414343413C393C3F3D4146443F3F3E3D3C3C3B3B3E3C3A3A3C3F40413B4043424243423F
3F3C3E3D373941443A3C3E3E3D3D3F423F3B3D3F3D4143413D3D3D3C3C3B3A39383A4244
3D3C40403B43413A3C3E39373B3C3F413F3B3B3F3A3E3F3D3C3D3E3C3A3E3D3D413F3B3D
4540464B433E3D38413D3C4245413C393C3B3A3A3A3A3A3A3A3B3D3E3F4143443B3B3C3D
3E3E3E3E3B3C3D3D3D3E40424546424246433F423F3F40403F3E3F3F3C3D3E3F3F3F3E3D
353C38373F3F3B42404142413F3E3F403B3A39393B3C3C3C36333D414144414744423E3D
404649493F3F3E3B3B3D3B373B3B3C3C3C3C3C3C35383A3A3B3D3F3E43413D3B3D3C3C40
3A3C373C3E3E434033393C3E44474543383B3C3C3D40403E3F42423C383A3C3D3F3E3C3B
3A3A3A3B3A3D403F3C3B3C3F3B39383737383B3C373B3C3A393A3A39383437373C403A39
3B4044413E3E3F3E3C383A3E3D3D3E3A383E3C393E403D3E36383A3B3A3A3D3F383A3A38
393E40403E42424B4548444A393D393E3F3A3F3C3C3A3D42434043483E393E3E40464342
41403D39373738393C3B3B3D3D3D41473C3D34435B8A8D9BA4A68B847A718D7E889086A6
809A79998092867975675A544D48615B717785939BA7BBC4D2CAC8C3CCD0D9DEE5E9E7E5
C8C3B1B6B6B5ADA69696929EA9A59E94917A776B6661695C69574B625F565B6B60615E5C
4D6257634E5952575451506BA7BDCCCCB2AA868976747F7EAEABBDBBBDB7B7AEA0988775
6E8491A49EB8BBBFB7BCC2BD907A6052455566778B969597A39C9784737C6A67676A616E
656C7594968F98887B61726B847C8A6158586B9AB9D2DFD6D4CFC8D4C3C9BFBFA3886C53
4E5547433E434458739EC2C6BB99786C59414737463C3B42383B424139393E3D373F353C
3D3F3E403B3640373B3C3B373036403B3E393D3B3237323E3640383C383A35393A383D39
3A40373A3E383B383837383A3B3B38353A39383635353535343333333435353533343536
3737373630392F373C3242446DAECFDCD3D4B09E
4F515454514D4B4A4D504A454846434A4A45444244474343484A4B484747464540414141
414142424A464444454342424244464746454546414443414040454D5B46404145464141
4D423C40423D3C3F4343454748494746414142434142434341413F3D3E42464641454845
424141405575754E48443C3F423C44473F43473B43403B393A3E3E3B403E3D3F3E3C3D41
43433D4246454640413F3F3F3F4245463C3E3F403F3D3D3D3F3B3D3E3B393A38403D3C3D
4042403E393A40413C3F46473F3F3F3E3D3C3B3A3A39393B3D3F3F3F393E41403E3C3A38
39363A403C393B3E42413F3D3B3B3C3C3E3B3A3D3D3F423F3D3C3B3B3A3A3A3A38393E3E
38383C3B4348443C3C3E3B3939393B3D3B393A3F3B3D3D3B3A3B3D3C3A3C3B3A3C3C3B3D
434143484642403E433E3C3E403E3A373537383A3D3F414239393A3B3D3E3E3E3A3A3B3B
3C3C3D3D3738393939393B3D3F423E3B40413E3F3E4041403E3E40423C3C3C3C3B3B3B3A
3B3F3C3A3F3C373C3E414344413D3A383B3A3A3B3C3D3C3A403941423B3C3C3B3D3D3B3B
4146443D3B3D3C3B3B3C3A35393A3C3C3B3A3C3E3C3B3A3C3C3937373E3C3C3D3E42423E
3D3E383A3B3B403D3C3E3F3D3D403E37373A3B3A3B3E3E3C3B3D3E3A38393C3D3E3C3A39
39393B3C3B3D403F3E3E3F3F43413E3B3A3A3B3C3A3C3B38373839393B3537383E423937
353A3F4141424342413B3E423F3B3A373B3E3B383C3E3B3941403F3D3C3B3B3B423F3B3A
3E454541403F393E373B3940403E3B4141393B3C4342403D3A393A3C413E3E3D42443B3B
424445423D3A3B3D3D3A393B3C3B3C3F39516C73ADC8CCC0BCB4BEA8B082A18092809464
6D4E574D4E52454348474642535A6E8C8AB4B8C6B4B0A7B3AEBBB2B3B2B1C5B5C5A9ADA0
90949C9BB4A2A399A3967F736C6A6B605C5E56715C6957584C4C495345454A48473F4D3E
4A646068516852675C696092A5C1D2D3CCDECED1C2C1B8B7B0A89CA8B5B9BEBDAFAAA289
7E5E5B50777585737C7480667B61787449607292C3DEDBD5D8DAD5CEC0BEB09A8C725A61
546585AEA7ABAFBAA79787748380848D73896D898EA2D4D3D2E0CAC8A7B7BDC1C0A29986
8B72634D5249575B709AABBEA48C5B4B4948454745555065676768655954595E4D51484A
48423E3A413B493B3A353F3B4847483B3B363C3A3935403440333D3A3839353738373936
33363539362D343E39363536383936323938373534333332393A3A3A3837363636373737
3736363539393D323B405870ABC4D4BBAD76574E
5352504F4D4C4B4B474C494649494950514D4B49494C4C4D4B4C4C4C4B4A494849494A4A
49494A4A514D4A4A4B4A4744484645474B4D4A464F4D4845474947454C4344444548484F
66534749483F40494142434648484643413F414240414240434341403F4041413E414342
3F3D3D3D3F534F4148443C4340363C413A3D46423E424544403F4245433F3E3F3F3C3B3D
41423D40424044403E3C3E3F3C3E42423F3F3F3F3D3C3C3B3E3D3E3F3D3B3A38423F3C3D
40403E3B3A3A3F3F393A3F3F3B3B3C3D3D3C3B3B3D3D3C3C3D3D3D3D42454645413D3B3A
3E3B414A494240433F3E3C3D3E4040403C3D3B3E3E3B3B353C3C3B3A3A3B3C3C3B393C3D
38393D3C4344413B393B3A383938393B3A383B3F3C3D3D3B3A3B3D3E3C3B3938393A3C3E
413F3D4044444447413D3B3C3E3F3E3C3B3C3E3E3E3E3E3F3C3B3B3C3E3E3D3B3B3D3E3E
3D3C3C3C3F404040404042443A403D393E403D3C3F4142403D3D3F423B3B3B3B3B3B3B3B
383B393A3F3C393E353A4145454039353D3C3D3E403F3D3B3E3A3D3D3A3C40403B3D3D3B
3D3F3A323C3E3D3C3D3F3D3938393C3F3F3E4248413D3B3E3E383535373A3A393E42403A
41413B3D3E3C403D3E3A3938383B3C38393C3D3C3D40403D383A3B3A393A3C3D3B3B3A39
393A3B3C3C3D3E3C3D40403F3E3D3A39383736353939393737393A3A3B363A3A3D403837
3C3D3D3C3B3A3A3A39343B444240403F3D3D3A383B3E3B3746423D3B3C3F42443D3C3937
3C41413D3E3C373D383D3B40433F3B3C3C3A3C3E3C3E3D38353738374141403A3D3C3237
373B3E3E3C3A3A3B413D3A3939393E434C88ABBFD5E5D3CDB7B391A07972605150453F41
374A474B3F3F3A3D3E3E46456E609A93BFBCDFCAB69E9B8891898E88898A95959C9D9D9F
ACCCCDDBDADCCBC9C3B8A292858282716C6466576F5B656E63757A724C464A42463D574F
6E84878A8F9A92A498ACA9B69AA1A4A19FC1C6C5BCA7A99FBFBEC4C8CDD8D9D5CCC8C7B2
936A42494A5051524D5E59494C3F4F5C4D5A6C90BAD8E5E1DDE1DAE1DCDBE5D3D1AE9080
57515A6873728E9AB9A6A27E7D697282A8B1BCB1A790958693BFC1C29B9C89898E9DB5CD
D5C0A5A58F9C999A9DA3A79BA38A7E6A6C5F8A6A96779796A59E9895979FA7ABABB29AA5
8989716D4F434C40475B8A9C68594A373B393B34433F3B3736353433373A3A3A36333536
36373739323E657D433D3634353635343736353433323232363738373432323336363636
363635353B36383C477A8EA6939C82624F4B3A33
4D4D4E50504F4C4A484C4B4A4A49484C46484847454345464948494A4B4A494843454646
44434445484745454747433E49464345494B4946474442414345443F4441444140413E45
4D4846464644413F424345484A484541454245474243454046444241403F3F403F3E3E3F
4141403F3A3D3A3F45413B3E4039383F414143463C424847403D414842403F41403C3A3B
393F3E41403D424141404546414245424543403E3C3C3C3C3E404040403E3B3A423F3D3D
3F3F3C3A3D3A3C3D393A3B38393A3B3B3C3B3A3A41403E3D3C3C3D3E3B3C3C3C3A383839
3E38383E403B3A4047444140403F3C3A3F433D40413A3B353B3B3B3B3C3D3F403C383A3B
383B3F3E3B3B3B38363737353B39393B3B393C403D3D3D3D3C3B3D3F3E3C3A3A393B3E3E
433F3C3E41403F423F3D3C3C3F4141403B3D3E3E3C3A3A3B3D3C3C3E414242413D404343
413E3C3B3A3A3B3B3A3A3C3E4146444043423C393F4143413D3C3D403E3E3E3F3F404141
3A3A383A3D39373C363A3F444644403C3D3D3E3F403F3D3B3C413E3D3F3E3F424446433D
3A3C3C3A3D3E3D3B3C40403D393A3D40403F444A3E3A3A3E403D3B3D373E3A3740423A39
3C3E3A3F413F433F3E3A393C3C3A3A3C393C3D3C3D3F3F3D3738393B3B3B3C3E393A3B3B
3C3B3B3A3C3D3B383A3F403E3938393B3D3D3B39393838393A39383939383D3B3A3C373A
3D3C3B3B3A3938373E3B4046413D3C393D3C3A383A3E3E3949443E3A3A3C3D3D3B3E403F
404445433A3A373F393B36393C3B3A37393F403F383E3F3B3A3E3E3B393D40393A3A3640
3D3C3B3A3A3B3C3C403C3A3B3F4B5F718FC1D0CBBFB19A98816F534E493E3D364A3F3D43
3C4441413F403E42414453586B789DCAC9DBC5A985817E8B829081888A7A96779E96B0AE
C8D3CBB2B5A0A09BA5B0BAC4C4C2BAA09F968477878899B3D3D1C9C08F77787A7E858E9F
9EAFA4ACB0B5C5C3C3C4C8B8AFAEACA9A5BABEBEAF937C778FA6A4A5A3B4ADA39B908779
6B5E4F604C414B5F4F5F4A414243414641598DC5D3D7E4DDD9D6CAD7D9D2E1D7D6CAC1B2
8B7F776C6768678498AA9F8881655A576F8BB2BDCBC2B38E6C6B7D8EBAAAB77F9D86A9AF
D2D2E7DFE0D5DFD3D0CEAFB2A9AFA59F868B8EC0A7C2ABB2BAB5AAA6B5CCDADCDED6D8C5
CDB2BAABBBA2B595B1A5D9D5B09A836D706B6759524D4B4A4E484035373739383839393B
31402B36354B8D803B393737383937343434343434333333313334333233353733333434
343535363E2C3B3D7B7FA47C745A403F3937343C
4F4E4D4D4D4C4B4B494B4C4C4C4A49494A4F4E4F4C464744454343464746454545484A4A
484646474A4B4B4B4C4C4944444444424141434547464A4B4645474741414442484C4445
4143464A4A474443444547494A494644433F44474041443F474441403F3F41444B454142
4443403E434441494442413D413E3A43504B4144413F3F3E3C3A3B3F40404244433D3B3B
353D3E43433F43424341484A434346424744403D3C3C3C3C3D41413F41403D3C3F3E3D3D
3D3D3C3B3E393A3D3C3E3E383B3B3B3B3A3A3938403F3E3C3B3D404244424040403E3D3F
413E3B3F433F3C4041403F404142414042483E41423C42403B3B3B3C3D3E3F403A363739
383B3F3D3B3A3C3C393B3C393C3A393B3C3A3C3F3E3D3D3E3D3B3C3F3E3B3C3C3A3C3F3E
3D3B3D41403E3D3C3F3F3E3E3F42413F3B3E41413F3D3E3F3C3B3A3A3C3D3D3D3E414546
433F3C3B3D3E3F3E3D3D3F403E42414044423B393E4041413E3D3D3E3C3C3D3E3F3F4040
403C3A3B3A3534393B3B3B3C3E4040403C3B3C3D3E3D3B38353F3B3B3F3B3B3C44444441
3E3C3D3E3B3B3A383A3F3F3D3E3B3C3F3D3A3D43403D3D3F3F3E3E3F363F3A3945453F44
3B3D393D3F3C3F3A3A3D3D3D3F393336373A3B393A3C3C3A3737393C3D3B3B3C393A3C3D
3E3D3B3A3A3D3B37383E3F3C3F3E3E404343403D3C3A3A3C3C38363538383E3B383A373C
3A383A3F42403D3C3A3B4144403F3F3B3C3A3A38383D3F3A373636383B3E3F3F353A3D3A
373738373B3D3C453E3F393C3C3D403C3E46413D3E4243403D3C3A36393D433D393A3B46
4D48413B3A3B3D3F3B393A404C63839CAAB7B08D8561554B4D493D4341413C3D3E3D443F
403D414040474D5D68707E8098839D849C79805C554B54454F46454F546387819AA5BBC0
B0B08890819896A7BCC3C0BCB0A190778F7C866881688383ADAFADBAB5C0CAC9C8CDCFDA
D8D1C9C3BFBECCBCD3C3CBC0C2C8C8C8C7C6C4CDBCBB9CAF9ABDAAB7A0B1ACA09C91847E
7E71726C6946545053544E465D5650423E4C80C5D9D7E3D9CAC4C1D7EAE1E5DDDBDFDCCB
ADA09588908582799A9EB19E9B7E7C594E5B5B677072737E7D70695B6F85979D98B5ACB7
A7BECDE0DAE7E2E3E2DCD5CBDCCEDBCDC8ACC4C7DDC9D1BAC4C3B8B0BDD2DEE1D8E1C2DD
B8D2C3CCD0CDC6DEDAE7E2DADCCCBDACB5B9C1BCC4B6BEA7B38D7E61473B3431373E3A39
393B31362E38543B36353536363635343233343434343434353636353535363732323232
333536373B3D4172778A684841383C2E39394130
4D4D4D4C4D4E50524D4D4F505151504F4E4E454849474B464B4746494A48474944484C4C
494645464547484546474642494948464444464748454A4E474245464746443D444B4548
4948494A4742434742444647474747484340484B43454A4546424143424041454A444042
444445463D3F3A453F42464241423F46524C404246403E4042403E3E3F41464947403D3E
42443F4244424643413E46484041474244423E3D3D3D3D3D3B41403D40413D3D3D3D3E3D
3C3C3C3D3D393C3E3C3E3E3A3C3B3B3B3B3B3B3C3D3D3D3B3A3C4043433E3C3F403E3B3C
3D3D3A3C423F39394442403E3E3E3E3D3F493F42433C44443B3B3C3C3D3D3C3C3C37383A
393D403D3E3A3D3F3C3D403E3D3A3A3C3C3A3B3D3C3B3C3E3D3A3B3E3D3A3D3E3B3D3F3C
39343B423E3D403E3C3F3F3F4042413D43454745403C3B3C3C3B3A3837383A3C3B3F4344
413E3D3D3A3B3B3B3A3A3B3D393B3B3D423F3A3C3A3C3F40403F3E3D38393A3B3C3C3B3A
3C36363B3C3A3D433D3B39393B3D3F3F3D3C3C3D3E3D3B393E453E3C3A373C38413D3D41
403B383A383A39393B3F3F3D433D3B3E3C37383D4142413D3C3D3E3E3C3E3C3E45444349
3E3F3A3C3C393B37364641383D3C353936383938383A3A383736383C3D3A38393C3C3D3E
3E3D3C3C383E3E39393E3E3A403D3A3A3B3B38353D39393C3D39373739373B38373B383C
45403E41423E39373D4045433C3D3D353B393A38353A3E3939383838393A39393A3E3F3D
3C3D3E3C3D3E3C433B3E3B4139353A393D433D3D393D3F3E3C3B39383E3D4540393A3A3F
4543403B3635373A3B3A3E465161768775795A54454941434A444040383D3C3F3C3F403D
3E3B3E425766717E847F7B73645C4C4B4445404244423C3C43545274919CB48797728D76
878F8699959A8D888083776F695F574C4B4C3D4A384B49535B6762696E8181737C7A7F78
86777B6B7D747569777077726F767B858D8F96A4BBB3BCB5C2AAAEA4ADB3B2ABB1B9BBC4
B6C2ABC1A19B714E5149474F5767707D70645E83A0A7C1CFCCC0B7BAD2D2D3D8DBE6E6DC
CAB5A7AAACB0A29999A2ABA5B0B0A8A87F97626251484C585F625F5765618E71927D9892
91A1B1B6CDCBD0D5CACABDC9D4D9E5DEE9DAD9E3E1E3E3D9D9DBD3CED6DEE1E3E1D6D7C3
C7B5C8BFC2B2B6B4D8CFE3D6DAD1C9BECAD2E0E2E5E2E1E3E2D8C5B57A614B39383D3635
36293438363B353337363533313234363334353535353433343433333332302F33333333
34353637514B7C607C54452E3635314236393038
4D50555654514D4B4C4A4A4C4C4C4B48695F4A4749494E474B4644464744444543474C4D
49464445484B4A46454848454A46424245464340463D414A4844444440494F494B4C4447
4B53544A444647443F41424242434749403D474B43454C474342444847423F3F47434041
42414449474437443F3F413F3E4243464A443E433D3A3C4245413C3B3F42494D4A434041
554E3F3E41434945423E46483F424A46413F3D3D3E3E3E3C39403E3B3F403D3E3B3D3E3E
3C3B3D3F3B3A3D3E3A393B383A3A3A3B3C3E40413D3D3D3B3A3A3D40403C3C4247474545
48473E3A41434142413F3D3B3B3D3F4138473F4344393F3E3B3B3C3C3C3B39393F3A3A3C
3C3F423E3A36383A36393D3B3D3A393C3C3A393B3A393B3E3D39393C3C393D3F3B3D3F3B
3C343C41393B423F383C3E3E4043423D3B3E41413D3B3B3C3C3D3D3C3D404448383C4040
3E3C3D3E3F40403F3E3E404141403D3F433D393D37393C3F41413F3E3B3C3D3E3E3C3B3A
4039383C3C3A3D443E3D3D3F42434241403F3E3F3F3F3D3B3D3F3B3E3E4659554A3E383C
3E3A393D383A3B3B3E41413D463F3C3E3D37383D3D40403B3A3E424148434142403C3E41
3D3E383A3C3B403D485D50373A3D353737393A39393B3B383736373B3C3836373E3E3E3E
3E3D3D3D373E413C3B3E3D383F3B3737393B3A383B37373B3D3B3A3B3B363835383D393B
49413C3D3E3C3B3B373E43403B4142393A383A3733373C373E3C3A3838393B3C3436383A
3F46484745453E4037393942433839383A3C373C3B3D3F3F3E3B3A3B3D38413F383A3A39
373D43423C38393C3F3F43494D4D4E514D50473D413C453F4236443F42424A433D3F3C47
4E4A464E56635F5A544945423D3F423B4A383C403F435057798C94B89695855D75669174
909A7B855E6C554E42494040454242404140443643383F3D42453E4B474443483E4A4444
3B454441443D424737424A40453E3F4748495253646165757966666265636A686E7F8792
A3C5D6E2E5DECC99AD8594829C84928C9194797B816F7E9E9F9284758E9AA5BBCAD5D9DB
D6BEB7CCD6D5CEC1CDC7C3A9A6B4CFBECDB9B69DB19B9F988E91847A6C5855514E506E87
77929FB0BFB9B0C2BEB09D9FB8BFDBD4DDE2E5E7DEE0E3E0ECEAE3E1E6E1D7D6DCE0D2DC
C3CBCACCABB1A6C2C6D3D0D1CFCBCCC8D6DBE4E0E7DADDC9D6C2C5B8B393724E3E3C3335
3C392D343E3D3F3A33353636353436393536363636353332333335373939373435353434
343537383F5D5B4A4636363431363A323833373B
515380967A7A7279535E55515B47524B504E4B4A50454D4B4748494A4B4B47444E4E494C
4D4A4B444852554B434648484A4A45484641464949444F4C46424F474243484C4941434C
494D4D4642454848404144464442444943414144454343453F4544414342434A49484343
4744424641464B4A443F3F423F4648413D404240443A414648453D43404242423B464550
4B474545444141454344433F3C3D42463D3D433D3D443E3E424445423D3938393D3B3F40
3B3B3E3C383E3D3D403E3B403D3D3E3F41434342333D39343B3A363C3A3C3B4046423D43
42463F3B4340393E434141413E3A3A3D3F3A393F4645403D393B3D3B3837393C3C3B373A
3F3A39443A393E3E37383D3C3E3A3C3C393A3D3A3A393838393C3E403D3F4141403E3E3F
393C373E403B4140413E3C404548454246423D3D4146474743413E3B3A3B3D3D36393D40
41403F3E3E3D3F42413C3B3F3E3F414342403D3C393B3E3F3F3E3E3E3E433F3A3E3D393B
3D38393834383D3B3A3D4347443D3C3E383E3B403F393D394A5E5B4448544A473E3C3D41
413C3A3C3E3B3B3F414040423F3B393B3F403C37393C3A36373E42423A3C3E414241403F
3C3A3C3C36373B3A3C3E383C3C373D3B3B383D37383E3636353C3F3A35373C3F383F3F3E
413C383C37393E403C37393E3A3C3C39393C3C3A3738383939393A3B38393A3B3D3F4142
4746423C393A3C3D3E3C3A39383A3D3F3A373A35353B3B403D3A393A3A393C424D3F4343
454A413D3B3C3C3B3E41413D37393B3B3A393A3A3C3E3C3E423D383D3740363F38414B3D
373B40403F4040443D3B3B494449393D3C4547413F403F3D3E433C373D414244393C4049
48474D403E4245433D3A3D413E3D3E413F433D4E5171898EB08F7C8F798F7C93926E7666
6A5447423D4345393941443F3A3B3D3E40403E3D3F423F393B3F403D3D41423F3E3E3E3F
3F3E3C3B3C3E3E403F41403F3D4E636A737481738B7C928CA999A696ABA0A69FA9ACB2BB
C5D5DFE7E8EEE7E2E8E5CAD9CBC0B1B8BBB9BBB8A3ACABA9A0865C505A68A3727D88CBBC
B2A9ADBBB9C4ADBDB2CAA17967587A9CA7B5B2B9C0BFC3CBC1C0C2A1B08695616E4B6374
A09DACBECEC4D3CBC4C5BEB2AAB6BED3CBE3DCE4D8E4DBE3DEE5E9E2DCCFB8B5CCD2D2CA
C2B8CDD4D9C3BBADC9CFD1CFCDCDD5D7DADDDCE3CED9B3B08C907D97789680844F3A303B
323639393C3E3F473436393334393435343637363535363739382F3A2F372C3636383234
35343B3A393C3E3B363435373838383838383838
4C4E669289AEB9C4B5A28E7D706C655F534B4B4D524B4A4B4546494545494848424A494C
4C484C4C41444B47464642434C4845464544464449434B4847424A4545403F4243404144
4042423F3E40434540404243413E4045413F42494D4A44413A3F3E3C3E3C3B403F42403E
404046544144464542414448434948413E4143403E393F3E3D3D3D4746423E413F4B4549
42414347484545474744413D3939424C3E3C413B3B403C403C3F40403E3C3D3D3C3A3E3F
3B3C403E393D3B393D3C3A3E3C3D3E4142413F3C3F4E493C3E403B3B3D3E3C3E43424043
4348423F46433D41424141413E39393C3D3B3B3D3E3D3D40393C3E3E3C3B3C3F3E3C393C
3F3A373E3B3C40413D3C3D3C3D3A3C3D3A3B3E3C3B3B3C3E3F403F3E3B3D3F4042434445
3A3B383F403C42413C3D3D3E3E3E3E3E42403F40434544433F3E3F403F3D3C3D38383A3C
3D3F3F3E37383B3F404042453F3F40403F3E3D3D3B3D3F3F3E3D3D3D3B3F3D393B3E3D3B
3C393C3E3B3D403D3D3B3C3E3E3D42483B3E3B3E403F474747514F3F41463E3E3E3C3D3F
403E3D3E3E3C3C40423F3E3F3F3E3E3E3F3F3D3C37393A393A3D3F3E3C3B3B3C3C3C3B3A
3E3C40403B3A3C3A3C423D3D3C3C40393B383B36383F3A3A34383B3B3A3C3E3F393C3A39
3939393C3F3C3A3C3C3C3E413A3C3C39393B3B393F3D3B3A3B3C3D3D37373738393C3E3F
433C393B3D3C3D3F3B3B3A3A3C3F43453E393B3A3B3F3B3F3B3A3B3E3E3D41464B434642
424B453E3B3D3D3C3C3F3F3C3938393C3D3C3D413B3D3B3D423D393C303D3B4136393F36
3C3F3F423F393B3E3840403F4D404C4D4E4B4A494746443F3E403F393A3D3C3F3C3A3A3F
3E3D403C414141424241403F3C463E595A8773918599857C958698B4908F6A6A5D3F483C
403639403F44463B3A3E3F3C38393C3E3D3E3D3C3E413F3B3C3D3F3F3E3D41453D3C3D3E
41413F3D423D45404E4C595B5B6073777D7F86837E939AC8B6D3C9D7D5CDD4D2DCDBDADD
D8CED3CCD6CED6D2DBDAEACFE3B0A4796F68797D7C9FADBFA3BDA2A46F575B574D6E90A4
79798AA3917574688E7790756F6472726D706C7472778796979FA7998999888C694A4F76
8EABB0D4CAD8CDD1D0CCD3C6CABCBAC1C9BBD8C5E2C8D2C8D8D7DEDDD5C0A2989CB5AFB0
919EB6D2D8D0B7B5B2B7A9A6A8A7AEAEAEB6C1D4CDBDB96D584D3B4641646C6758403932
33333335373D4F65513830323433313A36373737373737382F33353E3239363935383437
39383F3F37383837353637393737373737373737
7E676C5C61638982A091BDB6BCAEA4919D897F7160594A504948504B494C454749514C50
564F4B49554F524C494441454C474948454B504E4F474C4A4F484A494B48484A4A484745
454444464646474A46454546434143484643454D54514944454746454644424542464646
4849515F4646454442414244474947413F434340443E3E3C3E43414347413E4648514240
403F41434442424344424142403D40453E3B3E3B3A3B3B413A3B3D3E3E3E3E3F3D3A3D3E
3C3E43423E3E3A383A3A383A3D3D3D3F403E3B3945534F3F3B3935353D3F3B393D404041
4146424046443E413E3E40413D393B3F413E3B3C3B3A3D413A3D3F3F3D3C3C3D3D3A383C
403C393C3D3D3A3738393A3E3D3A3C3D3B3D403E3938383A3C3C3A393C3B3A3A3B3C3C3B
3B3B393F413E42423F4244423D3B3D40474542403E3D3D3D3D3D3F42413D3E423C3A3738
3B3E3F3E3F41423F3D3C3C3B403F3E3D3D3D3E3E3E3F3F3E3D3B3C3C3F40403D3D454740
3D3A3C3F3E3F4241423F3F3F3D3938393A3F3F42413E403F403E413E3C3D393D3D3D3C3D
4042413E3E3D3D40413F3C3B3A3B3C3B3838393B3D3D3F4344434142413F3C3B3C3D3C3B
403F43443F3D3D393A43403C3B3F4239403B3A35383F3D3C3F3D3D3D3D3A37363B3A3A3A
37393C3C443D393C40414040393B3B38383A3A37413D3836373839393838373738393C3D
403531383C37363A3D3C3B3B3C3F4142423A3D3F41413B3E38393D3F3C3B3E424744443B
384240373B3E3F3C3C3D3D3A3A36363A3C3B3D403D3C3C3F433F3B3C3A424444393A3A35
42443F433E333937354946516E647770866952483E3D42423F3F4B453E403A3C48413D3C
3F3E3B453C3D3F41464F585E8489A483A0958F96718F7894B69D8D76625A41444035423A
413B3F423E41453F3D3C3B3B3A393C403B3C3C3B3C3E3E3D3D3C3D3F3B373A4346413E3A
3E3D3D3A43464051464D434A4D45514E4E4E4E534C4C696E89859B9BA6A0A7A8B1AFAAA8
A3968BA498A7A5AEBED6CBEBD4EED4C9B8B8A790604E606B9A95B9A3A86C7B606E575D55
484D626F6E5B60686795A2B78C917E967B9774885E575957555C5F608E99A8909C725052
5065899CBBB5BDB3C1C0B1C3ABAC8790829196B6A5BEC0C9C4C7DCE4D7C2AEACB5B9C29F
A0869F9FD2CED2B2C09392765949464A59738CA6A6B6A39D6E48403A333F464450464344
3D3835363A51748A734634393B37353D383837383838383735383D403437383334373235
3639444737373635353637383535353636373737
CBB7AC94827D8773897D94ADB1C9BEB7CFCDD6C39F9376795C4B494853636C7E7273666C
7870625652514F4848424948444148463E424644494045424B4442444645494842404243
4642414443403F4242403F403E3C3E43443F3D414544424243414040413E3E403A3C3B3E
42404047454545454543403E46464441414444403B3937363C423F3A413E3E46444B3E40
42403D3C3C3D3F41414141434545413C3F3C3D3E3C393A413C3C3C3C3D3D3C3C37343638
36393F3E42403D3B3C3B3939403E3C3C3D3E3C3B3841423E3C3839423B3D3A37393E3E3B
3B403E3E42403B3E3B3B3D3E3B393D4348403A3C3F3F3F3F3B3D3E3D3A39393A403B383C
3F3C393A3C3D3633393B3B413F3B3D3E3B3D403D403D3A393B3D3E3D45423F3E3D3D3C3A
3E3C3C40403E40423E40413F3A383A3D4947423C38383B3E3F3D3E413F3C4148423E3A39
3C3F3F3E3D41423E3D40413F403F3E3D3D3E3F3F3E3F3F3E3C3B3C3D4141423F3D474B40
403C3A3B3B3D4044413C393B3C3B3C3E4347494A46413F3D3F3740423E3F3C3D3A3C3D3C
4045443E3F3E3D3E3F3E3C3B4040403F3D3D3E403B393C42433F3D3E403E3C3C3E3F3E3D
403E42433E3D3D384346433C393B3B3543403B37393E3C393A393A3D3E3D3D3E3E3B4042
3D3D3F3A403C3C4144413C3A37393938383A3A3745413D3B3D3E3E3C3B3A3938383A3C3D
3C36343A3C39383B3B3A39393B3C3D3D413B3F41413E393E41424747403D4041403E3E37
333B3E393B3F413E3C3D3D3C3E3C39383A3D3E3D3B39393D3F3B3737413E3C3A393E3E3E
3E42383C38364640506A6E8C969C9186775647453B373D3D4140555145453C3D48403C3C
4645405559667276788498A7CAD3C7BAADBC9D9F8BAD898777524E423E39353E3C3A423C
423B3B3A373B413F403C3B3E3E3C3E423A3B3B3B3B3C3C3D3C3A3A3C3A38393E4641423E
4541423D3A3C3F504A463B3F413C3F3C3B3B3B3F4C42413F464349495557616A77808587
9A88A2ABC3BAD0CAD2CDE5D6D8B9C7BEC8B4B3997C79728276947C8F7491729385916F87
566689998184ADBACFC0DCC7CBC0D5B6D3A5A9B0C3BBAD805A4F4C5D6DAE98C1AFC99472
6C5C55627085969CC4B5B5A4A889736754564C4D5C75978E99A8CCDACCBCAFABB1C4BAD4
BCC7AFB7ADC4C0D8C8CCB5B586644E423F424145766B9397956A49303A3B32363640384C
4C403C414D79A19C5A3A373B3737373839383737383938363837343632333936383B3738
36333A3A393B3D3C383534343435353636373838
C2B6BEB7BEC6C8B0B29DA7A4C1C0D7CED4D2D2B8949484846B56586E889CAAC0BDBEB2B3
B7AEA69D88816A56564C57484946494B484A4C474B454E49504A46494C484B4B42404648
4C48464847434244484544464544464A4B4744434241454A45403E403F3E3F4142434244
47423E42424141434647444241414140424443403940413F3F4449473D3D40443C413D49
403F3D3B3C3F42434045453F3F44443F3F3E3E413F3A3C3F3D3C3C3B3B3B3B3B413D3F41
40444847403E3E404041403D3F3D3B3D40413E3C3C4243413D3839413C3D3D3A3A3E3E39
383C3C3C3E3D3A3C3E3C3B3B39383C43453F3B3D403F3D3D3C3C3C3A3A3A3C3E453F3B3B
3C3A3938393D3B3D45443E40403D3E3E3A3B3E3B403E3B3A3B3C3D3D3937353638393939
403D3E3F3F3E3D40403F3E3D3D3D3D3D403F3D3A383A40443E3D3F41403E424846423E3D
3F40403E393E403E3F4447463E3F3F3F3F3F3F3F3D3E3E3D3C3C3D3E3E3D3F3C3941443A
423E3C3E3F3D3E4344403E4143403F3F40424542403F4043443D46463F413D37393B3C3D
4145433C3F3E3C3B3C3E3E3C3B393737383939383C39393E403D3B3C3737383A3C3D3C3A
3F3B3D3E3A3B3D394542403D3C3D3D3F41403C393B3D3D393D3E3F3E3B3A3C3F413D4144
3E3E3E383C3C3F44423C373634373837383A3A383A383636393937343B3A393838393A3B
36393C3E3E404346363535383C3F403F3C3A403F3B3A3740414247463D3B3E3C3A38383A
383B44443A3F41403E3F3F3E3E413E383A42433E413E3F42413E3B3A3E3D3E3E403C3736
343F3E484D586D647A7A7F7B6469534F48363A46403B3F3E413D504C41433C40433D3B3E
4D4C465D63778C9399AAC3D5D9D1D3C2D3C2AB7F606B4544423E3F373E3A3D4039383E3D
3B37383A3A3C3D393E3A3A3E403D3D3F3D3C3B3B3A3A3A3C4041403F4144433F3B3B423F
463D3D36403345374E32413C3E4440403F3F413F3F473F5141504A58616C7A8C9BACBAC2
C3C4C5E3CFE4E0E4E6E5CFC4837660676165647F8D889386B28CA06E8681A69AB59CB191
A49CAC9F957686B3ABD0C2DEE1E8DBE7DEDFCCE5DEDCE3D2C5AD765B5D547C92C492C7C8
D0BEAEA1A2A1A3A6C8C7B0BCAABDA1A78C7B6E55454D45495A6C909E9DA09C97A0A2C2BA
D6B7C2C3B0A2BFB1D5B5CAD4CDA27E62514A413D4445538388A6754B373D3E3E353F3340
514B618392A9A9733F2F373C353839383937363637383635373A373D3A323837353B3B3F
3C363732373E45443C3533343535363737383839
CEC2CFB6B9B0B7A0ADACA5B5B9C0C8CEC4BAAFA29390785A5D4A475F73767C87ADB8BCBD
B5AFB9BDC8BCA38D928482645A524144474549454442534948444143463F47504A44433F
47464545434142444441404242414245454443423E3B3E4446404044403D404342454342
413C3D4647433F3F424445443F3F3E3E4143434140433D39383B42403D424B524647414E
44454442414242403B464B433D40434240413E41413D3F3D3A3A3B3B3B3C3D3E3B37393B
3A3D413E3B3A3E42424446433C3B3C4044443F3A3840413D3C3F4040403F40403E3F3E39
3A3C3D3D3D3C3B3D433F3B3A3836393E3A3B3D3F3D39393D3D3C3B3B3C3F4345423C3B3C
3B3D3F3D383A3A3D42423F3F403D3E3D393A3C39393A3B3B3B3A39393A3A3A3B3C3E3E3E
403B3E3E3E3E3A3F44413E3F414342413A3B3D3D3C3C3E403B3E42434241414245423F3E
3F40403F3F4142413F4040403C3D3F4040403E3E3C3D3E3E3D3C3D3E3E3E403E3B3D3D39
4141414548413E423F3F42494C48444335383F3D3A3A383C413C44433F433E383A3B3C3D
3F413F3B3F3E3C393A3D3E3C3F3D3B3B3D3E3C3B3F3B3A3B3E3D3C3C36383B3E3F3E3D3C
3D38393A383B3E3C464141403F413F453A3D3A3A3C3D403C3C40423D393B3E40403D3D3D
3B3B3B383B3C3E3F3C36353833373837383A3A373A3A3B3D3F3E3B383838373737373737
33393D3B393B40423837373A3E3F3E3D3839403B383A3A4039383E3D35373C383A37363B
37363F3F3A3E41403F403F3D373B3A35373F423D433F4144403D3D3D393B3B3A3D363E46
465665777C838B7A755962433B3E3B3B3F373D443D393D3D3E39413D373A3840403E3A40
4B4540504C627D90A0B3C4CCBAAA957B70615F463E473D3F3B40404137383C3D383A4044
4140404140403E3B3A39393B3C3A3A3A3F3C3B3B3B3A3A3C3D3F3D393B403E383B3A423A
423C47484745424C494D4D54505D575D5D5F6363758880A390AEA6BEB8C2C2C8C3C4C5C4
CBC0CBBBC2B9CBC4C6B7BE84876F847988828D898D93969EA0AC95A581A79AC3B3CBC9CA
BCBBCACACDB7BAC6D0C0D4CAE1DBE1D4ECE2E9E5E6E7F3E7E1E1D2D6B37464A4A19693B6
ADCFCFD3CECDABB6C2C1D2BDC9AFA295A483BB9D9D7E515E47505C5556708A9D97998CA9
AAC3B2C6B3A29AB5ADAEA4C9CDAFA1978C7E5E44453D45436D639D7C4E373B3A413D3B3E
3C3A5B94ABB3A36765443837383C39383838373737363635383B353B31313E3C42433B3B
3A373B38333C44443D3635373636363737383838
B1C0BDCAB0C5CBCCB08F897791A1BED2D8CBB7B2A99E9F848C755756544D585D6A758288
7A727A779392A2A4BDB7AD967070575A59444645494B65554A4746464B445161584D4B4A
4C4E4D4A47494B4C4A4747494946464848464647464242444F494D524C46484A44444140
413F40494945413F4142424242403D3D3E4143444B4B413F3E3C413D42434B554D4C424A
474846424041403D414345454240414341433D3E403E413B393A3B3B3A3B3E413D383A3C
3B3D3F3B3B393D403E4044423E3C3A3D41423F3B3E403F3C3B3E3D39433D3E413D3C3C39
3B3C3D3D3B3B3C3D413C393A3A38393B36383C3F3D393A3D3D3D3C3C3E404244403C3D3E
3C3E413E3A373839393B3D3C3E3B3C3C38393B383B3E40403E3C3D3E3839393937363636
3D383D3C3D3E3A3F3E3C3A3A3C3E3F3F3C3D3E3E3C3B3A3A3B4143414143423D403E3C3B
3C3E40413D3E3F41403D3D3F3A3B3D3E3E3E3D3C3D3E403F3D3C3B3C3E414141403B393D
3F4041474B433D434D474241403E3E40383B4745403E373A3D373C3C3D423F403D3B3A3B
3C3B3C3D3F403D3A3A3C3C3937383938373736373A383534363938353B3E4242403D3C3C
3C37383A3A3E423F4946483F3C3E3738363C393A3A3A413D4348463D393C3A343A3B3A3A
3D3C39383A393A3B3A36363935383A38383A38353536383A3B3937353737383838383737
363638383735383C3B39383A3D3D3A3738393E393B423F3E3C393E3E363C433E37393739
35343C353B3E3F3E3F3F3D3938373738383A3D403936393C3634383934363137484B6779
8582868775655B494C3943383E3B3A3436383C3C393839393B3939383938363D3A3C3A44
4E4949515D6B787D7D7A71655154504B3D3A40464D453C3632393839393E3E3D3C383738
3D3F3F3D3B3A3D40393B3A3838393A39413C393B3D3C3C3E383A3B3C3F444A4D504F574B
54526973828E81A18EAB9CA9A6AFACB5B5BABCC7CFCBD3C8DCCFDCE0DCE2D8DBD2CFC9C0
B6B7AFB7ABB3ABAD9BA999AA90AF939C8F968D8B8D859B97B9A1B0B1BEB0B9ACB5B3BEB2
CFCDCBC7BDBEA9B596C3C2D5D0D5CEE2D2E6DFE0E8DBE1E3E3E2D9DED7C0A0ACCDBFBE8F
7296B4A8D5BCA7A9A2AEBCC0BCB6A9B0A48790A792BF96B4ACA99B7A68748EACC8B3AA97
B9BAB7B3D9C3C8BCCCA5A3A4B2A5B1BEC4BE9A747D6A715B4B6895C0915A41433E383A3E
3E383651636D755E6D4B373337393335393939383736363635353041364F614A534D3D36
3331373535383B3B393636373636363636363636
6474718485A1C7CDC8988960597181A6CAD5D2CCA97E9289968D706A5E4C514952596D84
8481826F90879E929C8C7B73586E6675714A4748494D6D59464445424C434F5B4C414C56
474B4A44404245464A4847494845444545413F4243413F3F4641474C443B3C3D46423B3E
46454143414040424445444345423E3C3C3F43463C4442443E374041493F3A423F453C44
4344403B3B4043435141383D4241424842453B3B3D3E43393A3C3D3C3A3A3D403D393A3C
3A3C3D383E3B3E3E38393E3C443E37373B3F403F3F3939404343434442393A3E3A373836
3A3B3C3B39383A3B3C38373A3D3C3B3C3A38393E413F3D3D3E3E3C3C3C3C3D3C47434443
3B3A3A353A373D403C3C3D373C393A3B37393B393A3C3C3A37383C403A3B3D3C39373737
3A353B3B3C3F3A413F3F3E3D3D3E40423D3C3B3B3B3C3D3E3E44433D3D43433D3B393837
383B3F423E3D3E413F39383B393A3B3B3C3C3C3C3E3F41403E3B3A393A3E3E3F3F36333C
3D3D3D4247413D45423E3C3C3C3A3C3F3B3C45413D3E3A41413839393C3E3B423F3B393A
3937393E40413F3B3A3C3A35353A3D3C3835373A3C3C3936383D3B363B3F42403B373637
3B37393C3D424542393C433A3A423B38373E393A38373F3C3B42403A3D464337343A3A3C
434038383836373B3C393738373A3B3938393633393A3C3D3C3A393838393A3B3B3B3938
3B35343B3E3A3C42353334373B3C3A36393A3D393F4A443D3D393D3B343B443D313A393B
393D463A3C3E3E3D3D3E3A35433D3D43423B3E473B383D4039383F413B464D6480798A8D
896F645A44383838383D35443B3A3639393F3E383A3F42413A3D3B3F443D383B3D434558
676870757D7B6F5D504B443C3F393B3B443E383D39373F3F3C3E3B3C383E3A3B403C3838
3B4245413934353A3B3E3D38373A3C3B413B383B3E3E3E3F4549515B626B7B8BAAABB5A3
A599ABB2C6BFC9B5C3B0BAB1BAB7B3B4ADACA4B9A6B49BBBA0BCA5BAB0B4A6ADABB0ACA2
ABA9ABA9A89381757C6C7467705245494147494146424F4D53646A8F8E96919E829C8C9D
9BA7AEC5C2B5B6A3AC8AA39EB39BACADC5BCD2C3CFB4B0B1A9A0A1AEA2B094B4A3C2A8BD
9DA89699ADB18B9875799592A69DB2C6D2C9D0A68F8FBBC1C4C8C6B6AEADB3C9C9CDC0B2
B5C4B7BCC3CBC6C9CFC6B9A89F99A7B1B6BFB29CB2C8BBAE93A3C8C6D7A472723F40353A
334035373C3A3F343B3940403D3A37423A3B3B3A383637383941517A718B844445423737
38373B3639363332343535353535353535353535
77757B7A7F7A8790AAA79EA98C998AB1B8B596896F555C61626E71748A6E6B5256596066
706A7576A4C9C4D2C4B992A173766575837B7A6F5153474B474A454A4954494D4A4A5551
43484B444C4444484C4D4B444B45454845434541454B433D484B4C4C40424C3C40424343
414040404140444949443F3E3B3B41423D3B3B373943403C413E393F3C3E444847444447
4948433D3D403F3B3D44423E4344403F403F3E3E3F3E3C3A383A4043403B3A3E3F373B3C
43493F3D3D3937383C3F3F3E3E3D3B3A3B3D40423C3D3F373E44383942413F3C39393B3E
3E3F3F3E3B38373737373B40413D3B3C3A393B40403E3C3D3B3C3E3E3C3C3D3E35393C3D
3B3B3D3F3B393D3F39363A3C383A3D3E3C3A3939383C39363938383E35363738393A3A3B
3A3D3E3C3B3C3C3A3E3E3E3E3E3E3E3F3B3A383D433F3A3D404242403D3C3E413B3A3D38
3A413E3E373A3B3B3E4344403E3A3A3E3E3B3C40403B3F3E40433C3C3C3B3A3A3C3C3B3A
3B3E404448433E423E3F3D433F393E363D3E3D3B3D41413E3C3A393A3D3F40403E3E3D3A
38383B3E3F41423F3A37383A393A3D3F3D39393C383A3936383D40403D3C3D3A363A3D39
3D3C3B39393C41453D3B3E3F3A3A3C39373C3F3B393B3E3E3A383C393F393B39343C363F
474042443B3A3A393A3A3A3B353C37393B3B3F383340383A4039393C3F36363D3E3B3A39
403D453A3B37383B3843443E3B38383D3C3C3C3B3A393939403C3A3B3B38383A363B403F
3B393B3F3D403F3E413E3A3C3C3A3E3D404038413E3C4545383B4B4F5A7B679462745951
4C3F3B403E3D4246423A3E433D383A3C3F3B3D3E39383B3938422F423D3E53595E7E6D96
6689545F45464849423B3D433C3B41433C3D4240373B3D393A404242423C393A37333842
3939434A413A39353A43413A3C3937433B3D3E4050576470849FADABADAFABAAAAB7AFB3
98A595ACA2AA8DA27B8F6F74585D615C5A4D53504D4C4F4C546263636C6D70778187837C
8399929A8E7A6A585A514E4843614D5250555451594A494540404149414E46534645514B
4F618793A3B8D1D9D5CFC0A89F8D8792A0B7B2B6ADA8A39E80796E636960645D77619199
C9D5DCD4CDB490877A7B9176958B8CB2C8E1D9D8C0A596C1C7BBA39DA8ABB2C3C3C4C2CC
C6C4BCA9B1B2ADB2B4BAC4BAA99E878A93919698B1BAB9C2DEDCD6DFD8D6BCA48357423D
3A39393A49404D68637A6A8C606C493C3F303A3A353B393D7870AD966872423C38353836
3639363831343435363231383335393631363A36
6D6D777B8E98A8ABB0B0C7C3BF9B7C80646B505E50534F5A5E7977A482857168746D7078
8C8E95929AACC4C8D3B3A3A19E8979829EADABAE9BA0967F726D78847E8E84916250505E
5148494B53444346454E40473C4D42444844424043484748434142494946453D3D3F4244
444341413B3E4448443E3D413E3C3E403C3E44463B433E3B47494343413D3C3F41414245
45474643424444413E43413E41413F413C3D3F41413F3B37383A4046453F3B3B3A363A38
3A3E393B3D3A38393C3E3D3B3E3D3D3B3B3C3F413F3E3E393F443C4041403E3A37373736
36393B3D3C3C3C3C39393B3F403D3C3E3D3A3A3C3C3B3C3F38393B3B3B3A3A3A3E3D3C3C
3D3D3D3D38353A3F3B3A3E4038393B3B393837363B3D39383D3C383A3A3A3A3A3A393838
3A3E3F3E3E414342393A3C3E404141413C3F3D3D43433F3E404141403E3D3E403C3F443B
3538393F393A3B3B3D403F3C404141403F3D3B3939373C3B3D3F37373C3B3B3C3E40403F
42413E3D3F3B393F3939363A3C3A3D4142423F3B3B3E3E3B3D3B39393B3D3E3E3B3D3E3D
3B3838383C3E40403E3D3D3F3A3A3B3E3E3B3C3E3D41403A3A3F403C38383A3A383E433F
3A3A3B3C3C3F42453F3B3C3B36393E3E383F4443414242413B3739343B383E3C4B524F51
4B3C3B3B3838393A3B393735373B363839393D37333E36383F393A3D39393E3D3437444A
4C4E44483C3C373839413E36393E40433F3D3B393A3B3D3E423F3D3E3C39383A3B3A393B
3C3D3B393B3E3D3D403E3A3B3A3738373B3B353E393840403C4855535D6048563A434142
3F37383D3C3A3D3C3932353D3B3A3E423E38383B3E43433B3D31476180748F727D745F56
45483A463B3C3E3E3B383B3F3F4044443F3B3A383C36363B3D3C3E453735393E3E3A3A3D
38373B3D3936393B373A3F3D4441343F435651747EB1BAD1BEC0B5A59D978C81837D8567
69535355474B454F444B414142464841403745474042494649514F505B646B6F79899190
858C9C9AAA9898938C887F778384848C94A5ABA5A59285727761735E785D65606D5C5F62
676B8085989EBACDD7DFDAD7D6C1BAAAC4C8D2DBD2CBC9CDBDBFBDB8AC97897886789BA5
CAD1D7D6D4BA918366648A8FAFB0B1BDC9D7E3D4CEA498ACB8B2A59C9E9B9CAEC9CFC9DF
DBDEC8B3A2A9ACA99A929FA095988F928F83868C969C9A9DB2D3D0E3D9D7CDCBBDA08F84
5C577E6CA38DB5B5C6CACBC7C3B6AA8C7D57433C405B6552736182553F393D3B39383936
3536373A353534373D3A33353B36393533383A39
5A5D635D6B799096B0BFC9D9BD9F61618381735B64596675B1ADD6C3CDA0B28685777068
6E6F73747D76877A78545E62705E697BA1C1BFCECEC9CAA5B1A1AAA3B7B9BEBCBA9E987C
6E4F474D5444474E514B4A4043424740504D4A4A494648494644434145443E4041414142
434342423C3F4346433E3E423F3B3E413E414A5041423E4656544846443D383B40424141
3F444745413E3D3B3E40403F403D3D42414243464745423F3C3C3F4446423D3C3D3D413D
3A3B3A3F403E3C3D3F3F3D3B3E3F3F3D3B3B3D3E413E3E3C40423F464546423C3A3B3935
37393C3D3C3B3B3C3D3B3B3D3E3C3D3F3D3A393B3B3A3B3D3B3B3D3E3F3E3D3B433F3B3B
3E41403F403A3C3F3B393C3B3C3B3A3A393837353D3C393A403F39363D3D3C3B3B3A3939
3F4243403F4142413B3C3E40403F3E3D363C3A373D403C383F3F40403F3E3E3E3A3D4642
3F3F38383C3A3A3C3D3C3A394046474240413D363B383D3C3C3E393A3C3C3C3E41444545
42413C393A37363B3C3F3F3C3E3E3D4744423E3A3A3C3C3B3D3B39393A3B3B3B3E3F4040
3D3B3938393A3B3D3E3E3E3E3E3B3A3D3E3E3F413E42423D3C40403B3B393B3B393D413D
393B3D3E3F3F41423C3A3E3F3A393B38363B3F3F3E3F40403D3A3C363D3B3F3C53524D4B
40373B3A353536393B3C3A38373A363738393B363B4138363B3735383D3C413F3C4E6261
5F52383D393F3C3C343D41454E50463C3F3C3A3B3D3E3E3D3E3C3C3D3C3A393A3D3A3738
3B3C3A37393C3B3B403E39393F3B39373C3E39404442423D3A454A40473D3C3B3C363E3F
3C383A3E3C3D3E3B3F393A3E3B3736373D3B3B37353D433E49546BAC928E6F5651404439
4B3D40473F403F3B393A3B3C41423F3D3E3E3F43403C393E403E3D3E3C3B3D4041403F3E
4544403C3A36383F454143393E4441577373A285BF9DB59A9E8D766358544E433F423F41
3D453E453D3A413A41373D3A3D3F3F3C4039433F413C42485464708098AAB7B4B3BABDB9
9E999395899282957A9173887F8C7F90879BA6AAB0A7A396A7979F9EABA1A5ABB6A7AAAF
B4B7BEB6B2AAB3A9A8B8BBC6D1D2BBB4A9B2A9BFCFC5C5D0CACECECCD5C9C2BEBDAAA29C
B2ABA7A4AAA392969785979CA5AFC0C4C9CFCFD3CBCFC4DAD7D3D4D0D5D1C5CFD8DED5DE
E1E6E1DADCDBDBD3C0A8A094968F7E7977737C899F8E9C899FABAAB9CABBAFB6BDC3CFD2
ABB9BACCBED7D7DDCDD5CBD8CCDBD7D4D2A28D8E8A97946F49413F3A31393C353B3D3C3A
38373B3D393836393E3B37393C31383536383332
5354584E545B6F77768A7C88646E5981A2B7A6B0A1B8A4C1C7CBC1C8BCDDDECBBCB9B7AC
9F8F7F799C72625B68575B55525060677B969EAEA8A3838A86B0ADBE9FAA97B9AEC2A595
9E766665634C48454846465C505B595F61676C727371747372706A52484C484D4845413F
4041424245424145474441403E3A40454241484D473F415663534345423D3C414543403E
41484E4D46413E3E3D3D3F41403B3C42413F3E3E3F414141423D3A3E41413F3F41424542
3F3E3E414543414041413F3D3E3F403F3C3A3B3C413D3D3E3F3E3F454848443C3B3D3C36
3B3C3D3D3C3B3C3E403C3B3C3C3C3D413B3A3C3F3F3B393A3C3C3D4041413E3B3F3C3A3A
3D424546423A3A3D3B3C3F3E423F3C3B3B3B39383C3B393A3E3E3A373B3B3B3B3C3D3E3E
3E4243403F3F3F3D3D3E3F403F3E3D3C3A3E3B3A40413D3B3D3E3E3F403F3E3D383B4546
46463C3B3F3B3A3E3E3A383A3F42444241413E3A3F3B3E3B3A3E3B3F3D3C3C3E41444646
3C3E3C3C3E3B373A3D40473D393E38393F3D3B3A3C3E3E3E3B3B3B3B3C3C3B3B3F3F3D3C
3B3A3A3B3E3D3C3D3E3F3E3D423C393C3E3F3F403C3B3B3C3D3E3E3F3F3B3C3C393B3D38
3B3D3E3E3D3C3C3C3B3B40413B3938343839393737393C3F3738403E4743453F453D3A3B
383A3F3B3D3A383738393837373838393B3B3B383A3C36363C3B3A3D3E3A3F3F425A685A
4E3B483244333D3E48484B555D58483A3B3A3B3E40403B373F3E3E3D3A3634343C3B3A39
3839393A3A3C3B3C403E38383C3A36343A3B383B433E3D3A373D3F373E3540363D34393C
3F3C3E3E3B3E413D3C3A3D42423D3A393E3F3F3938475453836D7464613B403E3F393E42
484239414344413C3B3F3F3C40423C3A4143444B3C3F3A383B4041383C3B3A3B3E403E3A
3F413C3A3C37353E4646474553656F7F92A1829F738D6263504745433D3D3F3A42443F40
3B413C3D3E3D423E40393D3F3F3C3D475E626C657B7582939C9B99A4A1B3C0BFB9B6B2AD
9898A9A5ACA4969B7D896E5E51524B54535C636D74747D7F8F9894A692A29FB4B7BBC7C9
C8CFD0BFB7A8A08E8B999CA5B4B0A9A0A99D8F89958E98AEB9C1C6C7BAB7BCC3BCB2968D
9A928F8E918E88959894A6B7BBBBBDB4B3ABBAB2C2C3C7C9DBD3D8D2D5D4C2CBCCD4CECD
D6D5D8D8E3E0E6E6E6D3BFA29F8D705D565460718884909D9AB3A0AECAB19E97949DB2BC
CCC8D1BECDCBDDD4CAA8B3A5DBC3D5C0BB8776715E5C5A4E3E3F3D4142423C3438393637
38383C3C363836353634374247353A353A3C3A3B
504C504E554D504F4C545B54584D4E5F7B879D99BFC0C2CFD5C7BF89A2ACD6DCDFDFDBD6
CDC7C0BEB7B799C39DAA808C6E70685A53585D595D53514953575A67635F6A728C7D888B
8462524A4D464C494B5A739998A29FA0A9B1B6B0A08B756578736D544345434347444241
424342414743414446433F3E3F3D4145403E4244433D42555C4B3E433E3E414444403D3E
343B4245413B3A3C3C3C3F433F3A3C403F3D3B3B3C3F4040413B383B3F3F3E3E3C3E3E3F
3F3D3D3B454341403F3F3E3D3E3F403F3D3B3B3B3E3B3B3F3E3A3C3E44433E38383B3B38
3C3C3C3C3C3E4144413D3B3C3C3B3D403C3C3D41413D3B3C39393A3C3E3D3B383A3B3B3A
3B3E44484A403D3D39393B3A42403C3B3B3B3A3938383939393A3C3C39393A3B3C3E4041
383E4141414242403B3B3C3D3F4041423D3C393B413E3A3D3C3C3D3E3F3F3E3E393B4441
3D3E3E47423D3C3F3F3C3B3D3F3D3D40403D3D3F3C393D3A3A3C393C3F3D3C3D3F424343
3B3F3F3E413F3B3C423F463C3B4F4A373B3A3A3C3E3E3E3E383A3D3F3F3E3C3B3A3A3939
3A3A393944413E3E3F414140443E393B3E3E3D3D3E37373D3E3B3D453E393A3C3B3C3D39
3B3C3C3B3A393A3B3F3C3D3D37383C3A3D3C3B3A3A3A3D3F3B3F4741464040383B363A3E
3C3F3E36383736363839393838373A3D3F3F3C3B43413D393B3B37383D424A46404C5346
3A39453F2D474C76866D58514A3E342F3A393A3C3F3D3833383A3D3C3B3B3B3C3E3C3A39
393A3B3B3B3E3C3C403D38383C3D37363C3C3A393D38393B38363A3C3B3C43383439363D
3F3D3F3F3A3C3E3A3A3A3C4042403F4143403D3A3E4C534C4B403440403E303E3B3F3D40
3B433A453C3C3B383B40403C3C413F3F44413C3F393A363F433F423D39393B3E41423E38
3B3D39393D3A3942485354637A8582737F685843443B42423C383D3F39383E3E3A3E3B3B
373C3D3A3E4238483A4C4A5B626A7B93B0B1B0A0AAA7B0B3B3B2B0B9C4C7C9C8C2BCBABA
B2B9C3C1CED1D3D5D7C3A777515141494E53535B5C606C70859AA9A79C989FA4A7A4A9A9
9A96948C8A878FA3BAC6CCD4D1CCC9C5CABCAE9D9B9297A4ACACADADB3B1B5BAB5BCADB1
AA9F9C9CA2A4A4B2A4A5A1AFC3CAC9C9CAB7B7A5B1B9C7C6C6C0C4B9B7BBB5C4BECDB5CB
C1D6C7CBD7D6DFD7DCDCDDCFD2C8B18F6F58586B7C76826F7F8999969D9699988C868C92
9CA9A7C3C6DDD1D4C2C6BAD3B9BFA6B2735553423B4C4D55958CA46F7647473D44403A37
383A3C3D3A3C3A3839383D494E3C3F383D383936
605B605D5E4F4F505457515752564C524F5E566B6E989AC0C4D2B5AD809E9DCFBFD0D4DB
D2CFD5D7DAC6CBBDDDBDB9AACDC3A997929AA0938D75655C636D6D7F5C72769FA2C3B6B8
937E6B57585B696B7288B3BED1C5C1ABAFAFB5AB9A846558524C4D4A454544433E404346
4746444242414344423D3C3F434042413D3E42403B3D4145474441433C3D40413E3A3D42
3C3E4346443F3D3F3D3C3F423D3C3E3E3F3E3E3F414241403B393A3E3F3D3B3B3A3C3A3E
3F3D3D39403F3E3E3D3C3B3B3E3E3E3E3E3D3C3C3C3B3B403E3A3D3843403D3B3B3C3D3D
3F3F3E3D3C3D4043413D3C3D3C3A3B3E403D3C3E3E3D3D40393A3B3D3D3D3B3A3B3D3E3C
393A3F434039383C3C3E43433E3C3B3A3A3A3A3A3837393936383E3F3A3A39393A3C3D3E
3B4043424242423F3D3D3D3D3E3F40413C3834383E39353A3A3B3D3E3E3E3F3F3B383D3B
3B3C3A4044403D3E3E3E3D3E403B3A3D3D39393E3B3A403F40413A3B403E3B3B3D3F4040
4044413D3F3F3D3F463C3D3A426061433B3A3A3D3F3D3B3B373A3E41403E3C3B3A3B3E41
43413D3A3D3B39393B3D3D3D423C393B3D3C3A3A433A383E3F3A3D45403A3B3E3D3C3C38
3738393938393C3E3B393C3E3A3B3F3D3C3B3D3F3E3B3A3A3E42473C3D383B353B3B413E
393C39383334363738393A3A3B383D3F41413C3D3D3B3E3C3D403B3D3C444B463E3F403A
3F3C3E47477780A26E574745423F41443C3A383839393735363A3D3D3D3F4142413B3637
3C3E3C383B3F3D3C3E3C393B3E423B3B3F3E3E3C3E3A3D403A33363F323C403D37443C44
403F4446413E3D3A40403D393938393F403F403D3B4040373E383C44413631393740483E
40403A3C3A3A3A3A3D3F3D393A3D3D3C3D3B38393F3A3F5E5F3F3A3E3F3C3A3C3E3E3C3A
3E3C3A3C4143485058635D666E6A624A4C3C3B3B40383C3B403E40403C3B3E3E3E413E3D
3D4249424B5C59847592889B97989A9EABA7AFA8ADBDD0CAC1BBAEA7918B888C8E8E8E92
9BB0ABB7AEB2A39F97898E9177927F8B6B6F67635C67716E84A0BBBCC3BDC6BDA3847475
60555C6A7D92A8BECDD4DAE0E0E7DEE7D7DFDCDCE3DADADADFDADDDDCCCCD2D0CDD3CDD2
D5C3B9B4B9BCB7BBBFBFA79DAAAFB4C6C8CCCAD7D2E0DBD6DAD3D3CAC5C5BCC1B2B1B3A4
B7AEC2BDBBB8C5BAC3C8D5D2D1CEC6AE96878CA5A4AA99947A77685E6F778E9C9B9B9FAB
A1A7C5B7CAABB4AEC0BDCFC0D4C3C5BFB3A1916470ABB9C8CBD3B9C597B47D885B524F44
3E3F3A3E393937383C3A3A403F363B363E363E36
57595F5858515B60596F68845C6D57604A4B4E454A4D607CB6ADCCABA070666679969AAB
A5A9BFC6BBC1AFB3A3B7BBD0DBCECFC9C9D2CBC6CAB8C3AFBA9A7B695D60778292A9BCB3
AAAEB0A5AEB4C3C8B7CAD2D7D8D9C3B0AEA4B6B8AF99736F4C4D4746464242433D404346
474645453F3F4244433F3E40424142403E4448423C40413E3E4345443E3E40413E3C3E44
3E3C3D3F3E3A38393F3D3F3E3A3D413E3E3D3C3D3E3F3F3E39393C3F3E3B3A3C3C403C40
403C3F3C3B3D3F40403E3B3A3E3C3B3C3E403E3D3C3D3B403F3E4338423F3F42413C3D41
3F3F3F3E3C3B3D3E3F3D3C3E3D3A393B3E3C3B3D3E3C3E413B3C3D3E3D3D3D3D3E3E3E3D
3B3B3B3C403A3C403D3D3F3D3B3B3B3B3A3B3C3D3C373839373A3F3D3A39383838393B3C
3E42423F3E3E3E3D3F3F3F3F3E3E3D3D3E3E3A3A3F3E3A3C393B3D3D3C3D3F413F37393A
3F40393A45433F3B3B3E3F3D3D3B3A3A3A393A3B403D403F41443D3D403E3B3A3B3D3E3E
4145403A3D3E3D3F3D3937373C4F56413D3A393C3E3B3A3B393B3E3F3E3C3B3B3D3F4245
46443F3B36363637393939393D39383B3C3A37373F3C3B3C3C3B3D3F413A3C414040403C
36383939393A3C3E3A3A3F413D3C3E3A3837393D3D393738363C4237393841403D3D3E35
353A363A3D3D3C3A383A3E42413A3E3E3F403A3E3D3B423F3D3D3738373937373A3A3A3D
43455D56836F866D4E4644443E3B3A373A393837383837373D41413C383839383E393536
3B3D3C38373C3B3A3C3A3A3F3A41373639383B39383A3D3F3C383C43393B3836383E393F
423E4349433E3E3E3A3E3B3737373A423A3B41423D3D3F3B383B494E4A3B41453D414839
403E3A383D3B3C40423F3A373B3A3B3A37383C3E3E404664603F3B3D433C393C40414449
464040434549505454564D4E4A4245403F373E41453C3A323E42423E3D3D3D3F47405044
6863826F949E9CB5A1A38E948C9BB1C4D8D5DCD5CFCDCAB7ACADA6A49C9A9CA5B1BABEC0
A6A6A597A2949E9CA89FC6CDDCD8DAC89FA195938A97A29FA1B9BECCC6D0D2D1D7B8A19B
80777B87809DB3B1B3BDC2CAD6D8D8CEDDD3E0D9DEDCDFDDE5E3EAEBE7E7EFE5E7E5E6E4
EBE1DFDBD6CBB3A68EA0ADAEB7B1B0BBC7C8C9C6CFCADED8E4DFDFE1E5E6DED8D4E0CAD6
AFBAADB1A595A6ADC8CBCEC6C9C4C2BBBABDC3DAD9DCD9CBC2A59B8D9499A9B1B3ACA3AB
AEC4C2CD9A99858E8B9CA3A59CACAFC6CCCCC9A6B1DDDBDBD8C5CBADD4CBD1BBC4BAB897
765E41403B3B38383A37363C3D424D4E55434B38
4E50554E55565C585F5D5F61595D65625E64616B5B57505E5E607FB39CA86E595566545E
5A648186C2C8D4C5C9BEC1B7CAB8CDC0B2B5A3B1C0CDD9DFD3DAC1CC8F6050614A5D82A4
95A7B5B0BCC0CFDADDD7D6C0D9D0D1C2BF9FA5A4A39D8A9F8A947C63574B4B4E42434443
42434548433F3E44494743403E404342434C4E434242434242444644403F414444424144
3F3B3A3E413F3F40413F3E3B373E433E4744403E404245463B3B3D3E3B383B413B413D3F
3C373E3D3A3E424545423E3C3E3B393B3F41403E3D3F3C414042483A3D393C424038373E
37393C3D3E3E3F3F3E3C3C3E3E3A383A39393B3F403D3C3D37393A3A39383A3B403E3C3D
3F3E3B383D393D423F3D3D3B3A3C3E3E3D3D3F4140383739393E3F393737363637393B3D
393C3C39393C3F3F393B3D3F4040403F3A3D39353A3D3A37393B3D3C3B3C3F43423B3C3A
3B3E3E4646454039383D3E3C383B3B38383C3D3A423B3A36393F3C3E403E3B3A3B3D3E3E
3C413E3A3D3F3D3E3A4140403939433C3D39383B3D3B3B3E3B3C3E3D3A39393A3D3C3C3E
3F3E3B383A3B3D3E3E3D3B3A3836373B3C393736363A3A37383C3D393C35394245474947
393A3B3C3B3A3B3B4440403D37383C3C3A37373B3C39393C3C444A3B38353C3B3C3C3B34
3B403333393938383B465561453C3F3C3C3E383E3837413F3D3E37393C3A34353D3D404F
517D65785441473436393D3B353A3F3A3537393B3B39383733383A3634373B3C37383938
38383A3B33393A3839393A413D44393739383E3D383C3E3C3B3A3B3E3D383839473F3B3C
40393C413C373B3F363E3F3C3C39383F4039383A393A3A354541384346423E393A3C3836
3942383B36343840433F3A393C3B41423A3A3D3B333F3D45423A4643454146535B5C6067
6B605D594E48484449403C42413A3B41423C363B3440403F3B423E39465C758B8D8E8597
A1BBC3B7C5B9AAA7A3A7B4C3D5D8DDE1E9DFE0D5CCB9B1B3C0CFD3DBD3D1CBC8CBD2D2CD
C0C2BCC1BEBDBAC4C8C8CCD2CCC8C4A6959083847473736F69797685869BB1BEC5C8C7C3
ACB0ADA69DA5B4ADB2BBB4BFB4CBC6CED2D1CED1D3D5DCD6DCD7DBDADADCE7DCE8E1E7DF
E6E2E6E4E4E6DDD9BDB8BDAFB0B4C3CEC9D5C2CEC0C4CFD2D3D3D2D4D7DBE0E0E0E1E2E2
DAD5D9CDCEA29EA0C1C5C8C3CCC9D0D3D9D9D4E1CFE2E4E1E0E1D9D1B7BCCACFCBB0887F
8A98C9C8C8ABA98E988C997F95849098AFB5C2BAC2D6D6DEC2D6BCD1BEDBD4D2CACDE5D0
B4A182875254514C494448544A6C96B2C3A7A37E
4D4B4E51504C4C50494D4F4D4B4B4B4A4E48484A4E4E6869635E615C67819963544D474A
4548617199CCD4CCBCB4958F7A8A908D685D64689892B9B2CFBACACCCAA69571574A5F8F
99A5B8AFAA9E9FB1ACC197938A9BA1BEBCC7C7BEA99C7C6C8073AFA4B58664644D3F4346
4445403F42403B434330423A3E3B4248464445443D414341414343423B3D403F3D3C3C3D
44393B43413D3E3F3C3E3F3F3E3E3F403F3E3C3C3C3F41433B393D3B3B3E3B403B3D3E3D
3B3A3B3C403C3D404248473D383F39373F3E3B433F413B41383F42393A423E3E39433B34
373F4443403F41423E3B3B3D3D3B3B3E3F3D3B3A3A3C3E40393938383A3D3F40363B3D3C
3D403E3939393A3A3B3C3D3D3A3C3E3E3E3D3D3E3C403F39393E3D3736393B3A3837393B
3A3C3E4142413D39353D3E3B3E3E3B3B3E41383839393F38383A3E3C393E423D423F3F40
3E3C3E43443E3D3D383A3D3A453D383B3F3F40423A3B3D3E3E3D3B3B393B37383C3A3A42
36393C3B38383C404040393840403B3C3D3C3B3A393A3A3B393A3B3B3A3A3C3E3B3A3939
393B3C3C36393F4445413933343637373737393B363534373C3E3C3A37393A3C4044433E
363937363C3C393D373C3D39373A3F413736413A3D47475B625C43343A3A363E39393A3B
3C3B3937353C3B3A506A67504D4A3F3A3E3E3B3E383A423A363B3639343B35414745504B
574D423E3F403B363B3D363A3B393F3B393B34353D334037383838393D403E393937373A
3936393E393A36353A3C3B3E343F3A393E403F373336393938383A3D3837373A3F42403D
383C39373C3C3B413E3C393A424A49433B3A3F46413637403D3C3C3F4243413F373B3B39
3A3C3C393438373D3E3A3A3437383F423B3A3D3B3B45394142464A516869858C927D827C
6363595442403A3D403D3A3B3F42413F40403D3C3E3A393F3D3F36406FA7C7CCCED5C9CB
CED0C5ABB6AA9593818A84A29DC1D2DFE3CFC2BFA4A6A59098B6D8D9C9CCAFAFAEBBC6BD
AD9FAE92A1909B99A496977974695F7961686963636D777B6A70727F7F8986887D817774
80807B82787382758A83938B9D91969AACA3A5A2AAB1B9B2B1A9B1B2B1C1B7C1B9C7C3D8
C6CDD9DBE1E3E8E6E6E3E3D0D2CAD1CCD4D3D7CFD5C3CAC2CCC3C4BEBFC4BFC3C0CFC7CF
C7D0C4CBBEB7888D6E7D6F7D8DB2C8D3D6E2D8D1D0D1DDE0E9E2DFD5D0C1B2B1BCB2C1B1
AAB2BAD8D9E5CED9C0C6AFA993947F81778B8E98A4B1CAD7D7D7CBB0C0B1C3C3D2CEDFDE
D5C1C8C0BEC0BCB4ADA8ACB7B5CECFE6E0DCD1C1
4E4E4F51514F4E504A4E4F4E4F5152504C4949495053717B705C494B4E606C625F585154
515364699EA0A78D966C60584C4D4B565654534B545D6A7F8B9DB5CAD3CFCCC5A08C5B53
62668984A28B938273806F5A4A57588290A2C8CDCDDEBFB582585A788AB6BBBC87695949
404C4E43434244453F3E4342443F4145413F3F3C3C444340454645484444424140404040
423C3D413F4143414141413F3C3B3C3D3F3E3D3C3D3F4244413B3C383A3E393B3A3B3D3D
3C3C3C3E3E3B3C3D3D42413938403D3D45423C423F42383D373C3E3B3D44424541494340
3D4447433E3E3F3D3C3A3C3F414041443C3B3A393A3D40423A3A3B3B3C3D3F4137393B3B
3C3C3B393B3B3B3C3C3D3D3D3C3A3837383C4144393D3E3B3C41434136393D3E3D3D4042
3D3B3B3D3F3F3E3E3D43413C3D3B38393D423C3B3B3C433F3B3B3F3F3C3F43413C39393B
3B3A3D42413B3B3B393C403D423E3B3D404243443C3D3E3E3D3D3C3D363B3C3C3C373842
3B3D3E3C39383B3F3E44443F3C38383F3D3C3B3A3A3A3B3B3838393838393A3B3C3C3B3A
39393A3A4041434545423C373836353638393A3A3837383A3E3E3C39373A3B3B3E413F3B
35393A3C42403A3932373D3D3A3C3D3B3D3E4239496362685E56433A41423D3F3B3B3A3A
3A39383734393B3E4C5B584C5D594D43433E393A35343A373A423D3D39413A4245424941
3E3935373E42413F3C3D373B3C3A3F3B353A383C44394339393A393A3E43433F3D3C3B3B
3A38393B3B3C38363B3B393C3D443E404442413E3A3A3B3C3D3E3E3E3D3B3A3C3F41403F
3A3C3A393B3B3B3D3A3835363D4445413B404444403D3E4138393C3F41424242383A3A38
3A3E403F363B393E403D3F3B363B44463C383B3B3947485B636F777D88828B7D7B666455
4E4C433F353A3B413A3A3B3F4345434140403B3A3D3A3940383B45668C9D9C99A4A29D8E
8D857A675D5E5A5F698792AAA3C5D3D5CDBBB0A9C7C1B89F9EA7B0A27F77605D595D5A54
525463667378828789998785678D677A797F84868E9CA3A2AA9DAD9FC2B2BEAEB1B5AFAD
B3B0ABAEA4AFA0AE9EB7B1BEAEB4A7C0ACBDB1BEB5BFB7BCB29C9788918A8E7F837E9195
9EADC6C7D8D5E2E3E2E7E1E5DBE2E0E7E0EBE4EBE2E7E5E2E1DEE0D7D1CEC5C4ABAFB9AB
B2A4A7A1AB9AA66F654E546C95BCD6E5E2E4D9D6C7D3CAD5C0CEC1C6B3AE968A7F85A1A6
B5C1CEE0E8EDE2E7E8DFEBC6D9B5B8A18477714E5586A3CFC4CDACAE939CA5C8D5D5DEE0
D5DADCD7DAD8D8DAD8D4CDC6CAD2EEDAF0C6B295
4A4B4B4A4B4C4B49474A4B4B4D504F4D4A48484956525D606B4B5B5E6A6D867D5B544C4E
4C4C534D585C4F58505746494D4C474C534A4A4A4B4B6C64967A96859A91A4A1B8A87C50
4C4C4E49504E6961707568615F56525A607397A3B0D5D6CFCFA766584E758393A7A5A48B
70685C4F594A44473A453E4947403F423F3E3F3D3B45413D4547454C4945403E3F403F3D
414041403F4345404242413F3D3C3C3D3F3E3D3D3E404244473F3D3A3D413C3C3B3C3D3D
3C3C3D3E3C3A3A39373B3C36393D38353B3B3A413F42383E40403C363B3E3C423B3E393A
404747403D3F3E393E3C3C3E3E3B3B3D3D3C3A393A3C3F403B3C3E3E3D3D3F413938383A
3A38383A3E3E3D3D3D3C3C3C3C3B3A393A3A3B3B383A3B3C3D404345383B3E3E3C3B3C3D
3E3A393D3F3D3D3F3B403E3B3D3E3D40363B393937383F3F3E3B3F423F3F43433F3C3A3C
3E3F4144403B3A3A3A3D3F3D3F403F3E3F4142413D3F3F3E3D3D3E403A3C3C3D3C393940
4141403D3A3A3B3E3B41423F3E3B3C413C3C3B3B3A3A3B3B3A393838393A3A3A3D3E3E3C
3937383937373738393938373A373536393B3A383A3A3A3D3F3F3B38393B3C3B3B3D3C38
3C3C393A40403C3C38363838363D433F40444C485664534944433F3B393838393C3C3B3A
393838383A3938393E44494A555147403F3C38383C3738373C423C383B423C3F403D4136
383635373A3B39373B3B373A3B3A3D3A3035363A423841383F3F3C3A3C40403C3E3F3D3B
3B3D3C3B383A36363C3E3D4040433B3F423C3C3D3E3D3C3D3F3F3F3E3F3D3B3B3C3C3D3E
3C3A3C3C3A3B3B393F3D3A393D4243413D45463E393B3B373A3D40403E3C3C3D3B3B3A38
393E4142383C3A3E3F3D42403B3F46453D3E474D5661697C7A7D7B76695B56444841463C
42423D3D383C3B3E3B3B3D3E3E3D3C3B3F3A3438413F3A3C484B586E786D626863565449
4B564A4A606D9385B1B6CFC8BACFD6CEBFB1A5958E83765D59585B4D4D443F413E423E42
4850787BA79EBCB7C5B8C49EAD9B9496A2A8ACAFBACAD5D8DAD6D5DCE4E4DAD0D1D3D3D1
CCC6C2C0C8CFD4C7D3CED7DCD6CDDEC5DAC0D4CED5CFC8C1A79F8C9392B6A0C9A9CBACCA
B9C7C0C6BFCDCDDCE0DAE3D9E7DCE8E6E1E2F1D7F0DCF3E2E6E6E6DDDADCD9D8CFDAC4DA
B5CEB7BCA8B9A3BC919D737DA3BDCFE0DFE3DFE7DAD1D9AFBAA4C0C2CFCFD2C0C7B3BC9F
9AB4B4D8D4EDE1EAE6ECE1F4E4F1D0BFBCC18B6E5D65A6C0CAC9DBA9B888AFBACBC6D9BE
BFC1D1CDD8D1D5D8D4D6D5C9BBCFCFD6ABAB6D77
4D4F4E4B4D504F4A4E50504F50524F4A4D4C4A4651474749536558606C8889985E595051
4E4E51475052534B4A4B4B454A4D4A4C57444247474F444B47505055534F53616F7F6C63
464C454E4C455751675D8178848972836A75717E89A9D5CED1CCB0877966645E749CC2CA
C9C0ADAB9B8E757760614E474E4340413F3F413F3B423F3C404445494A443E3E4042403C
414243414042423F3D3E40403F3F40413D3D3C3C3D3F4142413C3E3C3E413C3E3F3E3E3D
3C3C3C3C3C3A3B3935393C3740413A363A3C3E453F46413E393A3F3B3D3E3C443C3C373C
3E44433D3C41403A3C3A393B3C3B3C3F413F3C3A393A3C3D3B3D403F3D3C3E403C383739
3937383B3F3E3E3D3C3B3A3A3B3B3C3C3B3936343B3836383B3D3D3E3B3D3E3E3C3A3A3B
3C393A3F413C3A3B3F43403C3D3A383C3A3E3F3E3C3C42453F3A3E423E3C40413E3B3838
3A3B3C3D403D3C3C3D3E3D3A393E403E3E4143413F40403F3D3D3F42423C393B3F3E3B3B
41403E3C3B3B3D3F3B3D3E3E3F3E3E3F3B3A3A3A3A3A3A3A3E3C3B3B3D3E3D3C3C3E3F3D
3937383A3636363637393A3B393838393A3A39383A3A3A3C3E3E3C3A393D3E3B3A3C3B39
413E39383C3E3D3C423D3F3D393E433B48464A494B4535363E3E44474140413D3C3C3C3B
3A39393944413D3B3C40464B3F3C393738393939413C3A393C3E3934393F393939393C33
363738393A3A3A393938363839393A383D3E3D3C433C46413E3E3C393A3D3C383B3D3C3A
3C41403C3E3F3A383C3B383A3F433B3B3D393A3A3C3C3D3C3B3B3C3D3B39393A3938393B
3C383C3F3B3B3D373E3C3A39393A3A393E44443B373A3A353A3F42403A37373A3E3D3A38
383B3E3F393C393C3C3B41403B41484D4F5661696C6A66685756514C43383A39433B3D3A
434240403F403E3D42413F3B3838393B3F4140403F3A3E4B5E5C5E5E5D5244474C444E51
597F819C90ACC4C9D0DBD8CECEC3AD9176675B484644463D403D413C3C3C43443F454F5A
718D9BC7CDE1E2E6E9E1CEC4ADBBAFCBD0D8DBD6D1D1D3D4D4D2E0D4DFC8C7BAC3C2C7C4
B8B1AFABBED6C8DBCCDDC4D0CBD0BCCEBBD1BFC3AABAA8BEA69594939294C9C8D9C6E2D2
D5D5D4C2D1C7CAC8D1D8C8DFCEE8D6DBD6E4D4E4D2E4DEE1DEDCD6CDCACBC7C2CDBECEB9
CEBDCEBACECED3C6D7BEC9C1C1C6C5CFCDCECAD5CFDABDC89BAA9BB5B6CDD4DED8E1DBC4
ABB2B0BECED3DFE4E7E0E3E2E2D9C3A2DCCFCFAC92897F9D91BCC2D8BECEBEC8BBBFC0B0
92A9ACBDB5B7C8CCBCB6AF9AA58EA37F7D594545
4F514F4C4D514F4B4F51515051514D48484C534D5857667879828C817E727E635A575050
4D4E554E5B5453564E4D535C5E5A515A7463534A484A5549584F4F4F4D4B4B5150544A4A
5049535E876B786A7270716F78798C98857B5E58525D8781979BBCC1C3BAAF87536D92B1
CDD6CCCEBFC8A0987F7F7A59544843423D3C3D3B403F413F3C4248454A46424347484541
3F3F414344413F413A3D4042424141413C3C3B3B3C3D3E3F3A3A403E3C3C383C3F3E3D3D
3D3D3E3E3C3B3D3C383C403C3D3F3D3B3E3E3D3F3C413F3A36373E353B3C3A443E3F3C43
3B403F3B3B403F3A4843403F3D3A3B3E41403D3B3A3B3C3E3B3D403E3B3A3B3D3E3A383A
3A37393E3D3D3C3C3B3A39393A3A3939393A3B3C3E3935373C3D3B383C3D3F4041414142
3E3B3B3E3F3B393A3D413F3C3D39363A363739383636383C3F393C403B383B3D3D3B3939
3B3D3D3C3E3D3D3F42413D3A464A4A443E3C3A364040403E3D3E4042413B3B4043413C37
3C3C3C3B3B3C3F403C3F43423C38393A393939393A3939393F3E3C3C3D3E3E3D3B3D3E3C
3938393C3D3C3C3A39393A3A36393C3D3C3A3939393938393B3C3C3C3A3E403D3B3C3D3C
3C3B3B3C3C3D3C3A3E4B5D60544A443B433E3E3F403A37443E383E494D504C3F3C3C3D3D
3C3B3A3A36383735373A39343B393939393A3B3A3C3B393B3C3B3C3B3C3E393737393C37
3738393A3A3B3D3E3A3939393B3C3A3A3E3D3C363B353D3B37393A3A3C3F3F3C3A3C3B39
3B403F3A383A37383D3E3C3F414A423D3E3E403C393D3F3C38363A3E3837383B3B38383B
3B373B3E3C3D3E373C3B3C3C3C3A38373D3E3E3D3D3F4041373B3E3D39373A3D3B3A3939
39393B3D3D3F3A3C3D3B4140484E545A5E5D5A58544F4A4A3A3F3E3F3C3A404249403F3D
413C39373B3E41414242403D3A3A3D403C3F404446434A5B444448434445404A57619C97
ACACB9CDCAD1DCCDCDB9B0997965594E4242413B393B423F443D3E3C4846443E3E517483
9BA5BCC5DFD5E6DDE4DDD69B928FA2ADC5C6C4BDBABEC6CBCAD8D0E2C8D2BFC4C2C0C6C6
BAB7BAB5AEB2B4A0B0989087897F8276887F8276888994A9A8B5AAB9ADC5AFD0AFCBAFC3
B1B7AAAFAAB3A4A6AEB3C4C1D7D6DED1D7CBD8BED6B4CCC3D2D2CFD0D5D7D0C5BBC6B0CE
A5C5ABAEB8B6B3B9B0D1BED6D4D4CDD4CDC7BBC2C5BCD1B6C6909896B3C0D7C8DBD8ECD8
C9CBB0D4CBDCD1DEDDDCE0E4DCD8CBB9D4DBD4D8CDAB96876976A19CC1B4CED0DBCCD0A6
94888F9BA3A7BFCBC0BDAF8E7A4D3C423C433A3D
4E4E4C4A4A4C4C4A494C4C4B4B4D4C494D52646775757E887C8D686758534C595A554F52
4F5059566453575160576D786B665659695D514B4E4B4A454F544D5846434B44585A635B
574B53608A8CABC3C1B5B7ADA8A1807D6B5C594E494C504B5A657A939AB4A89B635D6F7E
848B8E92A6B5938D7D6E764D4F4541403C3C3E3C454145443C434B454443424447474441
3C3E3F4345413F443E40424341403F3F3D3D3C3C3C3C3C3D3D3F4845403E3A3E3E3D3C3C
3E3F40413D3D3F3F3C40433F3E3E3B39393A3B3E3A3D3A383B353C3A3839363F393B373D
3D3F3F3D3C3D3C393E3B3A3D3E3F42473F3D3C3B3B3E40423D3E3E3D3A393A3B3E3B3939
39393C3E3C3C3B3B3B3A3A3A3A3C3D3D3B3A3A3B3F3D3B3B3F413E3A3E3E3E3E3E3E3F3F
413E3A39393B3C3D393C3B3C3E3B393E3F3B3E3C3C3D3A3F3D393C3E39383B3A3B3D3E3E
414444433B3D3C404747413F414547464444444341403E3D3D3E40403B3B4248453F3B38
383A3C3C3B3C3E413D3D41423E3B3B3838393A3A3B3A3A3A3E3D3B3B3B3C3C3B3C3D3D3B
39393B3E383939383737373836393D3E3D3B3A3A39383738393A3C3D3A3F413E3B3C3F3F
3D3B3D3C393C4346556D817D6750423D393B3A3A41413E42423F45505559574D403F3D3D
3D3D3B3A3D403D393C4340373D3B3D3E3B3C3D3A393B383C3B383C3D44413C3A3A3B3D3D
3C3C3C3A383738393D3B3E3D3E413C3D4342443E413A3E3C393C3E3D3D3F3E3B3B3C3C3A
3B3B3A373D3E3A393C3B37383E4A433C3D3E413C3B3E403E39373C413A37383E3F3B3A3D
3B383A3D3D3E3C383E3D3F4243403E3D3D3A393C3E3C3C3F393B3C3A3837393C36353638
3A3A3B3D41423C3F414043404044464A514F49463D3D3F433B433E42383F40383D3E3E3A
3B3839363C3B3E3C3D3E3F3D3B39393A3D3B3C48514B44484541464652687C9EAEC5D7EB
CBD7BDCEC1BC9B9F7B785747473F464943413F3F3D3D3F39423D3F3F3B3B47546A89B1B9
CCD7C5E2D0EADEE7DDE2CDBF9097899DA0A0A3ABB8C3C7C7C9BCCEB1CAACBDB0B7ADA494
7C6B6258534F4E3C4E42433C403F3D4343474446475552686C677D7FA37B9C748C658760
61575B435045544E5169739698B7B2B7AFB2A5BCB0B8B7C3C9C7C3CCD5D7D4CCC0BDCEB8
C3B2C2BBBDA9BA8DB29FB8B7D1DADBE2DCD9CFD5C4CCB6CDAEAE93AAC6CFD3DBDCEAE6D8
DBCBBCC9D4CFCCD3CECADCC9CDB2BEBAB3BCBBBABCB5A6998B858EA09E989BB5C3B8A9A8
8F988D9EB1ACB9C7CDD9CFAA9A755A614741433B
52504F4F4E4C4D4F4D4E4D4A4A4F52525D576769716A615A4B4B4C514E4A5857574E474C
4A464B474B4F3F50445B5768565B4F4D4B484A5144504D565256526853594B4C435A5E65
6559615F5B616D9284A4A0C8D3CEC2AF8E817F6E7276736E596266606867636A68545757
4D545E637D8890A2AE8E8454484140423F3F4242444245433E4349453F40424343424140
3F45434042424144424343423F3E3F3F403F3E3E3D3C3C3C4141494644433E41423F3D3C
3D3F3F3F3E3D40403E41433E47433F3B3A3D41443E413D4759413D4C3E3E3A403A3E393B
3E3E3F413F3C3A3B3E3C3C3E3E3D3D403F3E3C3C3D3F4244403F3E3C3A393A3A3B3B3A38
383B3D3D3B3B3B3B3C3C3C3C3C3F42413D39393B3D4345413E40403D3F3E3C3A39393A3A
3E3F3B36383E403E40413E3C3D38363C3F3639393B3E373B3B3B3E3E393C3F3C363B3E3E
3F4242403E3F3D40484944434343454746434243413E3C3C3E3F3F3E3E3C4246413E3F3D
393C3F3F3C3B3C3F3E3C4144403F3E393A3B3C3D3D3D3C3C3E3E3D3C3B3B3C3C3F3D3B39
383A3C3E3A3B3C3C3B3B3D3E3A39383B3E3F3D3A3A3A3939393A3B3B3A40423E3A3B3E3F
3E3D3F3D363E4F59707C7867564437393E433C353A41403C393C42464545464548433D3B
3C3D3C3A3E3F3B36383F3E3939373C3E3B3B3D393D3D373C3B353A39453D3B3C3D3C3C41
393A3A3A39393A3B3D3A3E3C3E413B3D3C3B40393D373A393E403F3C3A3B3A373B3A3B3D
3B393839383A38383D3C393B38423C393A383B3A3E3E3D3C3B3B3E403D38373D3F3B3A3D
3C3C393A3E3E39383F3C3D41423E3B3A3F3A383A3A3734343E3C3A383738393A37353538
3A393B3E40403B404443443E3D3E3B393C3B37393D3D3B3B363F38423D45443E42433D37
3A393F3C423C3D393E3E3E3D3B3A3A3A4647494E4E423F4A484D6C8AABC1C4D7DFD8DFC3
C49F968067594A4646444C44423E45423D3E393D3E4142383F3C44495E6187A3BCCDD9D7
DDD6CCCBC9D3D0D4CBB2C5A5AE7880807F79747780878886746B655B5B53504A4C484644
403F3D3941413A38383F3E3E3F40465054585F69818FAEACAD9998979B8C8D7F7F6F6B58
625A5F5757545A4E49424E4F655C635E716C78718978908EADADADBFCED3DCDED4E1D0DC
C0CDB6BAA6BEACB599A4A8B8BACBD0DADADED5D5DAD6DAC5D7C2D0DAE1DBE6D8DED7E3DD
D0C09EA697A494A59EA999B69AAD9EB7B5BEC1B3B3BBBABEB9ADBEC0BEA1969A9F959597
9D9C9DA3C9C9D1D2D0D3C4A19A9297978C707C63
4E4B4B4C4A46484D4C4C494443494F5155454D484A4A4A48495854534E605F62685B5258
554B4B4440434B434E41474C434C4349474A48494950444C51525C726862594F54555A53
644A6C59665E636F658A85B7CADCD6CFD2D8CDC2C4B3AD909C849D7B8B647C626E524A53
6C8D9DA292776B608587957A4B454546414042423F42423F3F4244444144464644424344
454E493E3E424040444342403E3E40424241403F3E3D3C3C3C393F3E40423D3E4744403D
3D3C3B3A3E3D3F403E41423B403F3F3E3D3D3D3C413C3963996F3F383B3D393F3C433F3F
3E3C3F44433D3C3F403F40444441404241403E3D3D3E414242403E3C3A3A3A3B383B3A36
373C3E3C3A3B3B3C3D3E3F3F3E40403C383941473A474D443B3B3D3D3F3E3C3B3C3E3F40
383D3C383A42433C3E3E3B3B3E3B3C4443383B3B40443B3E3A3C403E3B40443F3B414544
4344444143443F3F4848434444414244433E3C3F403D3A3B3E403E3C493E3B3E3C3F4342
3B4043413D393A3C3D434D4B3C373B3C3C3C3E3F3F3F3E3E4041413F3D3D3E40413E3B38
383A3C3D4041403E3B393B3C3F3834373F433F393B3B3C3C3B3A39393B41433E39393C3E
383C44443D4456615B5A44353C3E3A413F4841393C41434142424141403E3C3C4F473D39
3B3D3C3A3A3B3C3B3C3C39363A373C3F3B3B3C383E3C343A3C363B383F36363C3E3B3B42
3C3C3D3C3B3A39393B363C3A3B3F383A3D3A40383D393E403B3C3B383639393839383A3E
3D39393E3A3C39383C3B3738373D383A3B35383B3F3B38383B3E3D3C3F3734393C39383B
3D3F3A393F3D36374A45424545403C3B3F3D3B3B3C3B38353B383535383C3E3F3B383739
3938393D3C3C373E4443433C383E3D3C3E3B383C393E3F3F3E4438433E3D36363E3F3B3D
3C393D383F3B41404241403F4145494C4E4843464D51627AA3ABC8D5E2E5D4DCC9C19B8B
7163524144423F403B36423D3B3A403B3E453D3C363E413847587B94BCADCBCFD0CBC6C7
B6B19CA692AA959E756B5E5A4E4E424142403F424547464442403F3F41413F3B44413D3D
3F3F3B383A3F3C41373F3A393D393C4347464E597485A1A2B59EADA1B293BC94B591BEA3
BFAEC0B3C1B1B79984665151574C423F4046474C53576263757E8BAABEC5D5DCE1E7E5E2
E2D0B29F98889B7C9D92928A92A6B0C1CBD6C7BEB6CBCCD1D2D6D2DED8D7E1DDD5CFD5D9
CCBFACA6979781888171716A7F6A6F76819098A0AEBAC9D2CCCAD5CACEC8B9AAA5A79EA8
A0A1999D9AB0CCD5D4DEDFCEAFB1A7BDC2CBCDAE
4C4E4E4E505453504E4E4D4C4B4C4E504B4B4B4B4C4D4E4F4D6160695D67616B6A625E66
6B5B4D4F4D4F4841474A4A4C484F4E4C43434C46434C474B49525360575158585C62626C
7B615C565E658C85987D7A8F98B9CACACACACDE0DACEC5CDBAC5CBC3B5B9C2BBA3A16C69
9DB9C4C0B9BAB789887363707068624F4546414547434E484843483C40473A464049474A
3B3F4147433A434C453C4D3F414146454142413F43413C43393C413C3F3F413E44403B43
3F3C433C3A3D3F3E4042413E3F3D3A3E3D3D443E39403470D29E3647363E43403B393939
3C3E3B3C42413C3B3F3D4045433C3C433A38383D3F3F40443D3E3E3E3D3C3B393C3D3E3C
3B4343373C3C393A3F3D3C433C3C3F3E3B40433D3B41423F3E3B3C423F403A363B3B3C42
3D3A393C3F41414046443E3E413B373B3A3C38373D3F3E403A3D42443F39393E42414140
3F3F4040423F3F42413D434D5A504642403E3D3E3A3F403D3C3E3F3C41423C3F393D393C
3C3A3F3C3B3C373A343C413F3C3D40413A3635393D3B3B3E38393A3A39393A3B3E3F3D3A
3A3D3F3E3D3D3B39383838363736353536393C3E3837393E413C3637333A3F3C39393A39
3136373A454F483A3D3F3B3D3D3A3D393A413E39404239342F363D3E3A383B40513E3638
383A3B363936383632383C3837363637393C3F423939393B3E403F3E3B3A393838393B3C
3A3C403D36363732333B3B383936363F393A3636393636413E3A393C3E3B373635353637
383A3C3E3A3B3C3C3C3C3B3A37393B3936363739333B363A373C383F403D3B3A3A393735
37393B3B39393B3E40403A393F3F3F4535383836383D3F3E36383B414646413C3834383D
3C3E3E373B433E40413C3D3E38393B3B3A3A3B3C3D43443E393A3A383A3F3B3B3C3E433F
3F38353E3842403B3D413F464548575157676B8F8DC2B3D4D4E4E1DED9D7C6AA997B5D4F
463D3F483D3F383D413F443F3C3C3F38373D393E3C3E37446FAAC1C1B8B4AEA89E907F74
7D7D78655C554547474040403C3F413D393E3A40403B3F393841453F3B3A3C3E403E3D3B
3A393939373B3F3C3C3F3E3E393C403941404745434B54676453575D59685D6F637D6E90
7B9A8DA38EA49DA8897B6452544C524548445B6F808996909392A5C8DCDBDDE6E2E6E7F0
E5DFD5D7B39C909A9AA18D888A83A2B5CFD2D5D7D0DCD8DAD5C4BDB7B1A9AAB0988698A3
BFC2C5C8B7B6B8BCAA95907986737A72796B718797A4B8C9C5D2CCD7D7D8DADDD7D6D8D3
DCD5C6AFA3A6A4B3C4D0D2DFD3D4D5D8E0D8DBD0
4A4B4B494B4D4C49484A4C4C4A4847464B4B4B4B4B4B4C4C4D564C524B54484A504C4A52
5A585863555F4E5A4E5F4E5342494744444E594E4B5048494649444A4C45474952606775
755E5C58584E68616C56535655677B7A848D9AB5CBCBD1CCC9D1D7DAD0D0D3D5D6D5B4A9
ABA3ADB4C4D1D4C5B6B29DAFA09F9E8A766B5E5E5E6381769377776357544D4452494D45
444841404541404343493B4D394A343C38483D474B434D4148393F3B4141494647444048
463E42403B3D3D39393C3D3C3E3C393D3B3C423C383E3561C7B44734383F423E3A3A3B3C
3C3D3A3A403F3A3A3635383C3A35363C3B3A3B3E3F3D3E413A3A3A3B3C3C3B3A3635383A
3C44473E393B3B3D413C393F3D3B3E3F3C3E403B373C3C3A3936353A3B3D39373B3B3A3E
3E3C3A3A3A3A39393E3E3B3A3E3C3A3E3C3E3A393D3D3A3C373B4145413A383A40403F40
424446463C3A3C403F3B3D43463F3A3B3D3D3D3E3A3C3C3A393B3E3E373A373D383E3B3D
3B3D45423D3C373B393F433F3B3B3D3D3D3B3A3C3D3C3B3B3A3B3C3C3B3B3C3D3B3D3C3B
3C4143433C3B3B3C3C3A3A3A3C3A3837383A3B3C3936383C3D3C3D3E373B3D3936383B3B
38373D484C463D39383B373A3B393D3A363E3F3B3C40403E39393A393A3B3C3E413C3937
373B3C393A383A38353A3E393333343637393A3B3E3D3C3B3B3A39373C3B3B3A3A3A3A3A
35373D3C36383A363C3D3A383939393C393B39373A393A42403B393A3A3735363C3D3D3E
3F40414241403F3D3A39383740403F3B3736383A343A3A423F3F373A3536383A3B3C3D3E
3D3D3E4041413F3E393D3A383C3D3D41383A3A38393D3F3D3A3A3B3D3F3E3A373A3A4041
3B3A3D3B373F3B3D3F3A3B3B3B3C3E3D3C3B3C3D3A3F42413E3E40403B413E3F3F3F4440
40413A3D3D463D38383D45474C658696BDBAD1C4DDDAE2E8DCDACDB6B29F8F6F604F4240
403D3E44373D3B3F3C383D3B3A393D3C3A3C3C3E4E404E65939C9C896E655B5351515251
4C4B4A3F3E423E43413D3E3F3C3D3F3B3F423D403F3B3F3B35393C3D3C3D3B3B383A3C3E
3E3D3C3B393C40403D3C3C3E383A3F39403E433F3D3F3F48453D474F4B5756655B695B6F
59716575677C7B86898D8B8483777B718780879193A7C1CDD2D1D7E1E4E0DFE4E0DDD7DF
DDE3DCDCDBCFD7CDDECAD6D2CCB9B5B5ABC4C2C4C4D3D3D6CFCCCAC2A1928B8D78615F58
7574847F8E8FA09A9F9DA6B1BEBEBCB9B4A29DA5ABB4C9DBD4DFD5DCDBDFDFE2E0E2E6DD
E0DBDBD3C3C2B3BCB5C3BFC9BED3D0DCCDD6CCCC
545553515153524E4D4F504F4C4947474E4D4C4B494846455357494C4751474A4A4C4C4D
4F4E515A56585253565D5A5B595F5B5759656C5A535146444448464A4C4F5E6A706E625F
5C4B515556495A5753495150595E6B5B566060626B697C7391A5BBD2C9BCADB5D0CAC9D8
CFB7B9BBC1B6C3ABBCB2BBC4CCCDCEC1B4AEA6A6A6A98A83859999AE90A493A88C9A909E
848576666A6A5D5853514A45483F434F50677789949689685B3B44374138413C46454046
463D3E4241464A48464442403E3C383C3A3A403A3D3F3C54A9B45D3B3A3F403C393A3D3F
40413D3D42413D3E403D3C3D3F3E3C3B3B3B3E3F3E3B3B3E3B3937383A3A39383F3B3C3D
3C3C3B36393C3D3E3E3A393D454142443F3D3D3A3A3F3E3C3C383639383937373C3C3939
3E3F3E3C3B3B3C3C3D41403D404141433E3F3C3B3E3B383A393B3F42413B393A43403D3C
3D3D3D3B3C39393D3D393A3F423D3B3D3F3E3D3D3F3D3B3A3A3B3F4449473D3E363C3B40
3C3E45413B3A373D3D4144403B3A3A393B3B3B3B3A3C3B373C3D3E3D3C3C3E403A3C3D3C
3E4245443D3B3C41403B393B413E3A393A3A3A3A3A353B403B3C413F363A3D3C3A3B3C3C
413F485453453C3C373B383C3D3C413F3E40413C383D403B403B37383C3E3C393A42423C
3D403F3E3A3A3C3A383B3C383537393A3B3B3A39403F3E3C393635353A3A3A3A39383737
34363B3B36383B383C3634373B4143413C3F3D393A3C3C3F423D3A3A3A38393C38383939
3A3A393941403E3C3B3A3B3B36373839383534343736363E3B3B373936383A3B3B3B3B3C
3B3A3A3D41403B373B42413B3A3A39393C3D3D3B3B3D3E3D3C3B3A393938373637373B3B
36353837383F3A3B3C35353538393939373637383D3E4143403C3C3F3C413E3D3A373B37
374239393E473C3C4142576483B3C8D5DBDFDCDBD0CABBBBA9A688816B685648443E3A3C
3D3A3737393D3A3B39373D3E3E39383A363B47454E5357715A5A4B4D474542424343413E
403C3F3C393D3A383B3A3C3D3B3B3C3A43433E3E3C393D3B413D393C3B3D3B3B3B3B3B3A
3B3C3C3C393A393B3C3C3F41464448414542464150545761666873798A92A0AEAEB3ACB1
A8B7ADB3AAB6B7BDBBC7D1D2D3CED4D1D3D1CDD7C6D3DAE4DEE4E8E6E1DDDBD9CAC8BBB6
AAACA6A69AA6A0C5C1D4D7E2DFD7E2E1CEE0D9D2D3D4CBCCBCB3ACAAAA9A9192877A776C
545D5A635D7573716E757D99A1B0ADB1B7ACA9A69A99AFC5CDDED9DFD9DEDCE0E0E1E6DE
DED1CCC3CFD1DEDAD9CAC3B3B9B9C8AFC2AEB6B4
4C4C4B48484A49454E4E4C4946454648454647494A4B4B4B424B474A4447414842454644
43424346494646424B4C51504E53504E4E5558474A4843414246484C494E5D6C71695950
56484C4C4D424A4648424940535B71615F5C4F4C4C555C514F5E6B79716E6C86978894B3
B1937D6E665656555861656CA2A5AAAEB5BFC1C0C8C5CB9FBE9AA5A1AD9CAAA3BDACC8C0
BAAF967D84A1AEAF949575906B897495A0BEB4C8CAC1CC9D5F4E45473B473B404B4D4644
46413F4540454A4A474341403F3D393C3A3A403A3B39363A5F6840333A3D3E3A383B3E3E
3A3C38373B3A373941403E3B39383735393C3F3F3D3A3A3C403C3839393736363E3A3B3F
403C39383E3F3F3D3B393C40453E3F423E3B3C3C3F43413F403C383A383837383C3C3A38
4144433F3A3A3B3B383F3D38393B3A3B3D3E3B3B3E3B383D403D3C3E3D3C3C3F4E494340
3F3D3A37433D3A3A3A3A3D4246423F41413E3D3D413C3A3A39383D444C4A41423B434348
3E3B3E383539393F3E4042403D3B3A3A3B3D403F3D41423B3D3E3E3D3C3D3E403B3D3D3C
3D4042413F3B3E4441383539413E3B393A3B3A383B3740453D3D413A373B404242413E3C
3B40454847433C373337343737353A393D3939383A43463A3D3A383B3F3F3A343D45443F
413F3B3D3A3C3D3A3839393538393B3C3C3B39383D3D3C3C3A37373A3737373737363636
3A3A3D3B35363A394038383A393E413B3E413F39393C3C3B3B38373939393C403C3B3B3C
3C3B39383E3E3D3C3C3D3D3E403F4042403C38373B35363D3B3836363E3C39393A3A3836
3737383A3B3A37333D4749413B3C3A373F3F3F3D3D3D3D3C3B3B3A3A39393A3B3A383739
3C3D3C3A323934363B383B3C3A3B3B3B39393A3B3E3B3D423F38373C41464344403B3E3B
4249403F3B3F3940445E99AFC4D9C4BFC1B3BC91A26F7C65605A56454A3A48433E3E3D3C
3D3D3C3A3E3B3737393939373C3D3F444350655B7E646449514A5B484644434342413E3B
3E393E3F3C3D3C353A3A3C3C39393A3A40403D3A383739393833313B383C3A3C403F3C37
373B3E3F3E424046505C666377747A777A757770979EA7B4C0CAD2D5DBD9E5E4DED2CBC1
D0D6D3D1CCCECCCAD7DBDDDDDEDDDCD7BBB099A595AFB2BED2D9DDDCDCDEDEDCE1E2DADA
D0C9AD996B5A59627579877D9194C3C7D2CFDADBDDE2D8DBD5DAD7DFD8CFCBCAC2BFC1BE
9B9B99867D74736B75797A868280757490919B9D8B7A7A808FA0BBC0DAD3D7CDC9C6CDD2
E2DDD5C6C3CACEDFCCDBD3CCA9A68A947E978DB2
50514F4C4D4F4F4C4E4E4C4A4848494B4B4B4A4948474646445052564F4C454B4A494746
474B4D4A4B4E41504050464C4748464946464D46494C52514E4848464846454C514F4E4D
524B4C484D4C4B444E5C69636D67715E504B4B5B5C746D6B5758554F474A4B636C64758A
89765E525B4C4D483E40474A4856677D92A1A9A7AEC0B1BBA8BBB3C6BBB6A5B6818D9DB4
BAB0A89EA3BEC7B3986D7B62868BABBED3CDD8D6D0D2CBC8AA9985555043403C4045413A
3F413B3C404141403D3C4044403E3A3E3C3B423B40403C3B3C3A393C393C3C39393B3C3B
393B38373B3A373A404446403936383B373B3E3E3C3B3B3C423D3A3B3B3736383A383A41
443F3C3E4041423F3B3B3F413D36373C3A393E403B3F3D3B3C3935383B39393A3B3C3C3A
383D3F3B383A3D3D3E45433D3E3F3E403A3B393B3E3B3B42423E3C3D3E3D3E414B46413E
3F3F3D3B443F3B3A3A3B3E423F3B3A3C3D3C3D3F3F3A393938363A404749454A42453E3E
3E383835393F3C3F3C3D3E3F3F3D3C3C3A3B40403C3F40383C3D3C3B3A3B3D403A3C3C3A
3B3E3F3D3C393D43403734393E3C3A393A3A3A393B3741453C3E433B4744424140403F40
3E42403C3D423F37373B3839373438373A3638383A4444373838393B3D3C39363E3E3A3A
3E3934393D40403C3B3A373438383838383737373C3A3A3C3B383A3F373736363638393B
403D3E3D36363B3C3E393C3C37393C383B3C3C38383C3D3A353334363737383C403F3E3F
403F3C3A3F3F3F3E3D3C3B3A3D39393B3A3736393B3636393D3D4042403933353A3E3B37
393B3D3C3A393A3B384247413C3E3F3C403F3F3F3E3D3C3C3C3D3D3D3D3D3E3E3B3A3839
3D3E3C3A3D403737393537383B3B3B3A39393B3D3C383A414039393F393D3A3D3C373A38
484843473C3D42566A82AFABA7AC969776735F594C44464140453642343B3B433B3C3C3B
3C3E3F3D393737383A3C3836424E565B5C6C7A6568716B6B393E383C3E3C3A393A3B3C3C
3F38373936373C373D3E3D3A3838393B3C3C3E3B3938383A34333541363835363139434E
5C6C757874858B94A4B9CBC8D4CED4CECBC1C2BAC3C4C7C9D1DCE1E4E8E5EFEBE9DFE3D7
DEDFE3DFDFDEDDD9DFE0E1E1E1E0D5CCB4A588948AA7A8B3B5B3B5BBC5CED5DAD7DBD9E1
DFDEC6B3946E675D6168726564586963756E8DA8B4D3DAD5D5E1DDDFE0DEE3E5E2E4E7E9
E5E2DFD1CABBB7B4B3ACACA29D8A827B85899DB1B2A28D7B7A8C88A7A7C7B7BEB5B1B5B8
CDD5DDD7D9CBD3BEBBB4C6B9BAA7AD85937F9DB5
4E4F4D4A4B4E4F4C4D4F51514F4E4D4D4949484848494A4B474945494B4C494E46434346
484B4A444E4B444A3F494A514D4C4A4E4B4C595A54555E5A544C4E4B4B49444849454644
47474A454F55504C4A574F4B52586154503F434643555155504D565357594F545053676D
6F746F73614B513D463D555153667788949CA6A7AEA7AF888E778D8CB5ACCFCAC89BA68B
867F7F858596A0815F4C586C6D9BA1C6B4A296ABB3AAB4B8C2C8C290906A583A403E3E3B
434A423E4141424341404246413F3B3F3D3D433D383C3A3C39383F3C3A3C3B393A3C3B38
3D403E3D41403E413D3937383A393634363A3D3C3B3C3C3C3F3B3A3E3D393A3E3F3F3E41
423C383B3E4044433F3F403D423C3D3E3B3B3F3E393E3C393A38363B3E3B3C3C3A3B3D3C
393F413C3A3D403F393D3B383B3B3A3C3839383C403B3B433E3C3D41413F3E3F44403C3A
3B3C3C3B3E3D3C3B3A3A3C3E3E3A383A3B3A3C40403F3E3D3C3C3E424547444943474142
3D373A3B4247403E3C3A3B3F403F3E3E403E44453E3E3E363C3C3B3A393A3C3F373A3A39
3A3D3E3C37373A3F3D38383D3A3A3A39393A3B3B3A383D3E3A404642564C403A383A3E43
4845403D3D40403D3E423F403D393E3C393C3E3B3A3F3E3638393A3938383A3C3F393539
3D3A383C3F44423D3E3D39383A3A3939393A3A3B3E3A393C3B38393E39393838393B3D3F
3E3B3E3E39393E3F38383C3C37373A3B36353738383D403C3B38383B3C3A393B3C3A3939
3B3B39373A3B3C3D3D3D3C3B39373A3F3E39383A3D40413D433D3939403832343B3F3B36
3A3D3E3C39393C3F363C423E37393C393E3C3D3E3E3C3B3C3F3E3E3E3E3E3D3C383C3D3B
3A3735393C4037373B393C3D3B3B3A393737393B413C3C41413B3A3F44453F42403A3C39
3D3B3A4640424F6A858E9A88786C514A5152434A3D3F3F3B403A3B374336403A3D3D3C3B
3C3C3B39363539373A444B55737B7C746D767762704A4237443440393B3C3E3F40403F3E
403E3B3E3C383A373F403C393938383B3C3C413F3C3C3A3D3E3C39412F393D4251627B92
ABC1CDCEC7DBDAD6D0D1DCD5C8BBBCB3AEA8B3B1B0B0B8BECCDDE4EBF0EFEFECE6E1E5DC
E1DDE6E2E4E4E4E1E0E3E6E7E3E7DCD8D4D0C5D1CAD6D0D5DED8D6DBDFDEDEE0DBDAD1D3
CFD9D6D6CFBEB4BA9BB1A8AB8B73534A473F516A7FA8D0DAE0E0D5D3D9D2D3D2D3D8DAE0
E1E4DAE7E2E9DDE2E7DEDFD2D1BCB9B29EA2B3CAD5D5CCBFC7BACAA5C0ABC6CACED1D3C3
C2C3D0D3CDCCCCCCAEA4938398AAAABDA5B7A8B2
5252504D4E51514F494B4D4D4B4949484F4D4B48474849494947454D595B575848444950
5152524D59545C5A5B55616268665F5A504C524C534E524C4A464E4B4949444A4A444846
4A4B4C454A4E495043584E66758A897D6F4F574459565D4C5A4B564A4C4843464445574C
424C484A4844414945555A58535E5F605C5A63626D756A6C596460696B8AA0B2A0ABB9BF
C7B5947F6669887D948AA4908A808399976D5649505A59708EB0A4B1A3AA8A70614C4440
43473F3D3B3C3F44443F3D3D403E3A3F3D3D443E3C42413D3C403E343D3E3C3A3B3E3C39
383C3B3B3F3E3C3F473D394046443E3B383B3C3A3A3C3D3B3C3A3C403E393A403C3E3B3B
3E3C3B403E3F43433E41423C434142413C3D3E393A3F3E3B3C3A3B423E3C3F3F39393D3C
464A49403B3C3C383E3F3C3C403F3D4138393B40423A373F3B3B3C40403D3C3E45423E3C
3B3B3C3D3C3D3C3B39393C3F403D3B3C3B3A3B3E3E403F3C3C404445504E44433A3E3B3E
3B373C3E43473F3E3E3B3B3F413E3C3C47424A4E4441423C3C3C3B3938393C3F393B3C39
393B3B3935383B3C3B3A3C40383A3B3B39393B3D393A3A3A3B4144424F463D3A3A3A3B3D
3E3C3B3C3A36373A373C3A3C3A363C3B353B3B393E43413D393A3B3A38383A3D3D39393B
3B3C3F3E3B413E3A3D3D3A3A3C3B3B3C3D3E3F403F39363A3A36363B39383838393A3C3D
3A383D413C3A3D3E3F403D3A3835343738323539393B3E3C3E3A393C3E3D3B3C3D3A3839
3C3D3C3A3839393A3B3C3C3D3936373C3B383B423D4C4F4751463B383D3936373B3B3835
39393939393A3B3D3A3A3D3B333337353B393A3D3D3A3A3C3E3C39393A3B39383C424240
413C393D3E42393A3E3B3B3A4343413E3C3B3C3E433E3D3F3E3B3A3E44423A3D3C363633
3B3E3A46494D536D71736653494240423B3B3B433F41413A393C34403C3F3B393A38373A
3C3D3D3D39363A383D4C55626D6A65554E514B433D3C3947373733403C3C3B3A3A3A3B3B
353B384041393A3A3D3E3A383B3A383B3D3C433F3C3D393E3A3A39483F5B6971949FA9AF
B9C4C8C5C3CBC0BCB4ABB6B2B8B0BBBDBFC1D5D7E3DDE1DFE1E4DFE4E3EBE5EAE0E3E4E0
DBD7E4E3E3E4E0DEE3E3E4E2DBE2D7D8C5C4C4CCD2DAE2EAE9E8E8EAE8E2DCDAD7CEBFC4
C5CFCCCDD9D4E6D8E3D2DDD6C3B58E7C6F575A4F556295B4CED5DAD9B9AEADACAFB6BAC6
D8D8DED4E6DFE4E1DFDFDDE0D6C8B6AEB4B7C1CACDD2D8D7D1D4C6C5A9B1AAC6D2DFE7D2
C9C0C2BBAAA3B1A7A28883718596C1CFE1D2D1B4
575653505053535150504E4C4A4A4B4D4A494847484B4E51454B5667746D5E57544B4A4B
47484D4E49535B715C5E51524D514E4C47484B3D50484D484A464C454D4E484D4B434745
494A504F5760657B677B5E6D65756D67604E76628F768C697E6C7E695F4A474B4D506A5A
454B44414547524749404C444A50494845424A4543494D464C464645486C8B87989EB6B2
B7BCA896694C605765829BBCAEC0ADCCB3A5815F4F494B544F657A84B2B8CEAEB1877166
5E5950513F3C3D40413E3C3E3E3D3A3E3D3D443E3B3F423838403C3941403D3A3C3F3E3A
373C3D3D41403D40403D40444138383F3A3C3B38393C3C393D3B3E423E36373E3D3F3A36
3A3B3C42413F403E3A40443E34363B3B383C3D36393E3D3A3A3A3D453D3C414139383C3A
3A40413B3B40423F3F3D393B3F3B383D393B3D434439333A3C3A3A3C3B3A3C403C3B3836
36373A3C40403D39373940453B39393B3B393A3D36393834343B414142423A3C353B383B
3A383D3C3E423D3F413D3C3F413D3A3A3C363F463D383B363C3C3B39383A3D3F3E403F3B
39393834383B3D3B393A3D3F383B3D3C3A393C3F373C3C3B3F423F3B3C393A41433E3734
34393F3F3B37383B343A393C3A383E3F3E413A3742473F38393B3D3E3D3B3A3938383B39
33393E39353B3835393A38393738393A3B3C3D3E3E363338393535393636363737373737
38373E433E393A3A3D3F39353B3A383D3C34363C3A393B3938333135393938393C393738
3B3E3D3B3E3D3B39383838383E373439414D6276767C6846493C36393537393B3B3A3938
3B3937393C3E3D3B3835393A333439393836383C3D3A393C3A363333363838363B3E3B3C
42413A3A353B363B424041404443413D393838393B39383A3C3C3E41413D363D403C3F3D
3A453E4A5A626078464D403E403C4140423C383B333838343A3F3F3F3F373C383D373335
3737383A39353B3C424A4649423D3F3A3C40393C3A424438393A3D39393A3B3C3B3B3A3A
393F373B3E35383D3A3C39383D3C383A3D3B423C383A363C4148506A6A8D9A9D9A978B7A
72747471726E5E6C777B8F93A5A8C5D4D9D6E0DCE4DBDEDBDBDDD9E0D9E7DBE5D6DBD6D4
D2D1E3E9E7E8E1DEDEDEE0E1DDE8D9D8D5D3DBDFEBE7EAEBEFF1F0EBE4DFDDDDC2BEB6BE
BDC7CBD6D2DDD0D8D8D7CECEBEBDAE96A087A2809C7D8F94ABBACCC0CEC5C7C2BDBAB6C3
BBCAC8C6C6D1D1D6CACDC2D2BFC3ADADABAFBAC1C0C3C5C0CBB5B39AA498A4B3CFDEECE1
E2DBD1BBBAA79986786A6B6B6F88ACD8DBE1E4D6
4D4D515656514E4E4F4C4A4B4E504E4C4B4A4A4A4846484C4E5F535D58434D494E4E4743
4647484E474B4E4E4B484748474747464444454640454A4B4946464644554B4B4E494D44
464652537661745E564C484C4C494E595658556F71716866586562735B57637D5B767071
625E58434A4641453D4A4F515251484848454740424443444644464F42435353637B7E8C
868B8C8568504D4645567EA4C5DAD3D1D6C4C08A7D7E8178767891BABAC1BCBEA2A5ADC0
BFAA8CA07342453E48413C3D3D433E3A413D4344434B473D3C3E3E3E3A413E38393A3B40
403C3B3D3D3B3E433A3C3C39393B3C3A3A3D3D3B3C4142413A3F4545413D3C3C3D383C38
393F3C4139373A3E3C3E403C3E393F3C3B3C373F3F3C3F3835393C443E3F3F3F3D3B3938
443B3B3F3D3D403F3B3F3E3E423E37373D45423B3B3A393C3A4447423E41413D413A3A3B
393D413E3F413C3A3F3F3D423B363941413B383B373A3E3E3C3B3B3C363F3E3A3C3C393A
3C38393F403D3E433C3C4045443F3A39353C4549484441403F3935373A3C4045383A3B3B
3938393A3D3D3C3C3D3D3E3E3C433D413F41383C3D3C3B3C3D3E3D3C3E403B3C3A373A38
384045433D3A393839393838393B3D3E3737393D40424140363D3B373A3C38373A3C4339
404A3A3C37383B3E3C38383C38393A3D3F3F3E3C3C3B393A3A3A3A393A3934353C3A3840
3633383C393A41453E3C3C3C3B3737393C3F36353739413C37393A3B3B3B3C3E3C3E3B3B
41403B3B38384833343C3D41444C3C496A84A2AD947052343C353F3C3735363B3D3C3A3B
3C3E3F3C3937383B35363738383939393E37353A3C38383C37353737383E403B3F3A3739
3C3E4044393A3C3F41413E3C3E3D3B3B3D3E3F3E3D403940403F353B443F434346494344
42494B64685A5741423F3F403E3B3D423D3B3D41423F3B3B3F4142413F3C3A3A3537403A
393D36373D3B3B393E3E353B3B3C3A373B4348473C3D3E3D3D3D3F413E3C3C3E3E3B3B3D
3E3C3E423B4037433A363D3538423C393B3F3D3F3A3F54566F7A93888D87817B60685056
454849484C525B6D799F9CB3BCCDCEDBCEDAD9CDCBD0D1D2D5D2D1D9D8DDD7D8D7D6D8D2
DBDEE4E4E4DDD9D5D5D8D4E2D5DED6E0DEE5E6EBE4EAEBF2ECEAEBE3E2E6E1DFE1E8E5E1
E1E1DDDEE0DCE5DEDECDD0B6A89D928E9098A0A299B29AB5A3C8B3C9C5C7C2B8B4A8B7B9
C3D3CFD2D1CBC6BEBDB7A89DA78F998F909398A9A5A39EA39EAA9AA49BBCC0DBDADFE2E9
E4E6E5DED9D6CCBBB1A28C737871A5A2CECCE4D4
5051555C5D5B595A4F4D4B4C4F504E4C4C4A4A4B4947484C4951444D50454D4A474B4A4A
4F4F4E514A4D504F4D4A49494748484848484A4C45484A4A4847484B50625D61645D5E52
4B53555559444C404245494C4F57646E645E5A5D62524F45414C485B4B4A50605B757C92
97917C594C4944483E464747404542484A45454447463F434946464844464C4449524954
46555F747D78725C4A556B7D8DA7B6C9CAC5D3BEBDBDB1A08D8CA6BFC3BCB7AEAEA5C3D4
A690909FB98467513B3F3E483C45383F3B4241463C3C3C3B3C41413D3C3D3935393F4243
3F3D3C3D3E3D3E3F3F403E3A3A3C3D3C383B3B39393D3E3C3E4042413F3C3C3D3C383C39
393E3B3F37383D3E38383D3C3C383C3B3A3B384038383E3B393C3A3E414142424241403F
423C3C3D3A3A3D3B3B3D3B3A3F3D383A3D44433D3D3C3A3D393E3C3C43423B3A3F3A3B3C
393B3E3A3D3F3C3A3E3C3A3D3A38383D403A373B3A3C3F3F3C3A3B3C3F443F3838383739
3E3A3A3F3F3B3C413E3E4043413C393A3A3C3F434443403D3E3936383A3B3E433C3C3B3A
39393A3B3B3B3B3B3C3D3F3F353D3A403E413A3F3C3A39393A3A39373A3D393B3B383C39
3B4145413C3B3B3C3C3B3A39393B3C3D363636373A3E40423B3F3C383A3A38393A3B4238
3E473A3C3535393D3D3B3C3F3838393C3E3E3D3B36393C3A363436393838393D413E3A3C
3C373A3C38393E413D3A393A3A37373A3B3F383839393E38383A3C3C3B3B3C3D343A3834
3B403D3A3D383E3A3C453E4A5555645C7AA299A696776044493B3E373F3B3A3D3F3E3D3D
37393A3A39383A3B393A3A3B3B3C3D3F3D37373C3D39373A373537393A40423C3B38383B
3D3C3C3D3C3C3D3F41403E3C393B3D3D3D3E414448463D413E413C43403F4545494F4A4A
504F4A524D444A413B3B3F43423F3F413A393D4345423E3D393D4446423F3C393A3A403A
393E393A393C40393A3B373E3E3E3C3A3B3F403E3A3B3C3B3A393A3B3735363A3B39393B
3B3342364036393C3E3D3B3A383A3D463E464D5E6E849691A3969565624E4E423D463A42
3C5059638994A1B8C2D7C9D2C6C2CFC5D0B7B8A49D9B9DA7A8A1B1D2D3DCDEE3E7E8EEEA
DAE1E3EDE7E9E0DFDCDFD6DBCDD3CFDCDED7E0D2E8DCE3D4DEDDE0DCDCE0D9D7CADBD1E2
D3E3D2D8CBCDC8D1BCBEB9AEA7A49F9C9D9C9B9BA69EBCA8D6BCD4CBD3D4D3C8BEA9ABA2
B0CCCBE3D7DFD8DED2D9C2D1C8C7C2C3C0BAB6BDBDBDBBBFC4BCCFB8CEC3DFDBE7E0EDE2
E4E5E5E1DCDFD8DAD1D1BCAE8B9089AD9DCCCBD6
5051535656524F4E49484647494A48464644444644424346484B414549434544464A4A4A
4D4A454747494A4A49464443414344444546484A4B4B4A4846474B4E575E514E4F505955
3C48454D47424A494B52534D4D565E5E5D6056635E5F554F44473E4B444C4F587C796667
6F72705C5656565E59605F604D514A4C4D4343484D4E42464942444340474A4855625A6A
57666166717C8A84645A4F4F51697688A9AEC6CBCFD0BEB2ADAAA2B5ABC3CBD4C2B1C0B6
6D5A65679389837950543F343C3D353A3F3B3B3A3E393A3B3A3E3F3943413F3D3E413E38
3E3E3E3D3F403E3B40403D38373A3B3A383A3B3A3A3C3B3A42413F3D3C3B3C3D3B393C3A
3A3C393C3B393C3D38393C3B3C383B3A3939383E3A373936373C3C414040403F3F3F3F3F
3C3B3C3B383A3E3B3B3B38373B3C3A3C3C4243403F3E3C3D3A403F444E473A3C3D3B3D3D
39393A383B3E3C3B3C3A37393F3F3C3E443F3B403D3F41403D3A3B3C3E43413D3C393535
3E3A3A3E3F3C3D41403F3F3F3C38383B3F3D3B3C3F403D3A3C3A393A3A3A3C40413E3B38
383A3B3C3A393A3A3B3D3E3F393F3B3E393C373D3C3A3938383836353639363A3B3A3E3C
3A4144423E3D3C3B3D3D3B3A3A3A3B3C3F3E3C393838383941413B383A37363B393A4038
3B43393B39393B3D3D3A3A3C3838393B3D3D3C3A3D40423F3936363739373B40403E3C38
3E383A3C39393D3E3B3837393938383B3B3D393A3B3A3B363637383837363738393D3B37
3B3D3D404A504D5A5060475559716266829AACA0967D6A51524648423F3A373B3E3E3D3D
3B3C3D3D3B3A39383C3C3C3B3A3C3F423F3A373A3B38383C3836383A3B41433C3D3D3F45
46423E3D3F3E3E3F403F3E3C3C4042403C3A3D40403F3C443E423E3E494A4E4A4D565352
54473D3E3E40413B42424343403A373739383C4244403C3B3B3B42443D3D413E3C3A3C38
383D3B3B3C3C3C353A413B3B3E3E3D3B3C3D3B373C3D3D3C393838383C3A3B3F3F3C3C3E
443E3E3D383C3B4136413744454764839AA0A7B9BFBDB19F695D5842433F403B3A434453
6290A6B5D4D5CDD0CAC6AFAC958F7B8B7B87737E728796999CAAC4DEDEE3E3E0E2DCE0D8
E3DEE4DBE4DBE2DEDCE1D5D3C8C8C5D2CCD2B9CAB5D6CDDADAD7D9D3D1D3CBCAD1D1D8C5
D3C4CBC7CCBECDBECEB3C4AFC2C8C4C0C1BDBABFB4B6AACEBED9CAD3D6D6DFE0E0D6DCD1
D3D5DAD6E2D1D2CDD3C8C9ADC8A7C4BCC2BCBEC7D6D7D8D8CFEACFE4D0E8CEE3E0E9D9E7
DAE0E5DDE0D9DCD1DACBC9BEC1AEB5B1C9BFC9B2
50515456565452524E4C4C4C4E4E4C4B4B49494B4A47484A424848484A47454A5254504D
4D4A46484B4C4D4D4D4C4A4949494A4A4A4A4C4E4C4A484543454A4E53554A4646464C47
47484145484952514E514E4A4C53524A52515E576D585E4C48494046424D4E525558575B
686B767065686A797A84868B6C69585558545B665F696568634E4843464E484650564653
57656053535D73867A6F59504146454E606A8299A3B5B6C2C7C2C7BBC0BDD3CFCFD0CBBC
988B786A524F5661566358453D38505877575D51514D443E4045433B413F3E3E40454640
3E403F3E40433F383E3F3D39383B3B3A3B3C3E3E3F3F3E3D43403C3B3B3B3C3B3B3A3C3B
3B3B3939413A393B3B3F3F393C3B3D3E3C39373B3C373835383F3E42403F3D3B3B3B3C3C
3C3F403B383B3D3A3C3B38383A3B3B3C3A3E4141403E3C3C383F404143403D403D3D3D3C
39383A3B3C3E3D3C3C3A3A3B40423C3C44423D413E4143433F3B3A3A3B3E3F3E3E3C3938
3A38383C3E3E40443E3D3D3D3A37383C403E3B3A3B3C3B3A3B3C3C3C3B3A3C3E433F3B39
3A3B3C3B38393A3B3C3C3C3C40443F40373B393E3D3C3A3A3A393836353835383A393F3E
3D40413D3B3C3E3D3C3C3B3A3A3A3B3B3B3C3E3E3D3C3B3A403E39393B36343B39393E37
383E393B3A3A3B3B3A3938383939393B3D3D3C3B383939373737342F3C36383B383A3C38
3A35383D3B3A3C3B3B38383B3B39383A3A3B3A3B3C3B3B383E3E3D3B3A3A3C3E3A393738
393741557E7D8B5960424E536E807E717B877E7568594D3C3E373A363A36353B3F3F3E3E
3A3A3A3A393735333A3A3A3837393D41433C38373736393E3B383939393E403A393A3F45
46413C3B3F3E3D3D3E3E3D3C404242403B38393B403C3A413A434443595E66605E60544B
403A41403C3E3B39403F3E3D3B3939393B393B3F403C38373B393F41393A413F3A383736
383A39393D3B393239453E383C3C3C3C3D3D3B3940403F3D3B3A3B3C39383A3D3E3C3B3D
393B39453941383841474869A5A4C4C7DBD0C5C5A8805846403A39413F4545475F7D96AD
B1C7CECDC8B6937C6D625859514C474B4C50485A618AAAAFB7CEDDDEDEE7D9E5D8DED1CB
CBCEC4CDBFC7BBBECEDAD7DEE3E3E4EADCBBBDA4CFBDD1C2C7C5C9C9CDD4D2D5D3DFC4D6
B7CEBACABDBDABCEBDCCB7AFACBABDBFCBCED1DFDECDDCC9E0C9D9CED7CFD4D2D4D2DBD3
D2DECFEAD8E7D4E1CAD1A8B58F9A89987F7D848EA7ACB4B8CDC8DACAD0BFD5C7DBCEE4D2
DDE0E0DFE1DBCAD0C1C8BFC5C2CAB5DEC6DECCCA
4D4E4F4E4E4D4B49484848484948474547444446464443454C50504A49474146484A4643
4544424544444546474645454647464543424344494745424244484B474946464543433B
574E4C414D424B42434445484D4F4D4949514E5B58574C424247474A44494445565E6964
6452564F45474551515959615C57484D5C687B889F9E8C7E6C534947454E454951533F4A
46484840414343504C4942484446454940444B5C5E6A6E817E9295A69BA9AFAFA3A9A6BC
CED2BDB78A583D3F504B4936463A4F5B79678895828B7E6C6D6E67644B47403939404544
3E40403E41433F383D3F3F3D3C3E3E3B3C3C3E4041414141413E3C3B3C3C3B393A3C3B3C
3C3A39373F3837393A3E3F39393B3D41403B3B3C3A373C3D40433D3E3F3E3C3B3B3C3D3E
4146443E3B3B3A383E3B3B3B3B3C3C3A3B3B3E403E3C3C3B3E3D3D3937424B483E3F3D3B
3A3A3C3F3F3F3F3E3C3D3F413A3C38363D3F3B3C3D414444413C3A39413D3A39393C4042
3A38383B3D3D40433B3A3B3C3B38393C3D3E3E3D3A393A3B3B3D3F3E3C3C3D3E413E3C3B
3C3C3B3938393B3D3D3B3937363A3A3E353836393D3C3A3A3B3B3938393A35383939403F
41413C36363B40423A3A39393A3A3B3B3A3B3D3E3E3D3B3A3B3A38393C37343A3A393C38
373B39393436383838393A3B3C3B3B3C3E3E3D3C393C3D3C3E41403B3E38383935393D38
3733383E3C3A3A383D3A3A3D3E3B38383A3838393B3C3B3C413F3C3937393D403A393636
3A435C7B968C78565056677B829189776D6051494541413A3F3A3A343C393A404443403F
38393A3C3C3C3A393939383736383C3F403C39383736393D3A373837353C403C38393E44
45413E3E3D3B3A3A3C3D3D3C3E3D3C3C3C3B3B3B413D3C47485D6A6F807D7763554F3F35
3B384644404138353B3B3A39393A3B3A3F3B3B3D3E3B393A36373F423C3A3B3839383639
3A3A3A383A3B3E36363F3E3C3D3B3A3B3D3D3C3C41403F3C3B3B3E403534363B3D3C3D3F
413B454049414A3E5F8E8ECBCCD1C5C99D856963524B4451685C76658A81A79FBCC7C4CB
BDAD90665C564B44463E3C3F3F44454B567589ABB0C2D4DBDDE3E4E0DED1D1B4C3A4A990
8B868F899D9FB2B5C3CED1DAE6DEDBD3C3C5AECBA7B5A2B89C9EACB7C6D4D7DEDCD7DCC0
C8ABAFAAB4A5B1ABC7ABB39CA2B3BAC1CED0D2E0D9E6DEEBDFECDFE2E1D6D8D0D2D1D6D1
CAC5D1CCDECAC3BCCDC1C8A9C4A9C9CBCECCC8BBB9A2959094B5A2B0A8B2A7BAB7BEA7B4
A3A9ACA2ACA1A9A6BBB9CBCFD3CBD4CADDCCE1D5
535453504D4C49464D4E4E4F4E4D4B4A4C49494C4D4A494A494A4743494C4A4C464A4948
4C4A464848494A4B4A4A4A4A4C4C4B4946454546464544424345484A4E4A4849484B4D48
47424C3F4B3C453F4143484B4944444846444B4857484F4442464A48414340454648554B
585264644F4D43474344414B4747455264768B9192826B5C5C616977677D828F8675514F
4B434040494D484B46413D42453F424149484552504E4750647B9AA4B9ACBAA89A8D8FB8
C0B9AFACA0795F63877E816D5B50414D3F425C7C82ACC2C1BFAD98988B877563594D3F39
40403F3F4142403C393C3D3B3B3D3C393B3A3B3E403F40423D3C3C3D3E3D3B393A3D3A3D
3C393B383736393A36373C3B35393A42423D40403E3A3F3E40433E3F3B3A3939393A3C3D
3D41403D3E3E3D3E3E3B3B3D3B3C3C393D3A3C3E3C3B3C3C3D393B3C3D4C53443F403C39
3B3B3C40403F41403C3D42433B3B3A393D43423C3B3F4344403C3A3A413B3A3C3B3D4040
3E3C3B3A3B3B3D3F3B38393B3C3A3A3C3A3D3F3E3A38393B3B3E3E3D3C3E3E3D3D3D3C3C
3C3B3A38383A3C3D3D3A37353B40434B41423C3B3C3B3A3A3A3A39383B3D37393A39403E
3C3D3D3C3D3F3F3C39393A3A3A3B3B3B3F3C393838383837363837393C3935393B393A39
373A3A3835393B38363639393D3C3C3C3E3F3E3D363D403B373839383D3C3C3C3B3D3C37
37353B403D3A39373E3B3A3E3F3C39383B3638383B3D3B3F3D3A37333133383C393D3936
41597790998277667271879288837C5A4A432F3C383839373A3A3A373B3A3C41413E3A3A
3A3B3C3C3B3A39393A3939393A3C3D3D393A3B3C3A38373836363837343B413F3B3C4044
454242443B3A39393B3C3C3B3F3C3A3A3B3D3D3C39434E626A7C7D7D716557423B403D3C
413A423F3E443E3A37393A3A3B3D3B38403C3B3E3F3E3E40383A3C3C3C3A3939393A383E
3F3B3D3B3C393D38373F3D3A3F3C3A3B3C3B3B3C3D3D3B3A393A3D3F3B39393B3C3A3A3C
3C34353F526F9095B4BBC8B3C5908F7563625F717C979BAC97ADA3C7B1DFD9D9C9C6A78B
6450523E3F3B3F39433D465252648B92B1B6CBD1E2E6E8E2DCDBD2C2B0AE8188677C6B6D
7D8990AAAFC7CCD7D6D6CFC6C3ABA5909773715D82779BA5B9BBCAD5E0E6E2E6DEECDAEE
D2E1CBDAD1DAC9E7D3E5D5D8D6DFE0DFE3E2E1EADFE8EBE3E4E1DFDBE4DFE4DDE3E0DFDE
DDDFCDE0D1DCB8B7ABB395A98FACA6C2C2CDD3D2D3C2B3B0A19EB69FB291B09AA7959F87
8B8B8A867D8387A4AEC4C8D3BBC5AECCBBE2DAE3
474A4A47474A4A4848494A4B4A4846454845454849464444494D47434647464642464545
47454143454748474443434544454543414142434846454446484B4D433F424646484741
3E4047444440424440424648443F424744453A4A44464142424045413C3E3F4944485E55
6A626B62524F44494749485551575C615E626B61655851495261667889A7B3BE9C794F49
45433B3E404248403F3C3D3E463A4A4D4244444E504942495B72809FB4BEC6BBB5A39BAF
A5ACB3A8A8B2A5ABC3C6CABD98967E8A66665D6356799BB2BBA78E89878C80787C6B4D40
413F3E3F404040423C3F3F3D3C3E3D3A3D3A3B3E3F3D3F423B3B3C3E3F3E3C3A3A3E3A3D
3D393D3938383D3E37373B3B373A3940403B4040423E403C3D403D403E3D3B3938383939
393B393A403E3C403C38393B393C3E3A423B3B3E3A3A3D3D3533373C3F4544373F403C39
3C3B393C3F3D41403A3B4040403D3F40404A4C403A3D40403E3C3C3D3C383C42413F3F3C
3F3E3B3A393B3C3D3E39373A3C3B3A3A393A3B3B3A3A3A3A3A3C3C3A3B3E3E3B3A3B3C3C
3B3A3939393A3B3C3B3A393835363840363A3633403E3C3C3C3B3A383B3E3A3D3D3B403E
383C404144443F393C3C3C3C3C3B3B3B3B3734363A3D3D3B353A39383B3B37383D39393B
393A3B36383D3F3A353537393D3C3B3C3D3E3D3C404748403A3C3C3A3A3E3D3B3D3E3936
38363C423D3B3D3D3E39383B3D3C3A3A3C3539393B3D393E3E3D3B3837383C3F363E3F45
5B758893969291947D75787E516347454232403B3D3C3A36383B3D3B39393B3E3C383637
383A3A38353333343938383B3E3E3D3A37393A3A3938383836383D3B35393E3D38393B3F
3E3C3C3F3D3B3B3B3C3C3B393D3C3B3A3B3D4143404F5766676A5A544A413D37383D3736
3B3C433E373D4244353738383C41413E3F3B3A3D3E3D3C3D3B3E39363C3C393E393B3940
403A3E3D40373B393A403C373D39383A3B3A393A3A3A3B3A39393A3B3B38373838363739
41536595A2C2CAC2A5AD94936A746A7E919EA4B3B3C3BBCAC5BED7C5D8B8C4A08E704D42
424E5745423C4C465E6E91B4AEBBBED5D1E1DEDCD6D3CDC0B1ADA699938989728D88ABA9
BBBDC7C2C6BDC2C1B0A5957D70586450617482AEB1CBCBDCE0DDE4E6E7E3D9D9D6DAE5E2
EBDEE2E6E2E3E6E0E8DEE6DFE6E7E6E4E4E3E3E6DEE0D9E0CED4C7C4BFC2CBC6D7DADDE7
DFE1E8DCDED8D1D3D6CFCEB6B59B9B9C9DA9A8AAADA89DA18EAC97BAB9D1C8D2CBCFC4CF
CAD3D7CFD0CED5D2D9CBC5BBBFBAC0A7B9BED6D7
5052524E4D4F4F4C494B4C4C4B494746494646494A4845453F4D4C4A4742454644474544
4848464A494B4C494543434543444444434345474A484646484B4F514A44494D4C4E4B44
484B454B3F49434A434241403F40414249463F4B49434142413F48474545434D4E4A563F
504650454E4E475359626677878E938B6F615D473E3B494A586A6D8594A7A39F76676173
5C645457525366546B5B524E5D4B5248494E4D4F4D434451444847526E6E7D6C8A948E94
99BBC4A7A8CFC7D9DBD9CBC0B3A991958FA0A1989D816A748D938B898C92868390805A4A
423E3D40403E4045484A484544454543403D3D3F3F3E3F423A3B3D3E3E3E3D3C3B3E393D
3D393E3A403D3F403D3D3E393C3E393E3D363D3C3E3D43414041393A484744403D3A3938
3D3C38393E3833383A353739373B3F3B453C3C3E393A3F3F3F3C3B3C3C3B3B3C3F403B39
3D3A36373D3C404039383C3B3F3A3F413F4B4F3F3A3C3E3D3B3B3D403D36394040404240
3D3C3A39393C3E3F413B36383B3B39393A3736373A3C3A38393A39383A3E3D39383A3B3B
3938393A3A3A3A3A3A3A3B3B3836343C353F4242454341403F3E3C3A3A3E3B40403D403D
40403E3C3F4444413F3F3F3E3D3C3B3A3F3C393B3F3F3A35363D3C383B3C39383E39383C
3A3B3C35343C403B36373C3E3D3B3A3A3C3C3C3B3E41403B3C42413B393F3A353A3B3636
37363C413E3E43463E3835373B3B3C3D3C353A3A3C3D373C3C3C3B3938393B3D3D444F67
889CA1A3B39EA6837B565F463C3F42343A41343B393C3C3A3B3D3A34393A3C3F3D393A3D
3F4142413E3E40433736363A3E3E3B36393A383634363A3D393D434037363A383C3C3E41
403D3D403F3E3D3C3D3C3A3835383A3B3C404950464E444341443A3B3E373A3C42443936
3C3C403D393D3F3B44423D37383C3D3B3D3A393B3B383636373F39394440373C373A373E
3D363D3D3D37403E383A393B3935363A3C3A393B393B3D3D3B3A39393B38383C3F414449
969EB3BFC0AB9F7A6B54554C62748996A6AFB1B6A2A7A0BCAEA191A185745D4B53423E41
4552574A58689DAAC4C2CCE2E0CBC9B6C5AEBBA2A8867579747694B6BFCBC5CDC5D1D8DE
DCE0DDD3BAA4918A6C65655F6B75A8A5BDBFC8CBDADADDD6DDD7DADBDBDAD3D6C8D6D7E4
D5CEBABEAEBAB4C7C9DBDAD8D4D5D9DBD8D4CEC9D7C2D5C4CBA8AB928B8E948BA0A8B0C4
CCD8DDE1DAE6D6DDD4DBD3DCCFD5C9D6C8D2C9C9C5BEAAABA1A2A6A4C7BDD4C3D1CED7D7
DADBD8CEC6C7C4C4BBB09D908B987B967DBDA8B9
5050504E4C4A4B4C44494D4C4A4A4845474A494545464643464848474544454642444646
4544444542454849494949494142434547484949464545474644474B44474A4A48464545
4243454747464443414141403F404345454546484643444741424846484F4E504443474E
5459616960535A66646E6D8A97ADA59489745E4E544E6662776F6B76677C707E685B5C6A
595E565657585E57685A505657594C544542484B454C524A5948725A73594F494C66747A
778990949697A5C5D2D3CDD2BDAD889695ACC9D3CEB6A98D7B725D63758DBCA3B696A87A
7450364A537E8F989FA9969E7E957C8B698344554B3C3E413A4734373E433D3B3C3D435E
583D3D383B3C3C3B393A3B3D3A3E3F3935383B3C3E3C3D403E3B3B3E393C3F3F3D3B3A3A
343B3B3E3B3538363738393B3B3B3A3A3A3F3A3C363E3B3B3E393B3C3A3C403F4044403C
40403C3B3C433F3B37373E3B3C3D3E3E3D3E41444146443C3A3A3A3A3C3C3C3B3938393B
383A424137363B3C3A3B3C3A37383C40373835383E3C393E39383737393A3A3A393D3F3C
3A393836393938393F433F38353E3E40424D584A40423F3E3D36343D3A3C3D3D3D3D3D3B
38393B404344403C39454C453A36393C3E40393D3E3A3E39363A3D3B3A3C3F40373D3E3A
37393A3A3836333132373C3F36383A3A393838393E41403C3A3D3F3E3833393B353B3F34
373A37373E3C38393A3943433F3A323A37383C3B36393C383A413E3A3C3638496774848D
8D8B8E9098836956463A393F363939373A3E3D38363A3C3D3B3A3C3E37393D3F3F3D3B3A
363B3E3C3836383C363A38383C3B383B34383C3B37363A3E3E3C48453A3A38383C3C3D3C
3C3C3C3C434A403B3C3B3E3C404033353A353B433D48423E3B33373E3A3B3936373B3C39
3A423C3842433C3E343C3B393B3A383B373E3E3D3E3A3538393D3E3A393B3C3B35373F46
463F3C3E3D3C3C3C3C3A383537383A3A3A383635363B2C3D363B3B403A3C393E415365A6
B1B19569574B4D473C564663618F89A67E86706666636C6666614D49473B3C3B413B3D4A
4D6072928CAFC6DAC8CEB6BFA29F7A7F5E5F51564E5E616A8891ABBBC8CBDAC4D0C8D1C1
C6BBB7A7A0999D9498ADB6C8C0D3D4DED5E1D8E6D9EAD2DDD9DCE1E0E1E1D8D0DAD6DDD7
CCB9AE9DA49FB9ADC7BAE0CED5DAE1E6DDE0D9DFD4DDD9DFD3CFD0D3BEB4A0918E8C909B
A4C3D8D7D3D1CDCBCDC8C3B5BFC8D7D7DAD6D7DADCDBD9DBD0D3CED2CFD9C7D1BFB0ACA7
A9C4BAB7A19B8D8392728368815B6863596F7D72
4C4D4D4C4B4A4A4A4B4F51504F4F4D4A494B4B48484A4A474A4A4A494847474840424344
4342424341434546454444444343434446494C4D4443464A4B4A4B4E4446494947454545
444444444546464745464645424040404040434749494B4F484A525051554F4E494A4F57
5C60656B5B50555B565D5B73718C8F8983736760665F6F5F6658535E4A56475747424651
5A5D544D46424C4C45494646444B424F403D42423C4249424E4A56737E8E5D493E474851
5464656554555772778685918C80637B7C9EB7C7C8C2CAC5BDB19996785A7C64736F9EBA
92724C4C5E90B7C2C5DDD0B3B19377857F797B68867166473F45404A4C4240433C3E3E4A
483C4040393939393A3D4145383C3F3F3E3F3E3D3A39393A3A38393D393B3D3E3D3B3938
383E3C3E3C383D3C393939393A3A3B3B3E3F383A39454240413E403F3B3D413E4345403A
3D3F3C3D3C3F3C3E3B373D3E3C3C3B39393A3E423C3C3E3E3F434645393B3C3A3A3B3D3D
3E3C3F3F3B3B3E3B3B3D3D3B39383B3E3C3A36373D3B383C3737383A3C3D3D3D363B3D3C
3B3D3D3B383A3938393D3D3A363C3A3A3A40483B3F403C3D403A363A3939353842403938
3D3B393A3D4142433D3F41414242403D343734393C3A3D393A404039383E413F383C3D3A
38393A393B3B393737373A3C3B3C3C3B3B3A3B3B393C3D3A3B3E3F3E3935393B373D4239
363B3B3A3D3D3C4137393C33343D3B3B363B413D383B3D373A3F3A39454F5D7382757477
767B7D736152433C38363A423636373B3E3E3C3B3637393B3D3E3D3C3C3B3A3939393B3C
383B3E40403E3D3C363A39383C3C3C403838383839393A3A383743423A3B393A3C3F4141
3D3A3A3B39413B3B3E3A3C3B353839383D4244493C3E3B42443D42473A3D3E3E3F41403D
353C393A44453C393C43403A3B3B393A3B3F3E3D3F3C383B3A3E3F3C3B3C3B393A393A3F
42413F3E393A3D3F403F3D3C3738393A393837362B3C3D323B373E3A3A3D4E4B7F94828B
5E514A42414C3C48586A877A91666A59414C413E4140443F3A3D3D3C3E3B3B4239383E4D
5772859F8C96B49A9D75685A5453464A4752575D61707175807B7F847F8B8492808D788E
7781929AB2C0D0D3D4DDDBE1DBE5E3E6E9E3EBDFEAE1E0E1DAD7D1C6BDBAB8B8AFADAAAA
A1A19F9D93A29DB1AFC7D3DEDFE0E3E7E1E8DFE4DBE1DDE1DEDDE0DEDFD9D2CBBC9F8D90
AEC3CFCDCFD2D0CEB9ABA2959B9BAAB1B3B2BDCED9DBD9DCC8BCC1B3C7C9D3D7D8D2CDB7
9CA2989B9D9B948D9C7F8E77967A897E827A745C
4E4E4F5050504F4E494B4C4A4A4C4B4748494A48494B4B494A4948484848474644464747
47464647454748484745454545454444464A4E51524E4B4B484341424446474746444444
44444445454647474A4B4D4D4A4644434342454C5154575A46474D49494C46444A4B4C4E
4C4846474F494D4B454B49595D6F7073756C676474696D595C4E434245493E5146464645
53544E4B4541484C516160595660566051535D605857564C564F4A4E576652454C484047
485049474847464D4C4D4D51554E48575D7286987F777F9DBECCBFADB5848C6B464D4365
4D4B453E4042606F8CC5B6CABBBD96B490A88E9D70856450483B3D4647373C3D43474440
3E3D3D3A3E3E3E3D3B3A3B3D3E3C3B3D3D393634403E3C3B3937393D393A3B3C3C3B3937
393D3A3C3A383F3F3B3B3A39393A3B3C46453D3C3E48443C383A3F3E3B4147444346403B
3E3F3C3C3839383F3D353A3D40403F3E3E3F4143443C3E413B3B3D373D40403B393B3C3A
423B393B3D3F3D373B3D3E3D3A393A3C3E3A36383D3B393B3E3E3F3E3C3A38373A3E3F3D
3C3C3C393B3D3D3937393C3D3C3D3B3B3A3B3F373E3C3A3C413E38383A3E3B3D453D353E
3B3B3A3C3E404142413C3A404647423E3D3D383A3B393C393F4542373640433D393B3B39
38393938393B3C3B393736373F3D3B3A3A3B3B3B383A39393A3D3D3C403B3D3C373C4038
3A40403D3A3739403A393C39393F3C3937373836363E413A3C413C3A47525C6863534E53
585F5C4D4A3F363537373A3F3A37383F403B393B373433363C4142413E3B38363637393A
3B3A3A3B3D3C39363C3F3D393B3A3A403C3936373B3C3A373C3B45433D3C38383E414240
3B393A3D3D433E403F3737383B3C463F3B433F3E44413E454642443E363A3D3E3F41403E
403D37353A3D3A3739413F37393E3F3D3C3D3B3A3D3D3A3C3C3E3F3F3E3E3B373C3D3D3C
3D3E3D3B3A3C3F40403D3A3938383838393939393E443341333E3A43447A837D805D5146
423B3840445D688881956C8A525A3D4139413F3B3C3C3A353A3C423A3B3F3A4346484C54
5464626B5F5A56484B4943454E55506051615052474F454545424248464342424D525687
B6C6D2CFDEDEDFDDE8E5DFDCDCDDD9D4CDC7B2C1A0B199A4938F867A6E666A707D75836C
88779090A7B5BDCCD6DDE1DFE5E4E3E5E1E9DFE0E4E4DBD5D6D4D8CFCBC9C7C6BCA9A1A8
B7BFBBB4B8C0C1C1BBACA6A0A1959DA79A969BADBDC2C7CCBDB3ADAAA9BBC5D0DDD7DAD8
CAC49B827977747A9896B1A8B7BEC6C8BBB7AFB1
4747484A4C4D4B484C4C4B484A4C4C48424344444546474745444242434342403F414242
4141414340414342414040404645454445484C4F514B4544444242444545454544444444
42434546464544423F41444543413F3F4844434648474748474546404047444546464646
43403F3F434246413D42424B414843474F4D5154646477757D6F58474A4740504645433B
41424751544E49464D5A544E515B4A504D505A5E5C6064605D5E56544F5552514F4B3F3F
3A44454A68676A5E5948443D3E3A4745494954625951506B8A9CA0917C566B4F4A5C4847
42434C46544345454262626F676C6D7B70828884898B958F9575695C5B4C51444746463E
383D3E393A3D424443403D3C473F393B3C3B3A3C39393939393A3C3F3B3A3A3B3D3C3937
3539363838363D3C3B3B3A3A3A3A3B3B40413D3A3C413C333A3D423F393D413D4145413E
40403A39373A393F3E373B3B3A3B3D3E3E3D3C3B413940463C383B363E42413C393C3C3A
3E3937383C3D3933393B3C3C3A39393A3B37363A3F3E3C3C3B3C3D3D3C3C3C3D3D40403D
3C3D3C394040403D3B3C3D3F3E3D3C3E3E3D3E3B3B3B3A3C3F3E3B3A3537383D3F383742
3A3A3B3D3F404040403D3D4244403E3F3D3B37373A3E434440434038383F413D3A3A3939
39393938383B3E3E3C3939393E3B3837383A3B3B3D3B3938393B3B3A4541413E383B3B34
3A3E3F3D3936373A36373D3D3B3D3B363832353E4448473F41453E393E42404043434143
49453C373D36323539393A3C3E3C3C3E3D3936373D3B3A3A3B3B39373B3A3A3A3A393635
3C393635363839393C403E3A3A38393F3F3B38383B3D3B393D3D44413D3C3536403F3E3B
39393C3F383D3A40423A3C413F3E4641393C3C393F3F3A3838434D4151504E4945424140
3D3B3A3938393834333C3B34353E3F39393937383B3B3A393D3D3E3F403F3C383A424641
3A3939393A3B3D3D3A3735343838383838393A3B3D3C42382F3E64718C9E666A50393E3F
4240455084778B6C7D6C544A3F35423E3A3E3F3A3A3D3B3B393B403A424B43474543444A
474E4243454B555A62665D605E505A4B4E413F393C413638373D3C454646464B636F84B4
C2CED6CACBC2BDB4AFA8A49C9E958F85886D735C5C444741414241484C51626E71817991
91B0B3CAD5D3D5DFDDE3E0D7DFDEDDDDD6DED3D4CCD1D0CAD0CBCCBCB5BEC8D1D7D9DADC
D6D4C6B8B9BDBDBEBEB4B6B6BAAEB5BEC3C1BEC6CDCDCCC6A89CA896A099B2B2BCB1AAA3
928D6C574E4F5666868B9A9094A3BFB5C4AFC1C4
4D4D4D505252504E4C4C4A47484C4B494848494A4B4B4C4D4A4947474848474545474747
464647494547484847474748444646464545474A48434244464647494544444444444343
434444434342414143454647464546464B474547484746474541413C3E47464746474645
4446494C4041453E3E424346454A444342404B54454D63686B5E4D3F59534C5247484A46
453F3E4143444449414540424850414750545B5E5F656967665364507D6683767C786250
3F46494E5D71768B7B826E6E5856505949564A5E4C4D4B565755584A51404B494557565F
838F9B82846D5C4E465A57654F4C413C4148455E648F6B90A5969A88918A896F52484640
373D443F4349535B616466675A4F45413F3B3A3B3B3D3E3D3C3C3D3D3C3B3B3C3D3D3B39
3438353939363B393A3B3B3C3C3C3B3B3C3E3E3C3E40403D3D3F44423B3D403C4144403C
3F3F3B3A39403F403F3D3F3A3B3B3B3B3C3C3B3B3B38454E423D423F383C3D3B3B3F4140
3B3B3A3A3B3A363436383A3A3A3939393B37383D3F3E3C3A3B3A3A393A3B3D3F393C3D3C
3D40403E413F3E3F403F3D3C3A38393B3D3C3A3B393B3D3C3B3C3E3F43383B4648494E50
3F3D3A393B3E40413D3D3F423F3A3B3F3A373636393E3F413E3C3B3B3B3C3D3E3A393939
393838383C3E3F3F3E3C3C3D3B393737393B3C3C403C3837383A3B3C3A3A3C3C3B3F3F39
36373B3E3D3C3C3C343E433B343E463E3C394658584E443E42433B34383E3E3D3B43433F
3E373338383534373B3B3A3A3D3F3E3A3839383632373D3F3F3C3A3A3A3A3C3E3E3C3733
3939393737393D40343939383B3A3C423E3D3C3B3B3B3D3E38383E3C3C3D3739413E3A39
3A3A3A383E44434B4F47484B423E3E4138343C3B3A3C3B3F47607B796F675A4D423A3737
3636383A393A3D3E353C3D35353C3B323837383A3B3C3B383C3B3B3E403F3D3C39424640
3A393B3B39393939383737363938383738393A3B373C412F477C977B70593A4336453335
476C628266695C504B3E3C3F3C3A3D383F40423E3B3D3D3D3D42433F444944454D433F4A
505E5B647E9493A98B95758154463F46353F363F3C3E393E414E4F5863626C5771576E6B
7D80877A736B6A5E5550514A4E44443F43373742373E383E404241515F6B828DA1AEBFC4
D6D2D5D9E0CFD5BDC5B2BCB2B4B5B1ACA2AAA4A7AEBDCBD0DBD5D3C0B3BCC9D5DCDFDCD6
D5D7CFC8C7C5C2C5BEB9BFBFC8C7D3DADCE0DBDDDFDEDDD0CDC2C8B6B7A4AFA3A8A19586
6D6D686A676E7B8B9C9E9F988F928E99999D9490
4949494A4B4B49484A4B494646494A484443434546444546444343424242414141424241
41414244414243434242434443454747454444464846484B4B4845454444444445444341
464442403F40424442434342403F4041403D3B3E3F3E4042413F4340444B46464546443F
3E4044454444464043434542484A42413E3A41434944494A4B46433D4A48464843434443
3E3E44423F3E3D443C3C3C413F443C473E4144444445443F453F3D4C5D6E818E82847A75
6F7C7F818788A390A3858F8291768162826B7A7A8180808985807E6A5F5355545A474C4C
6A89A4A1A29998987874593F46434A54474D4F4259576897C7BAA46B5E52554E46403D3D
393B413C3E4041424141424347423E3D3D3B3B3B3B3E3F3D3B3B3B3A3D3C3C3D3D3C3B3A
373B393D3C393C38393A3B3D3D3D3D3C423E3F3C3F3B3F423D3D43454040434042443E38
3B3D3C3D373E3B3A393A3D353F3D3A393A3C3F40393A464A413C3F3C3A3A3B3C3C3C3E41
3B3F3F3D3C39373A363738393A3A39393E3A3C403E3B3A38403D3938383A3A3A3B3C3C3A
3C3F3F3C3D3B3B3E403E3B393B3A3C3A3D3E373A393B3F3D393C41413F3539403A3D4545
413D3A3A3C3E3E3C3B3A3C3D3D3C3C3E3B393D3C3E403A3A3A37383C3C393A3E3A39393A
3A38383A3D3C3B3A393938383A39393B3C3E3E3E3D3A3738393B3D403D3D3E3C3B3C3934
3A3A3F42403F3F3B363D413F343845414444505B50403B3C403F3A37393E414337393E3E
3A393A3A3E3C3C3C3C3B3938383C3C36353A3C393A3C3E3C39383B3E3A3A3A3D3F3E3A37
383A3C3B38373739343938373A393A3F3C3D3D3B39393D403F3E403D40413A3D3F3D3B3B
3C3A3632414A4A51554C48453F3E39403D37424447515F7277737570554C423C39383A3C
3A3937383B3C3D42373B3D3A394040363B393B3E3D3D3E3A3A393A3D3F3D3D3D3C3C3A39
3A3D3E3E3F3D3B3A3A3A39373A39383838393A3B3B3E3744679170474A42453D384D574E
725D5A43423D3D3B39383B44383D3A3B3A3D3F3F393739364649463E3E4349555553607A
8893878A998D97747D56504541323F3B41383F3A3B3C414A5564666E59694E5F3F4D423B
3F3D4742413F47403F3B3F3C423E46483E383B423D423E464755607E96A6BEC3CCD0B4B9
96A08A9475847185687D647C757B80868AA3AAB5BEC9CFD5DAD4CFC0C6BEBDC1C0C1C6CA
B7C1CAD1D8D6D4D8CCCCD3D1D9D8DFDFDCE4DDDEDCD7DACFD5D6CDDDD5DCD4CDCBC3B8B6
A8ADA6A299A5B7BFBBB4A7A4B8AAB3A4B5A9AFA4
4E4F4F4E4D4C4C4C4C4E4D49494B4D4C4F4C4C4E4D4B4A4D4C4C4C4B4A49494A45464645
44454648464748474545464742454847454445474645474A4A4747494443444546454340
4343434243444545464747464442424349464444413E3F42444348474A4F48443F42423F
3E414343464445404642443E40413A3C3F40443F403738424644433D3C3E3F4245464242
3E3F453F3C414047413E4144383E3B4443423E3C404648473C3E4A4447434D545055545A
555B575860655C665865636F5D574D5554584C55525158646975817797888E7FA585897A
7D887D8F989FA398969C717366826C827299657D466476AAAFBFC19987645155444C403F
433F413C3D3E3E3D3C3C3D3F3A3D3D3C3B3C3E3E393C3D3A393B3D3C3B3C3C3C3B3A3A3B
3C3F3C3F3E3A3C38393A3B3C3D3E3E3F4137393B41363739423D4146413B3B3A3D413D39
3D3E3B3B3639353737363B383836343537393A3A33373C3E3E3F3F3C3E3B3B3D3C37393E
3E413E3A3B38373C39393A3A3A3A3A39403B3D403B393C3B3D3A36373B3E3E3D3D3D3C39
3A3D3C3839393C40403C3B3D3F40423C4042383B3A3A3E3E3B3F433E403E424238384143
423E3A3B3E3F3C38393B3C3B3B3D3E3D38353C3C3F443F4137383A3B39383A3C3A3A3B3C
3A37383C3B393737393A393737393B3D3D3C3C3C3A38383A3A393B3F333637383C414240
3D3E44453D3A3C3A3734363E36374A4C484546443A363A3B3D3B3A3A38373A3D3D3E3F41
403F3C3A3738393838383939363838373637393A39383737393D42463837393C3F3F3C38
3A3A3A3A3A3937353A3D39363838373C3B3B3A3938393C3F4443423D4041393D3A3B3C3B
3A39393A353D3B404744413C363A3B40474A4F555E615E64604E454047403A3A3B393837
393B39414C45383539393C3C3C42443D3D3A3D3E3A3C3F3C37373A3F3E3B393B3B373537
393A3B3C423F3C3C3D3D3A363A3A39393939393937344C4A63483C39404C55656D808261
5B3F4135393E3D44393F3E40393A3D3B363B3C44403C47413A39413F495C6780817C7B85
878E7D796D5B5140463E38393A3B3642374A4F4B554F544F525047434042363C31363D3B
393439353A333938403C3E3D403D41443B3C3E3F3E45434E566B768B928F979087757855
5E45564C4F595C6C75878298979EA6AEB6CFD0D5D1D2CAD1D3D0C9BDB5ADA9A49B9AA5AC
A1ABB7C4CECDCBD1D3D3D9D6DCD3D3CDD0D6CED2C7B3B4AEB2BBBFCAD4D0D2CCD5D0CAD0
CAD3D3D1D1D4DCDFDAE0D8DECEC8C7BFBCC0B9BF
4D4E4E4C4948484A46494845434547474946454746434244444546454342424343444443
4242444645464544424141424245484745444649494644444241454A4443444647464340
3D4045494A48464340414342403F3F3F3F3E3F424243474C403E423F42473F3B3F444543
4142413E4541423F4741433C3F45413E3A3A423F413B3F49443C3E3D3B3B383742474448
3F3C40393B444041403B3D3F313C3B3E3D3D3B3B4044413D454343393A403F3E3F403E44
3A3A3A443F3C49414B39414045475E586F5357555E5353575B6C787076997FA87FA484AB
89A48EA5A4ABAE919B918B767369554C4C5248484864787F989A895E5747517F7A886755
584C48463C3E40403E3D3C3D3B424645464E55575959544A43413F3C3A3B3C3B3938393A
3E413C3E3D393B373A3A3A3A3C3E404142373D475344403F3A333842403A3A3B363D3E3E
424039363D3B363C3E3A40423535383B3E3D3A373A3C3B3A3F43403B3C37373D3C373940
3F413A353837363C3D3C3B3B3B3B3A393F393C3E38393F41433E3A3A3D3E3A3638393838
3A3E3E3B383A4043403C3E443D40423B3F43373A3B3A3D3F3E43433A3E3F3F3F40434545
4A413734383D3D3B373F413D393A3D3D3C363934363C383C353B3D3936393B3B3A3A3C3D
3A36383D3E3B3A3C4143434033373B3C3B39373739383A3D3B37373A3E3F3C383A3C3B39
383B434338363C3D413C383D3E4F6D6F46403B35343E423B3A363637343339403B403A37
403F3A423A3C3C39363637393735373A3834343937383A3E42423E3A3334383E42413B36
3B3835383F4445433B3C3734383A3B403A383635373A3B3C3B3A38343A3D363C373A3B38
3537404840453B3A3F3F3F393C4348444C554F533D42393C423D3A383935353D43413D3A
3B3A343E524D3B373F3B3C3C3A3E413B3C393C3C36383D3C36373B403F3936383736393B
393333373C39373B40423E3A3B3A3A3A39393938453E464646454B628D98A4A97D804C41
3934313E3B3D3E3B363E36373C384238383D383F3934433D4842565A6B7E7A91807C7571
6B6F594E3F3F373D343C303E3D413B3C384F6154594A48383B3B3A3B37303C3A402E383A
3C3A3B3943393A403735373D403D3C3D3E49434C475D586B617576786B58574A584A6554
776C90889E94A5AAC9CFD4D6D6DADBDBD8E0CFC6C1C1BCD0D9DED4C8CCCECEC1AEABB2B2
BCBEC0C6CBC7C3C8CFC9CCC9CFC7C8C6CAC8BCC2B8A5B2B9ADC8BBD1B7B9A6AE9EA9B3C1
B6B6B2B0BBB9C1CED5E7DBDEDCBAA0797D786B6C
555655524F4E4F504D4F50504E4E4E504748494847484A4C4C4942444A47434848464A4E
4B43434949484646474848474145434646454B4A44474A4B4A4A4A4B4549494643454645
3F47484B484448453F444644434545424340464C484443414847423D3E444745434B4949
49484942474541454B443D43424545414042413D3F3C3D3E4E45403D393F444441404246
42413E3C40464743433E3B3D4144423F413D4144403F44473B3F3F40444342453E3F3C47
4B474D4C4744423E413D3E404E687A957184554F5467686A666752475360584D64565652
585360717B867E635051546B7A8D75746A6A5F5042433F4D4E474A4946413F495D547998
B79A615E4A4E4F5647445C575B5D6F78808E9BB2B9C29EAF918C69534B3F4B393A3E3B3F
39423A3C3E393F3D393C3D3C3D3C373B373D43444444413E47403C4C413A3B3E393E4241
3C38393C38393A3B3C3E3F403634353A3C39373834363D3E37373D3F383D42423E3A3737
393F403A36383D3F3D3A3A3C3C3B3B3E3A39393A3B3C3C3B423F3B3A3D3F3D3A3A3B3C3A
393A3E42453C3C444541475340403F3C39383839383C3E3F4245423C394044413D3D3F3F
46433F3B39373737373B3D3A37373D443C3C3B3937383B3E363A3A37383D3E3B393F3B37
41363C3E38393A3C3D3E3D3C32393C3A383A3B39393B3D383A3A333B3F44413D3E3A373B
36484A3E3837373A3545483F4C65644F3A373A3D393B403D3A3C363438393B4238363A3C
37393E3C3D3C3937373A3F433B38373A3A37383B3538393736393B3A3A3E3A3A37343C3E
37363D46453B373B3B3A393838393A3B363333383A39383A3B38373E343B3A384041413F
3E3D3B393241404042474C3F42443E3B3F4040453A3E3C3A3B39393E3D3B3A3B3E40403F
363D3D3B3D39373C373B36373C4B5848393B3D3E3D3D3E403B3B3B3B3C3C3C3D36383A3A
3938393A39353A3E3D414239363B363D3F373C3E46484D5F5C8E97B0BBA9886B5D423F40
373C3D39383C3E3D383E3C393E403C3A3C3F3E3D3C363E545E6C7B8A8E81777D76685B4E
413E403C3936373C3A363B45383A3C3D3D3C3B3A393736383737393D353B383833393839
353941383B373E3C3839433E343D3C3D3F424A51596E776C5D646D6A73838EA59BA4A9AC
B9CDD9DAD7D4D5D7D3D3D8D3D0D4D0CDC3BFBFACBCC8DADCE7D9E3DBDEDADDDAD4CCC2C5
BEBC9F98868F7886807982998F9A9BB5D1D5DDDCD2D0D0C7C3C7D1D1D6CECFCBC3B9C0B3
C4B6BCB2AF9F92A3BDDBE6EAD6D69B8C64595443
4E4E4E4D4B4A4949474849484747484945464645434344453F43454B524D44434947494C
484141473E3F4043454543414145434747454947434446464545464844484A4745474745
45453F424340423E4646454344474A4B4943464A47454543484A4947474947433A404045
48494E4A4242444A4C454247404142403F3F3D3B3C3B3C3B453C393A3D3D3E4043444241
47453F3B3D4243403F3F3E3F40403F3E3A3A40423A3941484144414144433F41413F3E3B
3B404A55403A423848475B5B72767E6F4F4E3F433D4944434249413F425D4859565E4A56
5450483F404A4B40433B5552827B7D718985916E8062676C5F54514A4443414A46456284
9CB4B8C79AA4A39E8374868595A6BEC4CBD4CFCBCECBC7D1DEC3A777644E4F3F3A373C42
40493C41413B42374245403B3B3E403A383A3B3B3E41403D353B40554C463F383A3F4343
3E3A3A3C3F3E3C3A39393A3A38393C3F3E3A393C37373D3E383A3F4041403F3B38393D42
3A3D3E3A37373B3D3D3A393A3A3A3B3F3A383738393A3B3A3A3837373A3C3B3A3C3D3E3C
3A393A3C38363B45464040463D3D3D3C3A3A3C3D373A3E414344403B3C40434242423F3A
3A3A3B3B3B3A393834363838383B414737383A3B3B3B3B3B3535363838393A3C373C3C38
3E353B3838383939393A3B3C3C3C3937373839383335373437393339343A3B3C403F3E42
4C4F483F3F403B39383C3F45515851453A373836343B413F373936353A3A3A3E3C393D3D
393A3E3C393939393A3E42463A38383A39363537373A3C3938393837343A393D3C383C3A
3B393A3E3E3A3A3E3635353536383A3B3B38393F424242443637373F393D39383736383D
3E39373837413E3E4044483E393C39383C3A383B353A39383C3C3D43413D393A3E3F3D3A
393E3D3A3B38373D3F433E3D3F454A3D3B3A3A38373737383B3B3C3C3C3B3B3A393A3C3C
3A393A3B373742433A3A3B393B413E3F424E64697B7B8F99ADB7B19F6C68513E3A353D3F
3838383939393A3C3D403C3C414441423C3F3D3C4657677388827B7872665E6148474A47
3C373835343335393835383E373A3C3C3B3E444A3D3B3A393835383D363A413638323B3A
393A3E363A373B373D353F3641403F3A3D453F484351505C6066788DAECBD8E8DCDFDDD7
D5D3CDC5C0B4A89D9189857C706E6A6D65626E6E859EA9D0C3DBCDD9D1CED4D0C4B29B93
776D5C4C505049535255677D9391ACAFCCD0D4D2CECFD2D0D0D6CEDED3E0D4D8DBDFD0DC
CBDAD0D7C8BFC4BEC9C2D0D4D8D5C6A2A0819787
4F4F4F50504F4D4B4A4B4A4948494A4C4A4B4B4A48474647444747474B4A44414C49494A
474142484746464647464341484B494D4E4B4D49484848474646484A4447484746474746
48474044443E4347454342424447494C4D464445424243403E40414142423F3B41434044
454044424342494E4942424444434446454240404040413E423C3C3F4341404246484642
42413F3D4043424041434545424141433E3E44453D3C44484849444144413C3C413B4040
484F433F4E5052585468747568675C603D5345554146413F3D4341434046433855516A7F
9E9472493B40423E444449424B48464950585B5D6C747892A09C9C90847A6E6E6F615664
5D8FB4CDCED7D2D2C3AA9F8F8694A4A7B4CACDC9C4BEB4CBD2D1BB9469474141413B403B
46403C3E41424243515B57544B41443E3D3D3C3B3E42403C3E413D473E3F3D383A3F4241
3D3B3B3B3D3B3938393B3D3E393C40423E38393D3C3A3D3E3A3B3E3D3B3C3D3B3A3A3D40
3C3B3B3A3836383B3D3A383939393B3F39383637383939393F3E3C3C3C3B3B3C3F3F3F3D
3B3837363E3C3C3D3C393A3E393A3B3C3C3D3F413E3B3A3C3E3E3F413B3B3A3B3E3F3B34
3839393A393838373C3C3A3837383B3E3C3C3B3B3B3937353A37383A373232373A3C3E39
3B38453B3A3A3B3938383A3D423D3838393836343B3A3C3839393235363B3C3D3E3C3A3D
5952453E403E39373A3A3E484C48434148443F39363C4240383937373B3B38373C3A3C3D
39393B3A36393C3D3E3F41423938383938353435363A3C3B3A3A39373639353839383E3D
3D3B3A3A3B3C3D3D3A3939393A3C3E403C3A3A3E41414243393E3D4140423D3F3F393A40
3F39383D43453F3D3D3D3E38383B39383A3836383B3E3B383A3A3A3E413D39393D3F3C38
3B3E3C3939393B414448403D3E3B3A353F3D3A38373839383C3C3C3C3B3A38373B3C3D3D
3C3B3B3B40383D3B3B3E3A3D3F3849708594B1BFC6B5B98F9970734E3D4B433D393D3E39
3A36353A3B38383C444542464A49424343515A585F72786E7562524B45403E3C38393E3D
363436363637393C3D3C3B3C373A3C3936373F46423C3B393A3637383C3B3837383B3835
3837373439393B37403A413A433E3E3F4045433E504F62819EA6BBCFE1E7E4ECE0D6C5B3
A18F7D716B6159514A47443F4546403E3C43515271687F7B92888C8C9C8F877B736E6566
6B766D8A89A99BB298AA93BFB1C7D0D0D2D2CECBCED2D5D9DFD9E4CFD7BDC0B5C4C1C2B4
B7AFBBBDC3C3B5BFA8ADA7B7B0C29DB68CB5ACBF
4E4D4C4D4E4E4C4B4B4A494847484A4B49494A4A484746454B4C4641424647454E4B4A4A
4744464C4D4A454242424242474945494A47484345454443424243444445454545464747
3C3F3F4D52464343424042474A484645443D3C3F3F434643424141414344444340403D43
443E4243433F464C45414240403E3F43423D3B3D3D3D3E3E3F3D3D3E3D3D3D3D3E3E3F3F
4343434242403B373D3E3E3D3C3C3E40423D3D3E3C3D403E3F403C3D454644463C3E4C5D
7074594164627A686B5A654D483C423F3E3E3C3D3C3D3B39373A3B3D42413B3F485C7EA0
B2A57E54464E514D4D524C473F3F3B4543463D47415555708DA2C3D0D0C9BBB89C937C7F
607B8399AAAA99979E9FA7AABEC2C7C9CDD2D3D3D3C3B4A99F9EAB9D8661504F5151645A
5C57666163635A768B968A887851423A3D3F3F3C3C3D3C3940413A453F3F3E3D3B3E3F3C
3A3B3B3B42403C3A3A3A3B3B393A3E3F3C3636393F3B3D3E3B3B3B3632353A3C3B3A3A3A
3E3A383A393636393C39383939383A3D393838383A3A39383C3A39393735373B3F3E3D3C
3B39373646433E3835363B3E37383A3C3D3E4143423D3A3C3C3A3B3F3C393535383B3B38
3C3B3A3837383A3C3D3B3837383A3C3D423F3B39393938373736383B3937383C3E3B3C33
3033463A3C3E3F3D3A393B3E3E3A393D3D38343439373B3A3D403A3B393C3D3C3C3C3C3D
433E3A3A3C3B3C413A4146433E3D434849423C3836373A3C3C3C3A383B3B373338373939
38383837383B3E403F3C3B3A393838383837373734383B3A3A3C3D3B3939333638393F3D
3A3D3D3C3D403E393A3938373738393A3C3A393A3B3B3A3A3E433E3D40403E44403B393C
3E40454B47433D3D3D3C3B383C3C3A373636383B41433D39393735393B3B3A3C3E3E3C3A
3B3C3B38383A3F4541433A36383433383C3C3A383A3D3D3B3E3E3C3B393837373C3C3D3D
3C3C3B3B3F3A393742443A474F5686C1D4D8DED9D7BC8C6C534444343B4A44443B41413D
3E3A383B3D3C3C3D4A4944505963636D76848B7C6B6C654E47383336363737313F3C3937
37383A3933353637393A3835383A3D3B3736373A3C3433333D393935393C3B3D383A3839
3A3938373A3C3F3F3B3B434042435768637E68988AB4A5D0DBDEE8F2EEDAC5BEA4907865
574A423F3F3C3F3D3B3C3A3C3D3D3A3A424E544F5E52434D455450605E5D69778BA0A6AE
B7B3C4B8D2CCD9E3D9D1D5C7D7BBD7C5D6DAD9DCE5E5E3E8E0ECD4DBA6AB8E98A2AD95AA
87A292A28E829497B5A1A397A693AD83AF95B0A0
4F4D4B4B4D4E4D4C4C4B4948494A4B4C46474748484847464547474444494A464B494848
4746484C4947434244464747474843454643464245444443434342424544424243444647
4345465C6D5F4C41434244494C4B4641433E3E404044453F43413E3E3F40414143433F44
443D41413E383D44434445413E3C3D41403C3A3C3E3D3D41434644413F3E3C3C3D3E3E3E
3C3C3E4042424140403D3A393C3F4142413C3C3D3C40423D45443E3C41413E3F424F5968
716E635140464C51404B4B403E343F3E433C40403E3D3E3B3D40444343435B6E7684A0B3
AFA897817A879391918489697E5A5E4C64586B606559636263799BA8ABB0B2BCBEB79D93
7E846974757B6C5C565A728B91909094949399A0999D8889596C7683887E81827C778978
7D97A9B0B6ACA5BAC1B88A77715547423E43443F3B3C3E3F474740504A423B3D3E403F3A
3A3E403F413F3D3D3E3F3E3C3B39393C3C3937383B383A3E3C3D3B353637373637393C3E
3E39383A3A3635383A38383B3B39393B3A3A3A3C3D3C3A373635353838383C433D3C3B3B
3B3B3B3B3D3F3F3C3A3B3C3C37393B3C3D3E40413C3C3F44423B36363D3B3A3A3B3C3F41
3A3B3B3A3A3C40433D3A37373A3C3D3C3D3B393A3C3E3F3F3E41413D3A3A39373D3A3F3A
3B435B4F3A3D3F3E3B393A3C38383A3E3C37373B373338383B3F3B3C41403F3D3A3A3C3D
3D3A3C3F3B36373C3A42443C363A444B4139363B3D39383F3E3D3B393A3E3C3635363738
39393838373A3E3F3D393634393A3938393A3B3C363A3B39393C3D3C3639363B3D3A3B35
3A3E3F3D3F423F3939393938383939393F3E3B3A3A3A39383B3F3B373A38383E41413D37
373C40403F3A393C40413F403B3A3937343437393D3F3B383B3A383C393C3F403D3B3B3C
3E3E3D3B383A3F433C3D38353835333C37393837393E3D39403E3C39383838393B3B3B3C
3C3C3B3A373E3C353D3E45698CABDBEADCDACBA78E7454453D37423E42484044393A3C3D
40413F3D3F42423F444C526B7A888792979487694D4741323B34373D3B3B3A3437373738
3A3A3837363635353739383538383A3C3E3E3D3C3A353938423C3F3D363A383F383B3537
36383838363A3F4569678C839E7F9389AEB3C2C7E4E1E7E8EBE8E4DABE9C8C887D6A5448
403C3C403A373C393B403B3F3A35363F484845484C4D505A61688297B5B2BAC0CDDAD9DA
D8DFD9E5DAE9D7E0C5C8BED2B1BCA7B0B2BFCBD4D8D3D4E0D8D2D8BBBBA5B5B7D1C3D4B5
CFB1C5B9AEA48FADB0CABEC4B1B599B794C097A3
504E4D4C4D4E4E4E4E4C4B4B4B4C4D4C46464647494A4948484749484647484447464646
46464749474747484A494846494B45474744484448474646464645444743414243434446
41443D49564C423E44434242474A463F45424445444747404A474546464342413D3F3E44
46434847403C3D414243423E403F3F41403E3E3F43424046454D4A4549433E3E43464440
45413E3E3E3D3F4146423E3D4145494A3F3F42423E42484645443E3B3F3F3D4036404044
40393C36443C4938433F564D443D39443B403938393F4E5662696E667677849B858E8B93
868A929490949EA396908B7F8E7E807688859CA49CA1A39C95959685726E75867C97B3BE
CCC3A29E9EAAAAA2998F8E979E9D8F806E5F5A5557545F474C54899CACB4C1BCAE9D9A7D
789E9FBCD7D0D4C9D0BC794C454140403E42423D393C41444F4A3E4C473C353B4042403B
3D4346443D3C3C3E414343423E3A393C3E3D3C3C3633373C3D3F3F393B3A3938393B3E40
3D3B3A3B3A3838383937393C3C39383A3C3B3C3D3E3D3B383A38393D3D3B3E443B3B3B3B
3B3C3D3E3A3D3E3D3B393837383A3C3C3C3C3D3E3C3E4042403B373637393C3E3D3A3B3F
393C3F3F3E3D3E403D3B39393C3D3C3A393A3C3E403F3E3C393E403D3F43423D3A373B37
35354539373A3C3B3937373838383A3A38373B413D373C3B393E3B3C4643413D37383B3B
3E3A3D434340403F3A3A3A3B3A3B3E42413B383E423C393E3C3B3B393940413B36393839
3D3D3A3B34373B3C3A383635393B3B3A3B3D3E3D3A3D3D3937393A39393B373B3C393A35
3B3E3D3B3C3F3F3C38393B3C3D3E3E3E3B3B3938393C3C3A393C3F3A3C363739383E3E39
3A41423D3B373A3B3E423E40393A3E3E3A383A383A3C39383D3D3A3D3E4143413C39393B
4240423F39393C3C3B3B3D3B3C3C373B3A3D3D3A3B3F3E393F3D3B393839393A3A393A3B
3C3C3B3A3C40393D50648FC2D8D3D5BC988E7F655342413C414248494B463F46403B4142
4043423D3E43433F4A5B647D7F82706F5C554B3F383A3C383A383A3B39393B3A32383938
373434393C3937383A3A3A39393735363B3D3D3C3B3840383E323B3D3D344A3F5D49574C
3E4449555967748290B1BBC29E9DABC9DFE1E3E5EAEBE2D8D3CEBFA9856C707663584D46
403B393B413B3D363A413B44474D5A6570757680869D96BFABC3C2D6D9D9E1E2E5E6D8D0
C8BCC8ADC6BBC4B9BCADCCB7C8B2BCB9C4CBD0CCBDAFB5C8D4DEC8E1C5E3D4E4DBDCD6DE
D8DFD7D7D4CAD3C9DBCED9D4D9C0DEB3DBC2D4C9
4B4C4C4B4A494A4B4A484748494A494845444344464747474F494A4A4544464548484949
4A4948474545464748474442454844464541454246444141424343434744434647454444
454D4340433D424C4748454147504D433C3D4346474D4F4A45414042423F3D3E42474445
4541433E4446454445413C3B3D3E3D3B3B3D3D3C40413F423A44434046413B3B3E41403D
413E3D3F3F3F424641403E3C3C3F44483E3E403F3B4045414848413C3E3D3B3E3C3C3D3F
3E3B3B3B3D3E3F403D40403F453B443C483C44393C486270848D8F7F8372826A6F575F5C
5F6D829697857B8172775E695F6C676E5E666780678B8388857F7D6E5A4E4B57616F8D82
8D80A0B3C5CACFD4D7D4CCC9C9D1CBC1AF978169545146444A7BADD5D2D5DACFCAC5C8B6
7E7C717E95A3B1B3A2956E4A404341373F41413F3E3F3E3B3E403644443F383B3D403E3B
3E46474344413E3D3F403E3C3D3B3A3C3D3C3F433733363B3C40423D3A3B3C3D3E3D3C3B
3A3C3D3B3A3B3A393A38393B3C39393B3E3D3B3B3C3C3B3A3A37393F3E3735393B3D3F3E
3C3B3C3D41403E3D39363537383A3C3C3B3B3B3C3E403F3B393B3D3E37373A3C3B373739
393C3F3E3C3A3B3D3938383B3F403F3D393B3E3F3E3C3A393E3E3E3F41413F3B39373A38
383340373839393938383838393A3A38383A3D3D3B363C3C393F41423E3B3C3C383B4141
443F40444344433E3C38383D3E3B393A3D3E38363B3A36363A3B3D3A383E4139383B3939
3F3D393A3436383938373738373B3D3C3D3E3D3A3A3D3E3A383838363C3D373939373C39
3A3B3B3A3A3B3C3C3335383A3B3B393937383735373C3E3C3D3C433E3E383E3C4144443F
3E3E3C383C393D38393D383A3A3A40413B3A3D3B3A3C3A393E3D393A4644413E3C3B3C3D
403F44443C3A3C393D39403D3B403B3A3D41413C3B3F3F3B3C3C3C3C3B3B3B3B3939393B
3D3E3D3C413F466B8599BFD1C3957C6A51443E3F413C404C44654E53584C444747424B49
3D3E3E3C3B3C3D3D515D585F545644443C3D3B383A393736383A3837393A3B3E373C3A35
3533353D39353337373434373937353435363838383138323F3845475C6C5E7A55644A57
4E4F4D5759656C797A86928BBEBAD8E0E4E0E9D3D7BDBAAA9386706251474D4843434241
3E3C3C3E3E4353505765697F9FAAB8BBC2C7C2C8CDCDD9D0D4C1C4BDC0C1C6C2BEB7A498
8B8E908993B0BFC5CAD0CFDBD2DBDAD7D8D2D0CBB9ABAFBBBCBBBEBDC1BCBBB6C5BDC5B5
C3B3BBB3D2DAD3D4C4D0D3DED5D5CDD5BECFB6C0
4F515352504F4E4F4E4D4C4D4E4F4D4C4D4B494A4C4E4E4D4A44494E494648474C4D4E4E
4E4D4B48484848494D4F5050474C4A4D4B4649474A47444244464848484545494B474343
425048454841434A4E52504B525D594C4344484743464740494542454747484B3D454344
4544463F424A4B4849433D404143423D3D41434044464444363F42414443413E3C3D3F42
403F4144433F3D3F404243403C3D43494A4442404146463C41423E3C404143493F3A4142
403E373D413C3E353E373D3D3F444446373A41464248595B6567644D4D4D4648424C404F
59697F999D765252544D433C5048524A504E574B4D5A64624E495053504C4B576E63837B
84577B788495B0C0C6CACDD2CBD1CED4D7D2CCBD9698807F6A878DA5ACBBD0CED0CCD0C8
BA847D5E537084B8B4A08E7D74766B55505153545552473C3F44373E3F3F3A3C373B3B39
3D45453F423E3A3A3E40414039393B3C3A393F473D38383A3A3E413E3A3A3B3B3C3B3A39
393D3E3B3A3C3D3A3B39383B3B393A3D403D3A393A3B3B3C39383C45453D393B3B3F4241
3D3A393A3F3E3F413E39383A383A3C3C3B3A3A3B3A3E3F3C3A3E403E413C3A3B3C39383B
3537393837393F43403F3E3E3E3C383437393A3A393A3C3E3C37383F43413E3E3B373836
3833413D3C3B3939393A3A3B3A3B3B393B3E3B343D363C3832373839403C3E3D37383D3B
3B383C403F444A473C3D3E3F3D3A38383C433C333A42403C3B3D403C363B3D34373A3737
3D3B35363738393837373839363B3E3E3E3E3B36373B3D3B393A3937373B393E3E393B36
36383A3B3A383839383A3C3E3E3C3A383A3B3937393F403E3F39403A3835413F4543403F
3D3B3B3C3A383C35343B373938363A3A33353B3A373A393A3F3F3B3C4A433C3A3C404140
3B3B43463F3D3F3B3E373E3835403E3B383E3D37353B3D3B393A3C3E3E3D3B3A3939393B
3E3F3F3D3B40629EA58F835E60423E403F45464B594F8D59756266586B605D5B58464333
3A38383A3935363C3B463B3F333F363C3B4340373634353D373B38363A38323434373332
3839373B3D37373C3B36353A37393B3A38383A3C4033393B5A60706F6A657164684C4A41
443F373F3D46485071A6B0C9E3E4D8E7C6CFAEB17F84687657514746413E4439393D3E3C
393A3F433D506C6968727D9EC9C9D3D8DCD2BFC4B2B8A9AB84907A867176818283817066
728EC0BCD0CFD7CBCFD8D6D2D8C5D0B0B7A6A2A59783756C646E677868766B71676E6676
6C7E7A839DA7B2ABA6A0A09CA9989C8085767673
48494C50504C4A4C494A4A4948494C4E4549494542454748444648484644444543505147
454847484542404D4A4842484C4A48484848464442424345484949484141434548494847
47464442404040403E45494844434241494443464541434B464144443E3F423D41404142
42403E3F40443E434441443D3D3D3E403F3C3D403F4B4B43403D3A3A39414644413F3E3C
403F40424443413E413D42413F3E3A40424C3C3E433C423D3D3F4442424945363C3E4042
413F3C3A3E3F43393D39404040464741443C40423E4041404142403C40414C75535C3B55
5F7788B6AD865550685E5B5344444D4A535260615A514952424F4D475C5E666563747389
788267617A8E8EA0B5B9C0B8B4BBC8B9C5BACFC9CFC6D9BCC8B3B6ABA6A1A2898B7BA1BE
B1BB8E905D505A6D98B0B1BBC0BEBEA4AC9FB1AAB9959B654E3F4A4B4F373E4439423E40
403D4965413F3A3B443D49443A3B343A3843393A3239433740433E3E373B3C3C3E403D37
39403C393638403E35383B3B3A38383936393A39393B3A37373B3F3D39373A3E3F41413E
3A383B3F42413D3E423E393D3D3C3B3B3B3C3D3E383E43444547443F383C3D3A393A3B3A
3B38383C3C393B413C3D36354046413D35393D3D3B393B3E373C403F3A3636383140373A
3B343F41443F3C3632393D38373A3B393634373A383A3D3F3F3F3E3D3B3C3D3E3D3B3938
3C3B3C4246433E3D3A3C3D3C3A393B3D3F3E3B37383D3D3934373837383C3C39363B3D3B
3A3B3B3A3A3D3E3B3737383B3A3C39373A3A393D3B3B39393E43413C3A3B3B393636393B
343C3B3F393238393A393C3C37383A373C373D3A3C413B3E403B363A43463F393E3F403F
3C3A3A3B3B3C373C3E3A3C383A39383737393A3B3C3B3A3A3D404141423E3A393C3E3E3D
3E3C3C3E3C373537383539393540473C393A3A3A3A3A39393C393C3E3A3B3D38403E3A3F
3B3F38393B4C6078545741413E3B40414D5D739A8CB0A2A98FA297997E8A5D544B39383A
38393A3937363738353937373D3C383B38393A393736373837393A393635373A34373434
3A3A373A3A373B3D3B3A393338393C3D3A383D453A5A5663635D5A5B55584640403C383B
373F3A3E3B5387B2C6D6D6CDC5B6BC9E90747169676B61666A6A6354463F3A36373A3C3C
3A393B3E434356626468759291929BA19A8D7B69665953585A524C4B5046474A51514D5C
688595ADA0B196B1979C95A58D9576775D604D484440473C433F4440443D474D52646272
829FACA6A5B2C2BEAFACB4B5A69B938B887A7C6C
4E4C4C4E4D4A4B4D4B4C4C4C4B4C4D4F494A4A484B4F504D484A4B4A48464646434C4C46
4648484B4B49444E4A4C474B4A4948474847454343424344474848473E4044484C4C4947
48484745434243443F45484746484847413E3F44443F4046434346494644433F41424342
434443423E403C4244404441423E3E4244434243404D524A444241414146484541403E3C
4040414346474644464144414041404740504B4C4A444D48423D41424145433E3F3F3E3F
404140404346544E4C495048434C4351474E3F453E3C3B3F474C4D4C5B505A665959464E
466160737C8E878788797165524C4B42504C52524F4D4C574F5B5E5968605B56574C5D7B
8A6F5C575E787F8E9C9FA9A4A9AA9CA794B3A7B7B2C4BACBA0B499A98F8F886871547D82
949AB4ADB9878D615B84A2BFC8C7D2C9BCC3B1D6C0D0C3B979583F443742434B4B4C443F
493E4841443B4333404A40403E3C42363C3A4440505456463A42344139393735373B3D3D
353C3B3D3C393D393A3B3C3C3B3A3B3C343637373A3F42423E4142403B393A3C44444341
3E3D3E3F3D3D3A3B3F3D3B403D3C3B3939383939383C3D3C3C3E3D3A383C3E3C3C3E403F
3A3C3A363C45443B3F3F3A394245403E3A3735383E42403D3A3A3A3B3C3D3C3B3740363C
413B44443A393C3E3D40413B3C3E3F3E3B393A3C3A3A3C3E4041403F393B3D3D3C3A3939
433E3C3F42413F3F3A3B3C3B3A3939393B3C3A37383B3C39393B3C3A3B3D3D3A3A3F3D36
33373836393B3C3B39373839383B38363A3A393D393A3937393C3B3734353637383A3D3F
373A393A3A3A3E3D3F3D3F3F383739353B373B383A3F3A3D3936363A3E4243414040403D
3A393A3B393B383B3B3D45423A3B3D3E3E3C3B393A3937383C4044453C3B3A3A3B3F4347
3A37373A3C3B3B3E39363A3A363F453A37373738393B3C3D3A373A3B383C42413E393C33
413940383B3E4741393E3D3E4B556C7D93A9B6C8C4D0CDBBC5A69F7B545A3C3F3C373837
383939393939393A383A36353A393639323437393A3A3B3C3435363635353739393B3836
3A39373A3C37373735373A3737383B3D3A383D443D55525A58504745393E403B3A36343C
393945527085A7B6B4B4A38572656C59614F57595B5D4F4F4345443E3A3A3B3A37393B3A
393A3E41404C5B5B5656565B524B4948454545403E3C3D43444142463A3A3A383B3B3C47
44525F617A7C87888B82766F6055484744464242444548445658605E65687B88A4B1B7C5
BEAEA1968D96A4A9A7AFBFC7BBC0CCD1D3CBD5CE
514D4C4E4C4A4A4B484848494A4A4948484644454B504E494647474644434242494D4A46
4644434748484145414743454A4949494948464444434344464746454C49474646464645
4647474644434446484A4A47464848464241454A494443464243403E4041414441454542
4348494643423F44423C3F40413C3A3F4444413F465157504542413E4346454240403F3C
4040404144454544443F4342424442494857595B5757635B4E414646403C363B3D3C3B3C
3F4141405B6073716C6C75676A65776A7D5951424542404043454645503E4B3C4A4B5555
5F7D767A819A968C86736354454446404B43423F3D3D3D474648483F4C4745484E424356
6B6D645C4C5F6678868C9DA29887776E8885A9A8AF9EA2899C91A0A0A186734B53798DAD
95BEA3C29FB699AA687A879A9D93938D8265706CB4AAD3C1C79082524B3A4B3F41565779
624246483E3F3D3942383A3C3F3C443C4A5B7876948FB88B915B45333D3B3A3A38373739
363A393F3F393B38393A3A393838393A3B3C3B38393F42423E4041403E3E3F4046444241
41403E3C40413E3E3E3834383B3B3938373737373F403E3A393B3C3B363A3B39393B3D3C
3A3F3C363B4744363B3A373A3F3E3B3C3D3732363E43413C464039393C3D3A3647473A3F
41373A39403C3F433F3C39333C3C3D3D3C3B3A393A39393B3E403F3E37393B3C3A39393A
413B3B3F423F3A363B3A3B3B3B3A3735383A3B3938393A3A3B3D3D3C3B3C3B3A3C41423C
3B3D3D393738393938363535363937363A39373A383B3C3835363735383737383A3A3A39
393C3E38373E3F40413E40403A383A373C393A383A3E3B3D3B37393A363D494A4342403E
3C3B3D3F3A3E3C3C383E4C48413F3B3A393A3C3E3F3D3A3B3C3C3C3D383A3B3B3A3E454B
443F3B3A3937353439383C3B373D40373A3A39383839393A3C3D414039383C3D3941373D
3C4141383D40494F4F57647F9197A6AFBFD4D6D1C0C8AB977E5D55414242323B3A3E3D38
393838393A3B3B3B3A3A36343737353639383737383839393A3A3A3A3A3A3B3C3B3C3A38
39383739403C3C3C3837353036373A3D3B393D433F49444544423C3D41373D334038383C
3A535A81768F7C7F7671695C5F656758745A51453F423C403D3E3C383737383737383938
383A3F433C4748433D3C3D37433C3939383E43413B3D3F3E3B39393A393D3A3D3E3F4F62
6B84838F92939B8F8981717E6F6B626D75757A7B7A7E8793A9B6C5C2BFB9BEC1B8B9BDC4
C0ACA6A2A3AABAC8CCD0D5D7CDD2D8D8D5CFDBD9
4E4A4C4F4D4A4A48464546474949464448454142464A494649494948474746464C4A4645
47424046494B44443F4845444A4A4B4B4B4A484746454444464746464A47434244464849
43444544424243454B4B48444447474446464A4D4C474546444947474B48444741474641
42494A4645434245423C3E424844424649464342444B514C4341403A3F3F3D3B3D41423F
3F3F3E3E3E3E3E3E3C39414343433E42434B4D4E4C535F54473E4747433E363E3A39393B
3E3F3D3B4F515D5653535A4B61777DA289834D483F444440424A4D4B584D64586F718586
93A093928986776D61564F4942434642423D3C3D3E3E3F4348474A434A4039393E405A53
7C74765955595A6B75747E837C665D6A658878938A8A76877F9588938D927E6A7D658D7E
9C99B194835C6B63617290B3BDAEA0987A83697F678B9FBEC4BEB4BB7E9381827B7B5F53
675A8A7B564334404B3540423E403B474668776F75878CA984874B49403D3D3F3C38393D
3C3B363C3D383C3D393A3A393939393942423F3A393C3E3D3D3D3D3E3E3F4041423F3C3D
3F3F3B383C3F3F40413B383D393939393A3A3A3B3E3D3A3735363838383A3A3737383836
3D3E3E3C3C3C3A373836373C3E3B3A3E3A3A3939393A3B3C403B35373C403E3B403C343C
3D34383A3E37383D3B393B3A3A3A3B3C3E3D3B393B3836373A3C3C3A35383A3A39393A3B
3C35373D3E3B36303A3A3A3C3E3D3935373A3D3C3938393A393A3B3B3A3939393E3D3B3A
383737383735353737353435373A38373A383538393E403B373638393E3C3B3B3C3B3733
3940483B343A3A3E3D393D403C3A3D3C3F3C3B3A3C3E3E3F393742473E3F453F42414040
404142443F444541383D4B443C3A3A3B3A3837383A38393D3F3E3D3D3C3C3C3B3B3C4043
413D39393A3A38363A393D3C383B3D353B3B3B3A393837373936373A3D3E3B3638433839
3A3D4940486570A1758E84B4CBC1BCB8B7BEB5A17A7849563C4B3E3D3C3B3338363B3434
3A3838383A3B3A393B3A373637373636413C3734343637373A3938373636363538393939
393838393D3A3D403D3D3C3637373A3D3C3A3C413E3E3C3A3A3D393B36443942313B3C5A
697E908B8673716469676B676E74655648383735343835363A3937353536363636373736
36393D403B3C3335343038373733373A393A3A343A3C3C3A3B3C3A353F424151595B7C9F
B4BBC3BDC0A69D7E7F6E7778968DAEBCD8D7D3C8B4A8B2C3C8D1D6D0CBCDD5D8D1CFD2D1
DCDADDD5D1CED1D8D9D5D2D1C0BEB9BDC4C8D4D4
4E484A4E4A494B494949494B4C4B49464A49474646484B4F484847474848484846444043
4845444C474B4546414A4644474849494948474749474545464747474242434648484644
42444544434343444544413F4247484642424446454242444045434246433E4142474640
40464742403F4245454343484B49494A484341423C4144424245443D3C3C3B3A3D424341
3D3D3D3C3B3B3B3C3B373E4042423C403B4042423D434B424241474441403A3F3D3C3B3B
3C3D3C3C3C3F443B4241443B5B60887C926B61565A61605B667B827A6A5C616069707F86
7D7F6F6C635D5653423F3F3C37383D3D3F3E3C3F403F40414240413D463F404045423A4C
47504B554A4E525C5E5A595353493E494E4650564E57514F4D586B8494A2AFA98E8B7C94
8BAB9CB79B9A606D47557A9FB3B8BBC6C0AEB28E98809B8B99A4D7CDC1A6A1877E9887A3
9A7E9AAF8D5A473840413A3C3C403A443A4C503E4345404C43493F3F3F3A393A3A3B424A
3F3D373C3D383E403E3E3F40403E3D3B3D3F3D3A3A3D3E3D3F3E3C3B3B3B3B3A3D3A383A
3D3E3B384243403F403D3C443B3C3C3C3D3D3D3D3E3C3A3939393A3B3C3E3D3A3A3C3B38
403E3E41403B3A3C3E3C3E42413D3E41353A3E3C3836383B393837383A3D3E3E3633323A
39333A3F3F36363A393A3F403C3C3C3F4242403E3E3B38383A3B3A393637393A39393A3C
3E34333837383A363A393A3D41403C37393C3F3E3B37383A38393B3B3A39393B56493E3C
393539433C3836383837373B3A3D3A383A383436373E413D38383B3D3C3A3A3C3F3F3C38
383F493D353A36383A363A3F3B3A3D3E3E3C393A3B3C3E3D41393E40373B433D3B3B3D3F
4142434440494A463D3D453C3B38393B3B3737393C39393D3F3D3C3E3F3D3B3B3C3D3C3A
383737393D3F3D3A3A3B3E3D3A3A3A353637393B3C3C3B3B40403F3D3E3F42463C414C3A
5B517E768D7FA6849582BCD1CBB0927D6C625542463F383C393B36353B413B3C3A3E353F
3A3937383939383639383839393A39363A373434373A3B3C393836363535353537383B3D
3D3D3D3C47413E3C373839363938393D3D3B3C3F3B393E40424242403C473D3E565A7A92
94A27C8A6579676377757360514B3A373A33383C3B3C3733383736363637383937373736
3637393B3D3A333C3E363B3B3B37393B38393935363B3B393A3E3E39414A5166707290AF
BAACA3907E73605A62707F9DAEC8D2DBD4D3C5BDA895A3AFB6BEC5C9CDD6D9D9D7D8DCD4
DDDDDACFCFCCCED6DCDAD5D4CFCEC6CED6D9DAD5
4F484B4E47474D4D4848494A4B4A47464748494947474D54454444444647474745444143
4745444A45494446424B4745434445444444454649474545464748474645444444444342
45454646464645444242403E414545433F3F4041414143464A4B47454646464842454440
3F43423F404045444446434546454748443E3C3E3C44413C4145413F3F3F3E3D3F434340
3C3D3E3E3E3E3F40413B3D3D3F413E433D444B49403D3F3C4449443E3D3E3F3F4443403D
3C3D4042383C413C4440413E4354596A596F5B70696C666170898E81866B534D44494C53
444F4743414647404343413E393B414541423D3D3C3A4042424544424A4147403B35413D
46363E413F474D4D4C52544B4F394944474F4A66658673967997859998ACA6A394647B7E
A8A3C3B0C29B987C776D6F696A7B90AEB4C7BDD0999D766A719495B8898F5A4845514F5A
948EAD9EAF9C8254403A3E3A3C3D3E38424A69615A554641383A43423C3A3A3B3C3C3F43
3B3D3A3E3E3A3E3D3E3E3E3F403E3C39393C3C3A3A3D3E3D3C3B3939393A3B3C3B3A393A
3C3D3C3C4B483F3A3B3A3D463F3F3F3F3E3D3B3B3E3D3D3F3F3E3E40393A3A38393C3C39
403F3D3E4245433F413F41423E3B3D3D37393B3C3A39393A383B3C3B38373A3C3E393A3C
3733373A484140413C3A3A373A393A3C3F403E3D403D3B3A3C3C3C3B383838393A3B3B3B
3E35383D3A3B3E3939393A3E41413D393A3C3E3F3C38393C393A3D3E3C3A3B3E4C3F3738
3631353E413C3A3C3C393C423D3F3C393B393639343A3D3A37393C3D3B39393C40413E3B
3A3C3F3A3A3D39353C363A3F3B373A3B3B3C37393A393C393B363A3D383A3D373737383A
3D3F3F3E3D484746433F403A403B393B3B3A3D43443D393B3B393A3E3F3C393A3D3E3D3A
3B3B3B3A3B3C3A353A3C3E3E3B3A3A3837383A3C3D3D3C3B40424141474D545B60746B85
7E9AA2AA818380AA89ABA1B67E694F47424044403F3E4F474036383E333C36363437313C
3A393838383737363836383B3A3B3B37333436393B3C3B3A37373838393A3B3C3D3B3D41
4142423E3C37383937393C383D3A393C3D3C3C3E3F383B3B3A384442435A65779F909E93
958A7A6D797676615B5952433638313A4138363634393D3C3F3D3C3C3B3A3B3D3A393837
36363738393A383B3D3D3D393E3A3A3B383A3D3B3C42443F3B3C3F3F43525D6569676D77
6B614F52436D6D92A7B6D2C8D3D2C9B7A09D89887E7488909CA8B5C9D2D8CFC8C4C5CFCF
D4D6D6D9DEDCD6D5D7D4D0D0D1D7D0D9DDDFDDDB
4F4A51554A484D4B4748494948474646454547484745494F4B494848494B4B4A46484544
4643414547494449464E4B4C4344444342434648474543434546474747433F3E41464A4D
464544454747444243444341424444414545444241424547414145484644434042434341
4141403E4142484242473F3C4442434747434040404C44383D3D3A403E40403E3F42413E
3C3E4041403F3F40443C3D3C3D3F3C413C414646423C383D3C463C3C403F474643444543
403F404242424C47443A42435156705B676162675C605F5E667272696352464844454544
39413E3B393C433F393A3C3D3C3B3A3A3C413D3F3E404E535E6B6B6E705C5C444F525950
5A5D645D615A5856565D605B5F4D735D8A6A8E92BBB8B0899B7C806D5F5355554E666188
7CA596C2A5AE7C8E67697A71696C67738A80A585A56F6F4B4159545C656159504A473E48
55495A677B958971614248453B454E5B7B8FBABEB6AF9385615B47393E404141403F3B37
363D3B3D3C393D3A3C3B3A3B3C3B3937393C3B3A3A3D3E3D393939393A3C3F41393A3A3A
39393B3D423F39383D3E40493D3D3E3D3D3B3A393937373A3B39393B38393836383B3A36
3B3E3E3B3E4545403D3C3F3E393B3E3B3D3D3D3C3C3C3B3A36393B3B393A3E423E393A3C
393C3E3D413F41423F403F3838373738393939383B3A3A3A3A3B3B3B3B3938393C3D3C3B
3C353C433D3C3E3839393A3D3F3F3C3938383B3D3B383A3E3A3B3D3E3C38393D3D3A3A3D
3E3D3C3C3F3B3B3E3C383B433E403D3A3D3C3A3D35383A39383B3D3C3B3A3A3C3E3E3B39
3D3D38393B3C3D3A3E383B403B36383A3C3E383C3D3A3E393B3A3B3936373B3C3C3A3939
3A3B3A393D464041463F3C3C3C393B4244403F433D37363C3F3D3F443F3D3B3A3B3E4042
393B3B393A3C3C393A3C3E3E3C3B3B3B3B3B3B3B3C3C3C3C3A424F6D92A5A3A092879F83
A684988591777F757458504A4140373A3C363938433C353E354139393B3F393E383C3A3D
38393939383838393935373938393B373637393A393837373234363636373A3C443E3D3F
3F41413B3A37393B38383832403C3A3C3D3C3C3D443C3D4043496B6F96B7ADC399968680
7F7767675966494242423A38363D384138363A3F3E40423D3837383A39373A403D3B3937
3638393A383A3C37383F3D3A3836393B383A3D3B3A3D3F3C3A3C40433E474D4B4B483F40
40445B669BAEC3C9C5C2B3A68594787F747C808E98A1BAC9D3D2CED5D3D7D0CFCDC6C9CB
C8CAC7D2CCD3D4D4D6D1C9C7CFD8D0D9DBDEDDE0
4C4B585E514A4B464A4C4D4D4B49494A4947484B4A4746494A4845454647474642464544
4645434741413C4240474549464747454446494C45434141434546464A47444344454646
454241424545413D3E414343454949474A494743403F40414641454743464A4641414143
42403F3F3D3F473F414A403A3C38383F43423E3C3B4D443539383644393C3E3D3E403F3C
3D4042413F3D3C3C413A3D3D3E3E383B3E3C3B3D44413B423D483B41453C44413A404748
45403D3D373547463E384D544950554943534A564951595A534A4441413C4142443E443E
3C3A39423F363E45423F3A393C3E3E3D383F3C3D3A3A4A4F5862565965678376A18FA086
A5889585846A636D716F6B6A595B5678608B799F8EA4807855584140423A424040453548
58565D6C80686569705D584E5E7A76796E685A565550444A4E714E64698A95AF856C5D43
4A3B4B49485B778AAA916D746F878CB2C2CED1CAC5C4ADB2898E5C464445433F3F42403B
353D3B3937373D3A403D3B3B3C3C3B39373939383B4042423E3E3D3C3B3B3D3F383A3A38
3535383C3D3D3A3B403D393D38393A3B3B3B3A393B38383B3B393A3D3E3E3C3A3A3C3A36
363D3F3B383A3F413B3B3F3E3B4146414343423F3B39393B3E3F3E3C38383A3D3F373839
3B42423C3A3B3E3E3D4142393C3B3B3A3A393939343536363738393A3E3B38393D3F3D3A
40373B3F37383F3C3A3A3B3C3D3D3A383635373B3B393B3F3A393B3C3934343935393836
373C3A343A37393C3A34373F3E403D3B3E3E3D42373A3A393B3E3F3D3838383A3C3D3C3A
4041393937353F413E383B413C37393C3F423C40413D413C373F43433F39373944413D3A
3A3A38373F473C3D463E393D3E39393F413F42483C383A42443E3A3C40403E3B393C4247
3B3D3C38373A3B393A3C3D3E3D3B3C3E393938393B3E4144556C89A6BBB7A59B877B736D
6E685E564A47484642433C4138423C3D40393C3D3B3F3C4535393A393735313C353B3E38
37393A3A39393A3C3B35363735373A363A3A39373535383B383A3C3B39393C3F483E3B3B
393C3C353C373637363A3E3C433E3A3C3D3C3C3D3E404E677C93CAD5C0ACA1878078866C
775E5C3F3D443338343C383B3638343F3B39383936383E3A3A393A3A3734363C403D3937
37393C3E3E4047403F433C3A3A373A3C393C403E433F3C3C3F4141413E3A3C393E403941
426B8DA6C7AA94707B6D727F758A7B9B8EA3BDCCCCCCD6E3D3D2CED7D0CEC4C5AD9D9394
96A9ACBDC6D0D0CDD3D8DBE0E0E8DCE4E4E3DBDA
50525658544D4C504E4F4F4E4B494A4B4A45474A47474B4C4746474C4C49484A48494A49
474647484744464845474A474042444444474C504A49484747484A4B4B47464948454547
45464747454444444342424243444545454A4F5656473B3F394445414449484841434345
48413E463E42504544404245373F4141434140463F3D3D3F3E3C3F443B3B3A3B3D404345
3B414043403C414040443A3A3E3C3E3D3D423C40434348413D3D3B3A4046443D4046423D
3E3E3A3A3A424846494956474C575C5446404143414B4F484344423C3F3B41463D393B3B
393C3F3E3C3A3C3E3B38393C3B383A3D373B3A3E3D45403D3D47443E3C4F6392879E8495
7D95757D5D60676B69675E4F433D43474846594F4B4A41433E37444B463A44353E363C41
3A473F47404A3E443E577B8E968C737071425851534B4656526E6E766E7B7D958D85835E
57413E433D4855A1B7C6CDD2CECDCFD0D5CAD0C9C9C0BBAF9C906272627E91796D644745
3D373F463741464A4D5048493C363C38393D3B413E463F3C373E3D3F3F3C373B3C39373C
3F3B3A383A383E3E3E413F443C3937383B3D3D3C3D37373A3A3E403B36393C3D3B393A3C
3738393D40413F3D3F3E3A373A40413F3C3D3E3E3D3C3A383B393A3C3C39393B3A383B3D
3C43474138393A3B3B3D3F403939393A3B3B3A383634363B3D3B3C40383A3B3B3938393A
343B3C3B3E3B3A40383E3D3B3B393A403838393A3B3D3E3E3437383735363A3F3C38363A
3B3A393A3D3F403F3D3B3A3A3437393938393B3D453E38373A3C3A363937373A3E403D3A
3C3B37383A383939403D3C3F4244413B37413F3B41443F3C3E45463D373C41403E3E3C3A
39393A3A36373939393A3C3E353637393B3E40413A3B3D3E404141423B454445433F4444
3A3A413D444640403D3A3E423E3F403C3738393D3E3C43535B8DA0AC969E827558464449
4A454B505F677E6C71535141413B38393938383A373B383C3C383B373637393A3B3B3B3B
3D3C3C3D3C393B3F373636373839393835393C3A3735383B36363A3C3935363B3937353A
3135364036353D35373A2F3A323E433C3F3B3D445C7094CADEDDDEC7A1848F948A7F6961
3B373A3B373A3E3B383C3B3B3B3536423E3539363639373E3D33343937383D3C383C3D3A
37383D433B41434E41473C3C383A3B3B3C404548433F3A3D3D3F3B3C383F394244445F6A
6C7F79867D646A708C88A6A8A1A1A89C96A5BDCBCAD3C8D0AD9B976E7E626A5865506066
5E6E6F6F6D7C8A97B0C0D1DFE1DEE5DEE3D4D8C3
4B4B4C4E4B47474A4A4A4A49474646464742454845444646474545484846454844454646
45444547464244454244484642434443424244474545444443434343454343464847484B
414141403F4041423F4041424344444346494B51524842483C4646414446454440434141
44403D423F3F493F413E3D3D3C43444345413F42423E3D3D3D3C3E433F3F3E3E3E3E3E3F
3A3F3D3F3D393F3E3D423C3F4440403F40443F42444448423D3E3F40424545433D42403C
404240413B3C42444B4C5E594A4E4F4A433F3E3D393D403E3B39393737383D3F3937393B
393B3C3C3B3B3D3F3D3936383D403D393A363E36423B48484244453F3D3C374842523D49
3C503F4A413F41414044453E403E444448454F4A474841423F3A3F3E3E36443A453C3E3F
4246403D3B434449526B868E979D928F6B485161646F5A654E68646559625B6665646A53
56464C5151484B7192A0C4CED3D7D6D5D0BEBDBCB1B0A1B6BECBB2B7AEBBCECEC7B88C80
6C3E3C3D4B6E728B9197847F584945423F403C413D4039383C41423F3E3D42493D393537
38393E433A3638363B433E3D393A3B3B3B3B3B3B3E39393B3A3C3D3839393B3C3D3C3A39
3C3C3E404242403E34393C3D3E4142403A3B3C3D3D3B3A3939383A3E3E3B393B3634383A
3B454C4A3D3A38393B3D3D3C3637383A3B3C3C3C3937383B3C3B3B3E36373A3A3A3A3C3D
383E3E3D3F3D3B3F3A3F3E3C3E3C3D423A3A3939393A3B3C33353839393B3F433C38373A
3B3938393C3D3D3D3C3B3A3A383838383A3A3A3A3B3C3C3A3736383B3737383B3E3F3B38
3737393B39393F4245413C3C42433F3C3B52584A414345484145443D383A3D3D413F3C3B
3A3B3C3C3A3B3B3A3838393B353537393B3B3B3A3838393A3B3B3B3B363E393B41414442
474C4B786B7C514C32313639383D403D373A393B403E43525769775B57444945474B4C59
5F7B8484849D8A9D62683D403A36363B3E3E3E40383C393D3D393C3839393A3B3B3A3A39
3B3837383736383C3837363738393837353638383837363638343535383B393C3736373D
3939363938393A373B3D373D383F364440626F81C6CBD6EAE5D2C4A7A5A29C947E64554C
3D393B3B37373834373E3F3D3C38363A3C3538363637343B39353639393A3C3C3A3A3A3B
3C3D3C3B3A363A353C3A3D393B3938393C3F3F3F3B37393B3C3E3F47455764819399AAAB
A4A29492819090ADB9BDB4BBA3C2C5CBC3C4CBC5B19C7D7358564C423F3A49464A3B4E4C
4B4A4E4947545C7180A1BBD6D8DED8E0D1D5D2CB
514F4E4E4E4D4D504C4C4B4A4A4948474A45484C49484A494D4B4A4A4A48484A46474849
4848494B4B47474845474C4A484949484746454549494949484745454745444546454649
474543424344464748494A4A494643414444434648434249424A48434445424245484542
454644444442473F4344413E4145444344403C3C413E3D3E3F3D3D3E414140403F3D3C3B
3F434042403C424144484143463F3F3E41454141424345403B3D4143434143464447443F
403F3B3C423E41414238413E3C3C3D3D3C3C3E403F3D3D3E3D3A3A3C3F4546403D3A3A3D
393A3A3A3A3B3D3E3F3B36363C403E3B40433D4A3C403A43423C403B403B38373F483E41
3E433A42433E3D3A363A3E3B3C414B464E4744444A4C443F41464B45403C4D4754484945
51494A44525D70705D6470777D755B4D5A3F51485F514E4D4C6362676572696B6D6F766B
766E8289866E58566066848B96A4AEC9D6D2D1D6D2D2C1B1BBABB1A5BCC2CDD7D0D0B2B0
8B56443B52727F9AB2BDC0B89C736A55514C423F393C3C3F3D39403B453E41383E3C3D3C
3B3B3C41413C3C383D453D37393B3D3E3C3B3A3A3C38393B3A3C3D383B3A3A3C3F3E3A36
3B3B3B3C3D3C3A38363C413F3D3C3C3B38393A3B3C3B3A3A39383B3F3F3C3A3B3E3C3C38
363B403F403B37373B3D3B383738393A3A3B3C3D3B39393B3B39393B3A3B3C3B3A393939
3A3D3D3C3E3C393B3A3D3A383B39373B3D3C3A3837373839383839393A3B3C3C3B39393B
3B3937373A3A3A3A3B3A39383B373537393A3836383737393A3A39373737383B3E3D3935
39383B38363E3F3741423C393D3B373B414F5248414142444142403C39393A3B44403C3B
3C3D3D3D3B3C3C3A3837383A3A383738393A38373B3B3B3B3B3B3B3B3B3B363B3B3A526C
7B7AAFB0B2755E44393A3B3A383D403B3B413C3A413E3C47444B42453D4B506278727774
98AFB08C81787C57583A433A403C3B3E403E3A38383D3B3F3F3B3D383B3C3C3B3A393838
3D393536353436383938373738393836343435373939363337343935363A34373B393536
39393B3C393D3A393B3A3E414248506F7CAFCCDCEDE8E6E3D8D4D2C6B8B4897B7D706855
44403F3D39393C3A3A42413B3A3A37353936373636363237373B3A393A3A38393A373638
3A3A3939353D2F403341343A413D393838393C3E424D4A76618777928E9FABC5D7DBE0D5
CABEB7969A849392A3AAC3B4D5CAD6C0AE9B8A76695A504F525642573F46454044444552
495A5C666B728F96A29AACB4C7C5D7C4D8C3DBCF
4D4A48494A4A4A4A48474545464644434540424644444746484746454442424241424242
424343434541434340424543414243454544424146454545444343424A49484645444547
46444241424343434647484643403D3B46434142423F3F43464B49434545424140423F3B
3E42423F403E423D3F433F3E4A4947454543403F3C3C3D4042403D3B3F3F3F3F3F3F3E3E
41454245433F43424A4C4242433C3E404042403E3E3F3F3C3B3A3C40403C3D4140444240
42403C3D413E423D3E333735383A3C3C3B3B42493D3A3836373838383943413A3B3B3A3F
3C3A3938393A3C3C3B3D3D3E403B37393F4350545A514D46493F473B3E36413C3E40403C
433D3C40403E4243404245423F4347373F382F3538454A494E565345404257576659584F
5F515B5065626F5F655748434749444143434A4847464754606E6F7B828F898C91909088
938CA7AEC2B4989481898786797A7491A3A194959EBEC8D4C4B9A89C8691929DA0BCBACC
A1917052493F4F4F72697E6B866D96868889827465594C423A3D3342384C44453C3B3F3F
3F3F3B3C3C3A3E3B3D3F39383D3D3C3D3D3D3B393835383C3C3E3F3B3D3C3B3C3D3D3A38
3E3E3E3E3E3D3C3C3F41403C393A39373A3B3B3C3C3B3B3A3B3A3B3E3E3B3A3B37393A37
35383B3A3D3B39393A3A39373B3B3B3A39393A3B39383838383838393C3D3D3C3B393736
3839393A3B393737383936363B3B393B3E3C3937353637383A393838383836343A393A3B
3B39363538373637393A3938393636383937373734383B3C3B3938383737383A3B3B3835
38333938353C3C36353F4243463E3940413C3A3E403D3A3B3F3C3B3B3A3A3B3D46423C3B
3C3D3C3B3A3B3B3A39393A3B403D3938393A3B3A3D3D3C3C3C3C3C3C3F3C3F49434B789B
828C96AA6B5B39403C3F3E39383D3F3B3D4239354142404B4F5C516B627D7A91999B8E8F
7E8C7B6B4E4542363F3A3E393A39393C41413E3B393D3B3F3F3B3D393C3C3B3B3A393938
423D3939393635363B3A39393A3A39373636373839393837353239363A413839393F3C3C
413F4241413F3A3538445462969DBAC7D8DEEBE2E6E3E2D9D1D8DFDFD5C89981847E7263
4D47423D3C40474A41423E38363737353A3A39363837343839423F38393834353235383A
38343438363B383F423938403D3F43474C5566749A89B2A5C9B1C3C0CFDADDE6E8DED0BB
A28C806D669593B4B1C1A3C1A5C19B939D928C85867674706E5762596D5769515F616E6B
7E7E979EACADAEBFACB4B8C6B8C9BBD4C1D9D2D8
4E4D4C4D4E4F4E4B4F4E4C4D4E4E4C4B5149494B494A4D4C4B4C4C4C4A49474548484847
474747464846494B4748494646484A4C4D4B49474A4A484848494A4B4749494745464748
4B4B4B4A4A49484847484949474647494845464746434242434643404242404045454441
42484A46404145403E433F404743403F3F3F3F3D3B3C3C3E4042403E3F3E3D3D3D3E4041
3C413F42413D403D45463E40433D40444041423D3C3D3C3A3D39393D3E3B393B3A3F3F41
44413C3D3D3C3F363C3C43443D3C3A3837373B3E3E403D383B42433E484F4A403F3D3A3C
3F3D3B3939393A3A3F3D393C403C3F4B616771727D7B7463514F615B5F50594C4E48473B
42393F413F3C3F413D3D3E3C3F3F423442494F5A555E6056545A54494A49524C5B54605D
665E70606851533C3E444542434A4D46474D51494443485352524E585A5C575E6C6D777A
8C859EA0AEB1B6C1BECCC3BE978567717773676668607F7A907E827D8590898F8C9B909D
C2CBB5957E656C5F715E735A735D81718DA4B8BAB5A9937C6D60523D3C3B423D3F383A36
383C3636393841403C3B3C47443F3A3A3D3F3D3939373A3D3C3E403C3C3E3E3D3A3A3B3D
3D3D3D3D3D3D3D3E3E3C39373B403F3B3E3E3D3D3D3C3B3B3F3C3C3D3C39393B30363A39
3A3C3C3B373A3C3C3A3838393D3C3A3838393A3B363636353537383838393A3B3C3B3A39
3737383A3939393737393738404342443C3A3836353638393938373739393735383A3B3B
3A383735373635363839383738393B3E3B383B413A3A3B3D3E3C38353938383838383736
3E363F3C3233374256534A46453E3B413E37373C3D393A3D3D3B3A3A3B3A3B3C46413C3A
3B3B3A383B3B3C3A39393A3B3D3B39393A3B3B3A3B3A3939393A3B3B3F3D444942547371
735C654E49374038393C3B383A3F4140373C3B43575F636F7F889284887C879092797461
5C414644393E2E46364A36393B3A393A3C3E3C3A3A3E3B3E3E3B3E3A3B3A3A3A3A3A3A3A
403C3A3C3C3937373D3C3A3A3B3B3A3937393B3A38383B3F3A393D38353A3E464153504E
49403D39453B42486087A2BAE0E1EDE5ECE4ECE6ECE7E3DCD9DEDBD4C5AF957567645556
4A47403C3D41474C423C393937353637373B37373F43484E3B433F37383834363D3B3A38
3431373F3A434053635C6070797C82898E95A4B3C2BAB9D2CBDED4DBDBE2E3E5E3DACDBC
A7A2A38EA794B09C9C8A9482A094A89FABA69D96917B7C74766D627C5F79666B7D9197B0
B1C4C5D1D6CAD8D6DBCBD6D3D3CBD0B8CDB7C9BB
4A4B4B4B4C4D4A464A494848494948475349464643434544444648474646444144434242
42424140434144474343433F43454748474442404341403F3F414344484B4C4845444444
4243444442404141414242403E3F414443414346454545413D403D3B3F403E40413E3F3E
3D4145424547494641463F41423D3C3C3B3E3F3D3E3E3C3A3C41444441403E3C3C3C3E3F
3D403E42423E423F40433E43453B3D414242453F3C3F3B3B403C3A3C3E3D3C3B3A3D3E41
45403B3D4243493D44434445413D36343A3F3C35373C3B373A4446403D3F3C3839393839
403F3E3B3A39393A3B3B363C494E52606C756D77778D80756A6E81828A787863524E4C41
443C3D38474040413E3E41403D3E4C4E63788C908073624B47545C616E737D768071796F
84838C71684D504651524C4945484F4A433A483442363F37413C3A43423E3F4A55587282
988F9B96938FA69BA49E998B8172626C74787E818E614C494148495D5D6F809C9D9F9399
AEAFB4AAA0968F898C8597907F706556597598AABECACDC3B3B0A98074524B40433C413B
3F473F413D3D433E38383B47474039383C3F3E3C3F3C3E403C3D3F3B3B3E3F3E3A393C3F
3A3A3A3939393B3D3B39383A404440393F3F3E3E3D3C3B3B403C3B3B3B39393C373E3F3D
3E3D3937353A3D3D3937393C3C393636383A3C3C34353533343738383838393B3C3B3937
39383B3D3A3B3C393B3D39393E3E3C3E393837363637393A3E3C3A393A3A3836373A3B39
3838383637363535373838383A3C4044403C4049413B373A41413A313938373737373838
3E3D4134364646496C5946403E3B37373C3C3D3A373B3E3B3E3E3D3A3A3A3A38423F3C3A
3B3B39383E3E3D3B393838393436393B3B3A38373D3D3C3B3B3C3D3E413B3E4138414E39
3F363A38353F3F3A3C3D3A383B3B3B3E3C4658748A8D8A8E989A8E7D6F6B6A716A4E394C
4240353C3D37403541333D3937373737393D3F3D3B3E393C3C393E3B39393939393A3A3B
3837373B3C3A38393C3B3A3A3B3B3B39383B3C3A37373D423C3A38393C414E595163514C
4449525A74697B8CACD3DEE9E9EDE9EAE2E8E4E4E2DBD4D5D1BE9F8079615C4A41473D43
3F3F3C393B3B3A3E3C36373C3A37383933424449524C4644393C3B38393A3A3B37333339
3E424B5448655F8A959F95A59A999FAAB3B7BCC3C4B0B8B8D4D6EBE2E6E6E3E0DDD6CDC4
BBB19E947A84706F6C7E7CA788A4859773776B6D706C807D8C6F7C5461628B9DC5CADCD6
E1D8DAD6D2CABCC3B4B6ACAD979C78826879686C
515353515152504C4B4B4B4B4A4A4A4B554B494A47474946474A4B49494B4B4847464546
474746454745484A4646474346484B4B484543434646454444444545474C4D484342413F
414446454242454844464543403F4245403C3F42414345403E3F3C3B4142404347424446
41424645404041423F483D3C45414345434547433E403F3B3C414445403F3E3D3C3C3C3C
3F413D40414045433F423D4344393B404141453E3B3E393B3C3E3E3C3B3E4040383A3B40
45434045484750495149444944423C39414B463A3E41424043484845443E3D3E3D3C3B38
3F40403E3B393A3B3D4C4E4F595954576E6A6E61716E70605A5C605B5F4F4E3B3F414242
444742393F3C4450555A5D5C615E6D768294ADA187705E5055646A73767B81767D6E7B73
666A69534A3E44484A443D44423F423A433E43453B48434441444C5656565F6D6F6A848B
98878378857C95859393958F8C85878F908F9C98927973665B444D474D5E85AEB3B2A593
B9BBC7D5C9B9A8998E78776D4C57464638404F556672868E9DC1BBC8ABAC868B57505343
3D423A3F3D40443D3E453F3A44413C3A3B3D3F40434041413D3D403D3B3C3E3F3E3D3D3C
3E3F3E3D3B3C3F413C3D3D3D40423D363E3E3D3C3C3C3C3C3C3A393B3B393A3D363C3A38
3D3F3C3D3A3B3B3A38383A3C3D393434373B3B3B36373633343739383939393B3B3A3633
3A393D3F39393B393E3F3A3739373335373737373738393A3F3D3B3939383837363A3B38
3638393837373736363638393C3B3E43413D40483C3D3E3D3B3939393738383838383838
33373930486151484C3D3D44423E3A323C3C3D38353B3F393C403F3A393C3C383D3C3C3C
3C3C3C3B3D3E3D3B3938393A33373A3B3A38393A41403E3D3C3C3D3E3E3C3B403B3C433A
3B3C473E3B3A3B3C3B3B3B414848495264677D999F92847E7E7C575E43543E483C36403F
3F333C3F38383B3D3C37383B3D3F3E39373838363B3D383A3A383D3B3938383838393A3A
3837383B3A38383B393838383A3A3A393637383837383B3E3B3C3D586A6B7372596E545A
5A768A9AA19EB2C5DAEDECE8EDE7E4E6DCDFD8CAD9BB8C776C5F57473F3B3F3E3B3D3B39
383B3937393733363734383C3A3C3F3E4E574840423B3A3A3836383C3B3C3D3C3B3A3D44
4541444B4E809AB0D1CACFD2D0CBCCD3D7D4D3D6C4C4B4D2CAE2E0D4D1C8C0B9B0A08D81
746B5B4F4F455A4F615D6752575550625D726E80827C8271727465726397A4C6C9C6C3BD
AEB5A6A69282715A594C4C4A4A4B4438433B4643
4C4E4E4B4A4B4A4745474847454546474D4444474747484645484846464A4B4944434243
454646444743454642434542404447474441414246464646454443424046494743434341
3D4143423F40454B3D3F403F3D3D4144454041424044484342433F3F4546444747404346
403D41423F3E3C42445044403D3A3F423F40423D3B4042403F4142403C3C3D3D3D3D3D3C
3D3E383A3B3C43423D3F393F423B40493E3E433B383C3639373D3F3A373B414343434041
433E3B4148404741493F3C493B403D3539423E313C3B3C3E3E3C3B3C4136373E3E3E3F3B
3D4041403C3A3C3D5D716B564F4D4A4B3F43434A494D423C3A3F3E3A413C47403E423D3F
3F4C463E3F42546B75787670685A60646475958172574943494E454653575A4E58526967
5F6560544F463F403E424043454E5C5374687A5F4E424A4A515A686F6D6E798594849691
97847B70766E7A7572857F857F777C7C756E7B7068766A67514F6857686E96BCC0BFA76F
76909AC2AD8B83626A4D59524A5E504E524B4D474942505B52607184C5CEC2B2B8A89A70
524A3F464249504D596958424141403D3A3A3F43433F41413E3F43413A3A3C3F42413D39
3D3D3C3A38383B3E3C3E3F3D3D3F3D3A3C3B3B3B3B3C3C3D3837383C3D3B3B3D363A3431
383C3B3E3F3C393738393A3B413A343336393937383A383434383A38343536393C3C3A37
39383D3E363538353B3E3A383B3A383B37373738383939393636353537393B3C353A3A37
36383A39373838373536383A3B37383E3F3B3C423C3C3B3B3A3A3A3A3637393939393838
3B373C40575B3C3A42363D443A373D3A3B3A3E3E36384042383F403A393E3F3B393A3C3D
3E3E3E3F3A3B3B3B3A3A3C3D3A3B3C3936373C41403E3C39383838393A423D3A3C3B3A31
38353F38423E3C3C3C3F46586B727B8B95888E998A7160585B50473F453B3738393E3F3B
374241353D3A363C39393638363B3D3A393B3D3C3C3D373838373D3C3939383737383939
3E3C3C3C3A36373A373636363839383735343435373939383F597093957F868869897589
89A4A8AFB8BAC4CED0D4D8D4E4D2E2D9D9C3B9926C5F4141443D433B3F4132363B3B4336
3A3D39363A38363A37363938363F4744414C3F3A3F39393A3A33383F3D3B3C393F3C3A38
35384A6078C2D1E0DEDED9DFE3DCD7D4CBC0BFC4D5CFD6CCD6B7BE938D7B6C6561584942
433F3C453A49474B4C5A5A61698F779678856C70676368555449644F877C988A91807F67
5A584B4644463D3A3D3E3A3D39483C443C433F44
4A4B4B4B4B4A4A4A4645464949484B50474545474B4B4845454144474547484348454343
4344495047474746464545443F4347474645474A474647494846474B4443434342434344
44444546474747484D454143423E424A433F3E4144444446434544414144423C3F404244
444341403B403E42424043413C404343403E3F42414B4D443D3E41413C3B3C3D3B38393D
3E3E3C3E413D3B414142423E3A383A3C3E3E3F3E3D3C3A39363E3F413E393E3B3D414340
404344433D3B3C3E3E3C3D413C383A42433C393B393C3A3E3B3A42393A374042383A4340
3F3D3D3D3C41484B70696453443E3C453E43433C3D43433D3B42433E403E3D4640443F41
3C43403F45484F61645F615547473F414C516E665A493A39404548494F5D64575A5A666D
8266514C494746413E584C4B4D53617B8885958C674F4C535C7F6F76798D7785746F686A
69594C4F5754585D5F646154564C484E504B47494745463F4F414C484E4A696FA8B5BD95
4D5266789E968F829884998BAE909F91A39BA79179726D544A434A6289BBA4AAAEC2BEB2
879F6F6B6F7174759488A5858E736A53454340433D413E3D3D37443737324242403A3D3F
3B403B383D3B383C37403C3D3D3A3F3B38383E3D3E423E42393F3D3D39363F4233373B3D
3C3B3C3D373C3735353942413C323637383F3C3837393D3931353B39393938393B3E4143
383D403F3A37393D3C383739393736363534343537393C3E36383836383D403F373E3D35
3740413833383B3938393937393D403F3B3A3E433F39383C3C38393F383837393B3D3D3D
3F3F454842403E3938393A3C3C3C3C3B353A373539393A403E3A3D3D383A3F3E3C403D41
403C3E3B3C3B3939393A3C3D3838393A3A393A3C403C3A3B3B393A3E3C3F3F3E40413F39
35393C393C38354C45576D81898893AAB187776A5449474D3C4143403F40403E3C38353D
343C3A3737363F3C3C3F393D3B3C413F3633373739383F383638343A373838373636383A
373C37413B313C3739333A383338383536383B3D37413D48806F90857C6C71797D838B84
8284939BA9C2A58E8882A5D1D0CBC9BA926B564D43403C3A3B3D3E3E3D3D39373B3B383A
35343538383534353638373E3A37413B353A383F3639383A3A383839383A3D3D39384339
424E727DB8B1D0CCE2CDDDD2CAC5B9BDB6C9C5D1CBC4B3B28B77584F4B3D3F3C3C3E3742
3D44555773707A7BAC98A7759C6C775B534140463D3A3F3B39414A60605F55514244483C
3D383E3C3A3A40433E3D3E394143444A51566B76
4B4B4D4E4E4E4E4F4B49494B4B494A4D474544464A4D4C4A4945474A484A4C4845444547
474545484847454443444546434445444345494C4A4747484745474B44484A4847474643
4444444444454545403D404546413E3F44404042444342433E3F3F3E404343413F404244
444342403C403D414340433F40424443403F40413A3F3F3A3A3F3E393B3A3B3E3D3B3C40
3E3F3C3D413D3B403D3F413F3C3A3B3D3C3D3D3D3C3B3A393B3F3E42403A3E3D3B3E3F3C
3C3F3F3E3D3D4144423D3A3B3C38383C3D383637393D3B3D3C3F48403B363C3F383B413C
40413F3E4044494E504948413C3D3C43393D3E3B3D4346443E424040414044473F423E3B
39424A505B5F5E61616367597D71665D605D62524C464243474B51565C62615153515758
64524B51555655516071584A464D53626B6A7C795E4E4849536252585664505044444346
4A45434A47464A4B494C4D463E475051483F3E4239373E3E3736453638423D435E706265
607475A9B7ADAEAD9CADAEC9B6BFAFBCBBC1C4C1B4ABA98E865D4F495450534E5A666E81
A8C5C8AFB3A195B7C0C2C6D0C0C7A9BB8CA376834D444445364835393E3C3A413540383F
3A3C36383C3B3F4134393B3E3A3C48423A3D4037363F3A36363A373B3B393F3D3A3B3C3C
3A3939393D413C3D3D3E44423E383D3B363A38383E3D3E3B373A3E3A383838393A3B3C3C
383B3E3D3938393C393635383A39383A3837363637383A3B383B3C3A3A3C3C3A3A3E3D36
373D3C36373B3C3937393938383B3E3E3C3C3E423C38393D3D373639393838393B3C3C3B
3E3E4346413F403C3637393B3C3D3D3D3B3F3D3A3D3C3C413D3B3E3F3A3A3D3B353A383D
3F3D413F383838383A3B3D3E393B3B3A39393A3A3A38383B3C3C3D403A3B3B393B3F403E
3E3A3F373C403C576B777D7C7A777D8A896453493F3B383B3B3F403E3D3E3D3A3937363C
353A39373B393F3C3A3B363936363A3B35363B3B3C373B393A3D393D36383A3C3B3A3938
343333485150594A453C3E3C393C3B403E3736364E6B62676569595C4A52586D625F5F6C
58626E8171785C5464779BB0A88E75614C404041413E3B3A3B3C3D3D3A3C39383D3C393C
3A38383A3A38383A393B393A33323C383A3C363A37403E3D30363B3C3C3B3B3E3E424758
5D7192BBC1CACDDFD0D5CACEBBC2CAD8D7DDC1B49A805F5C47483E3F373F3B403E3C5056
67868FBAB0BC9A9A8C8D73634946383B423A3433363F423D3436364240423D3D37383F3B
3F393E3D3B3A3E3E393F4C514E595D768093A5B3
4D4D4E4E4F4F4F4E47454547484645464C494544444543414643444645474A4646444548
484543434746464545444444454443434446494B4C4947474543464A474A494341434545
46454444444546464B4845444443413F4442414444413F3F3E3C3C40424344453F414244
444342413A3C383D3F3D3F3A43434342414041413C3F3F3D4044423C3D3C3D3F3E3C3D40
3F403D3D403D3A3E3B3D40403D3C3C3D3D3D3D3D3D3C3B3B40403D43423B3E3E3D3D3D3B
3B3D3C3A43424242403C3B3E403E3C3C3C3B39393D403E3C3B434C44453E40433F42443D
484C4640434140483D3B3E3A3C4341443D3E3E3D3C3F444744443E43423D433C49445644
62576F697A7266635E5C615D7A6A675B5D5A554845464746423F424752534E4146464847
554A474D4F4B4742515F4B414046414346424F4E4545434244443E46444F46403D424341
403E3E434240403E3D40413B3E4448433C3A3A3B3A4741443E484841433C42423D414242
49559191B5978E81737D9E8DAB95B1BACCCED6CCC8D4CACCABAF849E88886C75667F8093
93B1BAB9C7C7D8D3DBD1D9E1E6E2E2C0CDADA7A59B80845A4C413D4446404438403E3E3C
3E3C3B3F38333B3B403F43453B3F4C4538383F3E3C3E38383C3E393E3F3B3C363D3C3A39
3A3A39393B3D393E3F3B3E3C3E3B423D36373639413E3E3D3B3E3F3938393B3B3B3A3837
38393A3A38383A3B393535383938393B3938373738393A3B373C3E3D3C3B3A393B3C3A37
383A3A363C3D3C38363839393F40403E3B3736363B38383C3B3634373938393A3C3C3A39
39383C3E39393C393B3B3B3B3A393838393C3B393A38373A3A3A3D3D39383936373A363A
3B393E3B3C3C3B3A3A393838393D3E39373A3A373B3A3A3C3C3A3A3C393B3C3A393A3A39
3A343D37414E4A655D69695D575655544D3D37373C3D393B3D3E3E3D3D3D3B383A3A3A3E
383C3B3B3C3B3E3B383936393936383733353A393F3637383A3B36383A3A3B3C3C3A3735
3F424B5E594F503F433C3D3D3C3835413E47605C6A6C4E4B3C45504E856A84798957554F
53414E404E5657697B817C6259483C3C3C3D3D3B3D3C3A3A3A3B3B3A41423E3B3C383334
3C39393B3B39393C353C3D3D38383F3A363B3A39373F3C3C38413F393B3C414D59688C93
BBB6CFD9E5DBE6CCE0C4D1CBDCDEDDD5C6B99176624F404C46473B383C454147484D6E7F
ACAAB19D9E7D7161474E3E3F323B343D3A3C3732383D3A363536353B3B3E393C3F3D403A
3E3940413E495C696D7581879DA3B6C0D5CEDDDC
504F4F4E4E4D4B4A4A49494B4E4E4C4B504D4B4B4C4C4C4B4C484A4B494B4F4C4D484545
464444454346494B4A47434043434345484847464C494847454345494646464643424447
484746464647494A4E4A423C3C41423F4342434545403E3E444040454643424440414243
4443424143443F444745464043413F3F414242413C4143414041403E413F3F403F3C3B3E
3E413E3C3F3C3A3D3C3E3F3F3D3C3C3D3E3E3E3F3E3E3E3E413E3B44443B3C3C41403E3D
3E3E3D3A44413F3F3D3B3D4241403E3D3D3E3C3A4143423C3841473F474141423D3D3E38
4A504740433E39423D42453A3A46423C42403F3F3D3D424A4144445658545C4F59645472
5F775A56564E494B4B4748484940453F44454A453C3D3E3E3C3A3B3D3F413C363D414243
47403D40413F3E3D39453F4345493E3C3F393F3E3F4948423F3B3D403C3E3F3C353C3F3D
3C3C3A3845403B3A3F4440383D3D3D3E404141413B405A58433F594A4A5641484D636A83
8D88789B806A535F6374576D608D8DB1B7CCB5B9B5B2BDBCBBB4BAA5AB9DB5A0BDB4C195
9993948585B3C1D8CCE7DCDBD3DAB8C8A8B493AA96978E7C5444464F4F4E51454D525355
44363B3E37383C3B39363839353B433C3D373F403C3B383B373B393F413D3E383C393839
3C3D3D3B3937333B3D3739383A393F3C383A383C3E3C3F403C3C3C373B3C3D3E3D3B3938
3838373738393A3A3B3837383836373936363738393B3D3E36393C3C3A3A3B3C39373637
393A3A3A3B3D3B383639393838393A3B3A3937363B38373A393636393939393B3C3B3937
3A373A3A35363A383D3C3B3A39383736363838373635343637383A3A373636353A3B3739
3A383B3840403E3D3A383635373E3E38373B3C373F3D3B3A393838393C3D3C3A38393A3C
433E423E4448414F41494A434143413C373B3C3B3F3D373B3E3D3D3D3F3F3C3939393A3C
3A3B3C3D3A3A3B393838393B3B373837343639373E35373B3A3837373A383737393A3A3A
59595E614B3C433B423B38373B3D45606D5F5D4749483F3E5B7D709E8EA3A2BA8A7B7A8D
595F60616C604B4544464A3A44404045443E38343A3939393A3A39383C3F3C3B3D3B3738
3A3736383836373A373C3C39373839333B3B3A383B3D36383C474545586B7E94A1BDBFD3
D0ECE3E7DBDCD0D5D9DFD8DDDAD0C2A58A735545463A394442403E3F3A37464A52647490
867C715B51403B363A383E3141333834373837373733313435373A3B3D3E3639363A403A
45526A748192ACC2CED6DCDEDCE2D7E7DBDFD9DC
4A49474748474543454545464849474447464545464645444642444542444745504A4646
4645454745474A4C4C49454244434345484947454A484848464344474343495352484447
4646454546484A4B44454340434847414241434645413F404441424647423F4040404142
434242413E3F3A3F413F3F393F3D3C3D404243424043454443444341423F3E40403D3C3E
3E413E3C3E3D3A3C3C3D3D3D3C3D3E403E3D3D3D3D3D3D3D3F3C3943443A3A3943403F3F
403F3D3C3A3B3E41413E3D403D3D3C3B3C3C3B384040413B373E4039424142413C3B3D3B
3F46403C43403D463B43463C465C5748413E3F424140464F50565B71726A6F62665C5A4C
564D4B3E3E424545484A423B413C3E3C3E384039433F3B3B4043413D3B403C3A3B3E3D41
3D3A393B3F40424640413E4641413940443F4342464E4439403E3E3D3D3938393C3F4241
4347443D403E39383F433E373E3B3A3C3B3F50616B8E7E947984758E8AA5778B66785555
50445B54826F88787D7F7D789499A2AAAFAB9D92909B93A197AC827D6A907DA49DB0A8AF
8AB5A0A19197AEA4C8A2B395A88C9D7F95676E6A73899EB2A59D9C987D8A899C93B6B2C2
8B645540323A3A3A3B3938373B403E3A3F3A4040414A463E393F3F43423E403D3B39383A
3E403E3B3C3A363D3F3A3E3D3A373A393C3F393A3A3B42443D3A3B393C3C3C3C3B3B3A3A
3937363638393A3A3C3937383735363A373738383A3B3C3D3939393837373A3D39363537
3939393A383A39373739393633343537393937363737393C3C3A393A3939393B3C3B3836
403D3F3E393A3D3B3737383A3B3B3B3C393A3C3C3A3A3B3B37393A393938383A393B3639
3C3A3E3A3D3D3D3D3C3B3A3A363D3E38373D3E393D3C393737393C3D3B3B3939393C4247
47464140403B3638413F3C3A393B3D3C343E3B383C3B3A3E3B3A3A3C3E3E3C3B38373737
3B3C3C3B3A3B3A3938373A3B39353739373A3D3A39363A403A383C3C363535373C3F4141
433D3F4338343A333C3B3C3C4249536E4741463B3A496769947A999BC6B2CBC3CCAFBEA8
9A8183574D483F3F3F3A3D3F3C3C3C3D3D3A3A3E383838393A3A3937393D3B3A3D3B383B
39373637373637393B3A3834373C3A383B3B3E383A3C3F524B657B92B3C4C9D2D3D2E7DA
E2CFDBD4DADDDED5D9C7B8AFA18F7F6B5A504649463C3D3D3B373E423D3F504D4C53505A
3C4035433442393F393A3A343A34373B3833363A3837393A38383A31363B3A454F63797C
91A9C8D1D9DCDFE3E6E7E7E8E5DFE1D6DBC3C7BC
514F4F505353524F4E4F4E4C4B4C4A474C4B4A49474645444A484A4A46474A484B484749
494645464949494848474747484542424447484847464748474445484441454F50484548
434242424344454645474645474A494441414447464140423F3E3F4243413E3D3F404041
4141414141433E424340413C3C3B3B3D4042434245424143484A47423E3B3B3E403F3F41
3C413E3B3D3D3B3C3B3B3B3B3D3F41433C3B3B3A3A3A3A3A3D3C3941423A3B383F3D3C3E
3E3C3C3D3A393B3E3E3D3F42413F3D3E3F3E3D3C3C393E3A373D3D3A3E3F41413E3E4041
393F3D3C414140463F42433E50695F4B424041434341454B4E565D6E6D636762585A5150
474E4A4B4341403C40433D3F4741464A504A4E444F48403D414440393A403C3C3A3B383E
3F403D3D3E3C3A3D413A3C453B3A35413D393B3A40473E363F3F3A3B43423D3E403D3C3A
3B404039393E3E3B3D3E3C3C3B3C4247433F4A5B604C605072638D82A49DA28C9990A780
7C61678A92AA97AE8FA086AB95B79CAE9093778383747661594555434A4556626B77737A
80878E6D5D5A54585A5869657250514F4A453E474B507D91B8C7CBC19391B9A7BDA4B0A2
B294836244413C3A3C3A3A373D433E3D38354A585A584635383D3B3E3C383E3C3F3D3B3C
3E3F3C383C3D383D3E3C413F3D3939383F4238383A3B43463F3A3D3D3A39393838383939
39383838383939393A3737383736383C39393939393939393E3A38383837373A3B393737
383737363839383637393835363737373736353333363B40403D3A373939393A3B3A3837
3F3D3F3F39393B393638393B3C3C3B3B3A393C3D3A3B3E3E3A3E3D3C3D3C3C3F3D3D383B
3D3B3D383E3E3D3C3B3A3939373B3D39393C3D3B3E3E3A36363A3D3D39393C40413F3E40
3D3E36393B383D3A3F38383B383535353B443F3E413C38353837383C3D3C3B3B3E3B3B3B
4745423E3C3E3A3B38353A393B37393B383A3D3A37373A3C34333C3738393B3E40403E3D
39353940403E3D3836383E3B3D403D423D3D4953566A83717E8091D1BBD1BBC5ACB0A794
4F4C443A3B3A373E433A363D3B3B393839373435383837383A3A39383A3E3C3A3B383639
3B39383A3A38393B363639373B3D363A383A45435666748FB4C4CDD4E2E5DFDDE4D8C2D2
BBD0D5E7DDE9D2D8ACA87E7A6A584B4740403A433D373E3E47474F4A4B5A544E443D4338
39333A3339333B363B3935343B3935373836383B3A3A39323B3D443A4C5F6E879BB4D0D2
DBDCE2DBE6E7E5E4E8E7E3E3DDDECFDBD1D9DAE0
494747494C4D4B494B4D4C4846474745424242434446484A474548484342444246454749
494544454A494745454546474745434344464748464445474645474B4845424144474847
43424242424242424644413E3E40414143434547454140433F403F3E3F413F3D3F3F3F40
404040403D403C3F3F3B3D383C3C3D3F41424342423F3D3E4142403D3C39393D403F3F41
3B403E3A3D3E3C3C3D3C3C3D3D3E3E3E3E3D3C3B3A3A3A3A3C3E393D3E3A3E3B3D3B3C3E
3E3C3C3F3F3C3A3B3A3A3E4449434042423F3E423D353C3C393D3C3E393838383A3A3A39
40424140403E3E40434042404951443740404143434243444A50535751464A5452566C5C
69515546463F40424C514F5B5B5057515047433E4444413D3D3F3F3B3B3E373A393E393F
3C3F3D3B3E3B37393D353C463C403B433C383B3A3F4640403C403C3D3E413B3B3D3A3C3C
3A3E413E3B43423E3F3F3E40424040403D3B414A464B3D454F657582859583857A94827D
9C91998F9C7B7A5A675E75617D5B685E5D4C484B49474A3D4952456057707387637B778B
6E727F786B4A594458678992B48A7D6E5C634E544346476173A0A7A6AEB9C4E2B7B78C7F
747A817C6B5F5545413E433B363C3B3C3B47738E836B524445453E3F3F3D423F44413E3D
3D3D3B39393E3A3B3B3A3F3B3D3B3B3A4143393B3C393D413C3A3D3E3B3A393838383838
393A3A3A3A3939393B3938383634373C39393939393939383D39393C3E3B38373A3A3836
373838363C3C393636393936363637383838393935373B3D3E3C3A37393938383A3A3938
39383B3C37373835393A3C3D3D3B39373836393935373C3B3B403F3E403D3B3E3E3F393C
3E3A3B343E3D3B3937373637393B3C3B3A3A3B3C3D3E3B37373B3E3D3A3A3D42423C3735
3B3A373739393D3C3A373B403C393A383843454B4C45433C3B3A3C3F3F3C3C3E413E3E40
534F463D3B3F3A3C3A363B393D393A3A36383D3B393937383238463C3A3B3D3E3D3A3838
3E3C39383836353A3E3B3D373E4D4639575C6B6E556495B5BCA8A3A7B08D85706352503E
3F3B463C433D36393F3D383A3C3E3A383A393638393837383A3B3A39353938373B3A3A3F
3C3A3A3C3C3A3A3C36363C3A3B3A384846536F7BA8C8D1DEE1E9EBE4E0DDD8D2CABEBFC5
D3D2D8D8DCCABC998C6F654F443F3A423D48424C6E68706875767F7269654E463F363D36
3D393C3C383739353D373835463A3631323637373734394440506D7394AFC2DED9DBE0D6
D4C9C8C3D4DCE1E5EAE6DFDFE1E0E2E2E9E0EAE8
4F4D4B4D4F504D4A4B4E4E4A484A4C4B4C4B494747494C4F4A494C4C4644464344444547
4542444747474646454544444444454647464645464343454545494E494C4841444D4D45
4645454443424140434241414142444644444648454140434445423E3E41413D3E3E3F3F
3F3F3F3F41454144433E413D3D3E3F414242424246474744403E3E413D3A393D3F3E3D3E
3A3F3D393D3F3C3D4140403F3E3C393742413F3E3D3D3D3D3D403A3B3B3B403E3C3B3D40
3F3D3E433F3E3E403E3B3B3E4B423D3F3F3A3B4041353C3D3A3D3B413F3C38383C3D3835
45444544403E3F3E3737424748453D40383A3E41444646464046494845414A6158605961
535A4C4A42485355626A5F615B4D5C4B433D3941394145403A393C3D4343393D3E443E42
3D403D3B3E3D3A3D40373A3F353E393D3C3B434445443B3B384243453C4242443D3C4142
3B383B384044403B41423E3E383C3D3B38393D403B31514772719D85A081935E62617B6A
6F55544942443E4643403E4B41423D44433B41545A5F877E837F6C6D6176A28F9A8A9D97
9F96A5A091494A5B6B9B94AEA58F8590779D71785059433F43456855817FAEC3CABEB7A0
919D9BA8ABA6A1837970746146434240466BABC3AF9C908B7F78665E58504D4546433F3C
3C3C3C3C39413E3D3B3A3F393B3C3E3C43453C403D35363A39393C3C3D3D3C3B3A393938
393B3C3C3A3939393F3C3A3835323438363738393A3A3A3B3836394044403B3837383735
373B3B38403F3A36363939363F3F3D3B383535353A3A393838393A3A39383738393A3A39
38373C3E3A393A3735383B3E3F3D3B393936383934363B3A383F3F3E403B3639383A363B
3F3D3E38383736353637393A3C3C3C3C3B39393B353838373A4044433F3935373838393C
3A373B3A3A3E3B3C3C393B3C373C444445505152493D423F40404245433F3F423B38393E
554F4234373C383C3C383F3D37343637353A41423A3936393A4A5D503435363636373A3C
3A3B37363D3A353C3F3E464C62817A616555678C8A8F9DB89DA777806B504846453D3942
3F3D3C4450463E3B3E413A34343B3C393B39373D3A3838383A3B3B3A393D3A373837363B
3A38393C3C39383A3B3A3F3E434E60838DB3DFD8E7EEE7ECE4E9E8D8C6BDB6AEBBBCB4C7
C7C9C1D0C2AD7E7A5766493B3A3E3D48496F809AB8B9C5B2AD9282626B4638383E3F3643
3936383C373C3F3D3539383D3D3A363E373B393A3C3B568590A6CAC9D8D8CFDBC7AC9483
8B95B2C5D8E1E3E4E7E5E4EAE4E6E2E9E7E4E7E9
494A4C4B4A49494B47474746454547484244464647484B4D434649484442434544444341
454B4A46404444414044474741444542434646433F414447484846454240424648444040
3E3E3F42403D3F443C3D44474342413D474342413F3C3E434A48473C3E48454143434340
3C3B3D41434544414245433E3E38424341453F3D3D43434144403B3F3B3A393A3D3E3D3C
363D44443E3A3B3D36393F43403A3A3F3A3B3B3C3C3B3C3C3935363B3C37373B3A3B3D3E
3F3F3F3F3D403D3C3E39363D3B3B3B3B3E423F3A363C383D414143393D3D3C3A38393B3E
4640403F3B3D403B3C403F3B3F494C47413F3C3D4042403C3F3F3E423E3E4743544C4B4D
4746494743474C4E4F4F5152464447453D3C3F3E363C3F42413A3F5144464D4B403F413B
473F393A3B3A3A3C3F3B37373A3D3D3D3A393B3D3B393C423D40403C3C403F3B3A3A3C3E
3E3E3D3D3B3B3B3B35433E41393C393F373939433E413F574F675E6D5251464B3F424645
3B3C413D40433D453E48413E4245536B534E6076849DB5B8B9BAABAFA49F949C9D959290
827D6C735C79868AA79CA18E967D7A666861514E4144444F5048474342526095A4B6C8CC
CCCEC9BCA19992A1ABA5A59B808272817FB1CECFCBD1C9BABEB7B5A3A4979283936C8A5E
52463D363E39443B3C343C3B393F3C3D413C3A3B3833373E32444F48403C3C3D3A3A3B36
3A393B3D3C393A3E373A3A37373A3A3737393A38393B3A36373B3933343B3B3435343C3B
373431393837393A3835383E34383A38393B3A3635393A3736383A3A3438393736383A39
38383738383A3A3B3B3B393736373B3E3837363536383B3D373B3D3B3A3D3F3F39414848
413B3A3C3A3A3A3B3B3B3A3A3C383C38393F3B3F3A39383A4042403F3C3E3E3C39373738
38393939383837373B3B3B3D3E4143453C3E3E3B38373B3F3E3B3B3D3C393A3F343E3847
685E413F343A40413D3A3B3E3C3C4039383D373438393633343E4A4A343A383C38354142
414A413F3C384A415171749782994C41386297B9B29C908085695F5444413E3C3D3D4445
47564956514A403B3A3D3E3E383B3E3E3C3B3D3F393938393A3B3B3B3538393B383A3A3D
37403C3F353B3D4254596F728492B5E1D8E4E4E7E9EBF0E5E3DACDCCC5BEBCACABB0AEB2
C4CDC4B89B736E594C464344474D6265899FBDC1AEA18C856E67484D3F3A37383938383A
3B3733393C393B3B343738363D353E3D3A39354D7A86B0DEDEE2D9D1DBB2917F617B8D93
B1C2DEE2E5E2E6E4E5E9E5E8D7E1E5E0DCDEDEDA
4C4C4C4B4A4A4A4B4C4D4C4B4A4A4B4D484848484746474847494B4A4746474845454544
474C4C494145454343464745454746454546464542434546464543424341434749474444
45444547464444484543454642444847474443454645494D464549434245414242444440
3D3D3F41404243444545413C3F3940403F4442413C3F3D3C404142493F3E3E3F40403D3B
3C3E3F3F3D3C3D3E3A3B3E41424040413C3C3C3C3B3B3B3C423C3B3F403C3B3F3A3C3D3E
3D3D3C3D40403E3D3D38363A3A3B3A3A3D403E39393C36383B3B3E3637373737383A3D3F
3F393A3A383B3E3B393D3D3B3E42413C4A44414444403E3F3D3E3E423F3D4540433C3D40
3E3F44443F3F3F40404040403E3C3F403D3F454541413F4246403F49454546423D3F423F
3F3B393A3D3F4041393C41464947423D3F39393F3D373942403F3A38393C3C3A3C3B3A38
38393D3F3D3B3E3F3F4C40403C3D39413B3E3A3F36393B4439423841373D3B473F43433D
3A3B3F3B3F4440494D53474E51687B9A7C7C8897A1A8AAA4ACADAA979B929B9E988D837B
7C867E7D91ADB5A8A7837E6E594B52474C4C464B3D3D3A444B49494345395C567A7E9699
9DA3B9C4A17F6D7F969AB5B8C1CCCADACDD0C4A5A39D9889737F798490AFB7C2AFB8B1B0
798E66503F393B3D383E44433E3C3A3F3E3F453F3A353E3D373D4B473B373839383B3D3A
3434383C3D3B3B3E3638373535393A393A3F403C38383A393B3D3D3A3B40403B38343938
383834393132363A3A393C42393C3D3B3A39393733393C3B3A3938353A3C3B38383A3C3B
34353637383B3D3F37383838393A3C3D3A3937363637393A393C3D3A3A3C3D3C373A3D3E
3C383635343538393B3C3D3D3F3B3D3B40453B353537393A3C42423C3738393A3B3C3E40
39393938383838383D3C3B3A3A3B3C3C3A3C3D3B3A393C3E3A393A3C3B393A3E3B423A3D
514A383A363B3F3F3C39393A3B3B403B393D3838383B37353939393D373A34393F3E4341
3636414662556C6982809567755152506B8298A29482796A6B56524C3E3C3C3E373C494E
5058454C3536383B3E3D3A373B3C3C3B39393B3D3435383B3D3C3B3938343A363D363A3B
3644394B51697D80A5B2CFCED1D5E1EDE3EAEAEAE6E6EADEDCD8D7DAD4CABFADB0B4BCCA
D3C4AB9D8F838F867B6F5D5B5E677A7581787769655B4E4C4342323B3A3635383B3B3C3D
353A3B3B39393E3F393934383E363C424457709BCED3DDE8DCD9B4927761709491B4CBDC
E4E7E8E5E1E0E7E5E3E3DBDCD5D2C9BEBAB8AEA2
504E4C4A4A4B4B4C48494948464647484B4A49484847464546464645454445454B4B4946
464746444445464647484643494645454544444644444445444443424341424648464443
4441404243414141403F43454142454347434141414142444644494743423F4641454540
3E404242414040434442403F4740413E3C403E3E3A3F404042414043444341403F3F3F3E
423F3C3A3B3D3E3F3B3A39393B3E3D3A3F3E3D3C3B3C3C3C413B383B3B38383A3B3D3E3D
3B3A3A3B3F3A3B3E3D3B3C3C3A3B3A393C3F3D3849483F3B3A393A353D3C3B3B3C3D3F3F
3F3A39393738393640403F3F3F3E3B39433C3B41413C3C423B3E3E42403D423E46403F40
3C3A3D3E3A39393A3D3F4040403C3D3D393D424244413F41443F3C3F3F423F3A3C3E3E3F
3F403E3D3D3E3E3C414750575750463F3F3C3C3F3E38383C443E3739383C3C413A3A3C38
3A3A3F40423A3C393C493A3D41403A413D403B3D4042473E3B3A373B3A413E473F44443C
3B3C3C383C403F484C554D645A7574898E8F88869097999DA7AEB6A5ACA4A399938C8678
8292938B879490807E605E52473F473D3C3C3D484348484F5555564F5858787281868E91
9B96ACC0A7866C6C8698B2CCCFE1C7DBDCDCC0B4ACBBA89D8B825E53505F688477857783
83B0A57E8A6F706C7F756F4B48403D433D3B41313D353D3B3C37403C3B363738373B3F3D
3A39393A393636393637363435383A3A373B3B3734353636383737383A3B3A393B353736
383B36393435393B3A38393C3737383938363739343A3D3C3B3A37333D3E3B37373B3B39
3A3A3A383636393B3738393A3B3B3A393B3A3938373737373B3D3C3A3A3C3C3838363536
3838353236383A3A3838393A36373A35343A3B3E4A46443E384043383C3B393A3B3C3D3D
3B3A3938383839393B3B3938373636363A3B3C3C3B3A3A393C3C3C3D3A363536393F3A37
3E3D383C3A3C3E3D3B38373737363A37383B383B3931363A36393D3C3B3C32394A4B4239
4449476470786F7965757469636B768B9195918B7D716D627667665D4A4039393B3E4443
4244333838393C3E403F3E3D3A3A393737383A3C3D3D3B3A393B3D3F363B33443B47444D
577F839E9DB6D2D9DFD7DCD4D7E2E8E0E5E2DAD7D5DBE4DEDED8DBDCDAD7CCC2CECFCDCC
C4AE9B96AFB6C1B7A490727057565A4A4C414237433E3D3F413E353C3A38383B3C393839
3A3C3D37363936313B423B3D3C455D72839FBBD1E1D8D4D0B6997965919BBFCEDDE5EFE2
EDDBE5DEE0DFE1D9D1CAC0C0968E7F716B665A4D
524F4C4B4C4C4C4B49494A4947464748494847484A4A49474B4948474849494946464646
46474848464647494A49454248444244444243474242434343444445424141424342403F
454240414343413F40404649454547444B474341403F3D3C484547424043424740454540
3F43454345403E3F403E40444944413E3C3E3E3D3D404343423F3D3D47443F3C3B3D3F41
42403D3B3B3C3E4041423F3A3A3D3D3A403E3C3C3C3D3E3E413C3A3C3D3B393A3C3D3F3E
3C3B3B3D40393B403E3E413D3C3D3C3A3C3E3D393B3A3636393D41413F3E3D3D3E3E3E3E
403D3B3A3A3A3A3848423E3E3D3B3B3D3937383B3C3A3D423D403F42403D423F3D3B3C3F
3E3D40423A3C3F414345484A45403E3C373A3E3C3B3C3E3F3E3C3B3E3640403C3E3D393C
4345433D3B3C3C383E43494D4C47413D393E413E3E41403B3F3C383F3837353D3D3D403B
424754587B7271635D5D464743443E433D423E41524F54404943444245494144393F3F36
383A39373A3D3E454A544F6D576E5B665A6B6F7793A5ACB9CED3CFCFC2BF9D8D7A7C7A64
615E5D53535146404B3F433E433F433C3A3D4452596C7A868A898B847A93A9BEBFBFCACD
D8CECDBCA5A49D919C9EBCB9CAB6A2AEBCC4CBB0C2C9D0C6D5B28F6F65423E4B454F5143
475C6B63A5968AA5A9BCAC8F8C7954423A394542423B3A403F3C38363F3A3B3C3A3C3E3B
3B38353637373B40383837363738393A3D3B38373B403E393C39383A3B38383B3B373A38
383A3638393A3B3B383535363B39393A37313237373B3C3A393A39363B3B3836373A3936
3638393836373B3F3B3A3A3A3B3A38353A3A3938373736363D3D3B3A3C3F3D383C393637
3A3B3A38393B3D3B383536373B3838383635373D503F3835313C474043403B3A3B3B3937
3C3B393838383A3A38383837373737373D3C3B3A3A3A37363C3D3F3E3B363433343A3C3A
3A3E3E3D3C3C3D3C3B3A383738353634393B363B3E3A3C39393D3D403D505B68776C554A
49435749715D605E5D85958F85838D928F8D8687817777738576716451473F3E3D3B3C37
383C343C3C3B393837383A3C3736363637393A3B403F3D3A37373B3E3842464C616B8F93
C3D4D0DDD5E4D4C7C3AEA3A7BBCECEC0BEC0C1CBDCE4E1DBDED5D7D3D4DAD5D6CFDBD5BE
A896867F8389887B65604D503B3A3C3137353B37393942454D3E35353A39393C3B373435
3B363A33363E393A3B3E3E58719BB0ABCCD0D4D4CEBAA18981A0ACC2D0E2E8EDEFECD4D8
CACEC8C7C6BCB0967D6B5B595355545152575A59
504F4D4D4D4D4B49494A4A4948464647474646484A4B4A484C494747494B4A494E4C4B49
464443444746474A4A484542484443454644464A44434343434344444241414142434240
43413E3F4143403D434143444042474644423F3E3F403F3E4745463E3F48444240434441
4043444345403E3F3F3D3F4541403D3E414142424141403F3D3D4041413F3D3B3B3C3E3F
3E40413F3C3B3C3F3F43423B373A3D3D3F3D3B3B3E4041403E3C3C3F403D3B3A3C3D3E3E
3D3E3F40473F40433E3D3E3A3E3F3E3C3C3E3E3B433F3D3A38383738363638393B3C3D3D
3A3A393A3D3F3F40443D3A3C3C38393C3B3F403C3B3F424240444041413D42423F404244
444141443D424646413F4144433E3D3C393C403F383A3D3F4043454337444742413D3A3F
4042403C3B3F403E37393C3F41424241454948424044454341413F483C3A3A47524E4C41
4F5C747C939195867B6A4D4C3F46474C454A474A4D4C584C635D595146483F443B404138
363B3A3B3F3F414648494358486256665F6F7380A6C1C7CECDBCA9A08982635D494E5245
41393E3A3F41413F453D42433F3C3F3F3E43485462727A7D78716E6664756D8F7F999CB7
D2D3C78F6E869F9DA1A19FA89E9A86A29CACA19385A8B2C7BFB2AE9E97715237454A8F6E
7E4F5B6B9C8D8B8795939E847F7B5040453B3D3E403D3642373D363B3E3A3C3E3B3C3C37
3C3937393A3A3B3F3A3A3A3B3B3938383E3C39383D41403B403C3A3B3A36373C3839403B
37383437373838373737393A3A38383B3A36383C373A3B3A3A3C3B3837393837393B3935
3638393836373B3F3D3B39393A3A383739383838383838383E3D3B3A3E413F3A3E3D3B3A
3B3C3E3F383B3D3C3938393B413B383C3A384A5F6D4F403F393A3F3B413D3A3A3C3D3B38
3C3B393838383A3A38383939393A3A3A3C3A3838393A3937373A3D3E3C3B3A39383A3E3D
3B3E3E373D3C3B3B3C3B3A3A3D3837373D3B31373C413E34404A4959608094948D735751
5358525A57604A5B7B9F8D9D768A7F8869686774726261657A6659493E3B363737383A36
3A3A3539333436373838383836363737383838383C3D3C3A37393F44577E7B9F9DC1D6DB
E1E2E8DFC7C18C7C6F7B88A3BEC5B29D96999BB0D3DED3D1C2BDBEBABDC2BDC1C5CAB389
6E6358504E4E4941333D3B3E393A3F3B3F3A3A353C3D444752403B393635383B3B383738
3833403B383D37464D6589B1B7D1E0D3CFD0D0C1A79B9CA2BACBE4DCF2DFE5D1CDBDAF99
93756F5C565252484344444B4A50545351545A5F
4E4D4D4D4D4C4A4948494A4947464546474748494A49484748464545474848474B484849
4A4A4A4C4746464949464444494746484848494C48474544434241414243424244474846
41403E3E4043403C3E3D41423E3F413F3F403F3D3E40403E4243463F424B433C41414142
4241424241414242413E3E403D413D4044424342424142423D3C3D3C393B3E3E3E3C3B3B
3D4043413D3B3C3E373B3D3A36373C3F3E3C3A3C3F4142413B3C3E40403D3B3A3D3C3C3D
3F404242443F3F423F3D3D3D4041403C3C3E3E3B443F413E3D3C383B373A3C3D3B3A3B3C
393A38393D3E3C3D3F3B3B3F413E3C3D3A41413B3A42464342474141413E42433B3F4246
4845454B3D4247453F3B3C3F403D3E3E3A3C403E3E3C3D404750504840494B443F3E4146
3F3F3D3B3C40414139393B3E40414241494544464647515C47443B443A464E6265605F50
5E65797A7F83867C786453543C474C534C504D4F5556626178705E52514C3E433A404442
3F4642434540414247454A4F4E5A53625C5F5C6688A3A39997756E575244444C4644403D
3D3A43443A3D403F3E383B3E4443424640403D42494A4240404147434D3B4746587684AA
BBB6A77765809DA09E9DA8A1B09CADBECDC4BF90817070796B81889293A28057584E6C85
838A659683968FA08B8D84788E8B5B4A4E3F3F3F403D3E42363A3E4039363A3D3B3C3D38
3D3B3C3F3F3B37373B3B3C3E3D393737393C3D3937393A3A413E3C3D3A36363A363A413C
363734373637373536393B3A363536383A39393B34383B3C3E3F3B36373A3B3A3B3C3A36
3A3B3B3A373637393A393737393A3C3C383837373738393A3D3D3B3A3D413F3B3C3C3C3B
393A3C3F3A3C3D3C3A39393A3C38343936395A7A5D42383F3D3737363E3B393A3D3D3B38
3B3A3938383839393A3B3B3B3A3A393838373536393B3B3A373B3E3D3C3C3B393A37393A
393C3D373B3B3A3A3A3B3B3B3A3736373E3C37476852605E546E878D9A9E937866594A4C
665867526950565F78797B787C66675E5D5C5A64604B494F4D413D37373B3637393A3A35
3A36343637383A3C3D3D3C3B38393A39383737373A383536415A798FAAC6D2D7D8DAE3D8
DFC7BA906B68576D739CB7CED9D7C3B2A2999097ADAC958F7675726D6F706C70887E6347
4042424241403E3C363C3B373D3B3A3536353838393634353F3235363837393C3B38393B
44343F373B4D4F69B3B5CCEAE5E4E2CCD8CABFBBBAC8CFDBE6E9E2E5D5C9BCB07D7D686C
505046433E3C403C3B3F3E444042434140404142
4C4C4C4B4A4A4A4B4C4D4E4E4C4A494945474949494847464A494A4A4C4C4B4B4D484648
494746474745454746434447464848464648484748484745444241404546444243464744
454544434548474342414648444343404447464341434341404146414246403E423F3F43
433F3E4241444542403F3E3D3E443D41454141403F3F44453F3D3C383B3D3F403E3D3C3D
4141403F3D3D3D3D3A3B3D3F3E3D3F433E3C3B3C4041403E40434545423F3E3F3D3B3A3B
3F4141413C3C3C3E403D3D414041403C3B3C3C3B3D373C3B3A3A353A3D4143423E3A3A3B
3D3F3B3A3E3C37393D3C3C4042424141383B3B37383E414041474141423D3F413D403F3E
3E39383F3D3E4040403F3F403E3D40403A3A3C3A3E3C3D3E424D4F44444545413C3F4343
413E3C3E3F3F3E3E3A39393A3D3D3B393A383D464A4B576845453D4C4755545F5B5A5F52
5F5C63595F635D565B4B484B444B494C454B47484B4D51596C6D5D5D62564245393B4143
434B4445463F40403F3E524451443E46444B5A6B8193896C5E41493F433D3F494544383B
3B3C413E4845423D3C3D3D3B3C3E3B423B3D3C414244434B4E4B4D496D567E5782778E9F
B59C8B71707681888EA6ADB6B3B3C3CAD2D3D2C4AFA685866D7D7A8493B2A5947E578361
9A68565C5180A1B4B5A7AFAAC2C1A8A4957566495144574951414C373B383B3E3D3F413C
3937393E403E3B3B3B3A3A3D3C393739393E413E3A3B3D3D42434343403D3C3D36383E38
363A363837393836363939363C3C3B3B3C3D3B37373A3C3C3D3F3B36383B3C3A39393836
353638393A3A3B3B38383838383A3C3E393837363638393A3D3D3C3A3B3E3D383A3A3939
39393A3A3A3A3B3B3A3938383A39353D403E494F473B3B44453E3C403C3B3A3B3D3C3936
3939393838383838393A3A3A393837363736373839393838393D3F3C3939383536343639
393A3D3D3A3A39383838393B36353637424E6186B18EA4A5828795928E7F6A4E47515054
4F4C4B515157545F5D64566E50544655515249494639373B3D393C393A3B34343C3C3B34
3D3A3E413C3A37373839383738393A3A39393B3D3B3F44506689B0CBCDD5D4D9C5DAC3CA
93705C5662748AA6AEC6CBD3CAC5B9ABB7977F706A6556534B4D45414240414545423B3A
3D3A3333383C3C3A3F3B39373937373638393C3E3C3A3237403638393C3B3B3D3D3B3D41
463A525774A3B2D2E7E6EEF1E3D6E2E3DBE0E5E9E6ECE3E9DCCCC7B7AF8777574E4E4A46
3D373E373A373C393A3D3B3F413F3E3D3D3E3E3E
4B4B4B4948484A4D47494A49474544444245484949484848454647484949484846413F43
46454445474444464441444943464643424544404646464645444342494945403F42413D
4042413F41444440464242413C3E43433E42433F3E404140424044413F403F46433D3D43
433D3C414447453F3C3E403F3A423B40474345443C3A3E403C3F45434141403E3C3C3F42
47423C3B3D3F3E3D3B37383D3F3C3B3C3F3D3B3D40413F3C3D40423F3B38393A3E3B383A
3E41403E3A3E3C3B3E3A373F3F413F3B393B3B3A443D413E3C3B343A373C41413C393A3D
3D403C3B403F3B3D3A3937373A3E4040413E3B3A3838393B3E464041433D3D3E393D3C3C
3F3C3E483E3B393A3E3F3E3C38393F413B3A3D3B373A3D3A3740453E413D3D3C393E413A
3F3A3A3F42403E3E3D3B3A3C404242403E4248494540434A4C5559736E6E534944444D42
534E5346464C444657484D4D504F423F37403E3E46443C43505D5565706352584B464646
3B433E414540454559546B4D654F515C64667173717C775A523E414E464D383D3F473D44
3E403E373A393935353A3A37383C39413C42485365788EA3A08673646D8C80996D816479
675354525D5D718E9CBAC3B8B2A7C1B4C0C5D5CDD6DCC8C2C5BCB6B5D1CBCCD19E836E55
63695D7B80ACB7CECBC7C2BEB9B6B4C6B6A3A1799980A287A6808B5A413E404240434541
403B383A3B39393B3B38383B3B38383B34373838393C3C383A3D40403E3B383737363934
363D393934373837383A3936373A3D414952524D3D3D3B383A3C3C38373A3B3734343433
38393A3A3A393736383A3A3A38383A3C3A3937363637393A3C3D3C39393B3A363B393738
3A3B3836333435383B3C3D3D343E3E42413B3C3439393C404039373D3738393C3E3D3B39
3839393938383737363637383837373638393A3A39373432353A3C39383A39373635393D
3C383A3E393938363535373938393A3B4D6894CFBDBAC3BDAB7E55664B4B524A47504C4A
4D4B534B5A5C665E534B4B4343373E41484C3F3A3C393B3B3A383A35353A3A403B3B3A32
3A313534383736373A3B383534373939393B40454C5C71828E98A4ACA898A0948085585E
47485984A59EB6C0CBC5B7BFAEA08C7475534B473E42413E3941393B3D363838383A3837
3836373F363C38313E34353B3B3B3D3E3D3B3938363935424B403D3A39383A3D3F41464C
717DAFBBCDE8DCEBE8E7E2DFE7E1EAE9F2F0E8E5E6EDD3CDB39C7C5B463D483F3B3E363F
3540413B3C383A36373C3B3F3939393838393C3F
4E4E4E4D4D4C4C4B4B4C4D4D4D4D4C4B494848494C4D4D4C484444494D4C494943454846
434244474A4D4C47444548484947464745424348454647454242444744454443464C4D4A
46454444444546464F4B4541414345464245474542424548414345454341404041403E3E
3F42454748413E3D3D44473F4041403F3E3F43463E40413F3D3E42453B3F413F3F403F3C
3938393D42433F3B383D3D3E423C3942403D3E4446433E3C3B3C40423F3A3A3D383D413E
3D3E3E3C40443A3E42393B3D44423E3A393C41453C3A3B3F3F3C3C403E3A3F3E41443D3D
413A3B3F404445403C3D3D3C3C3D404244443F40443F393D3E3E3E3E3F3F3F3F383D403E
3936373A3C3E3C393A4042413A3E3E3937393A3938373A3D3C38393D3B383A41413C3A3E
3D3C3A3A3D3F3D3A383D383A3B3B433F39444C454F4D4C4557616776776961553E494C48
48453F3D3E3D4044413A3A4044403C3A36353A403C3F464B46414854484D4F4C47434344
3D42435C5B6456554E4D595D4C41506255595A5655565450474442413D393B42453C3A3F
413D3C3E3B3C3D3D393C393D404447554B6C739696ACB3C1BCA59375716260574C4A4747
3E4F565D60626960645957504E5457646C8A91AFA6B7B0AFB1BBB1C5CAD2DDD9CB805438
47474B5C719CC6C0DDD4D9BBB29A92A681746F77728C707973777A9B7B845D3F45443F40
3736393C3733353A393A39383838373735373A3A3A3A37393A37393B3C3D3936323A3436
3C3A3A353A343C3F3B3A39403949577B917C5A473E3C37363F413B3D353A3939393B3E3B
393A3F3C35373A343938373433353A3E34353637383939393738393A3C3C3A3634373A3D
3D3B39383838393A3B3B3A3A383F44413B39393938403D35373B3D3F3A3B3B3C3C3C3B3B
363B3936383533373A38353435363636353C3E393434373839403B393D37354341423734
34353E3A374235383D3A3F3643333E627488A5AAA3B39C7F71524E3F3C3B4A5A44464C4B
4B5479696860735941403F3E3C3A3938393B3D3C3A383839363A38363939383C36353C39
3A3E383C3A3C3B3D403A353A39383946494D5B758A879C8D857F6A5C545A4A4B473E4742
5F7C98BAC3C5C9C9C2A3887B6E5F50433D3D3D3E3E3E3E3E3E3F3F3E3A383838343E333B
383837383B363F363635363B35373835393E3B37383D373C3C3E403B3A474E54607A93B2
BFCFDCE0D0E3E6EFE2E4E2E8E9EEEBEFE9EFE2E0CFAC93734847443F3B3A3A3C38383939
3A3A3A3B37383A3B3B3B3B3B31383C3A37393D3E
4C4B4B4A494948484444444545454544464646484B4D4D4D4946464A4C49474744464746
4443444645444342464C4D4A44424243413F424647464544444443424142413F42474846
45464645444445464241404141413F3D3E4041403E3E404242424343424446493F3E3F3F
41434647413C3B3C3E4547403D3E3E3E3E3E3F403D3F40403E3E4042393B3A37373A3C3B
3B3A3B3D40403F3E3D3D3C3D3E3C3C42403D3C4042403D3C3A3C3F413E3A3A3D383C3E3D
3D3E3E3C373D3940433A38383C3B3A38383A3F423D3E40403C39393C3A3A41404040393A
3E3B3E403E3F423F393A3B3A3A3B3D3F42413E3E433F3B3F3838393B3D3E3F40393D3F3E
3A38393B3A3C3B39393B3B393B3E3F3B393A3B3A3B3B3D3E3C3A3B3D433D3A3D3C38373C
42403E3D3C3C3E41474E4744464A514A464B4D424641484D4E4F4B53565254513F423F3A
3D3E3E41403B3B41413B383A3A393C42433F39373A393C423F39393F403F4144423D3C3F
3B3B3746454D474A443F3E3E38373F4842424345474645453E3E3F3E3B393C413B3A3C3D
36363C3F384142383932433E64587C6789788A8B9A95817763505348413D474842424144
3D444442424449463F3D423F404644484049404F48515052526C79A1BED3D6C49A77546B
6384728D728F97B8C3DBD8D9CFBBA58C5246445B7B655D4A434D4D5F5F96A1836D51383E
3C37373A36393B3C393D3E3C3D3F3F3E3836383B3B393A3F3834383B3B3F413F3B3E3E3E
3F37323C39353D3C373C3F45517C87917B76493C393C3A393D3B35373D3D393434383C3B
39393C3C373A3D3B3A3B3D3E3D3C3D3E3A3A3A3A3B3B3B3B3938383A3A393838383A3D3E
3E3C3A393937393F413F3D3D373D413F3C3C3D3C3D443F383A3E3C3B38393A3C3E404141
373C3A383A3735393B393636383A3B3C363B3D3834353737414036323938353A393D3B39
38393D3C39373D373A3E3843394869888B94A8A39A895D47483E4142383C4E5E4A4A4942
494D6659595059403B3B3B3B3B3B3B3C383A3C3C3B393939343938393E3D3B3E3A3A3D39
36373A433C393A3834394140444D549C8FAD9DAE95999489625C47434237473D42495E6C
8E9CBBC2D3C6BBA88D70574D45413E3B3D3D3C3C3C3D3D3D383939393A3B3D3F353E383C
3838363B3139383B2F413537363A403D36363E443B3B38454E4C5A5C687E7E9DA1B9C9D8
D1BDC6B2CED4EBE6E6E4EBE1EBE5EADEE2DABAA17B544B403A3A3A3A393B3D3F39393939
39393939353638393B3C3C3D393F43403C3B3B3A
504F4F4E4D4C4B4B4B4B4B4B4B4B4C4C4A494848484847464A48484B4A47454646464645
444444444747444244484744464545454545474B494644444646423F4646444344484948
4547484745444446414244464746423F4848474746474748414243444445484A46454443
41403F3E3E3C3D3E41474741414142434443413F3D3E3F3F3E3D3D3D3E3E3D3B3C3F4140
3C3E3F3F3E3D3F4047413F403F414546413C3A3C3E3C3B3B3A3A3D3F3D393A3D393A3B3C
3D3F3E3B3A403F44463F3D3C3C3C3C3C3B3D40423C4143403B393A3A3B3B413E3D3D383A
3A3C42423C3C403F3A3B3C3B3A39393A403E3C3D403E3C40414141403F3E3E3E3B3D3E3E
3C3B3C3D4242403D3B3C3B3A3B3E3F3D3C3C3B3A3E40403D3C3C3D3C403A373A3C39393D
3D3B3B3C3B3B424B4D534C45474F544A4D4B4940463D404548443F4448474A493E3D3837
3B3A393F443C383D413D37353A3A3D43433E3A393D38383D3E3A383A3B36383F403A393E
3F3C373B3A3F404441413F404444413F413B3A3E3F3B383A3A3E403D393A3E413B3F4449
4344423E3E31354239484B70646660715F7D6D81645B4E545250606182716552413C3A3F
3D3E413F40413E403C3D3F3B3D4442423F43424F4E4B535A778691B6CCD1C8B4B795AA8B
AC8B979296939D9DBBA9B3AB9E969082666F6E8B6D6B525A5D8B7AA56D7A9AA4A3A0723C
3F3A353A3D453F36393A3C3D3A3839393C38383D403E3C38423C3A3C3C3E3E3835373E3E
3D383E62503E3C3A35373A4160777E4F44413F3B3A3F3D3A3A393A3D353539363A3C3D3C
3F3B3C3D39383A3A36383A3A3A3838383F3E3D3B3B3B3C3C3D39383A3A37383D3D3E3E3F
3E3D3B3A3D38373C3F3D3937393D3F3D3C3D3E3C3E433E383D413C383A3B3B3C3D3D3E3E
373A39383937363A3E3C39393A3C3D3D36393A37353636363E3B3534393C3936363A3E39
373938393B384038383E4460657C9DB0A49789695D50393940403E494E4E5359474D504B
4C474B40423E41343B3A3A393938383837393B3B3B3A3939373A38373B39373A3833313A
3D3B3A373B3A3B3A3C495554745F90B9DAC2BD9E97837151493840353C4242575D906A9A
95AFC2D0B5B184765E4C403E3B3B3D3C3C3C3B3A3A3A3B3C3C3A383738393A3B393A3635
3336323A3B363F2F3A353A39383439413D3B3F403E526A82A3A2BAB1C0A0978998A8A5A3
939194B1C0E9ECF2E9E7D9E4D5E7D3C2AD97705D4733383B363739383838393B3A3A3A39
3838383737373738393A3B3B3A3D3F3C3A393837
4D4C4C4B4948484747464544434344444A494747474645434948494B4A46444647464545
464544434246474442444748434344454545454648464444454544424443424141434444
45484A49464344454342424244444342413F3E3E3F403F3E404346474543424144434342
424242413F4042424446453F3D3C3C3D3E3D3A373F3E3D3D3D3C3B3B3B3C3D3F40413F3D
3C4043413D3B3D40463C3B3C393E423F413C393C3E3C3A3B3A393B3D3C393A3E3A39393A
3D3F3D3A3D3F3D3D3C3A3B3D4141403E3D3D3F403B3F413F3F41403C413C3F3C3C403B3E
3A3C42423D3E413E3F3F403F3D3A38373E3C3B3D3E3C3C3F3B3C3D3D3C3C3D3E3C3D3D3E
3E3E3E3E44423E393738393A3A3C3E3E3E3D3B393E41403B393C3D3A3A36363C3E3C3B3B
403C3C3E3D393C43494B4640424849413E3C3F4358554E45494542474A4846444640393C
403B393F463F3B3E413E38363D3F43423C373A4046403D3F403E3D3F3C3B3D41403C3D41
403F3E3E3F3F4041383D3A393E3D3B413F3A393D414140403E44453F3A3C41423A3C373C
3A3E3C433F413D3C4C425D57726A8C6C7D6370718882747C888A8D8A6F5D514643464449
4440413C3E413B43494644424346434159587881A0808E87858F9BBBCCCAC3B6A0987D86
6D897F968392758B6D7758594B4243494149404E565261657C86A5A7BDA0A0AEBECEAD6F
6A5E42353A4138323E3B3E433F3B3D403B3B3A3D3D40453F3C3E393B3D3B3B39383A3D3C
3D40598889553B3A3D3F3B3D434E473A34413A3D383D3A39393A3F3E3D3A423C403B3632
3936363A3936383B4846423D3A3838383D3C3A3938393A3B3F39383C3A373B443F3E3D3D
3C3B3A383D3B37363B403E383D3F3E3B3A3C3C393A3E3A373F433D373B3B3A3939383838
3536363635353638403E3C3B3B3A3938373837363636363538383938393D3F3D3A393E37
363D3A3D393E35363F4D6F899C9B988E705A4F393C4040413B444A647770615540474A48
46403A363939383739393838373636353838393939393A3A3B3D3936383735393C3A3740
3F39403E3838353D526570786D6B76BCA4B48E7E58513F3F3C444543594E9A6689708993
BFBDCAA193685E4E433C3D413D3B3A383C3B39383738393A3F3C38373737363538343635
3A3E353C393A383C37383541433F444D484C64708DBBAFD7BEDCC7BA9F9361664E637579
B5BCD2D8DFEBEFECE9D9E0C2B897947666533A393D3A3E3C3A3B3C3B3937373739393938
383838373A39383736363737373736353537393B
4C4C4B4A4A4948484F4E4C4A4948484844434345474949484746484A4A47464748464545
474746444347494643454748444647484848464445464644434346484443434342414243
45484A4946434445464442414243444447454343444544433F414445433F3D3C44434241
414243433D4142414343413D454342424242403E403F3D3B3B3B3B3C3D3D3D4041413F3D
3B4044433E3A3B3E453D3C3D3B3F413B403C3B3E403E3B3B3A393A3C3C3A3C3F3C39373A
3D3E3C3A3E3C3D3A383B3E41403F3E3B3A3A3C3E3C3E3E3E4347433C433C3D3D41463F3E
3B3B3E3F3F44443C3D3E3E3F3E3C39373E3B3C3E3C3A3B3D3B3D3E3D3C3B3C3D3E3D3D3D
3F40403F42403E3D3B3A3B3B3A3A3C3E3E3C3A383D3F3D38383B3B383C39393C3D3B3A3A
3E3B3D4448474646484442424344403F3C3D40445F61564347403E3F414241434C43393C
413D3D4645424142413E3C3C3A3E44454039393E484645433F3A393B3B4245403B3C3E3F
393B3D3D3D3E3D3D3C3F4042443D3B453D3C3A3A3E43433F4045453F3B3E4344464C454D
4B4B4D68694A48656873637F6E8981A46D8E637A7676625A635F554F4D44434246484244
3F3D40404F5D6273867A717578757577636A74A6B4B5A49E969794959A9790805D52674C
624A554B3E4D484A4543413F403A3C453D44484C526260846F89878B89918387A2ADB4C2
BFAA7545403A38423F3D3F3D373C423F3B3E414840373D393E493E3C3F37383E383C383B
393645588B5A413C3839393A3F3C30393E3E3A3A3A3F3A3C3D3D41393C354039413F3D3C
3E3C3C3E3E39393E544F48403B3837373A39383738393B3C403A393C3C393E473E3C3A3A
3A393836373C3B37404D4B3F3C3D3C393A3C3C393A3F3C3941453E373939383838393A3B
37363737353538393C3B3A3B3B39363438373637373736363B39393836393E3F413E413A
3A403C3E36404457768D9BA09F8367584339474C52473E383346567A726F60554345403C
3839393D3E3B363934343536373839393A38373637393A3B393D3C393B39383D403C3841
42445353574F4852605D54534D485F636150514343403B4555727C8576A993A57BA482B6
A3986F6C4A4B3C403D383A3C373536353A3938373738393A38373637393A393838353937
3B39323B2F474C4C484F4D4F444B5057556593B0CAD6E3CCCEA09A7560495B668FB8CAD2
DADEE6E1DDE7E0D6CDB998905D58433E3D3B35383B3A3A3537393B3B3A39393937373738
383838393A393836363536363838373737373A3C
4E4E4E4D4D4D4C4C4B4A4947454443434444444548494948474546494A48474848474646
484948464949474546494742484A4B4C4D4D4A46434647464444474B4746474847444446
4547484745444446474544444546464545434141424241403F4041413F3E3F4047464441
403F3F403A3F403D3F3F3D3D403F3D3C3C3C3C3B41403E3C3A3B3C3E443F3C3E40404040
3A3E43423E3A3A3B464342424244433C3F3C3C4143403D3C3C39393C3D3C3E423D39383A
3D3D3B3A3B3B413E3B4143453E3E3E3C3B3C3F413F3E3D3F4446413A3F3A3E4045483E3A
3C3A3B3C3F46463B3738393B3D3D3B3A3C393C3F3C3A3B3C424343413D3A3A3C3E3E3D3E
3E3F40403E3E404444403E3E3A393A3E3F3C39393C3C3B393A3C3C3A3D3B3939393B3E41
4948494C4E4D4741453E404143413C3F4446453B4A4B46393C37393A3C3E3C41433E393E
44403D4443434342403E3E403B3A3D42433F3D3D41444747423C3A3A363F423A36393C39
373A383A373D3C3C3B3A3C43443C36393F403D383A40403B3D3F3F3C3B3E42444E534F62
61615E796153484F6B66796F846F8A5267404D424049423B42433E3E39373A393B3C3943
37485B6D869497A1979296AFBEBAB9B8B7A1AE94B27F866B65584D48504C49404040403D
3E40404036424047433E3C3F3C3F454A434A524C4D4E5A48605C5C65697E808FA19EAAC0
CBC5A97A714D3D3E3D41433D415E716A6B615B696353554A484C3C44565758554D463B40
42424B4546363B3D3B484B423C353834442E3D393B3E3436373B463C3E344138423B3635
3B3E3D3C3B37383E413F3C3A39383736393939393B3C3E3F3F3B393C3D3B3F453C3A3838
3A3A3835333B3C3A424D4738383A3A38393D3D3B3D44413D42443D383E3D3C3A3A3A3B3B
3C3A3B3B37393C3C373738393B3A383638363638383736373B3A393B3C38353735393F3D
3E43444547445F6F94AD8D825E47373D3C3F5868865D3F38393D3E514C504A4A42443A3A
3537393C3C38373B36363637373738383B38363536383A3A353C3C3A3936363C3D435671
818D948B755847484744424147464245383E3C3B34476F81A7A9A495AA9EA0778367836F
70584B3E4D3641363E3A3D3E39393B393938383738393A3B363637383A3B3B3A39373934
3B3D495C6080845D605F66534D4635456D98C2CBB4AD8F9D73654A52658593C6C9DDE3E3
E4D7E1D5E5D7BF978D65553E443440373438393A3A3B3B38343638393837373836363637
38383839363636363737383839393A3A38353538
4A4A4A4A4A4A4A4A49494948484645454847464748484746484545494B49464647474748
494A4A4944444444474B4A4644464645474A494545464848484747474242454846414042
454646454444454644424040424445454443424141414040404243434241414241414141
424242423D44423D3E3D3B3D43434241404040413F40403E3C3B3D3F423C393B3D3C3B3C
3B3D3F3F3D3B3A3A3E413F3C3F403B373E3B3C4043413E3E3D3A3A3C3E3E40443F3B393B
3D3B3A3B3937403B363D3E3F3E3F3F3F3E3E3F403D3C3E4143403D3B3C393E3D3F413A3B
3C3A3B3A3B4344393838393B3D3E3D3B39373C413D3B3D3C393B3D3C39383A3D3F3F3E3E
3E3E40413737393D3E3B3A3B3C3A3A3E403D3B3B3D3B3B3E403F3F3F3C3D3C3A393B4044
43474947484A48423F3A3E3C3D3F3A3E3B3F3F343C393C3B38353D3E3E3F393F3A3A3A40
46403A3D3F3F3F3E3E3F3F3F3F3B393C3F3F3F403C3F4242413F3D3D373A3A37383C3C39
3B3F383C353F3A3C423D3C3C3C3E42423C3B3A393B3F42433D3C3C3E3E3D3E40423F3D54
4E55525F6250536B6D6C5D6D565046423547373E3C3C3D3B3A3C3E3F3D3D403C3E3E3C48
5C737C828981756F7B8598BED2CABEAF8E906E714C4F3D3E45393B404C43414044424C3E
483A413A3F423F494F453E3B42434846444745454646495C567176767F86A2BFC8CDD5D2
BEAFA6838C6A655D4341474E6393BABFB9AC9B9C9288877079756C82989D9D8871574842
383C474143383F42485F5D45434440483F3E383B37403D454850645B7D6C766265544742
3D434039363638403938383A3C3E3E3D39393A3B3C3D3E3F3E3B3A3A3B3C3D3E3B3A393A
3D3D3B38393B3A393D413B3135383938383B3C3A3A42413C3E403B38403F3D3B3A3A3A3B
3F3C3E3D38393E3C393838393A3B3B3A38363739393637393739393E423A39463E494D4A
44444E5469575E555F66413D3A3A3A403E47667877513A363D39353A3D413A3D39393036
3935383636343A3C3A3A3938373636353A38363637383837343B3A363639414E64708C97
8F8D8475604C4243403D3E3C4A3E3637343B403F638FA5C3C2C8B3A6878F6F6550433E46
4540323E373F383C39373A3D3A3B3B3737373838393A3B3B393A3A3939393A3A3A38383D
50556A796B8165513C433C39415A658AB9C4B089725E48534E647192B2AFBAC4DAE6DCDB
D7CBB7C4A9A46B5046413641363E373C3A35333437373535373839383635353637373737
3737373735363637383838383837383937373C43
4C4C4C4D4D4E4E4E4A4B4C4C4C4C4B4A46454547494A4A49494544484B49464547474848
494A4B4B474B4B474342424146474644474C4D4A4746474A4C4B46424445494D4B454346
46454444444546464B474342454A4E504544434241414141414448494744414044444444
423F3D3B464C48403F3D3A3D3F4041413F3E3F403D4042413E3C3D3F45413F4345423E3D
3D3C3C3C3B3B3A3A3D433F3B403F39383E3A3A3F42413F3F3E3B3A3C3E3F4245403C3A3C
3D3A393B423E453D353D3E3F3A3C3D3D3A38373738393E42403B3A3E3C3A3E383437373E
3B3B3C39383F41373E3D3D3E3F3F3D3B37343C423E3C3F3E3F4142403B39393B3F3F3F3E
3D3D3F413D39383A3B3B3E423E3B3B3F413E3C3D3F3B3C41444341433F4243403B393A3C
3D45463E3A3E3F3B3C3B403939413D3F3A3C403A3F36383B3C39403E3C3C383F3E3E3B3B
3F3D393D3D3B3A3A3D3F3E3C3E3D3F403D3A3B3F403D3A37383939383C3735393F42413F
3C41383E33403737393B3F3E3A424A45403B393A3A383A40413D3E42423D3A3B4347536C
575D58574C4B4F57544240423F3B3F39394235343D333F4A4546463F3F3B3B3C49545969
586B635D625F616082858595998A78635454493E3E3E47413E3B423C413E42434A484F46
5452696C7D736F687F6D6A58524D524E57636B89749797AFC9BFD1C7CCD0DDDDDBDBD6DC
C3A29D87A4929D8C836A5B5658708D97A2B8BFC2B7B6B897AFA9A4AFA391886566515C5D
4A494C484E40433E405E706A948A968A896B53413F5563787F86988D85717A666F666163
686D624F443E3C42413E3B3A3B3D3D3C3738393A3B3C3C3C3D3C3A393A3B3A373C3A3A3C
40413E3B423C37393C3C3B3A363A3B3837393937323C3D383A3B393838383737393B3D3F
3F3B3D3C36383C3B3F3D3A393A3B3B3B3836373A3936373B383C38383C394769727D7462
483A454B413E3B3A3D39363E363B3735364357583F3536343A34383A383B333937362F39
3732393739353C3638383838393939393938373839393634363A383439465C71A69EA08B
70675440444745464942393A4034363835394B548DACB5BAC3AF9D79624D3F43413B3B38
3A343A33393B38383A353638373B3D39363738393A3B3C3C3A3A3A3938393C3E3F3C3A48
5F575A544845393B4738435373AFC3C1B39175586A707B8891AFACB5ACB5B0C5D1DBCECC
BF9E907463473E3B3C3B3B363B3939383E3534383935343A373839393838393A38383737
3636363537383838383736353A3837393A3F4D5A
52484E425348514B46484948464648494C4B47434346474543413F404345474747444447
4744444844444343474B4A46414546434345433F3F46494642434442424446484745423F
3F424544424244474A424146433A3D483F4547423D3D404241454746423F3F413F40403D
3E41413F414141403F3D3C3C3E4047463D3B42444043423E3D4042414442424546434141
3D3C40413A393C39393A3C3D3A383D444138353A3C393B423D383E3F3B47373D3B3B3A38
36373A3E3A413F3D38353D3D393B3D3B373537393938393B3834363C3B3D3C3A3A3C3A36
3738393A3A3A393839353A3F3E40423D393A3C3C3C3E4144454A3E393B393D3E3F444039
393A3F483C373A3F3C3A3C3B3C3A3E413E3E3E3A3F454A48424149514B464343423F3C3D
3940403C3F3E3938383E403D3D4245443E3A393A3936373A353C3F3D3E42403A38393E44
433E3C3E35393E3D3A3A3D423840433C393E424137343D3C383B3A3C3836373C3E3C3939
3C3E40413F3C37343A393B3E3F3C3B3E3D373E423E46515050484B435345494841485666
57544D43424141403C3A40473B3E3E4639453944413F474D4B47484D50515A574A505F5F
5B5B5F63635F5F62635A5B594C42434B43483D3E3E403F463C4849505366696E656E7D80
7D90ADBBC5B4ABB4D3CBCBA1978D999DACC7CCD2D1D5DCD6D6C9C9C3C4D1CFCED1CDCDCA
BCC2C0CFCFCED3D4D7B66E4E4347546D7686949CABBBBB8F7D848DA7A75A493C403B494B
517F8D9791806D55498888ABB6D2C8D0B28B51474A494E605E767882A389A880947F9A91
ACAA9E9D8E6A6741423C383A3A35353D3D3C3B39393A3B3C3E3D403E373941453B413B40
46404438353D413B363739383338383B3637433D3B3B3B3F353E3C38403834383D3D3937
383938393B3A37363B3C3C3D3D3D3D3D373A353C3B353B393D3137433F4E6A7F7E6D5542
3A38383835383E413E3B3B3E3A3B41423D3D403E363738393A3A3B3B35393C3E3D3B3A3A
3A3A3A3A3A3938373637383A3B3B3B3B3A3B3B3B3A393734363C3B3747557E987E87604A
4452424957493C393B3E3C36343E353952667E838A9B968A7E7263453B3A393837373838
3537383939393A3A39393A39373738393737373737383838353B393A323B3D403E36414A
42403B3D37485863736E8392CFD5C4A28B807D7F9BB1C2D1D8DDDBC3CCC8C9CACDBD947C
73604E3C3A423D3B333F3B353C3C36393838373637393B3D3B3B34373B393C393B37393A
3735373E383C3B383838393B3E3E44477A7D9FA8
54534E504D504C4B4E4E4E4D4C4C4E50494A4A48494B49454B494747484A4B4A4A484748
4947474746464443464A4A464848484A4B4A4B4C45484947464748474447494B4B484542
404245454444474A474242484740404642444340404242403F424444424143443B3D3E3D
3F4547473F3F3E3F3F4040403C3E45463F3C3F3E3E403F3B3B3F43443B3B3C3F3F3E4043
413E41413D3E413E3A3B3E403E3C414848403B3C3C3A3C41413F45433C44373E3A3A3A39
39393B3D3A423F3C3939403E363839393837393B373A3E403E3937393E3E3C3A3C3F3E3B
393E43433E3C3E413B373A3E3E40413C3C3C3B3B3B3C3F40454D42393A3B3D3A34393939
3B39393F3F3A3C3F3C3C41423635393D3B3D403D43403E3F41424241403C3A3C3D3C3D3F
363D3C3A3E403E3E3E3D3B3B3A3B3E413C3B3B3C3B38373A363D403D3E42403A38393D43
44414042363A3F403D3C3D3F3F4547413D3F42423E383D3C3A3F3D3C3D3A3B3F413F3D3D
3D3E3E3F3F3F3F3F393C3D3E4144423F3B39434A45464A434748504855484F5147494F58
4746423B3C3C3E42423F3E40393C414C5060504C4B4C505C6057535555555B584D525E5D
4E4A4745413D3F433D3E403D3E3F3D3B3D3E3C3C403E3D3C466176827E8F989C999B978C
858F9DA29D9694A8CAD0D6B79F98A3A4B4C8CECECBD0CAC5A99C969FB4C6CBCDCBC7CFD6
D2D5D2D9DBD8DBD8CA9C5F4A4C585F757B746C867E85847F5D686177897D4B46414C676C
6A93A8BAC7B9AF796B655563639188B3C9ABA28C795C5654494E525294A5B7C6AFCEC3C6
B3B0A4A399838F7759453D3D383B43443838393A3B3C3D3E3D3C414039393D3C41343C38
40413C3734383B3C3D3E3C3A3936343C3B39423D3841383F3A3B453638383B3D3C3A393B
3A3A3C3C393B3F4039393A3A3A3A3A3A33393436393B3D333C4842505D45554F4C443B36
373A3C3C35353A3F3E3A3B3F3B393D413E3E3E393738393A3A3A3A3A3C3D3E3D3B39393A
3A3A3A3A3A393837363638393B3B3C3C3A3B3A393B3B3A3C383539435359696254533C3F
3F4F44453A3A3C3F3D36363D3A4761717E97868A75746150454040353939383837363535
3536383837383A3C3B3C3D3D3B3939393A3939383837373637393B433A38374134393C47
343D35415883ADC0C7BCCBD5CFC5AF9FA1ADBBC8D5DBDBE0E3E6E4D0CBBAA69388745244
3D3A3E3C445153565351454553544B4D383E4547434142463839383B393B3F3237373836
36393B3C3F37343A383840404E6E7EA7C2D3D4DC
54534A4C464C4949484949484645444545474746464846414B4947464647464646454443
44464441484745434549484547424245454345494A474545464443434143464848454240
494A4B484442424344424448494643434544403F4246443F44444342414141413E40403E
40444646413F3D3E404242423F3D41433E3D3E3B4243413D3A3B3B3B3D3D3F403F3D3F45
423F3F403F4143413D3E4143413E404545413C3A393B3C3C3E3D44413A3F353D3B3A3A3A
3C3C3C3B3A423E3B393D433E3A3A3A39373636363D3F403C383737373D3C3A383C40403C
3B3B3B3B3B3B3C3D3E393A3C3E40403C3E3D3B3A3A3B3C3C3A463E36383D41393F3D3A3E
443F393C3E393A3B373941443D3A3D403D3F423F413F3C3C3D3D3C393F3C3A3A3835373A
3D413E3A3C3C393A443E3B3E3E3A393D3B3B3D3E3C39383A393E3F3D3D403F3B3938393C
3C3A3737373B3F41403E3C3B414446433F3E414341383A39373D3A37423F3E403F3B3839
3D3D3D3E3E3F40413D3D3D3E403F3B373E3E4A5351514F4651545A4C5346484741404247
3A41413F3E3C3E4345403B393F434B53627063545054516168544B4A4F4B4E4C4549504C
4A46413D3A383B404043433C3E40433D3C3F3E4842545B67899CAAAC989E9E999C998A7A
7B81838488857E8EA2AEB7A89D9AA5A4B4C1C8BEC8C5BCB89B8A7A817C868587898EA5B7
C1CCC9DED8DDCEC6A48F888F949A939F9A91A09CA5909C8F9E809C7A846F6C80929BABA8
959E959198AC9FB48B9C6D7F71906E9BAFBABCB5B88BA594AD95AB96AD9DA77B8291B7C0
CECAC2BAA88C8F776B4E4544373A413639393A3B3B3A3A393C3A3E3E39393B393E3B3D43
353638413D3D3E3E3935363A3D3C3A3D3D3D434040413B3D3F3C463C3A39363434363737
35363F4137363B393D3D3E3E3E3E3F3F383631383D3C3C36425A64684B493F3C3F3D3A39
3A3C3B3B3D38393E3D36353A3E39393C3B3D3D3739393A3A3A3A3A393B3C3C3C3A383737
3A3A3A3A3A393837353638393A3B3B3C393D3B3A3D3934383C393B41464245394B403747
3F48413F373C3D3E3A313E5C5F79A1A9AB8C7A5D5A5140383431383A3737383736353332
3537393836373A3E3B3D3F3E3C3938373A3A3A3939383838393D40453B35374439364731
3F385364A8CCE2DCCEC0CED8E2D8CCCCD4D7D9DEE8E5E2E7E6E0D5BFA88D6D524840373E
4D51606C7D8C88858F7C625D665F4E4A3D434948423B393A34373A3A323B4A3F33383734
34393B374336354343517885B0C4CBD6DBD6D1D3
72655D4A514B4F48494A4B4C4B4948474F4F4C49494C4C494746444342424242494A4846
494D4B4649494643444747444C4A4948474747484A4441454745424348484A4A4A494847
464748474544454645444445474744404544414043474540484542404040403F41434340
3F41424143413E3F4243413F443E3D3E3C3F413E3B3D40403F3E3E3E44424143413E3D3E
413E3C3D3F41413E40404344403B3B3E3E3F3D3A3B40403D3A393F3D3B3F393E3E3B393A
3D3D3C3A39413C393A3F443D3E3D3A393938363434383835353A3E3E3A3A38373A3E3D38
413C3736383C3E3E3E3A393B3E403F3C3E3D3B3C3D3D3B3A37403B393B3E433C3E3C393C
3E383A463E3B3C3B36394144413E40413E4043413F3F3F3F3E3E3D3C4241424443414347
3A3E3C3A3E3D3A3C3B38383D3E3A35323A3B3D3D3B39393B3B3D3D3A3A3D3E3B42403E3F
3F3D393737393C3F403E3C3A3C3E40403E3C3F4241393D3A373A38373836373B3C3B3B3E
3B3C3D3E3E3D3B39413D414A4B44434A46444B515152524B4446473C453E3D3743404143
38423F3E47434243423D3A3B3D4046424B4B463A3F4942545E474143423C3D3D3A3D403B
4242413F3E3D3F413E3A3C3734364C4E4D5C617962848BA29E9EA1A0878A8D8B8F877065
70777B8788897D84848B8D857F7E82797E7C7E6C7B6971576249504B5451484B4E505E67
616B6C8B97B7B8BDBEC5D9E1DBD8CEC7C1CBC2D0BACFC7C4C3C7C0C6A8AD709BBDCBDAE0
D2D2C1B4B4A5B9ABBFA8B8B1BCABA081898A929B9E8C8CA9A2BAB3B2A8ADB0B8A0BFBACA
D1CCCBC3B39791787C625954444142343B3B3A3A393938383C38383936393E3D393B3A52
3C452F3E5F544A443C34363D3E413C35353E40384037403C433F3B3837393A3A3A393631
47434C4D403D40393B3B3B3B3B3B3C3C4A3D383F3B313A4D616F7F4E413839383C3B3A39
38393A3B423A383D3D36343840393838373B3F3C3A3B3B3B3B3A39393436393A3A383635
3A3A3A3A39383737373838393A3A3A3A393C38363A35323A3D443F3D3E393E424B413D47
363735373738384451505E818299959A6E584A3A3F3B37393A393B3D3737373736343332
36393B3936373B40393A3C3C3A3837373939393A3A3A3B3B3B3E3A3A3B3D3A3B383E3948
4E7287B1D7E2DED1C4C0D1DADCD9D9DEE2E0DFE3E4DDDBDDD1BAA28C725C483B3E444B5F
7074838F9EA79D968B795E52544A3A333A39393939383635373736373236423A393F3C39
3738404045495C7F91A9D2DDDCE2CFD7C4C8BDCB
B5A39076746861524F4D4A484748494A4A49474344484846474746464544454542434240
44494742494A484444464643454A494342464640484342494D4B48484342424141424343
4445464544444545484642404245433F424444414245464444423F3F414343433D414341
4041414042403F414344413E453F3E3F3E4144403C3D3F4040404143413D3D4144413C3A
413F3D3E42423E3C41414345413C3B3D3E424240424746413E3A3E3D40434040413D3A39
3C3D3B39383F3B393A3E423A3C3B393A3C3D3C3A353A3C3938393834393A39393B3E3B35
3A3B3B3937383B3F3C3B393A3E3F3E3D3C3B3C3E403F3C3A3F403D41403C403D363C4143
403D4A62424143413B3D43433B383A3C3B3E43413F3D3C3E4143413E3A3B3D403F3B3B3D
3A3E3D3D3F3C37393F4143444748423B3A3B3B3A38393A3B3C3C3A37373A3C3C38383737
393938353738393B3C3D3C3A3B3C3E3E3C3A3C3F413E46423A3B3A3C3C3A3B3D3D3B3B3E
3D3D3E3E3D3C3A393D3D4348443C3E474642434544454540383C3C343C3B3B3844444849
414B413F48474746403B3C413D3F46454D454A463E493E494D37353B3E39383A3A3C3D39
3C3E3E3B393838383E363E42465177758992A1A58D8F888E929097A2929AA9B5A092766A
73768098A0A597927C715E534F4F524A4A474839434440433A4B3F424E4E526674767974
686C5C7D7EAEB0C2C5D6E3E3E0E3DDBF8686A7A9C4B9C5BBD3C1D6B7B3B0B6A3CBD5D8E2
DCDED2C3C2C2A1C3A0C5C1D5DED2CDBA93998F9BB4AAB08685728892BCC0E6D0D8CBD2CF
B99E886E5E52584D4E433F3E3A3D424138383738393B3D3E3C373839373A3E3C3C383D41
3947466D6C55413E403C3736363B3D3C434A453D3B4244424C484A3C363D44433F3F444A
594D4D4A3F40453E3B3A3A3A3A3B3C3C3E39393A393F546C617C4B3A3B40323B37383839
393A3B3D3E37353B3E3A3A3E3B393B3B37393F3F3B3B3B3B3B3A39383838383839393838
393A3A3A3938373739393939393838373939343337373B46424941413F3836363C3B393D
32353538383C435B7067606F7B6A744E40353A3D38373635363938373939373635353535
383B3D3B37373C4138393A393838393A3B3B3B3A3A3A3A3A353C3931363A3D424E476669
A0A3C7DDE0E0DCE1DCD7DAD9D6D6D8D8D4CECAC7ADA19D97846D5A504E454343494B4B5B
6468716E6C6B615D4B493F393C3F3C3A3A383636383938373937333C3E3939353A3B353C
46587C919BA2B3CFDDE1E0CFD3BBBF9CA6767974
C0BCA5A597A08C82665F554D4A4A4D4F4B4C4C4B4D50504D474748474646464747474747
494C4B484849494645464542444C4C44444C4C4447464649494744424847464545464849
47474645434241414945403E404242403F434542414346464543403F404142413E424542
3F3F403E403F3E4043444341423F42444243433E4341403F3E3E41453E3B3C4449484442
41413F3F44433E3D40404345444140433E4141404244423D3F3C3E3B3F3E3E3C413D3A39
3B3C3B39393E3B3C3C3B3E383E3C3B3C3D3E3D3B383A3B3A3A3C3D3C393C3D3D3E3F3C37
36383B3D3E3C39373A3C3A3A3D3D3A3C393A3C3E3F3E3C3A3B39373F3C373C3B3D3F3D3C
3A3436423F3F42403B3C403D3E3B3C3E3B3E413F3B3C3D3D3D3E3F4043434547453F3B3C
3E403E3E3F393335363939373B403D363B3C3A38383B3C3B3B3A3937373A3C3C3E3F3F3E
3E3F3E3B38383838393A3A3A3D40403E3C3B3A3A3D3C46423939393C3B3B3E4345444649
413F3D3B3C3E4042464E514A413F40413D3C3D3E3E3D3D3B3C43453E3F3B3E4344464C4C
4753434141434647423C3E43414042444A3F423C363F393F423639403E39393C3D3D3D3C
3D3E3D3937393B3C3D363A3D48516E5C675D715F675B5D5A5C595E6E656C727A71685750
5550546960696362575346433D3B3E3D3A42464640424257679B9BA68785848F9494978F
99819A7CA790ACA5ACC1CFD2D8D9D2AB9BA49DA6A1C6C5CBBCD0A6B08EAC9FB9B8C1BDCC
CCCEC6B6BDBDCBBBD1BCD8D5D8CED4CDCFB0BFA6B2BEB09887868096ABC1C4BB98AFA0A9
64504D41403F42383B3D3C3B3C3A393D3B3A3838383A3C3D3C393C3E3B3B3B373B3C3445
615882864F3F34373C3A363538393C3A393B42535D877F898A6F6D3D3B3C3E404145505B
49413F3E37393C363D3C3C3B3B3C3E3E393C3C36435A594E4A443F2F3F36393D393B3E3F
403F3E3E3D39383B3C3C3B3C37383E403A393C3B3A3B3B3B3A393938413E393637393C3D
3939393939383736393939393938373638373B403E3A3C41363A39423A39393236383738
383C3A3A3543515E62564F59514D4344353F37393A3A3B35363C38363938373635363637
393C3D3B38373A3D393A3A3A3A3A3C3E3D3D3C3B3A3938383B3C3631434E5C6863748EBE
CCE0D6E5E5DFD5DDD6D0CFCCC7BDB3A99A8C7E736F63645F52484345423E3E3D41403A43
3F3F45403F423B3A3C41403835373735383B3D3B383636383536333938303B4641526488
A0B0CDDBDED9DAD8CDBFA78E7C6761555647474E
68726B797389807E615A514A464647474A4B4947484B4B48464748474645454646444445
4644444546494947464645424146453E3E444541454848454241403E4343434343444545
434343444545464646434142434241403F4243414144464647454240403F3F3E3F434441
3E40424342403F3E3F414243414145474140403C3E3C3D4041404449403F434849474647
3F403D3D42423E403E3E4044434141443C3C3C3B3D3E3D3A3C3C403A3B353A3A3D3B3A3A
3C3D3C3A3C3F3C413F393A383E3D3C3C3C3C3B3A413D393837373A3D363B3D3C3C3E3D3B
3E3C3D4146463F383A3E3D3B3C393638393A3B3C3B3B3A3B3635353A38363D383A3A3739
40403B3B39393C3B373A3C36433F40403C3D3F3C3B3D3E3C39383B3F3C3B3D4243403E3E
3739393C403C393E3A3A393A3C3D3A373D3D3B3A3C3F3E3A38393A3B3B3C3C3C3B3F3F3D
3B3C3A373B3B3B3A393838393C41413D3A3C3B3739373F3C3537373941414345433F3F41
403E3C3A3B3E42443B44463E3B40423D383A3C3D3E3D3D3E363D41424341444D49494C47
424F3C3A3D3E4042403C3C3F393D3B3D423E41383A3C393A3B38393B3B39393C3D3A393B
383A3A37373B3F3F3D3A3735443947344D41463A454A44494E4F4A4C41443E3D4245413F
423E3B42454A44403E423E41433D3F433D545D709E8AA793C7C5CFC0A69F94928E8E9288
8B8A7F9B8AA494A9A8AEBBBFC7C3C0B1B7B7BDA0A5A7ACA5B19F847D74665F625970758F
959CA5A1A2BBBAD0C2D5D0D3B9ACA4B0BBB7C2BDC2C6C5B5C9B49893ABA4A86D64524F42
463946424344433A383D3F3F423E38383D3C3B3A3939393A3D3B3F413C3C3C38383E4381
9C8A804B3B38393D3E3B3C3F4540403C3E485D816E845E564C404C343D3B404B4E48474B
39393C3C3A393937393837363637393A36353736495D4C363C2E43422E3E313B3436383C
3E3E3D3C3C3D3C39393A38363A383C3D39383A3639393A3A3A3938383F3C3836373A3C3D
3939393939383736373738393939383838343F4840383735393E3D4538383B3838373738
37393B3D424B504A413A3A3F3B3F353640313C3137353A36373C35343736363636363737
393A3B393736373838393B3B3A393A3B3B3B3B3A3A3A3A3A35383A497E9CA4A07085B6C9
D9D4D2CCD4CBB8B5A5A3A39F897D7C8075614F424C434A49413F3B3F3C383734393B353B
3C393A36383D373436373838383838373134373838383A3C3638373B3942617496A9B6D2
DFDADDD2D1B9B39C796650414941474959687581
4D53585153565B5752514F505253525156534D4645494B4A494A4B4A484646474B474749
4844434645484A48474745414E4D4A454446474740474945434649494445474848484747
48484645454442424340414647434141404141404246474442414140404141423A3E403E
3F454B4F4744403D3C3D4042454346453D3B3E3D3E3E4145443F3D3F42444747413C3D41
3B3D39383E3F3D403E3D3E41403D3D403E3C3A3B3D3E3F3F3B40463E3D333E413838393C
3E3E3D3B3E403E454238383839393A3B3C3D3E3E3734353A3B39393C33383B39383B3C3C
3A3B3C3D3D3D3C3C3A403F3B3B363236393A3A393737383A3E403E3E393A4036333A3A38
3936353838393B3B383C3E373C393B3C393B3D3A453F39393C3D3A373F3D3D40413E3B3B
3B3B393B3E3A383E3D3A3C42423C37363D3E3D3C3F43403A37383B3E3F3E3D3C383E4140
3F41413F3E3E3E3C39373737363D3F39383D3C363D373C3A363B3A3B3C3C3F413E39383A
3C3B3B3B3C3C3D3E4142403C3D41413D3C3D3D3B3A39393C3A3D3F464D4B4A514240433E
3D4F3E40413C3A3B3C39393A37403B38383A41393B383A3B3D42413D3A3A3A3D3C38373B
363A3C3A393C3E3C3E3E3A3D5137403D39464765618467796771665640413C3E3E43403A
3B3D3B393C403D383C413E423A3540555C8AA1C5C6C0BBC1AEB79394898B8E9BA4ACAFA0
AB8FAE8CAF849A97B59F9C9191807679766A6D76747579958BA17F7A6C7C5E7562716B87
96A3AEA8BCC3D2CDCBCACDB4B591956A6C63658596BAB9DBC9D6AEC8A8B5A3B0818F4E43
4637423735393F3E403F3B3A3C3D3C3B38393A3B3C3C3C3C3E3B3E3E3B3D4140404983B1
7C88423B3B39393C3D3B3A3B433F42434B4D434C40473E3F3D413C414647505952413C43
373B3C3A38373B413B3A393838393B3C3D3338393C3E383E3440383146473C3B3E3C3A39
39393837363A3B37373B3A36413A3736343739343839393A39393838343434363A3B3B39
393939393838373635363738393A3A3A3A30394035323A392F3A343D3C3D393B3A373C3D
373946503D3B39383C423D2F36393C383A4039463C363B38383A32353334353737373635
38393938363434343537393A38363535353637393B3D3E3F48657A84ADBCB19B7D9AB7BF
A8AFA5A3898A808274756E5F5A47454F4A3E3C3F3F363F3F3C3E3A3C38383B3940423838
32353C3634383538393333393D3B38383C383434373939373C3940536688B2BBDBE2D7D9
D2BDAE917E54554C394347494F68719B90BEABB6
4A5A776C868DA293A9999091898C85947D5E534A4A48474C4B474F4B444949474849454A
454A464748484747464544433F43444243464644484A444741474549444548545D524444
4447434645464E44414042464845454744444B4049485B4D414B4039433F3A4849454342
403D3F444140403F3E3D3E3E4142413E3E403F3B3B3B3B3D4042403D3F3D413D3A3C393E
3F423B3F423B3C3F3C3F41403D3D40433B3E3E3A393B3D3D3D3E3D3A38393C403D3C3C3D
3F40403F3C3C3F413F3A383A3A3A3A3A3A3B3B3B383B3B3B3C3E3B373A3A3D3C3A3F423C
35383B3A3A3B3A36353B3E3B38383939383D3B3D3A383F403B3A32363A3A3D383A37373A
3B3937383C3B3D42433F3C3B39383B3E3E3B3C3F403E3E403E3A3A3E35353E3C3B3E393E
3A3D3D3B3B3E3F3C37363D403A383A393C3C3F3D373A3C383D3D4146453D3939343D403C
3D43413A3B3A393838383737373E3E3C3D39373D39363A3B36393F3E35373A39393A3E42
393B3C3C3E42413D3B3A3D3B373B403C35393B3D48524D403B3F42484C47454B3C3C3C41
3D3D443C3C3A3F3C3B3D383A353F393B3C35393B39393A3F4138353D383B3A37383C3C39
393B3C3B39393A3C3C3E34393E3639413A54696B7D7264584A4A453D393A3B39353B413F
3D3E403D3C403F3C37404B5546528181BFB8CDBDB78A8477867E9B9BA697A09A9FB0ABAE
957D6C6A645751555353494A4D464647464C42494B49494E5455636C8A9AB8B4C4BEC1C1
B4BDB7BBAABBADC199B498A47E8D8391747F6F768D95ADC3C4C4CACFD7CBC4B8AE7A6C6A
71563941363F3A403A393C403B383A39363E38393C383B413C3C433C3E3E33465A779666
4C3E3E42383B4035363B35413A3D4234413540414140394036393C394B4E6350463F3A3F
3B41483A39353B36323235383836383C33373B364137333B3A373C3A3A3E3A3D393D3D39
383A3B393835373C3D3C434D4B483F3736393833373737383737373634363634373C3B37
383B3C3A3533343634353637383A3B3B39363A3C393A3C37393E3A3537393A3D40393935
42544E483B38383A38353335353135333C353838383938373536393B3238373538393534
36373837353434353439333A3D443C3E353A304236476A9A8EAEA5A18F848C76909AA797
918F8E787C6D665B49454841383D3B3A3F3D3A3C38393A3A3A3A3A3A36313438383B3B35
3B3E3E35353A383E353D373838373E353338383B433E3F485A8985B9B9CDDCDAC5C0BBB1
7C645A464443404C4A586981B4B1CAC4D6CAC095
7E998DB49EC7ACB3B0AAA39B918D83836F574E4B4C514E5042504F434D51464D42464649
4446454849494847464544434548484646494A4843443E44414844454543434C56514645
3F42414746474E4743424449494746473D3E403C4640493F3C453F3C45433E473E3D3E40
403D3E4242403F3E3E3E3E3E43454442404142413C3A3A3B3F403F3C3D3A3D39383D3C41
3B3F383C40393B3E3E41434341404244353A3C3C3C4144453D3C3C3A3A3A3C3E3B3A3A3A
3C3C3C3B38393C3F3E3B3B3E3E3E3D3C3A3938383A3A39383B4042413A3A3D3C383B3E38
373A3A39393B3B383A3E3F3C39393937373B383B3A383F3F3438353A3E4049493636393C
3D3C3F453F3C3C3F403D3B3C3D3C3E403E3A393C3B3A3B3D3B3736393B3A413E3D3F3B3F
3C3E3D3A3A3D3F3D3A3A3F3F393A3D3C3B3C3F3D383B3E3A3C4045443E38393D3A3F403C
3B3D3D393B3C3C3A37373839383E3E3D3F3C3A3E3B393D3F3C3E42403A3B3C3B3837393B
383E413E3C3D3F403E3B3C3D3C41433D42413D3C424A48403E403E3D3F3C3B4137373941
403E443F38373D3C3E423E4138403A3B3C3638393A3C3B3E403B394037393A3A3A3B3B3A
373A3A3E393B3738363F464D494752535F5E584C544D4946393C3D3D3C3E3F3F403E4342
3A3C403B3E433E4851738087798D9AB0BABDA18F797C6CA482A38C9E958583776C665650
4E463F3F424443423E413D3E3F40474341473D463C433A4740544D786F9EA5B3B7B1ABA0
87816B61515556544B544D525A626D767F8FA7B9BABDBBD8CADAD3DCD9E3C7D2A2A28482
7969505043544C4242373E3F3E393A36363A3A3B3F3F3D3D40363F3E3F4444574D5B5745
435F675C5C3C38383640413B3735413A47474D463F383D4039453C3F413F483A3A3B3B3E
3337403838343D3B3736383B3A38393C363A3A323F3835363835393636393538393B3C3A
39393A393836383B3A3B4856564E4136333536353838393A3A3A3A3A3A3B3B393A3B3A38
37383A39373637393A3A39393939393934343A393232383832383A3B3C38353935394345
4D574F4A3B38383938353536403A3C393F393C3B373737373738393A383C38323336373B
3738393938383839343B37383236353A38333C304782C0BAC8BAA1797574808C8C8C8975
717173664D4342403639403B393D3B3A3D3B383A3838393A3B3B3A393833363938393832
32363633393C36363238373338393D3A3838495C9191A295ACB7ACCFD0C8B9A0916C4E51
403C464E576882A7B6C4C8D1D3DBCFD6A8A8816A
7474948DBC9CA192919CA099918173605B4E5351525051525B4D4E504E4D464446454444
4446474748484847474747464445444344474848494A464B464B454545423F424B4B4543
4948484B47434741414143464644424247474241484347424044434346433E4042424244
423F3F4243413E3E3F403F3D3F3E3E3E3D3D3E40423F3D3F424443423B373B393B3F3C3F
40443D40423C3D3E4041434240404244404445403C3D3E3E3B3B3A3B3C3D3D3C3B3A3939
3A3A393838373A3D3D3B3C3F3F3F3E3D3B3A39393C3C3A383A3F403F404043423C3D3F3C
393B3B38383B3C3A3B3E3E3C3B3C3B38383B373A3A373C3A45453E3F3F3E44433637393A
38363C44423D3B3C3D3B3B3C3E3E3E3F3C39383A3A3B3D3F3D3938393B3A3D3B393A373A
3F3F3C39393C3E3E3D3F403A34373B383B3C3F3E3A3D403C3C41433E39393C3F3D3E3D3B
39383A3C3C3D3D3B39383A3C3D40403E3F3C393B3E3C3F42424344413E3F3F3D3C3A3939
393F413D393A3D3E3F3C3C3C3F44433A413C3736393C3B394044413D3E3F3E4139393942
403B3E3B413D413D3B3C37383B3F3B3C3D383939343837363836353A39393A3B38353639
3E3E353B35403D4261687D8D7F767C716D57433B45433F39403F3E3C3B3A3D403D3A3739
363A3E424A5F607B7A9C8F8B878BA085997E86798373907B95626B5C574B484944424242
3D3F3D3B3F43413C3F40404239353C36493F463F4E50535C6E6B876D83607A6866605750
444E494A423D43394041434447424A577489A7B8C3C1CED2D5CED8DBDED1E0BED5B5C29B
8363465057757262553D4741423D4240403D3A3A3D44443C3D3B4946506E69554A5C5975
85B2BDA98260433A3F3D3A466D6D82818B969185856E654C364335413D3C3F393D3B3937
4940433E3E3639333B3A3B3C3B39393D373B3730423E3933373538353537333639393B3C
3B3838393D39383B3D3F47524840373435393E423A3A3A3A3A3A3A3A3838393A39373638
39393A3A3A3938383E3D3C3B3A393837383A40403A37373637393534383937393E434A44
40433E3C3A383739383636393B3A403E3B3133333837373737383837343B393536363638
393A3B3A383635353437373832373839363C48659BC6C9BEA29B738594998575786F5D46
423F3E393A34373934393F3C3A3C3A393B3835373838383A3C3C3A373734363939393832
313836363A3A3838373B403A403A44525A778DB9C0C4C0B2CCBFA4BC95895D4B4745435B
67728EACC0C6CEDEE2E4DBD7D3B8C081834F6147
5A5B4D5D6B7B7A8E92A4B1B1B2A29B858074A185A37491888F61514F46484D4D4D4D4E4A
484445464747474748494A4A46464545484B4D4E484B474B42454043444341404244423F
46434448454345424647494B4B494645434642424140433E43424242413F3D3A3F3F4040
4040434644413E3E40413F3D403D3B3E40414243433F3E41444545463C383C3C3F423B3A
40453F41443F40413F403F3D3C3D4042393D3D383436393A3A39393B3F3F3D3B3C3B3A3A
3C3C3B3A3C3A3A3C3B39383B3B3B3C3C3D3D3E3E393A3A383A3C3C38454446443C3D4141
393C3B39393C3D3B393B3B3A3C3F3E3B3B3D393C3C383934464135373B3B3D373A393A3A
3735383E423D3A3B3B39393A393A3B3A393738393B3C3D3E3C3A3A3B3A393A3837373738
413F3B38383A3D3E373D3E39384146433B3B3E3E3B3F423D3D3F3C393A3F403D3B393A3B
3937393E3E3C3B3B3C3D3E3E37393A3D404140413E3D3E41434443413E3E3F4041403F3F
3C3D3B393A3D3D3B3E3E3D3C3C3E3C363C38383C3D3B393A3941413E41413C3A3C3B3940
3F383A3A3C383C39393B36383B3D3B3C3D3B3B3A393F3E3B3D3C3A3D3C3A3A3B39373B43
4041394A4C666A7586787D8A74594F3D463F3D3D3D3A3C3B3E3F4244433F3E3F403E483D
5D4D596087889B8294818E8176786C7379898384746E5359484C3C4949484B534A3E4242
3A3F3E3C3E3E3B3B3F3D3B423D323B445453527180A099A1818A727D4F5542423D3D3A40
3D4A505B4540413E41443E3D4946425354636A7B808889978B92909C929C89A38DA8A0A3
8270666C595C58515D3E4C3E3E383F413D413E413F45534A4047697E93B9B48E97A2A8C5
C7D2D5BEA68E67525A606E91C2CCDED8D3DCCAC5C2AC916B44433C443C403E3C3F3B3938
4C3F403C3F393F3D3C3A3A3B3B39393C373834384E453E3639373B38383A36393A393B3E
3D38373A433C393E43423F3D3D3734363837383C3C3C3A38373635353635373B3A36373B
3738393C3D3D3A373C3C3B3A393837373938393B3C3B38343A3B33303B4545443E414038
333537393A3737383937373A3432373B3B393D3E3D3A373637373635313737363A3B3635
3A3B3C3C393736363E393738373B3C394652989DD8B9B48788999FAAB88870414A473C33
3838393E3B373A3B37383B383A393839393635373837373A3D3D3936333335393B3B3936
353B37383C3936343E3B3A4463729EC3C2C5D5E0E1D3CEB3B68F7D62493B3D414B83A6BA
C7CBD2DCEFEAE1DEDBD3C1B38E8466653E47383A
4B544E565B5A4E565B646B6E746B71696B827DB5829171856D5C4F4B5352484F4C4A484A
4B4D4A48494948484848494A49464546484A4B4C4C4D474B454A45474648494845454644
454144464548484545474949494846443F4749494444493F45424343414245443F404140
4040424243403D3E40413F3C3F3A383B414443403E39383D41424244433D3F3D3F423A39
383F3A3C403E40403D3E3F3F3E3D3D3D3F41413D3B3F44463A39393C40403D393A39393A
3C3D3C3B3E3C3B3C3B38363839393A3B3D3E3F40363837373A3E3F3D433F403E38393F41
393B3C3A3B3D3D3A393A39383A3E3E3A3A3D3A3E3F3B3B34444036383D3E423C3F3C3B3D
3E3C3D3F403C3A3B3B383738363738363535363638393937363638393C3B39393A3A3C3C
403D3A3938393B3E3B413F38383D3D3A3B3A3D3D3B3F423D3D3F3D393B3F3E3A3A37383C
3B36373C3E3A383B4143413D3D3D3D3E3C3B3A383C3C3B3C404140403B3C3D3F40414140
3E3E3D3B3D40413E3D42423D3A3937363636393F3E39383C3C44434042413A36393A363C
3D393D3E3F3A3C38383A34353A393B3C3C3E3D3D383E3E3C3D3A36383C383738383B444F
4E504959586B686E54443D4A483F403A353A3E3D383A3C3C3F3E3F424850575B565F4E60
61746F8683927A8E5A6748544E446358998590757B6C524244454F60727C858D76544A40
3D45423B3D3E3B3C3B45444F5B586374A09495909E87816C524B4C414334423A3C3E3C46
404043515C565E59605A524D554E434C424540494D4D434C444E49505555595C7D8AB1C1
D6CAC5C8B6AE9C8A8A72826E65534E4B4148445A68758E827B7299C5D4DEE0D8DACFD3CD
CBC7D0C0A195969597ACC3D6D0DFDABFA19D7E85767D6D63464049484C4E454547413735
3C3B403A3C3335343B3737393938383B3A3735455D493E3839373B39393D393C3B3A3C40
3E39383C443E3B3E423F38313A36363A3A3635363D3C3A38373636363B3A3D41403B3B3F
3435383D40403C3936363737373737373D3C39393B3D3D3D383C3B3C42413F41393C3A39
38383937383636393937373A4036333836393B383E3B373637383938383934333D413D3A
393B3D3D3C3C3C3D3736393A3837404969AFB1D2B4B589AEB9BBBAAD79664647383C3839
3C3A384239383A3B39393B383A36363938353638383736383B3C3935333436383B3B3938
3536353840403A3A385773A4CCCCDEDCE8D6DACCB6A490785F4C40432C484B5EA0CEDCD9
E5EAE6DEDFD1C0B0A48F7560665559464F3B4237
494E4F49524B4B4F4E4C4B4C4E474C4D524D4D5C53494B504E495E72746D6365706E615C
4C4E4B504E4D4A48474646464B464445474746464B494146434942414542444542414241
443F4343444B473F404343424243423F3D43413E43414742424141403E4044453B3F4241
3F3F3F3D42403E3D3F3F3E3D3A3A39393D42403B3E39383E434242444941403B3C403B3C
3E453E3D3F3C3C3B3B3E424443403C3A3E3F3C36343638383A393A3D40403C3838373738
3A3B3B3A3D3A3A3C3D3A38383A3A3A3B3B3C3C3C403F3A36383E4241433E3E3D38393F41
383B3C3A3B3D3C3A3D3D3B38393C3B37393C393E403D3E3943453F3E3C394040413D3A3C
3D3B3A3A3E3B393B3B3836363638383533343535393B3A3735383A3B3839353739383C3A
3D3A393939383A3C3A403E393B3E3D3C3B393C3C3A3F413B3D41423E3A393A3A3B38393C
3C3735373C38373B4345413C3A393C3D3A3A3B39393B393A3E3E3D3F3B3C3C3C3C3B3B3C
3C4144413E3F43443D44443F3B39393B37383C3E3A34353B3F43403E41423E3F3B3F3839
3B383C3C3E393B393B3F3A3C38363C3C3B3F3E3F4146464647423E414F4C48464549515A
5653464940463D3E444239393D3F46423C3F3B3C3D433D3B363A3D424B5456535B496143
664C6D64695D56444035414A4E645980708C717A5A584B403D3F485849525B62523E3E3A
4B595241434946434E6A7380989C9EA596927F7F6757493E44403E43434149443F413841
3D3D43525C5266576C585B525E4D433D433D3E3B4040423D454044474951516185A3C2D2
D8D7D6CBA891909B9F97A89D9682746C5B605C768FA4C6C7CDBCC6DCE0DFE1E1DAD0D7BC
BFC2D0C7C6C2BC9C8B8D8CA0B7CAB9A68B947F968A9E949C8C8CA4A29F9C939392825E50
3D413B2C3B3D42423B3736383937383A3C3A394E62453C3837353A38383C393C3B3B3D3E
3D3A3A3B3D3D3D3C3B383737373536393B3B3D3F3C3B3A3A3A3C3D3E3F3F4042403D3B3B
393A3B3E3F3D383534343536373838393E454844403A393E4F535350483C3B473D3D3839
39363731373536393937363833333B43373638373B3A3838393B3D3D393B36374246403B
393A3A39373636373A3A3A353839587EC0BDE0BEBD93C8CBC8A08B6952373C3932363539
3637374039393A3A393A3A393B35363A373537393736353639393836363938373A393637
3C3A3A32343B405388B1BFDCE3DDECDBCAB5A4966560413F3F313E384F658B98C4DBE1DE
E4D9D0C4A3907C6B685D544A423C3F3539313837
5150515255505053504B4A4C4B4E4B504E4E505C5E5B5F57625785B4B8BDC2BDC6CEBDAA
735F4C534E4C4A48464646474F4A484B4E4D4C4C464C4B524C5251555C4F4B4D4C4A4A47
4A484F4D525D55484548484545484846494A42435D4C494D404547474746474C45484742
40424342403F3E3D3D3D3D3D3D4548413F43433E423C3C4246434144443F403C3D413B3D
4249413E3F3B3A373D3E3F403F3E3C3B3C3D3B39393D3D3B3B3A3B3D3F3E3B383A393839
3B3B3B3A3C39393D3E3B39383A3A3A3A3A3A393946433D37373C3F3F433D3D3F3A3A3E3E
393B3B39393C3D3B3E3F3D39393B3B383D3F3A3C3C3A3E3A363A373835333C3D3F3C3A3A
3937383C3E3A38393A37363736393A3635383A393A3D3D39383B3D3D3537313537353A36
3937383B3B38383A4648433F403F3B3D3A393A3A393D3F393D3E40403D3A3A3C3A38383A
3B3A373539393B3E42423E3B3C3B3F3F39373936363B3B3B3F3D3B3E3F40403D3A38383A
3A4043403C3D3F4039403F3A3C3D3C403E4347453E393A3F3C3C37383D3D3D413B443C38
3A393A36453F3F3A3A3C363638343E3D393E3D3F3B3C3C3F413B383F4443403B3A3E4143
4340393B383E3C3D393F3B3A3A3D423B333C393E3D3F3C493E403E3C434F4F47494F525E
494D413A3E424349474B4C514D4E4841423F3F443D3E41393C3840443E3D3D403C3C4647
56635A4C5058575751696B6E79766E676055584A4A3A4641444239433A3E43443D44363D
3D3F3C3C3E35453B4A3F4444413D3A3A3C3F44484B5C576A60726B7A768687989FB0B9BC
C0B7AA9F8E79747E85899396A3A4A09DA0A39E9A9492A4B6D1CDC7CBD8E4E4DDDDE1E3CE
C4C5C2B9AEBDC5AAA49062706F83768682A5A1BBD1DCD3D5C7D0DEDDD8CDBEB9BAB59391
757E65393A38383C403B38393A39393A393C3B4C5D403C3939363A38383B383A393C3C3A
393A3A39383A3B3A3837393B393A3B39393B3B3A3A3A393A3B3D3F413E404140403F3C39
3E3D3C3B3B393736383838383939393A364043403C37373F7D7D6D544237363C39393234
36353A373635363A3A363435343A47523D3938383B3C3D3D3D3C3C3C353A39383F403B38
383837363434363839343543647195C3B4BC9EAFA0C2C7B2756341493B3439323E3C383C
3439393D38373635343434353F36373C373436383636353536373737373A383639383639
38343F3C4C697CA1C9E2DCE1BCA6A38D8E634F3B3C3B3B3A3D43475B6E8AA7B5C6C8C4B7
AF9B9484614F443B403A3C3B373C3D3C393A3C3E
5148464F4E4D4C50504C4D5255696A74727A7983899BADA8A8948D8B8D908B8D92A19EAC
8B805A504A4948474748494A4945444A4F4F4E4E5F717E877E858E9D947D717474726F6A
76737A747580715E4649484545494A4840433E4975523D434F5A61646766676E78746757
4B4949473F3F3E3D3C3C3C3D3A494F433A3D3F3B413B3A41443F3D3F3B39404042433B3A
39413A393C3A3C39413E393636393C3E3D3D3D3C3E413E3A3B3B3C3D3E3D3B393E3D3C3C
3D3D3D3B3D3A3B3E3F3B373639393939393939393E3E3B38393D3F3D3E38393C38363736
3B3C3A37373B3D3C3D3F3D3A3A3D3E3C44443B3A38353A383D3F393B3B393E3B3A3A3B3C
3A3A424A3E3937383836363835393A38393E4141363A3B3837393A38383A34393A383C37
3735373B3C3837393A3B36343836343A3A383939383C3E373E39383D41403E3F38363537
3B3E3C38373A3F41403D3B3A36363D3F3A3B3F3E343B3D3E413E3B3F434444403B393A3C
3A3C3B393A3B3935333936343B3F3E413A4249473F39393C45423D3F433F3C4236423C38
3B3D3D383D373936393E393A3935403E383C3C3E3837363B3E37364036393937393E3F3C
3D3D3E4142403D3A3D3D3A3D3D3E433D3B3F36404447465D4D5252515A6763566463745B
644B524339423D3F323C393E373D3B3D3E3E393E3F3E393C3B4343433F3C3E414144433C
42483E363C3C3A423A4038383F4347444237413F3F3F40413B3C434A4A424A473D48393E
444D4539403E3D443E4946534C564E6C68867C817C82828A9AA8AFB8ACA9ADB6BEB9B8A6
A1A99F8D8784868EA0A49DA1BACCD3D6CBC3BFB5AEA1929E9AA0A5B8D2DADEE7E1E7DFE4
DDE6D7D3CCBFD3CDD4D8B0AC929C88A199B9ADB8C3CBD7DEDBECE9E7E3C2957062695C72
608E906357443B40443F3B3C3C3A393B343C3A47563E3E3B3C393D3A393C383B373B3C37
36393A383738393A3B3C3A3834393C39393A393439393838383A3C3E404344434547443E
38383737393C3E403C3C3C3B3B3A3A3A363A363339404A58666B5736303C3E35363A3539
3A363C393534363A3A363334363034423941413D3E4143423F3B3838363A352F3134363A
353638393B3F4548413F507BB3ADA5B3B67A777FA8859958433B4034353A373E4840393D
323A39363A3937363637383A4137383D373336373635353434353638343836353939383D
5E505F6A8FB8C1DDDAC9A39B69564D3E433B3545363A37444C596C8CB2B2C2BAB5A48E76
75726C48493C3A3942393C3D3C3C40333B353C37
5A5D646867706F777388809ABBC4D3CECAD7BFDCCBDCD2DFCFD1AB8B7360625B565F6460
7F6452515152515662686E7775766A6D726F787D99BDD1D6CBCAC5CDC6CCD3CBD1D0D2C9
D0CECAB3A29081634B473F4A5A6B7A70755B6E5363566B5B798D92A0969AA0B0C1BCB398
7D7E857B5B48483E403E41403E3C3C3F424241403B3C453E46403C4241433E3B41443F3C
3E3D403B403B3E3D403B3E413C3C44493F423E3F3E3B3E3A3B4042403E40413F42404042
403C3C3F383D3E3B393C3D3C3739393837383D4137393B3B3A393939383A3B3A37373B3E
36383C3C3A393C403E3E3E3C3B3B3C3E403B383B3F3E3D3D3B3C3E3D3C3B3D3E3E3E3D3D
3D3D3D3D3838393734393C3748423B37383C40423732363834373B3737343234383A3937
3B39363535373A3C393C37363C3B383B3E3C3C3D3A383C433C3A3838393A3A3A33383B3A
393A3A393836384045423D3B3E3B3B3D3C393A3F3A3A3A3C3E3E3B394244423D3A3B3935
3A3A393E3B383D3736383A3C3C3D3D3D38424D4F4439383D373A3D3D3A383A3D3F3B3A3D
3D3935353637383939393736373B3F3D3835383C39413F393B3B393B3E3C393839393938
3B413E3A3E403D3D3C3B3B3B40494C4945403F4345434346415665717E7A757E716E6A5C
4B433F373F3D3E43433F40443E39373A3B3B3D41363F353F3D3E3E3B3B3B3D444A4B4641
3A3B37423E443645384039413E373F3B3A40333C3A3C453D3F364B414D423E423F3A423F
4941414E685D7D697F6D8783999896ADC8CDCAC6B4A8A6B2B3ACA1858A788472876D7667
6F75736B666469758D919EB1C2CCD2D7D9D8D8D0D5C6C3C5BDCBBDC1BCC8CBD5D0DFD8DE
E6DFE6DDDCDBD3D5DBDBE0E5DED4D9D2E3D1D5B5B3ADBBC9DFD9E6DED2D79E665043423C
3E4A73645A854D3B473F384140383B363F3A383D3F3C393A3A393A3C3A3535383633393B
3C323D3938373F343F333A3C37393B3A39383A3C3A3C3C3A3A3C3C3A393939393E433F38
3436393A3938393A383A403C3B3F3A393637373940494B47433C403D3A3A34393535383D
3D3A393B3335373939383634353438343B453D353C3B3A3939393A3B3B3635343736303A
37354C545A81857C62537BB4C7A79B997569616A584C3D3D3A3D3F403D3A37353635383C
3C3836373A35353A3A333237372F353637382F332D383A323336363B353F3A5861627385
9AA3B0C8D7C9C19EA2796549423F2C463C3B4F53555768677A90AABBABB1AEA48A775C55
4A4940413B3A3B3C3B383B4139403A3F37373D3D
98A2ACBAB7CACBD9D1D6D6D2CECABBA19E9EAAA1BAA0ADA5B9CAC6CCC6AC9B87877F8978
706273738B8D8D8FA5BACBD5D1CFC0BEC0BEC8D1BDC1B4A19493959EB3C4D7DCE0DED9D0
CBD8D8DCBCAC866F4B4948586C81918A8C707F5D6E5A6D6275717F6A767971798F94A0A2
9DA3A5976C5853433F3B3D3E3E40413F3D3D3E3F403D40353F3E3C3E41413B3B41424041
3C3E413B3732373B3D393A3B3C3D403E3D3D3C46453A39393B3F413E3C3D3D3B3F3E3F41
403C3D403D3E3D3A393B3E40393939393A3A3938383A3B3B3A39383834383B3B38363537
3B3E40403E3C3C3D3E3D3C3A393A3B3C433E3B3C3D3A3736393A3B3B3B3B3C3C3B3B3C3C
3B3A39393634383A36373C3D403D393636383A3B3332363837363634383636393C3D3B38
33363A3D3E3C3936373938383B3A38393736383A39383C433D3B38373739393933383B3A
3A3B3A383835353A3D3B39393939393A3A393B3F3B3C3E3E3C3A3939373A3C3A3A3B3935
3839393E3B383C353737393A3B3C3D3D3B3F464A443C383A393B3D3C3A39393B403B383A
3B3A3B3D3937363536383B3D3E403F3C38383C403F423E3B40413E3F3D40413E3936393D
3F413C373C3F40444C53554D4645423E3837383D414344464A53595A5B58555645454744
3E4145413B3E4243403A373839393B3E3D39393C3D403E47445D71727C7C7E83898B8782
6F73687E6B7C67775964494C3A3C413B3C45453E483F55506463736B746B747878707575
8787868DA2B3B7BFB3BDBEBDBDBCB4BDC9C8BFB0948A717D60665B53424A4A514D59677C
8D969891898488949EA5B3C5CFD1D1D1CED1D7D6DED1CECDCACEC8C3B4AEB0AAB5B8BEBB
D5CFDED9DFD5CAC3CCD3D2DFDCE4CFDFCADDDADCD6D5D0DCD3D0CBC2BABDC08F5B413B3E
3A3E42475D827A5C3C3A3E433D3A3E3A3E3C3C3D3D3F42423C3A3B3C3B37373A3B383C38
3C363D3937333D333B35393B37373838383A3D3F393B3B3A3A3D3D3B393A39393A3D3D3B
3637393B3B3A3A3A3D3A3D39393E3A3B3D3C3A393A3D3B383B373A393D403B3F3735373C
3E3B3939353638393A39373636373A34353C35313535343435383A3B3A3836333732314B
637592A29EC7B49B6A6491BCBE987F675C4F5A54563D3D3534373B3D3C3B3A3A3937393D
3D3937383D39383A39343437322E383833343338353833353D3E424758707CA8C0C9CECF
C4BFBAC1B0A06D66463A3D3635383F627B86A1A198929D989F9CA68E897E7F646154403D
393E393935383A3A393938373D3D333F3A413A3A
C8C5D7CDDBD5DCDDDDCDC9AD8F8B7A66676A636669676A6F677980919896A5ACBBBAC2B5
B6ADB7B5C4CCD1CAD8D9D6CCC1C1B3B0AEAFB6C0ABA8A2999D9FA6ACCAD4DADDDADDDBD8
D5D2D6C1BA937C6957524C50555B5F555A4B52444E454D5149515F4855584B525B596168
686B675856494D45423F3F3F4548463F3D3F403D3B3D44373F41424444433E3E42403C3E
393E413F3A383B3F3F444843403A39383A3B3B45453A3A39383B3C3B3B3C3D3C3C3C3E40
403D3D3F3F3D3D3E3D3C3D403E3A38383A3A38353A3A3A3A3A3938373B3E403F3C393939
3C3E4041403F3D3B3E3D3B3939393A3A403B393B3D3A3838393838393A3A3A3A37383A3A
3A3937353632373B3533393D3A3A393836353536383A3A3A3C3A38393A3838393C3D3C3A
38393A3B3C3C3B3B3736393A3838393837383A3C3B3B3E433E3B38363637383833383B3A
3A3B3A383C3A38393A3A3B3D383A393736383B3C36393C3C3A38393B35393C3D3E3F3D3A
3638383D3A383C34373738383A3B3C3C3A393C40403B37363B3C3C3C3B3A39393E3A3738
393A3B3E3838393A3A3A3A3A3B3B3A3837383B3E433F39393F3D383833383C3B37383F45
42413D3C3F4043495A594F423C3D3C38383A3B3C3F4242404545433F3C40413D4441413F
393C3F3B3B3A38383C3F3D3738393B3B38363A404046637A7593ADB7B5B3B2B3B6B5B1AC
A29799948E888386636E4D543B3F3F3B46675E6C5E6D77878694A9A5A9A4B7BACBC0BCB5
BBB29E948997727E617F777F727979776E65665F4E453E464447524E5E776F9283A59EBB
B9C2C4C0BAAFA9ACBEC3CCD5D6CFC8C5D4CEC9B9B1998D8777677A5E6D52745F6C6E6886
92BAB2C0C3CAA8A2A39EBECFD6CFCAB9CAC2D3D0E2DBDDBCB59196808D9FB1BEA6665736
423F41465B8B9CA46D5B5654545E584538393F403C40443F3E3C3B3C3C3A3A3B3B383A33
3C393A363E3C41393B3B3A3B3D3B383737383939383A3B393A3D3E3C3A39393837363A3F
38393A3B3C3C3B3A3E383A383A3D393B3B3A393A39373536393939363D3E373B413C3A3D
3F3D3836373839393939383737383C343237323238373636383B3E40383937353D3C4873
9D9CAF9B99A29675675E788376615A413C393B4039393839393A3C3B393735353938383A
393736373A3837363635363837353A3631353533353531496370838CBAC9C4D7DAD3BEA7
9C87886F715540403F3C383F4D628CB4D0CED2C2AFA2A1979886705F51554D3A423F3637
373C3631363A3B393A3D3B36383A3C3B33333745
C6C5C6D2D6E4DADBDCD2CEC2B2A4958B808F79957C947F8E888F8D929699A7ACB9BDC6BF
C3BBBAAEAAB6C5C6D5CBBEAD98A5AAB7BABEBDC4D0D1DADAE2D9D9D7D4D4CDD0CED9DBE0
D0C9B3A08D7C5B5457504E50505150474C48434A4B535267567056574A4A3E454C434245
4548473F463F4746423F3D3E42423F3B414A473E4A515B463F3B3C3D3F43413E403E3A39
3F404041403F3B3839414A464639393D3B403C3C3C3C3F3A383A3B3B3B3C3C3C3B3C3E40
3F3D3D3E3C3B3D42423C3A3B403C3836373A3B3C3C3A39393A3A38373D3D3C393737393B
383A3B3C3E3F3D393E3D3C3B3B3B39383E3A383B3C3B3B3C3B3A38393A3A39373637393A
3A3A39383935373935353836393B3C3B393736363D403A373B3B3A403C39363537393A3A
3E3C393737393D3F3835393B36373B373B3C3D3C3A393A3C3B3937373738383736393A38
383A3A3834343434333335373B3E3C373437393835363838373636373335373838383634
3638383B38373D35383838393A3A39383C393A3D3F3C39393D3C3C3C3E3E3C3A3B3A3A3A
393837373C3D3E3E3D3B3836353536393B3C3B3A3F3935393C393535373737373738393B
414041454642424748453D3A3D3D3D404D4D49423F403D37393A36333840413E3E3A3A3A
373B3F3C3B3C3A383E46443C404448474342474E73677A83696D707E716E6B6A6A686460
65525D4B50414B46444637423B3D4348617B8D788774919DB8C0D3D0D4CCC6B4AD967E67
63615650464948414A454343454B4D52545D7177827F7B6764678C94B6B4BAA3BDA5AAA7
A9AFB4BAC1BBADA79F9FA1A29D9590907E746D5D58494746453E424544434F42453C5143
52525864616A6C63666B7595A3BBA5CDB7DCC6D9DDDFBCA97A817D7C5E607C96B080615B
8783B6A2C7BAD0D3CFBDBAAA9A926D42403B3E3F38393B343F3C3A3A3B3B3B3B3C363935
3F3A37363A433D373B3A3939403D393839393734373A3A38393B3C39393636383736393F
3939393B3D3D3B393934393A3C3D36383937393D3C38383C373C3A363A38353D4F453E3D
3F3C3734383838383838383838373B34343A3637373534333436393A393939363C455A83
83766C6E5868595246404F4B423F483A373A363F2F3A373A37383A393838383937363535
343333333333323132353838383A3A383D3E37333D4B5B8AB2C2D5D4CDC8ABA291856F5A
4F4F414339363837383F436991ABCDD8D0B7A2928780796D6B563C4135403A3938393735
373B373036363536383938363A38443D464F6785
8B839B99BFC0CCC7C4D9CED5DCCCCED1CBD0D2D0D4D3D1D4D3D4D0D2D0C2A685A79BB4C4
C8D8E9D2DCDBDCDBE6E0DAD6CDD8D9DFD9DCD2D8DCD8DCD9DFDADEDBDCDFDDE3DCDEDBDF
DBC9A179605E4C5049444649494A4843434245464D4B48594C60465C5D5D484745414347
47464644423C42433C3E3C404549494B5561615856647B6E6454483D4048453D3F434140
403E3E3D403E3E3B3F393F3F4638393A3C413C39393B413C3D3C3B3C3C3B3B3B3C3E3F3E
3D3C3C3C3B3A3C41413C38393B3B3B39383A3F423C3A39393A3B39383C3B3A3837383B3D
383A39383A3E3C383C3D3E3F3E3C3A39423E3A3B3B3A3B3E3E3C3A3A3A3A38363838393A
3B3C3D3E3D3A393739413F323A3C3C3B393737383A3D37343838373C3B3A383839393939
3B3B3B3B3A3939383A36383A35383C393A3A3A373534343437373738393A3938393A3936
363A3B3936393C3C3B3B3C3C3C3F3E3836393A383A383737383836343E3D3D3D3D3D3D3D
373A373835373F373A39393A3B3B38353F3D3E40403E3F423D3C3B3D40413F3D3C3D3D3C
3B3A393843413E3B3A3A3B3C3A393A3D3F403D3A3835373D3E3B3A3B383A3E40403D3937
3D3D414645403F413C3E3F44474247575C5A5146403F3B36383F3A384446403F403B3A3A
36383B3938464D484343403A3D464F514C4746475A474D4F40443C4F454341414242413F
40383C4139424044473F3E343C3B45484F7474877E959FBFD7D7E3CAB39F88755B4F463D
3B433E3E3D40403C3D4D44536D85939CA4AFBAB3AFBDB4B1A1B5C4C8B2C39CAE82916370
71726F70736959504F4D4C4C4946474A4B454640423B4346423F40495759625B5C666C81
6C8C7B927F8C757B7B63635B5F62918CCDB7CBBFC1C1C5ABB4ABBDAA927D766D72536283
9BB5BBDAC4C7C3D3D2D1D3B28B785635473D3B3E3D3F43413D3C39393A3C3B3A3D363A3B
423737383D503E363E383B3B3B3938393C3D3A36383A3A3737393936393433373A393A3D
3939393A3C3C3A3837363C3B3B3C37393B3A3B3E3C37373B343938373939445451463C3A
3B3A3634383837363636363639353632353C3837363534333436383A3C393C36333D4C5F
6F4F4C3A3D2F39353637403939353D3A3737463E41373E363A3B3B3A3837373836363533
323333323232323233363738353935393D333548708496B9CBC4BEA88B7D61594946403C
3A3F3C423B38383D4C6682BADCDAD2B588705F5F5D58504A4C3B3C343C313B393B3C3A34
373B3C393A35363B3C36363B3D4244677DAEB6D5
4D5259666879757D8BB9ACA7A38E9EAEB6B0AC979893979CB6C1CBCECCC8BBA79A949BA3
B1C6DCDDDFDBD3D4DADCDBE0D2DAD8DCD6E1D8E1E1D9D6D1D2D2D5CFCED0D3D6CFCCCDD5
D8BEA56B5D504D4C4F484E4F4C4D4A494D45503F5241484F504B4444545644484244484A
47444342403D474E484B474A5054534E4A4A4843494B5B5455534F474147423A3A3D3D40
403F453D413B4243433A4542473A403C3E3F3B3E3E3A3E3C3B39393C3E3E3F413D3F403D
3C3D3D3D3E3C3B3C3C3B3A3A35393D3E3C3C3E413C3B3A3A3A3B3B3B3B3B3C3D3D3E3E3E
3D3F3D393A3E3C363A3C3F403E3C3B3B403C3A3B3C3B3E413E3D3C3B3A39383739393A3A
3C3D3F403E3C3B393F4C49373939393837373738383A3A3A3C3B393A3A3C3D3F3F3C3937
393A3C3C3C3A38373B383839393B3C393B3B3A3736373735373636383A3B3A393A3A3835
363A3B393135383736373837393B3C3A393B3C3D383737393C3E3E3D3C39373838383A3D
393B38373439413A3B3A393A3C3C3A373C3B3B3D3C3A3C413B3B3B3D4041403F4041403D
3C3E3F3F3E3D3D3C3C3C3D3D413D3A3A3B3C3A383836393D3C3B3C3A373F4A4E4B45403D
3A393D3F3C3B3F404345454B5048475756524A423E3E3D3C3B4440414B45393C3D383B3E
3C3E43443F494E484342403B3A414746413E3B3A4240454239413749403E3C3B3C3C3A39
3936393B363B3537393E433440475147616A7E7A9794B2C4C9C2C496685A565C433E3F3F
383D3A3E3A39474462919DAB98BAC4C0C6CECCBAC0CAC8C2BEB7A98C62675452484B3D42
40434242474542443F3D3E403F3D3E423E3B4542423A41423F3F58559185A6A4BDB5C6BB
C9C1BEB0B1A5A9A6AEB19B9E8F846D73718B8896849896B5B5D9D4C9AC87645C53457881
B3A1BC95B599BAC6D6D4C19572675743413D39393C3E3D3D3B3C3B393A3C3C3A39363A3D
3E3444434456423139353E3F3B3A393B3E3E3A363A3C3B3837393835383535383B3B3A3A
39393A3B3C3B3A383C3F443C373A393D39393A3B3937373A3838383F3D3B4F61463D3636
383837383838373635353535393334313439343337373738393B3D3E3D393F3A32363839
3C35313D353C38373D3B3B313738464D47474D49423C3E393F3F3E3B3734333337383835
353636353837383938363535363731393B365787A7A39795897669534C43393F3536373E
40324230433E3D609CB7CFE5DCB8956D514A464A423C373B36393E39373537353A3B3E3A
3C3839363A35373F3D353944586797A2DDDBF0F0
4F4D5751555354574B7077746B595C6662695F61526356636D77837E72747F849FADA08F
9497ABD2CCD2CCD2D2DBD4D7D7DFDEE2DAE4D3D8D0D0CDC6B8B7B2A9A7A0A0A4ABA9AFB4
A49C9BA197A38681696471777A818489857A705D56535158474B494343463E44393D3F3F
3F4245474A49535D54554A4A494B4B4845444444433B4640454749453D414244453F3E46
42414F4551434B464D4C635D594B4D383F413C3F3E3A3E3B3C38373B3E3F40423C3F3F3C
3B3E40403F3E3D3B3B3D3C3937393C3D3D3C3B3A3B3B3B3B3B3C3D3F37373738393A3A3A
3C40403B3B3E3C36383C3F3E3B3A3C3E3A39393C3D3C3E413B3C3C3B3A39393938393A3A
3B3B3B3B3D3A393A404B493A39383737383838383B3A3E403F3F3F3C3C3C3E3E3D3B3938
3B3B3A3A3A3B3C3D3A3A393A403F3A383F403E39393B3C3A3A383737383A3B3B393A3937
383B3A36393B3B38373A3C3B38383A3C3C3A3B3D33363A3B3A3C3F43413D3B3C3D3C3E42
393C3938363B433A3C3937383C3F3F3D3C3837393A393A3D3A3A3A3C3D3E3E3D3F42433F
3D3E3E3D383A3C3E3E3C3A383E3C39393A3A39373B37383B3D42443D44474B4B47413D3B
38393D3D393E45443E4645484F473B3F47423D3B3B3C3E403B3E3E42463D363A3734383C
39393E4142423F3C3E43413C3E41413E3C3D3D3B373A3F434658566842403E3D3C3B3937
3E3B3C363A3D3B413C554F575C7179696A6A677C7D8986937F70694E363A42453E393E46
3E4647516A679A80B5B7D0C1B5C1AD9FA8A590797875765D644C513F41463A463F4B3B39
3D403E3C3E3D3C403F3C3D40413F3E3F3E3B4643413A464A5F7789A8C0C6CCD5D3DCD7E1
D7DCD2C0ABA7A9AEB1B7C0C5C7B8C39B906C6F6E7F878E90A1B6D1CCAD79614D454B4A40
5C5B59746EA387A8B4CBD1CAC4B89C7D545B4F3C3A3E3C3D3A3D3E3B3B3D3D3B393F4344
404269648E8A7A4E433C43403D3C3B3C3E3D3A383B3D3C3A393B3B38383A3B39383A3A3A
3A3B3D3D3C3B3A3A424A5141363A3A3D3739393837393A3A3D373D4E463A464D3D383637
3938393B39383837373636353734373434373336343435363738393A3B373C3A37363134
3B33392F3A35433B383539353E46585C5C5A4E533B3F383B37383A393837373736383836
363838353A373A3E3D3632333535333E4758809C967C62564C45443E3F3A394236363439
3E3C46515C7872A8CDD7DCC79F7B5E463E413D3E3538373B2E3A353C2F3B333434343B38
3C3437383835363A393C4C5F8CB8CBE6E2E6D8DF
4D4D4B514B554B5056494B4B4F524D514A5257534F55494E554E51514D5055565661655F
5753627B6E807F9199B7B8C0CED2CBCEC9DFD5E1D7DEDACCADABA8A58178849ABBC0C3BF
C8ACB7C0D6DDCDC0BDB5BFBFBCBEBDC2A8B3A4BD9FBEA4B095A77B79504F4A474B4D4A44
424444434441464F464A414344403E3E40403F3F443A453D3E3D4344454954666B5F5C68
6D6E8889A69AA195AEADC5B9AE9887573F463F3A393D413A443F3B3D3C3938393B3E3E3A
3A3F42423D3F403E3F403D363D3A38383A3B38363A3B3C3B3B3C3E413E3B3937383B3E3F
363C3E3B3B3F3C36373B3D3C38373C413C3B3C3E3D39373938393A3A3938393B3738393A
3A3937363B36373B3D4241383A3938393B3C3B3A3C373B3D393C403C3E3C3A373636383A
3A3A3B3C3D3E3F40393C393C4543393740413D38363939373E3B373536393B3C38393939
3A3C39343B3B373231363A3939383A3E3D38373B363B3F3B3431353C413D3A3B3A38393D
383D3B3A373C443A3C3835363B404343433D3A3C40403F3F39393A3B3B3B3B3A3C414441
3D3B37333D3B3938373738383A3B3C3F41413E3B3B36373C4453574E47413A393D403F3D
373A41413D444B483947443B3C3A373E3E3936383A3A3C403C373B423E3534383835393C
3634393C3A3B3C3B3B3C3B3735393B3B3D3F3D3851423A464F5A4C4E3A39393939393838
3B4434484168617B69835D6E57656554534348545E524844463F4247444A4C3F43415068
708A9BB1A9B6B0B791B6BBD4A39669525A53494B47473F42413C3E3E433E3E363A3A3E36
3A3C3A3D44443F3E3F3C3C40434444464B474F4C4D516974A5C0CAE4E0DED8E2DEE1DCD6
DDD0D2ADA58D91807890A0BAAEB0AFAF868C869A9EB9C3CDBBC5CCCCB8A97B61554A4C42
3D47434546454B525C879DA7B3BBC0BAB9BE975D443F3A3A393E403E3C3E3E3D414F5251
4C5B948CAC979055403F46433A39393B3E3F403F3B3E3E3B3B3E3E3B383F403A3537393A
3B3D3F3F3D3B3B3C43525B493A3B393A3C3E3D38373A3B383B333F5A4F3838323B3A3B3D
3C3A3A3D393A39393837363635353B383637363C3A3A3B3B3B3A39393A35353436332E3B
3532343337363E3A3A353D383A3F4C43453D433E3D33393638393A393634333333363734
353737343633373F3E3531333335353D48606E53614335393B3937363733353E363F4146
7680949DA8A2A6B3BCB2A57C54473D374043373534423B333E393B333B3436333B363936
3E3D4C55464543404253718ABBCDD2C1CEBABEB4
4A4B4B4B4B4A4B4B47484A4B49484747454D514D494A4D4E494C4D4C4A4A4A4A47464549
4D504F4E52504C575265696B787A807F8EA3C9CDD1D5D5CECFC1C5B69876787A94B3B1C4
BCD1C3D7C6DFDDE1DEDBE6E0DAE3DED7C9CFD1C6CEE2DDDBD9C6BF9077454844443D4544
414D4B3E433F3E4346413D3F45483E444A3B4A44423F3E41413D3E444087ABA6B6BCB9BF
BAC9CAD9D1DFD7D9D3D9D8DDD9C9B1A96C5D4F414642474640423B44313C3A403C403740
393F453F393A3D3C3A3C3C3E35363B403F3D4045363A3F3F3C393A3C3C3A3E3F393A3F3E
403D403C3A3B3638393C3F3E3A37373934373837383C3E3B373637393B3B3A3936394040
393B3F3A3A3F413C38393B3A353637393A3A393937393A3A38383B3E3A39393837373737
3C41413C3C42423D3A373A4246423A36433F3B38393A3B3B393F3A34383B3B3E3737393B
3D3D3B393B3A383737383A3B3737393B3C3D3C3C38393C3E39333740393B3D3D3C3B3B3C
37383E3F37363B3B3A3641363937393E3D3B38383A3C3E3E38383A3D40403E3C40414242
403D3937343936353C3F3C3C3A3B3C3B39383839383C3B3D484C4642413B3C404144453D
3E3E3E3C3B3B3C3E3C4044413B393D433C3D3D3D3D3E41433C3F3E3A393B3A3733373B3C
3A3A3C3E3C3B3A3D424646443F3D383C404A3B3F3F3C3C40403D3C3C413D404642495343
3A414E435D6476727A7D83736850473E3F3F4144433E3D40474853806D9076817D849290
9EAFC1B9BAC3BFA1B3A3D8CCBB98937483685D4946443D3B3F3D3D46413F39443C433C38
3B3940423E4449434D4846575A65808B9890A89992898B94A2B9CBD6EBE4E1D8ABB7A2B8
A1AE889B60695B5D55587D7F838DA392A4B9D3C6D4D5DED6D4D7D3D1CED0CAC8BA8F856C
7B5E574C534D47474C4A5C688D95B8D3D8DBD8B5734D4B3E3E3E423E474A5A5E84A3ABA2
8E76726D647081797C625E4B3E453B3C434447424340463A454147414036353B4038433E
676F8869664C364F413F443C423F3E453E383D383A383E393F403B453F3F3A3B423B332F
3136393A3839393937373738343433333335373835343638373333363536373634333436
37363832343A393B383535393B393A3E3738393A3A3937363435373A3934343836363738
393938373233353534343535323A3F4040403F3B393B2E393B3A3737343737334F6A81A1
B8C3CDC7B49C7A5954504A443F3B3939383D39353836343A373739393D3033414C585968
6B5967534B3E47535C6880A8A8A99071604F5659
4B4B4B4B4B4B4B4B4A4A4B4A4848494A4A4C4C4A4A4D4E4F4D4E4F4F4D4A4A4B524F4C4C
4E5051514D56544B4E4F4F52514A4A505B62828DA1C1BABA887E69655E5056555A64606D
6C7C8E899FA3C2C0C1C2CCCED0D6D9E5C9D5C1D5CFDCDCEADEDEC0AA7B6C52524C494745
4A453E4C444646463F424649484F403F42484446473E4446433E3E4D7FA5ADB4BECAC1CC
CAD7D9E5D6D8C8C6C4BDB9AFB5A69F9B967F736B7475766659454240443A3D3A3C3E3841
36373F423C3C3C3C3E3F3F443D3D4042413D3E413B3B3B3B3A3939393F39393B3A3D3F3A
39373B37373A373B383B3D3E3C3A3837383A3B39393B3B383C3A3837373737363A3B403E
383A3C37373D3F3C3A3C3E3E38393A3A3A39393A3B3A3938393A3A3B3A3A3B3B3A393837
393A3B3A39393A3B35373C403D383639413E3B3838373736363B39373B3B3A3C35353538
3C3E3D3B3A3B3B3B393838393838393A3939393A3C3E3F3D3C3D3F3F36383A3B3B3B3B3C
3A36383834363937393640383B393A3D3C3A39393A3D3F40383737393B3C3B393C3D3D3D
3C393735323A3B3C42433E3D3C3D3D3C3B3C3F41363A38383F413B38423B3B3E40424037
3E3E3E3C3B3A39393A3B3B3938383A3C36383B3C3B39383833383B3C3E403F3C37383837
373B40453D3C3B3D3F3F3C393A3C393E41483F433B37384045443F3C394146536A868661
60836B7C5F84738D7D85777A525146574B464242424349507D65897C958590888C898B8E
A6ABA7978CA496B28EB5A4B89A988A977C7E57543B3B3B3D403E3F453E3D44403A3D4549
495B6263757D767E5C6E77A3A5BDC6D3CAC2CDC6B3AB999B96999FA7B7B0A483645D5756
5B5B57686E745C596A76888FA1BBC6D0C1D5D3D5D8C5D0BDBFC1CFD4D0DFD4E5DADDD6D4
D2BDB7ABAEA79F9D8A8181758484A4BFCFD3DFDFBC987C57585258627488A4BDCDDEDCD9
D5CDC8C0B6C2D3CFCCA28A6B777F756E6D6E7D87897D826D6E4952534C403E3D403F4348
85A09A927B57484847464343485A67805E423B363B363A3C4642383B3537353A3B393738
3B3B39373839393937363738363635353536363739383A3B393635383334363635353738
3634383B3934333A35343537383738393132343637373636343436393937373B34343536
37393A3A373839393837383934383A39393A393631363D35433136352E41435B92BFBAC9
C5BBAA89624A413B3A393634343536373B3B37333536393F3F50586F5752506D71947D97
5651464F61626A656264636B4A524745393E4557
4C4B4B4B4C4C4B4B4C4C4A4847474A4D494441434648494B4A484A4C4A454346504D4A48
494D5154697E685F4B5A4E5A524F4D505450554A57729B8C8E6061514F5252524E4C4F50
4A534A504D5C5D595C617088A5B5C3DFDEBA8D7DB0A8D7DCDFDED4B8BFB4B0A59C6F6260
4F464544434543453F5665697D8D6D6F574B50464F3B433F3E3F4661948F8A7F9B9EA5A4
A5A9A6B2A7A7979575715E5F50544D586A5D677389989C836E54404C43433E4543454148
3F42433E3A3A35363B37363C3D3C3D3F3D3A393A3F3C3837383939383E39383A3A3C3C39
35353B39383B383C404040403F3B36323A3C3C3B3A3B3A383E3D3C3C3E3E3E3D38383B3A
383B3D3A3E40403B393A3C3D3E3F403E3C3B3D3F3E3A37373A3C3A383B3C3D3D3D3B3938
3B3A3939383636373837383A3A373738413F3D3B3A3837363A3C3B3C3D3833353D3A3738
3B3D3C3B393C3E3F3C3938373D3F3F3D3B3A3B3C3A3C3A36393F3F393D3F40403F3E3E3F
423A3737373B3C3936353D393E3D3D3E3B3B3A3A3B3D40433B393636393B39373A3A3A3A
39383635343A39373A3D3D3E3E3E3C3B3B3D41443D403D3A3D3C37363D3A3B3D3D404341
3D3D3D3E3D3C3A393B38343437393937393939393A3D41444C4D4D4A4744413D393A3A3A
3B3D3F414241414243403B36393D373A3A3A37383936353A3E3D3B3B3840496584938E78
9C8AA47089688B747E6D735A644657585D554D4A4B4F575D605D4C70497256685552535B
79796F657A6795617450504D494F50554848393F3E3D4144413E3E3C41474954476C7184
8A9EB7B7ABA08F83506B96B5D7D5DFDDE2D0DBC4C1A4907F78777D766D6B7258625C5165
5C716F888C8F776E89A0AEBECDC7C297A4959E8BA0858B788C91A8B6D0D6D1CBD6D9D9D8
DBD8DBDADFDFD9D8D3CECDBEC5BDCDD9D4CFD6E0D6CCC8B4938E98A0A3ADB2C7D0DBD5D6
DADFDFDED7E0E8D7C4A0A09CCFD1C3B7AFAFC4D9D7CEB29B755147434737393E3C423D40
4A61586656565F70A097AC8CAEA1BABC8B563E363E3A414D4C453D3D383B393E3A373536
383A3938373839383736373838383838383737363A393A3B3A3636383838383736343535
3A383535323033343436363536373736393939393735333134333537373638393A393734
32323232373838373635353635363534353737363940343B383F313F425F93AFDBDCBD90
7A634C3E3434393A373635353537393B3C393A39373B40426B5E8B718B578089A79C9574
7D50695B6D695E453940403D403D3C3D4A5F82A1
4C4B4B4B4C4C4C4B4C4B4A474647494C4D48464A4D4C4E514D4A4C504F49474A4C4B4949
4C535A5E737A7557525159565A5950515E6869574D5B576E5C625A6E575D515658535748
504A524651424C4A53524F515C6C90BCD3DAA39B8290A9D0D8DFCCC9CDD7C4BFD9CBC3BA
A8866460554D4B5F72A6C6CDD1AC9B918A95938F7D656456514F57685F635A6C799D9791
6F6453564E4F4342443F483D45354247423C45485A6B796C625A526D5C6156624C4D474C
4F6057434F4F45464A403D4139393A3B3B3A39383E3C3A3838393A3A393A3C3B37373A3B
383941403E3E383A44423F3F403E39343B3B3B3B3B3C3C3C3D3D3E414242403E3A383838
393B3C3B42413E3936373A3C3C3E3F3E3B3A3D403D3B3838393B3B3A3B3C3D3D3C3B3A39
3E3D3B3A3A3A38363A3938393A3A3B3B3D3C3A39393939393837383D3F3B383A48433E3C
3C3D3B38393C3F403E3B3A393E3F403D3A383A3D38383634363B3B38393A3B3B3A393A3A
433D38383A3C3D3B3D3C3E3C3D3C3B3A3B3C3D3C3B3D40423E3C39383A3D3B363A3B3C3C
3C3A3938383B3A3635393C3D3F3D3B3938393B3D4245413D3E3C393B3839393736394248
3B3B3C3E3F403F3F3E3A37373A3C3C3B3C3C3A3A3C41484E4E4C48433F3E3D3C403F3E3D
3D3C3B3A3C3C3E40403D38343A3D363C3F3E43403B393837353740494548527389827F84
7F92677A6183606E585340524754414245403B393A3B3D3E4F414542404343453E40443F
48414241474251423D4139453D3D433940373E43463F4247484C504B574F625C6E8899A1
A196928D7F7D82757B9EA8D6D4EDDBE6DBDBD6CEA791665A627896917F7D968D796E6D7A
6C716B777E7D6F69788F9FA29B95726158594D464A54636D9099A6B8B7B1AC96A8A19B9B
AFBDC7D2D7DED8D8D5D1D3CCD5CECDC7CBC5C7D0C9CBDDDED8CABCA695A5A7BCC8D7D5D5
D0D5D9E2F2EAE2DBDED1DBDADEDED8D4D2CED6E3D6D4C8A3A4858C6C654C4042373E3937
3A384F5250717FADCEDCEAE6E5D8B49C7F534D525C4D4142403A3A39373732353C393634
36383A3A383939393736373838383A3A3A39383737353538373434373939393836353535
383F3F3831333A35373A393535393A37373838393837373634323435333437363C3C3B3A
3837383938393837353434353836353537393A3935373D343C3332487FB9CAD2C6A85E46
423936373637393638373635353536373A3940433F40433F49535B72586473918A92646C
3B4841573B3B3C3632373A36414356628599C4D1
4C4B4A4A4C4D4C4A49494948464647494443464A4A47484C4D4B4C50504D4B4D49484849
4C51565A536051533C504546535244434B555A535852544C524A596E7780788897989D88
856B60525A556D817B818483796F727CBBACB28FB9A8B7B1C2C3D5C3EAD3DED9D1DBE0D6
D1CEC6CDB7AAABC0CBE2E6DBBC986F5A5F629D9EA18D85716758585057515647585D6652
574D40423F444247545652614F4D3D423B3E433B434549413D3C4A5152484C4D4F545A6B
758670534A4C4042433836363B3C3D3D3E3E3D3B3A3C3E3D3A393B3E393C3C3A3837383B
3D3C42403E3F3A3D3D3A38393D3F3E3C3E3C3B3A3A3B3C3E403E3C3C3C3B3938413E3A38
393937363B3B3B3B3A393A3C37393A3937373A3E3A3A3A3938393C3F3C3C3B3B3A3A3939
3C39393D3E3A3838343A3E3C37373C413837363536383C3E423C3B3E3E3A383846423E3C
3C3D3C3A393B3E3F3E3D3D3D37393937343336393C3B3B3D3C3A3C40353637383738393B
3B3A38373737383A3B3C3A3C3D3E40403C3D3E3D3B3B3D3F3D3D3B393B3E3B363A3B3C3D
3D3B3A383B3F413F3C3C3C393D3C3B3A393939383D3F3C3A3C3A383C3A3936343537393B
3A3A3A3B3C3D3F403D3C3B3B3B3D3E3F393A3B3C3C3D4042474542413F3F404147433D39
38393B3D3A3B3D3F3F3D3A3738362F343A3A413B3F3D3B3B3B404D5A5963616A77726961
806D7C5E604B5D433E3D413A454141373C3D3D3F4142413E3F383D3D3C3E3D3E3C414A3F
3B39444235423E40373B3F3D45483A434A5F667381756F6C65625B4D4B535D6E61857E8D
67695C79A6B5BFC1BEC0CAC1D9D7E3E8DBD5D4B0A2909BA5B6C3CEC2B4A9B2A377726381
56674A5658564B4D525B62534A4C3C47403F4A6466868B98968F82837C7867625D67596F
5E757C8D93A29FA59DA0ADB6C4C3BEB1A5A9B8CFD5D8E3E0E0D2C4AC979E97A6BCCDD2D9
D4DCDCE9E4E0DDDCDED2D9D7E1DFDDDBDCD7D4DCDDEAD8DED9DED4BBAB96716049403E42
43599AA3AFBDC0D1DCD2EBC5E2B5AA8C907371706F57453C3C363B383838343A3D3C3B3A
3A3A3A3938393A393837383936383A3B3C3B3A39353333353635353734343536383A3B3B
3E34333736373935393B393433383A3835353535343433333532353735393D3942434443
403E3E3F3C3C3C3A373637383A383637393A393939383C323A415E8DC5BEB88C6E4A4532
37393F3E373739353434343434363738393940443E3D3E39353645454442515444423F36
39323A3A3D3C3E3F3C434F4E597A84BEBADBD0C3
4C4A494A4C4C4B494748494847464647484A4F52514E4E504A4A4A4B4C4D4C4B49484848
484A4A4A494B49414846494944544D4A45494944454A4C454946424B616D6F8295A1AEA7
AC89867A9189A3B6CACCC8CBCECDCDC9B3A98D89768E7D8E7A9086A794AFA9CAD5D6D9C1
B1C6DBE0DBD1D4DCE1E4E1D4CEC0BF8E826A646360514F4549444D3E4245434F424A413E
44454446404042476C5D64636B554F44484E555057514D433E3F41453C3D3D3C3E414F64
676B534341453C3F3E383E373A3D3E3C3B3B3A38383C403F3B3A3C3F3E3D39383C3C3939
3F3A3C38393F3E433A383636383A3C3C413E3C3C3B393A3C433F3A37383A3C3D403E3939
3C3A373A3A3A3D403E3A3635393A3C3C3B3B3D40393A3B3937383D423C3B3A3939393939
38373C433F35353C34393C3A38393C3F3B3A3A393A3D42463D38373B3D3F42413A393839
3B3D3D3E3A3B3C3E3F3F3F3E37383938363637393D3C3F423E383B423C3D3C3B3938393A
373B3B393938383D3A3E393F3C3F42433D3D3D3C3B3B3B3C383C3C39393D3C3739393A3A
3A3938373D3E403D393B3B363D3C3C3C3D3D3B39393B39393C3A383D3E3B363A43433A34
3A3A3A393737393B3A3B3C3C3B3B3D3F39393939393B3F433B3A3B3D3C3836363F3E3D3B
3A3B3D3F40404040403F3E3D433E3D3E4240453E423D3A3C40444B51495E5B545C645D49
46534A4942463B424145443B3B41433E46464542403E3B37373939433F4641433C3D463E
3C3C453B3E4847414B455B527176787B97969C99898A9095948C7A68636B867D6F66676E
697F92B3C2B9B7B0AEAE9BABA0BCB0BFB3C3C3D1C8D6CED7CEBEA389847978664F3D4940
463B3F3C3F463C3D403E444044454F57736C8E9A9D9D867B615D5248434445454B5A6889
81968E9C98A5A0A8A29EA1A3ADB9C7C9CFD1D6E1DDD6D4C9D0CAD0D0C5BCABB1B7C3C8D5
D5E2D7E0DAE1DDCDB49EA7AFD4D7DCD9D9D6D2DADBD3D5D7E9D8E3DBDADDBEAA9472636C
7CA9D1D5E0D9EDDCD7C29F88727268786F5D544A46393C363A343F383A3B3B443C3B3938
37373738393A3B3A393838393637393B3C3C3B3A393535373938383A35343436383A3A3A
3C2F404E4639323938383633333537373A393837353433323633383C3A40453E41434442
3D3A38393A3A3937353436373A3837383837363838393550638A9BB898905A453B3C313E
3E3937353337382F3838383838393A3A3A393B3B36353635363B2E41314738353D3F403C
354C5F6C93897869616F84829BA0CDC2DCB4B279
4C4948494B4C4A48474849484746474846484B4C4E4E4B484E504E4B4C51514D4E4C4B4B
4C4C4B494C494150414946514C5D5450484A49484D4D433F49574F5952595E62656D767C
706B5B725D7874959DAEAEB3BBBBC5D0D6C3AF846A494F4A4C4E4E545157647A8AB1C5C1
CBCDC3D0D7D6DBD2D5CBC4B3A4A99FA9B7A8896A59444A3E43404B44483F4544483D4345
404243413E3E3D3B4840435C5F676569797F93989B8D83735F645A6749503F3E423D434B
42483E403A3F393E393C4B3F383C3E3A383837353A3C3E3D3C3A3B3C3F3F3A383D3D393A
3E3839373A4140433E3E3D3A3837393A3F3C3C3E3D3A393B423E3B3A3B3E40413B3B383A
3F3D3B41413F3E403E3835363C3D3E3E3E3E3E3F3C3B3A38383A3D3F3B3B3B3B3A3A3939
3A4C574E3E36393D3D3D3B383A3E3E3C3E3E3E3D3D3E42453F393939393F433E3536383A
3A3A3B3C3C3B3B3E40403E3B3C3D3D3D3C3B3B3B393B3E3E3B38383A3C3C3B3937363738
383C3B393C3B3A3F42483F443B3A3B3A3B3B3A3A3B3B3B3B383D3D39383E3F3C3B3A3937
373738383E3B3B3935393C363F3E3D3D3E3D3A383A3B393A3E3B393E3F3E3B3E48463D38
393B3D3B3836393C38393A3B3C3C3C3B3C3B3937383D43483B3B3D4243403E4036393D3E
3D3D3D3E3F3D3C3A3A3C3E403B37434142404441413C393B3D3E3F424855504948494A3E
494348493E40433640423B3A353D3B3A35383A393A3E403F3A3C3A3D3A3C3A3B3C404A46
484247454A455A54707D96A2B7B3AC8D9E81887D818C93979892867E7E868C9B82857F8B
8793ABA88A80847E8B7B82879496928EA6AAACB4C5C6BAAE907E65504E44483D463E3B3E
3B443D403842424349484C5957706B9693B0A79B896D6149454B555459607A7C97A2C0D1
CFE1CFDBCED4C7CFCFC3BCB8B8C0CCD0D0D2D4DBD9D3CFC0A49896969B9EA9B6CFDBDEE3
D5DBCCD8DDDDD1C5B7ABABA5C3CDD9D8DADDD8E0D6D0C7D6D4D6D7E1E1EAE8E1D9BAA9AD
C1E1E9E7E5E2EADED2C0A9806D5445404141424443353C304644574F4C42373C3C3C3B3A
3A3A3A3A3A3B3C3B3939393A3738393A3B3A3A393D3937393A3838393837363637383735
324B7C724A3B3540373635373736363837373738393A3B3C38353B3E3A41453C34373939
3736383B37373633313133353836363839383A3E3A4C7187A8A2967256473A343D373D2E
3B37393B3736393737373636353535353A3B383433323235343B35393139343A3C3A4360
75B8CBCEC8B4947F7E9ABBB8C2BFB0B57B824F38
4C4947484B4C4A47494A4A494747484A4A4B4B4B50534E464B4E4C45474E4E4747454447
4A4C4B494F3F495A4641464749483B484743414B4B46444050514751595B635B4F49444A
48414649494D47504E686C788781899C92A499A7897A725B534D4A4B4747484A55668AAA
C7D8D0CBD1CFC9A7A28A7B616760546B6D826C6E6E546253514647464643434B4B49464A
534E4540454A473F3E374352595B6A7486869CA4A6A2ACA49F979181665047413A3B4345
3B453C3C3B403C4039415849393E413E3A3B3B3A3E3C3B3A3B3B39383C413F3B3C39383E
3E393C3C40453F3F3F4243413D3B3D403A383B3F403C3B3C3E3D3C3C3C3B38363C3D3A3C
413D3A41453F3B3A3A393C413939393A3A3A3837403C3837393C3C3C3B3C3D3D3D3B3938
406777593C3B403C4044433D393C40423A3A3B393737393B3936363638424740393C3E3E
3B3836373D3C3B3E41413D383D3D3D3D3C3B3A38383D3E3B3A3B3934393B3C3D3E414447
36393533393A383C3A433C463D3E40403A3838393B3C3B3A3A40403A3A404443403D3936
36373A3C3B3A3F403E403F3543403E3C3B3A36343A3937393D39353A3E423E3B3C383437
373C41403C3B3D413A38383B3E3F3C393C3C3D3C3B3B3C3D3C39393C3C39393C37393B3A
393A3E42413F3D3B3C404549403E524B453F40403E3C3C3C3A3A3F4649473C3A38373C38
3B3B3F3D3B3B3C38393A3E3D3C3738383A3E3F3C3B3D3F3E3738373539393F4038434E49
47373E4E4F48757D8CA08CA28C9F828F839998AAB9B9A88E7E746F73817673858A919699
98A3AB92877E5B517262637A7B8877746F797281878E7B735049443E3D374746403F3840
39483839494B58616D6F656E6372757B797A887786759880958E9BA8ACBAC5D4D4E1DCD9
CDDDC3CCB5AE95978D7D767B828F9B9DAAACADBAC5C6BDA6ADA7A2989D9DA8A8BCD0D8D5
B7B8B0C9BBC7C7C5C1C2CED0D6D4CFBFC1CCD0DCD1D1D2CED1D1CDC6D7CAD6D6DAD6D7D8
E1E3EDE8DEEDD2E3C8DAD2CBADA4694B454B4D585E54675C787B968C7F6347413B40474B
4B47413D3B3C3C3C3A393A3B3939393A393938383F3A3738393635363635343538393937
3F68935F2D3B3B393836383C3C38373A37373636353536363A363B3D383D3F34393B3B39
3635373A3938373534343637353435393B3C41486A9ABABE9B8363393F483A383735393A
3630363E3932333734343535353636373A3E393537333136323437353F37393F4568ABC9
C8D9CEB8A0896D666D8BA9A2A67A7B4E3D3F4240
4D4D4E4F4E4D4C4C4B4E51514F4C4A4A454C57504949474C4844454D52514E4F4D4D4B47
484B4A464A4745474B4C49454C4E4844464544494C47454747464A504C4A4A4B4945464A
43484A4B4E4A4952505556514D4E50505650735E857286696D614A5C4C5D5358514C6484
A4A9AEA98B887D8984847B68705C655046524A577F9EAEA887887A7D62686B7E60638B8B
89797A6B796862615E5245473F4C465454547782837F7E79856D775A4F3A3F363C36403E
3D384447403D42363F3D423E3E3E3839403A36413C3A3C3B383E3B3F3A3E3941363E393A
39433943504757453D4144473D42383E3D3E3B3A3C42403C3738383B3D343B3A33393B3A
3A3A3B3C44433C3E3A343C403F3E42443E3D3E3A3940413E3E3B393E393D383B3C3A3F39
52796464493A3A393D3D3A37393E403E3B3635393C39363537363536393B3B3B353A3D3A
383A3C3D3C3B3A3A3A3A3B3C3E3C433E3A3A32363D413F37363D424239393A3D3E3A3B40
393B3B3B3B3B3B393E413B403B403B3F3B39383B3D3A383B3B3B39383B403F3A363A3C38
36383A3836363A40423F3F423C3A3837383939383E3633393B373538333D403D3D393434
3737383A3D3E3E3D3C3A3B3D3C37383D383C3F3F3E3D3D3C373A3D3A3634383C3F403D39
3B41423E393E413F3D3D3D3B3C4349473F3A3B3F3E37353838363A423B3736393C3B3C3F
3E3A3736383B3B3B3E3D3E403E3C3E433D3C3A3939393A3B3938383A3C3D3B39383B3D3C
3A3A3D41557E988E8E847C6E7077899799A0A9A8BBB8A885776565675B5D52555D8198A7
BFB4AAB3AC9176546F57584B62525347464344484B494747373B413D394334433F3C3F3A
46443F44566970777A6F60545A5E64978DA89FBDBDCCCAD4DADEDCD8DED4D8D5D9CCBFAA
9B8A6F715E62566F6682909CA2B2B9C6C1C6AABABDD5C3CEC4C0B9C6C1CECAC7CCD0CECC
C7B9BAB3C0C4D1D5DDD3E2D7E0D5D8D1CAD2D6DDD4DAD0D1D0DAD5DAB3B3B4BDC3C6C5D1
D0D0D9E1D9DCDFD0D6D1E1D8DED2CAA6B0ACB7AE907B78847F97A2C8A2BDA1A27C907B9B
96A4736D453D36373936333334363C403F3A3737373935384441383C33393A3D33383B42
535C473C38333B3937383937343336393735383D3B35363D3A3F423E3936373832393A35
3335383B3940303A303D37343A363A40435B7B7EA8C4B484634835373C3A373433333434
333C3132312F3C35332F383936383536383A3B3A373534343732343937333E517BB7CAC0
A3937C6155434845507B786B523A3B3B3C4F5858
4B4B4B4A49494A4B4A4B4B4B4A4A4A4A41454D49494E4C4F4846484D504F4B4947484845
454847444A4B4B4C4C4A47454A4B46434748484D4D4C4946474A4C4D4B4A4B4D4B484A4E
4B4E4C4A49434249484B4A444244474742404F444E49574D4F5B596A5F776D68625A6163
696469655B554D5A66798F93958F9481766D52566C8CACBDBACBC8D0BCB7A9B5A2ADD3D5
CFBEBBB0BCB4AFB3A09C8994879692978E7A534347404543433E444D3D433C413B3F4640
453F434434383B3E3D3E3D3E3F48463C3C41403B3C38413B3E3B413D3836413942344045
436A7F9185625A4337383E3E3C3F3A3E343E374139443A403C32402B454B42403C3B3D3E
3B393A3B3639373C3D3A40413C383A3A36383B38373E404143403C3E3D3E3940433D3C35
71775A6D5C40373E3A3B3A393C40413F3D3D4042403B3A3D3A3938393A3A3837373B3D3A
383A3C3D3C3C3C3B3A3A3C3D3E3B403B393C393E3A3F403A383B3C383836383A3836383A
3A3A3B3C3C3B3B3C3D4040443B3F3F433E39383B3B3C4043383B3C3A3B3E3F3E373B3C3A
3A3D3E3E3C39373839393A3D3D3C3C3C3C393431433C3A3F413C3A3C383F3E393A39393C
3B3B3B3B3C3D3E3E3E3E3D3937383B3C38393C3D3B393839383A3C3B38373A3E3C3A383A
3D3E3F403D40413F3F41413E393C3F41403E3C3A393B3F403A353E4D3E3D3E4142403E3E
3C3F413E39383B3F3A393A3C3A38393D3B3B3B3B3B3B3C3D34373B3E3F3E3C3B3A3A3936
35384046758F8B80646A6161595F6B74777A7D7C757572615F504B483B3B434E61878C95
8A81777B76685C47413F483D453B403C3A393B3D3E3E4248383C363F423F42423C3C3740
39453E4D4A5F565651475556827FB4C0D2CCD6BDCCC3C9C1CCBEC1BFAFA9958A79707B76
7C8E7FA98BA584A395B4CAD6D0D5D3D9D5D4D6C8DBCECAC1C9BAC5B8D1CEE6E0DCE4E7EE
E4E5DCDED3DCDDE7DFE3E7E1DACDD4D7D3D3D2D8D8D6E2CCE2CFD9D0C0B2BFBCCFCFC6CE
C8C0B0BCB1D2C9D9D5DBD9E3D4E7E0D3C6D0D19F5F43434F465D827EA0A1AEB6C6A18086
85948756473F3D3E3937373236383636383B3D42363C3C3A3A39383C343734333A3D424C
635047373538303B3436383837383A3C3A393B3C37333A4648413C39363334392F333636
373837353B3039343F3B34373B3D63707B928C8E78867553433A343934393A3535393A37
354A5663563B37303A353A3631373A3D3637373837373738333032383939435164877575
4D553F393C3A3E3C30463B3D3B39454D6187A1AE
4F4F4E4B4A4A4D504E4D4B4B4C4D4E4F4D4B4E4A4C524D4D494949484A4B484446494B4A
4A4B4A494A4C4E4E4A464444454644454B4D4B4C4D4D4944454B4B47494A4C4C4947484C
494A4847464243494747433F3E4144454448464C3F4543474251535E556E685F615D6158
5852524752473F434B53686F686D75726F64514F4F597F7C928A9492A29F8D9994A4C6CD
D9CFCBC3C1B9B4C0D2CDCFCCD0C0BFA595874B41453C4441413B3D4642433D44393F4138
4441413E433D4636423342413D45463E3A40433F444238423A473F3842453D41424D6081
87A5A8A37D564C40433D453B413E40413A3A48394B363F3E383B3C385888808768534947
3F3C3D3A343A383A3A393E3B38383C3F3D3D3C38373C3E4248453E3D3F3B3740443E3B36
648C786348484537393B3B3B3D403F3C3C3E41423E3A393B3B3A3A3B3B3A3735383C3D39
37393C3C3B3C3D3C3A3A3C3E3C3A3E3B3B3E3D41373C3F3C3B3D3C383F393D413B3D4342
3C393A3F3F3B3B3F3C3E43473A3E44463F383A3C36363B39373B3E3C3A3C3E403A3D3E3D
3D3F4040393A3A3B3E403E3B38393A3C3D3C3937403A393D3F3A37383F44413A3938373A
3E3E3D3C3C3C3D3D3F423E3634393C3B3A38393D3B363539393B3B3B3A3A3C3E413B393D
3C3736393C3E3E3E40444441423F3E4044433C36393D44443B353E4C3D3F414141414140
3C3F403D373435383837393D3D3B3C403F3E3D3B3A3938383F3C39393B3B39363E3D3B38
383D454B68605E41423E4B45464A4947454140444541423E4941413F4744555053665459
56524A494747483E4345413B3B3E3F393A3B3E42424041453F30443B3C3E353E3B373A49
424B47544A4E575256656F848A958AA393A6786F6A68677A69705C67807886688A619B8A
B3ADB096977F8597ACC3D5DED1D3CECCC0C9AFCCACC8B0BDB0B7BCD6D2E6E2E3ECE7F5E6
EBE2E4E5DED9E8D7E9D6E7D8D5C2BFC2C3C5CCDACFDEC8DEC0D7BEC8C5CCBECDC4C2BDC5
C3B3947F9893BAC8CABBCFB5D0B7BB93A2A2976C48403B36453C3F3A4C4C6C9AAAC2A294
614F3D3F423C3D3F3B3B3B373B3D36373B3C373B3C38393734383A343539393248414144
423238393A3D3438393A3A3A393939393C3B3B3C39363C454D3F3638383333383D383534
3433333238333B3A34433C6079788C8985806157464941383838343336393A38383A3C3D
577C959872423938393338383E4B484036353536373839393F3B38383736393E4047393A
363C3A3B373445364133363E3B4F6A8BBBD8C8B5
484948464444474A4A474443454748484A484A44444943414A4A46424247474340444747
464544444A4B4B4A484543424142454A50504B484B4A454243474641484A4B4945424345
444344464645464C484642404144454544443C493D453E44524F48514A56514C4948504E
595C57404A3F3F40463E45484947454845474E4A42494A5A4D5C515E5D685D6760657982
7E7E7F848697ACD2CBD2D3DED0CEBBA28D86676C646168625C55424B3C433A48413E3C33
3D3B3F40424944494246444444403A3C3F3B3A41404149455B555F575A5C785D896A8B94
8D896C6150515757504F4D5351605B625658536150544A4F4B45434387A2B3968D674F49
3F3C3C353D423C3937383D383B3C3F4242413E3A393C3B3E46453F3E3E37343C3F3B3C3F
3D635F5138383D403C3C3C3B3C3C3A373E3B3A3B3C3B38353B3A393A3B3B3A393A3D3C39
37393B3B3A3B3C3C3A393B3D393A3E3E3E3E3C3C3A3D3E3B3A3D3E3C423B424740454F4B
3E393A40413B3B413C3A43473B3E4644413D464A3E3C3D35383B3D3C3A3A3B3C3E3F3F3E
3D3D3D3C3A3D3D3D4144413A3F3D3A3838393B3C3C38373A3B3633333C43423D3C393535
3D3D3D3D3C3B3C3C3E3F3D38363839383E39393E3E37373C3C3B3B3B3B3B3C3C3A38383C
3C3A393B373C3F3E3F4344433F3B383D4447443F3D3C3D3E3B37383D383A3A39393D4142
3B3735363A3C3A373B3A3B3E3F3D3D403F3E3C3A383839395E544B4C54554D433B3C3C3C
3C3F4346433C3C4038413C383C403E3D3F3B383F443D404252515A5D514B574B474F3B3F
3E3F3B393B40403A3F453C3E363B3C3B43414245433F3C3D453B3F3B433D4E474F525188
76967B868998939E98868B8192756C6558544F4A4E659186918199ABC1C4A8B1998E8A78
6F6258514A546B90BCC9D4DCCCCAB9A99783A395C2ACD1CBD2D3DEE4E6E6E9E5EAE9E0E6
D8E3D5DAD5D5CAD6C8CEC6CBCCBEB6B3ACA5A8B2B4AECEB3D8B4C7B6BFAEBB9A9A9193AD
B1B7A2AA91B296B8B8BEACCBB0BD84645E5751423B403E3F393F4C573A413F4A568EAB96
BD75534D4038363B3C393431393D373C3A39394B533D3A3F3B3E40343A3B41384E403F3B
3538363F3A353F353D3C3B39393838373E39393D403D3A3A4139363B3D3835363B353435
3335393A373A313D457580A6A096725D51403A323C35303236383735383333393A373D47
6585928258373638333543484F584C3B37363536383837353C3A3735363838373C393534
3E3835333B3B343D3E434A6D749DBDD1E2D3AD98
4C4D4E4D4B4B4B4C4F4C4A494A4B4A4946484E49494D494A4C4E4D494A4D4D49484A4D4F
4D4A49494D494747494A48454443464A4D4E4A464C4643444644424245484A4844424243
454345484644444643413F40424342414B46434445444951524A474E4848444247454E52
656F6E59645A574C483A3F4853555058544D51444C4B49554956526451605555453E4146
46494D55525C6789ABB4DBCEDDD2DED1CCBDB5B4A4AEB4BA9CA688A06F7A5E7058505550
4D4656608891A195A2888A707D71554D61665E636E8686918A9492AA9A9E8A736D6A6B78
819199AAACB4B0ADAB9CB49CBCA7B3A8B7A1B3A4B7A6BEB4A798808A94A5977A64463D42
3F3F44433E443F3D3B3B413C3E3E3B39393A3C3E3D3D393940413D3E3E393B3F3D393B44
3A3934424038333C3D3B3A3A3B3A38373F3B38383B3E3B373D3B3938393A3B3A3A3C3C39
383A3B3A393A3B3B3939393A37393A3D3E3D3D3A3C3D3C3A3A3B3B393C373D413A414A46
3E393A40413B3B403D373F423C3E453E3D3D4A4F434142393C3A393A3B3A38363D3C3B3B
3B3A393942413C37393D3D383A393736373C41453E3C3C3E3D3A3736343C3C3B3D3D3939
393A3B3C3C3C3C3B3B393A3D3C3835363E38373D3E39393F3E3C3B3A3A3A3A3935393B3A
3B3E3D3B37404644403F40413F3B38383B3C3C3A3C3937393B393635383A3A3A3A3C3F42
453D36373D413D373E3B3B3D3C39383A3C3B3A393B3E42454C48474E5654473B37373838
383A3C3D3D394246383D39403E3C383E49453B3B4C474D4D544D53545148473F43473E3B
393A39373D423D38363C37443E3C3C3D3B3C40434240444A51576969756E84789B78918B
BAABBDB0CABCC4B4A6A397A49D9E8B6C5C514F6C82B3B3B69DB5C0DADDC7C1A7B393977A
936F8E6B8D6896A0CBD2D9DECDCBBBAAA3AFA4D7BFE8D1D5CDD1DAE1DCDDDDDBDCD4D1C3
C8B0AB98A494A38D9D8199A4ABA79D91847A7C82798876A087B1A2B4A6A684816B6E7D94
B2C4CEC1CAA4A88CB0A2B59EC1B2C6B1B69C816A5F584B4A463B587464483E4B4F7287A1
C6CFA89D634A3E403C3C3F38393B363E3536456A73626D72523B3C3A39353D343F363C39
3F3F3C48443D473E3A393837383A3B3C3C39393D3F3C373334373A3C3C3A373535343A3B
3534393732475370A3B9BA9E70684236373139393C32303637343333353031393B393E48
4D55514639313534343F53534B4A3E3335353537393937343534323235393937393D303B
313D2E37372F3D48736D92ACCCDEE1DED2A7755F
474748494948464548474645454444433D414945434846483F424647474743404545474A
494543444E4946474C4E4D4A4B47464646484A474C464448494544464246484746474746
4542444845434343424040444645424243434B42493C454C464549453F3F444342424F53
6064695D6C6662524842495B5E64575C615A5C5563546752654F5E605A6456564D4A494B
4E4C4F5D5B584B5A7197C0CBC0C6C2CDD0CED9D7CED4D7E8D8D3DEBEBC93A49E9E9AA8A2
928296A6C8DAD9E2DBD7D5C9C6BE8D6E90B4B3AEA7A6AD989E93A1BBE0D8D5A4B5A0B4AF
AEC3DAE1DAD5CAC9C3C8BCD4C0D4B5B79FA4B0D2CEE1DBD7D9A79D6C61504B433E353B45
3F37393C3D454445413C3E3B3C3E3C3939393A3E3E3E39373B3C3B3F3F3E45453F3A3942
3E3F3C3A3D443A333A38383B3C3B3A3A38383837393C3C3A413E3A3837383939393B3C39
393B3B3939393A3A3A3A3939373935393C3C413F3637383A3B3C3A3839363B3B353A403C
3E3A3B3F3F3B3A3D3D373E3E3D3C41393D3F48483D3B3E393D39373A3C3B37353A383739
3A39393A403F3C3A3B3D3D3A3F3F3D3B3838383A3E3D3D3E3D3B3938363B39363A3B3A3B
3938383A3C3E3D3B3936393F403A36373C37363A3B393A3E3F3D3C3A3A393938383D3F3B
393C3C383C454A47413E3D3C38373637393D40423838393A3B3A39393E3E4044433F3D3F
433F3A39393A3A3A3E3A3A3D3E3E3F41403F3D3C3D4044463C3E414444413C383B3A3836
373A3D4046394B414B464C53615243464E4B413C4A454A44433A3E3B43413E3A3F3E4441
3C3A39373E443C3C403F373F41383F3D3E434B515560758797807C5C646E848F9085759F
9FC5B1BAB5A7918D837A84869189AF878081AC99C4CFC9AABCBCD0C4C1C0A9C1A2BC9E9F
817D698E678372909DB3C8D9D3D4C5BABBB2C9B4D4C8D7BAC0BFD2CBCFBEC1B6ACAA9192
7B6F594A4C4F515F5865749C98A9B4BBB6A59B9596808F779F9AC7C9D6C8D3B4B1A8ABC5
D0DBD9E6C7E4BBB5919E8CA997C3C1D2D3C4B7ADAEADA09F63674F5649625975ADBAE6C3
D9CACCBA9C725544374B635D604E3A443D4D63868B93B8BD7B40373C39383B3937363A39
37335370786A4C473B3B3A393838393A3A3B3B3A3734363834393C393737373639383D39
2F343D3B466C7795A0987E48403936323A3C31363832333A3934343A383A3A39393A3936
3B363235363434353D414C463B3B363132333436383938383736343333343433373A3837
33383543434B568491A2BED8DCDAC7AE87594443
4D4C4C4D4F4E4B484A4A4A484747484947484D48484D4B4C47484B4F4F4C49494846484B
4C494849484746474A4C4C4B4C4747474345484547464647484746464144454546494844
433E414542424443434243484947454641464E464C3F424547474C413D404B4848465355
554B4E4A4C4C4B454348445253594F555B54524B50494F4F53514D514B52484E4D545454
504B5263685A4041496E999BA69CA6B1BEC8D0D5DAD4DBE2DCD6BCB492928F8B9FA1AEAE
ACA3B5C5C1C8D0CCD2BCD4D5D1D8B797B2D9E2DCD3C1C2C2BAC5C2DCE5EEE7E6D8DDD6D9
E4E0E6DCD9D2C0B79F8F9A85978380715E78A6C4E0D8CDBCB6876D4F3D3F353E39373D45
4139383C4046464841373938383F4140413D3B403A3E3B393C3B3A3F3F3E46413D3C373D
39363D3C393B373F3A383A3F403E3B3C363737393E42403A3F3D393838393938373A3B3A
3B3D3C393C3A3A3B3D3D3B39393B363A3D3C413E3C3B3A3A3C3C3B3A3A3C3E3C393C3E3C
3C3C3C3D3C3A393A3B3A413D3E383C3940454A453C393B3A3B393A3D3E3A39393B38373A
3B3A393A3B3A3B3F403E3D3D393B3C3B3A393A3B3B3B3B3A393938383A3E3A35383A383A
3E3A37383C3F3F3D39383A3E403F3D3B3E3B38393A3B3C3D3E3E3D3C3B3A3A3B35383A3A
3A3C3D3E3C414442403F3C383C3B3A3A3B3C3C3C37393B3C3B3B3B3C403C3E46463E3A3D
35383A3938393D423F3B393D4042444741403F3D3C3B3B3B3A3B3B373333373B403E3B3A
3B3F43464D4A4D5C5B69515A54473F403E3C3D404841453D3F3E47424043423C3B333F40
3F3B3B393E413A413D3D39354239525069768DA3AFB2B4B78C7B5A58695C746C836B6F57
72636D6B705963676B726A737B8E9AAA9CCDCEC4B9B2A1A6A2B9B8B0AD9C9E837D69665C
4A534B60536758707B8E97A09FA8A3A38A93819F90B8A8AB8E9B9BAF8E8D6E664B494C47
4D45484348435549615B6D7D8D93929FACAFBBC6BFBAA7BDAECCCBD8D3DCD7DBCBC2BFCD
DEDFDED8DED7DDC7CEC7CABBCAC7D4D0D4D5D2C0B2ADB2C7BDB798B2A7C1ACC9CAD4D1C0
B5B49C9A92816B5A6798C0C4BFA28283727F828A7884ADBA834B3D3F3D41373F39433E46
504F6D888F7448413D3E3F3E3A383737393A3A373334373B393837373634363938353733
304457557C867278515345383B353535393933363C36333639373D4A45453F373537342D
36343638363230333E373A3633383736343434353536393A343434353434363936313E32
3D3543564D5067868D90BBC4BC956856473C3D37
4D4A494A4D4E4A47474747454445484A48464944474F4D4D464343464643444844414247
4A48464741434546464647484846494B454546414045464344474744404243424446443E
463E40423E3E414042404247484544464345403C42403D3F4440463E42424B44483F4849
47393E41403E3B3F475240414946404747434538453D4142494942414F5752575257534F
4F413F464F4A404B48605C5C60637184AAA49099AEACC3BBCFB7C1A4BA96A3765655544F
5A565D646B7C8A9D998194A0B7D0D3C7CEDBDFDFD2B9D7E0DEE1DBE8E8E9E8E4D8D6DAE0
E5DDE4D3D4D0C5C0ADA5959C93A4939595B2B8C1B8AB878057473E3D483A403B49413A3C
3F3C3B40404443453D33393D383F403D3D3C3D46363D3E3D3E3B3A403E3B3E37363B383C
43393D393A3E373C3D3B3E43443F3A3A3E3B393E4A51493D3A3938383A3B3B3A35393B3B
3C3E3C383E3B3A3C3F403D393B3F3A3F413C3E37504A423C39383737393F403D3E404040
3C3D3D3B3A3A3937393D443D3E34383A333D423D3836363838393C403E3A3B3F403B393C
3C3937383E3936373634363A3A3B3B3A38383B3D3B3C3B3A39393A3A363B39363B3D3B3C
433C36363B40403F393C3C3A3E43433F42403D3B3C3E3F3D3E3E3E3D3C3C3D3E3B393A3C
3A35363B373838393D403D37363434363A3B3A383B3B3B3A3B3B3A383E35353F4138363D
404243403B38393B423D393A3B3A3B3D3A3A3A3A3937353439393938393B40433D3C3A3B
3D4044465A4F5347504B3B42363845493A323B444C45473E403F4439413E3D383E394342
3D3A3D3A3C3B333F423E3E40696C887791939EB2C0BFB4AB98897D767969768E797B5E64
485E4B634E567C9B9A88736B887CA89EB4ABBC9EA1756E6C6C706F5E584C4C4249566E79
7AA092AE8FA16D7D6B705F554E5146474744455658554B4D4A48565259525B555B5E6665
5C5B53574B484D4C5F66595661666C8EAEBACFDFD9CACCCBD3CFD7D1DFD5D8D5DCDAD3DC
DCDED8DFD7E6E0E6DFE4DAE4DDEADFE0DAD5D5D6D9D2C7D0C9AFBEB0C7C1C8B3B7ACACA8
ABABBBC9C4D4BE9EAFD2DFDFDFDBD9E6CAC6AF9C7E778EA596817C7770765D6968817B8E
7977656761463E3B383C41413E3B3A3B3837363537393A393B3332383935353B39373A37
3A54675F674A444037383935373E3443433640363536363B413D3D484C443A3333363736
3637383334383736373138363135373C393836333233363A353435373533363C45403E41
3A404668695B5D8C898D8F70654C3C433E3B4234
47494A4A4848494B4A49474646474849454647464545464847494A494847494A4B4A4846
4544434345474745464A4C4B444244484745464B40444543434748474143484945494B46
414445423F41484C404343414144444141424048433C444140453C4340484B4952473F42
494A47453E3F43494A4643433D404144463F3B403D47473F3E3E404456726968675D4845
3D3F394046495250484E4F4C4C5153516365676B756E7C7A808A8FA8B2C8C7CAB1A87553
4F3F3D514F4A8EA5C3BEC4B9D4E5DFE5DFDCDED1DED3D1D6D5D6DBDFD9E0D9DBD8DBE1D8
E0D6D6CFD1CBC6B5AC9A9C7A9283A381A6909D6F6950493E3C423B3D413C3C3E3E483A40
41464544463B4140403A43423838423A383846433C3E444548413B4B41403E3640393A3D
3E3F3A3C3D3D423E3F383E42413C373F443B3E42617353414443413F3B393A3B3D3C3B3A
3B3D3F41363A3E3F3C3A3B3C3A39393A3C3C3B39433D414E4D3D34383D3F323D393C4247
3C3F3D39393D3D3B363C46473C363838373C403F3B393E433B3B433B363D44534941403F
3B3B3B35383F3B363C403D3A373B3D3C3D3F3F3C373B3835393A3D443C3A3837393B3C3C
3C3A3635363A3F4239393A3D4041403E3C3C393E3741403C3A3A393A3B3C3E3F3D393A3E
3C36363C383639373C44403F3B3B393734333436423F3C3B3D3E3D3C3234373A3B3B3A39
3A39393B3C3D3C3B3A3C393C3D3B403E373C363939363E3C39373E39373A373E3E3E3F40
424446474248473F3C3F3E393C3D3E3F42464A4B40473A373C3A3C3A3B3E4148393B4048
403D4442383E48434955576F6F9173858EAB9BAA9FA69B91846A6F5B666A89839F725048
4C4D454A4A6274868F86817E7A858787747A5E57434544404C5245433F3F46567B8CB2A8
A996A3808E646663694D4645454A4748555460656E626F666A627578838788828F7A9986
947D82807F7E7894969E999AAEB3BAC4D2DAD8D2D1CBC1CCD4D4D1D7D3D5DBDAE6DCDCE0
DCDFE4DEECE4E7E8DFEBF0E3E7E9DFD8D1C7C0B8B2CED4D8CBC4C6C8BFCABEB5A49997A3
9AB0B7CECACCC4D4CBD7D6E4E2E6E2E6DFDCD7C6C6C2CBD0CEC8C5CFC4C1BAB2BAD0CFD6
D1BEA7808B533F443C3A3F3735323F3A3A3744363B36383A373634373B3C3D3B433D3443
3B4840473B333F393B3B2A3E363E363F403940373731393B4C553F3D4037333838343337
37373838373635343039343433333B36343D3E3733363530372F2F3D3A355883627E4537
3F39414E869BB0B9A7775049393B38373B3A393C
494A4B4B49494A4B4C4B49484748494A46484A4A48474748424345454546494B4D4C4A48
4644434345474847474949464646474743403F4243474845424447474343454440434540
3E3E3F3F3F40454A3F424240404343414C4A474C47424A48484A3E42414C5252534A4346
4C4D4B4A444140424342444741434142433E3A3F4449453E3E40444B62705D554F493D3E
3C42404443404746444647484B52595D6A5F626F7B73796E7C727E759595B0B2A5B0987D
6C5B68887E5A6694ACC7BEBEB2C1B7D1CFDDE0DFBDC6D3D1C3BAB8B3B2ACBDABBFA7BCBF
CFD7D9D4D4D6D2CCBCA7A07B83768B77736C765E4D403F43373E3F413E3C42414351443F
383B3C3B403B3E3637364244403E423A3B3C45423B3A3F3C3C3B373F3F3F423D46414647
3F3F3C3C3D3D403F3A353B3E3F3E393F424149475E7961454138333B423C3536383A3C3D
3D3C3C3C393B3D3D3B3A3B3D3E3B39393A3C3C3C3937383C3D3A3A3C42443B443E3C3D3E
3B3D3D3A393B3A373B3C41413B3A3D3D383B3D3E3C3B3C3D37373F3C3B3F3D433D3D4243
3B383835383E3A33373B3938373C3E3B393C4042353A39383C3B3A3F3F3B38383A3B3B3B
3A3A3C3E414242423B3B3B3D40444648393A39413C4846423B3E403F3B3A3D413B37383D
3F3C3E453B383C393C433D3C393A3A3A393A3C3E3736353537393B3B3838373738393A3B
38393A3C3D3D3B39363C3E454540403A363E3C3D39364043403E444140434045393A3A3B
3D3F41423C40403B3A3E413F38383A3C3D3B3A3A363D36373C3F48475052565B4D4E5056
484E5B5A4E535D586651504B5661728FACA9A18B956F715A49544D4A668A999F8C7E6069
698E78735B605A626D6D6E6B4B4C4444394A3F42423F3F3C45505156565E65757582837E
6B765660434E414A4A3C41424044484F7E6F93759F77957D82808E87857D7773707589A4
A3C2C0D3BBB7A7B6B8C5CDD5DEDEDBD6CEC0AB9A96838D879C99A9A7A9AFC0CCDDD8D8D7
DBE2DBE2E0E7DFE5DDE9E4E3E3DCE7D8D9CDBEAFA4B1ACACABB7B7C2BCC2BCC3BAB1B1B0
A0A1949388908A948FA5ABB8D3D1E1E1E2D2CABBBDB5BBC2C4C3C6D5D4D6CBD1D2E8D3D1
D4D2C9D9CFAE827F44353839413E403C3635393D393D33373E3C3838383A3C3C383A3A3E
3938343C3D3D3434393B3D3735433F413C35413C3A373A35393F373A352D3A30402C3735
3535353536363636333632363531373731353431323739362A3933323C52768487683E3A
383B5A96BBC6D2BF87503B3C3C3A373939353B4B
4B4C4C4B4A494A4A4746454342424344444648484745434345454544434345464C4B4846
4442414144484A48484846424145484643424344424546423E3F42454A4747443F42443F
48403D4043414042434445434445464444414045403C4240525344464045444049444042
4748484746423F3F3F3F42474545403E413D3B3F4143414146484C555055484846444343
40444244413D4141484441404042484F5C4A4F5F66595A4B4A4A41534D5E5F6C6D6E5D58
5A565A636543593F6F7B9A87847C7386AABDD5D1CFCFCAB09A8D8370716A6D5F60626F93
9AAEAEAEA2A9A4ACB0A9B0A6B1B5C0C1C8C3CEA98E5748333D404145444C5A545C604C3F
383D3E3B434748383A373D3D3D3D3D373D3C3F3F413D423B363C3C3D413E423D403B403A
4140403E3E3D3B3D3E3A3C3B3D403B3C574B4C4F6E9275453F3E393C45423938393C3F3F
3E3D3E3E3D3D3C3C3B3B3C3D3E3D3B3A3B3C3C3C3E403E38373D403D3F403B413D3B3B3C
3B3A383536393C3E403D3F403C3E403D4040414242413E3C3D393B393B3E3B3C3D3C3D3C
36363939383E3C3637393736333C42403B3A3C3D3A3D3B3A3B383739433C37393B3A393A
38393C3F42413D39393A3B3B3C3D3F403D3D3A4039403A333A4045423A363A403D38373B
3D3C3E433D3B3E3A3C413A383B3C3C3C3B3A3B3C38383939393B3E403B3A393837383838
38383A3C3D3D3A37383B373A3A383D3B383A373C3F40464639383C3B3B3D3B3D38383838
393B3C3D383B3C3C3D3E41423C38373A3B393A3F373938393A404B4955525151413E3D40
3D4249453B3F443E404134514E6C7CA99DA171946B745054595B6F5D7A7E8F7274627374
9C9BA09792886E5E554A4843403F393F39453B3F3C3A464C54636F7B7869785B6153554F
3C473A3B3B363E3C3B3A403E3B41464D4F595A6B515D56666972828080766E6F828BB7BF
D0CFD4D6C5BDBAACBBAFC1BFD2D2CCBDAA9785787D7590899A96A09FB0B3C2CBD3D3DBDC
E1E5DFE4E1E4DADBDFD9DCD6D6C0C5B0A99D89776C6D646758766D81848D96AECCCDDBDA
D8CFBDAC9DA2948C7C867F7B9AA0B7CFC8C7B2B09686878E969DA8BECFCDCFC9D8D8CBC0
C8B8BFCDD9C1B0A27B55473F433E3739413C3E3E3A3938423F40413E3B3936353C3F3C31
3E363E3E3F3C363B3836444A647C8481684A413536373A37353838383535373838343333
393837353534343534333238373034363836333233353737363D3E353D5059654D3A3643
4167A0CFD7B69A7847303537483F383836334668
4C4C4B4B494948484C4B4A484747474746474848474544434A494745444444454A494846
444343424448494847484642454A4C46434446464B4B494746484A4B4A47474541444640
423E40474743474F4445454545464645413E4146423F413F3B413A434246423B3F3D3C3D
40424243413F4042423F3E4043433E3C40403D403D3F41474E4C4B514848414645434642
44413D3F42444542474241454542464E433A43494C414440413E43494D474B515752474A
4E4B4A41443F4046384E5564646E628895C0CDD7D6D4D3C4C0B9AD93ABA3C08E94685C64
4F64676F595F586161626F767D8D8EA1A2B3B6C2A4906E5357626C797F7F765E524C3D35
363B3E3D3F4949373C3A3B38373D3C393E3D3C42423A423F343A40413F3B443E3E3C433B
3A3A3C3C3E3D3A403E3A3C383D4743414543453D485F58453A4F52484A4A3E343B3C3D3C
3A3B3D403E3E3D3C3C3C3C3C3C3C3C3C3C3C3B3A3D40413B363B3C353E3D393A393A3D3E
45413D3B3A3B3E413F3E4144403F403C4343434342413F3E433E3B393B3D3B3B413C3836
37393A39373E403D3C3B3936383E43403B3938363D3D3A38393A3B3E453D383A3C39383A
3E3D3D404243413F3A3D4142413E3D3C3A3B3A423D464038373D423F3835383C3A363538
3938393C3E3D403B3C4039373B3B3B3A38373636393B3B393736393C393A3B3C3B393735
3938393B3C3B39373C3E393B3C3A3F3D3A38373B414443403B3A3C3C3C3D3B3B3A3A3939
3A3A3B3C383A3E41403E3D3E403A393E3F3B3D443D3A3A3C3B424841423C3B3C35353A3D
3C3F45443C393D40414558447B5E7B80877880778C6365545A5A656A625E5B414D5B6598
94AE97A47B705649423C3D39393A38413A3D363B3F4055605F666E776D5C56423C40393D
42433A4341423B4243433F3A3B3E3E4041414557536D779594A3B4BDC4B8A8A3B1B9C1C2
AAA3939A87927C8D819A9CABB7BFC2B9ADA7A7A8ACBAD0D0CCCDBDC8C6C4CAC8C2C5D5DA
D9D4DCD1DECECEC4BEA88F946C835C6A5E5B4F484A4E53606C948EABB4BEC7D6D8D7DFD9
DFDBDDD7D7DBD1CDC1C5B4A8A5A5C8CADDCFD6CFAA928785868891A7CEDBD1E0D5E3CCCD
CDC2A2AB87937E80928C9E967F624A5272686451433340516C6965574A443D3D36423644
413356814B343B413D3E568DAAA48F7F65483D343935333434353731373A323A343F393A
3B3A393736353534333333373734353639393C3F3D373536453D4D403D422D3C34516277
6A8CC0B89A6B4B3E33383F363F38343739394F71
4B4A4949484847464645444342414141464544444343424246454445464748484A494847
4747474745474745454848463F44464343494E4F4A45403F42434240424143423F434540
3E424A4D443D465743434344444444444B44464844434343464C434A474B47413E3F3F40
414344443E3D4044443F3B3B3D403C3C414240424143444A4F484245504A42413F3D4440
403C3B3D4246434138353941423B3B423C40443A3E383A3F3D3E444F4C443F433F444649
423F4541433D4A3E49434B463C4A575D768BA5A4AEB3C6C9D1CDCFC2C4CABDBF9CAB819F
88A0B4BE9D9478605C575D636173708A8894A6ADC2BFC5A8ADBCBEBFB89B74504F433F3F
3E3A3D463E4545363F3E403E4047433E3C3A3C48473F525B53576066747478624B3B403B
42413D3C3F3C3A423D3B3E3D465452505861604F52697B8987836F5A534E423C39393A39
38383A3B3D3D3D3D3D3C3B3A3C3B3B3A3A3A3B3C38393F403B3D3F3A413F3E39393A3C3D
3936363A3A38393C3D3D4345404043413E40403E3A393B3E3E3F3E3E3E3B39373D3C3B3C
3F3D3936393D403E3C3C3C3A41403C3736393A38393838393B3F4344443E3A3C3D3A3939
3D3C3C3D40424342363A3F41413F3E3E353738413D47423C383B3D3D3B39393B35343538
39393A3C3D3C403B3C403B3A39393838383837363B3C3D3A3635373A38393B3C3C3A3837
3B3A39393A3A3A393D3F393B3B393E3C383A3E3E3D3C39393A3A3839393838373C3B3A3A
39393A3A38393C3E3D3B3B3C3B393C44443B36393E37393D4048473C3732363A3A3C4243
3E3A3A42453E3B425C8176796C6E7389686D5670535E4A4F3C483D3E47414550656D9481
9C8A8A726758423D4041413741403A3E383D485778747F7A6659535644403F3C3F3F3D3E
423F404B4A614C5E4A463E4349403C467474808090A5BCD2D0D3CBC8C2AB8C7B79757A6C
63555B696A827B9996ADAAB7BBC0BFB7ADA7A5A4ACB1B9AB9B937C82747273736A70797B
827982737F6C6F626753574C5A6B6D858F94918E92939DABC3DDD2E0DCDED7D0CCD2DBDA
D9CDCFD0C3C6C5CBCACFCCCCCDD5D5DED6DCDFDADDC6BAB5B1ACADBCD0D6DDDAE4D7CFC4
D4D0D8AEB39AACA5C5CEE4D9C0B3A9BBBFC29EA2666C5D77786C5D4233383A433E404445
8C718D6C734730303D5076B4C9985D463F3738383937363C3D3A3B3A38363B3139333B39
363636363636363632343635363A38363D3A393835353F4B3F3B3F34323A3436586E7A86
67667A6D4838353A393A3A35393A3A3B3A343744
4A494848484847464B4A4A49484847474D4C4A4A4A4B4A49444443444546454445444444
444444454547464444484A494647464342434546504842434545413F4142464541454845
49484848423D40484746464848474749544847433E4040425B5C4B493E41413E3E414241
424343423F3E3F42413D3C3D3A3F3D3C4143414241444445494540424C49433D3E3A423E
3E3D41403F403B3D3F3D4147453C393D3E4343333E3D3B414945514A503A3C37383A3B41
4042473F364144363D48493D3F50454B3D5954535E637B828E8A95919C95969593918092
86A1C7D8D1D7CAA69E93989EA0B7BDD5D1DBD0D9D0DFDACACCD9D3CEC8B39B8965473D3A
3B363A454144473D40383C3C3B424246454E5B6E8E818C949098A5B1B2B6B28860414140
3D4139414A44474C494D5D6B81999EA19EA9A3949AAEC1D1BD8959484339353A3B3C3E40
403F3C3A3B3C3D3D3C3C3B3B3E3C3A3737393E413D393F433C3E44433C3A3F383B3B3A39
3F39383D3E3A3C423D3C40423E4148493E3F403D39393D413D3E3A3B39373B393B40413F
3F3B3A3D3E3C3C3B383A3D3C3E3C3835383D3D3939383B3E3E40413D3F3E3D3D3D3C3B39
3F3F3F3E3C3A38373A3A3A3939393A3A3A3B3A3E353C37313C3B3B3C3E3E3D3C393A3C3C
3B393A3C3C3C3F3B3B403D3D3F3D3B3A393937363B3C3D3B38373A3D3B3A3A39393A3B3C
3D3B3938393A3A3A3C3D373838363B3935353B3C3E3F393840423E3F3E3C403F3C3B3A38
373736363738383736393B3D3A383B41423C393B40393B3D424941383B363D40403A3B37
3F3C383F47464D5F8A737158795E6B4F4D46433D3A373F3F394040354C4C727D84817279
667359593C39353C4142453C3F423E423E404F5B726C6C5D483D363A3B3A423546344545
5D5F86748E857871575853606652526894B4B3C8B4D6C6D0BDAF8F80726554484F4E735F
89739AA1B3B8BEB2BEA1A199999284766E6860596C5C6B585C4C4A414C49454743494743
4340434748494944414F65688F8BAFB7CFD7DAD7D8D3DCDFDDE1D9D8D1D3C9C0B7C0B9B2
977F73766C6B6B72727A8798B4B8CCC7E0D5EAD6E1D4D5D7D8D5D1DACBD5C7DDD9E5D3D1
CBDAD2C9C2CECCD0D1DAE5E3DCDCCDD1DBD1DEBBC79EB8B5B8A7936D585A586078AFA5B8
9383604843493F47454F89AE9069433A3B37353737343433322E39546260594E3F363437
383736353534353534363934363D3A3733353A3D3A373B423C3B374C473846404B4E564F
383B343E3735353735313236323839393C383335
4A484748494A49474747474646464545424140414242413F474646474747444244444343
434343444648474445494A4944424245474646474743414242403F4046484B4842454B4A
4944404044464545484646494947474A544849454143414341463B3D363D42423E414140
4042403D403E3D3F3F3D3D3F3C42403C3F403F403D434341454441434349463E413A3F38
4A4546403D3F393C3A38393D3D3A3B3F4141483F4B4A484C4C50404C3643353D42444041
403F41383B413E433F3E44573F4B524A474A4A434D444A4049475958575E5378789FA2BA
BFBCC8B7B1A6A48A8D88A1B5C3D2D6DBDEDBE3DCDECAC3AC9298989FA5A4A49E93664F40
3F39383C413E46413F3A4F5F6A717B8E93A6B7C8E3D7DBD5C2AE96887A807D5E4C3C4143
384A4D6D87818686979CADBBCBD8D6D6C8CCC6B4A19CABBD8B5D4142423F3F3F3F3F4043
45433F3B3A3C3D3C3A3A3C3E3C3C3C3B3B3C3F423F3A3F40373B4340433F463A3E3F3D3C
413B3D454339353A403D3F41404447453F3F3E3E3E3F40423F3F363839393F3D3C41403D
3F3D3D43423D3E3F3B3C3E3A37393A3A3B3D3C383B383B3E3D3E3E38393F403D3C3F3E3A
494A49443E39373742403E3B3B3A3A393B3D3C40363E3C3A3C3C3B3C3C3D3D3D3E40423F
3B393B3D3D3C3F3A3A403E3F43403D3A39383735383939373536383B3C3B3A3A3A3A3B3B
3D3B3A3A3A3B3A393B403E42413C3C373833383A3F453D3B3A3E393B39373F3E3D3C3B39
37363535363A3C38383C3D3B3C3B3A3B3C3D3F41403F413C41453A373C373F40423A3E39
35424442474B5B76716958634C4F443C3F3C3A45393F3B3E414E495D556F888B88625C47
553A4044383D414740393D363B424147454045453D3F4139383B3A4245493B3F3B3C404A
657C908A877364575F6D635F60525565899DA9B4C0BFB09E827A64645E687273738B929F
A2B7BBC6B3AD877B675A4D5558534A424043423E4639473F493A433E3C43414440464142
454857636B6E726D648876A18CB2B1BCC6CACCC8CAC7D0C6CABAB7A190806C6E5D6E5D66
576974898E857E7E7C7E87938B91A6BBD1DBE3DADDD7DCDEE0E0DBE0DCDDD1D2D9D1CCC4
D1CCC4B0BBC0CFD2DEE7E4E2DCDFD7DCD8E6CEDCB5C0B8C6DCD6D5C0B7BEB7BBD2C8D1BC
AC684D3C41424B6C6E666E52483F3B3C3D39363839353531363D5994928867644345343C
3B393736383B3E413C383B37383D383939393A3B393636373E3E5F795F403E3B363C3D32
2C3D323A3E393738393837383A3D393739363437
4A4948494A4B4A4949494949494948484848484A4C4C4947444546494C4D4B484C4C4B4A
494949494749484546494A484743444A4C494647444446494845484E47494B463D404748
4849484340414547423F3F42434040434A3F464643453F403D48434A4245444140434341
4143413C3F3D3D3F3F3D3D3F4045423C3C3D3C3E3C45464344433E3D3944433A433F4641
5C4D463C3D433D3F3E3C3A393A3C41474E48544D4D433D403637413B453C403A3D423E3F
3F40443D384441363C424B514C4C434846564C4844414D41473E4A4243474247525F736F
887884787D5E60535549607390AEC9D0DCD5DDDFD2AD8A6E524B48535A5F665D76534A3E
42414447493E4747495588AEACAEB8CCC8D4DADFE8DDD9CBB69B73574F514C3D484B5050
61808EBFE0D5D5CBDADAE3E4E3DBC9C2B6957B726254585E463A3B3C373F453B3E3B393A
3D3E3C393A3C3C3A38383D41373B404242404040424148463D444C465A52554244444343
3F43546A6D5F5251443E3F444546433A3C3A393B3E403F3D3D3E373E4341433A383D3D40
47453D3D433F444844413E36393C3C3836383B3B37323539393E433F353F433E3C403F3A
4546443F39373A3E3A39393A3B3A38363538383B313A3B3B3A3B3B3A38383A3C3A3E403D
3A3A3F443E3D3F39393F3E403E3B3838393A3A3A3F3F3F3D3B3B3D3E3A3B3D3D3D3B3937
3C3B3B3B3C3C3A383F40393938363C3A3D3B423E3B3E393E3D423D3F3D3B4647403F3D3B
39373736363F44403F413E373B3C3C3B3A3A38363B3F423B4043383D3B343B393C373E3D
47514A4653564E4E4F463F3C3B3E3F3B4035323E3A44474F5D7066626E62696A584B463E
40423F403D3D3B3F3B3A413B3E40393B3C393E39353C40393E41393D4742454053464847
46635A695B52636B88A28B6D69686B6B878D88919280746D70777887808996978EA5A998
9490887A5C5D454E48433741383E43403D3E3F3F3A3F3C423F3C41535C758089868B8892
9392B2ACBEA7AE9BAEA7BCA1B8B5C8B6B8AFA18D8376786065516052585A5B7D6D918AA7
9BB8B7C4CBBFB6B7BCBDBAB8C0AFC1BFD5D1D8D3E1DDDFDCDCDFDCE1DAE6DBE6E0DBD1CE
BCBEA7AD94AEB7D0D6DFDBE4E4E7DFE2E0E0DFBFB89FBBBEDEDFEADDD9DFD1D0D8E4DDCB
A4B686735F527688644F50484B48464140403B3636353B383933417F8D6E4E3F3D383536
373636383E48515743393B3A3A3B343A3F3C3837393A37343B3F8169393E2E3737402F37
393937383130363A3635393A3537363638343239
4848484847474747463F434549494141423D4749484A464741434443464A494445434946
494F4542403F4245454344493F42424649423F46434548484441464D4243454643404247
46494742414444414146494643444544424542494840444340464945424243433F404439
363F424B3D423F413A4241434247453F3F4546423F464A4C4E483F3E3D44403A4044403C
4E4944403C393C413C3A3C363B454E654F4D484251474144404142403D3B3A3A373B3F41
464C4C493A3D373E434249454C4A4542454B4B47424849423A3A4044403F413F3B434A46
42454C52514B4A4D4547536CAACBB6B7CDCFCFD6CFBB8C7D605A4D434144413A40558C7F
776B7B7588838C81909DC2CDAE848383918CB7CFD9D3D9D8D9C2B2A39A8875679794B19D
BACAE0E6E4E4D7D2D7D5DBD3D2C6B495875F63485142423E3D3D3A3F3C3F3A4D44403B41
3C3840393C3E40494437393D3E40413F3E404345434244493D584769485D464A4A5D798B
8CA2A0A1A085805E50414844443E3C3C3A3A42444545463F423B48484A4F464F3C3D3E47
4F484147403C3E3A403B3D3A393C45403B3B3A413A393944453C3D3E393A3B3D3F434443
3D3A3F423E3D3D373B423C3C403A363839373C3A3A3C383B383B3E3F3F3E3D3D383A3B3A
393B404538383B3E3D3A3C4147443F3A37383E43463D393C3B373A433D3C3E403C3C403C
3F41403E3F413F3B383A3D3C3B3B3E413A3C3E3E3C3A39383A38393C3C3A3D433F3A3738
3837393D3A3A3F3A3536353B3D3D3E3C36383C36383B3D3C39383A3D373D3A3C47463F45
434C4C4644413F433F3A3A414039383D3735374050616E74806C5F5B544C48453F3F3F41
42403C39383F3F453D413C3D383B3C363F3E373930343738403C495D626A665F6C857162
5B7578957EA27E8D91A2A294818078859E938D695F5F6B778A817F807B797B7971615E56
53494B463C3A363D343D3C3B403B3F403D3F42433F454C434250747EA9AEBEB2C5CBCFCF
D1D5DCE6D8D7C3C8BAC9A6C2A8B98687635E4F5052584E557473A29EB8A2BBACC3C2CFC9
DBD5E2E0DCD6CBD0C3C2BFCAA8B2AAC7AEC9CBC9C2CACCCCCDC8C2C3CAD3DEDAE1DBE3CA
D4C8CBB3B8B0C3BDC3CACCD6D7E4E3E4E3E2DACF9DB3A3CCC0D9DCD2D8DCD9DCDFDCD0BD
BAC1D7BCC29E9E7C9891B39BA79D917C6245483D3B38363839394B674632383C35383936
333A384A4B3C57413B383D423C38393737353439373136364044433C37393C3B33333435
34323436323137363639363A3439373B3731393B
4F4E4D4C4C4C4D4D49474C4945474B58684E47464548444247494A494B4E4C4744434846
494F47444442424444424448424848464848474B474647484643474C4744454747434040
4343454645424142424546423F41424142444046464046463C424746444544423F424942
3E423F423F423C413E4743414346443E3D41423F444848484A4640403741403B3F434242
3F3D3D3E3F3F43493D3C41424950505D4845433F4C4442443F3F3F3D3B3B3C3E3B3D3E3E
4044433F3B3D383D3E3C403C3F3F3C3A3C41413F3E4243403F403F3D3E3C40413E42443F
3F4044484744444743434547678382939A90878B8B907E7F727D807368635B505177B5CF
B7AAADC0C9BBBDBAD2D8DDCAAB8B9A91B6B0D6D3D8D9E1DBDBD4DEE4D5CDA5B3B5D5D5DE
CBDCE4E9DCE9D9D7C7CBCFC2BEAEA4979684947E7A5B473C3D3F40423C41435B59424A70
6A4740453E3E3B42413B3F41403D3B3E4244444441384338414A42534A5C5D6B849CC3CE
CCC7AB947F5D5B4946473D4B3B49474B54667B8F84817875746664554A45373D3C3B3A3F
45413F47423F3F3C3F3C3E3D38383E3D3C403C403A3A383B3C3C3F403837393D403F3D3B
3C393C3E3C3F4340353C37393D3B3A3538353A393B3F3A3D393B3C3C3A393A3A37393B3A
393A3E4238383B3E3E3B3D403E3E3D3B393A3F42413D3C3E3E3B3C423734373A38383832
373D413F3C3C3B39413F3C3B3B3C3E3F393737373737383B38383A3B3C3C3F433E3B3A3C
3D3B3B3E393A403C393C3B42373B413E36363A373637393A3A393A3B383F3E4554514442
3840403E42423F3F3A37373C3D3B3C413B3D434E5E6C747866564C49433E3C3837393B3E
404141403C3C393F3B42414138413A3B3339393F3D3F3F45466386A1AD8E90849D8D8678
9D9FB2919D9697968F877F74768885A1B6AB897B5B6F697B635A585954525452433A3F3C
3E393F3A3834433C453B453E3A3A3B3D3F474F4A4E4B627B7B9E98B8C0D0D9D9D5E1E0ED
E5E4E6DCD0B5AAA18879665F575C4F5859666F8392A8B0BCB4C5C9D4C9D7DEE1D1CDC4C9
C3C8C0BCB2A2A294997C73675E604F6659777C7C727B848378747D8691A6ABBAB9CCD5D2
D2D4DEDAD6D2D4CDB9BAB5B7BDCFDBE3DFDCDDB57D6162738E9CA4A09EA7BACAC9D3CCDB
C5DADAD9C9CA9EA096CACBD6CBBB97684B39423A3637383C3C3434413832393B37343541
4F5264736A4D4D3E3F3F474C453D3935383B3A3734323943453F37333232343633353634
33343536313135353537383A343133394235335E
4E4C4A484748494A44444A443F424B5D7C56474643454341454647464647454144434746
494E4946474442424343444640484741414547494A46444545444548494443484C48413C
403F444A48413F424243423F3E40424143433E41413F43434646433F3E40414141424844
41413B3A41413A40424C443E4444423E3D3D3D3C4344403E41403B3C3A42433D3D3F3F40
424040413E3B3B3E4440414246443B3E423D3E3C443D40403D3D3B3A393B3E423D3E3C3A
3B3C3A373739373B3E3D403E3B3C3B393A3C3C3B3B3D3E3D3E41403D3E3A3D4242403E39
3F3E3E403F3D3D3F4142473F475A63786A5A4F504F5E5C6178878874656360587379A4AB
B9A1AFBECACDDAD1D6D5E0D8C0BBBBC4CADDE2D8CFD8E6E7E8E0DDD8D3C0B69EADA4AAAB
C0C2DFCEEADEDEC7C7CAC8BABBA9A09C8B7A74524D413E44383C41423C3C3A4A503C3B4F
4B3B3D3F3D403D434542433E423F414544404044484E476766A296B3A9B8B1C7C0D5DAD6
D5B08064594C5656696770607875988E9E99AAA7A483725D574D4D433F413C433F3C3838
393739413A3B3A39383A3B3C463F3D3B3A3F393B3C3D403E3D3E3B3A3F39383D403C3939
423E3E3D39393A383B37333B3933383438343735383C37393D3D3C3B383738393A3B3C3A
3736383A39393B3E3F3D3D3F3B3D3E3D3A38393B3A3C3F403F3E3E3F423D3E3D3A3B3A36
363F46453F3B3C3D413D39393A3A3734403B393B3B393A3D4041403C393939383B3B3C3E
3E3C3B3C3D3D433E3A3B3A40393C413F393A3A37393B3C3B393B3F43494E4A4A524E4340
3D41403E42423C383B3A393839393B3C3E40454C54575654473E3B3C3B3E413E37393A3B
3C3D3F403D3B3C41393B39363339433F484357514D42585E778DBEC9B4927B8D858F8287
94A38D90709271786F6A57687A8596A8C1A39A6E72565B544A4442433F3D3D3B3D3A3F3A
3D3A403A3F3C3B3D373938373E4446586B85A1A1AEADC1B1CEC3CDC2C9C0CBB7D2CCDADB
E6ECD1D8B3AD9A998282739C79A88BA8B0B9BCC6C6D5D7D5D3CBD3A2C2A1BA9EAE9B917F
786C695C5C5149494B4743414241413D48454E47504A4E53535F747FA8B2BEB5C7C3D5D1
DFD9E5D4E0D3E0D6D2CCC3B6B6BBC5C9D0D9DDCF996D5D50584C4D4F4A556C779A8FA099
AD9DA9A9C2B3C09A9598C2B7A59D7C4E3D343B33393A393B3D3731343A39393536323653
775C5E59503B363733343B3F3A3535352E39373437383C454A3D34353836363834383934
333638363A3834353839383335373F3C3B3C5A9F
4E4D4C4A494949494642474646484A53664B484841454744484847454544444245454647
494B48474744424344454545464A4A454245484A4B45404244444343474342484D4A4440
3F41474B4943404141414040414343434A484544434242424A46403C3C3E404142403F3D
3C3D3C3B4040393E3F4A433F4442403F3E3C3B3C40403C3B403F3A3A3E42413D3C3E3E3C
3F3E3F413F3B3B3E433F3D3E403D393B40393D3A3F383C3A3C3B3A39393B3F423D3C3B39
3A3A3937393A393C3F4144443D3F3F3D3B3A3A3A3A3E3F3B383B4042413B3A40423E3A38
41403F3E3E3C3C3C403F4540414D5159554A484F4E606063656963575766707075776176
6A7E6C7A8E9CB2AEB2B6C8C6CCC2D5BACBB6CABBC3C9D1D5DADAD3C9B9C0B0BCADBFABB2
BCCCD8E4D8DABFB88A7A6B5B5F534F4E4E4A493741423F43454346444140393C363F3F3C
3E42423D3C44444A4E5156504D4441484E535E6AAEA7BBABC5BFC0B5BDB8C1B9C0C3D9CD
D1B9A69D9DA2B3BFB8C7B3C2ACD1CAC5B09B82877168493C443F423C3B3C373B403F3D3B
39393C41444644403C3C3B3A403A393D3C453E42423C3A3635393C43443A353C413F4044
3B3B3D3D3A3838363C39353B393F4E424942413D3F433F403F3F3F3D3B393A3B393A3B39
3736363839393B3E3F3F3E3D393C3E3D3A373637363D413F3E3F3E3C3636414037373638
383F4545413D3D3E42424243433F3A353A36373B3C3736383B3E3D39393B3C39393A3B3C
3B3938393C3C413B3737363C423E3F3C3E413A34383E44464445494E4954565350463B38
373A3A393B3D3B373B3D3C3736383836383A3E4347474440413D3D3C3A3F423F3A3B3B3A
39393B3D37363C403B3A3D3E404A4C5A4C5B544E4A45578999B3B6B68B72876B91778D7B
7E7488698E797861644D52515A7179938A81686D53553C3E403D3C3C3B3A3937403E4038
3D3C3E363838323F38413A3C425D7BA7C1CEDED3C8DABCCAB4C5B4B7A3AAA2BEC3DED5E1
E0DADECCD6C1CFC7C5B2C7B0BFABB0ACC2C6C3CDCDDCD5C0AAAA7F72525B565154495043
453A443B3D3F3D423C42434B3F56506A5F7B798F91868694A5B8CAD2D4E3D0E4D4E8D4DD
DCE0DBE5DBE0D2CFC6BEB5A09B949997ACAFC3BDC3A0AC9B917C726B5C585B56524F4759
5E6260706E8C8F9581887B9157564A373D383C3B3C3D39373C3C393B3B3835343A3A3F5C
5C413C3B3F363B3C3A37373634353D453E4938333B383938423C393C3F3E3B39353B3B34
33383A363637323133363B38343F303D445DA0AB
4D4D4D4D4C4A494848424647494A44474B414848434A4A444A4846444242434447474547
48464746454443444647474549474748434043474C454143464543434744454849464545
42484B4947464340404040414241404044444441403F3D3C3E3D3D4043434140423E3939
3C3E40403F40393C3A44414141403F3F3F3E3D3E3F4240424846403F3F3C3A3A3E42423D
3B3A3C3F3F3E404343413F3F3B373A3C3E383D3B40383C393B3C3C3B3A3B3E40403E3C3C
3D3C3B3A4341403D3C3D3E40393A3C3C3A38393A3C40403C393B4042473F393C403D3A3A
3E3E3F3F3F3F3E3D433D3F3E44555D5F4D46474D4B5D5E6158524944474F54555F605E4A
554B5253494A514F58616B646367657A677373847C8FA4B3B9BEBCB8C5D5D6DDE2E6DDD6
DBC8D8C8DBAF8A5F4C3F4140454047453E414337434441413D3B44424345403E3F434041
463E3F5557789AB8C6C4BEB0B39A878A9BADBDC8C5D3C5DCBACAA39D9AA8BED6CADFDCD5
D6CFCFCABAB2A9A3ABA8BFA5C2BDC6A995786C595944463D3E3D4140404340413E40413F
3D3F41424043443D3C3C3D3A423F3D433C423A42453C3C444A4D5A6A52463D3F3F393739
3A3D3D3D3C3A3A3C3741393A466A815F48403D38393F3C3E3C3D3E3D3C3B3B3B36373838
38383A3B38393A3D40413E3B37383A3B3B3B3B3B373D403C3B3E3D3A38333B3A363B3839
393A3C3E3D3B3A3A3D404444413D3A393836373B3C39393C383B3B38393C3C383B3D3D3B
3837383837373D393639383F443F3F393C423A383A3F474E51504D4B404B4E4A47423C3A
3C3D3D3936383A39373B3C38383B3A363637393C3E3F3E3D3F3B3B3A383B3E3B3B3B3A39
38393C3F3E3938393B3C42495D566B53514A483F5750657D9E968C7A69736D7F80908281
6E7157725B6F4446434036403F476C69554B4A43473A3D3B3C3C3A3A3C3C3B3A3D3D3F3A
4545443B3F383C34403C4E567A9DBAD4DAD4D1B6BB9298707A59617D93A0BEBCD1C1D0D3
DFE2D7E2D2E3D4DBCAD7BCD5B7D5B6BCC4C6BAC1BDC3B39288735B4A3B37423C3F403A45
3643434746495D5060566D70849FA6BBADB7AABCB9BBBEC7D1D3D5DBE3DFE3D6E5D5D6D6
DBD7D8C4C0ACADAAB3ABA18B8681888888998FA596A4A0B3C5CACCC2AE9F97926C756368
59463C403E52605F7D6F53554B413C36423B3E48363B3B383A3936373834393C3B373748
3435353D44374236343433363A3F49545E6542373930363235393B3A3A3B3935373D3C35
33393B3732393E3A373737363731455783B4A98E
4A4B4C4D4C4A4847494447464544404546424644454E4942494644434140424648484447
46434645434545454648474547414245413D3F414C484547494745454947474745414245
464A4B464648464042414243413D3B3C3C3E43403E403B3C403D3D3F42414040403E393E
424144423E413A3C374040423E3F3F3F3F40403F3B3F40434946403F433C393A3D414039
3D3C3D3F3E3C3D413B3D3F433E3A41423B383C3B453D3D3C3C3D3D3D3C3C3E3F43403F40
3F3D3B3B4541413B3839383B37373A3C3C3A3C3F3C3E3F3D3E403E3B48423A383D3D3A3C
373B3D3E3E40403E4A453F3A3E4A52545853504E454F494B443F3B3A3A3A3C3E49584354
4353464F474547413E424B4A493C49454F39464D4A52555A5B69747F94B0AED0C9E0CCCE
A9A390A794985D47424457595141433F40414638413A3F3D4340483F414B545864605D62
71788AB5C0D0D8DEDEDBDED9DFD3CDD3DAD8D2CED5CED7C7D6C5D2C3D4CDE4CFD0D0DFDB
D3C7B9A88D8475655D6563766F9886814E473D483B433D413E3F3F3C3C3F3F3E3D3E3F3C
393F43404646483B3F3D433E403C39413944404E4C586E9096827B79443D3A3E403D3A3B
4143403C3C3D40463F463C445A7F947047403F3B3D43414538393B3B3A39393A3C3B3A39
383838393838393B40423E393C3B3B3B3D3D3C3B3B3D3D3B3B3E3D3A4133404F6069513D
3C39383B3E3D3B3B37393B393635383B42423F3C39393C3F3B3C3C3A3B3B3A373E40403B
38393B3C3A3A403B383A393F3E3D41373A423D444E474143494A443C3F423F3B3E42403B
4545443E37393D3B3B3E3E3B3A3B39353C3B3938373736363E38383A383A3E3C403F3D3A
39393B3C3F3C3837443E3D4460646B593D50485850625770718B72706355625984647067
5A52444745443B433932443D394449413E3E3B3B3B353A393C3E3B393D3F3E3E43444844
4F4B4A454D4D4C484F5A7896B2CFDAD0BAA68F665D503D534F7A8EC3B9C5B0BCAABAB5C2
C0B2C1ADC8C7D5D3CECFDEC8E1C6C4A9A7A9928D817F755C553E37403C454C4C5C605F6B
6C767578868FA49DA69A9E96ACB0CCBDD1B2AFA9A7B2B7BDC7C9C9D0C3C4B6BEA4A896A6
919F939B839399B5D5D3CDBFBBBBC2C3C1C6B6AB9D958F9FBDD6E5DED2C5BCBACDD1CEB9
B78174574546424A5B6C493B4436393842393840363B3B393B39383B3D3944453C393A42
3B403538454356473A3D41484F4F5157535A403A392F3A39343B3D37333637363A3D3C36
34383A393936383237403936375B8693AEA76857
4E4E4F504F4E4D4C4D484B494848454B49454340464C4444494748494744464A47474146
4540464645474845444647464A4445474445474448464648484544454846454644414143
484746464748454245444546433F3F433F434B464245414348423E3D3D3C3E413F3F3A42
4540434040423B3D38423F3F3C40403D3D40403C393D3D3E43413C3D453E3C3C3A3D3D38
38383A3D3E3C3D414545444A423A3F3C3B3B3D3C4A403B3B3C3D3E3E3E3E4042433F3F41
413E3B3B3F3C413C393B373C3C3A3B3E3E3C3D403A3D3F3D3C3E3E3B44433B373C3D3A39
393E403E3C3D3D3C48494441464C5254444745413A4035384343413F4043454542444445
554C4D3F3E3F484D49474A4A41433B50465049554B4B484F4C514F535C5B817BA9A0BCC5
B0BBB49D6E64515643434C4B50494E4D55505C54635A655C615D69687D9EBFCDCBCBCCC4
C5CCCFDDE6EBE7E6E3DFE4E1E9EAECECE7E0D8D4C8C8B7CBBFCCCBC9C6C0C7B5A4ADA8AB
9E90796749494B47423A443647475348413A42414843473F4244423E3C3D3D3A3E3D3D3C
3F505C5B645E5D444C434D44484C546C6B7A717E7E909BB2A3735A433D3B3A3C3E3D3C3B
3C403D3A3E40454D474940525B6071603D393B38393D3A3E393A3A393838393B403E3C3A
3939393A3738383A3F423E37433F3C3D40403D393D3C3B3B3E403F3D3743718E978A593A
3D3A393D3F3D3C3D3B3A3938383A3E403F43413934363A3A3937393D404040403B3F3F3B
383A3D3E3E3D423D3839373D3A3B423A414D495553493D383A3C3A37393C3E3C3F433E35
3C393A39383E433E40403F3D3B3B39383E3D3C3C3B3C3C3D473D3B3D3A383B3B43413E3C
3B3B3C3C38434646564844547D80875B473F3E49566F6C747381706C625B495C554D4040
464335373537353F35424243443C4C3C343D38403C3D3D393B3E3A363A3D3B3C3E40433E
47434C546E77707E788A95B3B1B9B6A7958C7F67505D7484ABB5D5CBBFAE8C7580859390
8C8B8893A1BABFC2AFB2A4AE909D7F78545D46464043453B3F3B37594A73728FA1A9B1AC
B6A8A2A0A3B1BBC0C0C3BEB6BFBEC9C9C6B3998F94948D86888D8D8B8879887C7E696C71
728797A5A6AAB4C9D3D9DBDBD9DEE0E3DAE3D0D9BEB79B9EBACFDEE0E1E0DCDCD5E2D3E9
D9D8BAAB6F7958585D754451494045383B3C3A363E3E3A393D3D3D423E3A41403A3B3838
3E3B39374A545B514042414447413B3D3E3E373839373B3D383B3C393636393B3C3C3B38
3637393A3B3643424D5C48415CB2B2B299564A3C
494949494949494947414444464742454743413F46463F49414042454440404445463F45
453F4747474A494442444746454242413F464A4242424446454140434642414446444343
494341464A474443464647494745484E3B3F48403A3D393C423F3E41413E3E413F3F3941
433C3F3C42423B3E3B443F3C3A40403B3B40403A3D403F3E413F3D40403B3C3D393C403D
39393B3E3D39383B3A38363E3A353D383E3F3E3C4C4037383D3D3E3E3E3F42453F3C3C41
423F3C3D3E3C433F3C3D373B403C3B3D3C38383B373E413B35373E433F433D373C3E3836
4145453F3A3A3A383D4038363D40424339413E3C3A4339413F42413D4148473F38443E40
3A40443D433E4146403C3D3E414543413D414143504C434B4A5559646655564E525F709A
8CACA6B994B99EA35E5A5C6A94A7B0AFC0B0BBB4C8BAC3AFC3BDC7C1CEDDE7E1E7DCE2DD
D9E2E4E7E9EAE4E5E3DCDCD6D7DCE1E3DFD7CBC3C0B2A6A6A5969A8A918288675F5F5D5E
5D4F40463B44473E4044404942454944444241423B3E3E3A3C4141414041413B403F4044
516F878A988E8F72817A8A818F9AACCCC6C29F9A848975756343463A3E3D3B393B3E4040
3D43403C3D3B3A413F4A47554B394A463F3C413E3D3F3A3C3E3D3C3A38393C3E3A393839
3B3E4143363738393F433E35413D3B3E4345423D3E3B3A3D41434240507ABFC9A4774739
3836373B3B38383B393735373B3D3C3B3640443E3A404443403C3C40423F3D3F353B3D39
37393C3D39393F3B383A39403C3A423E4C5C56603D3D3D3B3838393B363C3E3A3940423F
413B3B3C3E45463E3D3C3C3C3D3E3F413C3D3D3D3C3B3B3C4337353C3C3B3F413E3C3A3B
3E414242485E635A634D4E6B7B8884674E463A40577B7C9A85936C68655B4F443F37443B
3D3B3C35453A3D373C4B4F4546383C3D393F3B3B3E3B403641453F393E403E3F3A3E423E
494D667EBDB1A4908B757176847A7D8A99AEBEC6B5A6B3BEBFC8B1AC737659595A717D82
96928F889487867279626353424643414958454A4A4743393E3A445B618078917B8C8084
7B858198A6AFC8B5BDA19C85A093948E8F8B81816E6F7272778A96929E90A1ACADA8A3A6
B9C7C3D3C7CFC8DAD7DFDFE4DFE7E6E9E7E6DFDED8CCCECBD0DAE1E1E0E0E2E3E8E3E9E3
EAE2E1DACBB0B39CA89F948C9A8B7C4E3E444536423F3A3B413D383A393C4C5C707F7A76
736F7E6F716C5851403F393A413F3C424A383634373C363A3634353A3B38393D3D3C3A38
3636383B3E5489939184503C7293A16845423240
494B4D4D4B4A4A4A48494A49474748494849494846454748444647474544454640454943
46454256564C47494A4545484743443F425C654F41444746434244474643474742444948
454849454344474A444C4545464145463F3F4246474443443D3D3D3E4145494B3F444240
43403D423A3F42403D3E3E3E373C3E3B3C4041403E383E3B3B3E383D3C3D3D3C3E434341
3B3B3A3A3A3A3A3B383A3D3E3D3B3B3A3A413D403E393F3E3D3B393A3C3F3F3F3B403A3E
3D383F3C41403F3F3F3F3D3B393A3F3D373C413E373D413E3B3A3937413C3A3C3D3D4044
383A3437393A403D373B3C39383B3A373A3B393A3F3C3A413F41403E3E3A3C453B414445
4646413A3A3E3F3D3B3B3A37383E3C3B3E3B373C433E3E48555B5C5C58544C444041454A
5E626F73858A908A89807F95A3ACBDC2AAAAA3BEBDB297B8BECDC8CBD6DCE6E7E3E1D4E5
DAE0E3E4E0E6DEDBDABDC0CDD5D5DFDCD8D8D0D1CCDDC1AE8D9472764F5F475848494041
4042404744393A3B393D3A454B42423D3E3F44464140413E353E443C4A3F444240454744
4F596A766C7C87A3C5D2D8D5D7D5C4D6AB7F795A5342434B4B3C354A524844403E4C5B5B
84737E666B5A533F404141443A3C483B3E3A3B39434A41443E3F3F3C38393C3F3B40413B
383A3D3E3C4245413D3C3B3936403F3F3E3D413A4338424544443D5389B7CDB77A443A3B
383A3945443839383C383B36373C393D38393B3E41423F3D3A3A3F4D483A3B373C3A3A3B
38363A3F40423E36403D363F3A3E3B4B53443F3F353C3B393D3D3A3939413E403F3C4038
3D3E3E3C39393C3E3A3E403E3E403E393B3F3F3936393B3C3A36353B40403F3F3E383D40
4549454B6776615A594E585F84787755413E474B656C86838573715F4F423D3D3B3C403F
39424339363E413D4953473A40423A3A3C3B3D3A484545444B423C3D3D3C3C3C41454F4D
576B80A6A5AC7C634F4554657A858A8FA8C3CDD1CDCBC1A3AE9585736583849096B3A99F
95857A676950454542444A4145514E688A8A725C55524B3D4240424952584A52656D5451
56646E777B8A837C72768B7E8D86969DAFAEA6A39A98ADBECBD9D7D8D5D9DBD9D5CDCBD8
D4CFCDD0D3D1D2D3DBDDE0E1E3E5E4E1DEE4E0E8E0E6DEDEDCE3DDDBE1DBD7E3D6DCD8DE
D5E1DEE1E0E1E4D5D5CED6D5DEDAC7AB9E8B6E67685D6F52474541383A7B9CACC2C7C5AC
A8B9A6B69EA387784E3D3A3E37403D3E3A393E393738333C333C3F3E374141393D32353B
45444C748198BBC3A950423D414C594253606067
494B4C4C4A4949494647474644434344474747464545464740424445434242423F424440
4546435451494447484444474A4645423F494E4443444544424142444342474A47484A46
474241434341424644474241413B3B3F47423F404244484D44434241404040414044413F
413F3D4244464542424444413B3F42413F3F3F3E3A3B413C3E45404040413F3D3E40403C
3C3C3C3B3B3A38383637383838393C3E41453F413F3C413F3D3C3C3C3E3F3E3D3C3D373A
3E414C4C3F40413F3C3938373A393C3C3A3E4039393B3B38383E4243403C3A3A3835363A
3C3B35393B383C3A3F4142403F3F3F3E3B3C3A3B3F3B383E363C3E3E3D383A443C414443
403D3C3A3A3D3D3A383A3B3A3A3D3D3D3F4040444B49494E535455574948464340414549
4847494450555F5E5D636A74757987887C778B91A58278888D989AA8BFD1DBD5BDAFA3A7
B7C3D2CAB1A89AA49DACAABDC8C5CED2D9DED6D4C8C2BAABA291818760664A45414C4D48
3D3F3B3D3E3D46483D3D43424F40473E3E3E43454140403C43403F444E8983987B896268
6181748C87A0B0CFDDD5D6CBB5A68E8A5E524B474B484C525046557E86909186756C798E
A6AAA69981725C5659595951403A423E4141433A3C45403D393B393B373B393B373C4545
3D4047463D4244403C3B3938373934373A3D444240494143384A508FC5BB9E6C463B383A
3436343C3D373D3F3939393C3D3B3B3A38383A3D3F4141403F3B3D44403B3E3D3637403E
37393A3B3647394037363F4244483F4146403F3C363D3D3D41423E3E373D393C3E3F443E
3E3D3C3C3E4245483A3E424241403D3A3C3F3F3B393A3C3C3E3A383B3D3D3D3E3D353F3B
3F50596F6E71584E4B465863705D57403C3F4F5D6378757F4D54454E41393A3E3C3C3D3A
373F4039383E413F3F453E373D403C3C3D3C3D39443F3E3D3F3E3A3A40474A4D4B524555
62657F7F867E626E62888297AFB4ABA5ADB9C4C9B4AD9B9E8B95929A9EA494968F9D979D
908B7E8E888E7D81758D768775817C8A807F67534D49473F453F483C49434851445A514C
46484B534F575F6B768FAFB9C6C1CFD2DEDDD8D8DBD2DCE1E0E1DBDBCBD5D4CCC3C0C1CB
CBC7C9CCD9D3DBD8D7D8DCDEDBD6D9DFD3CFC9C8C8CBCBCDC1BDB0A9AAA1999CA6AAB0AF
BEC9D7DDE4E6EAE5EAE8ECE9E2E1DAD1D6D0BBB8ADB6A6C18A9B635388C2D4E5E6EBE7DD
CCBB8B74647A9170503F443847383D453730383A3B3D3A403638353B34403D36353C4040
45434152779EA18B5E3F414C6884A0A4B7AEC7B5
4A4B4C4B4A4848484A4A4A4947454546454443444445454544464748474645454445433F
44433F4A4B44404446444446464545474544464944444443424140404141464B4A4A4844
4E4441474A454347424242424544414A5148403E3F41464B43434342413F3D3C4143413E
3E3D3D40413F3B393B3F3D3940424546423D3B3D373B3F373842413E40403F3D3E41413E
3A3B3C3C3C3B39384141403E3B3A3B3C41403A3A3A383C3A3D3D3E3F40403E3C42423C3E
3F3D3F3B414445423E3938383C3938393B40413B3C3C3A393B3E3E3D3C3B3B3B3936383B
3A39353D403A3A363E3E40413F3C3C3F3D3D3B3D3E3A373A3D4345433E35333A383B3E3F
3C393B403B3D3B3736393B3C3F3E41424043474846464849464344493C3F41413F3F4144
4443433D43454A4945494A525E71827C808390A09C8B7883767D7D818B9BA39887726757
6E71826F75596C678298AAB3B4B0B4BCCCD8D6D8BDA2827F6E7367756061574342414A49
464F4C47444347404345424B48494741433E3F414043474650567980AFC0D8CDCFC3BCB0
C7CFD5C6C9CDC0C5B18C826C635F5D6C52644A533D44444846394A6EAAC7CCB89C755D64
566858634E533F434A4547423F3C3C3D3B3C403B3B413D393C413D433639323651505751
3E3C43403C40413F3C3B3A393B3D3B413F383A383E4246343C5689CACFAB624239374534
3F3F393A39373F423B3A31383B383F3F3E3E3D3C3B3B3C3D423B3E3C3A3D3F3E413C423C
3A423F3D3C3C424456505844474C40383A3E3F393D43434144433D3C3E3F3A3A3C3D403C
43413F40434544423B3E4447453F3C3C3E403F3D3C3C3C3B413D3B3B3B3A3B3D483A4748
597375875454484A453E4A4F5E4A42373E3D495B5D5C674C442E3B393C393D413F3D3D3B
3B3F403C393A3B3A3D3C3A393A3A3A3A3A3C3C373E393839343D3D41525C5A595C58465A
61617A6A817D8A9B909B9CA2A89F858395A2AAA1A99DA88A8B7481717C756267697E8291
A6A7AAC0C1C6BEBBC9C8B1987C775D664A5047424240424140453E4E48615E72617D7E7A
767B81898E8A909898A2AEBED6D3DCDDE4E2E1E3E6D9D9D8CEC7C1C3BABEB3AAA7B3BDC5
D8D7D7DAE5D9E0D7E1DAD5CDB99E908F888174786E706A6F6663646C757B818696AEADCC
C9E3D6E2E5E5E6E3E6E6E3DDD5C8BAB6C8D8DBE8E6DAE8DEE8C9C3A1C6E2EDE4ECDBE7E2
D7C59EA1847E7C514E424D8587A076564C37383B3C3C3C3A3B3C34433340363737413A37
3D3D40444C4A533F4A717FB4ACD0CCEFDAE8E7D6
4B4B4B4A494847474646454544434343454342434546464543434444434343434646413E
43433F4346413F4346454547484A47474944424A45444242434342404242444748484642
49424045474240414141443D3F423B414D464141424244464142434342403D3B4041413F
3E3D3D3E3F3F3D3B3C3F3E3B3F404345413A3A3E4547453D3C4447464142403D3D403F3C
393A3A3B3B3C3C3C393C3E3F3D3C3A3A44403A393A3C3D3C3D3D3E3F40403F3F4A433B38
3A3C3D3C424241403E3C3B3A3E3A38383A4043433D3B393A3D3D3A35383A3D3C3A383A3D
36353440453D3A3539383A3D3B37383D3E3C3B3C3C39383A383C3E3F403A373C3736393D
3C393B403C3E3C3836393B3B434043443F4145433C3D3F3F3C38393D3C3F41403C3A3C3F
3B3D3F3F41424443484A4E60778A8E7B796D8A798D6E736D6C6B665E5B686E6150434338
464652466354616B789FA5B2A5A2A0A3AEB8C0CACDBCA1A2899068554A3F453A48425968
879BA19D979594878C799C7DA8819877807A7C858A939A9B9D9A9996948F9E989B9FAEC2
CBD8D5C5B4A6908C7B6C7673968CAA91976754443F483D40483F414B7196A2978F755346
3C46363F39403C3B3C343C3A43403B3E3C3D3F42433C373D3B4647544549424B48464742
393A43453A3C3E3D3B3B3C3D4D44383B3C373D4043343F405A94C4CEA26D4A3A3E453C3C
3E3D3B3B3C3E44484A43383A3B373D40393A3B3B3B3C3F41413B413B39413C39433A3A37
3C41373B48485968677A50453E433E38393E3E383E45454244423D3B3C3B383A3E424442
3B3A3B404647433E3E3F4448453E3C3F3E3E3E3D3D3D3C3A3F3D3C3D3B393B3F5E4E4F4D
565F514F3F3B39433F3945474942413E4940424D443F413A3E3B403E3E3D3E3D3B3A3C3D
3C3D3E3D3A38383940393B3E3A383A39363A3A373A373639353E3F47595748444E415062
7292A6A6A29A96A18F747D6C676D647C9EAEAA8979766458474C4845444743434256565C
7A748E84997C8A76806E794457443F3F3B444144484852596C637472999BAFADAFBBB2A5
A8B9C5CCD3D0D0D6CECECCD7DDDBDFE0E4E3E0DEDACBC6C5BFBFC9D3D9DFDADBD8DADCDB
DAE0D7DDD4CBC7C0AB967D6B5D524E514E4C4250434C48575A658098A2A9B0B1C3CAD8D2
E5D8DAD9DFDBEBD9EAD4D8C8BCB1ACB0C4D4D9E7DFDED5EADBE6DEDEDDE9D7DFD3D8D6E0
CDAEA395BBB2C1A29C758382BDCBCA94835C4D494A484C4542353B3A42383E394042384D
6A79929DA68D4D4C7E7AB8C7CCDDEAE2ECE8E1CD
4C4C4A4949484747444444444445444446444344464747464544434242434444484A4546
4C4E4E4E4440404347484848454944404747444845434243454644434645424244444241
434445464543413F454A4B40434B4344413E3F434646464843434443423F3C3A3E404242
3F3E3D3C3D4143413F4041403B3B3D403E393B4041423F3E3C3C40424746433E3C3C3935
3C3B3A393A3B3C3D3B3D40403F3C3B3B3F3C3A393A3C3C3C3C3C3D3E3F40404149423C3B
3E4342413D3936373A3C3A383D3E3E3D3D3D40443C3735383F42413F383B3D3B37363738
3938343D423D3C373837393D3D3A3C403E3A3A3C3B393A3C3D3C383B3F3B34353D39383D
3F3B38383D3F3E3A383A3B3A403D42433C3D403C3F3D3E40403D3C3E4142413D3A383B3E
3939393A3A3F454B595C617076746F5D585A4F68506851594741403F485E64574B424346
464A4E5058565A677D9EA2AD9B9C948D88858E9FC9C6D1C8CDCCB58F9377717187849095
AEC7D5DADBDEE1D7CCC3CADAD9DED1BCBBB4B8C3CAD2DADBC9A49A71605B53564C607888
9BA2B1BFC9C0C1BFB2AEBAC4D1CCAEA2785640403F47393844433F3A3C50544C4B4A413B
3C3B3F39413845383B36423C443F414942443D3D4343536F787D767D655A434042423B37
3A3A3B423C3C3C3C3B3A3B3D443A313C444041403D4A597D8AD0CEB382673E444134473F
3C393A3C3D3E3F43423A3B3A3A3A373B3E3F3F3D3A383839413C423C38403B363A3A3B3C
434144609691A582775D423C39383A3A3A3D3C3A383F403F43433F3F3E3A3B3D41444343
3D3A3A3E4344403B3F3F4346423D3D423D3C3C3D3D3C3B3B3B3B3D3F3D3B3C4042403D3D
3E3F3E3C3B373C49443F4849474C4D444839373742463843333E3339393B3A373636383B
3737393B3B3A3B3E3E353A3F3A383D3C363B3A393938353A3A3E3C414A3F353D5C577380
9CCDCFC2A693646C4A464D4F4F758B9FA69E8C6453493A3F38444A58545B5D5141494243
464D44594650484142523C4A444D3D3D4257667A898D9AA5A5A89CBBBFE0D8D9D3D0C0AB
B1C4D3DADEE3DCE5DEE2E2E8E3E2DFE4E5E3D9CFC5BDBDC3C3C7D6DFD5D7D8DEDFD3D7D1
C5CAADAA8078636258504743454949484945545464627D8EB3B7CAD9D8DAE0DFDAE7D5E7
D1E1CCD8D2DACDD6C1CFC2C6B7B9C7D5E3E6DCE0DCD6DFDFDCD4D3D4DBD7D8D0DECFDEE2
D8C39A6A7CB8D3DEC1C88C7D82B5ADD0B39698A5B5B0B3A488715557454D4C564A566295
BFC8D4D1BE97774149456499B1DBD5E7C4D6B4AE
4D4B4A494949494847464647484949484746454546464747494746454647474740444041
4445484544424245494A4948464A4440484D4B4A45434243454645444747434042414042
44484A48464746433C4241393E45414041404144454344474141424241403F3F3E3E4345
4140403D383E413E3B3B3C3C39393A3C3C3B3D3F40434348464043444343403C3B3C3B37
3F3E3B39393A3B3D454544413E3D3D3E38373C3A3A3B37393B3C3D3D3D3E3F40433E3F3E
41433B383C3835373B3E3D3B3D424444423C393D3A37383F47484440383C3E3C3A3B3C3C
403F36373A393D393837383B3D3C3C3E3C38393C3A3A3C3C43403B3E44413B3B3D39383D
403F3B373B3E3F3B393A3A3939393D3E3B3A3B3A43403F4243403D3D42413E3B393A3C3E
3D3E3C403C41465059555157534C4D47443D423F444441403F3C3E3A3E4A494450423F42
3E4342474649535C8E98A0A39CA2978B7E6C707F8F898C898EA3ABA98F898AA2B9C7C2B3
B5C7D2DBE0DFDCCFCAAFBABCC7CBD4C4B4A8A5ADB6C3D3DBDFD4C2BDA29E6B534E597395
92AFC0C3C2BCC3C4C1C4C6D0AF9E655F4840434238403E3E4344433F41403D3C3D3F4041
3E35443B4E414A3241373E36403C454535464D565D5E6E808C78584F40433F463F413A39
43413C43413E3C3C3B39393B373A3B44423A434B5675B0A9DBCAC9A1856B63594F504C4C
483E3E3F413F3A3F453F413A383C383D3A3A3B3A3A3B3C3D423F403B373D3D393A3D3C40
464C73A9BBB3846D483D373C3D36393B393B3A3E393F3F3D40413E3D433E404041423C3E
46423E3C3E3F3E3C3F3F40403F3D3E423C3A3B3D3C3B3C3E3B3A3D3F3E3C3D403B403B3C
3D3D4441383B49544E45423E3E47473C3E38403C3D393C333E353C3E343A3B393A3B3A3C
3838393A3A3A3B3D3D36393D37363A3B393F3B3C393934393B3C3B3F454555728C929395
AEC7B48A735C4B453A47566F6E919F93755F553C413645425358797F967F6D544142393C
3D473446394A48434752425145553F4C6C89A3BCC8C5C9CCCDC6CCC3D6CDDBCDD4CFCAB9
BECAD5DBD6E1DAE5E0E8E3E6DEE0DAE0DDD7C8B7B9B7B6BCBCBECBCDD5C5BAB5B89C9982
656A595C424F454E46474A53668197A398A8A0C0A7C1BBD4D6D4DCE5E3E1E1DCDCD9E1D8
DAC9C9C3C9C0D5B4D2BAD5CBD0CED6DCE3E5DBDBD7DCCAE4C4DAC0CDD4DBD7E3D7DAD6E1
E4DAE3ABB2BDD2DBDFE1D5989F848EA3C0AEB1BACBC7D4CCBDBDB3C7ABB6B0C19EAAAECA
DEDCD9C8A3774341443A4E7FC5E0DFC29F6B6F59
4D4B49494A4B4A49454443444646464446464645444445464443434445454442484E4A4A
49474D48444344464A4B49464E4E4A454647464544444343444443434447454345423F42
47434042434343434A4B44434642404147474747433F3E4242414140404142433F3E4345
414143403F42423E3D3E3D3B3B3C3D3D3E3F3E3C39413F403D393E3A3C3D3C3A3C3F3F3C
3C3B3A393A3C3E3F3C3D3D3D3C3D3F413A3D484642403A3E3A3C3E3E3D3B3B3B3E373937
3B403B3C3C3D3D3E3E3E3D3D3E414142443C373A3B393C4449463D383A3D3E3C3C3F403F
3E413937383A3E3837373637393C3A373A363A3F3C3A3B3949484444453E3739393A3A3B
3E403E3A373A3B39383A3B3A373A3A393A39383B3E3C3D403F3B393A3E3C3B3A3B3B3B3B
35393A40393A3941443F3B424240453F40423B423540333F3B3D433D3C403F48493D4A45
4F4E514D5761586C7A8A7A85717668635E4D4E585B52485245534E5D4E5E567680B4C3C1
C4C3BEC8CFC9BFAF987B7F8D889EAAACAC9B92969CAABFCCCDCECAC0C6A4916D9A99CBC6
D2BFC79A8578685F65717A868F8157564D534C394238393D3E3F3E41403C3B4146443F3D
3D38414A6272736B605252485049514049403B4444444F4D47423F4948463F403E3F3A3B
403D393F403D3B3C3B3A3B3E3A3F3C3A3742698781999EC3BFBF968E6F6F6F8589869384
513E3A3E4343404B5C5B54463D3E3F3F403E3A383839393A403E3D3D393A403C3B3B3D53
5E678DA8A6895E463E2F433D42383D3C393C3C403F44423D3F3F3B3B3E393E3F40423D42
3E3D3D3D3E3F41423B3D3D3C3C3E3F3F3B3A3B3D3D3B3E43403D3D3F3D3A3B3E49453C3C
444B4C443F434C4E47403D3C3F434138383541393B3935353B39373C373E3E3B3E3F3C3D
3D3D3B39383939383B39393937373B3C393E393D3A3C363B42403F434B5A7896A9A78E81
89856F5C513C494B61647376737975614A43474140473A544D7A829488645240373C373D
333D5947765F8B7D97819360725C667B9FB8C7D2D4CED0D2C5CEC8D6CBD6D8D4D8D3DAD0
D4D4D4D6D7DCD7DFD8E2D3DBD8E0DAE1DAD2C1B0B6B2A9A6A3A8B7B6937966526250644F
51505F6375888D93898D97A8B8C3CBCFD2D5E5DBE0CCD1CDDBD8D9DBD9D7D8D9D7D5CBD7
BBC1B4B5C0CCC8DACDDCCDCCCBC3C3C4D0DDDAD8CDC3CEBAD6C1DBD3E4E4ECE5E7DFE2E1
E7E3DFE3D5D7D9E4DCDDDDE0C1CCC0C0AFA8A69898859697A7A1B8B0BBA9C1C8C7D4D3D7
D5CCC6B39D66615B52505CB3D2E1CBBC8D59423E
4D4B49494A4B4B4A4A494748494948464546464543424445454547494B4A46433D454344
41404945454444464A4B484544434444424143464444434342414140404748474A454043
51443D42484746494A483F474C41424746474A4B463F3E41494744413E3E3E3E403E4345
414246434644403C3D3F3D383E40413F41433F383E48413B36363E383C3D3B393B3E3E3B
3536383A3C3F42434042444442403E3E373D4C49423E363B3A3D40403D3937373C383F3F
41443938383D42413C38383A403E393B413E3A3E3D38373D413F3B393D3F3D39383A3936
343E3C3B3C3E40353A3A38373A3E3B3439353B413D3A3A36373B3D3F413B393F3B3F403C
3A3B3B373437383636393C3B383D39363938363C37383B3D3B36363A3A39393A3C3B3835
393D3D443A3A39413E3D3B3F3D3D433C3F3B46323E313B454240403B4045414F6661806C
7E6D705F6C6863555E55515D4748383C463D40484B394146524540444B6E648E84B8C0BC
AB98848F9FA09C9197709F8EB099C3B8B9A79B958E8D959B9B9D959D889B839D9DCBD7D2
D7D0B1A476745F54585E6B76A597B68CB99CB189845B4C4A484743483D43424045474545
3942415969979BB1B3ACB1A7A799A68E8A57363D3B3E4C403E3E4246423B3F4844413F3F
3E3D41473D39383B3D3D3F435C5C534E494D65758D69717A87666960605560767873736B
5B4037383C3C39484F5952494240453D403C3736373A3C3D3A3D3C423D3A423C3F3F5081
938B87685E4B4C4C3B3A3D41413A423F3B413F404045423E41413F40433C413E3D3C363D
393C40403E3C3A3A393C3C3A3B3F403D3C3B3C3E3D3C404745413E3E3C38393B44393334
465D616144494E48413E3D403B3B3D3B3C384437353A383A3A36323B3A403C36393A3839
3B3C3A37373B3D3A343637383A3E4347353B363C3B3F393F4F474242495A707F89796758
5F5D5B865F584863605E5F4A4B42413F3B3F413E4043434F625A4B4E4435403C363A363F
47787C9C91A4ACBAAAB38B93687B7CA8B6CDD5D8D4CCCCCDD0D4D7D7D3CACFC0D8D0DCD9
E1DDD8D6C6BFB9BAB4C4B3C8BCCAC5CEC3BBAD9E828784858181877C5A5760547270A29A
BAABC7B2D1CAC7BCB3ABAFC2D5DDE1E5D8E2DDE8D8DDCECECFD5DEE0DAD0CCCED2CAD0D8
CCCED3CFD5CCCDB8C1AFAE9F9C92929AB4D2D7D6C6D9C5E2D1E1E1E5E4E2DFDDDCE4E1DE
D5E3D5DDD6CDD7CDD9DAE6DADCE1DFD3CBC7B88F765160666C675F8085AEBDD2CBD9DEE0
DAD4D5CCC8C5CEC4B2717178A39FB2ADC391666C
4B4846474A4B4A4745454444444546464444444444454748484848494A4946444845464B
4D49444343424142454A4E504C504B43403C3E454041464B4943414241454745413F4347
433F3F4344413D3B3D46443E42443E3C3D3E3D3C404645404047433B3F4341403F404140
3B393F48444647433B373A403B3D3D3E41423E373C3B41413735383535383C3F3C37373A
393D3F3D3C4043423C3F3F3A383A3C3C38393D42423D3A3A383B3D3C39393C3F3C3C3C3A
393A3C3F3D413E3D3F3B384039393C3A4042363B38393D43423D3C3E3E3D3B3A393A3B3B
3E38373836393A353B3B3A3A3A3A3A3B3A3A3A3B3C3B3A3837363A40413D3B3D3C3C3F41
3D3635383E393C3D37373B393C3A3C40413C393A3A3B3F3E393C3F393B3B3A3938393C3E
4041413F3B39393A43433E37394040393B35383B3A3C3E37373A45413B4D48555D7B8683
7C696E5A585C55483D3943553F3C3E403E4144423F3B494A484E5A64868D9A98A3A09E92
877A706A697172685B5A69757182798F7A866E7575808C77766D866991839D8EA79CB8AD
C2AEBAB8C1BDB8B5A3A5A5AAA0B18B9B90A792AA8BA09BA681926C697F6F857C8B829174
6564545257637E99A3A0A39E8F8A8F91694D3E433A3F3D47434242555F66746E6A5C545B
576C5B664B3F3D394559626E71624C3D3B40413E42404042454542403E3D42494C484342
3E4041413F3F4244454746423C39393B3E3B3A3D404140403846414736424145424E7593
906F473C3C3B3C453E464643494542403C383A3F3C393D3E3B3E45444745403B3C3E3C36
353E45413C3B3C3C383D383B3B3943433441403E45413C443E3E30383D373F37423E3D48
5D6D6D6546423C3B3C3E3D3C3A3A3A393737393A3838393B3D3C3B393C3B3938383A3B3B
38373637393A3938373A343536353C3F353C37363E3A3B4B505F49363B3D424D4B404D3E
50628E90775D524D48463F3E3D3C3B3A393B3F413C3D404344423E3A3A3C39373939404F
7984A68D8C8198869F716B5654596D9EBAD0E0DFD7D3D2CEC7DBD9DBC6D5C3CFBCCBD9D6
CCCFC8B5A88686756A5E817494808D798F86846F75695F586C8A94A2A0B7A9BCB5CACFDD
CFE3E0E6DDE1D4C2ADA9BFD3DBE1DFE3E2E1E5D9E2CFDDD3DFD8DFDAD2D0CDD2D8D6D1E6
D5DED7DDBFC0A5958384706B798E9BAECCD9D6D9DAD8E0E1DAE0DCDAE2D9DECDD0C9CCB6
B4B8BFC7C6C4B9C9B3CDC3E0D2DEDCD9CCCABFB29087ADB9B8A1929296A4B2B5B9B8D2DB
DAD7DAC2CBCADCDFC0907782A7C3A8AFA5C6BAB9
4A4847484B4B494647474746464748484746464748494949424243454747464449454345
454444464343434344484C4F524E46444A4A45444847494A484342444141414141424344
46413F42454442433C3E3C3F4545454C40403F3F424543404047443E4145413F38393C3F
3F3B3A3C414142413F3E3F403C3D3D3C3D3F3D38393A3E3F3A393A3A3B3C3F42403C3C3F
373B3E3C3B3D3E3C3B3D3D3A393D40403B3A3B3F403C3A3B3A3B3D3C3A3A3C3F3C3C3C3B
3B3C3E40443E393C403F3C403C3C3E3A3E40373C383A3D3F3D3937373536383A3B3D3D3D
3E38393C3B3C3D393C3C3D3C3B3B3C3D393D41403C39393B37393D403D393A3E40414242
3F3D3E413D3E41413D3D3F3E3736373939383839423E3F3E3D41423A3A3A3A39393A3D3F
3E3E3E3D3C3B3B3B3C3E3C393C444541413B3838383C3F3D3D3B403F3D4D414648535652
53474E4244454241433E3C4139394148494B4D49494A525C57636470737D757665736D71
59534E4743494E4A42434846424B414644574B585E676856495E587D77AAA8B8939C7C92
7DAA9FC1CDDAD6BD978D765F4E50514D564C4F545A6B877F6C69606D758F81AD80A58C9F
87AC9AA3815E5B51544C4E534F4B4945424049534C524B4D3E5277A2B7C1CFD4BDB9AEBE
B0B792965E4D41393B4340443E4446413E4044453D3B3A3C40413E3B3B3C4044423D3B3D
3D3E3E3D3C3C3D3E3D3F403E3A393B3D34373B3C3B3A3A3C38413F3F465A4E604B4F5E6E
674F44453535363A363B3D3F3C3B3B3E3E3C3D413A383B3C37393E3D3D3D3B3A3C41413E
393E42403E3F403E3638353D43454D4A3E3C404B4D3E373D353F3E443F404E424242454B
565B544B3F3C393A3C3E3D3B3B3B3B3938383B3D37393B3B393737383335383B3D3C3A39
45423D3A393A3C3D333A37393A363B3C2E3F454549484549424F40353C3D3D3E323C3B58
5A878987695248413D3E3A393738383B3F3F3C3A383A3D3E3E3D3C3C383735363A3E4550
5455515446464145524B3F4E4F8197BECED3D6D5D1CFCECEC0C9C8BED0AEC6A5A9A5B5A4
AA8879594B464A514A4C5C585E5E5B7D769F9298879499A4B4C1CCD1D8D5DBC9E2D4EBE3
E7EEEAE6E8DEE3D5CACAD8E5E9E7E1E1DFE8D9EADAE4DBDCDAD3CEBCADA6A5B2B9BBD5CF
DED1D8C8C6C8C0AAA7A2A8ACB7C0C6CED9DDD8D3D2C5C5C4BCBDB9BBA9B29FA7A1B29D9C
99A2BFC1D1C2C3C2BCC4D0CBD9CED9CCCCCECAD0C4BAC9C4B2A8A7B1BDC9D1D2C9C2CFCF
D0D3DDCFC3C0CDD7D5C6B1AFCCD4CDBCABA9BCC6
4A49484A4C4B474444434343434343444442424346474544414142444647464447454343
414042464444444443454A4E514C43444F51494447454443413F40434542404246494845
4C47444647444140423D3E474C4545504E47413F3E3D3C3C414644404446423D423D3B3D
3F3D3C3C41403F4042433F3B3C3E3D3A3A3C3C39373A3B3C3E3E3C3E42404142413D3B3D
3A3E403F3E3E3D3B3D3E3D3A3A3D40413E3A393B3D3C3B3C3C3C3C3C3C3C3D3E3E3C3B3B
3C3D3E3F67503F3B3B3B3C3D3E3E403B3C3C373C383D404040403F3D3C3E3F40403E3A39
403A3B3F3C393A383D3E3F3F3D3D3E3F3B3F43423E3B3A3C393C3F3E3835383E4546443E
39393B3C3C44443D3A3937363A3B3A38393C3E3E47403B3B3D43423A393A3A39393B3E41
403F3D3C3C3A39373D41403C3D41423F4A463D393A3A393A413E40413F4A3B3C44495454
55464239403D3A3D44423F433D414E595B5D5D584D4853495448484A4A4B4A44474B4F4B
4C4B4B4742434543443D433A423A45493C4C444C4A49484C54496C5EA59CC0ABAE8A8C6E
8D9DC4BBB6C2C3B7A2987C5A5B666F8A73725851574E5B41434640453F45494F4B494B58
5B75A098B08C968276635755514E5053718093979094877E7588B1CCD0CED1DBD1BDB693
997566554F453E38353E44516A7679695549423E423F3C3C3F403C373C3E403F39333438
3F3E3C3B3B3B3A3938393B3A38383B3D3B3C3B3B3C3F3E3C3F3E3E41637658693F42424F
4A37373844443F3C3D3C3C403B3A3B3E3F3D3C3C3C3A3D3D3A3B3E3D3B3C3C3A3B3E3E3C
3B3C3C3C3D3F3E3C3E3F3C3F3F3D403E443C404A473F3D3E403B394747495A514F4D4943
413F3B353A39393B3E3F3E3C3C3C3C3B3A3A3D3F3D4042403B383A3D3B3D4042413E3B39
403E3A373536393B383E3D3D353440424E504D474444413D3B413A393934383C48476A55
7E69785C645149413C403D3B3A3F3D3D423D36363537393937373A3D433B373B4042423F
3F374C453D41584B565A797EB1ACD0CDCDBFB0AAADB2B8BDA1AA8BAE89A585785C58534E
493F414A4E638A84A393B5B8C3AAC5AAC3ACC3B3C0C3D8D2D8E5DCECE3EACEE5C9E6DAE0
E0E7DAE6DEDEE1E1E0E3E3E7E8E4E3E3E4D7E8D0F1D0E4D1CBB5957C776F6063779897BB
A5D3C1C1BCCABFCCBACECADCE0DEDDD8CEC5BAADAD929C8492798380909E9F9EB0B5B4BB
C3CFCEDAC9CFC9C8BBBCB0AB99A6989C9AA9B5CFDAD2CFC2C1BEBCC2CFD6D9DEDDD8DDD7
D9D6DBD2DCD6D4CFD2D7CAC1C3C6BAC5A89E9CAD
4B4A494A4B4A47454949484848484849494847494C4D4B48474646474848474543454848
45424143444546444243474B4B4B4644494945464A4947454546484B46434143474A4946
494646494A453F3C434147555952525A5A504642403D3F43424443414244413C48423E3D
3D3C3D40404142424444403B3C3E3E3B3A3C3C3A393D3A3A403F3B3E403C3B3D3D3B393A
363839393938373643423F3C3A3B3D3D403A373A3C3C3B3B3E3C3B3B3D3E3D3D3F3D3B3A
3C3C3C3B614A3F413F3D3D3A3C3E403D3A383639343A3D3B3B3E3E3C3B3F3F4043403C3D
3F383A3D393638393D3F40403E3D3E3F3F3E3D3E403F3D3A3B3C3D3B3736393E4648443B
363739393946443C3D3E3D3E3E403E3734373836453E3836393D3D38393A3A3A3A3C3F42
3C3A393A3D3E3C3A3F43433E3C3D3C3A3E403B3B42413C3E423D39373343424D6C6F7E71
6853443D3B3E3E3E3E393D4B4F4F5558514A433A41453F4B464F3C474340463C4B46493F
4D48433F3E3F403E3D3C2A55454A37434A5B606D6C6A7192A2ABA0A69BAAB1B99EB08191
76AC8CA18E9099A59A87807AA899B393A08AA49AB3B1A68163624F4B5144514D5E4D5651
6C6E74747D929FAEA19DA2ABA79A979DC7D0DBD6D3D7CBC0C4C8DBD3C0AD9493937F6947
4A3F463C444440413B444D5E717772604F47413A3C3A393A4045433E383A3B3B38383B3F
43403D3C3D3E3C3A3A3B3B3A39383A3C35393A3A3C3F3D3740404345545647594F473F46
48414242534E41383E3D383A3E3E3E40413F3C393A3A3C3D3D3E3F3F3D3E3E3C3A393938
3F3F3E3D3C3C3C3B3B4042403B383D4148433F3E404442393F3B496C705A524C48453F38
373B3D3C3D3C3C3E40403E3D3B3D3E3E3D3C3D3E3A3B3C3A37363738434242403E3D3D3D
3A3C3D3D3B393839433A383C3B4D6967634C3D3A3A3D3E3A3A39373B363347585C6E6E77
6366575B4F44423B383E3B373A413E3B3F3C393F383837363738393B3A363739393A3B37
4C6066856F767AA385A198CEC0D3B8B79285756F71757572765B704A5B4E493C40443C48
45505A7990B8C2CEC3CACEDDD6D5CEDCBFD5D0D1BDCBC8D2DBDAE4E5E5DEE3DCDFDCEAE5
E4DFE9DCEBD6E3DCDAE2DCDDDDD7D8D4CFC9AEB6A1AA999A797258454846485D7081A29B
BAC3DACDD1CAD4C7DCD0DFDDE3D9CEBFAFA2978D9189889292A1A4B3C3CCC9CBCDD1CED4
D3CDC5B9A8908D7B81707E59645E66697894ADCDE1DFDDDAD7D6CDC8CDCDCCD2D5D4D8D3
D6CCC9C1CBD2D8CDCBD2CCC7BCA99A95A48C98AA
4C4B4A494949484744444342424242424442414447484542494847484949474643484C4B
474443434445464441414548494C48444441414643424140404243434040404041414343
423F414648464240393A4148494546484C454040403F4145434242403F41403C3F3E3F3F
3C3A3D4342484A48464645413B3F403E3D3E3D3A3D403B3A403E393B3A3635383B3B3B3C
393838393A3A3A3B45423F3C3B3A3B3C403B383A3D3C3A3A3E3C3A3A3C3D3C3B3F3C3A3A
3A3A38364538383E3D3B3C3A393C3F3F393536363A3E3F3B393B3A37373B39383D3C393D
3F38383B37373C3D3B3D3F3F3E3D3D3D3E3B393A3D3F3E3C3D3B3937383B3C3C3B3E3D36
33363939414A453939393738363A3C393A3F4242403D39363737383B3A3B3A3A3A3B3E41
3E3B393A3C3D3B38393D3F3D3B3C3D3D393D3A3B43423C3E3B3E434E5262646E6763664B
423C37363640484A44393C4C413F4446413E3C363F384034463A3839454B43493D484448
4646444343424143404146464F4A71848299A9B8B7B4B0C9C7B2B68BA981977E8C7F8E70
706A735B5952566A6B6275858E9D939D749487979AB8C8BFA6A1A2A68E8A9CA2B5B0BBB7
CCC8D4B6CB9FCCC2D2D1D6DEDCD4D8E5E6E4E8E2E3E4DEDDD7D4DECDBEAD85755B4C4D42
4A3E483E43443C413A403D3F4044413A393F403C41403C393B3E3A343D3C3A38393A3C3C
423E3B3C3E403E3B3D3D3D3C3B3B3C3D3841433C3B434B4C68504861777C7A7164565154
5F6E778287724D393A3D383A3A3A3B3D4042403E383939393B3B3A3B3A3B3C3D3D3B3B3B
444545433E3A3B3D3C3F43413D3E444B4A46414042403D3E455B728579533D3D3C3C3B3C
4044413C403F3E3E3E3D3C3A3A3C3F403F3D3C3C413E3D3D3F403F3D3B3B3A3937393C3F
3C3E40403C37343342363D5052637259523D34373A3E3E35363736393A45627268646857
553D43473A343A38363C39363A3D39363B3A373A3E3B38383B3C3A37363A3C383337424B
6B6D9B7772618F7D8B91AD9ABB8E8664615C50444347443C404444433A473843414A606E
8E92A4B2C0CFE4CFE4CBDACCDED5E1C8CCBFD4C5CAC6D9D4DBE6D7E5DADDD7EDD6E8D9DB
DEDCD7D2C6CBC0C2B5BDBABBB5A69F938F7B7D636D52534945493E466778849AAAC4C5DA
CBE2D5D9DBD8C5D4C8DCD3D9E1D9C9BFBCBABABCC7C9D8D0D2C7C1C0C5B6B59EB69D9C90
91847E7D766261536C617A6476727E879EB9CADAE5E2E4E9DADEDAD5D8D4CFD1CDCCCFCA
D1C8C7C4B3BCC8C4C6D3D6DACDBCA5939E92B0CD
4C4B4A49494949494A49484747474747484747484B4B4A484544444446474646474B4D49
4545454644454543414143464B4C47434543414449494745454645423F41434240404346
46413E414342414242434645404143423F3F414343403E3E434142413D3E3F3C3C3D3F3E
3B3C45504E54554D4644423F3B3E3F3D3E403E3B40403D3B3E3C39393E3A383A3C3A393A
403E3D3F41414243403C3B3C3D3C3C3E403B393C3D3B3A3A3D3B39393B3B3B3A3D3C3A3A
393837353D393A3B3937393A373B3D403A3539353E40403E3C3C3C3B3B3F39353B3A383F
46403E3C37393D3A3B3B3C3D3D3D3C3A38393B3B3A3B3D3F3C3A38373A3E3E3B3D3F3E3A
37393C3E3B403C3535393A3A404343403D3D3F3F3D3E3C3A3936373E3C3C3B3A393A3C3E
3C3A383A3D3E3C3A383A3C3C3B3C3D3E403F3B3A3E3D3A39333D4A60626355514B464835
393E3F3E3B3F444A493F3E4A3E3B3D3F3C3D403D3C3C38423D493D483D3D3B3E3E434242
383D404041404650545A6B5F8F96B59E99ACB3BAB7B4A2A192927D6C5648525449514B41
4A52494F4C586A828A7D7F717062684A5D626C6A7F87918E8B7680807C9699C2C0DDC9CC
B7B2A7A89EA7BED1C5C8CEDADFD9D9E2EAE1E2DCDED5D0D8E2DEE3D9DBDEC7C2BFA09B7C
764B48433C44394039433E393D3E3E3C3C3E3D3A41423F3B3C3F3E383E3C3937383B3A38
3E3B38393C3E3C3A3C3C3D3D3E3F404145443C384B6F8A9392696292AFB49C7C777B8D97
9FA6A2A7826D4A423F483D3937393A3A3C3F3F3D3E3F3C3B3D3C393A3A3A3B3F403E3D3D
404244433D373739423E3F3C3D4241444442444740374A6D83968C6C5340373B3E3F3F40
44453F363E3E3D3C3B393837393C3E3F3D3B3A393A3735373C3E3B38393B3C3B39383A3C
3B3C3C3B393838383B41576A646464483E3A3B3B3A3E3D32363E39373F54686656434339
44353D393C363E3E3A3C3939393736393C3C3833413D3A3A3D3E3B37363B3838434D565F
6D635546454A5C6D6C79667E68714A4C4E4E4438373F423D413D483941504C62728DA9B6
AEA2A1ADC2D7D0DCCED4C7C1B4C1A9C3A5CAC3CDC8D5D6E0E2D8D6D5D5C7D7CDDFCBC5B2
B2A4A48A90858884908A868273645B4D403A3F40423F3C413F4A507AB8D0D1D3D1DADDDC
D3CAC3C7C0B9CABFD7CFE1D9DDD7CFCDD3D3D1D3C7CDBFBA9C9F888E76785B6961694D57
554F4762637478838E8C8A9A93A3A2B7C1CED3D5D9D8D8DDD7DCDCDBDEDEDDDCDEDADDD9
E0D9DAD9CFC8C6C1C7D2D4D8D7DBC8C7AAADBAD1
4A4A4A4A4A4A4949464645444343434344434343454546464544434344454443474A4A46
4243444444444342424243444648444246454245434443404042403C4243444444454749
4D464142424140413B3A3E403B3E4444424549494846423E424145453E3D3F3C3F3E3E3D
3B3E4A565155534941403E3A3C3C3B3A3D403F3C3F3C3C3D3B3B3C39403D3B3D3D3A393A
3D3A3A3E403F3E3F3A37373B3E3D3D3F413D3B3C3C3A3A3C3C3A3938393939383A3B3B3B
39383838343A3D3E403F3C3C383B3B403A373D383A3A3A3A3937383B3C4039363D3E3D46
4542403B373D3E373C3B3B3C3E3E3B3937393B3C3C3B3B3B393B3B393B3E3E3B46444442
403F44494643403D3A3B3C393A3B3B3B3836383C3B3D3B3B3D38373E3E3E3C3A3838393B
353535393E4142423D3D3D3C3B3B3B3C3D39383A3C40413E484E4F594F483B3A3C3A413A
3F3B3B39413A343A413B38403C383A3B383A3D3B3D34403A403D42464039403A4C414236
424545464B505B6C7D9A86967CAAA4AA95948889807A695F4A48383E4341463D40414653
465E6471717E878D89726F586F5A4F50576A5A59524C464B463F434C4F5D8082A29C9A7A
88768D869CA6A7A8A9A49C9EA9B2BECECBBBBBBCCCC8C8D5E2DEDED3CFCCC6D4CFD7CFD8
B9A772785E706A746C786D5F49433E3E3F3E3C3B4648453E3C3E3D3836393A393A3E403F
3C3A38383A3B3A393B3B3B3C3E3F41424243465A86B2BFB4856A759093957986AFBDD1D9
D1BB9F8F8A83717C6E7255463A3E3E3C3B3C3C3943443F3D403F3C3E3E3B3D4143413D3D
3D3D4043423D39393E383B393C423F42403E42423D4B7295ACA28058443F3D3F3C3D3C3C
3F43423E3A3B3D3D3D3B39373B3C3D3C3A3838383B3B3B3D3F403E3C3B3D3F3D3A38393B
3C3B3A3B3C3F40413F4F544F443B3C3635373A3A3B40423D38413B38414B5149453C373E
394240383F373C3C3636363C4241494B4341423D3E3D3C3B3A3A3B3C31404550686B5D59
4433433346506A4E4D4B544B634746423B3D3C3A3C403E3A3E3042416A8294A0819599A3
787B83A3B9BFBEADB5A6AEA9C6B8B9A5C0ACC8C6D2CDD8D3D0C5A7A89C9D849F869C7278
60615569686E6F7277605C574845433C433D48464C4C56656E889BBBD9DAD9DEDEDFD5CD
BBAFA8B3B4BEC9D6D5DFDDD6D9CEC8C8C4BCB2A9988C907176564F49504F484B4F4A454E
5C596A6B8485949C9785858BA399B1BAC5CBCFD1D8DDDBD9D7D7D8D7D7DDE1DFE4DCE0DD
E2DCE1DFE2DCDAD3D3D6CECDD4DBD8D0C2B8C1C4
47494B4C4C4B4949494847464545454546454545454648494A4845444443424044484945
4243423F44434242424243433D434342454342464344424042454440403F3F4144464747
4A454345474543423D3A41453F3C4040393E403E3E41403C41414749403D3F3C3A3A3C3E
3D3D42494649473F3C40403B3C3B38373B40403C3D393C3D393B3F3B3736383C3E3E3F41
3D3A3B4042403D3E3936363B3E3D3C3D423E3C3C3B393B3E3A3A393837373838383A3C3C
3A3A3A3C39403A34393D3C3E3A3C3A403B38413B43403E3E3B36363A42463C353937333B
39393A363742443A3D3B3A3C3F403C383A38393C40403A34373C3F3C3A3C3D3B39363638
38394049433B3C3E3A3B3C373B393A3B39363940393A38393E39353B3F3F3D3A37363839
413F3D3C3B3A38363E3D3C3C3C3C3D3E3E383B3F3D40413A333C3E4539393D493C3A413D
3C323B43493D3339423D373C3A37393B393B3E3C40393F403639393D383B3A433F443C3D
3E464E5B6867636787727764857582737A69555D52484141453F4239574159475A5C536A
5F75687B7667595F696071678A5F6A485B42463F414A435F475D495965687A7375848B69
6672799EA9B7A88E8C8B80787671707788737482ADBECBDADBDADAC7A6806E80798E8783
899B849E96AEACC1C0C7AA885E4C3C393C3B3A3A3B40403A383E3F3B404647403A383938
3D3B3A3A3A3B3A3A3B3A3A3B3C3D3E3F4A6284ACD2DCB98B78545C697CA496D5DCE1DBD5
C4A78D757E745E69525D483F3B4042403E3F3E3B3F403B393E3E3C3F3D3A3B4246444140
413F424A4E4A4441413E45403D403C4244403D384574958F96765A4C443B373E3C3F3F3D
3C3D3D3B373A3E41413F3D3B3C3C3B393736373837393B3C3C3B3B3B3537393736363A3E
383736373839393746584C4146403D403C37353B403F3E3E353C373B403A3A3B35344437
363441323D32373935373D4863636D6344383E3D3A3C3D3A36363B4045677A8690785245
4A4642504A544A41515D47403D4039373E3A38393A3A38363E4A41718F8693686E626366
5F617789878D7C8397ACBAC7C2BD99AEA4AFACC2C4B39E928E806B63635651444E484045
464C4568706267605A3D41433A40444241486A77888C99ABBECDCEDCE6DDDDE0D4DAD2D3
C7C6C5D7D3D3E0D6D9D0CFBBA9948E8E84817E72837384708C6B69637F71777B827C8482
919DA5A7A8B3AEBDA1987CAAABB8BDCAD4D7DDDFE1E3DBD2D6D4D7D8D5DBDFD9DCCFD0CE
D3D3E0E1E2E4E8DCD4D5D4D8C7DCC6D4BECABDCB
4D464D524E464A4B4343484F4B44454C434C464843424440444A4A444348484244424347
464241433E43474744403E3F3E4444454946424446414043474644444341424546454342
43474B49433E3F4140414149443C413D3F434C47403D3B423D3E453F41483F3A3A3D3F41
414141423B3F43423E3C3F42453E3A3A3B3A3B3E3E403F3D3F43403A3A3C383C3C3A3F3C
373E453F414337393640353B3C4443433C4043403A383C423B3D3C38373A3B393F3D3C3D
404143433B3E383D3E3B3F39413F3C3A3B3B3A39373B3A353234383A3A3F3E3C413F3C3E
3A3D383A3A3A403C3B34333D413D3D3C3C3D35403C3D3B3A3C3F413D38373A3D38393945
50443A453A4246413B3B3F423A3A393C383945443A3D483F383C383F3C3A39383A3B3C3C
3C3B3B3A3B3D3F4141403F3F40403F3E35383C3F3F3E3B393A42453F3B3E403B3A3C3E3E
3C3A3A3B3D403A38393B413B363A3F42413E3C3B423E3E3C36383D3C3C3940423E44483D
50585B65625657554E495A5B5A5A515E42413F3E3E3E3F40473C405C77818180735E5B59
595F59564F3D49666B666869555B4A434944454D5A646C77736A6A5E5E5C5E677F9CA08C
737E77838A7A7666615E5C554C556569805E6E5A98B1CCC8D7D7DECFAD9C8B6A6746434A
4B49514A5D647873A6BAC7AA93754A3A433C403C453B373D394D4241373B40413C393A3D
43393A3B403F423D3E423747354C52609EB6CCE5E4CAA4919090A7A6CACCE1DBE2DED7CC
A47761534846463F403F373B373C413C3A443E3A353F3E3D3D393A40393C433744424653
556A7E84724646403C403E403D393B4D443D465C809C8993544C4B42393736403A3B3E3F
3F3D3C3B36363C4445403A383C38383B3A37383D3D393F433C3A3F423B3A3A3B3B3A3B3A
383E41393A3D415255584D3F3B38373B383A3B3A3837383A393D38343A3C393A3937373C
36372F433A3935384B616A897F705A49403D3A383A3B38393C3C465A737D8487685F4750
6A6355525D6465696B463B3F3839413A373C3439483F3646605D8C928D7B63675F5D434A
484B5F6F5A647195B5C0BBA8A793A09DAFA38E84816355554A4343403D3C3E423D404140
3B44445041483C41393C4968656A6B79648EA8BCC5C5CCD9DEDDE4E2EAE5E6E2DCE1D6E4
D6DADCE6D7DED5BCAC8C7C7C5764585A5A5973878F99959DA08F7F93939A8FA6BAC4C8D2
D2D5D3C9D0C4CABBA98E9090A59BB0C2DCD6E1E3DDDCDBDFD0D7D4E0CEDECDD6C9C5AEB9
BCD5CED7D7DBDFD8D8D7D1DCDFD1D5CCD7C7CFD0
4A4949564C504D5046474C504E494A504B4C4E4549434B46434546454545444143464643
4245444144424244474744413F434344484643453F40444A4A4643434344424143454440
404242413F4041444343424A464046423B3D46423D3E3C423D3F4641434A433F3D3E4040
3E3E3E3F4442403D3B3B3B3C433F3C3D3C3B3B3E3D3E3E3D3C3C3B38393A36393B3A3E3C
373B413E43463E4237433B424245403D414141403D3C3C3E393B3C3A3A3E3F3D3D3B393A
3B3C3D3D373A363C3F3E423E3A3B3C3E403F3B3835393B3A3A3D3E3D363635393E3A363B
363C39393A3C423D3E3A393E3E3A3C42383F343C3B3C3C443B3B3B3E3F3E3D3D3B3C4356
5F4A3943393D3F3D3C3D3E3D3A3C3B3E3937413E393A413E3B3C3B40403D3A393A3D3E3F
403E3C3A3A3A3C3D3C3B393A3C3D3E3E37393B3D3E3D3C3B3940423D3939393636383A3B
3B3B3D3F3B3A363E413F45463D3D3C3B3A3A3B3C36353A3C37383C3A3B383D3E3B475452
51535354514B4E50574A4F4A4848404B41403F3E3E3E3D3D454246566A77777361504E4B
4A4C46453F38414E515659534D4853716B4E5C7F7A7C79786A5A544647454B566473766D
53614A5A494F464A465463625E6E8DA4A59A89969CBEABAEB2BAC6C7C1C5C3B2AB807C60
6752695D6F849A7E8789A39F9A957957453A423F403A4843433D3F413A3F434443404043
41463D3E3B443E3E393F48485D84ADB8D4DDDDEEE2DEC2C3C1D0D2DDD5DED7DBCFC2AC96
71524A434644423A3C3F3D47433D413A3E403D3B404039393F414043404F414F58707A9C
7B8E807746393E4E3D3B403B3F333B443D668495BC9F89674F4645403E3F3D443F3E3C3C
3C3D3D3D3B3B3E43433F3D3E383A3E403D39393B3832383C3C403D383A373837353A4040
4744433B3B40414B474C484142403B3B37373838393B3D3F3C403B363A3C39383737393D
393E353B3B3844536C7E8186584F423A383A3B3B353838383C41546E726A5F56444A4858
5D606471828070654D37353C37373B36313C39343A41587DAD9A9F8A76635A604C4E3C3F
36406282868E97ACB4A9A095A1A1A1A38E7A5454423A3C413D373A403D383E41413B4540
3B40373E3D444F5468738B9DA4A5A7A3ACBECDD0DCD8E3E0DFDDE5DFE5E4E6E9D6DED6E0
DBDFD5CCBCA6855E5E4E4B4B414757597B738C858A897D7A6D72656A5B727998B4C1C5CE
CCD0C6C6B6ACA8A6989F90B39BB9B7D8DCD6DEDCD6D6D5D7D1CCD6D0D6D1D0D0D4C1BDAB
C7C2C6BFC0C5CCCDCECBC5C7BDC5B5CCB0C4BFD7
7F6C645861616D6B75736F6A656263666A6E696756554441454343464645464842454542
4245454247433F414547444144464544454341423E40464B4A4542434545423D3E43423C
49474243434644444C474244403D433F4340433D3A3D3E453D3E423D3D413B3842434342
3F3E3D3E3E3D3C3F42413C3741403F3F3E3B3C3E3B3C3D3F3D3B3C3E3E40393A3C3A3C38
3B393B393B3A35393C43383A3B3B3A393F3D3C3E4243423F393B3C3C3D40403E3F3E3C3A
3B3D3C3B373A383D3F3F42403D3B3938393C3D3E35363534353838353C38373E433C393E
35403C39393B413C4147463B39403F3A38433841433F3941423A35393D3C3836393B383A
413B353C383938383C3F3C37393D3D3F3A363C383A3E3D403F3C4243403D3937383B3E40
413F3C3A393A3B3C43403D3B3B3C3C3B3A3A3B3C3C3D3D3D3F4343403D39373738393939
3838393B3E3B363C3F3B41433B393737393C3F403A3B3F413C3B3E3E494548463F454F4D
4C4B4A423E414145483A3C3A3E433E463D3D3C3D3F403E3C474843404651534C4E454643
40403C3C3A3C413D3B484D4043516F86735F72826664605F564E4D434842444B4B464340
3C4542423D3E414B516C7F7B6D6A7A8E91918990938D746E6C7274747D8E97949D9788A6
8AA89D9F96B6D8C4C1B9CBC9C7B1A387917B7F6A86777E636452564B4951524F4E453B3A
3F4240373B454A425E7E87AEA6DBD9DFE2DBE1D5D2C7C6D5CFCBD9BDDAC0C9BCCEC3AF9E
897E848181715A413B3D3C474135403345393B383C3D3D3C3F3E393A445BA298BC8E9F6F
64584A424541403C47433C433840444F7DB2C1DBC2A65A47433A39373A3E3A3D413F3C3C
3D3D3C3B36383B3E3C38383A383E42403D3C3C3C433A3D3B3D453F3C3D3C3C3A383D403A
594D4A44444B4B4D3C3D38363A3D3A393C3B39393A3C3D3E40413D393B3A373739383837
353D35323E497A83897161443E3C3B3B3C3B39363A3A393A3D435367514945403D3F3B40
4449515E696453473B35383D3A383A38393D3A3742597A989F948E81736465644D4A3F43
41587FA49B9DA4B8BEB2ACA8A79994796D473E3E3A3836383C3C3F453D3838433A383F36
38404B5472708E8898B1BDCCB6C5C3C4BFD0D1DFD5E0DED9D9DBE6E1E1DDD8D7DEE4DAD8
D0C7AF9264604D3F434D5C708E939FA8AFA5947A665B574C444B433F3F525266859BA4B2
C5BEC8B2B794A6A5BDB9D2BCD4B9CFC9D3D1D6D1CAC9C1BDBBBBB0C7B9D2C2D0D1CAA4B4
98B48B908889898D8C87847C857B80717B6F838C
A09B84918BABADB8B0ACA49A92909090998C916D6C544F4447464342424447494C4D545B
5B534C4A4342403F3F3E3E3D4444444343434243444242454542424442413E3C4044443F
44423C43454C47454542444947474843423E403C3C403E424042433F3E403D3A45464746
44413F3F3D3D3E4246453F394141413F3D3C3D3F403C3A3C3A353335383D37383D3B3B37
3D39393B3C3A393D44483C3C3D3C3D3D46423F3E3F3E3C383C3D3D3D3E3E3D3B3F3F3C3A
3B3D3D3B3B3C3C3D3E3D3E3C3C3B3A3A3A3A39393B3935343A4144423C39393D403C393A
3945403837383D39404948393B463F363F4439434649494E584B3F3E3E3B38393F443F39
3D403F40383938373A3D3A34373C3C3E3B363B3939453E3E3A3845423D3A363536393C3D
3C3B39393A3D3F3F44423F3D3C3B39383C3B3B3A3B3C3D3E434542403E3A383C3C3B3A38
363636373C3E363636363B373C3B3A3B3C3C3B393A393B3C39383D43655D585147464845
44424439363C383A3F373B3C3E40393D3A3A3A3A3E41413E3F413E3A3E47474040404241
3E3D3C3D3D40433B3740463C4C697C745D5C63504642414342434540463E3E4649454242
495468676E68656B7D8B8A796B626774747978717550443F4244454750606966898BA6B7
C5C7C6B0A0AFBEB3B9BBC6C0BEA59D958B70767E9DC2C1D19CB8A7B19CA9ADADAA957768
4A424E44536D999CBAB8DBCFDFC8CEBFC2C9CDD4B2B8AAC9C7CFA6BDA4C29EA5908C8077
6E6E7772837159423C3C353A3F423E413A42373F404247413D40455079C7C0CE919B5A46
423C433D46373D4548343C334C56818BBDC4E2C0B15F433F403A3B383B3E3A3B403E3E3F
403F3A36353B41423F3A393A3D403F3B3B3E3F3D3D38424141443C404045433F454C4E4E
46393A37363F403E413D37363B3E3D3B3E3C3A3A3C3D3D3C3F3F3D3B3A393737303A3E3D
3B3D3C42597784A0686840353D3E3F3F3E3B38373F3B383B40414347403B3E3A3E393734
3C3E3E3E3D3A38383C3D3D3B3B3A3A3A3B3A3A4050637072787B75756A565044433B333F
4D6C81979B9EA8B6B7A59489746A5A564340434E404042474C4E4B463C3D353D2C37443C
527371A197B9BCC8C7BCC4BAC0BAC1B2C3CBD2C2C6B9C9C2CECFCAC3BFB8B6B0BAB5A598
887059434549425B7298A4B6BEC0C9CDB39669474A3B423B413C3B4149708796AAB6BECE
D7DCD4DCC5C7C4D3CCD9CBDBC1C9B8BABBBDC4BFB9B6A8A0A38DA390B7A8BEBCBAA09D7B
836C60515A534B4E4A484D424742444448444A4E
D6D6DAD5DDDBDFDDE0D7C5AE998B817D817B7265555647474D5457585F6B706F7E81868A
806C5A51474747484746454440404142434547474A433F404241404142404043484B4A49
47443C43424C47474C474847454746423D3B404041433C3C3B3E3D3D3E40434141444747
4542403F4B4945413E3D3D3E4141403D3B3B3D3F4C45424446423F403E48414145413E39
3F3B393C3B37383A49483C383D3A414343413F3C3B3A3A3B3D3B3B3C3E3D3B39393A3835
373B3B383D3D3E3D3C3B393A3F3E3C3B3A3B3D3E47443F3B3D42423E3A3B3C3A3B3F3E39
3C483F3737373C3B4040413A3D3F39423B41445651555A5B574E46413D38383B383A3A3C
3F3B383B393C3C39393A3936353B3A3C3C383D3D41544B443B3A4D473B393737393A3A3A
3A3837393C4041413A39393A3A3A38373D3C3B3A3A3B3D3E40413D393B39373E3B3A3837
373838383539363B3D3A3C373536383C404241403536383C3E3E434B584C423C393C3F3E
3F3D3F36353C3738413E413E3B3A373C3C3D3B393B40403D37383B40474A453F393E3F3E
3C393A3B3C3A3D3E3B3C41425A66665C4C444235413C3D3E3D40413D43403C3C3F3E3E3F
5064728B86947C858B89766056515158515C494F433A3B504950647785969D939EA39CB2
A0B39C8D6D6B66585B636F7069574556494F506CB0BFD6C9D2CDD5C0D0D8DADDE1D6BCAB
9B98859F92C5CED9BEBCB5C59E9E7D848A8FB3B2B0A8A9BBD2CCD6BBCA9B825F514F453F
3A3E463E4543433D40413B413E4858454B464B507061554542515E6DB1B3B17C4B484D3B
3E453E494857586B6E645E66677C8C968FA993A35D3D37463B3A3E3A383A383C403F3E3F
403E3A35373D42413C393A3B3E3E3A383C42403A443B3D3E4043455359717C79725A4039
3E363C3A373F4141413C3A3D40403C373939393C3F403F3E3B3A3B3B39383838353E3C37
3B3A475C756E7E57603E4F3F3C3B3A3837383A3C3A36363C403F3C38413D3D3439353F3E
3D3D3E3C3736393B3B3C38363A3C3A393C4551565658564D5D6055554E42423D3C45495D
7187888E9596958C7B675349453F3F423339474A484E6271717069593E4559454C517F7D
98A4AAAEADB7C3CBBBAB9DA38A949FAFB9C4AFB2A7ABA0A48185777979777B707A6E5D58
4B3B40494F5D7C91B4B8BDB9B89FA0877F5B564748494F6D677E7F978BAFCAD2DBDEDEE5
E1DAEDD4E5CCDBD5D6D2D9C6CEADBDB7B0B4BAB4B2B0A49E888478897E91818B78746268
4E5C4346443F383D3B3C443B3D3E3D3F38393B43
DFDEC5D5C9D9C3C6BEBDBAB4AA9E9795988C9171796265595C666C6C70787871797B776C
60564A3F3F3D3D414648443F434143434143454348423F4143413F3E3F40403E4042423F
47473C433D4A474B3B4D718686785A43514A494342443F413A3D393A3A3A403F3B3E4142
413F3D3C4B4A48433E3B3C3F40413F3B3A3C3D3D433E3B3C3D3C3A393F4C46444743403D
3E3D3A3B353238373D403B3C433B3D3C393A3B3B3B3D40423C39383B3D3D3B3B393B3936
383D3E3A3A393D3B3A3B383A44413D39393C434737393A393B3E3C38383C3E3A3841443D
3B453C373A383C3F434344383B403C4C525A626C5145423B4041413E3937383A383B3C3A
3B3C3C3D3B3E3E3A38393938363D3A3C3D393E4044564E463C3B4C483B3B3B3C3D3E3C3B
3A39393B3F41403E39393A3B3C3C39373C3B3B3A3A3B3B3C3E433D393E3E3C423E3C3A39
3939383737373A4A4C3F3C3A3D3D3C3C3D3D3D3C393A3D4347434148443D393C40434544
413D3A36373C3C3C4241403B36373E464042403A393D3E3B3E39383C3F3D3B3B3C433F3D
3C393B3A3A373B42413E424A50554C47423A3B3C433E434240434241393E3D3A3B3F444A
5E666A726D705A5D56575047444341413F423C3E4E547791777A8995989E9D8F7C72625D
535F5B504143413E3B3F40403D3D4A3E4D47566376938CB093C0C7DDDFDAD4D5DDDFD0BC
ACA6BDA9DBC8DDD0D9B2B485907E99A1B5BBC3D8C9D9C7CFCACEB1C7A3AC756242433F40
3E41473E393E423C3F4B586E889CB3989988898D8C716562789FB3C19B8B614C3C453751
495F6A81A4BEBCB3AC9A9B7D806266575A5B6A4D482F483A35383F393437373D423F3C3B
3C3C3A393A3E3F3A3636393C3B3A393B41433F38413D3A43515E6E7E9B9F8F735A40343C
39373E3B373B3C413F39393C3D3D3D3B393A3C3D3E3E3C3A3836393C39383A3A3C39333D
565D676C5A5F4747373D353A37383939393939393736393D3B3C3D3B393D3F393C37413F
3C393A3C3A3A39353A3937383E41403E4553605E534B47434D4B413F383636404B6F777E
8081747672695E4D44423C3B44323F2F485475708076797B706A624E557B858F6D91A3BF
C2C2BBC0BEC9BBB2957879676467A3C4D5C5A78F987B6B5C4D6570888D85765E584E3E41
3A3C56716E9090B58A946D7455556F879988847B8F8EB4ACC1B1CFC4D4D6DBD1D8DEDFDB
DBDDDADED1D6C7C9B7C5B0D4B5BCABB3A3A09B8C837D717166596E556F58605447454344
3E3E3E3B3B3C3C403E3D403D39413E5046554F58
D2B993847C766766605D5E63697282928E857560574C4D45464C5152545755504F504C45
43464644444344484D4F4C4945414445414244404443434543404144414B4C42424D4F47
4B504951454F4B525F6D8E9B9A9179675F554F444044424643453F3F3D3A41413A3B3D3E
3D3C3C3C3F404242403F3F3F3E3F3E3A3A3C3C394345433E3B3A3A3A30413C393F3E3E3E
383B3A3C383B4A49333B424A53423C343D3D3E3E3E3E3C3B3F3A383B3D3C3B3B3B3E3D39
3A41413D38373D39383A363A3B3D3E3E3D3C3D3E383C3F3C3A393734393A3C3833383F3C
3C43393A4039393F4245463B4B5E555B56575257413B3B3A373F423E3B3D3F3D333A3D38
373B3C373D3E3C39383A3B3939413D3D3F393D3F3A443E3E38343E3D3B3B3C3D3E3E3D3B
3B3A3A3D4142403D3D3C3C3D3E3D3B393A3A3B3B3B3A3A393D46413B42444144403F3D3C
3C3B38363B393A494A3C39383B3C3C3C3B3C3D3D3B3B3A3F433B363B34353940423E3C3C
413D37393C3C3E3D414444413C3A3E413E43433D3A3D3F3D3F3D3B3B3A393D4240473F3C
3E3C3E3C3C3E4041414043463F47403B3B3B4041443E45423C3F3C3C3F44444348494B52
525051464C4440403F3F403E3C40423E403D4B4C6B69858B87837B70665F564C52484636
3B3A463E3E403F4440433F40413B5552958F9389B1A8B3A7C7C1DFD0D6C8C1C3C9D0C1A4
99BCAFC1AECCBFD7DBCBCBC4BDCBCCDAE5DDDEDEDFE1D9CCB38E765254494F3A40444852
54565B53555450454B5F779491AC9899667256716E739ABAD1DCC6B7A07E5C56535C6474
85B4D4D0DFCAC2AA9489775F554743414640433F304F3A3A3C3E453E3A3E3D41403E3C3B
3A3A3A3A4145443E3A3B3F4139383A3F42413F3E3955667E9399A4A2927F69554339393E
3A3B3F39393B3A42423C3D413E3E43433D3D3E3D3B3938373834393E3A393C3D3F3E4C65
80837F63454739393834373B3B3C3D3D3D3B37353C383A3B383A3E3B353D3D3B3B373F3B
3C37383937393C38443F3E3F3F404444434A4D49453F3B3C3F3B3E3E393E374F69988B77
685B4D4E493F3D393A3E3A3E3B3A43496C949D9C705F524C4747463F69799C7F8582A2BB
D9D6D5C6C7AB95735F4A4C657AA0C1C9AA93655B514B43486F82929A8C7E5B45474C4048
425264727E73685E5B534C4440515D8592928D8CA8C6CEE3D1DEDDD0D1CAD5CAC8CCCFC9
C7B4BAA3AA9495949E9AA896A874816B5A5752484645414B565A5655454E3C3B40443F4C
47494E474D4E4E474342434C50567E7CA08FA096
B7A983785B54434F4745494E4C474B544E4A4A3B493C4C4043414243434242434241454A
4A4440403A3E4243414042443D3A404442464A4742444646413E444D596D7062667D867B
727A73765D5C4D50495470797876665B4E494A45434540433E413A3C3A3741413C3D3D3C
3B3B3D3F3E3C3A3A3C3E41423C3E3D3B3B3D3B36333C423F3D424A4E4151473D3E393839
353A383833394C4A3B3B393943383D3D3B3B3C4043433E3A443E3A3C3D3B38393A3D3B36
373E3E3939363D38363833373B3C3B3836343637373C3E3A37393B3C4642434138383E40
3E433A3D4338353B3D383D44698171724945363D3A3B3A3A363E3F37353B3D393D3B3B3B
39383B3F3E3D3936393D3D393C44404040393A3C3C3C394141393D3E3A39393B3C3C3B39
39383A3E4344413E363636383B3D3D3C39393B3B3B3A39373844403941443E3F3B3B3B3D
3F403E3C3838353C3D3839363C3E403F3B383635403D383C423D3940383B40423E37373C
3F3D363F423C3E3A3840474C4B44403B3841443F3C404240343C43423D38393C3C443938
3C3B3F3D3C44433A383D3E39403D373E3D35393D3F3A423E393D3A3C403E393E47433D40
40463940364037413D3B3E403E44474044524F7B6B7F5F5C4F52484043423D3F3E3C453A
3E38433E3B3C39403C4447504A5662859DA99AB7A6B8A3C4B0D7CDC9B59E949AAAC3C5AD
AFB9B899A09DA5A1B9A9C9C3D8D3DCE1D5CFBFBFB0B3A3927B736F73636B675A63687081
8A92A09DA79B876C5D564E55525A5A4F546581ABC7C4DADAD3D5C9C9B7CDABB8A5BEBAD6
CFEEE2E5DDC9A37F6059553D4939403F3E393C3D433C413F3F3F433B393D3A3C3B3C3E3E
3D3B38373D42433E3B3B3C3B3A393B3F3F3D4148689DB9CFD5CAC6B4966D554E46444338
393B3B35383B374238363E443F3B3C3A393B3C3B3A393A3B39353B403B3A3E3E555A707A
746A6942463F35353A333B39443F393535383B3D3E363538393E3F37373F3B3C3A363B34
363438393438414450474340383840443E403D3C403D393B3B343E403F4F4C715E8A6849
3F3B35393E383F3D3732303F384D7A6F9E95816A403E3C3C3936373D4449504D4F7084B4
B9D1BDBA8770534345507D96A8A8A5845B4C4042484D6E85A9A59F8A768277817D8C7D7A
67716558535A47583A4C3B443F4B535C7C769396C1D8D9C7CBB1B6A0B6A0A4938A8B8E84
736263656E747F9490A18F936D5A514F3F3E3E3B3E3F40504A4D55474C5255534B565475
7D8A9991A5A39D8B858A90A6A8BDC6D6C4CCC9D5
6A687E72725A504C4B4749474F58514C554A4B48494A4145474E4C48424A41493F4E4C43
434544414844434E4243444B41433F3E4547484C46443D474E5C71939AAFAEAEA2929384
7B5E694F54454541423B444947413F4D4C4245413C43474B3B3D3E3E3E3E3F40383A4143
3E3E403E45413F3B383E413B3B3F43433F3C3B3B3943383C3845617F3A393A3E4142403E
3B36393B37393E3B383D44433B383E433F39393E3E3A3C433F3C3E413F393638363F3A39
3A3D443B3C3837383837383B3736373A3A383A3F3A3C3C3A37373C41383D3D443D30383D
363A363E4339383D383C3E5D6E635D4B413E3D39383F423D363E423E3A3B3D3C353B3D39
383C41433A39363C4747424437363E423C3A3F413E3A37394045464446323E343A363947
4D4754594E4D5042373B4142403D393B3F39383A3A3D363D3B453E3B48423740423B3D37
3E444D4332353A343536303B373C3E3A36383B3C383C34323D3C363B3C373C393B40393C
363B3B37394140394143454A4C4A443F3B3B373940403E45393F3E3A3F413D3B3C3A3839
3C3F41413E4041403D3B3A3A373835373A3633393D3C3D403F3D3D3F42433C40423E423B
393D41413F3D3E40393C383D4448525058597067694F453F3B403F3A3A3D3D3B393D464A
3E3E404044565B6B617671848586868B9499AB90A483A08FA797A88D9070636E778D919D
9EAB9DA797C0A7B0A8BDD4DAD8D4D0C9B1A696897674666B7394BEB6C9B9CFC1C4C3C3B5
B0B1ABB4C7D5C7BCA68278707F6F788DB1C1D5E4D6E4DFDCD2BEBDC5CFD1D6CFCCD1DDDF
E6E6DED9C2B18D6D674B3B4E433F373F3B3B3D37443A3F454943403C3B3C393A3B393C39
3B3B3C3C4038403F3C3A353B3D413C453C4D6F76B3D8D5D8DED3DAD2B0A0938372716B55
47414340383E463F404344423E3C3E40383C353C41393839383A393C405F777C8479795F
4F44423C343A3A383A3531343738393938383A3B38383E413B393A3639373B39393C383A
383F3836474D4646474A3B343A453F3D3438373C3E3C413F34443C4D715C5250444A3F35
3E40373435363B393C3A344256807B81684C4A3A3A3C2F393D353C37393C4B52886F707E
A8857962484F5E646B79839A8E6450403F454A656C9F93C5B9AA847D86888C8597829271
7955674C53514F4E57454351628DA6B8BFBBC5C6BEBC9FA56D6B54616A72696C6D756764
50577880AAAFC3BDC2ADA978884F4E46454F4E50616F80979EA29A9E9E939CA9A7B1A0B8
BCC0B2BFC3BCBBC0C3CACECAD0DDDFDDE1D1D5D2
4E48574F584C4C4C45434541444B47464B454A4B4F524E52545B5A5A5556424147505147
494D46413F413D4441433D404646413E4141404341384E658A878C8693A0968D7A645C48
4F434A434447423D403B3F3F3E3F404A4A434443414549483D3E3F3F3E3E3F403A3A3F41
3C3D41413D3B3D3D3B3D3E393A3D40403E3C3B3B39403C3F45574E46403E3D3E3D3A3B3E
36363B3C39383B3B343B4041413E39373B3A3C3F3D393C433E3E3D3B393A3A3A3A413C3C
3D3F453E3A393A3E3F3C393A38383A3D3B38383C383A3B3A39393C403B3C3A4240353839
36393841433A3D4164563D42453E433C3E3B3D3D3B3F433F3D3E3D3A3A3C3F40393A3A39
3B3E3F3E3D3D383638383C483B36393E3C3C40403E3B37373A3F43454E3D40434D5B5E75
69767D8A57523F383D3B3C3D3F3E3A3743394039413A393936423F3A403B37423F3A3F39
3C3B45403C3B3F3B3B3D363A393D3E3B393A3B3A383F39343937363F3A363B393A3E383A
393D3E3B3C3F3E3833383C3D393636363E3C3D3E3B393C3F3C3E3C3C403E3A3C3D3C3A3B
3D3E3E3E37393B3B3A3A3B3C3739393C403A363A4240404343403F413E3F393C3D3A3C36
3939383736373A3D3C3E464E565B5D5F5D5156474C4143453B3B3F3F3B383A3B39384244
52586A6E777A8A728A848F909A9F9593A19C9C80736D637466705A6246444655565B5966
8E7D9270A49AAA99A9B5C1BEB8AB9D8E8B8C96A39B958489759788B3B4CDDDD8CAC6C4B8
B0A8A3B1BFCFCDD6D8D0D5D0CAC6CAC4C9C9DAE7DEDDD3D3CDC8C6CAC4C9C6CDC3D1D2D4
CEBFAD8E736E5B4F5043394B3D3F39433C3D36403D433E4542403E3B3A3C3D40383D373D
3C403F41413936373E423D3D40555C7E6A7C95A6AFC3D1CDD2D3BFBCBBB4AB9A84786C58
483D3B3A3741473E3B3C3C3B3B3E4348353D3F40403A3B42314C42465A9AA9A965544F3A
37383D3A3B3E3B383937353835373A3A39393B3D38383D3F39383A3639373D3B3B3D3839
393D3E47544A3C3D3C3B3F3C4341433D3A3F3C3D3B3B484D54584A4C5741403F363D3632
3E433F403A393835383C404B73776B55443F383B37343F37353D373C556C67928C855056
574446443E516672525F56544A3D444062689476B29AB3AAAC91746C767974756F595648
3D474E525F6D666E5E6D708396BDCBCFC9B8AE9B98706B5C605A748AA69EA4898F6E6B5C
566C749897B2A9AD94916D684B54516262727F93B2C2C6CECCCEC5C9CDC7CED5D6D5CED4
DED3D0CEC0BFC4D1D5DEDED9CBDBCCD5BDB9A9AC
53484E434D46484748474A45444846494C484D4D4E4F4A4D464F5B6C7682716F60574F41
49574C4846493E40414942454546434145444143464B58786D6D5C57525B52504B45493E
424443433B474442403F443E3A3E404A454242404140433C3D3E3F3E3D3C3D3E3C3A3D3E
393C434439363B3E3B3A3C3A3C3C3D3D3C3B3A3A403C3B3E404F3E3539393C3F3F3C3C3E
3E40413D3F3A38363C4340393D3C383A373C40403C393C413C3F3E39383C3C383F423E3E
3D3C3F3C3A383A3F413E3B3A393B3E403C37363935383B3C3B3B3C3E3E3B3840413A3835
3938363C3837464E68583B383936403E3C393E423F3F4241433E3A3A3B3C3C3D3D39373A
3D3E3C3B393C3C3C3A36373F3E3634393B3E41403B3B3938383A3E403B3F656C8F858995
918A887D57484139383A3C41423F39303E3A39413C463C413B41403B3A3839403E383E3B
3F3B413E3A383D3B393A3738383B3B38373838353A403A353735363F383539393A3C3737
393C3E403F3E3C3B393D3F3D3936373A3E3B404137343B3C3F3C393D413B373C3E3D3D3D
3E3D3B3A393A3B3B3B3C3E4040403C3B3E3C3B4042404042423F3E4040403B3D3E3B3B35
3E3C3A3A3D4043444B4C5B61605747474D41443B44403F3F3A37424B44404445434C4C61
687C79806780667259816779717266657B7C77565E5B4F4B51493E57546870807E7A757F
787368707F928785748B778A5B6A45465369889B988E6B594E415E6DADB0BBA8B8BAC0BD
B5A7A1AECEDAD7DEDADCE5DED9D9D3BDB6B5C8D0CCBFBEC6B9BAAC9EAB909C748E728B78
776B6A4B3D443F3E433A46394233413E3B3C42453F39393A40413F3C39383A393A413D3D
41393B3D3642434C5F696E728C96A9B6AC909C979EA8A7947D7F656D6B6D6A5F534E4B46
493C37393D47483B3E3D3B39393B3E40393C3C3A3A3839404044465F7C95A871493E4238
3C3D3E3944423C373839393C393C3E3D3936373839383B3C3838393839383E3C3C3E3839
43413E43493E33383B34383F3B3D3F3A3B3E3839393B484C6154424042363B31353A3534
3C3E3C403B3A37393C475659585B463A39313B36393933393844656B97898F7587554634
3A353C403B4143473E4235373B3848556385729F74A4829F7D7452545C545A5046413946
4E57787D9CA8BE999988A09AB3C1B3A28A70665558506E929CB6B3BEA79C7A7C52533A3E
52556A607468736A4948383E3A4C5F657B8EA0B5CFD8D1CEBFC7C7CCD2D3DADEE2DFD9E5
E0E2DED2C8CBD0DDD6D5C6BBB0999E718F5F6E57
504A4D464D474946484549454447434544444849484744455048404652717B8A8B817755
44463C4243444049464942434346444448453F3F42404B4B483E4345444C494845424640
414747443E3E41404540444240403E444645443E423D40383D3E3E3D3B3A3B3B3D3B3D3D
3A3D44443E383B3E3A383D3F3F3F3D3C3B3A3939453F3E42383E3A3F3C3E3E3B3B3F413F
3B4142363A35393F45514B3F3F3C383F3A3F42413D3C3D3D3C3F3F3E3D3E3B36413F3C3C
3A3637363B37363A3C3C3B3C3C3E41403B37363835383B3D3D3C3B3A3D3A393F413C3734
3B363541444855544C4436393C383C393E3B4045403D3F403F3A393D3E3B3A3B3E38363A
3D3C3C3D3A393B42464139353D3734383B3D3F403A3B3C3D3D3C3A383D5B80A7B7B19197
7F66594A3F3A4139353C4045423F413943394E425345483E4543403C3B3D3D3A4036393B
4741423D38393F3E393838384343403D3D403F3C3B3C36343939373A3737393A3C3C3836
39393C403F3B3B3E3D3C3B3B3A3937363B393D3F3A373B3D3C3C393B3F3B383C3C3D3E3F
3E3D3A383E3D3D3C3B3C3D3E3D3E3A393F4143494442414343403F40403F3C3E3F3E3B38
37383B434C5253514C474E504C42393E403B414046474140413B464F4845463F4F525E59
6C5C574E576064434F484E55585E646673797E636667515653655F81737F777F7A777270
705E7D578A5B6F5E6176877B73646464707F8F8F8C896E594A4749756A8E6679798898A0
A09998A2BFCED3DACFDAE8E5DFDEDAD1D7D4DAD1BBA69F9471736B6554515B5248465E67
7B6F6C4A3D4042403E42423E3E44443E53625971404C3A473D3F3B3C3F41443F373E4239
40333A43456E8496A7ACB6BFC9C8C2C2AC91938A867D714E4F3B453E3A3D3B37373B4146
4E454142444741313939393B3D3E3D3C3F3B353A3E393939425461876D7D6C3D3E394237
3936383846423B3737393A3B3A3D403E3A3636373B3A3A3A38393A3A3A383D3B3B3C3739
45413A373838393C3C353839373B403A3B3A34393E3F433E443E373A36313B393E3F3A37
3A3634393739393E40495850394339373E303D363B355666687885988F76614746393B36
3838353A373B353738413B4251565B5B8862624A534D516B6A5E543B3B44363939384764
6A9290AAA8C9C3C79FB2A1A4A7956F5D4E3E44425360A393A7959B7D78554D394230403C
3F40453F453F4038424156516B55716791ABC3D1D8CFC0B9B7BEC1C3CAD2D9DBD5CBE2D9
E9D1DCB9B5B7B7BEACA38B7B60594C46403E3E42
48494D484B44484548444746494A4343404243444442424044424247434C454A68676F5A
4A4B434840445C7D777168645757514C4C4741424343433C423F485067757C7D73655F58
5147473B493C46444B3D3D4247453F45413F40353D3C45443F40403F3D3C3C3D3E3C3F41
3E404443433D3F423D3A3E413F3E3D3D3D3D3D3D4146434B403D3C3E4B5553443F4B595D
5E64614A473F4B55575D503F3F3E3D474041414040403D3A423F3E41413D39383E3B3B3A
383836383C38373A3C3C3C3E3F40403D3937393A38393B3D3E3C39373B3A3C3F3E3B3738
3B383E55616057423F3C35383A393C3C443F42453F3B3D3E3736393D3D3A3B403C38373A
3B3A3D42433B383E43423B353838383A3A383B403F3D3C3E403F3C38494D696F967C6A5E
4C4538483240383A3D3F3B3B383C494244444E564D5246404442413E3B3E3F393F37393A
463F3F3B413E3837383B40413E3D3935363939363739363639393739393A3A3C3D3C3A37
3C3A3B3F3D38383D40403F40403E3C39393A393C403C3A3E383C3A373C3E3C3C3B3C3E3F
3E3D3B3A3C3B3938383939393A3F3F3F43413D3E403C3B3E3F3C3A3A3B393A3B3D3E3A37
3A3A3D43494B48443A38373F3F383D4244413F3C3A43424946424C5553595A4A434D434B
4247373D3C48403F3C504F67818E998D8275796C6F596A4464526E6A6562525750545349
4C4E4B544D554E6087A6A6A8858370787C7A7A6A5E564C4844423E514A444653556D828F
999FA5ABB0C1C9D2C4CED3CFDCDBDADEE9E0E3D8E1D8CBAE887C71776F7C8C95726D727E
9888775649464F4B5B5B6F6086818D7788847D72504441454A575F727F7F78675D665B5E
444D466084A8B0ACA38D80797786677B4E5B5158494A444B4549464047443F3F4346494D
423F3F414448453B3A3A3A3C3F403E3C3E3E3944433B4546557B8C5A49463E3F3D394138
3B37393D423E3A383738393835383C3D3B3A3A3C3C3B39383A3B3B3C3B383C38383A3739
3A383A3B3A3C3E3C34464753404D42423B3C373E43403F37343632373634383A3D3E3B39
3937363A3639383C383A42373B3340323B3D37433F59A1BEAB91746D5E523C3F313E3736
3A3E353B39403A3D4C6159474F605C45442E45455F607B946361413738363F383D3D4B4B
76628981A3ADBFA1B89EA599826B49484E515E5C687F6D854D6E473C43362F3F3A414043
3F47415A5B797478737E8994948796A8C3D1DCDBD0BEB0AD9DA3ACB1BCCDD7D9C8C9D1D8
CABFB19075726E6E5E57483E3F423847313D333E
4C504E4947424743494347494C4C444444474344454446424B4543443A423F4743414C48
454B423F47496890857C736E5E5C524A4A4744473D4A41463D4846566A7A8C9594908F8F
886F6C596D524A3B4A404549484447585553583E403B3E4142434442403F40403F3E4245
4243444144404446413E3F3D3C3C3D3E3E3F414243473D4A433B4255778D96847377838A
98908568685F6561625A463A3D40424A43403D3E40403E3C463F3C3F403C3A3C3A393C3A
3B3F3E403C3B3D41413E3D3F40403E39383A3C3D3C3B3B3D3E3D393639383E3D3C3C383C
545A6373746555413F3D3939393A3E41454042433D3B3D3C3D3C3C3C39383A3E3B3A3A3B
3B3B3E42423B3B3E3C3A373435393B3B3A35373F44413D3C3D3F40404849454F57544241
3F3B3A483B3E3A3B3B3B37414957695E7867735456434C403B41423C373A3E3D3A3A3E38
3E35383A3D413D4754534D46403F3B38383C3C3A33393C3B3836383D3B3D3A3D3E3B3C37
403D3C3D3B36363935383B3C393736363B3D3A3C433E383C373D3A363B403E3D3B3C3E3E
3D3C3C3D3B3A393A3B3C3D3C3D42403C3F3E3B3B3F3B3A3D3F3C3A3A3C393C3C3F413B3A
43413F3D3C3B3836373A374041393D3D3F41403F36403A41403E4244444A4838403D4135
4039434442453E4A4E6D7186868A8168604D4949494746523F574E4B444039413A43443D
413F3F47435954718D8F946A6E4D514945505F524A47474A453B414649464C5B5E7A8D9B
A7AEB3B1B2BDBCC2B1B5AAA4B2B9C1CED9CEDFE2D8D8CDC0C7C3B9BDB2ACC3BDAC8A8A7E
847B757177849A9FA4B1B4C0CCDBCDBF9B957A826474697494A6B0C7D5D0C5ACA695966C
633C4B4D5C665E565751473F444B43443F3C4741525C7B9D99A98B8858483C3A3B3D4042
4745413C3A3B3B37403D3B3B3D3E3F3E3B3F3E3E3B4057605A7A5257494841383A353C36
403C3A3E3C393A3A3839393637383A3B3B3A3A3B3B3C38373A3B3B3D3D393C37373A373A
3731373E3A38393542507F5E6F43513B363B393C3B3739363A3B3235383A35383B3C3B38
393A3A3B393A39383534373338323A363C3C333E4C89C2D6AB745B405641473242314034
37423941363E3D4165685C483E403E333F42577AA39F9465563E3A3139403140413D514F
728187939BAA97A699A2858B615F51545960726C7E73686A5E5348403E45525C5B5C5F61
646B7F8FACB8BFB9AFA6939887909BC0D7D6D5CFBFA5928E99A6BAB8AFB2B6BCB4AAA990
8B6C694C48413F3D3A3B3E3A3D35424147404243
464A454648474D474541454646453F42474B4446494B504A494140453D47464D44454B46
3D3E3F3E4640495E504B45424848423F42413E4044424738423A413C424B565D5F62666B
746B75728473544144434C4B454247596A6D805F59473939424343424140404142404548
45454540444243423E40403A3B3D3F3F3E3E40424545383F3D3A446992AABDB6A1918D8D
8B7D7660686265554D443C3D403E3B3E403B393C3D3C3D42413D3A3B3E3E3D3C393A3F3A
3C4542433E3E3F413F3C3D413E3E3B37383D3F3E3E3C3A3B3E3E3C383A373C3A3B3F3A3D
4E59595951423D383D3F413F3B383636413F40403D3F413B41413F3D3C3D3B393C3C3B3B
3E403F3B3B383E423C373633363A3B3A3934343D4343413E3B3D4248444149404A393E3B
42373C3A3C333C3D424545545D6B7D6D685B5C483A39403D3E46443A373A3D3E383D3F35
3A34373A394D53626F5F4A3F3A3B3937373A3937373C3F3D38373B3F3B3E393D3D3A3D38
3E3C3C3D3D3B39383B3D3F4040403F3E3B3C3E41423D3B3D3A3C39373D3E3C3E3D3D3D3C
3B3B3C3E3C3B3B3D4041403F393D39353A40424645403F43454341403F3B3F3E41443B3B
3C3C3B3A393A3D3F3E3C393A3B3C4041363E40473C46383A3B3A3C3F4043433F42423C41
373E3B3B383744435264717459524536413B3B42434048484246413E3D3C3B403A403C42
595268595E5A4E5F596148484458505B5B636C544A464543423A47443C4B466075868990
98999E9C9DA192907D81767C7E91A5BDCABECECFC8AE937B8488968F9D9EACCDB9C1BEC1
B8ABA9ACACBDCDDDDCE4E7E1E5DED3CABBB1ADAAB5ADAAA5C8D2CCD5DCDFE6D8C6C2A0A4
705E4F49514E4A48546466675C58605A7B739D9EAA95B8B4CDB3A685644D3F3D383A4040
43423E38383B3C3B3A3A393B3D4042433B3A40384160665F4F5D4E8EAC857C4841404843
493E373A39373C3F3B3B3D393B3A39393A393837393A36353A3A393B3E3B3E3A393C383B
3B333538363E46415D776E8C4D5F3D403438353735323735393E3A3A3539363E3A3C3B37
363B3B3839393B393938373E363B383E3C383B497095BEAA7C5E47474A3D363536383E41
3B4B4549333D4C595A4D463F34363D3D627C7EA777854F3942393139403C41506B747476
999BA9A3918886727D6969665C666468686F858192998D9C70643F4D607284848E96A4AA
9AA9B6C5C2BDA99C9274726C8196B5D1D0BDAEA79C8E8C93AAADB49E7C6D686E666A5253
45473D3F433C423C413D453F4451557E63817186
4A4E474B505154494A474D4B4745424957584B4948474B43463E40494249424342424445
404349444C443E48424746483D42424449453E3E3F4243463C43413A3D3E424241403D3E
454851555E674943403D424142433E4144547E696B5A44443F4040403E3D3E3F44424649
464646414542403B393F423C3D4042403D3A3B3D40483F3A3E443E59687B929C927E726F
605A604C4C434B3D3C34343A3934373D3C37363A3A373D47383B3B3B3E423E373A3C4138
3A44403F403E3D3C38373C443C3C3936393F413E3E3B393A3E3F3E3B3B363A373B423C3D
43483D3B3F3B3A3A3B414A4A4744403F3C3C3F3F3E43443C3A3C3D3F4448423A3D3D3B3C
41443E343A363B413C3A3B38393B39383935333B3D4246423B3A424A4F48454140393D3B
3B3F3D4E3A3F3D496060565347465340443D5443433B463D4A4E44383A3E3C3B3A3E3D33
3D3A3D3C485C524E4F3C343B3C3F403F3F403F3B403E3E3D3B3B3D3D3B3E383C3C383D37
39393B3E40413E3B3E3A373B4144403B393941463F3C40403E3C383A3F3B39403F3F3E3B
39393C3F3A39393B3E3E3D3B3F433F393B3C3A3B3D38373B3E3C3A393C383D3B3D403636
3A3D3E3C3837393C3B383B37393F3A3B3C403C433A4D42463F3F4041413C3D453F383D40
4243473F38424A4B384A423E40383C393F393F4640423C41363E33443939383A3A423B4C
62577151504437493E4837404A65616B625758474640404242465558736A848198978581
83838F958F907A725E696A83778695AAB9ADB6ACAB897E65535680708F7A9FABCCC0D8CA
C0B3BABEB5C2C4DACFDFD6DCCBD2C7D2C2C6CCD3DECCB7ACA4B0A8ADB5BCCFC9D9D6CBD5
C69EA78692939E9D9FA7A5A79AA68DA78CA0ADCAAEA07D8A706761494D39373E3B3D4441
3F403D3A3D403F3D3D3E3F3F3F3D3A393D3645405E8C6D47658BA1C4D4BE857659667E7D
795B454238373E423D3D403D3A3836373A3B3A39373934333939373A3F3C403D3C3E393B
393639373A53645A816C78625942513F383934393B393B353B3A353A363E383A383B3A34
353C3D3637373C393B38313F3A334038324B52839AB6B29C6E433D373D363D414A414445
70847C74453F465043434334375C6D5B905E8650573F3A3A35323B3B4455688C919B848A
879E8689635C4E4B4655637162646376838EA39E9E8D885B5B4A48526F858B8A95AAB6BE
C7CEC6C1A79C867F8161786F8C9EBECAB69C88827B75809295807257403F41483B4A3A42
434339424040585F74738078928BADB3C4B5B2AB
4B4A4744464B4B474646464545464748544C46464541414540414546423D404745464848
4745424046444242434545443F4345433F3E40433D3E403F3F3E3F403E3F3A3940413E41
3C414B4B434447433C3D3E3F3E3D3C3B3E3E474F4E4D49404347484442413E39484C433E
40434044454441433E4B3C3C3F3F3E3C433F3C3F4038473846403C5A70828B83735E4D47
3A3E41403C3A3C3F383D403E3D3E3D3A38343A3A3C3E38394035353B3C3D3C363737393A
39373B413C3D3E3E3F3E3E3E393C4042413D3A393C39383B3E3D3F4444394033424E564D
453B3E39373E3C3C3B3C4341434741403F3A3B3636423E4250445158615E3F36373C4040
3D393736383C3F3E3B3A3C3E3B434437383D36373C4138373C3A3D41424E4A3C393A3838
423D393C3E3B455C5F544C3E3E464244393F3E3B3D3A383E3B41423D3A3B3D3C3B3E3F3D
3D40403F433F3E3F3D393739383C3A44443D4445383B3D3C41454540473D403C39404140
3B3B393B37353B36373C3F3C3B3E404037403A3C45454440383A3E3F3F35403637393B3A
3837383A343D413C3B403F393D3E3E3C383433323C38373B3E3C3B3D3C39393B3C3A3A3B
373C3E3A383939373A3C3C39393E41413B3D454443423C3D3A3E3E3936393D3F3738423D
3839343B393A373D3D363A393B36404747403842353937383F3D36363B3B3C3F41434648
484B5143383939423D403F465558504D3E44393D3B3A525A6075798E8D9E9BAB8D8A7978
6D717D89999A9D7B7B6F928990747275737B747F757A777E748B98A39A9F97B3B2C7B8B2
ABA4A1B4C5C8CCCBCDC8D2D2D0C1C0B9D6D5DDCBC299816956534C53575F79A2AAC7BDDD
D6D1CFCBC8D1C9C6BCB1B7B2B2A9A18C775D5D64524B473F494243433B42433C3A414747
3F3B3C3D3A3A3E3E3A384140443D474E46659189B56A7674A3BBD0CBD5BDB7A5A7B2BFBB
B8946D4E443F455242423E3B3B3E3C37363839383A383D393536343A363831393B413F4B
4A45414379958168646D666C41443A38363737373636373836383D3F3A35373C39373536
3A3C3B393742313A36373B3A364B465161688496969A8F6F4B393C44353649767F635A60
88A18A604838353B383D383D475363654E44423C3837343C363F3E3D59818B7A82725558
765D684A393F383F4A6572806F7E838DA7AD9C8F69634F46313E41454C7065737F939BB4
BCC8B29D9375735A6F686A7F869EA8AF9D9581846B6C8386815A4D4A50525D53675A7662
7E6E866F7C8492A3AAB6B4CABAD1CDDBD5D9D2D3
4A4A4745464A4A47484949494848494A494846444446474744444546423E404542454746
43403F4045434343444443413E4041413F3F414441424342424345474045454548454244
3E424847404144404243434443424140413E414442434541464847444344423E3D3D413B
474546414E5258534F49423D41403C3D3D483A403F3C3D454376658F7674665249444245
373F433C383A3F3F373A3B38393D41423C3C3E37394040463E383A3F3D3C3B383838393C
3B393B3F413E3C3D3F3F3C393A3A3B3C3C3D3E3E3C38383B3C39363635363C535F94717C
3F34363638403C3937383E3B3D423E3E3536473F403E4C5C56484C4B5054424040424343
403D3D3D383A3C3C3A393A3C363A3A373938373F333B414C504E504A4042403D3D3C3A3C
3B3A393C3D373B49403B3C35384243473B3E3E3D3D3B3A3B3B3A38373A3D3D3B3B3C3B38
393D3E3D3F3D3D40403E3E403D3F3A3E3C363A383F3D4F49635A63574F42403B383E3B39
3E4137373B383B3C31393E3D3A3A3B3C35404047504C453C393739383B36443E393A3C3C
3A3A3A3B34383B3C3D3E3F3D3F3D3B3A3A3A3A3A403D3C3D3E3D3C3B3B3736383837393C
393B3B39393A3B3A373B3E3E3F403F3B413F433F3E403C3F373C403E3C3C3C3B3B373B39
3C413B3C36383740433F42413E3C3E3E3E3F4147393D3C3A3D3D3C423D3B393B3F43413D
3A3B403D3B4041403B3E3C3C40403D3F303E44565E5F737991949A98A499938C7A746063
6171879899A49A937876746A6D63656F61747288969DAFB2BABECAC8B195A9A5B799A088
8C9092A1AEB5C1C4B7B9B3CFC5D8CAC8C6CBC5C3A28D6E6067666E69665059686C7B8D9F
C8BED3C7D7D0CCC6BFB9B5B9ABAB999265534049474533424050454D464143444143433B
3E3C41454244443C3E3C403D454D66779ACDC7CA967C80AE9EBBD7D6DABBAE9AA1A6A89D
987D624D39384045343A3A3A32373938383A3B3A393A403C3738363C3C3E373D3B465775
8171666C9499847171685753373D3A37353A3F403E3B3A3A37383C3D3A36373C34343539
3D3E3C393A42363C3C3C393D4A6C78898C79767463635C4C3D393A3C36587B8571585151
54695A443D383B40333C3F444440433F3F393A363538383F4249453D495F615244414641
463E3E35303A415C77908E8D817C7C868E856F5D443A373D343644556388939D827E7977
80806D655052404851638888A4A4BCB1A8AA9E9A878B91827462516F6C8C88867C8D89AF
A1C2B0B1A3BAC8C8C5CEC0BFBECBC8D4D8D9D4D0
48494847474948464445464443424446444948434247474448464544413E3F4242454846
413E3F41434343444443413F454442403E3D3C3C3C3D3E3E3E3F4244474E514F4C433D3D
414244413D3E403D3F3F3F3F3F3E3E3D4540403F3B3D4241454542414244434047505468
67766C666A7A75795B5543403B39483441403C3F68627161897B8A7050524A413F3B3636
3F39393A4140403D3E3E3C3836383B3C413F3A323B433A3A36384147443E383339383A3E
3D3A3A3C413D393B40413C373E3C3A3939393A3B3F3A383A3B3B3B3A3A49757BAA897D58
453A3A3A3D423E383B3C4240444E4E523E5D737A5B5346534740453F42473B3A403F3E3D
3B3A3B3D3638393A3B3A3A3A373A393A3934363C4243464D4843463B4138383F3F3A393A
373937383C3A3A424040443E3D4242443C3A3A3B393837343C3735373B3D3E3F41403C38
393C3D3A4040414342403F40393B373839393C393D3E3F4E51574F4C3F36383B3D453F3E
42463E3B3A353B3E494B49423B3C4145424F51524D43403D3C383A383C39443E3A3B3B3B
3A3A3A3B3D3A3A3D3D3A393A3C3B3A39393A39394343413F3E3E3C393E3B39393A393C41
3D3A3839393A3B3E3D3E3D3C3C3F3F3E413D3F3B3C403D413A3D3D3A3B3F414037343535
3B423B363638353C3E393A363B3E3F3B393C3E3B373C3C3837383E4744413C3A3E423B2F
3736373B3B40463F4948413D3E40444B4F5D66787C767E7E82817678726E595252504553
5E758B999C8C936978566D5C6C636F66666D7A8A9AA7A9C8C0D9CDCBA9AC83AC8AA4798D
7D82808790959C98AAA1BAAFD2C4D4C2CFC5D8BCC2A1AD9DAAB2B6BEA59A9097939D779B
8FBCB0BDB8B29DA7A9A0B3B4B29B91635D3B4A4B454D515E5D5746464243576968676356
5E524E4A45525B514F5B6E798DA4C1D1D6D8D9A4A061797B909DA8A4A78A785E57575146
48413C3A3E363B3B343E383435373A3A393B3D3C3C3739373A3F3A3A43483D3938516B85
94877D85A3A09A907F5D453C333538373A3937353434363739393A3B3A38383B39383739
3B3B3835393C3735373A384D99A99D8E7758514F3F3E3A37373939363A5C7360473F3934
323D363235363D3D383E3F44413B3D3834343834343B3C41424C4D423D40403A443F4A39
3835433A555E627A8C9683775D555B61564A433A39353F3743507481ACBBAB966A5D5046
4F45433A4045536D7AAAACC6B9D2C0B19D978D8B8283755E5F5A74749F9097859495AEAC
CEC3CBC0C1C1BEBAB6BABAC7C8CCC3D3D6DBCFCA
4749494948474746494948464444474A464949454345464648464342403F3F4045464746
444344444343434343424140403F3E40434443414042444443434546494C4E4C47403938
4241403F3D3D3E3C3F3F3F3F404040414744464540414544413F3D3D4043423F57566A65
6D5F604C56616A5D593F443944473C434D777C8C99AA8A976E6E5E4A3A414341413D393C
4140443F423C3F3E3B3D3D3C3B3A3B3C393C3C34383A353F3C3B3C3E3E3D3C3B3A393B3F
403C39393D3A383B3F413E3B3C3B3A3A3A3938373E3B3C3D3A3B3E3E3C636795756A4F38
423A3939383B3A355D59574A444540415D728362543D413F3739403B3A3F36343C393838
3837393C3E3D3E3F40413F3E3A3F3B38373B44483D3D393D3B3B433F4337393F3B373838
393C3A3A3E3E3B3D3D3F413F3F424140494141423E40413A3D3B3C3F3F3C3F444846413C
3D3F3E393F4042434240404040413D393A3D3D39453C423C46393D3A4842414440463F44
3D3C3D403D4C6D79847865544B4F585F535A534C41383D3F3E3739363B3A433E43413E3D
3D3E3E3F423E3C3D3D3B38383C3E3F3E3B3837374345443E3D3E3C383E3B3A3B3B3A3D42
413B37383A393B3E42403C3A3B3D40403A373B3B3E433F414644403A393C3C3A3B3D3F3F
4244403B3B3B373D413E403B393A403D3A3F3C37373A3A3938393F4643433F3B3F443D30
3A3A393E393B4843433E3B3E45494B4E575D5D635F5455534A4D42493E463E43444C4E67
74838787827A6464576260645C5A505F57797584948B9B97B5B2BCAAA9899E819282997F
786B575A6C82979CA0B7B1D3BCDECCD5C3C7BACEB0C6BEC4BEB9CDBDBDA5B3ADBBA8AE81
A1818F7B79625D555D737F998E8A6C7E6C8D879790A8ACC29F8C605F5372A2C3CACAC5BC
B9A99E938D9DA89CA9B8C6CBD3DDE5E6E4D495845659484A474C504C5042443A3C40403D
403D3B3D40343A3B3D473E3A38383C3C39393B383E3C3F3B40505A6683725143435E7180
8997A6B5CCC7C2AE7A4F3E3A3F383B3F433D363436393B3B3A3939393939393A38363434
383B3E3F38393B363B414466909681664B36393F383A3B3B3A3A393945484A3A333A3431
3537343838373D3A413E383A37363B3536393F3A393F3C3D3D4143403B38353437323535
403D68577B7B6F6F6A67554F3A35383C393A3B343A44467C688589AE97976F544846353A
353A3B3F5456869FC0C6B99EB19D9A735452585B535156626F8F7DA69CBFA0B0A6AD9EBE
AEC9B8BFBDAFA5A8ADB6C4D8D1BCC4A5C099A08B
4849494A494746464A4947454345484B474646474746494E464542403F40414046444345
4748464543434241414141423E3D3E42474947433D3F4141403F3E3E4341404141413F3C
41403E3E3F3F3E3F3E3E3E3F40414344403E41413C3D413F3E3C3B3E4142403E3E464652
404A423E404E444D3C3F3C3B3F3E44528A9EAE9DA1878A615344423E4546413D3E3D3F45
4A54574041454E444141403F3C3A3A3B3F3F413B3A3837463D3A37383D403E3B3B3A3C40
403C39393A3B3B3D3E3F3F3E373738393B3C3C3D3A3B414139393C3A4C495E504F3C413E
3B393A3B37383F3D3B3A3D37363D3E42505F4D43313E393D393C3F38373C3C3D3C3A3A3C
3C3B3D42494745444544423F39393938363B464D4448403F3F3A3C3C3D383B3C36383E3E
3C3F3C3B3F3D35333B3B39393D41403B423A393A383D403A413F4043423D3D404544413F
4043413C383B3E40404143444343413C3C403E3B443D443A41343E413D3D3D423C474758
66656A716D7B999F968368554F52585C514C3F3E3C3A3F3B41383D383D3E46434C484341
414344443E3E3E3D3E41403C3E4245423C383A3D4143423D3B3D3C383737383A3937383B
443C38393938393C403E3D3E3F3F3D3C3A363A3A3D423E404041403E3F3F3C3636363639
3C3B3A373D3D353739383A353D35403D3A4340413B3B3C3E3F414342373D3E3C3F444139
3839383E3A39444038363A454A48444140413E413F3A3E40474146373E3543434B55576D
73777066786359414A4049484D45494A636F736F6E75728D87A0949085967E886A83585E
47484E677D899AA1B9B8D1B1C7A9BEB3B7A8B8A6BEB1C8BEBDBCBBBAA6A5A5A6A0B6A0B0
8392626256686E848E8C9791AD9A9E86A8A3C1BDD1D1E6D8E0AB9886A4C6DDE0DFE0E1E3
D6CFCECDCCD9DDCEC5CFD4D6DBE6E7E2DCC79B866461554B4745423F4138413D41443F3C
3B3B3B42443C42413F3F3D3F3934373A383B403D413D41475F8398A7A17243434E687C92
A7B5C3C9CFC0B08D573B3A373D363437393A3B3D3F3E3D3B3A3A3938393A3A393E3C3836
373839393E3B3B37404040585C6965574537363835393D3E3C3A393B3F383C3A3C403A3D
393A3A403D393F3D3A3A383833353E373A3D443F3D4039373D3634383B383331313B4066
596A817F686451493F3F393F3E3C353236393C414E669D8895738069484E3D34363C3542
48666D86828B99ACA89E6E665F5B4F4041414B5F7E91989CB1B4C4B1D5C5D0C7C9AFBBA4
B49AAC9D9BA2A7A9B4C0C1B5998C7A6C5D564C47
4B49494B4A48464647454343434547484C4746494845474D444543414143434144424244
46474543424242414041424443414043474844404547494947454444433D3B3C3E424440
41403E3E413F3E423F3E3E3E3F4144454844464642444847403D3D404342404044424A3D
44404D4A4F4C503E4739443C3F514E768D99856C6C564D463C42393B46433D3E44423E3F
5B5D5E4A545A69624B4743403B37383B3B3A4347474439373739383B43443B343B3A3C3F
3E3A393B3D3E3F3F3F3E3E3E3B3C3B3A393A3D3F3F3C41413B424B494E4C3C403F3D393D
3D3F40413A3841403B3C423C3C4242463D3E3C34493E423D3B3C3C3837393C3E3B3A3C3F
3E3B3F464845413E3D3D3B3A39354854524B48534A4F4442443E3E3F36383B38373F4647
3D3D37353A3C393A44443C3C3F3F3F36403A383A3D424543423E3C3F43413C373C3D3C3C
3F444340393C3E3D3B3D3F403E3D403C3D403C3C373B3A403A3E3F473B454E5E5B68677D
90979A9C9184817970614F4643413F3E3F3B363C3C393D373C39494B5252545048433E3D
404242403E40403F3F42413D3D3F403D3A3A3E423E40403D3B3B3B3A38393C3F3C38383A
413E3A3939383839403D3B3E403E3D3C3F3A3C39393E3B3E3F403E3B3C3E3D393C37333D
4440413E4B4B413F3E3C3F393B343E3D39403E3A3C383A3E4042403B353B3E3C3B3E3D39
3738363C3E3A3A384945474C474242433D3C3B3E3E3D3F43403B403E44434945444A444F
4F55514B4B4442393E3B363737413A4F4A5C4A4D6066867F8E7A8171765D665042414943
49596D858B8694A19AA48B997F94828D8A8A71867A9D99A8AEA1AC98A798AEACBABACF9F
B6929D8A8791B6BEC4C8B1B0A7B6AEC4B7D4CCD4DCD2D2D7E3CDB7A9B7D4DBD2D7DFE2E6
D9D2C9BFB9BAB7ACC3CED2D8DBE5E1DBDEDCCAD8BFC2A292887B6C6255423F373A403E42
3F3C373E3D3C4040444245414C403F454A5B6E72706A707FA0BEBFB99D7454637796AABD
AC9B91858274694D443E443E393E383D3D3F403D3937383B393A3A39393B3A383637383A
3C3C3C3C403A333948464A4B555E5C4F413938363A39393C3D3A38373434393B3C3B3839
3639383D3B353B3B33393B383139473E3939403E3D3E36343835383C3A34384149396962
716071684C4938373336323A3A3B3235495565808E979997695142493A393D37314E7187
9CA1A9927B71585E514D3D3F3D363D404E7A9DA9B9BEC3C0B4BEABD1B7E0CACCC0B6A8BC
9BA2939298999A9893857C6A554B4739363D4242
4E4A484B4B494646484747494C4D4C4A4B49484848474647454747444345454343454748
46444444404142424242434543413F4145474643404142413F3F4041433E3E3E3C3F4441
42413D3C3F3D3D454644434242444749403C3E3F3C3E403D413E3D3F403E3F41454A4145
434E4A4D4545443F3C403D3D42464547574E5146444439403C363F3A403E3A3D44423E40
403B433B453F5056444140403E3B3D41535B72756A634C363D3F3A373D403C3A3B3A3C3D
3B393A3E403F3E3F4142403E3F4142403B38393B403A3F4547535A5241442E3B41363F3B
3B3D3D403A353B3634373F3B3A3F3D3F4146333A3D3F3D453B3B3B3D3B3837373B3A3C3E
3B363B453F3C3938393C3E3F4B45636F695F4F5A4849403E3D393E3D3B3D3B393E434546
3C3C3A3E464746493E413B3B3D3C3F383A3A36363B3D3C3D3F3C3A3B40433E38383A3A3A
3C4244423C40403B37393B3C3F3C423F3D3B34373D384435473C494347515563595D5264
6D798283705E5D564F4741403F3B38373A393A413C394140514D5D58564E47403E3B393B
3F413F3C3F3F4042413E3D3E3F3E3D3F434544423F3E3E3E3C39393C3C3E4143403B3A3D
3C3D3D3A383838373F3B3A3D403E3C3C3E3B3F3C3A3C383B484640393637373537353547
4B3E3C3C3D403A3A3A3C413D373A3A3D3A4049383D37383B3A3C3C373A3C3D3D3C3C3A38
3A3D3E3D43413C47524642433D3B40423D3A3A3C3C3936383F3E3D4A464D453E3C423A41
3E45454244433E37363F3B4539434B4E51494649525D676D5B564A4245413E433846415D
6F859CAEA68E837C716567566D5F69666861584C62697C88817B7C809199A7B3C4D1BBB9
ABC1B8B8B7BDC4CDCDC4BCB4B5BED2C7D5CCD5CDCEC3C9C5D7BBB4ADC3D1CEC2C3CCD1D5
D0C9B7A49A928C8B85949FB0BBD2DBE2DDD4D4CECFC5C2BAB8B0A493704E453F3F423C40
3C3E3C464457626A7B7D8472685E677D92AFCAD0B8BDC7CBD2D5C4B6B59A7F828492918E
765A534948444336393A3E41364B4B657A6C56433A393C3F373A3C3A393B3A383A3B3D3D
3D3B3938383F425A6D646E594347473E383A3B3A413C393C3D3A37373B3C393838373936
363A363838323536373B3A3634434D3A393439393B3C353634373E4039323C4D4742495A
435946484140363937383137343B3C527F9AA7B8B19C80583D3339353A3439384C8AB9CB
B69B8F585042373C39393D3837374B539EBECED0CFAD9A8A7281A6BFD4D3D2C5BDAAC0AD
B88B8F7E787274766A4D4E4A43444C4B4C5E605D
504A484A4C494747434345494D4E494442454645474C4B46464A4B4745464644444A4F4D
474344473E404344434344454C48424040413F3C3F3F3E3C3C3D40423C3A3F403B3E4646
44433C393C3A3C4743413F3D3D3E4042454246494746443E403C3B3C3B393B4044474543
504E4640403E4B3D444142413D403A3D3E3C3739433D403B3E3F36363C3F3E40423D3C43
4339403A4A40443E42414244413B393B3B45616D727C643D3C43403B3E3E3A3B3B3A3B3C
39373B40403D3B3E444744403A404646403B393A3835404F555D57413C3340423D3D3F4A
3A3D3C44423D4238393D45403D3E393A3D4B443E42383C3F45413E413F39393A3E3D3E3F
3A343B473C3B3A3C40464C506B5D7064524A373F3C3B3A3E3A39403946453D3B43433D3E
3A4149565E564B493E4540403D393E3941433F3C413E393B3A3D3E3C3D42433F3B3D3C39
3B4043433A3E3E39373A3E3F37343E40403F383F42403C393F454742444640493F463B50
41526B6F4E3D4944423F3D3D3B393B3F423C394040424E4E51495348474444443C3A3B40
4648443F3A373B44443D3E454744454C55554C43403E3E403D38383D3C3D40423E39383C
373C3E3A3839393738373C4447413935373841403F3E3839393C3C3B3B3D3C39363C475E
5A403C3E3A403B3A3A3A3F3B3844373B3B48654E413C3C3C383B3E3B3A393A3E41424140
3A42464147494C664737343B3D3D3D393A373A3E40403E403E374846544A504338434048
42433F393F4144383C403E463D4B485044403B4743404940463F463C4134404642596B88
B1B6B2B1A7907A64514F434A4D50474D4A554751576B6D826D6771749692A1A9BCBBB19A
B1B3BFAFB9AFBBC4CAC9B9BDBDC6C4C3BDC6C3C0BBC4C8D1C1B6B1C3CCD2D4CECACFD5D7
D8D8CDBFB5A394938B8E8685849DB3C8D2C9B8AF9C9A959D97989BA08B70665D6066656F
7074727C7CA6BCC4D0CED5BAB1ABB9CFD9E3E7DED4D9E1DDDBDBCBC0A489747C7A807974
5C464B403B3B3E374642455B537480B2B8986C4E43413E39363A3D3A393B3A373B3B3B3B
3B3B3C3D355163858D6F724A3C40433D3A3E3C373E3A393B3A37383C4042393835323936
393D35363A363737383A3A3F4B6366453C3335373A3B35383734353A373338423A393B38
39344232343832393638333C40596C83A6B5ACA58D6145343D373E39363A3C4784C1C4BA
71623F37343D3B3F3C3A3B3B456F96A9D3D1C1B9A4614C4C5986A0CCCAD0B7C09BA597B8
9290676E7B8EA09A89706D597C75A687B3A1B59B
4E4C4A4A4B4B4947454A4C4844454646434647464344484C4D4A46444445444342454747
454241414140414343404246414040414242403E3E3E3F403F3D3B3B3F4044444042423A
3B3E4345413C3D423E3F403F3C3D40443D40423F3D3E4143383E454043463D4143423F3E
42464138413E3E3E3D3B3E433C3B3B3E424443413E3F41434444434242433F3D3F3B3A43
3F3A3D3C3F3C37463A403F443C403C3F3B3D424740455145454A47403C3839403B40383B
413D3A37383C3642463A4B4D4C5C67734C3F37433E3745465E544D3C3B39353B393A443E
3B3F3D3F4044473B394340403D3B413B3A3F353F4149473D474242413D37353E3439383B
3E38373F323841424B524F5A50544F46403C3A40403D3C3F36423F3A3A394440425C5979
666D707F6D4E4D434451463E42403E3D3A433B41393D383F435557494346474845474846
403B3A3C363F403E393D3E3F3844484B534B3D3D393E43363A4036484844493F373E4242
3D44566641333D413C394D43323A3A3B3A3B3D3F40424548423C37383D403D39423E463B
454A433B393F3E3A3D3F3D3E42464C4D463E414A3C4244403D3D3E3C413B3C3F3C3B3D3C
3B403D3A3E3F3C3A38393C3C3B393A3C3D3B3E3A393D3A3E3A3B4140383A403C544D5755
3C384038373D3F3D3D404140403A37393A3A3B3E45453C453D3B393939393A3B3C3B3A3A
4844473E3C423D3F3C3F353A3D343537373F363A393646474144484B48424245373A4045
443F3D3E393A393A41484844443C3E423D3B3D3C3F3D3F3D36383D3C34455363779993A9
97978E8C80695844443E41454C473B47465151656C6F848B8E7D7C7E92A9AAA3A19F9797
95A0969E8FA8AEC2C8C0ACA4ADBABFC5C0C3BFBCC7D2DCCCC4AEC1C5C7D9CEC9BCBFCBD8
D1D0C4B287967D9CA5C7BFAA94899592AFD7D4CEB7B8B6C5BCC7C7BCAFA094928BA5BACD
C9C7C3D1D3DDE6E1E1E7E2EBD8D6DDE2E5EAE6DECFDBD7DED3D5CAB4908E798070786461
5C5051454F52635F817EAA89A49EB6BFB4926D646E6D66665C5E4D413E3F3F423C47516A
68784643486CA4B47A5E484140323D333A3A3D393A39403F3A38353C39353C373F3B333D
39413B3B3E39363D3F555F5A564E423C3932393631373538373B3B3837393B3A373A3933
3033373931353E33333745517D8F918A8679624E453C3F33353A383A313D3C75A1A59A61
484235313A3E3A3A40465A798DBBBBD0C5A680805845445B8A8ABCC4CCBDB89DA9858A8C
99949A9FA5A6A4A28F7A828F95BEBDC7B6D9CBCA
4B4A484849484745454A4B47444546454245484947454546444342434548494843444544
434243443E3C3D4144413F3E413F3D3C3D3E3E3D414242414141403E393A3E3F3C3E3F39
35373B3E3D3B3E433E40403F3D3D40423A3B4045443F3D403C40453F42453D403B3C3D3E
4245444139393C40403C3A3B3B3E41413F3D3E403C3C3B3B3B3D3E3E44433E3C3E3B3A42
3D3B3D393C3E3A443C403E423B403D413B3B3E443E3B423B373D3D404846404240443C3B
3D38383833535165647B7059474947513938323B3B3B45404B3E443C3638363839414F4A
423D3739383D453B3D433B38393D443E393E39413E44424039373E46463B383E3D3F3A39
3D3D3F46424145434A4B41443B413B413F43393D3D4440423E47485153554E4F6B78A4B3
B1A795825F4448525B675647413B3B3E3C3A4032433742424754564D494B515A4E4E4D48
424040413A3C453F423F4E5761655D56574B3B393E393E3A40433846433A3E3E3E454648
3D3637483D3F443E41373D3F38383A3B3E3E3F3F3F4041413B3B3B3D4042413F3A363D35
3F44403A3D3D3C3F464A453D40424445413E3E4043454645403E3F43443B3B3E3E3F3F3C
3740424144423C3A3B3A39393A3C3E403E3D43403E3E393C3E3D3D3B3C444B4A4A434949
3C3A3E363837383A3D4244413B37363A3B3A393A383D38413A383B3F393A3B3B3B3B3A3A
413F433C3B413C3D363A33373C393E4143423E41403D4345514B4644424040423A393A3D
3C39393C3E3B3B3D4041403F3B383D424140403D363F3F3A3C3F404449689E8BA188857A
6D615454524A433B403A3C3C444C474B43544C69697F94A3B59B9A88A19C9E87817A8875
8D81898896A99DA19F9D9999A1ABAEB5AAB5B3BBC2C9C5BDA6A7ADBEC0D0CFD2CDD2D4DD
DCD5CEBDA7AB9DB4C6E2E9E0D1BDAFA2B5D6DAE2D1D9DBE1E1E2D4BCAB9F9A9EACBDC8D8
D6D6D1DCD2E1DFECDEEDDFE7E2DEE0E1E0DDD0BFA4B2B4BAB0AEA5929B917D6F605E5C61
68888D7F7893A5B2ADCACED0A09878796E665D647885888B958B614E4B4C666F8E96B0A4
BFB99D78727B9C88664642383C353F3B3B3C3C3A383A403B383B3739323E363F34363E3E
3746593242353E5B5B5F5647423E393935353138393B49453C3D3B3635393B3B373B3D3B
383835322D372E363D597B8B9388715A4C423C39303F323F373440466B705A7462624E3B
33383C3E39303A527B88B2AACBA6AB857256414A3844587F8AA6B5CEB1A78981637289A7
BCC9B0A48D8A7C746A657B92B0C4D2BAC4C3CCC3
4F4E4C4C4C4C4A4945484A48454545454345474948464442474644444444434243434241
41424446423E3D424746424046433F3E3E404142424444403F42423F3D3C3F3F3C3E403B
3F3E3F41403E4045404141403F3F40403E3C414C4C43404444464741444740423D3C3E3F
3F3D3D3F3B3B3E4445413D3C404344423D393738414140403F4040403E3F3E40413D3839
393C3F3D40433C3D3C3F3B413B3E3A3D423F383C3831373A3E4645495552484954564B45
40383A3B4F7B878773806C56443E3540353D3C433E3F3E363B31454548494037343F5050
4C453F3F383D473B393C3737393C3D34383B3E464041383C4138394044414B5445474239
393B37353F3C3D3A41433F413C40373D3A3F373C3C483D40454F546A8570704B6C668A8F
85786A564440506C757B6451453E3C3E3B403A3D393E373D3840423F3E3D434F484A4740
3E41423F4046485B596972857970594947423A3B4C3E3F3D3F42415259453E3A393D3C40
3F3E393F393B3F3B413C3B40403B3C3C3D3C3C3C3C3B3A3936383A3C3D3E3F404440433D
44474542423E3A3A4044423D40403F3D3E3E3C383E3E3F403C383C445748403E3B3A3934
4146443F403D39393A3D3F3D3B3938373D373A3A3F433C3C434B4E4E4E4A433E3E393B3F
3F4140394139383C3C3F403A423D3A3A3B3D40433D413B423D3939393A3A3B3B3B3B3A3A
3A3A3E39393E3B3B3D413B3839383B3B3F3F44484A4E5662574B403D3E3D3C3C3C393739
3938383A3F3C3C403F3B393B3B3A3D3E3E403F39333D3C3B413B37426996999D68735252
453D3A3A3F403A3A434043424B5C5C54536B5F79688290A293846E6E69706A5D5C65586C
6080748A95AA97958F8E929295898D95A7B1A29C9D98A994A0A0B8C8D5DADADAD8DDD9DF
DFDED9DCD5DCD3E2E3E4E8E3E3E1D5D4D7DACBD1C9DBDCD6E1E6DFD4CEC9C6C8BEC3C3CC
CACBC4CAD0CFE4D4EAD3E2D4DEDFDFD5BFA383665C5961515951655D7C807788747E737C
93959674939EB7AEB2A9BD846C55505D6A76808CA1B5C3CDD1CDA9B595B8A4BDC7D1DDD9
DEDDC4A07372806E6659585363564E453E403B3939363C3B3C3F3C3F3E3B3B383F444E66
576048383C4866735E5543373637393D32413C4A4236473C3E3D393535393C3D36373636
373836333A353740558995A788694D3F3733353C36383D30424569959B75594340383A35
3A39383E4C607E9BB0BB9AAF76804F3E483937463E506388AABBC2AC9E6A615A6688B6B0
CAAA95867D8178787C7E90A3A3BEAFBFA4C0AEB8
494848474646454445474948464545454645444445464544434343434343424242414140
4042444645403F4346464444403E3A3838393B3D4043413C3B3F403D434041413C3D3F3B
403D3D3E3D3B3B3D4342424242414140423F404749454448444745414546414047434344
423D3C3E423E3D40424141423D3C3C3F42423F3C3F41444443403E3C413F3B3A3C3D3D3E
3B3B3C3D3F3F3B3A393B38413C3F393B3B413C41453D3D3F414B474753524D555E5D504A
453E403E4751675A51403B3A3E3F3C4742494A535651423B433E565456544B433E45535B
60615F5644444B373C39373B3E3E3F404C403D413D41363E403B3A3C44475A5E4746453D
3F46413E3C3C40393C363737373A3D3A423D434B545A47484A4C4D5B655A55433F4F4952
4E4844403E3C4252585B47433F413D3B3A3C473D473E40433B403F3D3F3D3B3F3E413F39
3B444641514C595A706C78775B54453F45443C3B3E3840403A393945483D3C3B3D3F3839
38413E3F3C393933343A3F40403F3B3A3C3B3B3C3C3C3B3A3A393939393B3D3E3E3A3937
3C40403E39424240423E3A3F4041403D3D403D383C3F43423F3F43494C3F393A3B404747
5D584A3F3E3E3E42363C3F3D3A3A3C3D3E3D433D383B404D535E5D534C413A3C43413F40
43423D393D34373E3D40433E3E3B373536393D4038403D42433E40413B3B3B3B3B3B3A3A
3A3B3B37373A3A393A3F3D3837393B3B415363655B504D4D4A413A3B3D3C38363C39393C
3E3C3A3A3B3C3E3F3E3B3B3B3E3D3B37373C3D383B383B413E3C506D96918C58523F4D3C
4041443B3A3D383F47464E55607172646677686A4F59606C544C493F463E504650585F6B
748A8D9E9AAB8B7E73727775857F9C9BA89B8D899C9B9B9B9BAEBCCED2D0D6D4D2D4CCD1
C8D3D0DBDAE4DCE1E6D5D8D5DBE3D7E0CFC9C6B8C2BFD2CBDADCD6D2D5D3CBC6B6BCC1D3
D6DCD5D7C3CEC2DAC6D1C5C1C4D0D4CAAA876A4D4F465244595E858AABA6B4B2B1958979
7365516C6F9398A296A87B955576769E9DACB6BCC5CED8E3E3E1E4CFECC4E4C9C9BDD0BC
CEACBEA7AFB3B2B6A9A0807C61544E3F433F4340403B3D393B3F3C3F40383E404F78AF78
7458323F38556F58463F38383B3B3C3F566869684E353C363B393635373A3C3B36343232
3538373637363F4B8B91AD8E75523C373838363B413C384F65827CA26F563D3C2F3D353A
3A373B568AB2B7A8A5798D5D6C4F49393D3E476268819DBAC4B58F735A5260748BA9AABD
B0B19FB9B9B8A69F9F97989CABB3B3ACAAA6A5AA
4E4E4D4C4B4A4A4A45464849484645454543424245474645424243434242424241414141
424343433F3E404343403F41434341403F40414240413F3B3A3E3F3D423D3E3F3B3B3D3B
434041444542424344444343434342413D3D3D3D3F4143433E44413F43433F3C423C3A3E
413E3D3E423C393A3C3C3E424341404041403D394143464543403E3D403F3F4042444441
443D393E3E393A3D3A3A37423F444247464E433E403B39373F464244535859634F4C4344
4341443F45303A3A493D393F3A3F4049474A494F5A5544404640504A4B464444413F4656
5D6D746B5C65705F4D3F3A3E3F414E6286674B433D443C45474E58585B545C4C43373F48
4A453A3F4B45443B3F39403C3837493F56424C4D585947473E40474D424544393B3C443D
3D3E40494A423F3F464B3C403B3D373339403C3F323F374A3F4340404C55534F5453493D
3C4345403D433B48414F43413E3D3B414D4F47423F41494843423F403C3D423F41443C3A
404135323C41464045444E4B4C4E43474040403F3F3F3F3E3D3B393B3E3F3D3B413F393A
3D4344414E5A5144433934433D41423F3D3E3D3A353E423C393E403E46403F403B3C4244
5B5242393D3F3F4244423D383A424848403E45434147506152585245403D3D443A3C3B3A
3D3B393B38353A3E3A3C3F3C35373A3A3A3A3938313C3A3B403C41443C3C3C3B3B3A3A3A
3F403B3736383B39373A3B3431373C3E60716C604C3D3F363D39393C3E3C38373D39393C
3E3D3C3D373F423D3B3E3E3A393B3833363B3C3B42343B433A48728E796B504339413D34
3A383A363A3F41535651555E6368675A5B5C5446413F4A4A3F393C3A494A6869877D9172
8D7582806478676C75858F90938C8C897A837A8D9DA29DA8A9B7C3CBCABDB9AA9E9896A0
B5BECDBDD4C8D5CBD5C8D4D7DCDECED3BFD1C3D6BFC9BBC1B5AFA3A2B1BEBFBEC7CBD2E5
E4E5D8D3D2C9D9C2D9B0BCA3B2C4D0D5CAC0BCAA9FA997B69CC8C1D2DBD9D6E0CBC7B8B2
AD98A7A7BBADC4CAC094B277936D93ABC6CFD6DBDDD8D8DFE4EAE8E9D3DDBFBA99946C80
6491A9C5D2CFC0BAA182504A44444D4E5D575C574341443F3D3F38383D3A4B8096D7B0A0
5E314138394445363C383A3F3E39383952565E50382F333B383636373939373636353639
3A393634393A3D6271A0786F44323033393A353C39476D95AD887C5E3D3D3641353D3735
36384E7DACB89973554A55614C5E39423A4B58798392AAB0A7817165647796A4B3B6C5BE
D8C8D4D6C9C0A8A2A7A5A7A7A1A9A2B0A9B2ADBD
48484947464445454646474A4A4745464241424447474543424343424141414242424242
434341403E40454947403E3F3C3D3E3D3C3C3D3E4341403E3E3E3F40403C3E413F3F4241
3D3A3A3C3C39383942434342424142423C3F403F3F424342404843434644423F3F3B383B
3F403E3D413D3C3E3E3D3D3F3C3F41413F3F4143454544413E3D3F42393D464C4C4C473F
4742444F4D41413F3D3D3C48464C4C5561634F413F3F4241474542465257555544413C40
403F433C4038373D3C43393F3D3E3B4043443F413F413B3B3C353D38403636393C3C455E
6A7E81746B77857A57443E3F3D3D49628A6C4B443E453F45566173777F7A8B798557433E
3B3C496B84746B5F62514F3C4139423A513D413D484B3E41385075829B8F8B6457534E47
403C3D44413C3E3A3B453B43383D3D413F45474F516F748F9E9A897E858982796E665542
393939363A3C4438413B423A3B3C3E464F50494340413F3E42443D38393D4037393F3A3C
39464B4A4F5161657D65635B544C393D3F403F3E3C3B3D3E3938393D41413C38393D363D
4554595363614B3A3C3634443A3E42403D3C3B3B3F494B434046463E3C3B41453F3B3E3E
3E3B34353C3C3A3D49443D3D4956575055484645474742474143403C3F42403E3E414342
414144483B3F3F3B37373635383B3D3C3B3B3B39373D37394944413A3D3D3C3B3A3A3B3B
41423B3837383E3B38383F3A34393E425E624C423B3A483F3D3B3A3D3E3C3B3C3D393637
393A3C403842433B383F3E37393C3A37393938393A354556596A7669594E3D3F3E463A3A
393A404C58544E5A57514C51514C4B454842463F4D484D4341434965758E9EA4AD998361
5B55565F7589848A8D90837D896D7E56796782818B93A0AABBB4BEB59C8D8A8382869AAC
B8CDBFCFBED5C7CDD6D0D9DDDFE1DADAD1C8D2A8B7828D7C83848694B3CBD4D6D1CCCAD8
D8DED6D2D2DCCCDDCAC9ADABC3D1D6DDDAD5D1BAC7B8C7B4CFCEE0D6E3DCEFE0E6D6E7DD
D3D8C4D3C9DBCBD4B5A7829581889DBDD0D3D5DAE0DDDCE2DDE5E5D5CD9F9B744C544C50
5E86AEB8AC937E64706D788C87947BA696B49595645047433E3D455C7074A8A6CFBABE7D
6E626155473F3747403C3D3E393537393F39423A333D414C393737393936343433333538
3837383B3E403D455951563F3A38403E3E3D3A4D5472A0BB805E49383B36343236323C33
374773A2A5815D4C3D44514A463E39393F5358768491A79D6F555F77778F9AA0A3C5C8DA
C7D8CDCBC5C0B8BDB9A89A8C9290A09BAD959B9C
4B4C4D4B494848494745474B4B48464743424243444544443D3E40404143464945444343
4342403E4644454848434040404142424142434545403F41413D3E42413C3F4442424545
423F3E3F3D3A3B3D3F40413F3E3E40434243444544434548434C45444541434045454442
42444443403F4144423E3C3E404142403D3C3D4040403E3A37363A3D3C3D434441454843
404349555146453D3F4245534E4E494F46473C3A3C3B3F3D443E3D404243413A40414042
3D3A413D383E413D3438363C3D3E38393F403B3B373A3A3A3A373A393D36383D48525E7A
828B7B665B5A5D564B3F403F3D3B39454B45363D3A3F3F434D4D56575D55746C6E4A4543
3F40445C6D656C728478775D3F3C38424A4A454B3E4945535A88C0D3D0C1AD9571957B83
5F4745433D43443D373F36433D4F5D6AA491AF86AF95A6A3BCAE947E756959514945403C
3D414648393E3A3F363C37393A3D434A4C483F3840423E444F493D3A393B3D3A40454148
4E6A878A7E6D7A7D6B52504F47423A3B3C3E3F3D3B3B3F44414142434342403E3D463D46
51686D624F463B383D3C3B3F3A3C3F42413E3C3C3C42423C3C40403B3C393D413D3A3B3A
3538393B3F3E40484042434855615E544C454745413C383F403C3A393A3F403A3D3D3E3C
37383D3F414942373B3E3A393A3B3A35333538393D4A4F566B5E4E3D3E3D3C3B3A3A3B3B
3C4039393A3B423F3B3D4F524B4945473B3D3A43484340363F3A383B3E3D3C3C3D393738
38373B3F393F3F39383C3C373D403D3B3B37363D394D62727E7C62444A3E3F2F413E414C
566261636759494442433C40433E4242414145474843403F51507582A39CA4987967503F
44566172949C93887C745C5B6365656465758492909990A1909884837C72777D8078878C
9EA0B3AEC8BEC5C3DADCD9D9D3D0D0C3B3B6A8AB8F8E8F9698A3ADBBCED6D2CFD2C4B9C5
C7D0C6BDC6C3C4B5C4AEA4A4CED9D4D2C5B2A48270766D9699D9CFD5D5D5E0DBD3D1D6CB
CCCCC8BFCED3D7D5D2B7C0ABB69CA7B4BEC1BEBEC5C8C6C7BFBDB0B48B8365634F738199
93A0918A637395A7CBCDC8C6D0BBB692AF868B716A504546506992C1C4D3C6D4B6BA8B9E
737F58593B343040413A393A36393F3E3C39393B38393F3C3A3737383736383C3C3C3E3E
3A383C423B323B33383634383532342F38424B73A69EB08556403B3D383B30453140404C
4C6694AA8C5C3E36363B40353B3E415066716C777D80846B513A594C6F5D8A93B6C4C2AD
A0949E998C8F9CAC9E806E5A727C708B74795D69
494A4B49474546474745474C4C494647484542403F424547444443413F3F414348464342
42423F3D4B443E3F41403F3F3F4040403F404346443E3D42413B3B423F3A3D413F3D3F3F
3D3B3A3C3C3C40453C3E3E3D3B3B3F4247424145423E434D4049403D3D383C3A3A40413D
3A3D41413C3C3F413F39383A3E3C393B3E414141404242403C3A3C3F38393E3D393E433E
3A3E3E443F3C443C3E454D5D544B3D3F4641393D3E3A404139363B3E393C413D383C4042
39364241473A3E3242353F3B363A37363D3D393C413D3A373739393A3A3A4247535C5F73
65675346454142423E393E3E4042393939423D463C393E42473E4242402B49454639433D
3A443E414B42474A5F5A69584B574F6E627160705E6D66717697BEC1C8B5A87A8B7C9C80
845C574F49564B3E3E443D59668FADC2D0D1C6CFB7C08F90655B4E494A423C3F3F3F3F40
3E3B39383E383B3F453F3D3B42414142403F3E3C3D3E353B463E38423C373A445C717F94
767C827662494E48463D404339393F3A3E42444341434B515454514C47464A4E4D554240
404F4B394C3D383A36383A353E3C3F4547423E3E3B3B3B3A3C3F403F433A383A37383A39
3B3F3E3B393740514C52544F4E514F4949404242403D3A43403E413F393D403A3B393D41
40475153525A4A383F433A363B3F3F3B393A3A3947677E84896952423F3E3C3B3A3A3B3B
373D373A3C3D46424A4F69706252403B3A32343F433C36393C3634393F3F3B393B3B3C3E
3C39393C383A3A38383A3B3A3D3E3B393B393D4A4D737F78745B3C36383B3D3E4C646785
6B7F6D544D49453B3D463D3D3F383A3B3B424248363E4358646070746F67595343453E51
59766E7B797C74665B5C4C59544C5E56847D8D798D7F73635A5D585C59525761614D524B
525E6F9BADC3B8C7C2C8BCB9AFA8AE9794859896AA9BB5A7C6D0D3D0CFC8BDB9BBABA2B1
B3B49C87888F848D98A89BB4B8C9C9CEC6BDBA9F9F92ABA2CCD0CDAEC3BAC6B6C0BECEBB
B9B7B5C7C2D1D2D7BEC4A8C29CA5929F78817F797C7C71676D5B625B684F6F718993AEA7
B9A1B2BCC2D0D2D8D8E5CFC99BA47D7F595A4950585C636376A0C7E4DBD8C7A696726A51
4F4D4E48413E3E3C3D363638393F443F3A41363E382E3D303A36343536383F474C505454
493D3B3F3839353D373434393C383C435F717CAC9C986A493D3938363C343E5259627181
828F947C5847403540303A354A675F887D7763585861624B3E4A5A65746B8DAEBFAE888D
86868185736E767E664E4E47554D5047513D4043
494A4B494746474943424447464343464343434445464748454546484541434946474746
4543403E41443F42423E45423946443E42403C413E3F41423F3B3E433E3E44463F3E4241
3A3F423F39383C423F3E4043413C3B3F43443F3D444440423E3C423D403942473F3F3F3D
3B3B3C3E3B4044423D3A3B3E3D42403C404342433D3E3E3D3B3B3C3E3B393B3F41404042
3F3D3D3F3E3D40463B494851453F3C3B393A3B3B3A3A3D3F444A3E3B3B363E433F3B3E46
48423C3B403E3E3F3D3A3A3D3A393F4039393F403D3C3E3C3A434A444D53555D52524A4D
4446434447403B403E3B373D4640393D40494E413F423F4B4746403E403D3F47393D3D3F
423D3C42383B3B414F534F4F745E785E6E555D474445454A464E5A6A6F7E87847F7F7A71
51453F3F3E434D513F3D43516B83AEB7C4ADC2B7C7AEA878434C414C3839423F3F3B454A
4F4C4D4241474347373C3446453C413F3F373E3C443C4A394A4C43463E4F55779A919C7D
7150463E443937403A3D46443E42393D3E414549515D6D787E6A6054575456494D444040
3B393D393F4141403B3235443F433E3F35473F4442433D3D3B3941423B343840403F3F3B
46363E3B4E5F4F5C58544F4141473F423D433D4A393B3844443B3E3E424741453F424E53
5666674F533D3642433A36363A383A3E3D415F4A6B7F81755E5745393C3A3D443D3C4236
3B3241404D6C798661806B62513C3942383A3C373836443738373C3A363B3E393A433E40
423A3838382F393C3D3B383F37393B425069617D5759645240443B39334B646687688872
6358464546403E383B3A3A393A3E3E373C3E4348423A3C455147444746403E41435F836A
7A575E584D4F4B4B453E45494B556B756E727A745D514D4D48494E4D414346494A4B4B48
45587C84B7AFADAAC1B7A3948C94A5A692A39EB6B7D2C1CBC2C3B7BEAEA187858A8E8B90
9E8382727E789C90B799B3AFC4C7C3BFC0BFBFC5C0CCC1D6CCDAAE917877A6B6A7B0BBAC
ACB5BEC4CBCCBFAFA499ABA0C2B0A9816C5644464D505155535F7274828697BDC0C7CDD2
D8D7D7DDDAE7E5E3DCBAAB8A71615B716F6E7998B9BFC3C5CAD0D2D0BEAE866D4D403F42
3A3F3947404B404138413843455E674B4C3D3C35393D3A32353A3A3E5665879492857B66
484136373B3B3830373E363B373C3F5776888A78735B3C423D3938384C5D76929196969A
7F7B6457413A34403C3A35557D8782735454413E44453F505A6B889195A398A29A8C90A3
979F9E9260484B4B403F3D3F3B393E432F38363C
484849484748494A47464749484546494645444444444545454343464846464842434444
4444444441443E41413E44423F49464043413E44424142423F3C3D413F3E43443F404443
3C3F4243423F3E3D3E3D3E3F3F3E3F423F413E3C3F3F3D403B393F3F443D3F3F3B3C3D3C
3C3D40423A3E42423F3E40423F44403B3E403E403B3D403F3D3C3C3E3B3C4045453F3B3A
39393C3F3D39383B393C3D433E423B3D3A3D3E3E3C3D3E3E37403C3E403B3E3F35363D44
443F41484A423C3B3C3D404336363C3E3A3C3F3C3D3C3F414149575F796968595B424340
3839383A3E3B3A403F3E3B3F433E3B423F3D3E383A403B3F3C414241403C3D463B3F3E3C
3B393D4848453E3F4E5B646D6A6050553D4744433C3F394C4B646E807D73645A54504A44
403D424846444441413F40424847575255595C737D9DA6A9758276815E5547444D4E776B
85636B564C5A5D4A4A4D433E403F46443E3A4144464C61666A887B6B56685A8B6A7C4E4E
3E3C43484D4142434339423C433F41474346494D525A646B5A4C483E403C413A4039393D
3C3D413F393D3D3F44413C3D41404D464840404346413837393B3D3B3B383C3F3C3D403F
3F3E4F5C6F78686B4B4743393B3F393E3C3B39443B3E363F3A4C616766645C56524F545A
5A5D57463A4541393F413A383938414F5E657157615C4F443A3D3E3C33393940413C3E3C
3A3A5763899CA6997D6A4743413F363936323D3E453E3D37383A37383C3E3D373D433D3D
3E38393A403B354142463B3E39343C546C8A8C594241463841314F4661857F9D6E68504C
44423C424440423F3B3F3D393B3E3F3F3B3C4246423B3C4348413D3F403D3D3F587C706B
4E4A486746443E4041424D53635F615B4D4D514A49434446423F403E3C3E3F413F3B3F49
68A48CAC8AA18D96968C767A7571898C9D96C4AAC9A7BA90998E877E79615B61688997B1
B0A6A6A693ABA0C19AA890A89DAAB4B9BBB7B3B6BCBAC6B7CDC2C1AAB3A8CBC0BDB1B8A0
9CA4ADB4BDC1BAADA7C2B7C7C2C49B9967666B798998A3A9ACB6CECAD7C7D0DEDEE3E5E0
E5E1E2E4DCE2E0DBD5B9AE96A3ACB7CACACED0DBD6DADEDCD7CEC2B995836C6862666063
50524D544B4F4C5454524552586B613B3F303B3A3C2C384039576877A0B4C1BD9F7E5C4D
373D33393C3B36383F3E414E544E505963655D5747343C2D403E506281A7B5A48B968E78
51463D39422F3F2C343555777B75654C3A3E343A4C4A7D76919AA5A3A88F948A9CA0B0BE
ACA3907A473B3B38383C37373A4232333E3F484C
48474647484A4A4A484848494846474A4645444443444445474342464949464444454543
4140424341433F41413F4240434B464042403E4446434142403C3C3E413F40413F414545
424141444645403B403F3D3B3C4042413D41403E3D3B3C41413E42444A4442403E3E3E3D
3B3C3D3F444445433F3D3D3E41443F3B3D3D3B3D393D41413F3D3D3E3E3F434849444141
3E3C3B3B3A3A3C40433D3B3E3D473C3E3E4243403E3E3D3A3A3F3B3D3F3C3E3F3C3B3E42
3E383B44473D3636393B3C3D4744413E414D56545E5F5F60606270837D685551483D363B
3D3D3A393B39383D3A3B3C40423F414A4A3C39393D413C383C3E3C3B3B383A433B404140
403F4655605B514B4D4E50555041443A443144373C3F4F5F73777C7A6E58454143403F41
3F3C4044403E3E3C3938393A3B383F3A40433E423E4E565F61718992967E78736F838996
837E686A80A58EAB7F954B424343444646576870968EA383908588736F696E665E443E3E
43453F3C403D4A475C55505D53584B564848484849494A4B4943453E3F3B4240403A3D41
3F3D3B3B40443E363C44423F504E47533F463541413B38383C403F3E393A3E3D37373A39
424C58656A5E504A42403E3B3F3F3A4041393E3E3D403E4A5B82A1A4927C664F574B4548
4B47423F3D3F3D3A39383F49565D6E7072665D47483936393B3C4342353D383A3E41566B
6E6D7E798B7C7A5C61463A342F41363B46373B37403836413B4B474744393A3A373B353A
403F3F3A373E3A3A3A37333B423B4D6D6F8758493C3B373D42456369A18D8365513B3D36
3B3E3C403E373A383B433F393B3A3B42403F41443F37363A403D393A3E3F3E3E655B543A
543A4644403F393E403F46484F4948463F41433A3C3A3E413E3C3C3B3D413F3F403F4E68
9AA0AD6B6F5D5E61725D5A57586673858DA78CA57E8360554D574D634C5A6089A3B0C5BB
CBA8B3A4B2B0B899936D777D839BB2BEBAA7948D8A988EA696B0A4ABA4B3C2CCBDC8BDB9
B3B6B9BCC2C2B3A1A4A4C0A6B294A69EA8B3BFC7CDD6DCDDD2DDDDE6DDDDD9DCDDE3E5DA
DFD9D8D3C8CBD8DBE0D4D4D1D4DBDBDAD5DBDDDFE5E6E7E4D8C4B1A79F959AB0BECCBDC0
A7A39F9D96908C8E846C525143434039403F3A46323B4D696C99A6999B9087836A4D4837
3C2E373B333C3A4B5D677776775E50453F3A323B36393D53598A7EA2BAC7AF7A55605B41
3F3A403734463E3A403A5863544B3E353A37384A57899AA99F8B82817791798191979C9A
87796048493E38373A3937433E415449725C8D75
4A474546494B4A4847474746454446484243444546464645474544454745423E45464745
403E3F41404140414241403D4448443F403E3C4147423F403F3D3C3D44403E3D3E404343
46423E3E4142413E42423F3A3B40403D3F4446433F3C3F44444243464844444440403E3D
3B3B3C3D424241404040404040423E3B3E3E3C3F3B3E41413F3E3E3F3C3A3B3D3D3C3E42
38393C3F40403F3F403B373A384138393A3E403D3E4343403F403D3D3F404243403A393E
3E3A3A3F3F3B3A3D3F3E3C3D4042434654676F6B687174726C5D555B5E523E453C423B43
44423F3D3B39383943414041403C3B3F4536353A3A3C3C3841403D40464139393D424345
4744465050504F4E49413A383F3E314C3C4A42435662617C6E765B564E433E40413C3C41
4B4543403A3D44463D3B3A393A3A40403E39413F3F3E463F4E5C5E726C6F5E697984A28F
9D70695B8B808C71855A575D5A5B60788DB3C2C3AFA07C7A72786B7F6A7F5C7E4F52444D
4D4C4850626F7B79897B7D6D6E54514C45434241403D3A373B393D383B373D3C3F393E42
423F3B3F3E443F3D546F746D725C5144443E393B3C3B3D3B3A3C3A3C403F3E3D3E474F52
595C5250463739373F3E3D3F423E3940413949424446495B63879B9B866C573E483F3639
423F3A3F414246434C748977797A7F6657453C39372D3940443B3F3A3E3C393E4150748B
87786D5B53424337394335453A36453C3A393F383D3B547874807165523C4242383E3A3D
3E3B3B35353C4138443D353B415A5C4D5547413A39384952536972857C5254393F393D36
393D3A3D3B373C3B39423D383D39333B3E3C3C3E3C38383B3B3C39373B3A36343F3A4340
443F3D373B41434B4B424240484345453F3D3A314140403E3A393A3B3B4543444E556784
77795C483C4041504D636F8B989CAC9C95837F5E5F52415453525E5D747595ADC7CBB7C2
B6B8A79C8D8D737F5A6E697D84919A9C998D82828F859E82A3849A8E8C99B6A3C2B4C4BD
BCC0C1BFBDB8A9989CB0A3A4959F9FBFCDD5DCDFDFDDDAD6D3D4DAD1DCCDD8C8CED6D9CB
CEC2BCB1ADAFC5CCD4C9C6CACDD0D4DADCDEDDDDE7E4E4E4DBCBBEBAB8B6BFD5DBDFD4D8
DAD3CEC1BCAA9A896F5543463A3B3B443A3E48405266939DAFB0906B5F5346423839383F
394654685E68677F96ADBD9C6C54423A383838403C457679B8BABDBCBB986D4E3D3D3D38
3B3938354877574E3E3A3E3A3A37303F3B3142589AB18E836C5762608B85906E7C746559
524C3D3137363B3E3938558081A373856A8E85A2
4D4A4747494A484648484846454546474143464848474544434445454342403E40434646
424041423F3F414344443F3D44464341423F3D40453F3C3D3E3D3C3D45423D3B3D3E3E3F
42403D3B3B3D3F4041423F3C3D41403C40454947403D41453E404245413D3D423D3C3B3B
3D3E404042413F3F3F3F3F3E3C3F3D3D41403F443F3F3F3E3E3E3F40403D3B3A38363A3F
37393B3D3E3F3E3C373C37403B3E3D3D3E3F3E3B3B3F413F39393D4042454545423C3A3E
3E39373A3736363737363B41444D555C6971685A58605D555149403F433D40353F38403C
3B3B3B3A393A3A39443F3E40403D3A363934383E39384042443F37373E3E3A3D44444141
443F3A3D39373B403F3C3C3E4440444D4C5B616D78726D5B54433D353E4042423E393636
3F3E403F3B3D413F3B3C3C3D3C3D3A3C44413D423D4444465A504F445B58646B737C7975
6B5D4B4A514C424A424B5E96969698ABB3C0B19E90675845674F5949424B474646334138
37415D7987867873686A5858414237393F3E3D3F4142403E413F423D443F424042393C3C
3D3D3B47545C5F6D93B0A79167554D3C41403F3E3D3C3A3A3B3E404247413D455C778B97
9281604F433B444441403B3D413F424B64576455534B48544D5A5B5D5549453A3E3F3B3F
49463D3D3F47515D7A9FA185625B5A42403A3539393138373B39413D3E3745564F566C66
635042433538343C3B3932403D3B373F38363A517B8386818073564D41384036363D3937
3335403F43443946516B525B42584249353F3B494149776E75635E554832393F35473A3D
383B383C3E3C3F3B363E3A3B443E3437413E3C3A3836373A373D3C3C42413C3C393E4A47
40514C534E5455574E3E3B38444142413C3C3E3D3B3C3B38383A3D40334A55585F594F52
45483640384C51709093AA9E98A0897E6D5746423B43646A7A836E847BA19EB2B8A7AA91
A4868B726E62726E7C7E9B9B9C9B928D92979EA89F9B989B99978F8C96A89DA9B0C5BDC4
B7BCBBB2ABA9A6A0AFA5B7ABA79EB9B6CAC8C9CDCBC1B2A9A7AFA1B1ABBDBBB6BBC5C7BA
BAB0A89E8E7E888B9B9EA1ABC0C3CDD5DAD7DBE1E5E2E1E3E0D9D5D5D1CEC1C7C0C3CCD9
D3D0CCB7B09A866C5C524E62728372615D615F737B9CA1A18273543A363C3A3B3B455D55
777FA0A29F85758DA2B1AC7B44423C3E4141433F5A8B9AC9C3CCA29C724E3B41443B393C
3D39334A8F9E8A4F36383A3A3C383238364F5083AF8A7046495972A7A39C7E5E594E413C
403D3837383A3C39385288B2C196875B56729BA2
504D49484A4A4745494B4B48474848484546484A494643413E4243424243434242444746
44414040413E4242454741404544434444414043443F3C3D3E3D3D3F44433E3C3E3E3B3C
3B3C3E3E3C3C3C3D3D3E3E3E3F41413F404347463F3C40423B40444A423E3B3F3F3D3C3B
3D3E3E3E444342403E3C3A393A3D3C3F4442404543403D3B3C3E3F403F3E3F413F3C3E43
41403E3B3B3E3F3E37433E473E3D4040413E3B3A3A3C3D3E3C383D3C3B414345413E3E40
3D35353B3B3A3A3C414B5D6C5054545660645C53383E3D393B3D3935393D403A3A393A35
38383A3A383B3D393E38393E40423F39393D40433C384143383B3C3F433F3C4148443D3D
42403B3D4039393D3B3A3F434D5D5C715471667D575B494E38453C423D3F3F3C3B3E3D3A
35373E423F40413B3A3C3D3F3F453E443A3E3D3647434C5A4E54495F61756E72695F4E3F
3B393C403E3F3D413B454B657571707675776C5E5846394E47656E4F5045553E4E484E4B
435070857B674B4D4141443A443C48423F3D3D3E41434342413F403A433D3F3D473C3E3C
40434255717B7C7F8F937D6452545354474B3D403B3B364456637170766D65718A9FACB5
AE937764584F48403A3D383F4D596B79856E685450453F44413E3B40413C3B393F433F3D
434139383D525C6B7E7056553F383F3741413C3B403D3A363B3D403E3E445D6A51464D3B
403938423235323F4349423F3B413C4E3E5B7C939E8576615747353A3D3F463943433D42
4D5D6D69827992728D615B4A4E494235443D426F7F84837362464B393A33414841453633
393D393C3E3C3B323539393F48443A3B413F3D3B393A3D403F44413F433F3C4342534C5A
587452594D4F4B4B433A3E403F3E3F3F3B393C3F373B3B393C3E3F414451504849463C38
3C3944494D71688C8B8F8883715E543F41443B3E53618D8B89868371828693928E847274
615D4D4754676C9B83A7A0AAA6A399949A9FA3AAAEADB9BAC8BEBDB5BABBC3B2D0BFCDC4
BAB6ADA5A8B0B0AAAEC4ABB0A5AB91A59290939B9D9282787D7D7C78898D989486929696
989B999B8D77787E9CAFBDC8CDD4DBD4D0CDD6DBE5E3E2E2E1DEDCDDCAC5AEACA4AEC3D2
D8DBDCCBC5B7AE9F9C9C9AB1C1CAB49A866470708A756F64464B4940373B363B47738DA9
B6CBC2B2865C4E5F635F5F59616F70767D879899AFC4D6C2C894886A483E3F3E3D383D3C
3C4259748B8A6F483E353C3B313B453E798578885F434242656EBFC3BA79644A3F3A3A3A
3D35373B3A38323F6494ACA1876B544A609596AB
514E4B4A4A4A4846484B4C49474848464848494948464443414241414347464245454645
44424140453F424044494445454140424341434545403E3E3F3D3E414244403E413F3B3D
3A3B3E40403F3E3C3E3D3E403F3E3F41424146463F3E403F4043444C44433D4042403D3C
3C3D3C3B3E3F4040403F3E3E3A3C3C4044403C4146413B3A3C3F3E3D36373B3E3D3B3E43
4042424141423F3A373F3D41373A3A3F3B36353B3E3F4145433C403B363D40453D39393E
3F3B3C4248423D3C3D424E59524E433D4244424446423E3B383C42423E443D473B453A3C
3D3B3D3B373C3F3A413C3D3F3D3D3D3738413E40403D403E414445474A48484F42403B3C
43434247443B3C4444464D5163677D61694F5B534446464241403E3A3E3E3B37373B3C3A
4444494A484A4A4243433F3D3A3F353E47515853685C5F6B6D76737871665C464740413D
413E413C463D373C37473F414A403D3A393A403E40363E3949588C7866666F7973785E5F
42475368655F5459414134403E434240403F3E3D3E3E3E3E4141423A423D3F4246404D53
5C605C70838A83756A5E514A5E5B73676D4F49433E4746637E8EA5A19E8B767277716A6D
7A67675C535245456D716461666D7C836A56493F3F3B3B3F39383E4243403A3B42413D3A
3C3D3E4150646458534635323E373E393F3D403D3F453F3D3C3A373F41515B58453A3E37
38393F3E3F3D565E6E90645D46344C445E6F8B9085634C363B38373D3E3C3D3B434A556E
89A1AFA3928D7A70655B6873768A524F5B748A9E9D9271674B414540383B334137463B3B
353B383A3C3C3E3737383A4043403D3F3A3C3E3F4044494C46473F393C373A4A4C606D5F
74584D4647453D3E3B363A3937383B3F3F3B3A3C4246413B3E3D39393D41403C3E414241
39424E5C707375757C64614E3F403842383F46454F806684616652605E776B6E55444F46
52425150707694889B84928C97968F8B8F949AA2B0BDC7CFCACAC5C4C7C7B9BAAFA8A6A5
A5A4A1A1A9AEA597978C9A6D836174666C717675716B625B5A635C66626E5E6658676C79
7985848F86808B92A5A7AAACAAB2BDBAC1C3CAC9DFDFDCD9D7D8D9D8D8D8CAC4B9C4D0DD
DFDFE2DFDDD7D7D6D2CFC0D2DBDDD2C2855A5A55594B3C40403C3636373C374B8FBAD4D4
D4BD9A6E483A404040465E93B2BABCB9BCC8D4D8D8D8C0B18D84655E463E3E35373E5359
80889B845457353D3F313C3A3F64787994757651494A638088A3B9C28A55563D3C393F3A
3A343A3937414B6F949C8E75795B766C9A9AA68E
514E4C4B4B4A494744494A4745464542484847474747484847454140454A463F41414143
444647484840423E424A464A433D3C3E3F3F4246474340403F3E3F424044424144413D3F
3E3C3C3F4243413E413F3F413F3B3C41454246474140423E44423D443F423B3E3E3C3B3B
3D3F3F3F42434443403D3B3A3B3D3D40433D383C47413A393D3F3D3A3C3C3D3E3C3A3D43
3F3F3C383A3E3F3C393A3D3F3842404A453C3A3F3F39383C3D3944423D434346483D373B
403E3A3A3E3A37393A3A3C3F3A3C393B43423D3F3732373D38373C3D3F383B3942393B39
3B393A38343B403C3D3B3F3F3A3C413E39443D424E4F4F483F4040454C4842433A3B3A3B
403E3E453F3539454A525F65636A584E4143443F4042393C37423C3B3D3F403F3D3D3F41
4A4A4C4B4748453C393C3C3E3D453943576A648476836B7767725E64484B45353F3A3A3F
393E403D4B353D3C413B414142393F3E41393D3A3D45383E443B4F5649576387897A685C
4345476D84908B835C4B383A423B413E3F3F3F3F3F4040403D4041383F393F454F4F6571
7B796A7A757569574A403E4452506270716153554B5E6181969BB1AAA98E6D5D55463C43
3E34493F3744465C6D7260554F4A504E4E474143413A393B41424C4742403A3F43414347
48494E5489604D4A39343E3F3D353C3C423E403636433D3E3D414865414F3E333D3F3F41
40434F4863597E6F857B6E5448574C5C6058655A504442413B3E3F3E3E3A3A454B637E97
A0A3A39282706E678F6A8A719369505D7299A89999726849483A3B3D3A3F373437383E3A
3A3F3A383738403D3A383C3E3A373A3E45484846434243443D3F393B474D5C787F88555F
464B3B433D3B363E433F3E38403D3C3F403B38393B3F39343B3F3E4038393E413E3C3C3B
3948607E717A464B42393F423E3E3C3F49484647504A604E4A4E4B4946413A3C3D39484E
473F4B5A5E7B597A547756725A606265707D8B99ACC0C1C5ADB6B5C1AE988A81877E9089
92A2AFAEA4958170767A6F5B4F4E5051505D61554A494947484E4E4F575F56665B6B6D7C
737A727E778092929285888B9A8D868196A7BCC2CBCBC7C1C0C6CACACCD3D5CBBDCBD0DF
DFD6D5DDDFD7D6DADCC89AA1B8D1D3BEB285875858454042404241443F425494B4DADDDF
CCB37B494340443C608B9DD3D3D5DFDDDDDED1CCCCB4AD826B604B49543E404E667392A6
AAA48E4C383C3E403C3C4E4F73A1A0AA6C71535E778A9EB1ADA5AC7A523A513C38343A34
38383E343A58789C9871789F86938098949D8788
4B4A49494A4B4A494542414346484542404749494C463F4042434442403F40413D424441
4144433E4D4843424445444342393743423C42403B3D3E3D3B3C3F433D423F42413C3E3A
3B3D3F40414243423A3D40414140414140444444474B4A45403E3F43443F3C3C3B423F3A
3D3E3E423A3C3E3E3C3A3A3A363C3F3D3C3E3F3D373B3C37363A3C3B3B403B40403D4441
3D473E3C3E3B3D383A3C3F403F3F40413E4040464A423C42353E43443C3B443E3E3C383C
413B38403C41443E373A3B333B3B3A3837393C3F3E3D3A3B4146423A3C3B373C3C373C3D
403B3A3D3C393A3E37373B3D3C4141393A4046544F4C403F3C3F423F3D474A3F3A373839
43473E403146515E6A54524447433A3D413E403C443C3E433F3F4342433A3C3A3E413B42
403D4946433C4B513A443D40453C3E4962646B6468616058504C40414E493B3A3445453E
3F39343E3D3C453E363D4041413A3E393738374342433E3D3A4246524E717987765C5845
36474D6B8A989D85704E45403E4A49423A3A3E3A3F433B423C3B4145404261867A97778D
6661574F4C414651454660659B6C5B50504A4A464450585858616C73725E534E433B3C3C
393B42453F414A484848443B403F4D4A433D3C3B363B394240535E53515B554945445B7C
769982915E5B4039423E3B3B3733353C3E3E3C3E3E41515A6651554F5643413E48565C5B
5D616C6F78848EA7999C79936D866B795F5048443E3D3E3A3D3D40353D3F465058818588
766C6B667895969A7677525B4B4F50668AA58D8A6D5E4D44403C3B3C36383B3C3B3B3C3D
38353B443F323542383A3E3738444A515C69595B40443D3F3D3C485C687E8C777B55413E
423F37413E3A3E403D364539353A3A3F3B2F393D3D393633433B39383C413D3C4446403E
4D6B6A6F64423B3C3F3D3B3F3D383D3E574D58543E433A3B3537393D3F3D3B3939384245
3F474F485146414446413E404E62728284849398A4AEAC9B9C8B81816C675780888E98A4
A5B7B0A492867980807A605C4846464C5759615E686260565B5F837D8D78797689939286
8B7A7C8F828A928F928883857C826881779B95A39DA2969F999A9C9AC0C1CCA7C2B8D3D0
D3C5C5C3CACEDDDEDDD1AA99A7C1D4C7A5BDA1B89BAB85AC95A69A998A98A9BDCCDFDCDA
D1BBBB9393727D7EA892C6C2D4D5DCD9D0BFA2927F604B52444D605F4942475B758DAAC2
C18D553B3D4342405F5C898DC1B5C7968D8899B3BDB7BCB093876B46394A4C3B3A343B3C
3B38353D466B9B916966877984768B8A98778570
4C4B494A4C4D4E4E4A484647494B4A494E4A42414746424343434342414041423F414241
42434442454543413F4041413E3F4047423D423D3D3D3D3E404142433E423E41423F4340
3C404343403E3F413C3E404242424242434345494C4B4948433F3E40413F3E3F3C42403B
3D3E3D403B3D3F3F3E3D3F413A3F413E3C3C3B393C3E3E3C3A3C3E3E383E3D41403C4342
383F3B40433B3B39393A3C3E3F4041423A3A3A3F443E3A423B3C3D44414049473E3D3B40
45403D4544444640393C3F393C3D3C3A38383A3B3F3D3B3A3F44413B393D3D413D384146
3E404141403E3B383A383B3C3D4448433C4146524C493E3D3E3C3F413F41433F3A38393A
454D474C4A5A5A56543D4441413D373E3E373C3E3F3D4045423E3C3A423736363D433F43
393C443A383A443F364142526665605F5C554E414442443E373D3D4450493C3C3C413D3B
3F3C3E4B4542473F383D3E3E3B3B434242443D3E40434A4663557C718D7977614E404647
53636572776E68534D3F403D393F3D393D3B3C383E423E4564655A453D5480A3B4A1926D
645A5856485768767A6E779B91604F3F3834393D393D40404145494A3F38393B383B4142
3D393839393C403E3E3E3C393F3B423C394136483450414E435250534D4043435E5E987F
946E675641413A3A3F3F3E3E384242434045505A5E746E8A5E604756606C7B867D857E83
8287A58FA99BA8A8AC96A0809A7885746856484138373B3D373C3C4541484C635F6E5C5E
5F718A96A5938B6F4E413F3F3D56747E9472765948413D3D3E3B393A39393A393939393A
39383A3D3F3C3834383B44465062686E715F5C534E5B516162656B7A82827B684E403F3F
41403A3F3B36393A3935443A3A3D373A3A3A403D39373A373E373B3E2F3B414244414044
666D5E564D3A3C403B3B40413F40444E614A4D3C3A333F3A3A3E373B3B38403D48454A49
404448403B3439433D3343616F828F9D9E94918C8A7D805B654E5F57567078989CA9ADA2
9B969775886D6F67605A695E756076707B818C888A84847F8598A2ABA39A8EA19DA197A2
9098919C918E9A909B8D908A91718D769A80A6918E8E8A88808784898092859B97BBB3BB
938F85ACAED0C6C8D0C1B7A7B0C2B4A69990C0C7DDCAD2C1CEC4AC9EA7A6ACA6A1BEC7DD
CBD6D8D5B5BAA0C49FB3B4BEB7B9C2C0B59F80705F5B5F4F657D9B8085687C8FB095AFC8
AE704A3E5D827C82768E8ACBB8CEA9A69E9D9FBEB8B69D81464440343340433836383C36
323A3F4A566A6F62595B665D608691A3797F7978
4947454446484949484745454547484950494243494742424543424141414141423F3F42
42414245444A4C474344454542474647433F403645423F3F41413F3C44454041413F4441
3D4246443E3A3C403F3F404143434342474343494A47464A45403D3D3E3E40414448443D
3B3A3839383A3C3B38373A3C393C3E3D3D3E3E3D414040403F3E3F413E4241403B343737
3A3D3B43473E3D4142403E3D3C3B3A393E3C3A3E403D3C42423F3C44443F45433D3C3C3F
403A363B454344433D3D3F3B3B3C3C3C3B393A3B3D3B3836393C3B38373C3B3C3731393C
3C42433F3D3E3B353C3C4144444647403E43444D45443C3D463E3E44423F444A403E4042
4F5A596053574F474636403D3F3A36403E353C453C3F4043433D3838403534353B403B3A
4342443C3C3E4744414F55687C78685A4E463F383E3E3F393B3F3D3E413A343A403F3D3C
3D3F3F3F3D3A403E3C413E3D3C3D403B3C413B36404D4B8179B2A1A684674F493A596C82
7B7A68605446473F3E3E423E3B3C383A3B3B3D3C454A474D636B6550495B727E7A6F4B51
496A7580878F9DA6A2795567633A3F4141423E3E43403E3C3937373A3A3B3E3C383B3E3B
3A3C3D3E403D393B44433F3D3E383F3D45434A474F544E4947414A464343435D626F766C
564E38373C3B413E38393C3F3D445F5389748E7A927B8E6C93789894A9A9B2A5ACA8A8A5
B0B8A5A5899887927282708D68784F4D493F3D41403C3D3D3E3A3C49636A788378786980
95A5A69E835654473B3C4C3F698191A57470524C403E3C3C3B3837383C3B383737373837
383E3E38373E3E39383D50606D736E706664687B6F8A7385827769686459524641424743
42443F3D3E3A3D3E3C3A443B363E333A343F3B363A373E403F383B3B3B414442403F444F
6D604C403A383D423A383D3B3C42444F4B45394537413E3E3D3E343F47464B4045414443
3B3D413A3833353A3940628888908B8B87776860574E4A3C444A5D617F8D92A390827B6F
6A6A6254584D4440566F6E9D8CA08E93828F9D9992888785A3A7C6A7BC89A2A7B3ADB097
A8979E94A1A09999908F878389897593839C8D9F808A75776F6D7D7779677D588E74917D
6D668088AAA2AB9DB9C5B2B09F7D6C474C5376B6AACAB9ADB2B08B9E959F7B6A626BA2AD
D0CADBDADAD5DACDD1B9C1A5ABA5AEBAC4C2B2ACA8B89D946B827F7A787D7C9894A6A6B7
A6907285A0A3A18C9181B9A4D1A9CFA09E939D9BA88A7749413B383A3A3C3D383C3F433C
343A383D4C5E493D44433E4787ABD89A915C6D4D
4D4B4948484847474A4A4A4948484A4C4E4C4A4C4C4742424542403F40414140423E3E43
433E3E433F4648433F403F3D41433E3F403F4037403E3C3C3F41424144453F4142404442
3F4041413D3A3C4142413F4041424140494441424241434645413C3B3D3F41423F41403C
3C3F3F3F3D40413F3B38393B3B3B3C3C3D3E4041433F3F42413E3E4241413F3E3D3A3B3A
363733353936363B3F3D3A3A3C3D3C3B413E3C3E3E3A3A3E3B3E3D44454246423F404244
423B393C3E3B3F423F3D3C3739393A3C3C3B3C3F3E3C3937373939393D3E393B3A353836
3D3E3C37373A3C3A4342464743413E37404341463E403D4049413E403F3E4651504C4943
474B464C46453F3C443C423B3C3A353C3C3740463F43403D403C393E3F383839383A3834
373B424245484D4D5A635C5A5C544B41403D3C3B3F3F3D39383B3A3A3D38363D373A3C39
3C4949393D3B414243443C39393A3B383B414445554E8E95CEBDB7874D555E68847F9488
76674C44403C434347433C393A3736403F43464A545652556E695F524B4A49474C494751
62728B8CAA9EA7AEA8A09A9C7E4B403A39423F4144403C3B3B41506043413F3D3B3C3D3D
494E4E453F3D42555E615D5951464A4A58584C5D50695C695556495052597C877F7E5E53
3E473D47453E423C3A3F3E4140564F626F7D8C938FAAA8CEA8C1A6B79EA7A1B0AAC1ABAC
B29AA475895E726A70717A605E45473C403A3B41413B3839475956818FB4AFB89B96899E
A59B7E644C363B4D49607474917C8E6B5E47443A3E3F41403E3C3E403D3B383839393837
3F44443D36373B3F49495D727F83828D8F96999493827A686252464641454F435450483F
3F46433D3D383A3A393B43403D3C45334036433B463A3C403E3B3E3C4743404145495056
64514B433E403F3F3E3B37383F42404139363C384042443D414542464641443F3B383A3A
35383C39393C3A3A4963767C7070625855493D3B40423A3F4D616D7C79736D765E4C4946
42414239494348486E789996AC888C776F76797066646A707D9BA0C2A2ACA8B499A989A1
96A7859A96908F7780646B61826897829F83A58F8D8581706A736C6F696B566355695A5E
5868558B6E926B718E949694856C5645524C6B63846E726A72758596BCAEA083818285AE
A9CBBED7D4DDD2E5D7DCC1A48B8A9CB3C6CECBD1D9D2D5A797647B819AA1AF788E8BAD9B
A294ADA6A4A990A096B3ABB9BFD6C7BA9F9C8693757254415E4A393B39343B3C3A313138
3639323C525F43383A3D48679BC4B39F5E62453D
4B4A49494948464447494A4947464849464343454849474343413F3F40403F3E423D3D44
433C3A3F464949464445423E3E3F3A3F424046474342403C38383B3D41423C4042414542
403C3A3D3F3E3E4244413F3E3F403F3E454745403F40413F43403C3C3F41413F3E3F3E3C
3D4143403D3F41403D39393A423F3D3C3B3C3D3E403D3D40403D3D3F4A44403F4144413F
3D403E383B3D3A3C3E3C3A3A3C3D3D3C3C3A3A3B3A37373837423F3A37373B36383B4144
413D3E403B373A3F3E3E3E393C3A3A3D3C3A3C41423F3D3B3A3A3A3B393D393B3B393D39
3E39363738393D434842413F39393C3B40423C3E383F3F4442413E3A38393F474443433F
4448444B46413E3A403B423C3B3B3435383B44424348433D3E3C3A3F3E3C3D3C373B4545
3E535E5F616A68615E655D55514B4B474D4A46433E3E3E413C3A37383C3C3D4244434441
43515443413F44464A4D46474345484D4E50585F779098B3A0867C55667A7A9387806C5E
4A40353B413E3D3A524B3D3B3D363B4E62645E5B5A524A48564B4241454A4F534E5C7298
7DA684987F80837C687087859A6C524038424147484441403E3D444E4A413A3E4344474D
4F5050484F6584AEBFC2BBB5A18A7C718B69704D6852737E92797760515E5F64655B4A3E
463C3E3F3E3C403D42443A3C4B474A5789879F95B3AABA9FB2959E8E999FADA4A59D9591
868A758C74897E8C7F977C9456693D43453F3A3D465059617574967AA17D92868C867573
645E544F625C596674848A885858404639393E3A3C4043423E3A37353B3A393A3C3C3A38
3D393B403F3B4251657088969EA4A4ACA29F7C7D656B564B3A3E4451565E614D524A3D37
3A3F403B413E3D3B35383B3C3D3E393C37403F44483C3C443F3C3C3B4A47484E55585651
504249463D3D3735353F37424C47463E413C3F3040514E494941403C3F4540413E3A3A3A
38383A3932393D4455635D4B4547443F413F3B4039394A47625A635F53524646383F3E37
3E47435D5E706266627370806B65514A4B4F4F4C494D52568087AF99B087A0868C828D8C
A37F797A68766768615C5B636A8B76927A9F7997848C7A81867D897678718A6B7F5B6856
68667B71846F7975706E69757E7B7A726F76566055684A615E726D9FA3B99E9A968AA69E
B89CAEB6D0D4E4DAE0C5BB9B8694B4C7CAC7C7D5D0E1CEDFBBC0B6C8BBC3A89B799296A5
ADBCB5B6A28EA8B5CBC5DBD8DAC6C8A088736D575C3E4A3F483B334147495B63694A3741
39383B5A77633E3E4963819C9F9687594B383C38
434445474848464342444545434242434B48484C5359503E4242414141403F3E413D3E44
443D3B3F41403F3E3E3D3C3B3C413E43433C40443D3E3E3C393A404446453E40413E413C
413B393F4341404243413E3D3D3E3F40404649454243403A413F3D3D4044423D4442413E
3B3F403B393A3C3C3B3A3A3A413D3B3C3D3D3E403D3B3B3E3F3E3D3D4B433F3C3E413B39
383D3F373A3D3635403F3D3C3C3C3B3A3A383B3D3C3C3D3C4B574E403B3B3E3835384042
3B383B3B403B3C3E3F43443E413D3C3E3C38393E3F3C3A3B3A383737373F3F3E39353B3B
3E39393D3F3D3F443F3A3C3D39393D3E3E3F383A364040443F46453E3A393A3D3F40423E
4245424A53443D363F3F453D3E413A393D424944454947423F3C3A3B3E3D3D3D38435C61
5661605E5C625E5F616763636159554E41413D3D36383A4147413B3A3B3B3B3F3F3A3D41
3F403E353D3B3F40474D4C565354545D60616E77A0909676805E7D6D9878806758443D3D
3B37353B3D3A38383D3D394045414F644C4F4643423C3B3B3C3D3D3F43494F536265988C
906E6A5D4C5A524743444A43554A403C3A45485045413F4143413E3C4C41393B403D3E47
3C3B49546A8BA8CCD2DAD5D7CBBFAF9E8160494B4C4F4B5A4F49404A454251463F3C383F
433F3D403D3F3D363946566B687F7DA490978C937E856B6B59748A9E9A978A93757F6462
7C768D728A67775E6C5E64425239483D5154555E72858F949586636954654E5F4B4B4346
48667E8CAA9479617A68604E3D423D3D3B36363A3A3C3C3B3B3C3C3A39393A3B3C3C3B3A
3C35363D3D3F567591A8BEB6AAA18C7C7A5E5C4244413A4241505258615E534040413C3C
3B383A37383B4041393A3539393E3E534F605052504741443B383B456463625E57544E44
413943413A3B3A3E3C50454C4F3F41373A3F3C3F4A6A514F49393A3A485445413D39383A
3A3939393C38394144403C3C3A3A3F3D3C40434A423D4B51524A4A3E4240324037423E48
5E5B75667C5B5F50474D4D4744393E39393C3D47546A767C8C987F8766715B5C5E696B96
758F74666A6E6C575E4456556F6884647E788C87837B827F8581726B6D837B976F83686B
70836E855B72627D727C667A7E6D7E6D7A64684D6C5F6863646C7779897D8889869089A4
8F978CA4B7CBCFE0CDD4C0B9A6ADC1C7C4C4C9D9DADCE5D0E0CBDCD1D8C8CFACB89DB8BB
C9BDD2C6BFC8C1DDD5E4D0DAC4B28D885D533745343B39433F4854707D8396969570565D
4C4A56868F603E577DA1B3AD825F4B3C3F3A393A
4747484A4C4C4B49474747464545454641444B53617069524243454543424140413F4044
44414043464344464542454C444D4A4F554D443A444342403F3F3F404A483E3F3F3E413D
423F404748413E40403F3E3D3E4043453E41444442403E3D403F3D3D4145423C3F3D3E3D
3C424540403F3D3E3F4041413C393A3F42403F403B3C3D3D4042413E3E3A3E3B3C403A3C
3C3E413D40423A3F3A3C3D3E3E3F40403D3A3E403E4043403C473F393A3B3C373D3F4746
3C383B3B42404243454A483D423E3E413E38373D3C39393C3C3835343C4544423C383D3B
3E3D3D3E3F3E3E3F3A373D413D3A3C3B3C3E373A3742403F404948403D3A3B403C3D3F39
3C3E3C4451403C384244473D3C413E4141404644424447443D3D3E3B3F3E3C3D3A49676B
635C4C4C4B4E4B54615F55544F464743403F3C433E413F453D3C3E42413D3C3D3F40474E
4C474340545457565A5D5D6B5B5D5A636B6E77768771637A72A07B8B5E464B4C39413644
403D3B3938393D413C403B3E3F3B424541473F3E3E393E404043454443444648424E596A
58474A3E4B48393540444144555C483E393F434B49433B383D464A4A4C4C4845453D3B42
49445B6C7D9197A7ADC2C7CEC7C6BEB2997B72778071584E453E434243433B42443A3F37
3E3B4341443F3C445577A1B6B8A0977C766067585362687A918E937A8169646A636D6964
6065585D46484036413C403D463F423E626B6D71818C867E7B5D4546506C5E70666D6F78
86AFBFBFA6896549503B403B3D37463B403E354147443E39393D3D3A38393A3A3A3A3A3B
42414140404D6E8CAEB4B09176685243453C414038473C4F464C44444B48433937424242
3D383B363D3F434239424350857F987E8E71674F594D3D3F3E465065726E65544545443A
3E3B41413E40454D515F4D484A404645414653475E55473E403D454344453C3C37343438
3A383739423C3939363339434039423F39404549564C4149343E3D3E3946415F535B506C
6A6465564F3C3E3D373E3B3836353E3E454E576A778784808D736C4B52404C4C57667979
8196926C5A5C52534845585561776381719D738A75756D757A697167807995758E718368
786D6A58675B676B787C7C7D776F6E6D716C617765827172637265725E6462737A747D71
7E6C747A9FA3C3AAC9B7C8B6B2ACACABB0BBC0CACCD6CBD7C3CBC9CBCFD0C8CEC9D4CFD1
CEC9C2CFD8D6DBD9D7BDB68D8A61694E433A3837494457587C8A93A8B2B3B59F7E695C6A
5E68749E946A556F95A6A9966741373B3F3D3534
484746464848474646454341414143444045474347575642434548484643424242404043
444445484644474B47434A575E67646E7F7D674B444342434647444245433A3C40424947
4343484E4B403C3F3E3E3F3E3E41464A3E3B3C3F3D3A3D42403F3D3C4145423C413E3F3E
3C41443E433F3A393B3D3E3E3D3B3D43443F3B3A3B3E3F3E4145443F424149444040393D
3B3638373C3D38443F4042413E3C3C3C3E3A3D3E3A3D403C3B433E4148433F39383B4342
38363A3A3F42474A4B4E47353F3C3D424039383D423E3F4344403B39353B38393A393C36
3F413F3A383C3C38433D3F403A373A3B3B3D373B39433E3B3E44413B39373B473E3F413C
3F43434D3F394442433F423B33383A403D353B3E3E3F43413A3E4541403E3B3E3C496462
514E3D4046524A4B3F3F3C41403C45494A453A3F383A35393F3D3D3D3A393E45474D4F4B
4644434243474F51565756656C726C71736D65525B4A7769936D645447423B393B363B3B
37383B3B3D403F4041453D3E4142423338423D3E3E373B3D413E3D40413D3B3B40374349
3B413D403F36424A443B384343563F3A3C403F403C3F3E3C3E454A4A737D7D756D625B5E
715D656058574D52597F939F92928F887C7E71987D8754543A433A373F3E404B49423D3C
34464442423D4C7BA4C3D0BA9D7D6E4A4549645F87A6AAB9AE907E5A504F627B5854403A
3F3941404735443A4041384539413C46464D4743515F5B514D4D726F909D9EABA1B1BAB9
AEB7A0837A6240473B3939393E3D323D403D3F3B3E3D3B3B4045423C39393A383737393B
363E434655718C999A8A7555403B373C3A3C37363D414B473C38353D4141453E3543413F
3C3C41393A3A3B3E466C88ABC4CDC7B795916E614541384C5A6667785B564D3C333E443A
3737393A39383C434C503D3B4E5F727E737C6E645443333B35383C3A3634363B3B38363A
3C38353630393E3C3E4441393A324246404B4F4D453D3E393F3840425E8B8C94747B5C65
51453A3736393D41343E3D3C37363B393947556E79857B74644841473B474C5945604E55
5F7F665C453C4047494D74697D6785769C929486887E7C797D727D848083777D6B7A6655
5653454B52616675768069706C5F736975668564836575666F6E6063656469717274716D
686C657467857B9177A2929A87868E929DA9A7A9ABB0BCC3C6C0C9C1CABBBFC2D9D1D3CD
C7B6BAC2D1D9CDCE9F8A584F40443D413C494E63758C9FA7C8CCC0C6CAC6B98F786F656F
6574758C90776464706973735D3E4B4043344041
47494A484443454843403F424342444844444342414142423F424545444241413B453D44
484751464041414243484E535C615B70827F76594D474248545E605E4A443F3E49626B5E
5659645F686B4B3D3D3C3B3B3C3E464E443F3E41403B3C423F42433B463F40423C3A413F
3B3B3D4A44423E3D4348423940464A423B42433637393F3E4442433F3838403D423A3B38
3D3D3D3F3F3D3B3A3D403E45443E4441423F3F42413D3E423A3B3A3B3D3F3E3B38403F3B
3C3B37393D3D3F494F4740453B3D3D443B343F40383B3E3E3C3A393945403A38393A3A39
363C3B393B3A373B423B3A40413D3E433D3E3C38373B3D3B3D41423E3A3B3C3B393F4040
423C3C46453F39383C3F403F3E423D3A3E3C3E493D45463F3E4447453A4247434F577158
474852625A484948403D393A3C363B4B413E3B3B3E3F3D3B3B393C3C373C4649685A4846
4A42393D3C4242434A515A666062605952504E4B4E5C59554D4648413740353E3B3A3A41
3A3E40515357624D3F3C413F3E40393B3A423C3F3F453D3E3D47453F3D383740393D3E41
433E3A3E3B444F424240423E453A363D43413C3C3841363F3F445D849FBEC8C7B0937472
5855524B3D44414D5361776E594A3F46494F5A4F5647473837344144423E3A4649403B45
5D4D5B51515E7FB1CAD0CEB4846655494B6A8EAFBCCABABBCAB89C8D55544D4941414A42
3F423A3D394139363841383B3F3C3D3C36403A46483D4F5E608385979FA5959593908B75
7C5C6256493E3D373A3B4034373A3F3A3F4145413E403A3F3E383E3D3B39423A3F3D323B
3E556D8395A7AF9E654A48403E323E3A3E3B3F3B423E413E373D3C3B3C3B3A3E3D323D3E
414033453B4A72839CADC1D4D0C9C4A9A1868A73745C6A74896E6B6150413C3F3B383E42
333D36414239344140556A8995989E8B88646B54443A3B36313A3B38364034363C343B32
3B3C39373B3A3E4148443E383949545A5D584B3B373D474E4B4565769397A278664A4740
37383E393E3A403F323937343D343E403C45535F645A4D4F3E383A3F46413742423F423B
403B3D38323C4D5C6B898D937D867D8C899C828F7988847D7873757270605F4A45433F39
373F506169767A746B70736C70746E7570766F7266605660575D576A7087786E6E67695E
6265655763505E556965737072777A7C8287827782869998A6AFBAC0B3B7C1CBCFD1CDC6
BBBEC2C7CDCAB7A39A8E685A54696175647C99B6C2C8CCBCBEBCC0BACAC5A58F90887E7A
746C686C5858474A4D516E79747877745C44567F
434547464545484A423F3E403F3D3E40424241404041424341434444424040403B423A41
433F473F3A3A3A3A3B3E434543483F4953515241413D3B414C5455534A4846454A5B625A
55545B565E61484147403C3E424446483F3C40494C4644484140413C413A3C3E39363D3E
3F3E393D43423E3C3F474F52545A5D52413F413C353C36403A483F3E3F3E433F433D403D
383F44433F3C3B3C3B3D3E4B4D42403C3D3D4043413C3A3C3F3D3D403F3B3A3D323C3D38
393A3B3F3C3F3F4146433F41303439413C363C37393B3E3F3E3B3A393F3C3A3A3C3C3A37
373736393F3F424C433E3B3D3C39393D35373736393F44443C3F3F3A383C404146433E3C
3D3C3D433A3837393D4245463A3D4951483F41473B40413C3B3F43424B534E5856636E58
585250584F3F3E393B3D3D3F403A39423D3B393B3E403E3C413C3E41404447423F3E3C3F
4542404745464141484B4D525052514B47474745383E3E3F3B3F473A3D41383F3D403F47
465C768D87726143413E423F40423E41404640413B403B3E4044413C3E413D393B3D3C3E
413E3E453D41483E403D413D3C3F4548443C393B3D484759627692AEB7B8ABA292765C5D
57565551454B46504F50564F4641393B363B3C4541423B3B3E3A424444464752554B4757
7B7B8E83818A9AAFB6BDC3B19A7E6D5F5863707F72899CB4CCCDB9A56D503D37373A3E3E
3B3D383A363D3A39423E37393E3B3E4039443F4E62718E9BABB0B6999078606D5957503F
41464B523B38314436403D4B43443E493D4C50594B463E40413E3E3D38394338353B4765
739CBAC1BDB69661444241484346423E3E3F383C423D443B363C3D3E413E3A3C443F3B36
37374F739098ADB2BBB7B3AE948A7C7067646D6F53606A978AA28B7E434043443D3B3B37
383B474B5E425161768AADB8B1A48A7C6344403E323C373B353D3B373440383D3E353F3C
4239373D333A3E443C424850596E7B6B5145464C535D6481726F75836A756157433A4440
3635393338343B3C383836364440423F44474542433F3B3E36383C3A3B3A38453B393C38
3F3A3C3C4152798192878A8787828A6D7D6B717871796F645F5650483F3B463C3D3F4240
4B595E786876635D5A61656268656765675E624F5D4549453C4A4E6367796A625D5E5B4A
514E4E4A4B46464B495D5A5958626A6B6F75736C7374817C878F989DA5A6ACBCCACCC9CA
C7CCD0D2CFC6B7ABB4B8AE979FA3B2B8A9B8CDD5D2CBBCADA9A99E9F9DAC9694949F939E
7E8471735E63616B6E718691A59E937C6D596A83
47474645444444454744434442403F4041403F3E3F41424442434342403F3F3F46484045
443C403B474542403E3E3D3D40453C3F3F3C453F46423F3F42413D3942444646464B504D
48424540474A3A3C474340424242464C4540434E51484345524948413E383F423D3A4041
42413A3B45454543424A5B6B6D70736A5546413F3D3845394635403E3E3E413E413E3E3B
3B41433F3B3C3E3E3B3C383F433E3E3B403E3D3B3A3B3E413F393A3F3D35343B3842433D
3D3F3D3C3B403D3A3C3E3D3F3F3F3E3F3B3A3D353A3B3C3C3B3A3A3A3B3A393A3C3D3B39
403A363B3F3C3D474C49443F3B37373840403D3938393A3A3C3F403C393B3E3F4B403A3A
3A3C3E3D393A3B3C3D3F4041434158644C3A3D3D434444403C3C3E405A5056475C516B54
564E4446423B3B34393D3E3F413E3A3A3C3B3A3B3D3E3D3B3D3A3C4142423F393D40403E
3E3B393B45423C3C464945453E41434240403F3D403D3C3C3A46503E413F393F414D4E5B
7D878D856F584A404341464342433E3F42474343383F404441403E3B424F4A353B3E3D3E
413E3E453D3E4441474348463D3F4447454450605A676D8080888E8F8C83756966544E57
55575553474A4349413F413D3A3C3C414136443A4A353F3D3A3A414242444145484B5467
898893837E7C7A7A7C8992846B574C443F3F3C3E4D4F62798B937E615B3F3B3F3F3B3744
3B3D3E3F3C3E3C3940363D3E3F393F474964748CA5B7CBCACCD8C7BF9D9C7F97716F4346
40414844453E4D405B47524B4B404A414A3D4B49453D3A393A3B3B3F41403A494065709D
ACCED7BB93796240404356435D505C4F463F443E363F313A3B41444648423B3B48373E48
608D8CBEC2C0BBB2AD9A8469514650455040484C5B659D8FA1858C61585752453B3F4542
3E45305460858CA395B0A5A3896261504E455C3C483C4132384041403F4C454B433B4543
463A383C3E3B3E3C40598095A7AF8A7A6456736C91939F877A585E51544A483C303B303C
3737403E433A3B37403B3C3B4747423F393D37333636353636393D37393F3B3E3A393837
3F383B4353738598837F7273686F5D5D4855485C4A5046454A49463D3A36423D444A5251
67676A5D564F5653515760616B6471665355404A3842323A39484C59525A4C454D4E493C
45434642564C50444B4F514B475863636366645D6763685F646B6F7274767C92ABAFABB2
B2B1B1B0ABA29B97AACED4D4C7CBCCC5BEC0CBC9C1B5A5AAC0B4B59BA79CA3A3B3B1BC9F
978798908E9198A19F9CA5ADA8A17D6B4A4E4654
494745444443424142424141403F3E3F41403E3E3E3F4142424241403F3F40413E3D3941
433D413F413F3D3E3F403F3E41474344403C434243413F3F3F3E3A373D3E424443424344
473F3E3B40423A4244404042434248514C4342494B433F414E4446463E3A4041403F4541
3D3E3B414244494D4E5365777C7C8181725B4B45535C5D76544733443A3D3F3F41403E3A
3D3F3D3A3C403F393D4342424543403E4344444241403E3C3B36363D403D3C3F4246433C
3B3E3D3A3B3F3C393B3B3C414643403D3C42463E3A3A3939383839393D3A3737393B3D3D
413D3B3E414141454948433E3A393A3A3F3F3E3C3A3A3938343A3F3E3D3F3F3E4137373C
3A3C3E393E3D3D3D3E3D3A384241555D463A403F3D3E3F403F4044484348405449565552
4442393A3B3B3F393B3D3C393B3E3D393F3D3B3A3B3B3A3936373C403D3938394344413C
3C3E3C3843413A3A44464241383C3F4141403D3B413D3C3A3A484F413C3C43525B6E6D7A
787568513E373A453B3B434241413B3C454B4948393F4246403D3E3E455955383B3E3F41
433D393E3D3D4142473C4342403D43505B6475876B797C8A8076675F5B534A4456555757
50524D4D4141393C3C3E41403E3E3D403E383D3E403D3B414342424040413E3C52617176
7D6C6957524D49474A565D554A403B3C3E3E3C3D3E3441494B50473D483C414C4A414253
5D66637B67735D594A45434A33464F6987A5BACAD0D0D2C9D2DBD1B7C2A2ACA1896A4B40
4354556D7A96889786996C585A625061485135373C39403D3B3E3F4A7258796595829BA1
BAC5BEA47D6161606B72656554645F60586E546B404A3E474E53514D483E393E3E4E677D
BBB7CFCFBFBBA89A917D664548443B423A494256587676945D71514D5F5E584C44444440
40496C7CBAACAD90867C7A574A545475869F9B8052543F3E434B4B4A4750454A403F4640
453E3D393F40576786A1C4CACCAF9683838E89818E9F8F834F5145453A373A3944353E38
3B3639353B363C3D3D393D383B3D3638383C35363B3837363B40443C3C433B363D3C3838
3E393E4E718487736353564840433A3D3D443B4142463B393E3D3B353F3C484D5E68716A
58584A493D5159655D5B6660665B6657423E403538323B3E494F4A4B3F42393648414141
4C4E5547534C404C3E4F434D4F5E69666260594E534E4D44464C4B4C4D5559667A796F73
726F71797D7B77779CB5B2B19BABAEADA39F9F9F9B9296B3BDC3B7C7B8CBC3D0CFD4BBC3
8EAEADBBBCB8BEC3BCB5B2B4B49C965E61434F49
45434242444545443F404040414344444241403E3E3F404041403F3F3F41424244423D42
423C3C3B3F3D3C3D3E3F3E3D3D403F41403D41413E3D3C3D4041413F3E3E3F4245434243
47413F3E43433F49473F3D464C4A494A47403E43464341443F3D444D474546443F3D403B
393C3A3F3C3E444D52576470757980847A655551707395928C50443E3F41414142464440
393B3B3B3E403C363C3E3F41444142505E6F828E8F836B56423E3C40484C48434044453E
37383D3F3D3C3A3D3F3A3B46433F3F3C3C424138393A3C3E3E3C39373D3B3938393A3B3C
3B3B3A383A4144413A3A3836373A3D3E38393B3E3F3E3C3C383E403E3B3C3C3B3C363B3F
3B3B3E3D3D3A393B3F403B3640424B4A3E3B3E3C3C3D3E3E3C3B3D414B44564556394C41
3B403C3C3D3C3F3C3C3C3A37383E3F3A403D3A38393A3B3B38393C3E3E393A3F3D40413E
3E43454148473F3C403F3C3D4040404141403F3F4545423A383C39343B3E4D5F646F6569
4948453D393A3F4843434A49494C494D4C534F4C3C3E3C403F3D4141425352373A3D3E40
423C373C3E3D3D3E42354142505864727F878A8983887572625043484347545F70655A51
454740433A3C3839393C3E444645423E3A373F3B3C3E3B403D3E3E444E5659576C76796A
5D49453B3C3A3E3D393B3F42413F3B3D3E3C3D3F41374044403D383F3D3C3F5161697883
8A89A7AABBA39C829079845F6C6C97A6B7BCBAB8B3B2BABBB8C29A96766B534D4E503C41
54588490B1B2B890A58E8A6D879091777B605143443E454958748DA89D947B946D866379
858F8E84705D5F646B5B6B53655A79728D7691575A3B3C403E4445433E373A4768A79EDC
D1D4C1B28B877066636563544D445143504A4D4E5E5D655154414843423E3B3E44484C51
71949ECEBAB68D847C866D71797CA0ACADAAAE716544535456554A423A41373E363A423E
43404B4C667B8FBEC2DAC5B7A79C7F7B746E786593898F6757363E383835373940323A37
413E4547504C51533E393D39363B3538404033353A373D41444A4F41383C3835393A383C
3F3F485B686C5E48413A403337323A314A3B3F343D433B393B3A3D3C48485457605D5C4D
3F464250516460625C515D4C4E45493D353339333B3A47484D4B413E373D3C3E4845484D
59575E4E494943554C5E515D585E605B56534A41433F3F3A3C44414242504F4E57544A4B
4A4B525D625E5A596E69715C656877767B807A78736B7C96AFA9B9B2CAC0D1CBCDC2D4C0
C3B6D0CAC5C0C6CBC3B8AB9F93A294AC7F997B8C
47454343444443424142424244484B4B42424140403F3F3F403F3E3E4042434344424144
454343424847454342413F3E403E3C3F40404344413F3C3C3D3E3D3C3C3D3C3E43423E3F
3F3D3A3B403E3C434843454F5249434341404042444442404444454A464A4948413C3E3B
3F453D3A3F3E3F44484D535858626968615650526374788B7065454043453F3E3E484744
3E3E3D3B3A3B3F42494244505B59608097A5B2B9B9AE937A66615B595D5E574D3C4A5D61
4F3F3B3C3E3B393F423B3B4648403F3A373D3B38383C414646423B353A3B3C3C3C3B3938
3A3C3C3838444A443C393637393B3C3D39393C40403D3B3B3D3F3E38363A3E41413E3F3F
3B3A3E423C3937393D3F3B37404545403C3C3A36373C3F40404143454549444F4146444B
3B444345443F403F3E3C3C3A3A3E3F393B3A3938393C3E403A38373C403C3A3F43484E4A
424246444646403C3E3D3A3D48433F3E3F3F41444444474342423C3E414045514C51494A
433F3B3D3E4047485552534D4B4E4F564A534D4A40413A3F403D43433E4546343B3D3B3C
3F3C3B413E3F3F48575467677B888C86878F8C7F76755A534A4243564D52647372574644
3D40383F3B4041423D4446494741444242394E39473F494D424A546876736B5E5F5E5748
413B3D39403B3F3E3C3C3A3E3C403B3D3F3B3B3A3D35373D3E3A3B47465B6981959B9F9A
95A8ABDCBAC9A0979295819785AEA8B89D8873675F5F676A8B788661684F4954586B867F
94A0A6A596875F6A5D77738780957979607C6F80868A99AAB7BDBBBDB28A835B5B484F54
4E5D574C48484B4549424250414F55584C4B4944443C403D45443F3D434E6680BCC7DABA
CA908E664D4E45474E64737863584E504A5C62674B503F443E483C3F3A3D4B647A828996
B7BDC5A3A58EADAFBCA5A6908F9887968987746E5E6662695B5240363442414E51535A5C
615D7585AEB4D2C4D4B1A587826C6E636174757A8379645E3E45363A3F383A423D554B5F
6E707E83846B5B4F3E39393B373E3C3C333D394451535E5F564F4C3F363A383734393E47
4347505E675E4344373F393A393E38413E403C3A37403C3B3B383E4241454D49483F453B
424C58555C56585751474D3C3E3B3B37393D34483E564E504B473F3B383C3E4049535253
5D50564F5657615863615C59504C474341403C383A3A3B3C3E4B484B46514D4345474444
4144484A4846494E51494F49585D5B5C53615F5B55505B5F656C67878CACB1B598A7A6CA
B2CEC4CBC4C3C8CBBFAF9C817670A58BA9889C96
4A4846444341403F3E3F3E3C3E434747414142424242414041403F3F414242414342423F
3F3F3C393F40404040414244403C3B3C3D3E3F433F3C3A3B3E3F3D3B393F3E3D3F3E3A3B
3E3F3C3E444240424A45474D4B403D413E42423E3E413F3941463E3E3D464241403D3F3E
434A413C41403E3D40434443404C4D46454645464A4D584D554B4D42444741413F4A4541
46413E3F3F3E434A403C435162615E76939EA6A9AAA2876A5D575251504C464241537588
765641393E3D393B3F3C3A40463B3E3B383E40453A3C404445423C373A3B3D3D3D3C3A39
3B3E4446454D524D443C383C3E3C3A3B39383A3F403E3D3F383A3834353D464B42413D3C
3B393B423B3B3A3A39393A3A3F4040404041414041474A454141403C423D4B40503F4741
3C444246494140414541403F3B3D403C3839393A3C3D3F403A3B3C41443D3A414B4C504D
434247463D3E393940403C3D45413F41434242444940464845423A3B403E3B463F464B4D
453E384141414D464E4B4C433F414148434F454242443A42433E42453F3E3E383D3E3D3E
403D3C43404345587477877D878A84757076746A595B4849474D545F6D5C50554E423B41
41443A423F444645474F4D4C42393E3E433F46494454566E73716E7A7C69574646423E3A
3E41413F423D3E3A3E45403F393D363A403D3B373A3D3D3E3D435765829CABACAAA1968D
A09FBFBCBA98937D857D887E9B82847264524642404344414942555250615679759DA1A8
B1BFC4AE8F6E665B65515B5D525350516083A2AFB0B1B2B8B7AA9F96745B5143383D373D
42473D3F4D534E403C31403540313F38413543414960556259534C556C87AACAC9CD9898
6057443740434446434E5059503D494855495A4B4644454045424648586C8CAEC0B9B0B4
C1D0BAB4A2BBC3C4BBAD9A97938A877C786A716779686F63544E464B5770748386807C7B
84839EADB3CABCBA968F6D6C5B56506065697564765C543B3B3438343D4C436A738A979A
A097968A7E5C473A383A383F363A3D3C3D5E6C7E8C8A8877655047403B3E3B3B3E46525C
4D4D4F5149393C3442373B3A393C3C3B3C353F3D343F3E403F3A3E423D3F403A3A384B48
52615358434F46534A4843383C3B3B3A473F4F45584E57474746423F3B3D40444F595453
594A534E5458524E484E3D3F413B383B3B37373A3637383A3A4945494D4D463C3A3C3B3A
36393A38383E464C49493C424957535B4E4F5253504D4C47454248495E627364666D7E7E
8C92A19FA3A8A7A5968C876B626763795C84758A
46454444434343434243413D3E4447474041424444444342424140404242414040414340
4146433F3E3F3F3E3D3D4042413D3E3F3E3D3C41423F3C3D3F3F3B373C464742413E3A3C
3E423E404645434250423B40433D3B3E3B403F37363D3E3934423E424650433F3B3A3F3B
3D44403F393C3D3C3F4443403C4642383E47433D3E4342433E424347464D4A4D4951473F
463F414C504943424444434251564B544D52545866726A59443F40474742424849547692
89684D3E3D3E3A373B3C393A423942423C3C383D3E3C3B3B3C3D3C3A3C3C3B3B3A3B3D3E
3B3C464B45403D373F36323A3F3C3A3C3E3C3B3E3E3B3B3D41423F3834373C3E3D3D3837
3D3A373D35393C3A36363C4149434446413E41433F484A443F3F3C364640403E46484847
3E433E43483F3C3C4E4643403A3C4140383A3C3D3D3D3C3C3B43494D4B3F3D4A534A4642
3C3D42403939353740413B393E3D41484B47434247343F4743423C393D3E3A473E404645
433C3745413E4D4141404642404241474350413D4243353E453F4248443F3E3F3E414143
443E393E4547485E7C7A7C6564605D5E5F5A514A4B50464D4E5E65635D5244453D444B58
4B4D3F464142433F3C403C42444145405847574C55546681917B5B534D41403B423D3B3B
3E403C3B34383D33343F3B3D4345373A43403D35383D3C45526B898DB0B6B29B949A9CA7
9CA4A9B38779635E5F5F4C5C5C55464542393A3A393F413D3B3A48373E3A414C51777780
7CA1A1A2898788876A56453D3F47588892B8B6AEB0B6B3B19B775F4B463A413F38403B3F
383B3B4D55463D3E3F3F3F3C3F3E40413D4E7293A3B4A4A492959EB3C7CDCED5CC968B5D
53544C53433F3D3D384A51646E504D4F4A39473842404D52575C7D93B5C2CFD9D9CBC6CF
DDD8CDC5CFD0D0BDADA3B8C2C0B5907C6B56545F5A484D5650535A6F87A3A5B09A8D7A72
7E859B9BA6B4AE8C7D5F52524F545F72706A6D5B543B373F3C41425264687E90A7B1AAA4
988678665D4742413E494A513F3E47496D9CB0BCBEB09A7566524E4A413E3E444E586871
555049403F424D544F4E3B39393A3B373C313F3A404947474439373839393A3941455B57
6D69584B49473D3A353C31313B3E4445464B4E55484D453E3B3E414140434C5457555053
564C5B4F504348334434383D39363A43433C3B413D3E3D3E3A484449443D3938393B3B39
393B3A393B3F3D3838444B4762545953644D4E54534E454442474149484F4E3C47564E4D
455E6269656D68655B60725F5F4F5C464D535855
4543414143464748434241424446494B49433E3E3E3E4043403F3E3E3F41434544444444
44434241403D3E43464544463C3C3D3E3E3E3D3D3A3E41403E3F41433D49534E4036383F
3E413F404849474A4E4C4245433B3F3B3E42423E3C3E403F3F3C403C3B3D393B3C3A3D42
434242454938403D3E473E3E4047453E3D3B393B3A373A3D3B3D41413A424B4E4C474546
3F40474D4A414148383F3F414A4E4741494343493B434541453D3B42464242454B56616F
786B524542403E3D3F403D38363E3C393C3C3B404141403C3440383D383A4045433D3A37
363B3D3B3A3C3D3B373B3E3E3F403E3B3A3A3A3D41413E3B3B383C3E38383B38393F3341
3542393C32363B39353C423F4344423F3E3E3E4040413B3D3E3B3E3A423E3E4345413C3B
3B3B3C404445423E44433B373B3C3C403D3C3E42423F40454450595A43444647423E3D3E
3C393B403A373B3C373A403F3D40424040424341383B3A3C44423C3B323D423D3C414340
3B3B413C3A3F424C5A4644413F413F4343464644434443403D3F3D48483D41423E434742
3B393E45413A4451545959515764666C6248444B444A5256534F4C4B45433B465B575F4E
504645433E464B42383A4040393A4040434E4B3D4046465656463C3C383F333A3D403B35
3E3A3F433A39413C3E403D3E3D3F3E443F3B433D4C5D5A755E8A8AAD9CA5A69F91909A94
998377665248403E40413A4143373A40393C3A3F3B453F403C433E443C413D3D423E433F
414D515D807CA2878C5E594143587289A7B6BABABBBEB6A67D4F403F3E3F3C37393F383F
32425356483A373A363B353B373F424A528EC3C1CDCCD7CDCFC6C5CEDADCCFC49B908077
87A887854A4642423D50727379574B414D334E5455697090B2BFD2D5D8DCDBDCDBE0D1DB
D7DACFDDCCC9B9A998A2A1A09E8462553B3F3B4C4241384761717A949DAAB3B4A38B8570
6F7E7E7E738B707A4E5650574A6A6F725F4D574540413B474B64647A8591A3A6B1B6B599
795D554C5040454265688769845B7483B0C0BCB4A5876E60484C384037454A70637B655D
505B4F4D606D755D4F49443D3B3240353F40475D6A544639383C35373E3742514F6E687A
706854533737393A373A444256515C51534B535150423B3F414F55594E4F4847403F3B3F
424C5257473B3B403538353C3D3E393E4139524A4B3D43444E55534C3D383F3C43423B38
353C383339364045495756595352525D535A50514748433D4641424644464B4D3A433E3D
403E424242403E3D3E424649413E423B383D3D45
454442424446474744434343444547483F3F40414040444B434242424344464741424242
4141414142414449494441403D3E3E3F404243433C3C3F43413E40463D4349463F3A3C40
3C3F3D3E454644464B494042423E454543423F3D4045433F3C393E3B3C3F3C3F39383A3F
403D3C3D423B463D363F3D443D403C393F423F3E3936383A3C413F343F40414142424242
413E3F434139373B414240434A463D3B3F3E454F4447423A3D3C3B3B3C3F444A4B505256
5F5B4E474F555D5E53433C3D3D4F554C48494D53443E3C3D3B443E4453493E393A3A3E46
393D3F3C3A3B3B39393C3C3A3B3E3E3D3E3B3A3B3E403F3D3A3937363B3D3B393A383938
3D3B3E3B393C43453E3C40404845424140403E3D3E3F3A3C3E3C403D3C3B3C3E3E3C3D41
3D3B3A3B3F4344453C3E3C3E45464242393A3D4244444548484F47443C3F383B3D3C3D3E
3D3C3E413D3B3F403B3B3E3C37393B3D4144433E383B39393E3D393A393E403D3C3F403D
3C3A403F414542454B4045433C3A394040464A47434343433D41414741363C413F42433F
3A383B3F3E3846423C536367837C6B5F54484A52524E484341403F3F3D4544494E44524C
43393B41465255493F3E41413D3D40434C45403A404542493D373740424C3F403C3C383F
3B4534403A3D3A3A3D544C474546464F50515852756A7058615F737E8B98968D7C6C6257
554A4A464143414142423D41433C3A3F40413B3B37403D3E3E3D4D454E3F413B393B484F
5B6B737E817984685E45464448565D74869C9B9F9BA3987F5B4242443D3845384B3E3D3C
485A594235393E3C3A403D3B32496C8AA8C6CAC4B9C5C7CBCAC7C4BCB4AA9E9690828D70
847D84645A544D473F465451544B545C6B678B9CA9C1C7D2D3CEDDE0DBDBD4D3D2DCD9E0
C4B3A49B9B8D877072746E63584C413E38383E46463B3A504D606F8B8D8F949B97846A5C
4B54504E525A465340504B5046505D574D4A4444403F535B797F8A9498A1AAA9AEB0A58D
6F5E514E43414A55708B97A8A2A194A3999A7E6862524644443E4F3B6B5C9099887E7166
7C6E76767F6F6B44484337363549475043615677584D463C3939374356516B6280667862
50474140433B423C474D5755645A615457524E584F5443484148494E45463D3A363B4746
545455494035323C363E363C3D4650514D494D444041465146534A4D43413B443E4C3E41
30393C2D3E3C51505C595C4A574B595C5E6254534746454348403F4343413F3A37413C3B
3E3D414134343536383B3E3F3C3A3F3A383B393F
4C4A48464543413F454545444444444440424646413C40483F3F40404041424243444545
434345474445474A4944414042413E3C3A393939403B3E44433D3F474443413F3D3C3B3A
3E3F3D3D40403E3F41403A3D3D3A40434B443E3F474D4A423E3C3F3C3B3E3A3C3D3B3C3E
3E3D3E403A3D4A3F363D3D434D4E474043423D3B413D3D3F47524E3D46423D3D40434241
443D3B3F403D3B3D49433A3C413E3C41403D40463B3C39323A40423F3D424B504D4D4745
4C514E4A525158605B4A3F3F49595E585B656C6E4C423D41424844497770605145363442
4243413C3A3B3C3C38393835363B3E3D3837373A3E41403F43443B3740443D3A403F423D
3C383C3F3C3D403F3E464B47434141413F3E3E3E44443D3E3E3C3F3C3C3C3C3C3A3A3F45
3F3D3B3B3C4043443F3F3A3C45464241404242424242403D454C3C393E42363D3E40413F
3D3D3C3B3E3E42433F3E3E3B41403F3F4346433D393B3A3B3E3D3B3D43434241403E3D3C
403E434242443F41443D43433B38393E3E464B48424244463E4040443E353A3F3D3C3C3C
3C3C3E404B454A3F4A6E7A7D756252433C4041414C463F3E424545423A46484742364444
4942444A515E6257494746484946454945383B3D3E42444B443F3839394741424040403C
4C354841464955455B6C7871737676787471746F5C574A4D45585661767D6E5E5547413C
4640433F3C42403F3D3E3D3E42453D4144453F3E3B42403D413F47463C3C3A4A4F5C7584
8C8A7E79756D665447454D60837E7B687062605A656C6967655F5847524E5D545D473F3C
424C473A3A3D3C3C3D3F4751567BA7C4DBC8B4847E6F8591A6B1B8AD9E8C83796B825962
4C57414A4240403D3D3F3D403D5985ABB8B9C7CBC9D8D6CEBDB8CCD1CDCFCDCFC7C6BFB3
7D775D664D574B483F4042403F4445403E4847514550517C6974768070686D7D876E564D
6061786F806A6247493E444649544B4E463A423B495A679797AA8E979290837D81867260
665B4A503C474B5B869BA4A399897C7C6561493D3F424A4C6380698E7B9FA2AF99957296
85896B785C5A463C41333E4A7A62805C7166745646433F3A3C42506C717D718666664C40
424E3A534658525F7171706466575E55564B584C6055544A4E4B4449454944464E535059
5256463F3D3B374443504957516352554A465B4D4A3D4C40534C51485C56614B4C3B3E3E
353E3B484A4C51585C604C59495E515C5A594C524D4E4D4C52443C3E3F403E383C443D3A
3B383A39343537383838373637363A3737393638
454545464848464543454644444544413E404445413D4148424343444444434342444645
4342454843444545444344474241403F3E3E3E3E413D3E42413C3D43413E3B3B3E41403F
41413F3D3D3B393941424245433E404248413B3D464B4842403D403C3B3D383B413E3C3B
3C3E4245383D47403E453E3A4349463F3E3E3D40443C393C444F4D4145423F3F4242403D
45403F42434242444F483D383A38363B4B4645443C3D3F3C373C40413E3F444840413D3B
4047453F4A403D454C4A4442454C525C6C756D5E504B4544434645475C656565624B3D47
4B4B4946423F3D3B3C3D3D3A393C3C3A3D3D3F434544403C41423C373E423F3B363E3C48
374744565B6977797A7B633E3B393C3E3A3A3F413E3F3A3E4141474541403E3C3B3C4044
3E3F3F3F3F3E3D3D43423D3F474842404042413E3F42413C3B483F40414239434044433E
3B3C3B383B3D40424141403E43413D393A3C3C383A3A3B3E4344413F393A3C3F3D393A3E
3F3F443F3B3E4049483F3F403C3C3E3F3F444743404244453F3C3B40413D3C3C423D3A3C
3E3D3C3D3E4F5450636B59555345453F3F4C494245413C3D4143413D3F43404140393E3A
4743444342494E49534E484849433E413F3A403E3A3B3B413C46494D474E443F403F3F46
34554A5F565E5C645E766E7466737B776759524E4F435742634D5C4E53584C45443F3F3B
3D3A3C34323937363A3C3A393B473B3F3F433F404246453C423D404233444C73888D969C
9B948882877D7567605D60715C615356484D3F453C4241474B4D524D7B8797A3896B4037
3D413E3D413B373E474A678497B7CDD3CDB28F70524F6183AEBDC2AE967768574D424245
453941413C3D3F3C403E3746577EAFD8D8D7CCC3CAC6B9B3AEBAD0D0C4C5C1BDA58F7D5D
524841444141403A4244403B3C43474769678C6B967894A39B9B8A80707688A4B0A07A8F
95A7A9A599906E7A4E6E59796569504F474A6F678381B1B0CE9E8C736A6A5B504B53494D
4E4B4F6467747476767F8A7B7453504845413E4344597679979DA7829E85A5979E938C82
825A5048473B413A3C4D5E8E849A818F6A8A60694F4D4644484A5772887082605F494748
52585C566A59626664615B4E4E45514F5257505E526752533E3E3E4F545F61686A5B6254
5E41464248475046514C52616062645E545E525243443B4C425F58655860545D3F53475A
504854546C55635F5E515F465E4B57504B493F5053544F4A4E403A3C3E41413D3F463D3A
3A363735393A3B3C3B3836343635353537383535
44444547494948464145464444464541494543413E3A3A3D42434444444342413C3F4140
3E3D3F423F4142414142444541414141403F3E3D4141403E3C3C3C3D4745413F3E3D3B3A
4140403F3D3C3C3B3B3A3D3D3C39383C403B383A3E40403E3C393E3B3C3F3C3F403F3C3A
3A3C3E3F3A3E433F434940383C43423D3F404144453A383D3E3E3E3A3E3E3E3E3D3C3B3B
41414142413E3E413C403C3A3F403C3A3C3B3F403F3D3E3A3F3C3E43423D3D433A3B3C3D
40444038413F3D3C3E424445413E43515E5D5041484D4A3F3D3F4441394758718679625F
525253524D443B353D41434241403C373C3B3C3F41413E3A3D3D3F3C393E423E494C4F64
617C7A8EA1B2C1C2C0B9976A443A393D3C3D403F3B3C383C3F3F4543413F3C3B3D3F403F
3C3E4041403E3C3B3E4243474F4C433F3F403E3A3C40403C394040443B3C383F3C40403C
3B3E3F3D3B3C3D3E40403F3F3C3F3F3B38393B3B3A38393E4244403A3A3D454A4742464E
3A3A403B393E424D45403E413E3D403E4142403D3E414341403C3D4143423C3A3D38373B
3E3E3F414B6D706A664C3B3E3E363C37384545404A46403D3E4246484340393E41423F38
3D3E42464B545A585F564B45413C393B3A3D413D40443E3F586E7779675F4E4242414238
4E4D7666775A5340493E44484751564C413B3A3D4347444E47483B353D403F43403E4036
393A3D37383F3C3D3C3F3B383643383D3E444248555C6053503F504A5D6988ABAAA9A5A2
9B90867E7F6D6B565747454450494A3C4B3E403C3E45403B39455E6B788698A7886E4743
3A44423C434F596169698694969A958B947F6F644B4A547691A5AE9B886E6F6465464945
46473F443C3D3B353C3E436495B1D4E9DBD0B9ACB6ACA6AEB8C4C6B5969393917F6F674A
464040413A3B40453D4744404D60768CA0ABB3C3BFB292987B7C6A6165849FBDCBC1C1B7
BFA7A79D9D89A78CA87E867C8B7F7A6E6D90ADA9A1A7ADC2A69563574445403E3D463C46
4C4B5F6E807C78686060505A443F3A3E3A3B4658617A98979BA88883738E848C7B7C6365
4B44383F3D393E3959558984A0788F6A7F65764D414446515B57575F594A565F565F5263
53654F6B5E6343473C3C3A383D3B494A4B45533A494049433A424D6161635D605958565E
524B47515161556C536D59735D644C5B5852554846475D4854495E686556564552525B5D
58584E5A5C6565615D5F505B3E543F4B494941504E4C45403C363A403F3E3D3A3A413A39
3C3A3C3A35363737383837373937343537373836
49484747474643414044454343474642433E3A3C3F4042443F3F4040403E3D3C3C3E4040
3E3D3E3F3D40424241413F3C4040403F3E3B39384243413D3B3D3D3B4242414140404040
3D3C3F403E3F4241423D3E3D3D3F40473F3E3D3F3F3D3E403E3B3F3C3C3E3A3D41424240
3E3E3C393C41403C4044413F4447423F43443F3D433A3D45423B3B3B3D3F3F3E3B3B3D40
3B3D4041403E3F423D433F393D3F3A3741404543464243404B413E43433D3E443E3C3E42
4344413B3B40434240414242433E424745413F3E3A45453A393B463F3F526A84968A7064
5B56504C47403C3B434A51555858544F45403B393A3B3B3B3B3B444A48505D617E717C84
99A5A4ABBAC1C7C1B6AC9A835E483E414143433A3E3F393B3B383A363A3938383C403F3B
3C3C3C3D3F4141423F43434346423B3A3F3E3D3B3B3D3D3B3C393B43383E3F403E3F3F3D
3B3C3D3D3D3E3B3B3E3E3C3D3C4347433D3B3B3A3B37383B3C3E3D39383C41433C363840
3D3B3F3C3C3F3B3E3A3D40443E3A403D41403C393C40403D3F3E444341403A3B3C38393D
3F3D4046586456524B37383C3E3D403C3A42434254514B45403F4144413F393E4044403D
404041464D535047574E4740393C43433C464E484A504C50616E655D48464544473E3F4D
4A79747553463C463B3D32413E4040363840404543463C443D403C3B3B3A393D38384039
37393D37383933363C453F413A4740484D53525E788795877E69686A7A8B9AB1A89D8779
6E66645F5A494F424C484B425049343C3C483C403844413E4555656268687B776C564A47
444C535C728E98928D7F897D746D6159503F4D48493F424E617D928C86738685887B585C
487142553F413D3F4F5A73A1C8C9D4CBB8ABA4A2B2B1B9C9CEC0A2856A68747870605741
3E403B472F46506D5B58494C6D91B1CFCDC9CBC0AE7B635D49514B4D5F8391A4A9B8BBB7
988D7C8A868D7FA28985594E5268859FADC1C8A69B88A17A875658433E383E454E503A38
3B384A4653484D404A3C323C414054546266687480898F878D7E9364916E7D5F4B4B3E45
3C3A3A403A3D4152568B877E7080626C4557415B43454751534A43393F32524E71485A47
555957515E443B343837343941424E4F52564A493448414F505A606B615C51514B4A5A46
5341514C5B5468546954595460504A474E57484C48514F5F5666545C5C5E4E63516D575F
5951574F61525F525A4D6449534046414C50474F474441403C393D413D3B3C3B3B413A39
3C3B3C3938373636363738383C3B353638383C39
4444444547484846404546424246464145403D3E3F3F40434343434241403F3F3E404242
42403F3E3E4141403F403D393E3F40414243444444413F3F3E3D3E40484542403F3F3E3D
3C3B3F413E40444340383937393E3D4542414243423E3D40403D403C3B3D383A41434340
3F403F3C3C403C3B3F3F3F413D413D3B40413C393D373B413E3B3B3A3D3D3E3E3D3E4042
3B3B3C3E404242413F403A363B3E3E42423E3E373B373C3C433F3C3E3D3A3B3F3F373940
3E3C3C3A3B3B3E4243424040403E444743403F3B363F403A3F3F4B44475A6E7B7C705E51
554C433F3E3E414550586064686A67625951473F3B3B3A393B3B414A505969777E6D777B
8A8D80828390A1A6A19E948571574A484242433C3B3E3A3D3F3C3F3A383A3B3A3B3E3D3A
3D3B3A3C404344444347453F3D38363B39393B3E3F3E3F413D3839443A4143423F3E3F3F
3D39383A3B3D3A3A3F3F3C3E3E42433F3B3B3A38413E403F393E494C444444423E3A3B3D
413E433F3D3C3536363A3C423E3C443F3E3F3E3B3B3E3E3B3F3D424040413A3B45434547
433D414B514D3A3D4641403D393E3C3C3D3B3C3C3D3F414242413F3E3D3E3B403C423E40
404040424A504D48434148473F48544C515159524949494C424A3E3E38455258594A4D4F
5651645046444E43443E4144444B504B5054484547433B363C37403C363A383C3B3B4445
4240403A3B3C384245534C53474D4A535B615D698897A591746D64797989848F6D645048
45414540433A444A4A5D5E54564A40374441474B4D545051575C5E5250454B474C545D62
6D6C788A99A49E88806A664F4C493F3D42424D66596C545B5F768A87856E8281795E6C61
6E7C856D65655D6571738BB3B7988E74747185918B93A4B7BDA98B7B5A55676B65514336
4438444552637F95907251557CA3BED1D0D1BDAD7F5D4F484D5149464C5B50586C727862
5A4A484E53614C66534A433C4A7F99BDBEA79D6F525059504A4C5051554E6265655E5154
484A514C4641413A39394A5D706E8C848388848991908C8270766E896971533F3C3E3B43
44434A4B646C7F758B7180576150563F4B38473A434443463D3A3F34404B49635258504E
515A45514042343D373635404B4D5351524B534045434F555E625E5C4D4A413F464A4D44
47474B47555B4E654A654E5852554C505E585244584F56506861564B5456616667675B57
51535760585154505251545B475440454B4E4349464A4741453E3E3E3A383C3C3D433A38
3B3939363B3A3837363738393C3D37393A383E3B
4645444546474645414646414146454042403F4040404246403F3F3E3D3C3B3B3C3D3F40
403E3B3941413F3B3C40403C3F3F3E3D3E3E3F40463F3D42423E3F4547423E3D4042413F
3E3C41423D3E4240423A3D3C3E423D43403D3D403F3A37393D3A3E3C3C3F3B3E3C3D3B37
383D41403A3D383B43403C3C3D45464242403C3E423E3D3C393B3C373636383B3D3D3C3A
403C38383C3E3B3742403B3C3F3B393F3E3B3C353C383E3E3D4144424040404043383A43
413C3D3D413C3C41403C3E46483F3B3B3E4541333B3E3E3E4945504A50565D5E5B584F43
413C393C3F4043464F5458585857534E48433C39393B3C3C4C473F3E403D42534D494E5F
566349544E5A66676B797A6C755F544E3F3B424341444043433F413C3B40423E3A3B3C3B
3D3C3B3E4244434140494C49453F3D42403F4144403937393C3A3C463A3B3A3B39393C40
3F3B3A3D373A383A41423F414444403D3E44474648474A463D4459654644414143474848
3B3D44403A3A383E3C3A353C40434B423B40413E3C3C3C3B40383B3A40473E3B3D40484E
4C4A54624A4F4038423E3841394138393C3637383A3B3D4144433F3B3D3E3B3F39403B3F
3A3D3D3C414A5053484C6064586068585A474A4A4143413C3E4438413F4950504A3A424E
3D3F45473A43483F3E4D4740464D514545473C3D4B443C363F363F35383F39393E3F4C56
4F49423A3B3C3E4E55675C64514E4A535D6058607A7F85695457666E7460574D42433C43
4845463D545255634A6356483D3E393A3D455062665F555C645F57494746465E5E7E777A
83828B8B7C776E58534549373F423E445B5B737A7A81706A70787B706D50615A555D4661
5E7F7C7C7875686E6F5D667F75535C556F67706F74777F898E7F6E7160515A5451423D3E
403F485C5B798AA89D79606B8BA5B1B5C5C0CD99A570875647463D3C41493A4643433938
41483E38456B577347373A3B7695A0927A5E4B45534F6B52605469626F6076757673727A
77858B9682816D62577571A37E9A9B9F808B959E998D83706D5D766B6B4866443E473E46
455E717B86898787755A4B453F493C4143483B3B34393D3F343A4F494F4E7A575B464741
4A483A3F413C373536393D505A544E4449494D4F4C56565F383E3C3F39413C3A3F3B4942
554A5148544D544B45495154534F493949514F4B4D535555545A56624D514E625B6B5555
3C47554C4944564E60505A4D4B4D48474B493A444A544B3B413A3A3C39363531383F3736
3B3A3B383434333435383A3C3B3E383B3B383E3B
44434143484B3F43484C4242443D403F3B3E4C40483C444042403F43463E393F42403F3F
3F3F3D3A3E45413A3C3D3B3E3A383E393C443F423F4443403D3E4148454B4640413E3C42
443F4244404245403E3E3E3B38393E4246414042413C3A3A3C3F41403E3C3E403B3F413F
3A383B3F393F3C373A3B37383C403D3D423F393C353A3D3E3F4142413B40403B3A3E4242
3B40433F3C3C3A373C3F3E3A3A40413F3D3F41403D3A38383B3C3E3E3D3E4042423A3E40
393C413A43403E393E3F39403D41423B3E40373A3A42423E42484D5551524A454B4C4239
3C3D42413B404745474446454246483F42403C3A3A3B3E403F454440413D3B40363F4044
413C44443E4044474A4C4D4D565053505245474A40463C3C3F393C3D383C3E3C3B3C3B39
393E443F4961758F73737172705E49434B403C3B3C3F4741403E333D3736373D3942453C
3C374747434D3E3F3F4D434649433848555252473E41463A46425C59424D4846494F513F
3C3C393E364345423E3B433E3C353D3B3B3D3B48493739413D3C3D3F41423F3D454C4E4B
51524B4A49453E43414045393E3B38363F42393D3C3B3C4047443B3E353B383F40403739
403D39484F5D60665F5A54544D494D44413B404142413C403F353943423F41433D3D3D3D
40403F3E3A3C4E514B4B454441474541423F3F4737413F373738393A3D34383C3A485B5C
47473E3739404A5758505C5F50464754545A666D6F646D62716B696150474A4C41434A48
3C3C4446565B60544742433C374544534E686F7D726F7A6B655A54504C435E67716E6D7C
8B897867574F545355494C5042494869596A64746176707B78816F5C494D524F5545524C
59595D504F554C57595C5E66676C6C756C6E6F7A606E5F6D5C6864645F58584A4C414745
3D425858595E637A6C6A6B768690929298B6B6BA8D845A494039343D414C3C443F3B403A
49414B44575D775546393E45496B6350483C55877F9C898A64644C5C4B49506054576880
7F85ABADBFA2A18BA599B9978E7682838790968F8379726E6662665A56615A644D4F4952
546C747C8B8179614C433C423E3C3C3F403C39383943393C3B39484555646E5B48423935
393939343541473F383E454B4E4E4D4D584C524F5F4F4C40323839403A3E3D4344495459
57544D3F44494C3A3F4A3F4A3C4A484C5A605A49534B5454574F534C48494F594F595345
4047474B5845444B55575C4C4E4946493F49403943423B3F32363531343B3D38353B3D38
383A38313C383536393A37343435363738373534
4F4B5251696B646064634E454746453E3B413F443C43444B403E3B40443F3B423D3F4040
3F3E3F3F3D42434243413E3D3C3A3D3739403E403D433A4937463B403D3F3F3F403F4046
423D3F424042433E424343403E3D3F414040414545423D3B3E3F414242424242373A3D3E
3D3D3F413B403E3B3F403D3C383B3C3E41403D3E3A3F413E3D3E3E3A4042413D3A3A3C3C
383B3D3C3C3D3D3C3C3B3A3A3A3A3C3E3C3D3D3C3B3A3C3D3F3F3F3F3D3C3C3C3E394044
3E40433C3C40423A3B3F3A3F3A3B42403F423B383942423F4244454946473D363E45433F
3C3D403D373B403E3E3C3C3B393E413B3939393B3F424445363C3C3B3C39383D3D414141
3D3A3E3F4243444443413F3E423C4140463E454A464A403E3F393B3A3C40403D3B3B3A38
3C3C3D3B4B66798E87796C6E6C5948493F3F3D433A423D3F40413A47423D3A3C3A3F413C
3F38423E3E42473D4351605D4A605C70674649363D44363D36444B503F4540403F40433C
38393A413C4647463C363D3E464444383D413B42464041433F43494A48433F3D393F4042
4948403E3F3D3B4347494F463D3D3F393B3D383B3D403E434C473C3F3E3D4652695B5953
3C434E6871776B675250484743404541443C3D3C3C3D383C3935393F3B393D4037393E41
3F3E3E3C403E4A4A43433C3B3A3D4145453D37383B3D3B3A3A36363D3935383B373C4340
3A403F3E454E5D6C6B5B5956504F4E514F566570766E74686F66615A4D44424040414447
4545474547445039403A524E54617573766F7574686060565851545A55595D6D6A7E7189
6C6A65696C6F736766525748504E4F584F5869676F6C73726C645A434A43544E43403B43
3F483E494C514C5B5A58535462615A5A52595F6B646465575C4C5850464644454950514E
46564B5C4B654A685753525760696D6B85899481755244353E3940464D473E47433F485A
5E6B637155594E493B4B313C404E4F5966687686968C785A54483F3F3B3E3F4D484C5E86
8F98A6C9ADB396A4A1B0AEBA7F987E8C7B7A7770696562606A59624D4858665A494A5256
606B6D6D615C5953504D4745403E3E403E3B3F464851464644414F4B575B62513D3D3D3B
3F404343444B4E48404246484948494A504D564D52404038373D393C3845474A54555753
4A4949434C51533F404942514B5A5C636E6E67585B57605C594F56554E4F545A4849443B
3842484E5B4D525762626452534C484A3E43413F4340393835393835373D3D373A40413D
3D403F393A393738393938353636363636363535
66737C9098AA9793918C6E544946443D41424D464C42494747474343433E3F4A43454543
403D3D413F3E43494845423E4041443F3D3F3A3849414A45453D443B3E3A3D423F3F4344
423E3E414244433D4443423F3D3A39393E40414141403C373C3C3D3F41413F3C3D3E3F3F
403F3F3E41413B373B3E3E3F3A3B3D3E3C3C3C393940423D3C40403B3D3C3C3D3B39393B
3F3D3C3E3E3C3C3C453F3C3D3A3434373B3B3A39393B3E413F3F3F3F3E3D3B393D393D3F
38383B353940443939403A3A393642413D423F3A3940413F3F3E3C3D3C413D393F433F3B
3B3D3E3B36393C3B38383D3F3E3F3E383B3B3C3F4242413F4143413D3C3B3E433E3E403E
3D3F40443F404142434241403D383E3E433B4245484A4240403B3C3B4043423E3B3B3A38
3B3B3C3D4D5D6066625A4F4949433D3E423E4B3B443F434A5652434A413E3C3E413E3D3C
433B433E48573B5067A09DAC97865E5849323F3F42433C3A3B3A3F3E48483E3C3634373B
3A39393E393C3C3C3E3A3D393C3D3E323D45403E4242423F3F43484A49443E3A3D414243
434041463F4041494A474439404148413C4142443C413E444F4A40403D3F576887635E4E
4B535B6D6965544F494A403C3A363A3B443C3D3C3E3F393A37393D3D37373B3D3B393E40
3A3A3E3D3F3B41403B3D3A38403E414543403F3E423C393E4037364245403C3835363838
3B40403E414651616A584F45444A4643434A585D61575D565C524E4D47423F3B3E3E3D3D
3F3D3B3C3A3F3C464361707A738285856B645A5D515356616D5E585A676C84687C646266
595E677A888C88756B534B3D424441464E666084688269705C5941463B4542444C304A39
453654525F58474E46434041504F4846444F575F5E61545947474347463F483C544C5548
64506E566B5E66575752525354626C666E6F71706454464139444152424C3C4C443D4A4B
735B796B624863546F69715C55596470676169636E6854523E53444E424A485159708095
8D818D889265878AA491C186A47383626C6764656765605B515341434860524F48545A70
6B7E65666E706D685C4F4944423F3F403C3A45555D61544F49444D49443E453D30394447
4E4A4B4C4A4C4E4A474745434141424445464E4245383C37444A4445455759594C44403E
3D4448444B4F5448494E4B5D536061676E6B68636963675F5B5056575552545B4B4A4745
50555755594B4D475B58584548423D3D3B373C42403F3F3A41423D3635383733363E4546
46453F3738383939393837363837363535353535
A2A6B5A0A9A7B2B2B7B7A38367534C4D5562807989787867626767615748444B42434243
45413E41463D3F44413F403E3A3E4241424646454842434B3C42454344393C423B3A3F3C
433F3F424547443F3D3C3B3A3B3D3E3F3F41403D3E41403C3C3D3E3F3F3D3B3A45424040
41413F3D42403C3A3C3E3D3D413F42413B3D3F3A3A42433D3C41413C3F3D3E42413E3D41
45403E41413D3B3C413E3C3D3D3A3A3D3939393A3B3C3E3F3C3B3C3E3F3F3D3A443F3F3E
38393E3C3E3F423A3A4039373B39403C394040403B3D3E3D3C3B3939394345424647403B
3B3E3E3B393C3F3E403F3E3E3E4041404140404041403C39383A3A39393A3D423B393F3F
434B494F4240404041414141433E4645463C403E43444140403E3F3F4043423E3C3C3D3B
44474747505249444347463F3B3D4043414749504D64576D615A46473D3C3D404D46413F
453C454472524D476884A1929B684B43494738413C3C3C39403D454A525245443E3C373C
403F3F413D3C3C3E4141433E3A3E433D3842423F403F3E3D423F3E424848423C3C404044
423C4146423E3B3C3E40413E42414840373D3F3C3F403D434945413B44464F536243453F
44494A5147453F4342483D393A35383C413C404145473E3B3C40423D393A3D3C423B3D41
3E424B4A3F393A3B393B3B373E3D403E39404845463F3A40443C3A4441403C3A3B3A3635
383A37373A3D444F4F44413B3B413F424649524C4A424A4A453D3E413F3E3E3B393D3B3A
3E3C3D474840564A6D6B8980777C6864434C475663787A7970585D6E6F83767A57644B62
495C6B7E8B8880735E47433E47485060756F705F5F4F524C48453D373B37403C414F4154
4B645778534939423D3F4141494C4A47474D4E4D4B5242553C483C494A49444F515A5453
566C52725C8754685B575A5753626E666D637657725565534A525541403A3C3C393B3D4B
446958665B69537D7BA7819565697B87746E7B757A628450623C4D413F4340444A6C7A78
6C5352484751637D8FA191AB6D8455593F3C3C4247453D383E474944645248454E4D5C5B
717B797A80888379644E4B46443E3C3D3B3A46575C5D4F463E393F3B37323A3A38434C54
51474444404146484746423E3A393B3D3C393C34404146404D4F484B485049453B36383D
424C524F4E49494443424359535E5E63655E5E5E6D635F56574E515059514F5C54565151
5E5E5C55574E5042514D4D3D43403C3C3C3037403A3D443F46443C333134353330394144
4441393034363939383636363837373635353434
B2B6A692717F7F8F8D96998D775F545C86A6BECAC6C6AE967B83858175604D4A42444751
5C574C4A62534C49424348494C51525253575C5C56484851484B4A424A3C3E433C3E453F
413F3D3F4446423F44413E3C3C3F42443E40403E404646433D414444413F404243403D3D
3E4041403E3D404444423F3B414043423D4347414146463F3C3F3E393D3B3D403E39383B
3F3B3C41423E3B3C4143413D3B3B3A3738393B3C3D3D3C3B39393A3D3F403E3C3E3C3D3D
3B3E4445423F433E3A3B383C3B3E40393B3F3C423E3B3A3A3A3B3C3C3B44433E41464646
3D403F3B3B3D3E3E3A3D4043433F3B3A403F3E3E3F3F3E3D3B3D41423F3E3F40423F4544
484E4A4E3E3C39393C3F4142413B42404039403C3E3D3E3E3D3F3F3F3D40403E3D3F403F
3F423C383C3C3A383B3A3C3E3C3A3F454F485643544C43464A4B404740403E3E3D3B3D40
4A4555584F543346405E5776543D44505E5D403A3940344134423D53484A3E4141493D3E
43464A4A4A4543444140403E3A41474543423F3E42413E4345424043494A45403D3F3E45
43383B383C3936353A3F40433C3A43413D433F39403E3A40403F44383D454349483F3D3F
3A3A373F3B403D423D443C3B3E393C40423E424246493F3C4144413C3C3F3E3A433D424E
53565855423C3A3C3B3B3C3437424B443B444B4443403A3B403E3C413B393434393B3A39
3837353B444341463E383B3C3F42434F4441443A3E393E403E3A3D403A383A39383C3D41
4A4B4E595C64647467756F6F665A4E3E3E4256617A76585058565354665D70515E445657
465B5D626A605855454839614D70637D5E5D4D4F3D443D433D3F3D3D4B515D556557745E
6A5E71615D594C55525454534F514F474342413D3F3B47424B40484B4B3D494258475554
6B5173556B5E705A5C595C564C565F555054435247625C644D5D4A4C37483D4242475642
60456C5C6649605778768C79736E74817E7C8176766B72695353424142413A3A34454B4A
4444353B535F8C83938397727446493C3D3B393A3C3E3E3E4E5E66745857515750574B59
5571616C7078757162504D48433B383A3B3B414B42433B3532333937393B404045464049
423937393638404641403D3A3635373836333534444A4D443C3E3F4E4D4C3F3D34384246
41424B4F4538333437353C52515D606562544F4D5B534F474C464B4E595352615A564D4D
565A5B53534D574E4946483B43423F3F4033383F3839403B3C3A35313135373634373939
3838353132343738363434353637373837353433
7C777D61584E54525D616A6C675B55627F99B1B0B1A9977C7677737373675851575B606E
7D73605A7063574D46474C5065727C889197A09FA1888B828D78745D5043403F393F453E
3E3E3A3B4143403F4543413E3D3E41433D3F3F4041413E3B3C3F42434141434541403E3C
3C3C3D3E3C3A3E42404041404040413E3D42423A404343403E3E3F3D383A3D3E3B38393C
3A3A3B3E3E3A3736363A3B393A40413D3B3B3C3D3E3D3A383B3B3C3C3D3D3B3A37393D3F
3D3C3E3F423F47443A393B42383F423B3E4039404039383B3B3C3F3E3C4340383A3E3F40
3D413D38393B393A40413E3E3E3C3B403F3E3C3B3A3C3E403C3B3C3B383C44484D4B4B48
464541423F3B38393D424546433A3F3A37343E3A3E393E3D3B3E3C3C3A3E3F3D3D404140
3F443C383A3B3F403E3B3B3F465259555651494B434E3B3F383F3A453F3F3D3C3A3D4244
4A434F4F5A3F47474437454039413E49525253453D444953575955685D5A48484956484F
585F6158564A443F3D3F434A4A5F77886152464043413D464344454543403D3C363D3C41
3A3341413A3A3D3C40413A3B3D3A4347484A413D3A3B363D3E414D44414643474344383C
4840353D3D433C3A41443D3D3C383A3A4540413C3E433C3B3F413D393D403E3C44454D5C
625C524D3F3B383E3E3F41383A4950463E4448413D3D38353A3B3A3D453E39393E454847
3E3B3A434D473D3B453D3C3C40413F4B4B44443C4845413E3E3C41423B373B3D3E3B3A41
484744485C5C77646C54665F58504443424A4F57585D4E484748474B4C544D644E5B4749
4B54484246403E3F4C41614C775B6D5A41424146413F3B3C3D48425B6479716553695661
597964796B73666864635B584645443B3A3B454946464B4F4E504C51534D485251535159
586A59735472455646444641393D413A423A3B3842414A4C464C4C4C554F535355535561
5769545E53644B5F4E685165535556616460635F816A8C657C5462503F4A464B4F574943
374144585F86827A665E4A553D43343E353A3D3D40464A4C555D6A534D44545B595C574D
554B423C4D585F5F544745443F3A383A3C3C3C3D3F413E3A383839363C42464348423238
383234373434393C3A3A39373534363735373B3E4647453F3B3D4355514A3B3A35353B3D
3634393C363335393B3B404B4B5451514D403C3B403F413B423E495354575A675C53494B
535D5E514C414D4E4241453942403B3A3C37393D3B3C3D39363535353536343235363736
3635333131343636353434353536373838363433
4F4C4D4D404843454A46464142413D495B637A6B7B6C6F5D5A5A5451555450505D61616C
786B585657554B413F404246566A7C94A9B8CACCCBBFB5BFBAB5A39B7265584A3F434439
3F403C3B424341443B3E4244434344463F3E3E41423F3D3C42413F3F4142414041434442
3F3D3E40433F44484240444443484643464840373B3B3D3E3E3D3F423B4145433F404345
393C3D3C3B3A3937393B3C3C3D3E3E3E403D3B3A3B3C3C3B3C3C3D3C3B3A3A3B3C404343
403D3D3E423E45433F444341393C423C3B3F3C404139393E3E3D3D3A3A43423C3C3C3734
3C403C373A3B393A3D414042443E3B413F3E3D3937383C3F3F3C3D3F3F4A595F4B4B4643
3F3C3D3B47433F3D3E3F3F3D443B423C38353F383D373E3D393D3B3B3A3E403E3D3E3E3C
374039393C3A3D3B3A3A3A3842575E514A3E3E363E3F45413D453F463E3F3F3F3A3F4342
49444D484641324B4449343A37413B44494853493D394B475F4B474F4949414E54635566
666D6A56544A46403E41464F495A748D71635646403D3B4B464645413C39383942474142
393340373C3B3B373C413B434640414144423C443C473A3D45444E4D4841453C41424454
4E44373C3C433F4144433C3D3A373D38423F403A3A403B3A393D3B393E40414543494C53
574B40443B39353D3F40453D3B414039373A3A3B3C3C3735393A393D443D41484A4E4D43
403C3A4149433B3C44413F393C3D373E413C4037423F38393D3A3E403B393D3F4138373D
3D3B3D3F4950575B4C4D4F5350503F4D3A46383F47433C3F3D41373A4C53605361515449
404039393C424D4C5C5E525F545B463E39373A393D393F4345444C526B61614D5A525744
474B585B6074655C544C3B37393A3F3B40425460565C4F5F475F474F413940394E4B554F
6B516149463B3F373E3E3F3E3B3D3E3D343C35473C4D444947554D61595A4F53514C5550
6B5765535250644E534255483842464D4C464C515D5D6469636261655F6B686E6F705543
3A3F54496F4D714E4B453D3C3A3A3F4642505B5D61696963565B50454351485954604448
3E403738323945443E3B393D3A3C3C3C3D3D3A35373D44474B4E4B473E43484446443739
3533373A35343635373737363535383A393A3E42433F3C3A33393E4C47443B3D3B323236
363737343B4A4F463D3E3E393E443B373631333334353936403E4A555255555D54514A4F
4F59574B4C3D44484142493E47433D3C3A3D3A373D3E3B3D3A3937373735333234353738
3836333234353636353536373536363737363535
4D444B46424143434343453E4146424B4446474846474747474E4D47423D3C4146474348
52483C413F48443E41434245424E515C6773878B9D98A4A6B9AFB7BAAFA18A6E5D5A5447
4345403E44454549474C51514B443E3C423E3E4448494C504F4942414546423D3D424849
4745474B494A575E554B47424952514F58594D443E3B3B3E3D383A3F3941443E37373A3B
363B3E3C3C4042413B393A4042404145443F3937383B3E3F3A3B3C3B3A3A3B3D383C3D3C
3A3A3C40443D3F3F46534A3A3D3A413B353D414340393B42403D3A343842423E40413C39
3A3F3B373C3E3C3F3C3E3C3D403C3B443A3B3B3836373D423E3D424541454C4C3F423B3C
3B38403F3F3C393A3D3E3D3B3C3742403D3840363C353E3D393F3C3C3C3F413E3C3C3B38
39423B3D4241444045403F3D3C44473E423D3A3E393E423E424B474E454544454144433F
48454E45433E464F443F40403E39414544403B434039383F4C493B4A4950587376765A6B
4D5450393D3F4645434246554C5056626866614C3D3A3E55524B433E3D3D3E3E41423D50
5D5F5D403D3C3D373C3E353D463E3B3B444A4F65495C46414A4144475A55746367483E4A
46443D413B41424A3F3B373C3A3D48423D3C413C3D423D3B343B3C3C4041454F3E433E3D
413836483E3C363D3D3C42393B3B36363C39353A3F3D39383C3A3A423B31373F3F454639
4C453D3E413A363D353E423A3B3F393D393B45393F3C3C473E393A3D383739393D35393F
3C41515B534D554D50454B4349433F3D3B3636383F393E453B403C4C4A65605448463C3C
38363B413D475B545F534645433C3A3A39393A403E41454D524E434E4C494442434C4548
414E495F4C624B3C393E3A413D404C4A4E48586560595D4E4F4E46424040403D4E5B5D50
433D3D473846343D393939393A393A3D3B424B3D474A53494759585F5D57534E4F585F56
51545452474D463D3C3E3D37434440474A4546455A5151464F435051565355615550423C
3D4440514342484B4A46384146524D4950606A6A6D746F6450374340383D3B3949563C3B
3B3436353C343734383D3434373E413F3E3E3A343D444D50504E443D3A3B403B3A3D3736
3232373935373B393636363535373A3C3E3A383D3F3C393A3B424144393A343638313237
373738363F595A4030394135333B3433363639373634353444434A5154504549454B474C
4F554C4550413F403E40494048433D3B42493C31393B363C3E3A36343537393A37353332
3334363836363636363738383636353535363637
56544D46454746433C404746424549453F42434245494844404345444546454240414245
48474543414243413F3F40424440414241464C4C54595F585F5F6F7C9BAEA8A392818276
3F4041404A4D6A76888D95856F676572735E5C61635E6A937E877877504B393E4A5C8A9D
9D949A90967FB098A46F797B887F7A81775E4F42403B3D3A3D373D40413E3E413E3C393F
3D3A3A3F413E3D3E433A363C434442413D3C3E403E3A3839403C413E3F353838413C3B36
3E42383E413D3B3A3A42463E343B3A3940403E433F3D3D4143423E3A3837413837403B41
3D433C343B403C3746413B4047443C3D3A43393639383F40403D4543454944484248413B
3F3C39433D3D3B37393E3F3C384654473A3B383E383B393A404141453C3F3D3D423F393A
3C3D3E3F40403F3E45493C3C403B3F40423E3B3B3E403E3C3B3D44453D3B3E3D3D404446
45434141464041494A413C40424141413F3B3939403C3B3D3E3D3D3F4D595E716D555146
3F4244413C3B40453E3D56584A555B554A4B464940413B3D3B3D4747474741433B444D75
818A68533E36363B3A3B3C39393F3A3D4B6885837E75616260676D82888E9CAC8F786B72
626B544E404140473E413B3A383F4D4340393D373D3F3D3D3938393C3F40403E38393739
3E3A373B383D353D3B463E3638393A3937353536363A3A3A3B3637433D363C3C3337413E
3C3734383C3D3F413937373A39383B4137373A3A3A39373A343A35413B373A3D3B34393D
3B4B58514A4745433E39393D3B393F3A383A34383B3B3C3D3E3F41423A3D3A3B423F3838
363F4961594046413F383A3D3D404039363B4040495E4E5344443B3F403E423D3D444A4D
4C47414040413D3C3E3836403A3A4D524C4B4A52464E4B464A4B443F464A464345403B3D
34383A3A3B3F3F3C36383E4141484C453F3F41454F5656524B5953575E6657555D5B564F
5C4E4646473C3B3A3B3B3A433F40424D4E454A4E514B4340444645454442403F3E3E3C3B
424B5248393C4646423C3B40403D3F46414C4D474D5D5E50423D3A3A3B3B3E43544C3F37
393E3A333536363636383D403B494D514A514B473A464648473C393831373A3E44403836
393534353535373B373434393B3835363C3B353839363834353835393B37393437353334
373B3D3D3F37323438373535313737363A3A3634383F40434B4A4547555B484F505C515C
3E3F4346413A3A3E4037393B3F41393934353739383734323735373833313F5342393334
3431333936353435363838373235383835343639
4747433F3F434441444346453F4145433B3E3F40434849463D4142414143413E3D3C3C3E
3F40403F424343413F3E3F403F3C3E3F3C3E42404043443C413D444A4E656B73716B7269
54403E414645678F878D96897569636A736C69616163677B8B8B8576645856585E7691B5
AEC1C5CBB8B3ADC7A6B7A1BEA9A396907D5C4A4547474445393F40413C3B403F45393F3D
38393B3E3F3E3E4039383A3E403E3D3D3C3B3E42423E3C3C3C3B423F42393F42393C3F39
3D423D433D3B3937393F403B373C3A383A3A3B41373D424141413E3935373B3E3E3E3F41
42443D383D3F3B39373734364143403E37413D3E43434847433E413E4045404239403C3A
4240393B373C3F3E3D3E3E3D3D3B4139353C3A38363A3A3D44423B3A3D3F3B3A3F3E3B3D
3C3B3A39393B3C3D3B4037393E3C3F3E3D3B3A3C4042413F3B3E474A423F403D3F3F403F
3F404142403E3F42454645443C3C3C3B3D40434437363A424340434A434946534F3E413C
3B3D3F3D3A383B3E423F505043484B473C3F3B403B413D3D43444D4E4E4D45463E4B5168
646B5B59564D4A4C4744433E4045484F5A6E7D786C6A6067687073829387A199A583918F
99918D6B564D3D443B453B3B474B4D4A3C3D3B433A44373B423E3A3837393B3C3A393636
3A38373D3D3B3F363B46413E41403E3B38383B3D393F3C3637383E473B393F4139393C37
39393C3E3B37373B403D3A3A3734363934353A3B3C3F403E423938333D303D363A373C3D
383D433F423F3E3E3D3A3C4139373C38383C393E393B3D3E3E3C3A38383A373941444447
5D6568694F353D403D3B3E3F3B3C3F3D3B4C5A5748493B42403F373A3D3C423F3D3F4445
403C3B393C3B38373A3A3D434640494B494C4A4B474C47414549474444474340413D383A
37393A38393D3E3C3A3B414544484C48434444464D54514A4C5D5B5C5E62575951525048
50423D4140393C3C3A3939443B3E414C4E484B4C514B443F3B3D43453F3D3A393B3C3D3C
37424E493B383B394038343637373C433D403F3C3F46453E3936343637383B403F3E3A36
35363634393A3B3B3B3D4043474A4344434E49443D443F3F3F393B3D3438383A403D3837
39363537363535383938393B3C3A3838373A363839373A35353A383B3A363A3837363535
373838373733323333313336333C3E4045464241383A393C44464444424A3F4B4B54464B
3E3D3E3D3B383A3D403838373939313237363535363737373736383A3633373F3D363335
35313237313235383A3B39373636373736353433
4B4A484545474745464141433F4045464242403F4042413F424445444445444143414040
42434343434342413F3E3E3F403E41423F3F413D3F41423E454141423B49484B48454C45
59464845453F455A55595F56494341474C4E4A3F40444246565056424838444358647782
8B92A1AAB797AF85B08FAAADB3AC9D8C70617589948D7665484943403B4439483E403D3B
4142413D3B3D3E3D373E42413E3D3F413E3C3B3E3E3C3C3F3E3A3C39413A3D3D3B42453C
393B3B4243403A36383A3A3A3D3E3B383737393E393F3F38373D3E3A43433E4340373D3F
3D3D38373B3C3A3B3A3E3B343C3E3B36333E40474D4B4944433D3C393B3F3C3D3F443E3C
4749423F3D4347433C3837373F363A3A3C423F383D3C36363D3F3D3E3E3D39373B3D3E41
3F3E3E3E3D3E3E3F373B373A3F3D3E3D3F3D3C3C3D3C39373C3E46494240424043403C3A
3A3D40424849453E4046453E3C3F3F3B3D4244413B3B3F423E3738403F40373E3C323A3A
3D3E403F3E3D3D3E433F46463F3F3F4142443E3E3D4847454F4B4E4947463E3E3A474B55
4851535F534A4848423E3C374140484B4F57554E4A4C45494952525A6B71789380827D8A
899E87824E3F3D3F585F4F5471725E524238453648424D4D514F48413E3C3D4038393839
3D3A394036493440304040393D3E3F3F3D3B3A393A3E3933363D3E3E3C3A3B3B393A3C3D
3B3C3E3F3B373638413C393939393A3D43403F3B363B403A383B3344323D3D4138393C3D
393637393B3938393A3A3E423F3B3B38383B393B383A3B3C3C3936343A3B393A41474B51
5856555042383C3F39383B3C393A3D3D414B5253403E383C3B3B373C3F40423F443E4041
3C3E3F393C3939393B4249484A404140444C48414347433E4247474540413F3C3D3A3637
3A3B3A38393B3D3C3F3E434643424545464948484E5450455760574F4E524D524B4F5148
4C3E3D44443E4243444340474649464B4C4A4C494D474742383B4446423E3937393A3A38
3E444A463A373C3F3B3534383B39393C403C3A3B3C3B39383835353739383A3E3D3B3939
3736373A363738393A3B3C3E4B483D3C3D48443E40443A383A36393B383A37363A3A3739
39363638373434363537383736363533363D3A3938373A343238383A383236343B3A3939
39383534323334332F2C2F35333A3B3A3E3F3D3D3F39383C42494B483D423D4A464B3C3A
3C3D3C3A393B3B3B4840413F3E3D37393C39343234363839363637373735323036333336
35313135383838393A3936333534333536373634
4848474544444443463E3F4240404446403F3E3E404343433F4242403F41403D42414142
44444241424241403F3F3F3F42404446434445413E42424044413E3F3F46403F3C3B423E
3E3D403C3E423E3C404346433E3D3F4442413E3C41413E42403C4439453A433F3D41483D
49414D5556564D5A5E776F836E676A6A555E8BA19A949970705061626159493A4435463A
3D3E3C3C434E52504449494038383B3C3D3B3B3D3C38383935373C3B453F4140383E4442
3D38363B42413E3E414140433B37393D3E3E3E3D3D3F3E3B3D4245453E3D403C3A3D4049
3B3C3B3A3D41413F383C3E373F3C3C3A3B3F42474B49443F3F3C3A38393B3A3B42453D38
404643413E41423F3B3A3B3C403D3D3E3D3D3B3A3C3D3A393D3D393B3D3C39383A3D3F42
393C3F403F3C3A393D3E3C3D3F3E3D3C3939393A3B3B3A393E3E42423D3D424247433E3B
3B3D3F3F4B4C463F414847403C43443F3F4240383D3E3E3C3A393C3E3E3E383C3C363D3E
3A3A3A3A39393939413D3E40414040464546403D44555B594D45433D3E434246484C4749
3D42434A433C3D403E3C3C3A413A4346484D47443C43424846504D4E6B638372815A6A62
5855604F46424A4B474E4B52676D645E4F4F4456517067745557534D4A4440423A3B393A
3E3E414B4848573E3E443B3934373B3E3D3A37353D3D3D40494D473F3D3C383535373A3E
403C393A3C3C3B3A3E3B37383A3E414241403E3C3539413839363A3A3339494D3D3E3B3B
3D38373F3A39373738393C3F413D3A37373837363736353637373737393938373A3D4043
42393935373B35333936363A3F41403C3A37353E343B3D3C383A3D434746423D4235373D
3B4041353B393B3C3C454B45413A38393F49463A3C40403E4043423F3B3C3B3A3A383737
3A3B3B3A3B3D3E3E403E41433E38393D454949484E5550455352443B3D413F4044464943
483C3E43493E3E41474941424F4F464345474D47474147473D404844433F3B3A3C3E3C3A
3F40413F3A3C464F3834343A3D3B38383B37363A3B3836373A38383A3A37373939343338
3B3836373334363738383939393B393A3D44444143453B3A3B3636353A3B37343737363A
3836353736343437383D3F3B383A3A373944423D39383B3337393435353237353A3A3938
3735333235383A3A38383C4042464039393B3B3E463C3A3E41494D463E3E3A4440463D39
3B3E3F3D3E413E393D383C3B3A3934383F3B363434363636363735333336343034323437
353233373F3D3937373635343534343435363737
424242434343434449414245403E404042403F40424344443F41413F3E403F3D40414447
4846423F4140404040414141423F42434041423F394041434647464C41454242403D3E39
3B413F403B3A3F3F3F43454745414140413F393C42403F4441403E3F3F3F3C3A3C463C41
3B423A463F403F3C42443E44493E424C42475E5E5B746A795F6E74A29E93615742494942
3A393A41515F60593E413F39373B3D3C38393D413F3A383941403D37433E3C393F3A3B42
444148505D554E4B4A4A4F584B3E3D4345494D4A4A4E54554D4341454D4D604E47503D42
3F41403E41494A434041453E44383A3E413F414242413D3A40403D3E3F3E3E3C3D413F3C
3F4241403F3D3D3D3E3D3C3C3B403E3E413E4046373D3D3C3C3936393C3B3C3C3C3D4040
3B3F4243403D3B3A423E3E3D3D3E3D3D3C3C3D3C3C3C3C3D3F3E41413C3E434248454341
41403E3C4A4742404142413F3B41433E3F43413B444641393B4446413C3C383C3D3B4040
4442403F40414141413F3A3E424041474444403C455156514F47433D3E45454A4C494041
3D4341433C373A403F3F4140483F4749494E49493F4B525B575C514A5B5153514F44433D
43413A48385750554B45494741474D48463A4C44655E6256494E4C4848413B3D36393B40
4A525F6F586E565F444B473F3838393A3B3C3C3C3939404A4F4B4642393B3A3837353537
3D3B38383A3C3C3A3F3C3836373B3D3D373B3B3D38384138444143464147494741413A3A
403B363C3B3A3937383A3C3C3B393637383839373B3A393A3D3F3E3E3A3A3C3C3B3B3B3A
3C393E37363A33363C3B3B3E43443F3C373738433A4042403B3B3F4346453F3B3E373D43
3E40423738363B3C3A3F41383838393C3E434337393B3C3B3A3C3D3A3837383938393B3A
39393B3D3F3F3F403C3C3D3E3B35353B40444544484E4A403C3D3934393A3937413F423F
484042444C424242474A43434A4A403C40454C46463D41443E42463E3A38383B3F42413F
3B3E3E3D39373A3F38333032353738383537393A3C3C3A3737353638383534353634383F
423E3A3A393A3B3C3D3D3C3C38393B3A3D3E3C3743453B3B3E393836393B373436363539
383533353534363A3A3F403C393B3B393B4645403C3B3F3737362F3338393D3937363533
323233343436383B3F434647393F3E3C41474C52493E3A3B3A3D3D353736343E3E474341
3C3F3E3D3E413F3939363B3C3B3A363A3938373737373635343838333236363335353537
3635373B3D3B383737393939383838363536393B
494848484745454845414345413F4140474442444442424241434341414343403F414448
4947433F41403F4041424343454142423E3E3F3C3E4441413D3D393F3E3F3D3E3E404241
3E433B44403F4242444643454442464443473F3E414041414444394038423B3D393E3B3D
3F3F393D383C3D3D3E3E3C3F403E3C45474348463F3F423C47405877928772595C525A49
43414149555A5247393A3A3C3F4242403C3C3D3D3C3B424A6664573E3E373D454C464654
5A5B6364625A5D656568747D5E463E42475C757D939AA3A2907D7D89A1A0B49D908D6255
403B38373A4346413B3A423B43353E47433F464845433D3B3D3C373D4444423A3B3E4246
47443E3C3F3E3E41423F3A38393E3D40423E3D39373D3D3C3E3C3B403D3D40413E3E403E
43454543403E3F413F383B39383E3E3E44454644413E3E3E3F3F44464241434045454545
44413E3B46413D3E3D3A393C4042403B3B40413F4C4B43393A4241383F3D3A3B3D3E4142
403E3C3B3B3C3D3E42423B3E3F3C3E3E4342423E4546453B4E4847403E413D414B473F3E
3D4142433E393D42403E403E423D4345434543403D454A524A4E453D443B3F3C413C433E
3A42404A534C56454B404D4E3F454B434D4B44575261453F3E44413F423D373B383E4245
474547515E585F4843453E403C3D3F41434443413C3C44483F36363A36383B3B38393C3E
393D3E3C393839393B3A373435393B3B393F383C3D3D4D516B766D76555A3C3D40413D3D
423D383A3A3B3A383A3D3D3C393A363838373A373A3A3C404343403D3C3A3C3E3C3D3D39
383A3F38373B3841393D3E3D3D3A36373A3B3C423C443F403E3A3B393B3E3A3A3C3E484A
403D403D3B3B3E3E3C3C3A34393C3F43403E40373B39393834373B3A37353738373A3D3C
38383A3E403F3F40373A3A3A3B39393E3B3E3E3E3F3F3C3735383C373835393C413C3F3E
4943464649464A4643454349494A424143454942473C3A3B393D3E363536373A3C3D3C3B
3C403F3A37343133373534353839393934393B393A3C3A353735373A3B38383A3335393D
40444B533C3C3C3E3F3F3E3C403C3A363B393731404238383C3A3D3D383B373536353439
383432343434373B393B3B39383838373741403F3D3D423E353B3E4B524F4B413A393836
36383B3E3C3C3B3C404444403C44454142413F413B363537393C3C39383A394046494341
3E3D3A37383B3C3A3531363535343034333437383938383733393B383636363338373737
37383A3C3B3A393A3A3937353637393B3E414447
49474646444041453F4044443F424644413F3F44474646483D3F3F3D3D3F403E3C3C3D3F
4141403E4341404042434342454244443F3F413D41453F4342463F4343403E3C3C3E4144
454239403D413E3F42423A3B3C3D46463F4A4341423F413E47453D3F3D444244423E453B
493D40393D373D373E37413E394141484941414141393E3F443A3E4049554F504955524D
433F3E454D4C453E46424040413F3D3C3F3E3D3B373A47547383836555434C5E464E596B
706D6B5B59566C817A71716D6752525C617EA5B5C0C8D1D2C7BDC0CAC8C9CFD0D4D0B095
624D413F3C3A3C3C494A5041493E4C554C4246433E4040454E473E4D6067645549423F43
443F3A393A3A3D42434141443E3E3E41393B44354A4C484648443E3E403F4445403E403C
4041413E3A393B3D3D343A38373E3E3E3E424749464443443F3E44464241413D40414344
42403E3D3D3B3A3B3A3A3D4245433F3B3A3B3D3E42423F3D3D3F3D3942403E3D3E404040
40403F3E3D3D3E3F3F413C3E3D3C413A3C3A3E3D4643433C413E403C3B3E3C413A3A393B
3F44484B423E4145413F403E37393B3F3D4046423E3F3F463E464442413C453F443E453E
36373D494B5F3F3E3436494A3F414447574A4F44514942383D44413F46423A3E3F484F51
4E433D42434A3742343B3A3A3D3E42454846423E43434744383336383A3941433B3D4545
3F43433F3C3D3E3E37393937383D41413C473E4852546C7E9DA29D83705F4D514A4E4C46
423F3E403B3C3B393B3D3C393A3D373938363D3B3E3F41474C4F4C49443C393834363935
3A3A3A363837343C383C3A38393634373839383739493C3E3F383833353A3638363A3F3F
3A3738394242403E3D39373B3D3E3F4540393E393936393935363A393834363836393C3A
3837383C3D3B3C3F353B39373A3B3A3D39393A3B3935333539393E3738333A3C3C373B3B
433E43433D3E453F3A3C3C44474840414240433E413B3837383A38343738393938373737
363D3933373B3C3D3637393A3C3C3A3933363634343535333938393C3C3A3A3C40403C36
33363C403B3A393A3B3C3A39383537343B393E3D3A3D35353A393D3E373A38353635353A
38343335353435383D3A3A3B3C3B3A3B343A393C3B3A403E39444C585B5551493B3B3B3A
3A3C4144444544414243413D3E484945433E383840403D3A393734363B403E4149463C3A
3F3B37373737383A3D373938393A373C3336383736353738353738383838373439383737
393A3B3B3C3B3A3A3A38363439383B424B504E4B
4342424443414449424447433D40454144414145474443443F41413F4043434243413F3F
4144454645434141424342413F3D40423F40413D42443B42444A40413E3E4140403F3D3F
403B3F4A413E34423E413A3D3D3B423F38444144453E41404741403B403D3F3C3F3F3A42
3E443D3C3F3636393A3A43403A39373F403E45413E3D495545464640454E51413B3F4543
433C393D3F3D3C3D413C393B3C3B3E43383C41413B39414C70848E7F7758443D3E4C5560
64686A55564F667A6B5E5D544B414F5C56637D858C939A9C99938D899A9B94B1D0D5D1B5
9B775F594C3C393D6369715F6B697E878D766C5D566373847D72667C9BA8A59167534342
43404043424142433F3C4148433C40453C53776C766B554644423D3D43414647403E403C
404244433E3B3B3C3E353C3A383F3D3D3E444A4B46413D3C403E40413D3D3F3D3B3E4040
3F3E3F404444413C38383B3E42403E3E3D3C3D3E403E4247453E3B3E413F3F3E3F3F3B39
3A3B3C3B3A39393A3A3E3C403E40483D3D383B39423D403D433F4039373B3B413A3A3A3D
4041403F3B373B403D3B3C3B3B3F3B3B3638433D43403F453A3D3A37423B373C3D444138
434D42413E3C39383B3A3D3B4348424C4A44403F3D4339383C4543444C463B3D383F4241
3E36363F3836363B3B403C40403E3D3D3F403F3D3A393B38353B3E373F404F52433E413A
4B49433F414749463A3E3F3D3D424646435551616E677A8F939F8F8C7B856C7A61646050
413E42453D3E3D3A3A3C393435393438393A454659595A60686E706F5C4F453E373A3F3C
393D3D3D3E38353E3F3F383840413D3E40464B464959474C3D363834353B343739383537
3C3E3B3942423B383A34343E3E3C3A423D363E3A35343B3E39383A373934373834373B38
3A3736393938393D363C3933373936373837393B38323338333139383F393B36413D4341
464047483C3C423E3C3F3D423D3C343537373E3E3A3A3A3B3E3C3735363739383637393B
373F3B32363A3735363634333336393B3C3B3A3A39393B3D3937373938353435383A3939
3E423E373B3A39393B3B3A38383A41393830383C353B34363A363838373B37343635363C
383535363633333539343337383636383437343838353B3B343B393B38353E4036363736
36383D4035393A3837393A383A42433F3E3A3637343A39373A393941353C383945403536
3D3A393C3B363538383132313336353B393A3A363230333737343234383B3A3939383738
3A3B3B393B383635373A3C3C4541414954564D43
41474441413F43493E424444444147403F3F3E404441404745414042434140423F41413F
3E41423F4241423A3D404D3F404040403F3E3E3E414C464047463D4141403E3E3F3F3D3B
3C3D34473E393F3D3A3F3D44423A40403D3E3E3D3E3F3F3F3F433D4242453D403F3F403A
453E404141384041443D443F3A38393A3F4242444544504B373B44383E3A3E413B393C3C
3F403D393A3D3B363E3E3F3E3C3B3B3C3D3A3F413C404E555A675B65525147423D3E4042
45484B4C4445514A4A4548423F42464645464A4D4E55534F54565559525B687F7892938B
7580816B5D403F4D6D97947B8394A5C0BCB0948F7B8C9FBEBBA39EACC1CDC7C5AB88775A
4C59595F697A6D52525F6364697B685B567F909E7B795E4C4E51514A494D54506C5D6557
554046393F3B413A3D3C3B3E4447433B3C3E4E464A4A4134383C3D443E45394940373B3A
473F3A4146433A3B3D46433E3B444A4742403F3E41383F464339393537423642434D3A42
4240433D3C403B3A3D3F403C4041393E363B3F423B3C443D3D3C43454042454038383A3C
495D423A343D3F393B46484144423F3F41403C39353C3B3637393F493E383D3D41373F47
4041413E3C3E3C353B3E374F5D4E4C49433B374146393443414D4D4646433B37393F403A
36393C3D3838393B3E3F3E3C3C3B38373A3E3D39313A393B4340404D405C53504F3A3C44
3F413C3B43454143474A49464239353B3E424B4F5B516C6280726C64687271766D716C5E
54555756514542393540423E393E393C3E586B7A7E85838295928D7B6E705E3C3F433A59
4F54423F393B3A3B3F3743373C3F5A5763605F6461644F49403E3C3A38373737404E493F
403B363D3B3D3D3A38393D3F413F3D3B3A3A3C3C393E393C3A373F3E373A3835373B3936
40383D3E3B353A37393433383B3B3B3B3B393932383833373B3B37353633353D393D403F
40413E393B3E3B383A38373B393A3F3E3534383831383C3B3B3F4242393B3A3534373736
3636373838383838333435373838373733363A3B3A3837373636383B3936373B3B3A3938
393A3B3B3838383A3B3B383632383B393537393A35383B3A3837393B3A3A393836363637
3736343435383C3D38393938363536383A3836353435383931343835343837372E333238
31363439353934393A373C38373640473E373A3E403B3D3C374642423A3E3D3C46453E3B
3A47473B3D353C39353C32393A353A4238373737383736343333353738393B3B3B3A3736
38393C3B34363436333844404743384147473C42
434642404646454542473B4A47504A494645404146443F41433F3D41434241424242403E
3F4343403A3C404146424A4136404141454442474045413E44433F423E3D3C3C3E3F3E3D
384A586B584642403D3F3B3F3E3A43473F3E4043444342443B403D3D3B403F42373D433D
443C3C3C37393541393E3B3C3D3E40404344413F383945463D444A3E413C3E403B393B3A
4040403E3E3E3C393738393A3A3B3D3F3A3C3E3C3F4D534A474E3E44363C39383C3B3B3B
3C3E3F3F3B3B3B38393A4F4B373C4245434140403940424142423F3E383F404D445B5C58
4A545A504F3C3B45536E6C5E656D7588867F6D71626B6F817A818C91999FA8C0B19D886B
63696A787C8F8B7D849092949E98996D817A999A8F8F87919B96959597938F8E929A9D8F
67564C56545C48413C414442424749485C4C7F5054414D464740483F48424041423B403B
44403B3B3C4245403B393A3A434545403B3C40433D363F3C44373D3A4138443E4A3F3D45
3D3C403E4249434138393C3A3F413B413E4444433C39403C3F3B403F3B3D3D3F383B3C3B
3943373F3940423D3F4547413F3F3F3E3E3E40413C3E3F3F3F3E3F433E3B413F463F4240
43423F3D3D3E40444A595D6F6C50443C403B373C413F40484048453C3C3C3A3938393939
38383B3F3A3937383B3D3F3F393C3D3A38393A38383E3F434C4E515D4351424041353D46
3D3D3A3B3F3D3A3B3A3D3C3D3E3A383F363B4449564C645A504848485363686F5C68695D
5861645E5F524A3C353B3B3D353C3E4B56768FA39FA096898B7E7F798889795755554657
4E4E3E423C3938413F4946634E7376807C7D7F7E6E654A433D3C3C3C3E4145474B4F463B
3B3A373C413A37383A393A3E383838393A3C3C3C3D403A3B3A3A434435363737393A3A38
3A373E39413C3E3435333538393736383E3E3F39393933393539383A3B37353C393B3C3B
3C3E3C38343B3C3C3E3D3F463C3A3D3B333339393236393B3F4343403C3E3C38373A3A39
37373737383837363536373939393939343537373737393B3736383A3936373A36383A39
37393E423938383839393838343636333335373538393A393635383B3B383636393B3C3B
3636363636373A3B383838383939393938383838393A3A3938383836373836342F35363C
363936393B3B343637363C3A3D3B434941393C3F3C3743353C38423D403946425B46453D
384341373C363C38343834363B32373B3635333334353534323436383838383835353335
37383837363A3B3F3E434E4A3F38454862504F46
494A464447454144485559626C5F554C45443E3D44453D3946403C3E403F3F3F3E414141
4547433F41423F40463E454646524F484B49464D4945403F3F3D3C3D3B3A3B3C3E3F3F3E
393C40483B373C4242423E404143505747434143413D3C3F3C40413D393A3D3B4044463C
413C3E3B373E393B3E3C413E3C3F41414143423C413F403D3B424640453D3D3E3A383A38
424242433F3B38383B3B3B3A39393A3C3E3A3A3D4045453F4145383F38423E3C3F3C3A3A
3C3C3C3B3E3E3C3E3B3B5348383C4244423E3C3B393D42413D3E3D383B41393D35444243
373D3F3C433A383E414948464B48464E56534A554C4F464B48545A565D6060746D6E5B49
4C4B4D5F6B736D66738695A19897807D6B7876869197A0BACAC4C3C6BCB2C5A8B9A7B39F
A492A795AF85786664798679645C6065587967755655454A4D4D4A5E5C6B52494B454941
4344413E41403A39383F3E3C373B4043423E3A393B413A443D433A404E3A403F44453838
423D3D393C423D3B403F413E3F3F383D39424041403B3D3B3C393F3F413F3841403F3A3E
393B333B404244404241413D373A3D3C3A3A3D40453E3A3C3C3C4044474241383F3D3F39
3A3E3D3F44404352626E6C6F64494038403E3D3B3C4145424247433B3B3D3E3E403B3A3C
3B37383D3B393838393B3C3C353C403B36373A3C3F444C5557514A493C41373C3F363C3E
3A35383D3C39393A3B3C3A3A3E3B3A3F45414045564E5746433E3F40464E4D4F454F5046
434A4E49464445403F3F3B42494D4E5858666E7B8C908D817A6467677E7D7762605F4B4A
4A473A453F3637466B677A727D7B908B90908B7F6559444449474441404144454C483F38
373939383F37343B3F3A393C3D3C3C3C3C3B3835373C3B3E3D3839353C393A393A373B3B
3B383D35453D3E373637393B3B3736393B413E41373E313B393934393D3D383D4343403D
3C3B3834343C3F3D3B37373E3E3B3B3933353A393637393D4244413B3D3E3C39383A3A39
383635363838363436363738393939383535343334363A3D3837383A393636383B3B3A38
37383B3D393838373637383A3B3B3734353938353A3A3A373434373A3B373233383C3C3B
36383939373637393838383A3B3C3C3B3C3E3B37383A38343C393537383735323639383A
3538383B3939333638383D3C38363C413C37393D39413B43313D3F433E3A374E4E473438
3A4141393F394039383939363E333A3A373533323436383835393B3C3B3836373D3C3A3C
393C3B3E3942485053555C555055557B76836C68
464548484A494B5C7BA093A07C754E4B484C4744494B4541433F3F4447454240454C4B47
464440404A4B4246565F717E8F8E7D685D564E4C4E423E403D3E403F3B3C3D3F40403F3E
443C3C3F3B3C3E3F43423E3E3F434D52413F3D3D3E3F41443C3B4043413F413F3F3F3F35
3C3C3F39404D3C3F3D4141413E4140403E40443C3E3E3A3639404343453D3C3D3A393A38
3E3D3F413E38383C393A3B3B3C3E41433D38455B573F363E3E4039403F49433E3F3B3A3E
41403E3D393B3D42393745363C3D3F3F3D3C3C3D403F4240383C413D414940413D453F43
41423D393D3A393E42404044443E393844433D4741433A3D3C474B434547444F4E58473E
433A39434A4A423F474F5761635F54534C51525C5868778FA2ACB6B6B6BBB0A6929D99AE
ACBFC3D7BCB08C9F8D9FA38966524B495D4C836D95799A80A3A0BBA9BFACB6A599836E52
4242454947484D4C524F4C4347434040414244474D50584E60575E5F7462694A54454A3E
39393E3B3B403A393D3A3E3D3E3E383D3D42393A403C3B3A3C383C3D424139484541353C
3A3E38383C3A3E3B403A3B383A3C3F403E3D3D3E40383A41403C3D40453F3D353C3A403F
3D433E3C464C586F726E5C534B4140393E3C3E3E3A3F4139393D3C38383A3A3846413D3F
403E3D3E38393A3B3B393735363C3F3B38393E414E49494A453E39363839374041393C3B
3E3539403B373A3C393A37393F4141454F464041504949373D3E42474A4B464343423F3A
3535393D434549484D4D4B5A47494750484A495157626B6C6F626763655D5B5556584C47
454539453F3738465A565F5C5F62717275747067555650595B57514B45413F3E3F3A3B3B
373A3B363F3F4345413936393A39393A3C3B38353839393A3A393B3B413A3E3C3C373F41
423D36383E39363E40403D3E3F3B383C3D37402E3F343A3C393B363C3B3C363C39383737
393A393733393B3B3D3A383C3E3A3B3A37383A383A3B3D3F403F3B363B3A383636373736
37353436393A383534343535363636363635333233363A3D3838393938373637403A3536
3A3B3834373838373536383A3D3D3B373639393638393937353537393A37343436383837
383A3B3A3634363836393B3C3B3A3B3D46474037393C39363A393538383537363B3D3C3C
3838383A3739393C3D3C3B383A383B3F3D3A3B3E3B3C3E3C3A3545424B41464C53413E40
3C444741443B423B3F3E393939393B3C38373637383A3A3A383D3E3D3D3937393B3A393A
353F44535966707B7F7E7F777E6D8B85A9919E87
50494B4C4E4F556E99B2A5836A53463F5057544C4A48464750566372766E6259616D716D
6F71767F777A6F758A9FB2BDC4B49F88746B635652433E413E3F423E3E40424342403E3C
3C3941413C3B3F42423F3E3C3D4041423B3E3F3D3F434543443D3C44444140443A3B423C
413F433E3F414131453A463F3D4141454040463B3B40403E3F3E3C3D433B3A3C3A3A3C3A
39393C3F3E3B3E45393B3C3C3D3E41433A384659553C35423D3C373A3B46403E3A36373D
413E3B3A3F3D41433A3F443C3A3A393938393B3C3F3E403D3539403E3D453D3C3D413A40
4345403C3B3C3C404643444540403F393E3E3B403A3D3B3F383E463E3A3F3D40444C4040
433B3E3E45433F3E403B393D463E45354236443F3440454B515B655F5A59745B6A505D68
9598B89BAD7D8999A5A49884746A5F545A848CC0B8CDA1B0C2D3D5E4D7DFD3D0CCBFB5A5
8C76605D7482BCA2BE8FA2929B8C76655E5F6469737B6D7068726C777077595C434D4041
3F424944414545494B42444342413C3F48493C3E4744413F3F3E43484E483D4640433C3C
333A3B3D3D393E3C453D403D3F3E3D3F4141403E3D393C42413B3B40423D413F41363A3E
3E48433E49535D6D645B49403E3E3F383B36393D3A3C3E3A36383939393A3A37403F3C3C
4147464236383A3C3C3B3A393D3F3E3A3A3D40414B413A37353537393D3B393C39363E40
43383A3F39363A3C3B3C38373D3F3E403E3E3C3A3F393E3A4345464745403B36403E3C3B
39383C4245484E4F54524E5C484640453D40414B444B51515A585E515947414041464545
3F463C423C39394143463B4734444149404243443C433E464E4C4945423E3C3B38353B3F
393A3E3A4652594F3F38393C3B3A3939393735333A3A3B39373837393A35414041384241
3B3E3A40464949554F4A403D403C373B3B3A35383A43383E363E3B423A39323B3D3A3839
3C3D3B3A3C3E3C3D43423D3D3B393C3F3C3C3C373C3E3F3F3C3938393B38353536363535
35343336393B39373535353535363636373634343536383939393939393937363A363335
3B3D39343638393836363739363B3C3834343535363738383737383936383A3A3837383A
3A3B3B3935343639353A3F3D37353A3F4749423A3D3E3B3B373B373938333A393C3E4140
3E3A3836393A3C3C3C3A37363F3E3D3F413F3D3E3C3D3F41413842393C3C4344453E4245
485057524F4249434D47403C393E3E3F38393A3D3E3C3936363B3A383B39373C3636383D
3A505F7B828F959DA19F9F9996948DA99FB1A39E
7C71706B6F75768AB2C1977E57615558555E5E5856565C65717C91A4A89A887C849BAAB1
BABEC2CDBDBBAAADB4BEC0BBAF9B8D806D6661535044404344484A4544454645423F3D3C
3F3D403D393643443A383B3C414843403D40413F3F403E3C44413843454A47554C494D44
413A4342414044414C4A48434B5055625D575D505455514A443F3A3940393A3D3A3A3C3C
404042413E3C3F433D3E3E3D3B3A3A3B41433E393A3B3B3D3F3F41414248403D3B38393F
413C38383D3D3E3F383F3C3A393A3B3C3D3D3D3D3C3F43403A3A3D3B42453D3B3C3F3C42
404644423C3F3C3F4140413F3A3C3F3C3C3E3E3F3A3B3C414340443F3F443E3947494041
3F3B413F4B454040403D3F453E413C42353F3B3B3E403E413E4049454E4B444B35403E4C
505A5461565C4D6767635C595A5B554D535C929DC5A1BCA1C4BEC0B2CEC1CEC4D4D2D1D2
C9BBA9B2A8C1D4E1D5D3CBCCC3C3BFBAB6B2A9A1A09189656449504D566059666A62635D
59616F6F6F75747862514B4642413C3E424B50606960564C404042494D484446484B4C4B
3D433E3D3F3A3F3A453C403B3D3A383A3E403F3D3F3E3C3E433F3D44453F444345394047
5158524A4E504D4F45413D3C3B3E423E4139373A39383A3C3C393A3A393D3F3D3D3D3A38
3D45443E3839393A3C3F44474645413C3B3E3E3B393735393D3B3A3C3C3C3B3834353B3E
3B34343838393D4144463F3A3D3D3A3A383B3A363936393C40423F3F3C383A3833383B3A
3A3C3D3C4142484848453E423F413E453F4443494043444048484D3A4C3F3C3F3F40413F
3B463D3F3A3C3A3C3F3A423B4138403F3D3D3D3F383F363A3B3C3D3E3E3F3F3E3D393D3F
3A3A3F4045555B4E3E3D44494342423F3C393634393B42413F413F434C4A5C5A594B524B
4A4B694870586F5C544E40393C38343A383C3645465E535E4A46364040483E4250494342
42403D3C42413B3B43433D3B3B393E413F3F403B3F3F3F3E3A383B403E3A373739383737
35353537393B3A3839393838383839393736363638383837393A3A39393B3A3739393939
383836363738383837373838353B3E3A36353738353637383939393934393E3E3B3A3C3F
3A3B3A383635373A353B403D36343A4142453F3A3D39353A39413B3D3C3B44404644443F
413E42423C3B3E3B3B40434A4A4A494D545552535157556655564B474855556555676368
686E75716B5C625A6C53693F62455E4D45474B4E4E49413B3C413C3A3F3D383D3B3B414D
4E6B7796949F9EA0A3A1A3A0A898AD9ABCA3B3A0
A6A6AA9DA3B3B3BFBDB79F847F81908E898C877E787377848D929EA9ACA8A3A2AFC5D2D7
DFDAD3D7CCBDA6AAA5A3988A7D6E6560544E4E4D514B474A51585852494947433F3D3D3F
3F3E3E41443C44374542484B56615A564B4441434340434A45564D5A5C6F6B7F705D574D
4A414745454E4E7B6B9170786F72758479696E605C544E49464545423D393B3E3A393C3C
434546423E3D3C3C393B3E3E3E3D3D3E474B42373C423E373C3E454341443B3A403B3C41
413B393C3F48414542443F3D3C3D3E4040403F3E3A4244403C39373842423D3B3B3C3C3F
414642433B403D3C3F3D3D3D3A3B3D3D3F40403F3D3D3E3F3A3C403B3C3E393D383D3D3E
3D3B4143433F3D3F3D39393D3D3C40423C3C3F3D3F3C393E3B3A45443A3B473F453C473C
443C4A384F3A3F423C3E4143413D3B3C3E4144565B826E9794A0899594988C9596A9B7C6
CDC9B4BECDCBD1C8D2CCCEC5C6C9C6C0C1C8C7C0BBABA18A7A646463798D94A99B9DA2A5
A6ABB4ADA29782786F564A433F434347495D768D89715E4B43443F4A51556563665A5755
484B3C3B3C38403A4A454D474C4F53575855504C454C484E5F5C5052554F524F57535C60
7065544847484746403D43474444454344403B3A3C3A393D3B353637363A3E3B3F3C3838
3B3E3C393D3E3E3E40454B504647443F3C3C3A37383A36373E3B3940383D3D37373A3837
353432343B3D3E414044403B3F403E3F3F403E3A3E3D3A3D3C403B3C3A363C3A373A3E3F
3E3D3C3B4F47453C383E3C3D3D45464D46473F3C3C3F46464B474E414143464645474740
38433A3F3B3E3B3B3837393B3B3736393B3A3A3C363E383E3C3D3E3F414244443F3A393C
3B3B3D3F3C454A45404145483B3F4243413F3E3E3C3B4340424C54615C5B6F68665A655B
5F75677D608161554A4A3F383A3738454B4D6D617E6464595D54404E5564565650463E3C
3E3E3F403F3E3939414341423E3B3E403E41454348433E3B3A3A3E44403B37393B393838
37373838393938383B3A39383839393A373636383A3B3A39393A3A393A3D3C38403F3D3A
373636363A39373737383939393C3D3A393B3C3C383838383838393937393C3C3B3A3B3D
3839393938383839393C3D3B38393E4341433C3A403D3F4E4C564D51585D685C5E5A5B55
5B59606058565A54545F67756E706E727D7F7B7B7B76898284737670777884828788918B
8D8C908D897B80747E7E6E7F66846F726A6D7174726A5F57595C524C4F483D3F3D3B465D
65817F9697A29F9FA19D9C99A2A39FA3A6A69D9A
B4C2CCB5B4CAC9CFCDC2A99E959CABAFA3A39D97949197A6A19D9B9DA3AFC1CFD2DEDEDA
DED7CDCFB1967A817873675A544C484B4B4B566568635B55585B53494C4A45403B3B3E41
45433D424F5169616E686D6E7A867D776B574B4D4A41485962847A827D9186998F736866
6D64605572649194B3A8A09185817D867158594A4E4441434446433A3D393C3F3A383B3B
3A40423F3E3F3F3B40424443403D3B3A46433A39403F3B3F403F433A383D3A3E3F3A3A3E
3E393A403745333A3B3C3E3E3C3B3B3B3B3B3B3B424C4B44423E3A3E3C3B3B3B3B3A3A3A
3F403A3B353F3D3D433E3D41413E3E4142403E3C3D3D3C3A3C4140393D3A313B3A454A47
4138373C39373A3E3E3D4044403A4245413B404144413D413E404C49465A50473E40423D
3E3E423C3E3F404C3A393B3D3A3639403F39443E443B3E4B4C54434B5C554E555B75818D
9AA08E9C809986AB82A58A97909BA19FA3ABA6999A8C9F94A0899C98B9B6C3AEA9A4B9AF
AEABACA6A6A89F9B8D6D5A4E494D4F536C809AA88F69503B46525A74808595888365584E
3E4338424343504D666976716D77848A867B70695B61585D797D70717773746D736C6B64
67523F3A3B3E3F3F534F585D564D443C3C413D3C43433F423D373A3E3C3F413C3E373539
3D3C3C3E4143454546484C4F414546413C3B39373A3E35333B3734403A403D34393F3936
3B3E38363D3D393A3D423E38393936363B4244403F3D3B43353C393E3C363B38413C3D43
433C3C43433A3C393A494C49444D4E534C5149464B4B514D473A464239444238363E423B
3740373F3D3E3B3C3A3A393D3B39373C3A3D3F413A40393F37373637383A3C3D3B353338
3E3D3A3937383B3F413E3936353A40413D3836363737403B383F434F4544574C4E4A5E56
5E5A71627B6F72503F453F393C3A4052616E727D757F717C595F5A6E6E766568584C403C
3C3C3E404A4A433F41403F43413D3E3E3C41494A53483E3A3B3C3F44403A36383A393738
393A3A3A393837373938373636373838373636383B3D3C3B393B3A393B3E3D39443E3837
3A3C3C3B3D3A363536393A3A38393734363B3C3A3C3A3837373838393B39373737373636
3637383A3B3A39383C3B3A3A3B3E424444443D3F4B4F5B746671666D7C88938272747E7E
8680807B8482867D7A838B9A91928D8E9797908D95959EA19294919A9F9D97A397A5A09F
A0999997978B8E7F8A79947B978894828E919698958B7F7778796C62615443413E3C4D6E
7D998B99909E9D9FA198938D969298869B888A83
769BB4B1A69C9AA0969992837D858D8F9088878F9597A0ABA895848091B2CACECED4D7DC
D9C1C1AB90756E787C705F6245444741575B78798F8286696D6A65504945413E3E404040
45475F808AAAA2AEA09D90A49FADA69C806E5D434A4E7474A4A4A793969590938B7E7F86
8F8C869992B6C4D9CCB9918D6361504F504444463F393D4340463E3C3A403B43373F393F
3B3C46473939374748544944454A4040565652444C4640383939403E3E3D383B423E3C42
3E39403E3C3C40413E423C3E3F3B3E4343415864635743434F3F45433D43434347433D3E
393F3E3B3E3F3E403C3B494641394344443E413C40383D3E3E3C3B3C3E3F3D3A3A3C423F
4336394039403D393E414042403D3F3D3F423C3D404746585962686266534B3F3A413F3F
414242403C3C47553A3D3A3A403F3B3E3F4142413F3F404041453F434B474440474A524A
515150474B4E564B4F4A484D52616B6B6B6762685B625A7F78878FA59793898979888599
908B92949C98A8B3A89F8172728A7D7B7582807E7B72706F727993A6A7B39D8665504E43
443C4D515C6777858D949A9F9B9EA0A79A9D88846B6C5C716D716C78838377656A5C635B
4A4A4A5047514D5B5F6B6960534A4941443F41453E4A423E434D454E4D5D574F403C403B
4F3C534C5D58524A444B4F4540384539383E3B3C39363D3C4A373C423C3635393D434137
333E3C3B3A3C363A3D43393A373B37413B5558484A3C3C39373C374240403E49443C3D40
41413D3A38353E353B3E5050565254484A413941444F4A3B3B41434245413F3F3C373639
353E3D393C3C393B3A3836363839393837393E3D383B3D3538424036363A3A3936393A3D
3F39353A383B3E3F3D3B3C3D323838383C3B393D353B3E3A363739393D40413D38383E45
40504D606276575D494E404344445756716A776C826570606E6767696767655C56514C4C
4F52575A56535A4E4A493C4E42403C3C3E4041413E41343C393B3D3D3838393A39383736
393C3E3D3B38363635333933373B3C3F3A32423B3B393A393D423D3B3A313A393C40373B
3437333E373737343A3E403C43363C363C35403233383A40383C35393B3C3B383C3C3B36
3739324234413B3B3D444954555866617B5B765A89698C908F9192909497A094848D9290
939899958A94899C899F99A697A7A5A39EA0A796A492A79FAA98A695A29AA89AA49C9FA0
A2A69E9C95928C828191819185937F8C889B97A39998979C8B8A87767B664C4C48596C80
9C9DA299A09BA29F9C9A92988CA091AA87AA95B2
5165706E6B6662635A5E5D5755595D5C5C5B5F697072767B7463595C677C8D917D8591A6
B2A5A38A7A707985826B514E4A3F423C58667A7A82787C696B6D6C5F4946434243454748
6061779BACCFC8D0C8C0AAB2AABFC9CCAB9F7A6B5E8095B0B9C2B6AC949F8E97979399A2
B6C0BABFC7D2E2D7D6A98A745E57545867716E6E5D5657493E3D3E3F43423F3C393B4045
423E4E3C453A4650655354424F526353565552484F4745413D3A413C3B3F3F413A3A393F
3C3A43413D3840353E3D3A3539465B7678757A7B73635947494A565C55514D4944413F3C
4046433E3F3F3C3D404751473D3C44433C3A4040463F4242403D3D3F403E3E4037393A34
3E3B3C3B393F403F42403B3C3A42463F3F3C3E556671737E6F6967605345423A373D3C3B
3E393A3D3C3B3B383A3E3C3B3E3C3A3D3B3D40413E3C3E41393F3D414B4444403F3F4237
3F42494549494148424D3D454248484141444548495A596A67757878746959574B5C5B6C
6B67685E61647B8A919078817A94746D5363666D78808C939994ABA7AC9E93755B645C69
48575E7B747E88898991A0ACAEAABFADBCA49F937F74555E5962697D7C7D6E7578777370
6A6A5D6F5A6B535B606F73706A64665F706373616D606B656666746E7574665B4E4E495C
516E5D6C666257473D3F413C2F38453E4B3C463D3A3F3D433E3F364039393C3C3A3F4038
3F4345383E3A42463F40373D3B423C405662604E483E45413F3842385041535957403C40
393C43403C39393D4250575546494A58525A474D3E47443A3B4144453A393A3D3F3F4041
343B3A36393937393B3836363739393939383C3D393C3F3C37393938393E3E38373A3A3C
3F3A373C373A3D3C38363739393C3A383C3A3638363C3E3C3A3A3A383838393B3C3E4041
323E3A444557444E3F463E4445414C484A4C4E59615C5D5846454B505358564C4D4D4B49
4B50565A5E55554B4A4A3F45423F3A37373A3E40403F3C383F353D363D383434383A3937
393A3B3A3A39393A39303F3740343D463F353C3436393E3F3C463D46393B3A3C3E3C3F39
453A3E403C3F3B413D47484F3F473A403F43363C3C3B363B373E3839353D40413C3F3E3E
3A383A3B373D505C5C586575818C8F8E8D8B769C81A08AA5939E9BA99DA49B8E88879989
A196A2939F96A994B49CAB9F9CA0A49E9CA5A398939C91AD97AB9CA69CA499AC92AA94A0
9499908D907F8A7B7B7A8D779B818F8A8090969CA19A9FA19CA99AA2A9B2919C8FA9A1BC
BCCBBCC1ADB3B5B8B1A8ABAFAEAAC0ADC5B6BEBE
4A4D4D4C4E4C4B4C4344454544434140464544464A4C4D4D524644494B4E545750525766
70696A575952585C594D4042433A453E545B5C575651524B4A50504E4545444445484C4E
5854638396B9B5BAAAA48F948EA6BBCAC3B2B6859D92B1BFD2CFD4A4A796A5A3B6B7B7B7
C9DACFC2BFD1C3DAB5C2A5AC8D9992A1AAADBBA9A68D8969604D55586E5E4D4245474A48
414C3F53547B798F70715153405A535F4E4846434D4543404242404433463F42494B4846
3E3C444141433E41394B444B556E82A696948A897F806F6560596F5C6156504A403E3F39
383D3B383C3D3B3C3B3C404743434343423D3D3B3D383B3C3C3E4346443E3D40373D3E38
4142403C41413E3D3E3C393C505758494345537369696164514B453E473F413F3C41403F
483F3C3C3B3E3F373A3A36373C3E3C3D47434243403937393C403E3A43393D3B4042443A
40404842473D453B4B3F3C3D47484540424F58536671757474706D614E483F4744544E57
4D49463D484C57586A5964486A585A47404E525A626771746E716E7F70746658545C6E68
6E6478877F82817F83909DA3ACB5AFB5A9AB91997A6D5260626D768B968D9387A2889289
8981867B796B6462707E8485817C7D767D827C977A8D7A8A7B8A75907B7E6C62725C704E
6953584C4D4F493E3C4042434B50575B606752514A47473C3C403638383939353540453E
3B43413B3636363A3B3E454C4F5253505A5B594B433B47414A5649634C5F51685046383C
484545515248524658515D4F4A3F4F4B5A4F4E454045433D3D3E3F423D3D3C3C3E41403D
363B3936373837393A393736373839393A37393C3A3C4143433D3E3F3D3E3F39383B3B3C
3E3B393E393B3D3B373536383C3C39383C3B3737393C3E3E3D3D3B383B3B3C3D3C3A3735
3B423D3C3A423841393E3840413B413B3B36433E5543514845444547484D4A4141454540
3F464C4E453F3C3B3B403F3B38393A3B3A3837373C393D353E333C333A35333841454039
3B3C3D3F403F3D3B3B353F423F383C4F4840443E403F3C373B4141443D3A3D3D41443941
3B3E343B403B423D4B444D4B56495D495C48584C4346434A474B444140403F424549443C
3C333F313F436C7D80837B929C96A295A58AA188AB8A9D9AA0A0AA9CA4939C868B958E9E
98AA9C9889A596B997B296AA9299919D9E9EAC9AA089AC97A58CAD98A29AAF97AA959F97
98989AA49DACA2AE9BAE92B194B294A6AEBAAFC2BCC4B9BCC5B7CDBFD5C6C4A8CFC6DFCD
D8C0D8BCC7BCCBC6C6CBBBC4C5D1C5DAC5DAC2CE
464543434240444C4A454345454140414242403D404647444844484B4642434244434045
44424B43453C3C3C40423E41474A5850544C4741434340423B4040454041424243454A4D
4A40414E5369646568685D686673828C96A2A2A79CAAA8BBC0D1BDBFA0BDB4C0BDC0BCB7
C5D7CFBEB6A9BEA2B7A3C5C1C1BDC5BDBFD4D5D1B79E7B937284738D7B836A7B5971616F
545C7773ADA9B3A7AE818470867F906A60524C4A5246413D42474D5A4D635B5A8488837A
695F5E535B5159484F4B5E6B777B9E8E9F7E9B939079725452584E454B44413F3C3C3C38
363C3A393F424142433A3545484C44453A383B3E413F3E3F3C4753554F46403D3F46453E
3F3F3F423D3C3C40464A4E536866695D505359605D564B4C3E403E3E3F3B3E3F3B3D3E3B
3D3F3F3D3B3C3D3B40424343413F3D3E443B393E403B383B3E444641483C42404145453C
403C423A4342424540403B4E4D53555555626B5F66656A5D61504E404444424E4C504545
4644433A413E44474542433F3E423A3B3C46474948464A474945464A4D464F45404F566A
737C767D807E7978808B8D88959693888B837A85797263767A7A788188918896909B959F
8B908294798D7989848F91938E8787808976927D9A7E9496907B866F766A61626F6D5256
4C4B463A3F4746464F525051535B5557715974585C4E5137444E4B4743424444464D4837
393F363D3646454C455A5478516C555B4C4C4B454744555369637E5E7047555853464B5C
5A5D65585A5446423541454742443D594357444643454443403D3C3E3E3E3C3A3D42423D
3A3C3B3939393A3C39383838393938383B37383C3C3B3F443B37373B3D3C3C3E393D3C3B
3E3C3B403E3D3B3B3B3B3A39393836383C3E3C3B3C3C3D3D3E3E3C39363B403F3B373739
393D3B3A3C3E393E3C3B34393A373C393D3F3A4444424241524A4341424343413E43413A
383F423F3A3A383C38394036383838373536383A3D423643314038383A36353A41443F39
3D3B3A3B3C3D3C3B3E41404638433F4E3F3B3B3B41474743413F4841453D494747484745
4A46474E5257526668796D696678606B5F71576F5B676770696A6764584D5C4A5F4E5745
434035403D6A7C91948F9A9B9EA59DA19E9C85A286A1879A949E909F8B9E98948C849B83
A58E9F8E9B939E89A98D8E8083798E969BA9A5A8A4B2A4B5AAB9A9B7ADB7B4C2B6C4BABE
B6BABBBFCDB9D1CAD3CAD3B8D1B8C5BFD5CECDC7DACCCBC4C5DBC8D9CDDAACA7B0D0BEDB
C2D9C4CECDCDC5CFD3CCCFC8D3D1DEC8D8C4CFCE
4D49494A46434850474240444642414340434341424746413D414848424346423E3E3D42
3E404642433D3E3C3F4541434D55584F4A404846424640473E403D433F40414041424649
50494646404844424649414B484645464C59787D8776847EA0A2B599AC99A7948D929191
9AA6A5997F84769781AAA6B2B4B8A5ABACAEC0A8B07F80657955615F737C978A917B8887
9FB39EB5B6DDD0DCC4D1B7C5B1BCA2B1A18D817471616264746FA290BEA7BEA9BEC5C6C4
B8AEAC9E8B7C6868525A5A74606F5D7655716F7D6F64453A453C45383D3F3D3E413F3B3B
363B3936393B393A40433C3E383F3D41474E5A68685E4E464354605D554F473F40413E3F
4040424C5051565F676D7171675B5B5549464241413F40453739393F403E3E3F3A393D39
373E3F3E43474E5751565954473F3E404A434145433E40474750514D4C3B3A373C403D34
3A37423A3F3E3E403D444A646C7779756B6B705F555155424C44483D4042404844444042
403D3E3C4639383C41443F4536453C44414642403C3B423F44413E3F423D4B4737485164
717B74766E6D6A68696A635A6768625C5F5E5768686559676961595A68667458766C7F79
897B8478877E8382737A79797570716B767A6D91788E748A737851694D554F534F47473E
5B4B61504B4F4C4E595B53514A4C525A51626A6B6C7B6D865E8554564A474745464A4433
3B33493B625B7469706C856D7558624E454D52535F5A6461616D5F7653664A6355655B5D
6C675C564F444D3743384C444A4555535745493D3F3E4143413E3D3D43423D393B403F3A
3D3C3C3B39393B3C37383A3C3B3A38373B393A3D3D3A3B403E3E383E494135383A3F3D3B
3D3D3C40413C383A40423F3B3636373A3D40413F403D3B3C3E3E3C3B383B3F3F3C3B3C3E
3A3B3839403E3C3B3F3B353839373B3C3B3E3743404142434D423A3E4343454C4447443E
3E44433D3F3F3D464441473A393A3A3837383B3D3E3543313D33423746413C3A3C3F4041
45413E3D404448494744583A5653675D494D4D545D64625D54584D6249645E695A6D5778
56725B7275747F788E8B8D7C957B937B81779085808C888F898C8E8B777A6C8773896C61
413C383A4A7B8F9899A89AA09C8D9584947F9478977D8E888B8A978795879785828D8496
86998E93879A8C9F879B8EA2858792B3B8B4C6C0D3C0D5CCD6CADCC5CFD1DED2DFD3DDD4
DCD8DEE4D6E4CFDFCAD4C1D8C6DDCBD6D0D2C8D1C7C8B7BDBFB6D5C4CBB0B58C9E9DCBC0
D1BDE1C3D1C5D5CDCDD5C7D5C6D8C1DCC0DBC9DB
4C454446434041424541424646423E3E4244423E3E4345443F4349464045494444403D42
3E42413C403D403C3C414045474C46413E3943413B423A413C3C393C4141414140414345
444346463F43423F44453F4A4D49484A3B465C6664535C525764576B5566554E494D4F53
5353544A514561507163827A7F7A817D79796C6767594C53414B3F47576A7184747F7A86
A2ABB6A0BBB2CDCEDBC7D9CCD3BBC8B5BAA79B887F76879394A4AFCEC5D5BABCBFC1C0C4
C0BEC2B89D7A6C575846474D3F3B4138453E4E41493A4235444538444145413C3E393438
3D444340424342444B5A636352484B5D767C848F87775F52465157514A494641464B5164
6F71696D7B77736D6868655D4F4544423E393847453F41493E413B3F43413E403B3A413D
3F3F424C5A66737F776C5F52474444424444454541404B5961675D574E434244494F4B48
514F5C514D48565166626C767A867F76665B5D4F4A3E4238413D424444464247403A3B3D
3A363941554841434D464E3F423F413A414542413C3C433E40473F4B404D4D524C5E566E
6177656A66615D5E605D52494F495347594D50585F60565E615A535155594C4A4C645A58
4F524C5C4C5E4F5C51534E4D4A4548456258776E8D6E726F74626A575C534D515152546A
607052564947454A565F61616566656568547C6073658D637F555F47413E3E3E4049514E
4E5B4C73608670736B805A8D59916671555D5E585F575B5565566F5874585A5862655F5F
595A5F4848453F403B484D4E48534561445242483F3D3E403C3B3C3A46443F3B3A3C3B38
3C393B3C3837393A373A3C3D3C3B39393C3E3D3E3E3B393D383C38425A543F3F3B403E3B
3D3D3B3E403B393C4245423E3A3B40423F3F4140423E3C3D3E3E3E3F3F3D3C3D4041413F
43413A3E413F3F3D3E3A393E3F3B3B3E3C383E3B483C4A464B433E444B47454B46484744
464A494447423C484E4B4A3F3C3D3D3E3D3D3D3E3B33503C52495E515656565556585C5F
5E6063686B6D6D6C677A63785C8F767B67726F7576766E65795F7D52735373635E6A6773
676A606C6B76737D7685808184887883708F7F9784918A96969A9A8F8B72987BB0879466
453D433B4F7587898D8E938E8E8C7D7A7B847394779A819289978FA090A19D989A95AA95
B09BB0A8B8A1B190B99FB8A8A18EB0C9CED4D0DCD2E3C9E5D4F0D1DCD0E1D2E6D1E8DCDF
D6D7DAD6DECDD7CFCBBED8BBE1BFD3C2CBCBD9C2BD9E9EA4A3C2B9CDB8B48D868DB7B4D3
C5DCCCD5D2D3CDD3D4CFD3D1CBCBCEC4D6C7CFC9
4D4644454343443F41414143423E3B393F403F3C3C424A4F48474A484243464344424044
3B424040403D4243464742444546443F3E3E403D40483E414343424142413F3F40404140
4C4C4C4B454748424B4B4145453C3E4442424545413E464D51494C41493A48394144464C
4A484D444046414C3D4A4A54444E48524E3C4343423F4340383E3C3E38474B574B5A6173
7F8D7D82758B9AACA8B4B5C4ABACA7B7AD9A9387898FA9B5BAB4CFBAD7AFAAA0A29F9EA6
A39C988B6D59484A484C3B3A3A404345464547373F3D3E3B40363C3C43423D38393F4850
586264616467696D848B9592836663737C7A7479706A5B57434343423F3E41455868768E
9897837D736D63534849463A3D424E4C474849534F413E4641473D3F3F3D393D3B3B4540
483F4F666D737A7870625A5A5F6A726F6D6960554C4A50584C55494E494F535D666A625F
69667366676B6977788573796D77686055494D47453A3D3F403D3942393D3C44423C403F
40444848574F515A555B595C4655433D4548484A4749524C595C6A5B62585C565E626D61
6158594E4E48485055514A4753554E6253614D5B595D54555854504B63595D445B545143
4B49574B4B3E424844443C3C3A363A383C434055495443565B64556C616F6D716F5D826A
82544C3C3E3B3F47536372798075716E63645F4D535D527B5B76585E4D4A4F585C626969
77697B62796475626B646B5B7872796A69675F4D4A48574E575A5B6D616D51616273615B
635D5C5654515D4F554B575053554B4D4B41403E45403F3D383C403D3E3C3B3D3E3D3D3E
3D393C3F3A373A393A3B3D3D3C3B3B3C3D43413E3F3D3A3C383E3B404D4839383B413F3B
3C3C3A3C3F3F41434546454540434B4B413E424144403F4142403F413C3A393C42464747
3B3D37413F3E41413A383D43433E3B3F3C41384640454549494A46464D4C4543464B4E4E
4D4D4F50564D434B534D49494A453E39393D414548545F796A8A808172767B7F82848483
7F858D9496938F8D9C8F9E8397868C807884777774787673786F6F766A7B767661696471
6B7168726B69716B6D61676A6D5B6B5E616770726A7C7A8C90959689808888A38E9F897D
5C5B5A6E6D9B929B93998E9899899092A797B18DAB8EA198B0B3B9B0B6B0BEB1B3B7B4BE
B9C2BCBFB6BBABC5A8C9C4D1AA95A5CAD1CDD5D6DED0E2CDE0CFDECADBDAE6CDE3CDE4D4
DDD8DDD8CED9C6CCC0CBBBD8C3DCC6CCC8CBCCBBA08D869AB0B7CCCBD0B3AF96B9C6DFD1
DACADCCBD7CBD3D1D4D9CACEB9CDB5D8C2DCCAD5
48444544404346434041414142434343404244433F3E4043453E4144403D404140444A4E
3D403E424E424042494C43414342463E3B413F4241493D3D4342443F403E3C3C3D3E3D3C
4744403D3A3E443D474A4447473D414B46414639413A3E4A42423B473F4149463D3F3E43
42454E454C464C414C4147414142435053413941403A443F3C3B3C3D3B3B3A3D40454648
4750575B6261726F8676868D8279827787746F6D7E8DA5A9A6B09BB0989B6F7F5F626F86
89796752443E454A5C665D54505D5F5E4E4C4B403F36473F40413F3F474243454B627E8C
9EA8ACAAACAFB2B8AFA79A857B5E504C5C54464740433E41433B3A40413D424D5B707A85
817C665D42454742434F51434B56665748575F5644393D453E43393F42413C424345514C
634F61776B686E626467757E7F858C8C81735F4D4442403D41524D615F6C6E7878766359
605F7165716B6B616B685F5C525B484341363D3B3B3E43433D463A3B44443E43433C413E
4950524E5E554D4A666176525C52655B605E58565359686567737A74686958554F64646E
445041423C404A54514749525A4D58535A4E4D4D5359504C52545753504F54505B5D504E
4A47494840403B433E3E37393A393F3E3A3B453F443A3B4745424142444F51565B5C5264
58443B383A373D4447556870736F696061515642544052597D707E707568656B6E6F6E6A
696D686E5A5F544E4F61496353765C62606064595253614E5754655B5D555163616C6265
655C5F55575B625547414C4F4B5542564D4F3E3F45413F3C39434C49403E3E413F393739
403B3F433D3A3C3B3C3D3D3C3A3A3C3F3F47443E3F403D3E3A4243403E3B3A403B42403B
3C3C3A3A40454A4A4846484C43485251443F43444442424545424143404142403E3E4043
3D44404B413B3C3D39373D44443E3C423B393E3C473C4946464F4D49525A554F4C535A5A
5551565D4F4840474F4B4C5B4C47413D3D3F40415B598A7D9990A08C93929395989A9998
9496999A9998999A97938DA2939A87958E9E91918B8E8D8C9E84A384A0889B879B919687
9E8D97959D9696A09A8E89917878716D65725E6F586F6F81848E9993A195AEA0B3A1AE95
A98DAF96BEA9B09FAEABA5A8A2949EB8B4C1A7C59DC8AEC4B7C0C1C5BFC4C8BFBEB8BFB9
C7BDBFB7C8B3C2B4C3BBD2C3B591A4C5CFD2D0D7D2DED0DED0E4D6DDD1DFD1D8CCD8D9D6
D7D5D7CDCDCEC9C5D3C7D2BFD3C1CCC1D2CBCEB5AD9BA2B7C1CDC4CDCEC6BCBBC2DDD9D8
D2D4D0D2CDCDD3D4D2CDC8CAC9CCD7C3D8BDD3CE
4747464341414447433F3E41434242434346453F3C4042413E3F414241403F3E3B404446
444343454342413E3D404448404E4E413E42424042453F3C444948494E49403A3D42423E
3F3A4048413B3E423E41403E404546434240403F3C3B4047473F3D463748424D45535048
4347504C45434244474744413B3D3F3F3E3C3C3D3D3E3E3C3A3B3F4340423E42403D464B
514A5968685A505A4F4A4C3F434B3E444B4B3D4F626C7E778675856E71554D404347576C
72634F4544404C67807969757A8D7F6E4C4E454D4F4644414539496367686A6B7494B7C6
CACDCDCCCFD0CBC2AE9A7E60463D3E3D40403D3B3C3839413B393E3B413D444657536252
4C53444A4448455363686554484F574B4D4B4A4F3C3F423C3D463D42413D404D53556563
655F6264696D66675D757773687371695C564F41403F45455C686B6E696D705E595D5050
544E5050524E4946474B4F5143423F4046433C43443A3F4951403A393A433F504A514852
4B555755534B474D506668635355586856624C454D556562786875637461554449495251
44454B4540484F555E5F55564D514B4B4745455347534D5354515A4F524D53555E534D46
5144404849413D41403B3A3C3D3B3E43423D3A3D3D3B3A3C3C3A3D3E3A3C4140453F4042
3D3B3D3D333939393E3E3D43404345474B4F4E4A4A595B62637B6D74516155555B585D54
564B4A423E3F3D473E3D4549515C5F6668625C5B5D5C5753525F5B504E4A4B5A5169696A
5E5C5959544F4847473F3E4A53484F43513D433B3D3B3F3A3E3A4142413E3A3F373B3E3B
383C3D4035383843423C394442473B4541474340373D40453F413F3F3E363C3B3F404041
3E3C41423C4451585B5B5757504B53434140464446453C46483D434F4441493B4B3E4A40
4F3B4743434A484A404C485152534642443F3D45434842595C72667D74837C8177757B73
735E7B677A54574F453C47505A4742444341475C66818D9A969F9CA596A395A9A09FA1A4
9F9FA6979A95A295AB9CAEA4B89EA89EA7A8A9A199999DA4A3A49EAB94A5969D93A093A6
A5AFAEB6B1BAB3B6B9B7B8A6B394A287AE949F634F678B929799989F9FB6B1B5AFC3B3BF
A6B5B8C8B9C3AFC0BCBCAAA7ACB1C1C9CDC6C3B2BDBCC4BCCDB7C7C0CDBEC5C6BCC0BFC5
B8C5BAC2B3C5BFC0B2BFC9CFB3A8ACBCC7CBD0D3D5D9D4D7D6D1D5D0DBC8CECBD9D6D9DF
D4CED7D0D0D7CFD6C9CBBEC8CECECBCFCBCBC9C5C2C4CBD1D1D2CDD2CED5D2D5DFDEDDCF
D9D1DBCFD3CFD5D5D4D4D1D8CAD6C9D0C3C9CAD6
44444443424243443D3B3D43464442424644434343414346444442403F40444840434443
413F41434849494847474747414D4D44434544434949423F4547424142413E3C4044423E
473F40433F3C3E3E3D4142403E4043464341403F3D3B40474444495445514C574E585146
434950464543414243433F3C3A3C3D3E3E3E3E3E3D3E41424449505644494D5959505355
58515759544A41484640433D475041413F41394147474F49463C4D424D4343393A3D4754
5A57545652474A5E726D657982907B64454F56696F6A696162576A8394887D736D7C94A2
ADB0B8BFC0B7A99F988E86775D49413E373A3B3D3F3B3B4342464E494B464D4E4944544F
5563565B575D5F6D7671665345473D413F4F4043404C464935463D5242485D5F73647263
5B53596468665C604B56494E46464A443E423A40384643464C605063596A564D4249444A
525152503D4042403C3B3D413E3B3A3E44433F414D434B4D5141413E454F4D5B5355464D
4C524D444243454B424F4F4E4546454F434A3F485357646168666B655E594B4A45444B49
3F4249434E535758584D413E43444A3D453A464F4B58565B52455151584F4E4A4E45433F
47414045443E3F453E3C3A3B3B3C3E413E3A3A3D3E3C3B3C39373C3E3C3F44433E37383B
393B40423A3D3A373B3C3D443B3C3B3B3E42403C43484A51495C51543544414B55555C52
4E3F3B3B41453D3D413E454B5662626560595253595C575150524D494A44444F5668615D
4E4C4A4D4C49434042404450494E3B533A4B353D3F3E423A3C373E4042403B4439413C3A
393D393A36423E3C3D39414C4C4F454846414838463F4C473E413842404747454B443C3A
3C3D3B3538414E5555514F514B485446413F474A42413E4B5B565D6259535347464C4648
48524E6E5C816880687667737169615358454F3C57495B68818B90909F9AA29F9E969595
88859192898B76754F574D6E48533B373D4F77778B8EA490A9929F999D9B9E9E9D92ADA9
A9AAAFB1AABFB8B9A4B39EBDA3B59BAFA8ADA5A39B929C9EA5A6B9B2ACA1A09DA7ABADA4
B5ACBAB5BFBDBBB6B9C2C2C0B3BFA8C1B6D5C0B6828297B1AEB5ACAEA69EA999AFA4A8A4
A9AEB8AFAFAAA8B4BABFB8BCC4C7D1D5C4C6ADC2B3D1C2C7C4BEC9D0CBC3C0C3BDC1C2C6
BABFB2B6B9BBC8B4C7B7CFC7B4A1A6C1CFCDCFD4D5D8D3D6D5D1D5D1D2CACDD1D4D7D0D5
D5CDD4CECDD3CAD0CDCACBC6D4C6D1CDCACDD0D1D2D3D7D9CED3D2D9D4D9D6DAD4DBD1D4
D0D8D8D2D1CDD3D3D3D4D2D9C9D1D1CCD0C4CCCE
4443424343434342403C3B3D3F3F4143423C3C44443D3C423D4146464340404140414241
4142464948484746454441403D45444042423F4149453F3F44433D3C4343424041413F3B
3F3B3C3D3B3C3D3C3D3F41403C3D465046423E3D3C3D444B5C5C5C6251564D53585D5247
474D514543403E3D3E3E3C3A3A3A3B3C3E3F3E3E42444646484D5459484D525E5C4F4C4A
49484E4B4742393B3F3C413D464C3C3B3E4141403C393B3B3F3945404542433D3C414749
474446494B3E3C45514E4E65687361523E4B50606B7078706C5D66747F766753474C595E
736F71797B75706F7579868A7253403844443F3C40444E5B63686B5A534B514F544B5654
5F6D5F606568686B65564E4650434735504B4C454347564A51474F5B647C829188857267
655746574449354546483E42393B3C3E403B4332423C4B474C5661546656594B42484344
494A48423D3F403E3B3B4044434042464544464548404A44493F48424F53494E44463C44
474B463D3B3A39393C3F3D413F3F3A3E42443F4950525A4E5E576A525E49524D4B494D4B
44494F4A4A4C4E4D4D403E403F4B414D415048524A5453574B3A454B4B44423F423F4141
484441413F3C3B3D3B3C3B39393C3E3E3938393D3F3D3B3B3B393C3E3A3B3E3D40393839
353539393D3F3C38393A3B403F3E3C3C3E413F3B403E3F483A4741423B403F4B5151574D
50433E414A4D413B433D40434C534E4D4B454046535C5A555E544D4E4D45424844544B48
3D3E4045504D49464C474443443F433C443C42403E3C3E383E3C42414D4940483D483F3E
38433E3E3F52524A4E4054464F42483E4A4F3C4B3B5243463D3E403846414D42544A413E
41403B3A40464E5554515860605B5E594A4B4B51515B4B71718C7F857D757156694E6959
796796859A879D8F989A9B9C989A827C79785D79658879948FA38DAD95B4A1ABA69FA09B
A782A99CA88E9C707A59634D4943444043576F8A8C987EA187A88F9F99B299AF9EAEACC5
C8C2C9B6CFB5CDB3B79EC2A5C49EC0ADB5AFB9B1A8A59AA5A5BEBFDFB0C6A7B3ADC1ABC5
ACC5B2B8B7BDADB4B6B1C0B7C0B6CBB6CCBDD9BBC5A3B5C1C7BBC3BDB39A878B88989399
97A798A3798B82A2ADB7BAC4CDCCCDCDCEB6C3ABD2BACCBDC6BFD6C4D0B1C5BDBEBFC4C4
BBBBB2B6B7C6B2CFB8CEC0C5B09599BDCECACED7D5D6D3D4D4D1D5D2D3CBDBCDDED1D6D0
D4CDD1CCCDD3CBCEC7CBC0CEC1C8C6C7CFCDCDC9CBCACECECCD2D3DAD5DAD7DBD7D6DCCA
DACBD9CACFCBCFCECED0CDD3C8D7C8D8C7CFC5CD
48454242444543414B454241414042464540414646403E413E424544403E40433F404141
4244484B45423E3C3C3D3C3B3C3F3E3E413F3B3E423F3D3F41403F403E3E3C3B3B3D3E3F
3A3E42424040403F3F3E3E3E3B3B44504D47424142464F575D584F524A5047484E4E4441
404146403F3D3A3A3B3D3D3D3C3B3A3B3D3E3D3C424445454445484C444A494B473F3F3A
3939404141413C403B3D423E4142383D403E423C393B3C43403E484D494446473B414646
42403F3F3F3B3B3B40403F4F454E44423E4740414D56625C57464645525953403943473E
403F41474B4A48494A526670655448414948403E4A5C71858F8D85695E565B574F454B49
515D515255575753463B3E4640474054526F626F4E584C6D657E6D7B808AA491A7848678
775C554A4E42454F4A535755484A4143444B3E4C3F58535C627260744E61484B53524942
4244423B3F3C393A3D4142424041454A4445504F4544424B4352534F565647443B3F3C46
3A3A3A3C3E3D3A3A3E3B393F413F3A3C4043404449555C494F4A49454847464444424442
3E4346413C3A39373A313D444E4D5A495C4D55484247444843393E3E403F3F3F403E3D3C
433E393A4044423D3A3C3B38383D3F3C36383B3E3F3D3B393A393C3D383739373C38393B
38383A373A3C3D3C3B3A393B3B3B3A3B3E3F3D3A39373640373D3B40443D363B39383E34
3D383636393A3532403A3B393C3F383846423E404950504B5A4E484845403E40414F4746
3D3D3E425249423C484A4A43423F3D3A3B3C41443E3A3C3743454A454F453F3B3D444141
394946443D4C535163536E5A67586758675D6A526A5763544A594E53424B474554494442
403B3D505E636973736C70748B7285667B607068817C847F99949A8C90898581778F828E
88A58CB794BD8FAC97AB9DAEA9A0A393A68FA284AB8CA297AAA3B39AB7A0B3A5A6A29EAB
97A599AA8EAD91A482966F8466856E6D66648B8099839C7CAD8BA99DB5ADC4B7C0AAC9BA
C2BCB8C2B5CFB3B9ADBDA0BFB2CAADC0B8C1BBC6C0ACB1AABBBEE3CDD4B6BDB2BBB3C6AC
C8ACBEB1C1B3B8B2B4BAADB1A7C5A5C0BADAC1D0CCB6B8D9C7CBC7CBD5ADB293B8A6B9AE
A6A4B58E815A7891B3BDC3CAD0CCC6C4BFBEA7CAB8D3BCC6BDC1B5BFAAB1BAC1C5C2C6C1
BAB7B4BABFBAC8BBD3BBCCBFBC9D9FBDC7C2C8D3D6D6D3D3D2D1D3D2D2D7D5D7D1D9D3D3
D3CDD0CDD0D5CFD1CCC6C8C9CAC4CEC5CECACAC5CBCACFCECDCFCDD4D0D6D1D3CFD7D4D3
D5D6DAD1D4D0D2CECCCECBCFCED5CDCECECACBCD
4D4944434446444244424244434040424345433D3C3F4344474847443F3D3E4140414141
4040414242403C3B3C3D3D3C40413F4043403C3F3F3E3F3F3D3D3E3F4644413E3B3A3B3D
3B3E3E3D3C3A38373C3B3C3E3C393B403B373436393D42484E4D424340444040413F3A3F
3E373E433F3D3A3A3A3C3D3D3E3C3B3B3C3C3B3A393C40403F3E3F403D45403B3A3D433C
3E373A3A3B3D3E48393C3E3B3D3E3B44433D413A393E3B423D3F4B584D41454E3F403F3D
3D3F3F3F393E423B3C403D423C423B3C3F473F3C44454B42413A3C363744453A39423F35
373B3D3D40444340434447464246494344464345546475848681765D585559544840433E
414741464A4B4E4B423A3B444040574D6B64727675676766847C7F78788684918484727D
797C5F815F8A6E826E7C5E66584F61595E5B6A5A6E637068756B735D6C595E524F4A453E
3C403E3A3B3A3C4043433F3B4142404541424E48564C644E6C596A534B4F464540423D42
443A363B3D3B3C413C383B3F403C3D3E3E3F3E4045535A4A4C463E3E4142413C42414140
3E41423C403F4242483E4E4F505B505B445243443E423F3F3F3E3F39393C3F4243433E3B
3E3C393A4046443F393C3C38393D3F3C383B3E3F3E3D3A3737373C3E3B3B3D3B3F3B3B3B
3A3D3F3B38393B3B39393B3B3B3B3D40403E3B393B3D383F3D3C3A444E443B3C393A3F38
3A3C3A3A3A3C40413C3A3E3A393C393D40413F3B3C41413E4744423F3B3D41434C584F4F
464645494D44423B47474E494342423E3E3D3F3F414247424D5057535145433B43484444
41504E554E58666F777C7C987A9582837F8B7C90788D7A7F737B806F7160685B65524945
3E36436E8585808A8F8F98999795819C7C9C879791A385AD86B897A29E9C9D8DA38DA998
B198B998B091A78D989FADB0A8B1A6AB9BA68EB598B79CA39CA797B29DBFAFB8B0B3A99E
AB96B4ABC4A7C3ACC6A8C2A2B5A2A9978F94889B99A790C09FC5A9B9ABC3B0C7BBC7AEB9
B9B0B4A2C3A0B9A2B8A1BDABC5AEC7B1B9B3C2BEBBBBACB4B2C4BBD7AECDB1BABCC0AAC3
A5BCA9B7BEBAA7AFB6B1B6A9BBADBDA4C4B2CFB9D0BDC5C4CEC0D0D1C6CCB6CFBADAB8BD
A8B3A9B47F7B7FA7C6CBCECED0CCC5C5C1B1BCB4CDB8C3BFC5B9C1AFC2B1D3CECAC6C8C2
B9B3AFB6BFC8BECFC2C9C2C5BAA3ABC5CACAD4DDD8D6D5D3D1D2D1D2CFCFDBC9DACCD9CE
D3CECECDD0D3CFCFCBC5C5C7CBC8D0C3CBC8CECBD4CED0CBCDCDC9D2D1D5CAC5CDD5D4D2
D4D4D8D0D9D5D6D0CED2CFD1CED5CDCFD0CCCDCE
4F4A45434546454443403F404143484F6E72674F4144494742424141424241413C3D3E3F
3F3E3E3E3C3C3C3D3E3E3D3C3F403D3D403E3B3F3D3D3E3C393B3B353D3C3C3E3F3E4042
3F3F3D3E403E3B3C393C424645413E3E3C39393E41403F40454D46443E3A39393E3D3A42
3F373F48413F3D3B3A3A3B3B3E3D3B3A3A3A3A39373B3F403D3A39393C443F39393F463E
3F393D3D3C3D3D45403E39373C3C3B40413C3F3C3E423B3D4A4B535C4D3B4046433F3B3A
3B3A3938373D4238373F3C3B383F3B393B403D3E403C3F373B3A413A3E4343404345413F
3E3F3B363A444C4C524E483F3C43453A434643444E565A5F5A5652434643464049434743
4245444C4B464642403F3B3D444C4A5B55675A6A686F59746D806E716F687C68775B6262
73697D688984958C947871646074677C73796B73606E626459685365566D536A514B4D4A
45443E3B414446464442424243443C44494B534856645A6E5B694D453B423F3E3D3D393B
51433D3F3C383A3D3E3B4140403D454748454344454849434E484A3D4839443C3B3B3B39
383A3A363A3F474951434D404B495745493C4E4C424949444041423E393C3C414146423F
3C3F403F3E3E3F3F3B3C3C3B3B3E3E3E3B3F413F3D3C3A383B3B41433F3F403C443F3C3A
393F443F3B383939363A3F404546494B48423F3F40463E41413A3A4245403B3A3A3D3E3A
3F413A393A3C42403C3C43403D403E44494D4D4846494A474246443E3C3F474D4F584E4F
4745444745414B464D4752504A4B55505950514947505C58606470706E72587050724A58
58636073757E8E979D8CAB95AD95A5969C9AAB96A6929E95919C939B8E9288806E52443F
3F40558C8E938E99A09EA29AA88FB382A77C9D909E93AB8BA494A89A9D9C9DA197AE9DA6
99B18EAF96BA93A791A59EAEA4A1AFA8B1A7BCA8C7ACC2AEBFB1CCAECEBBD1C4CED3C3C6
B1CBB3C7C1D7C3E3C7D5BDCFBDC0A7A3A19CA593ACA3C6B1D3B0C3B0AA9DB6ABBFAFBFA6
B0ABA5ADA3B49EAEA0BB9EC3A4C7A8C2B3B9B0B6B6B0BBB6BDB3C9AFC0B0BBACB5A5BEA5
C0A9BCB3BFB0B8B4BFCDBAB9B2CAA5B6AAC5B7CDC7CDC2D0CACDC4C5CACBD2C1CFD1D0CA
CCC2D5BEC79FBDC0D1D1D0CACBCAC3C7BBB6AEBEBBC2BDC6BDBBB0C1B3BFBFC5C4C3C7C7
BBB6AEB7C4C8C9C8CAC2C9C4B9A9B6CDCDCCD3D4D7D5D7D3D2D4D0D2CDD6D4D9D5D8D5D0
D4D1CECCCDCDCAC8C4C8BCCAC3CEC9C3CDC8CEC6D1C9CEC9CBCDCBD7D7D8C8C0D1D3DBC9
D7C7D5C7D4D0D0CACBD1CED1C9D7C8DACDD6CBD0
4A474444454646454E474240434C5A66979E92725852524E524D47454644403B3D3E3F40
414242413A3B3C3C3C3C3D3E3A3E3B383C3D3C3F3F3F4142464E4A3A423D39393937383B
3942484B493F3E494F555A585351525446403C3E3F3C39383644403F3C373A3A3D3F3A3B
39343C3F403F3D3C3A3A3A3B3C3C3B3A39393A3B3B3F42423E3A383840433D3C3B3B403C
393B413E3D413C3E3F3E39393C38373C3836393A3D3F3A39404145463F333C393C38383C
3E3A393B3E3D403B3A3F3C3D363C3A373A3B393A38353C383B3A403A3F403C3B41423F42
3B3C3C3C40454A4D49474948474B493F3D403F40494E4B494241453E423D403C3F3D4242
4345474F413C3E3839414044554F56474F43464C5A6364646C62645E5C5C616156585055
5A6250675681717C6A71516869626F5F605B5C4B524B534F4349504452464353574F5859
504A424243434241404143463C49444F595A625B6C6E81627A5657453E44403C3C3E3D3F
423D3E403F42443F44434A444445525151524D45444442433F473B46383C393B4143423E
3E41424145494E4D5749553D4647454F3F494A52474A4C48413F3F4140413C3F3C433B37
36393E403E3C3E423D3C3C3E3E3E3E403E42423F3C3D3D3B3E3D4345403E3E3A3B38393B
3D4549443D393B3B383C434344464A4B463F3E413A403C3F3C363B3C40433F393C403E3B
44473F3E3E3D423C3E3D444241423D3E474B4A4340423F3940433E393C3C4251565F565A
524C46474E44504F5D59696A66756A846E846B6C606773707B7F8884927F94708F74756C
70787185878A9495A09E95A897A998A2A3ABA2AB9BA79EA1999DA2A0A69B9F9685695645
414251849AA196989A989F9398A298AD8AA794A0959E8FA685AD9AA5A7A8A79FAB9FADA1
B1ACBBABB9A8B1A1A9ADB2B7AFBBBBBDC0CBBFD6C3D8D3D2D0CFD2D3C9D7D2D4D1D8CBC8
CBC0C0C5CFC8D8D3E5C9D1BBC1ACAAA8A29992A2A4B0AAC7B2C9B7B7ACB4AAB0B2BAAAAB
B0ABAEA1B59BB1B2BCAFC8ABBC9FB9ACB7B5B8AFB0BCB9BCB4BBB7C4B1C8B6B5A8ACABB0
A4BCB5B6AEB0AFB2BBC1BDB2BEB3BB9FAC96B3A6C0C5C4C2CFC8CFCAC7CBBFC0AECCC7CD
C6CBC8CFC9CCD3CDD6D3D1C8C8C9C2C9C9BCB4B3BABBBEC0C6B7C1BBC1B5BFC2C3C3C6CC
BDBEB5C2C7CDCAC9C9C8CAC2B4A2B1CDD0CFD4D3D5D2D7D4D4D7D2D5D5D6DBD4E0D2DDD2
D4D3D0CECCCAC9C8C6CACEC5D2C7D1CAD0CACEC4D0CAD4D2C8CDCED9D6D8CCC8CBD6D0D3
CCD1D2CED1CDCDC6C7CECCCECAD1D2D0D8CFD4D3
454444444647464547413D3D41495864657578665350535343444B576160554A47464545
4444434240403E3C3B3D42463B413F3A3D41424546464A505C6C664E524A413F3E3F4349
53687A7D6E59596D737977695D5C6368564C423E3C3A393A3B463E3E423F424045483F3A
37393F3B3C3C3C3B3B3B3C3D3A3B3B3A38393B3D3B3E42423F3D3C3D4440393E3E383E40
3C404337353F3D3B33393A3C3B3539423B3B3C3C3D3E3D3D3B3D3D383A384539403A393D
3C3739403F383C3D3C3C363A41413B383F423E3D3B37403B3B38413E3F443F3940454241
3C393A3F3F3D3E423D3A3F45444546423E4444474F4E423A393B433F423C424346424443
413E3C413E41493F3A40404748484640383A394B475A50584F5454565751604F4E4B4F49
5F565A4B585A5E5A4D514E4F4E5B5049484B4747424643423D3F3E48414835414138464C
46423D433F3D3E42484B47434159575C5D545C5B5E6D665B55493B404046443E3F3F3D3E
3A3C3E3B3B474B4048464C44464A59565F655A443F423F403A3E3D3E423A423D3D3F3D39
3A3E41423F414240525168524F4346484B46474048444645413C3A3F383B373D3C453D38
3E3C3D403F3A37383F3C3C40403E3E423F43433E3C3E3F3E36373E423E3E3F3B3A3A3E40
414442383C3A3F413D3F434140434849443E3F453A3E3F443F3E4943404640363B413E3F
3C4542423F3D443F3D3C434447483E3C45484845484D4A413D3E3637403E445A58676572
6E6A616071606C71857C827996929E8F9F8F9181818083808E919082898A7F8A7B947483
7481798B89898F8B917D977FA17F8B839493969097979C99959FA1A8A19B9EA0907F725D
5759649390A09BA0A2A3ACA0AAA3B8A4B1A5ACA0B4A9B6A6ABABB1ACADAEABABAAB5B2B3
ADC4BECBC2C8B7BCB5BAB4C1BDC8D1CACED1D5D1D2CCDBCFDBCFE3CBD5CAD4CCD5D6C4CC
C2CAB9D2BAD8D2D4C9BCB5C1B2C1AFA290879D9EB4AEB6B0B8B8C0B4B9B3BEB4C0BBBFB5
B0AEADAAABA7ACBEB2BDADBFADC2B6C2B4BAB7B2B4BABEB6B5B5C6BEC1C0BCB0B7AFB595
9CABBBB2B7B4B8ADB0BFB9B9ABBEA0C0A0C0AEBAB7C4C2C9C7C5C8C6BEB4C9B6BAB7C5B8
C4C8D1BFCDC7DAC0D1CECCC3C2C3BBC2C9B9ACADB7C2C7C8C4B6B9BDB4B9BDCECECDC9D0
BDC1B8C9C9D0CAC9CACDCCBFC0A7B2CFD2CFD3D1D3D0D7D4D5D9D3D7D8D8D2D2D6D0D8D4
D4D5D2D1CFCCCDCCBFCFC9CBC7C8C8CCD4CFD5C8D1C4CAC4C7CCCDD5D0D4D0D3D4D8DBCE
D4CAD4CAD8D4D2CACAD1CFCFCAD6CAD5CED5D4DB
404244423F3E40434241403F4143464846474B494144463F4143505A65795E524A4D5555
494447463C43413F454745473A3E393D3E3C464543464C535A626A6F66644F4D4940483F
6477A39A8E6C686E857F72574F59657B706B666156493F3C3B3B3A39393A3A3B3A3A393D
403731373145493C373A3C4043403E42443D3A42393D403E3A37393D383D3E3B3B3E3F3E
3F3F4243403A38393838393938373A3E353B413D393A39383C393B3A37393E3D3C3C3C3B
3A393737423B393D3D383941464A423E3B3B423D3A3C3D3A3F353E3C3F37413D3C403841
3E3D44453A353B3E3A3C3F4141403F3F3D42414147443D3E3E3F444948413D3E393B3D3F
403F3C3A353F45413F4344413D403C3E3E3D44454847413D3F3D404A4A4A53444443474A
47454B50484F5045444C47445051494A524F4641443F3C43374045403B3A3B3A3C3C3D3F
3F3E3D3D3B3A3F424041423E494D4A424043413C4745464949443F3E3B3E46463D3A3E3E
3C3E42423E3C4551494A4447434F555E535E463E413B3F3F3B3B3E443A3A474141443B3F
414842473E40414D50554D4A45444541403C3F423E4247443D3B3C42403C3C3A423F3D36
39373F3B43453F393A413F3A3D3E3D3F3F3F453D423D4442343B3F403837413C3D3F3E41
42433E3A383E3E3D403F414A3F4045444540494F4A4051334E46494A3B4843404F453E45
414A4745494F4F53474F434E495747464F564C49473F4B42403A403C3B55686D79848D8F
958E888988938A9894A198A4A0AA8F9B8DA0979E8C8E97969F9E9D88A386A691A88A988A
98969691979598A590A39D9D8E96888A77897B7F7A847B8A929C93A3AAA3ADA0A792AC82
A0839F9EADA6A6A9ACB3B6B2B9C3B6C9A7C2AFC6B2BCB1B9ADB8B6B6B4ACB6B4B5AABAAE
CCC7CEC8D5C7C4B8C2BCC1C7CBCDD0CBCCD5CAD2D6DED4DDD2D4D9D0D2CDD3D2D9D2C3C5
C6C2C7C4CDCECEC8B9ADB7B6C5AEA392929F9EABAAC0B2C0ADC5B7C1BAC3C2BFC3C1B6B1
B3B6B4AEAFB8C2C6C5B8BCB5C5B7BAB3CBBDB5B4B1B4BABBB8C5BCBAB5BFB6B69BB1A9B1
B1B2B9B8ADBDBCAEACB2B6B7BDBBB6AFB7BEBEB4C2B6BEB5BBC2CACDC2C4C2C1B7B3B4BB
BAC0BCC2B8C1C0C7C9CCC8C5C4BDBCC5C5B9A5B1AFC9C8C9C9BAC1BCBDB7BCC1C8CDD1CB
C5C4BEC9C7CED2CDCEC5CECAC3B3C0D1D1CACBDBCFD7CED6CED8D5E1D3D8D8DCD3D5D2D5
D6D2DBD6CDCDCCCBC7C8CEC5CDBECCC7D2D0D1D1D4C0CCCDBBCBC8D2D2D7CDD9D5DCD5DA
D4D5D2CCD2D0CECDCED0D3D4CAD2D3D5D6D5D9D5
42444543403F424444434141414141403E40434240434644403E45474B5D4D4C484A504F
464245443F44403C404241423D413D40403E4645393B3E42464C52565A5B4A4B4941473E
525C7A6F6A535255575A594A474F57697271716F635140383C3C3C3C3C3C3C3C3C3C3D43
47403C423D4A4A3F3D444A504E4E4D4E4E4540453C3D3F40403F3D3C3A3B3B3A3D3F3B36
3E3D3E403F3C3C3E373B3D3B3B3F403E3D3B3B3E42423E3C3A363739373B403E3838393A
3B3B3B3B3835373D3E3B3B3F3B403F3F3E3D3E39373A3B3A403943414842443F3E3F3841
3D3A4044403D40403B3A3B3E4242403E3C403F4045433E3E3E3F43464643424339383839
3A3C3E3F393F43403F4142403F413B3C3C3C444543433E3E4242454E47454F464C4B4946
4D434F525854584B454C46424B4D474A524D464444413F43373B3F42414041443D3C3C3D
3E3E3E3D3B393E413E3F403C393E3F3C3D4446423C3A3A3D3E3B3B3C39393E403C3D413F
3A3A3B3C3A3A3E43434540443E47494F4C514442413C413E4040404843414F444041383F
454D47493B394745564D51494B4942414248433C393E44433F3E4145383D39433C453E41
36393C413D483D3D3840413E41413F40393D39433B433D433D3D3E43403F48453F3C413C
423C4242424C624F61505D5B5658596359635C6858605268537D63755E70595E5D555252
6F69785F7D68776F767081747B6F7B6E6971616B64625D503F403E3A435A769B8D9999A3
A1A59EA4A197AC94B098AEA3A1A4A49AA79EA8A4A5A1AD9FA0A5A6A3A1AB98B496B090A5
9CA59AAAAAABAAADB8BDC2AFB6A7AAA5ACA39F889088928F979391939CA5A9AC9CB0A1B3
8EB7A4B6AFADB1B6BAC1C1B9BFB7C6B8BEB0B5BAB1B5BBB7BFB5BEB7B2AAB4B8B5C2B3C1
C6CAC8D3CCCCBAB4B9BCBFC9C3CECFD0CBD1CFCED9D7D3D8D5D6D8CED2D1D9D8D1CBC3C4
C4C4CACDC7CFCDD4C3C3C7C6BEACABA8AFB9B5BEBBC1BBB8BCC0BAB8C3C9C7C5C6C1B8B5
B3B6BBBEBEBEC1C5C4C6BAC6B4BDB3BCBCB6B7BAB9BABCB9B5BEC0BFBEB8ADAAA4A8A8A9
BFB5C3B6B9BEB7ADB0B8BAB9BBBBB3B2ADB4B4B6B8B0BAB9BFBCC0BDB6BFB9CAB7BEB1B9
B5B6B8B5B4B0B4B8CDCBC5C1C1B9B4B8BBABAFAAC0C3D3CBCBC0C9C1BBB2B9C1C3D0CCD3
BDC9BCCFC5D2C4D5C5D3CACBC5B9C2CFD3D4D3D9CACFD8D3DDD3D7D8D6D1DACEDDD1DAD4
DDDAE1DED5D2CBC8C1CBC3D2C6CECDD1D1D3CDD0CCC7CECFCAD1D2CFDCD5D1D4DAD9DED0
DCCDD9CDD4D3D2D1D1D3D5D7CADACAE1CDE1D7DB
43454544424143454442414142413E3B3F403F3F413F4045453F423E3A4239403F3F4141
3B393B3B40423E393A3D3E3F393D3A3C3B393D3C393A3B3B3B3D414340433B40423E433B
3D3C493D423A3D3B3940433A383B3C465150525450473F3D3C3D3E3F3F3F3E3D3B3D3E44
484340453E43413C3D43494F5157595854483D3B3D3B3B3F43433F3A3D3A383C454B4943
3C3937393A38393B3A3F3E383942433D3E3A3940423D393740393839383A3C393B3B3B3B
3B3A39393A3A3A3A3A3939393A393B393A3E3C3D393A3B393D37413C403E3A383D3D3B44
413F43443E3A39373C39383C4143413D3D3F3F4043413C3C3D4041403F414242403E3C3A
393A3D3E3D3F403F3F3F3E3D3E403B3B3B3B4445474541424442414647454E4549464340
424750634F504746454A443F454745494D464444414040403F3C3D42433F3E423D3D3B3B
3D3F3E3C3C393D3F3C3D3F3B3E41403B3A3D3D39413E3D3F403F4247413D3D3E3B3D403D
3C3C3B3A3B3C3B383E413D413B403C4043414144413F423F403E3D454745524749474046
4B5048464046404B404A4144464B45403A433F3A3C4143423E3F44484540453C443C4341
3A393E383A3E3B3C4246443E3D3B393A493F413B433A424342403E454440464449473C4A
434F4C575A77708A73917E887C828083947C9585947B9B6F977B918388848A757F7A797A
868F7E99889F8C96839D86A185A085988F8F8E8D977E73556042443D466A92949C9DA59C
A79EA6A79CA296B69ABAAEB4A4BB9EBE9AB8A2B0A1ABAAA9A29AADA4B0A1BFA3B499ADA0
B0A5B5AABDBBB7BCBECDB6CFB2CCB7C6BED0A9B8ABC2A1B2AAB397A2A191A18E968DBC82
B891B69DA2A3ABB4BCC6C9C2C3C4B0CAAABFA8BCB0BDAECAB4C5B9C1BEA8BAA9BAAFACB4
C2BCD0BDD2B5BBABBFC2D0C6CBC7D5D1C6D4C9D8CFDBCBD6D4D3D5CCD1CFD5D2C5BFBEBD
BEC1C4CBCFD4DCD2D5C9D5CAD1C1C1C0C2C0B3B8B0BCB1C0B2C5BCC8C4C2BEBBB9B6B5B9
C1BFC2C7C5C0C1C7BFBAC3B1B8A7B2B1B9B8BDC1BEBEBDB6B5BAB6BEB8BAB3BAA8AB9EB8
B7C1BFBAC5C4BCB4B6B8BABCB9B7B6B5B6B6BABDBFB6B8B8BDB7C1BEBDBCC7C3C8B6B6B1
BABABCBCB9B3B7BDD3CCC2BFC1BEBCBEB8BAA3C1ABD0C4CDCEC1C6B9B3ADB4BAC0C6D4C4
C7BCC3CDD4CCD6C0D9C1D0BDC4BBC1C7CED6D1CCC9DACAE1CAE1CEDBD5D9CBDDD0E2D6DA
DDD7DBD8D3D0C6C3CCC7D8C1DABBD3C7D2CED3C2D1C5D6CFCEDAC7DBD1E3CED8D1DDCDDD
CCDCD5D7D4D5D5D3D2D3D6D9D6D3DCCCDFCDDED1
444545444242434542403F4041413E3C42433F40443F3C44403C42423F3E383E3F3E3D3C
3B3B3B3B3E3F3C38393D3E3E3D3F3F3F3D3B3B3B3E3F403F3E3D3D3E393C383E413F433E
3F3C3F343D3E443F3D41403B3E403F42413E3C3C3C3B3D403B3C3E40403E3D3B3A3B3A3C
403B393E393938393A3B3B3D41494B4A4A443E3E3C3A3A3C40403D393D3A383C47505251
4E4843423F3B383843433E383A434540454B4C4C453B3C3A463C393B3A3A3B363E3E3E3D
3C3B3A3944443F38353839383E383B37383D3B423B3C3E3B3E3841383C3E36363C38373D
3A3C3F3F3B38393A3C3B3A3C3F403F3D3F403F40413F3B393E41403B383A3B393F3F3E3C
3A3A3A3B403E3E40413E3B3A3C3F3A3C3C3C4444423F3F424644434543424B3F3E3A3E43
504852474A3C443C4145413E41424349473E3F423D3C3F3C433E3C3E403D3A3A3C3D3C3C
3E403F3B3E3B3E3F3C3D3F3C393C3D3B3D42434244413F40403F42474742413F3A3C3F3D
3F41413E3F413E383B3E3C413B3F3A3B3D393E424140424548424341423F473F45474950
555753514747483E40404849524D493E4341423B4144403C393A43444B3F3F3947414844
4D44493845444A48494844404044494E4E3D43374834403E3C4344494C515E60664E5E4F
7A68827D8B879B87A493A296989D95A99CAD9BA09A9A8AA383A6919A95A58D9E9299A39B
A494B190B88EA79AAA93B59CB095B298A8AA97A599977F6E56694953548985AC9EA69FA8
9CA69FA7B3A7BBAFC1B5C9BDC1BACBA7BF99B3A7B1A9B8AEAAB3B0B8A8CCAEC7B3CEA7C2
BAC6B2C6BDC1C4C2C9BDCBB5CCB4C4BFCBBAD1BAD2B9C6AABBB2BBAFABAC9390899B88AC
93BB9DA07D8194ACBAC0C1BCC4B7C1BEC9B4B5B5BCB4C0B2C8B1C8C4C4B8B0C0BBB7BABA
B7C1B2C4AABAA7AEB3C2C1C8BCCECDD1C8CED4CFD8D0D2D5D4D3D7D0D5D0D0C9CAC2C5C3
C5C9C4CACBD9D1DACDD9D5D0CFC3C7C7C5BFB6BDB8B2B0ADB6B7BCBDC4BAB5B5B2B2BAC4
BBB9B9BBBAB8BBC0C0C5BBC1B1BAB0B3BDBDC0C1BDBEBFBAB9C1BAC5B7BFB5BBABA6ACB7
BCB4C0BCC3C5C3BCB1AAAFBABBB7BBB6C1BEC2BBBFBDBCBCC1BCC7BCBAC2B3CCB5C4AFB6
B7B7B9BDB9B7BBC5CFC8C2C2C3C2C2C3C2AFBDA3C1B1CFC7D2C0BEB0B1B2B9BBBBCAC1D0
B5C9B7CCCBD7BCD8BEDAC8CBCDC5CACCD0D7D1CAD7D5DEC9DBCAD5D2D5CADDC5E3CCDFD3
D9D0D0CDCCCCC5C5C4D3BCD9BCD4C7D1D2D1C8CDC9D1D1D4D2D0D5CADDD2D7D5D9D4E2C7
E0C5DCCDD2D4D5D4D2D2D6D9CDDEC1E2C3E5D1D9
444444434242424443413F3E3F3F3F3E40413E4045413E45423B3F3F403C383C403F3C3B
3D3D3C3C3E3F3F3C3B3D3E3C3D3E403F3D3B393A3C3E41413F3D3C3C3D3E3B3E3E3D3F3C
3E3E3E373C3C413C3E4039363C3E3C3A403E3D3F3F3D3D3F3B3C3D3E3E3C3A393C3C3837
3A37363B3B38393B3C3A383742443F383838383C3D3D3C3C3B3B3B3B3938393B3F434648
3C39383B3D3B3A3B46413E3E4245454443504D4439353C38463B383C3D3E3F3B3B3C3D3E
3F3F40404848423A373B3E3C3C363C3C3B3B38413B3C403E403D473B3A3D393C403B393E
3B3B3A3A3D3F3E3D3C3E3E3D3B3A3C3E3D3D3E4040403E3B3E41413B383938353A3A3A39
393A3D40403E3F41423F3B38383D3B3F3F3D4342403D3E43444341413D3B453B3D3B4149
4A514749384843433B3F3E3E40404247443C3D413D3C3F3C3E3D3B3B3F43413B3B3E3E3D
3F413F3A403D3F403D3F413F4243423F3D3F3E3D413E3E3F403F4043413F41403A3B4141
3C41444140413F3B3A3D3A413D423D3E3D3C3D3E4141424C4B41483D403E41403D434D52
5352535251515143423F4747554C4C41463A41424047424141424B49535044524B54484B
4C4F3E53456957604D4945423F42494D49433D4844433B3E415964666A7586878B897091
819E8E9D98A089AF90B19BAAA1A9A3A5BA9CB69BA590A78AA28BA194A198A998A2A2A7A4
9DA99AB998AC98A694A891B298B599ACABA7ACA7B3A09F8FB787967C9993B29BAEADBBB3
BDB2BCB8BEC4B9CEBFD4C9CFB8C9B1D1AAC3B3C0B7BCB7C8C9C2C8B9C8BFD9B5D8B8D2BD
CBC3DAC6CCC5C2C5C7CEB5D9B5D1B8C8BFD6BACEBED2AFBDB6C6B3BFBEAEB9A2A8A1B39D
BDA9B39B757183A1B0B5BCC2C7C2B4C7BDC1BAC4C1C8B2CBB4C6BFCCC6BDB4C5BEB6AFAD
B7AFBDA5B7A0B0AAC5C9D2C2CEC8D1C9C9D6CCDCCCDACFDAD7D7DCD6DCD6D4CBC6BDC0C1
C5C7BEBFC9D1D9CFDCD0D7C8D0CCCFCBC1B6B0B8BCB2B0A8ADACB6B7BAB0B4BBB6B3BABF
B1B4B6B5B6BBBEBDBCC2B6B9AAB8B1B4BAB8BBBDBABEC2BFBFC0C8B9C0B9C1B7A9A5AFB9
BBB2BFC0BEBFC1BAA99FA9B9BDC8BAC1B2C9BDBABEC0C0BCC2C2CBBBC1B8BEB3BDABAEA6
B4AEC1B0C4AFC5C7C2BFC1C3C1BCBBBBB4B8A2BEA6CBC4D1CBBDBFB5BBC1C8C6C2C0CDBE
CABFC2C5D0C9D8BCD9BFD9CAD1C7CED2D2D3CFCEC6D9C6DFC8E6D1DECAD3CAD9C7D5C9D0
D9D0CFCDCFCFC9CCCFC7D5BDD8BED8CED6C8D3C7DBCAD5D3D2DECCDEC7DACAD7D1DED0E0
CFDDD6D9D4D6D7D6D4D4D7DBDBD5DEC8DFCADDCE
44444343424243434644413E3D3D3F4143423E3E403E3C3F423B3B393D3A3D403E3F3C3C
3E3D3A3A414142403C3D3D383B3A3F3C3A3A36383A3D4041403F3E3D3B3B393A3B3C3F3F
42464543423E433F4348403E4341403C3A393B3F403E3E403E3E3D3D3C3B3A3A3E3F3B39
3C3B3B403E3A3A3B3A3B3D3B3A3B38383C3B3A3F3F40403E3B3A3C3F35373B3E3D3B3C3F
403E3E40403C3A3A3B383A404443403F4C5649403E424E45483C3A3E3E3D3D3B3C3D3E3F
3F3F3F3F4A4A463F3C3D3D3A3D383B3C3A383C484441443F3F3C47383C3A3E3F3E3C3C40
434039394348433F3D40413E39373B3F3A393C40414344413E40413E3D3D3D3C4543403C
393B41463F40404142413E3A393E3D41413D4240433E4043413F3F3E413C453F45414042
454D584342394036393A3C3F403F4145453F3F41403F40403C3F3F3D4146453E3B3F413E
3E41403C423E40403E4044413F3F3F3E3F404141423F3F43454444443E3E42413A3A3E3E
393E41403D3D3E3E3A3D3A413E454142424540404240464D473E463B443F43403D424F4F
4C474C4C495552584B595559565F4B653F5042594F5B5A6165666E6673647F6383596C5E
786881658C7988787873706B6159575559524A4C48453E4045718C9394979C96A992AE85
AF83A499A295A999A98C9E9AA1A69FAC9FAF9D9F9AA589AD82A78EA09AA795AAA1A2AAA4
A99EBDA0BD98B2A5B29EC5AEBC9FC2ADBFC1B7BFB5BDBAC1ABC99AB388B996C6BCC3C4D1
C4CCC5C7CCBFD0B8D4BCCEC1C4BAD6BAD9B1CEBCC7B6BBBFBFCBBFC2B9D6B2C5BAD3B9CF
C7D5C8D3C0C1C6C3D0C4D2C3D1BAC6BDC7B9D3BCD2BCD2BDC0BCCBBDBAC2B0B2A8BEACC0
A8C5B3AF848193B0BBBABCC0C4B8C5BBD2B6C8C2CAC2CEBCD1B8CEC6CBBECABFCABAA1A7
B1BCACBFA3B5A5AEBDC7C0C8C4D1C8C9CFD2D8D4D8D2D6D8D4D4D8D2D9D5D7D0CBC5C7CB
CFCEC6C5C3D5D1DDD5D7C9C2CDCFD2CDC0B5B2B7B0B4ADB2A1B1B8C4B1ABB9C6BFB8B7B1
BDBFBBB5B6BFC5C5C0BEC3AAB3AEC0BDB9B4B8BDBBBBBCBBBAC7B4C6A9CABABCA9AAA8BF
B9C2BFC6C4C0C1BCAFAAB6C4C5C9D6B4C3BACFC3C5C5C7C2C8CAD1C2B9BDAEC5B1BFACB1
B1BEB8CAB5C7C1CEC1BCBCBEBBBABFC1C3B2C4ABC6B0C6B8CBC5CDC0BEBEBFBAC1CBC0D1
C0D3BCC8C6D6C2D9C0D7CDD5CDC4CDD3D2D0CED3D4D5DCC9DAD1D9D4D2CBE2C7DFC2D6CC
D8D2D3D2D4D0C8CECBD7BFDBC2DCD1DCD5CECED8D5D5CDD6D5D4DCD2D9D0D9DADEDAEBD0
E8CBE3D4D8DADBDAD9D9DBDED4E4CAE6CAE7D6DD
4645444444444444444443403D3E41454A46423E3C3E403D404147454A454A4A42454342
46433D3E414043413C3E3E38403E43403E403C3F3E3F414140404041403F3F3E3F414345
3C3F3D403E383F3F3C474240403C4142403E3E40403E3D404543403E3C3C3C3D3E413D3B
3E3E3C3F3D3B3C3B36393D3B3C3B393D423B35383D3D3E3D3C3B3D3E39383B3E3E3C3E42
3838393C3B38373A383A3B3C3F403D38454A3B3C424853474A3D3A3E3C3939383D3D3E3E
3D3C3B3B4947433E3B3C3C3C3F3C3B413E3A47575A5452494645514151454B443737363B
3E423F3D444846463F3F3F3C3A393C3F3C393D41414447433E3E3E3F3F3E3F424D4B4740
3B3A3E423F42423F3F43423E3E423F42403C3F3D3B373C4241424748453F4843473F3B3C
3A423D3F3B4844413A393B3F3F3E404345423F4042403F433F4042424242403E3C42433D
3B404240423E3F403D4045433F3F3F4041424444433E3D414543403F3F3E43454141403C
403F4042414041433F413E4643494445484C484943414B474A454544574D544654556160
5F5C6666656C7A6E787079717D6C84688B687F7474827F878C8D958A898B86988B8F8289
838D839D8AAC959E928E9192887E7974736B675D5B4F4A44487A9CAAACA8A59D9CA499A6
919F97A3989D9BAE99A19AA1A2A8A8A3AD9FAC9FA89DB092AD8DA5A1A5A1AAAAB6B1B4B9
B2B8B6C8BACAC2C2B6BEBBCDBAC4BCC6CDCAD1CACCC1C6C8CAB8C198A39CB6ADC2C1CDCA
CCC4CAC5C1C5B4D3B6D5C5C9C3C6C1D4C7CAC6C3C1C0B9CAC4C1C5C2CBC2D3B4D0B0CEC0
C6C0CDC0C0C3C8C9C3C9BED6BCCFC0C5C0CBBFC7C2CBBABDBAC8C2C3BFB8BEB2BABBCBB0
C9B1C6B2A6A3ACB9BEBFC3C4C1CAB0CDB0C6BCCAC5CEC4CCC2C7C5C5CAC7BEC0B1B991A0
B8B6BDB2B6AAAFACC8CBD0CAD5CDCDCCD0D8D3DFD1D9D0D5CECFD5CFD6D2D3CDC7C7C7CB
CAC4C4C4BFC9D0D1DBCDCBC3CCCFCCC4B9B4B3B3B3B0B7AAADAFC0BEBBB2BFCBC2BFC0B5
C1BDB6B2B3BBC4C9BAC2B2B2A3BAB7BBBEB5B8C2C1BCBCBCBDB7C2B7C1BAC2B5B0AAB5B5
CBC2C9C8C9C6C9C8BDBAC3CBC6D7CCD0B8CFC8CDCAC3CDCDD4D0CEC5C9C3C4C0C3B9B6B2
ADB5CABCC9BECCC7CAC0BEC0BFC1C6C6B9B8B2C3BBC9C0BDC0BDC8BEC1C5C6BEBEC1CBC6
CEC9C4C7CECED7C9D8C7D6CBD3C9D2D8D7D8D5D8D2E0CFDACAE0D1D7D6D8D6D7D3D3CFD0
D6D3D5D3D4CFC8D3D6D3D5CDD8CBD8D1D7CDDCD2DED2D3D3D0D7CEDED0E1D9E1D7DFDBDD
D9DBE0DFDADBDBDBDBDCDDDEDDDDE1D6DFD4E0D8
47464545454545453F4142413F40454A4C46433E3B444B45505964605C4A47403E434141
45403A3A3F3D41403C3F413B3D3B413D3B3F3A3F3F40403E3D3D3F404442413D3B3A3839
3C3E3A42423E484B4E5C554C413942473B3B3F4445423F404A47433F3E3E3F403C3F3D3B
3D3B37393D3D413E37393C373F3831363D3A38403939393A3B3C3B3A413C38393A3B3E44
3D3D3E403E3B3C3F4447443D3D43423B3F453B454E4E554A4439373D3B393B3C38383A3B
3C3D3D3D433F3A38383C42473A3E414E4C42505D7068645A575968595F4D564A383C3E44
3E4B4D443E3A3A41413E3C3B3B3D3E3E403C3F43414345403F3C3B3E3D3B3E434243423E
3936383B4044433C3D444642424541413F3A3D3B3E3A3E43404148493F3D4943433A3A40
3C424643433E3E3C3D3A3A3E3E3D3F4243433D3C423F3C423C3B3E43423D3C3F3E44443C
393F4444413D3E3F3D40454445444444434343444943404346433E3C3D3B41494B4D4A43
4A454347494747494547444B484D47474C504E514441504041434151736B7C66837E8580
7F7C868386929698939C9B9A8B958E9E909F9297939F969B9D9EA79BA4929B8DA48E9992
9F9CA797A09BA09EA09DA5ABA49D9B97869085947A7D5F5A6389A1A9A8A2A3A1A8A0AD95
A793A39BB0ABB9B2BAB0B9AEB8BCBFBDB8C0BABCB9C5B2C2ACB7ACBFB0B5AFC0C6C1C5CD
C7C0CBC2CFC8CEBDC8B8C9C6CABECABDC9C9CACBC3BFBAC0B6BEA2A790ACA1C0BEC0C6CC
C5C9CCCBC6B4C4BFC3BECDBCCEC1CBC1D0BACBBDC2C0C5CFC2C4C4D0BED6BCD9B8C9B7C7
BBBFC3CAC7CED1CACECCD1D0C9C7C8C2CFC5CABECBC5CCBEC0C3C8BCB7BDBABCBCBFB6C3
C2C1C1BEB5B6BCC0C0C4C5BFC2C2BFBBBEB4C3C2C5C7CABEC6BDC9C1C2C0B6B9BBBBBEBE
BABEB5BBABB2AAAEC3CBCCD0D2D0CCD2D3D7D8DDD6D5D0CFCED1DAD5DAD3D1C9CACFCDD0
C9BFC6C7C6CFCACFCEC5BFBFCACBC1B6B0B1B4B1A6B4B6B7A3B4BCC4C1B2B7BDB4BAC4BC
B7B3B3B9BFC2C9D0C7C2C3B0C1C1C9B9C0B4B7C5C7C3C5C9BBB6ACBBB3C8C8CDB3B8B7C0
C6CCC5CDC5C6CFD0C4BEC3C7CDCFD4C8CBC4C6BED4C0C7C6CDC9C9CCCFCCC0C7BBBEB4B7
A6BDC3CFC1D0CACCCDC4C4CAC9C6C0B6C0B5BEB9C9C2C7B9CFC6CABDC4CAC8BBB5C1C4CC
C4CBBEC9C0CBC8D4D3DAD8D4D4CBD1D4D5D9D4D1CDD9DBD9DBDCD3CDD8CFD6C7D8C9D1C9
D9D6D6D3D4D0CEDECAD2C8D7CED8D5D6D7D4DDD6D9D9D3D2D5D3D1D5D7DCDBD9D8D8E0D0
DED0E3DCD9D9D9D9DADBDBDBD6E1D6E1D4DEDBDC
48474442414141423C3D3E4147515E676C716F5D50605C6F709389A586997374514A4F58
524846464145423F42403D413E3F4148433D433F4A554E50484C3B484C5050544B434247
3C444A424D455C5B5F68665A4F464940433E4243463C3C3D485B443E3F40443F3F3F4137
3F393A3F433F4E3F393F3B383D373B3C3B39353B3D413A40384239383940483F3D3F3D48
3B3840404841423F3F4242413B453D3F3B4A4C5B5F55523F474143413F3D3840444F4746
49484E4E4142403F42384545434A4E5B575E626D7A777F6C6C73746B5E554A433F3E4248
3C3A413D3B3E3A403D3F363C3C3F394144404C53453E413C3C403D3B403E3B41413F3C45
463E3A44453F3E3F3D4248464045413D433F3F4142423C4049424547423C47464C484144
4541524C424044423D3C403B383C3F48464947404649463D3C3C3B3D3D413F3F3E414A42
4041453F3F4343384341444544453E393F434344484B444B474C403F45433C574955484C
494D49475C4C51505554605D775F5E5F6062575153505447483D4A6E7D8F919F8D9A8EA0
96A698A39BA19FA0A4A1A79EA59DA293A899ADA4B09C91939A94949791969292999E8C96
8590829388998C9899A5A9B3B4AEAFA8AD9FB4A5AE8F8C8DA0A4B4BDBAB6B7BDADC0B9BC
AFC0B1C9B7C7C8C7C0C3C2CCCEC9D1D1CBCAC4C1C6C3CEB8C5B3CBBDCEBFC3BDCAC6C4C2
C0C7C0CABECBC3C5B7C7C8C4C1C7C7CEC7C4C9C8BBB5B6B3BBB3A9A0A8A6B8B8D0C8CDCD
C8CAC9CDC3C8BEC7BFC5C0D2C7C7C4CCCDD3CDCBC0C7CDCDC9C7CACFCECACFCCC9C9D3BF
C2C6CFC8CBD5CEC8CBD0CED2C9CCCACFCFD1D6CFD3CDCEC9CDC9BFC2BFB6BEC3B9BCBDB7
C0BDC6BEBEBAC5C1C9C6C3C0C2CAC6C2B8B9BEB7B5B5B0C1BABEC2C4B9BEBEBFB9BFC4CB
BDBFB5B7ADADA6AEC3D1CDCDCECBD4D6D3D8D5D9D5D1D2CFD5D5DCD1D8CFD2C9C8D1CED0
C0C4C5CFC7D1C6C8BCC6B9C0CBCCCBBFB3A599A3ABB0C0ACB4B4C8C0CCB6B5ACB6B7C6BB
B6B7B4C2C0CCCDD6C9CDB8CAB8D0CAC9BEB0BBC7C4C9CABEB3A5AAB2C2C5CBC3C0B4BCC1
C9C6D1D3D0C7C7CDC5D0C5D4C8D2C7CCBECAC0C5BFC4BFCBC3C1CCCAC9C5C4C0C0BABDAC
B8B2C8BDD4BDD3C1C6C3C3C8CDC7C0C7B2C5B6CBB9D2C0CAC6C5BDC1C7C0C0B5B8BCC4C8
CCC0A1B6D3D2DBD0E1D0DACBD0CAD7DDD8D6D4D7D3DED9DBCFDBD6D7CDD4D2D1D6D0D4D5
D2D9D5D2D5D6D7D6D4D2D1D2D4D5DDD1DBD6D9D5DAD3D7D7D1DADADAD0D9DCE2D9DDD8D8
DADCE4E1D9D8E1E1DEDCD9E0D8DEDBD9E1D4D6D7
47464443414141413F3E3E3E424850556C6872566160606376849E99A99694856C61687B
79634E434548454245423F423C404D656D69685E877B855B6C585E677E7A8678766A5F5B
606C616B5F696A6E5B796F8359685C665F5254474F3E4748515E503A433746413F3E3D35
3F3A3B3D393E3C453D483B40453E403F4248484F4B45463E4B494C443D413D3748534746
414749404B45423C43423F3E3A4742465A60534E463E47414E50554C4345485258645B5A
61584D4654504C4C55505F5F5B59545D5D69707B7E777A7073727165584F45403E3E4348
3D393D393A3E3C403A3C34383638333C37353C3F393A41413A3F4140403D3B3C393B3D3C
443F3D3E423F42433F3F403C373C3E46434542413D443E4747464345403F5343483A4349
4840534A4640474339414145423D444453443C423E43433E3B3D403E4142413D3E493C44
444E44473B434A484944424242484643464847494B3E5246574553444D40495254566160
64726D7A7D776F746C856F96829770857C7F6D6D65665846433A616D9793A3A0A6A2A59E
A39EA5A39BA39BA3A0A9ABAAA5B3A3C0AEC2B6BCB5AFAAB7B3B2ABB2B5ADBAACBCB0AEA8
AEA9B7A0B79AA2989AA3A5AEB1B0B8B6AAB2ACC7A6B39AB0AAB5B6C3C9C2C3C0C5C6C8BF
C9CCC7CCCED1D8C5D1C3CBC9CFCAD1CEC9CCC9C6B6C9C3CEB2C5C6C4C4BEBFBFC0C3C1C7
C2C0C9BDC9C0C7C0C1C0C8BCC7C3C8BCCCCBCFCDC1B6B5B7B7BDA9BBAEC3C4CECBC4CCCD
CAC9C5C5CDC9C8C0C5C0C9CFD0CAD1C8D4CACFC8CDCECFCFCECCCCCCC4CCC5CEBDCDD2CF
BFBFC9CBD0D6D0D1CFD2CED3CCD2D0D5D1CFD1C9CFCED3D0D5D1C8CBC6BCC1C4BCC1C0C1
C3C2C8C4BEBCC9C5CCC8C5C2BFCFBAC3B8C2B0AEADAAA9B8BFC2C5BCC2BEC4B7BBB1BCBE
C3C3BCB6B5ADA9B0BECDCCCDCFCDD4D7D1DBCEDFCED8CFD1CCD4D6DAD5D7CFCBCFD0CEC8
C3C3CBD1CCCACCBBC9BEC1BCCCCBCDC3B6A7999E9CAAAAB9ACC8C8CABAB1ADBBB6C5C2BB
AEB1BBC5CCCED4D8D1C3CEB6CFBAD3BFC6B4C6C8C1CAC5C3B2AEA4C0BAD4CCCFBFBDB5CE
C0D2CDD7CEC9C8CCCDC8CCD0CCC4D4C6CBBAC3B4B9B3C3C0C7BEC8C8C4CABCCAB8C1BAB8
ADBAB6D2C0CFCACCC8CAC1C8CABEBFC1C6C4CEBACDBCC6C2C8C2C5BBCEBDC8BABEBEBDC9
C5D1C1DAD3D9D3D6D4D6D8D4D5CED9DFDBD8D5DAD5D9DED5D7D7DBD6D5D5D9CCDDCAD7D1
D1D5D2D0D4D4D3D4D5D7D0DAD4DDDDD5DCD7DAD6DCD4D6D6D7DDD9DBD5DDDBDCDCE0DBDB
DBDBE0DCDDDADFDEDBDBD8DFDAE1CDCDB6B2A9AE
4645444342414140403E3C3C3E4143444D4B4C464C594F515168618F6F8F747D6C5F6980
80674F424647444244413F4043424E6C7C7C7B718280746D5B77698B8C998C9C91918D86
9D929F7B8E68776062708C8292778A84857D73767072737D768B70705A5F595D57524C43
4A413E394751625B7468747165626562656D6A6A7371616C6877655E6A6C5945535E5559
5564655664635E554C47414140515057636556514C495551565C625349546373717B6F70
7F7A6D6A7C7572737F7B86858779635F5A646871776D6C6A6F6765545850474342424549
423D3C383B413F403C3E393B383938413F40403D3C40464744474A453F3F3E393A433D3B
3D46403D434243413C3C4041453C464F57544B393D4848494B4648484A4856494F474A46
4A43524C4944474347434B423F47444E4C4F46444944414F464547404340413B4A48554B
4D3C53434643564A55455755575D5B56575A5D625D705978657A5D715C6C55726B857491
8A8F9C90A18185809C8AAE90A880977D888784747B6D674D445052857CACA0B09EA693B2
8FAE9BA2A5A7AEAABAB8C9C6C5C0D6C0DDBBD0BFCCC6CEC9D0C3CFD5C0C0BED6C0D7C7C7
C6D4BEDBBED4B6BEC2C6C3C3BEB9BDBDBBA1BE90B283A09BB3A3B8BCBACBC6BBC3CCBCD8
C2E3C6CCC9D2C0CFBFD3C4CBC7C7D0CDCBCEC8C3C1C1DCB5C4ACCEB4C4BCCAB6C0B3BFC3
C1CEBCD2B7D1BDC5C6C5B9C4B6CDC7C3C5C8CDD2CEC2C1CBCCC5CEBCD0BDD2CAD6CACCCC
CACDCCCDC6CDC4D2C0D3CACDC9CDC7D2C8D3CCD0D5D0CCCDD1D2CECACCCED2C6CFC8D8D0
C8C2C8D0D3D0CCD1D5D4CDD0CBD0CCCED6D2D1C7CECDD2CDD3D1CDD0CDC5C9CBCBCABDC5
BFC1C1C1C0BEC8C2C7C2C0BFC4BBC0B9BBB4BCA4AEAFA7B6B6C2C0B6BCBEB3C1AFBAB5C3
C0C9B3BCADB3A1B0BECDCFD0D2D0D4D6D4D3D6D1DBCFD8D0D8D4E2CBDAC5D1C6D3D5C5CD
BCCECBD6CBD2B3C9B5D3BFC7C8C4CAC4B6AA9B98A69BB89EC1ADCDBFC6B4C8B5CCB4C1A9
AFBDBFD8CAD4C9D1CAD5B6D8B5D8C5C8C3BDBFC9C1C0CDC5C7B7C5B5D0BFD0C4CCBCCDBB
D5C0D6CFD4CCCDD5C5D6BED1C2D5B7D3BAD1B1C4B5BEAECDBCBEC6C7C9C8D1C2CFB4BDB4
BDB7D6BCDAB4D1BFCEC5CBC4C4C3B7C5C0CFB4D4B3D2BACEC7C9BDC7C1C9C5C5C9C0CAC3
C9CACAD3D4D0E1C7E3C9E3D5D9CFD7DEDBD6D3DBD2DED2E1CDE3D5D9D6DECFD8D1D6D1D4
D8D7D4D4D9D9D5D9D6D4D9D4DFD8E2D6DCD6D9D7DED7D9D8DBDDD8DDDBE2DCD9DCE1DDDD
DCDCDFDAE1DADCDAD9DAD7DDDAD7D1AE977B8986
45454544434241403E3C3B3D4042413E40413B3D384A40464C494F5752525656534B5360
5B4D444142413F3F3F3E3C3C413A3C525D5C5D556F64684C525A667F94889C8A9695979E
A4AB97A5828C6E6756736D9682978794998D968797828F8E969FA997A78E998D8B81766A
6C5B54465D7D818D7D948B938B90989392907E717F6A6E5B827C8D7D777C70616365646C
6471776C7777736759534C4D4F62636B6D6B6063696A685B5855574D4A5E7689888E8888
92908A8D8B878C919D979D9E8F7D60564C53575F6F6A66646860614D4B443F3F3F3F4043
403B38353A3F3D393F3E3D3D3B3A3D443D413F3A3B3E3E3C3E3C3F3E3D454A43474F4042
3B4C41424242413D393C43494C41504A584E5148414C4F485049545359555C5A63615A49
4A4B4A59424D3C403E4C404A4B485E58655969494B4363574F4C454A4346434944695567
646F656D5D6357785D7D798B7E8688878A898585977FA0879D7995818E7D8F84998A9E94
9AA79CAE9EA3919A99AF95A8889E808E8A968D91828D7F787E698C75A08FB0AAB4A5B69E
B9A6BFB5BEC5BECBC2D0CED3CFDBCCDFCBD6CCD1CBD0CAD6C6CBC6D2CCBDD6C7DAC7D8C6
D6CDD7C6D9C8D0C6CFD1D1D1CBC4C4C5ACAF8DAF8CB39BAF9EA88A8EADB8C3C2B7B5CEC6
D6C9D2C3D1C5CFB6CEB9C7BDC7C6CAC3C2CAC8C7C0CDB7CFA4C9C0BDBCBFC2C2B7BEBCC9
C4C2CABEC8C0C6BFC8C1CDB9C7BDD1CACCCCCED5D8CBC5D0C6D0C3D6C7D5D1D6CFC5C9CC
CCCFCAC8C2C4CACCCBD5D8CECECFD4D0D2CCCFCED2CCC8CACFD2D0CDCED7CDD1D3D5CEC9
D2CACBD0D1CCCACFD5D3CBD0CCD1CBCACECCCDC8D2D2D4CDCFCDCCCFCECACDD1CDC0B6B2
BFBAC7C5D0CBD3C8CAC5C5C6B8CCACBAACBEABB7ACB3A7B4ABC1C4C1C4B7C0B2BFAAB9BB
C5BFC4A7C1A1A8A8C1CED4D3D4D2D1D4D1DBC7E0CBDED1D6D3DBD2D8C7D2CBD0D4D0D0C6
CAC8D3D6D7C2C4AAD0BED6C7CAC5CFCDC2BCB0A8A6B09DBF9EC6BCCEC3C4B9CDBBCCBDBA
B1B8CBD1D7CDD0D0D8CDD7C1D6C1D4BFBFABC0BEBDCDC6CCC6CFB7D8B9D9C1CCC6CDB8D5
BCDBCBD8D7D6CED2D5C2CEC8D5B9D5BCD4B4CEB8C7B1C9B9C7BCC5CCC2D5BEDAC1CFB9C5
B8C4BFD3C8D0CBCBC6CFC1C9C9BCC6C5C7C2C8BCCABAC2C5CCC1CDB7CFBBCFC6C8CEC8D5
C6DAC7D2CEDACCDFD1E0D7D7D8CDD3D9D8D1CDD7D3D2DDD1DED6DDD5D9D3DAC6E2CADCD3
D6D1CFD0D7D6CFD6D1DACFDED4E0DAD7DBD5D7D6DED9DDDCD9DBD7DFDEE5DEDCD9DEDBDC
DDDDE2DDE0D9DAD8D8DAD6DBD3D9CAAA73657276
45454544444342413F3E3E41454644413E3D4A3C44414D4F4C43444944454C4F45444746
3E3B3E3F3E3C3C3C3D3E3D3B3F3A3A484941423B4C4C4746445B647D889A858C7B869293
A592A87E9269755A4E5E6D74857C878A91908D978F8D858A82958FA79BA592918B857D7B
81757464676F947D8884918B959DA9A39C91745F5B56465760807C7C746F6B6E6F6F757A
75768280837E7E706C6661646474737B77706568737873656B5B5A5B6074869489919C9F
999390928E8A93959B9195998A7B6156484C4E575E61605758555C483E3A3A3D3F3F4042
3E3E3B3C4247463F4A454543413D4043393E3D3A3D41403E433D3E40434C4F454F4C4D41
4F464743474948454345494F4E50515A53584852475D52635768656D77718A768E76866E
7F6E8A6F84626D60635F5F53525F636C6B8A7478657C61674E4B465549453E496C7D9285
8B7B957B9881A182A985A797A2A49E9CA2A5A2A092A78AAA91AC8FAA94A4899DA0B197AA
B2ABB7AABDAAAEA9B9A5C4A5AD94B397AAADB9ABB6ADB1A7A1A393BC9DC2AEC5C3CFBCD5
BFD7BFCACFC8CFC3D0C8D3D3D9D5DDCCDAC6D7CFD5CCCFBFC7BDCBCDC8D1C4DEC8DECED3
CFD2C3D4C5D8CBD0C9C9CED1D0CDCCD1D1BFCBAFCCACBBAABE9C8A7A8FB9BCBBB3C4BEDD
BBD5C5C8C6CBB8CBB2C7B7C0BFC2C9C7C8CBC4C2CCC3C9BDBFB6CABDC9C2D2BBC7B7C0BD
BDC5BCC6B9C7BDBFBDCFC7D3BFCBBEC8CECBCAD5DDD3CBD3D1D0D0CBD2C8D1CCCEC3C8CC
CED1CCCACAC9C9C6C5D3D9D0CED1D8D4D5CFD2D3CDCBCACACDCFD1D1C6D0C7CFD4D5CCC8
CFCDCACBCECFD2D3CFD0CBD3D2D9D3D2D4D0D0C9D1CDCCC3D1CECFCECCCBCCD0C7CAA9C3
A9C2BAC8CBC8D0C7C9C3C2C2C6B7BCB3B5AEC3B1B7B4B4A7B1B2C6BABBBBADC1AFBBB1BF
BFCEAFC8ABC0A1B4BFCCD3D2D2D1CED2D5D2D5CEDDD1DDD5D3D0E3CBDDC6D4C9CCD6CCD9
C4D3CCD8CFD0ADCCBBD9CACCBDB9C5C6C2C3BBB4B8ABC7A8C3A9CFCCD2C1D3B8D2B6C7B6
B3C1C1DAC9D6CBD5CCD4BFD8C1D9CCC9B7B2AFC0C6C9D4C9CDC5D4C0D8C4D1C7D4C8D7B9
D8C0D5CBD2CCC9D5C4D6C1D4BDD0B4D7C3D9B4C7C4CAB6D2BEC5C8CCCBCCD1C4D8C4CFCB
D1C9D4C2DABCC7B5C7C2CCC4C6C9BDCABFCAB9D2BED0BECFCCCDC2CABECBC4CBCACDD1C7
D5D4D3D7D4CCDBC7E8D0E4D0D6CED3D6D5CFCAD5CEDACCE1CCE3D2D8D5DDCCD8D0D9D2D6
D6CFD0CFD5D6CDD5D3D5DAD2E1D6E0D6DED7D9D5DCD7DDDDD8DBD9E1DDE1DCDDD9DEDADB
DCDDE3DFDDD6D8D8DADBD6D9D2D7C7A56E667371
46464545444443434342414447484642484B5550484347474A434443423D3F4040404340
3C3F433E3F3B3C3E3E40403C403F3F46433E433F4140564D67606F70777D8D6A6B727777
78796F78586A5A5B53635D6E727B767B786F7C74826D74717F7E8E899D8B8D817C766F6E
726569585E5E6979687E707A7E85908A82775D4B483F4B42605B65576B62626E6D6B767B
7D76858A8B85897D7B75727775807B837E7B76767B807E787D696B7177838A8D878B9E9F
918882828178807D80787E89837863594847454C4E53554747485142403E3E40403F4042
3E4444484E52554C564D4C484740413E3F3E3F3E3F434745403E434C545958534C594463
4A5E404C4B4A444044484E565A4C664B71566061697082779380938C949C97AB95A39D9A
87907CA47C9F80958898868A847683737B6E9B7396719578856F7B5D6C42585A679A939C
96A199A6A1AE8BBC8CBB98A8A4A7A5A6AFAFA6A0B09CB499AD98B9AABCA5B6A3BEADC3B0
BEC1B9CEC2D3BEC6BCD5BCDAB7D8BBCBCACBC8D1C7CEBCBBB69FBCACCDB5CDCBD3C8D7B7
DDC1D4CCCFCBC2C9C3D3CFDACADAC2E2C5DFCFD9D0D4CCD4CAD3C9CAD2D0DACAE0CAD7CE
D9CADFC3DFC2D6C5D5CFD1D1D0CECDD4CDD8C6DAC2D1C1C4BDBA8C89B3C4C8C5C7C2D0C1
CDBED0C2C9BDCBB8C7B1C0B7C1C1C4C2C6C9C5CBC3CBC1D1BBC4C4CAC5C6C8C7C2C9C1C4
C0C5C2C6C1C9C4C5BFC3CDBFD1C1C8C7D4CDCCD4D9D2CACBCDCDC8CACECDD3D0D4C8CACB
CDD3D1D2CED4C6CFBDD4CBCAC4CDCBD6C9D2CDD4CFD0D0CECDCED1D3CACED1C9D8CAD2CE
CED0CAC9CBD0D6D3CACDCBD3D0D6D0D0D1CCCBC4CDCDD0C9CFCDD0CDCDCFCED3CEC5CEB5
C5AAC4BFC8C7D4D0D5CFCBC9C3CFB0C1B9C7B1B7ABB59EB9A4C8BFBEBBB1BAAFBFAEB9B7
C9B9D0ABD0A3B6A9BCC7D1CFD0D2CFD5D3DCC9DFCDDED5DBD7DED8DBCDD3CACBCBD0D9D4
D3CCD1D3D8C8D1C0DEBED0B7BCBBC5C8CACFCAC6ADBEB0CFA6C6BDD2C6C9BFCDBFCBBFC1
BFC0C9CCD2CDD1D3D3C4D8BADBBBD6BCC1ADBCBFC8D8CBCEC0D1BADBC0E2CAD7CCD8C1D3
BFDBCBD5D4D5C8CECFBCCAC4D3BCD7BED7B7CEB6C7B6D3C3D0C9C8C9C6DBC6E1C4D9C4CA
C7D1B8D5C5D8C3C4C5CFC4CACBC2C8C5CBC6D8C3DEC4D2CDD5C8D6BED2C3CFCACBD6C9D6
CFDECED9D3DAC6D9CEE0D6D4D5D3D7D7D5D1CCD7D2D1D9D1DBD3DAD6DAD6DCCAE1CADAD2
D8D3D6D1D7DAD1D9D4DFD4DED8E0DADBE1DBDDD7DBD4D9DBD9DCD9E0D8DBD7DBDCE0DBDB
DADADFDBDBD5D9D9DADBD5D8D6D3CB9C81718371
48474645444445454342424346474543464B4A59495149484043404443433E403C3A3D3E
3D414441413C3D3F3E40413B3C3D3A3C393B4440444F5470627A5D635A6B615F4F535651
544A664B5241534955645961686E6665666568706F6965676C707080797F747767625B5B
5E545F505649574F584D4F52585C65615D5A4B423F443A453D4E4749454A516060575D5F
645D696D736E736C6A67676E6B746E777C7F807B77757270685B6164656F726F7E7C8584
7A70636267585E5B64626A78675F4F4C414340454D4A504243454A423F3D3D3E3D3C3F45
444F4F53575B605963555451534C4B414B44484B47494F4D56575B61635C585C5E5E6562
6C5D585647443C3D4B57616B6E696D716D7D7D9691A094ADA2ADA1A8A59BA9A5B1A0B1A0
9583937A917B8F9298A1A3A2A3A7AAA4939C848A7688859F889884A16E7B5C6D9BA1AAA1
ADA5ACA4B1A5B593B399B0A6B3B6B2B1B9BDB9B7B6C2AAB2A6C1BACAC9CAC3C5CAD0CDD2
D6CFD9D4D9D3CFD0D8C8E7C9E1C2DECAD5C9D0C9CDC1BAB9AAA9A4BFB3D0C8D6CCCDC5CC
C9D1CACBD7C9CDC6D0CFD0D3D2CCD8C7DEC5D7CAD0CED1C7CECACFCAC6D3C7D9D0D8D0D3
C8CFC2DBC2D8C9CDD5CBCDCECFD0CED7D4D8D6D2D3CCD0C8D0BDBAB3B6C9CCC6CBD2C2CD
BCC7C3C2BFBFB9CCBECAC2C4B6B6BEC4CAC8C1C9C6CFC9C6C0BBC0C2CAC5D1BFC9C1C5C1
C1C4C5C6C7CBCBCAC2C6BDC7C2CFCBD2CBC7CAD1D2D0CECDC8C9BFC8C9CFD2D0CDC4CACE
CED0CAC8CCCFD1C8CECBCBC6CBC9D2C5CCC0C9C8D1D2D2D0CECED0D3D2DACCD7CDD3CED0
CFD2CBCBCDCED4CFC8CCCAD0CACECACDD3CECCC2CAC9CDC7CBC9D0CDCCD0CCD1C8D2BFCE
B8C9C3C9C0BFCCCAD2CECBC8CCC4C3C6C8C2C5B5B4B0B5ADBAB5C5B7B0B3AEBCB8C4BEC2
B7BDB1CCB5C7B5BAC1CAD4D0D2D5D2DAD6D7D6D4D9D4DDDBD8D4DDCCDACED9D2CCD5D1DD
CED6CDD2C6CCC1DCD2D3CDC3B7BCC3C4CAD0C9C9BFBDCCB9BDB0C3C0C6BFCDBED2C1CCC4
C1C5BFD2CCD8D0D7CAD3BCD8BDD7C8C7C3BCBBC6CDD0D3CDCBCDCEC7D3D1D3D1D7D5D9C0
D4CAD5CECACAC4D4CAD3CAD5CCD5C4CEC6D3C4CCC4CAC9D7CBD3CBC6BFCFD7D3CFCCD4CC
D6CDD8C0E2C3D3C2D1CFD1CBCED1C8CFC5D8C6E2CAE5D0DDD8D4D2D2CED6CDD1D2D3D7DD
E2E0DEDDD3D2D7CBDACEDBCFD2D6DBD7D5D3CED7D1D9D0DFCFDCD3DBD7DFD5DAD7D7D5D8
D4D2D7CFD3DACFD7D6DCDBD4DED7DDD9DEDADFDADCD3D8DADAD9D4DBD5D8D5D9DDE2DDDC
DAD9DBD6DCD7DADAD9D9D3D7D4DDC3A575777263
49474644444546474040404144454545443B41444C474A3C47484B3E4C3E3F3C3F393A3C
37394044423B3C3E3C3E3F383E413E3E3B3E453C4D41594E5C594B4747424848473F4047
4244585340403F3E465C5656555550524442525A685E636368656E6E6E6463645450494B
4E47594D424842423F3D3A433B3D464444463F3E414544423C3E3C3B3C45424A4C434343
474449474F4A4D4A48474B54535C57605B5E615B55534F4E4B454F4D49575E5B5B585F63
6A634E4D6D595A545B5759635E56474943484447493E463B3E3F403D3C3C3E4042454E57
5A6767696A6C736C7A6A6A696E68665A68606A726C6C7370767A7B7D7B6F6D7B6F7B6D7C
6A7561684C4E4D586F808890A58EA798A99EA3A3B0AFACACB7A8ACA9A9ABA7C1AEB3B0A9
8681717D6E85839D889C9CAAB3B7C6BBC5B7C3A7B08C907F939AAF9FA796A5A4B7BEB7B9
C0C0B9C8B1C0ADB8A7BCB0BCBAC1C1C1C7C9C7C7C2BDBBAAB2BDD0CFD9CEDECFD5C8DACF
CCCBCCD3C8D3CBD7CCD5C9D6C9D6CCD7D1C8C9C8BEBAB4C2B9B2BEB9C2C5C9C3D5C5CEBE
CDC1D1C6CEC6CAD0D4D9CFD2C8D1C1D7C8D8CFD2CFD3D1CECACFCECCCCD2D2D3D6CACFC7
D2C7D7C7D5C6D6CCD1C7CDD1D6D8D4DCCED8CFDBD6DBD2C7D6D2CDC1AEB3CAD0CAD0CEC9
C9BFC8C1C0B5BBBEC3BDBDB4B0AEB5BDC6C3BDCABFC9BDB6BCC0C3C3C4C4CBC1C2C5C6C7
B9C0BDC4BFCAC6C7C8C3CAC9C9C9D2D0CFCCD1D2CAC6C8C5C9C6BFC1C9C9CFC9D5CACDCE
CDCFCDCDC8D1C5CBC7D2CAD2CED0CDCEC6CBCCD2CFCFCFCFCECFD0D1D5D1CDCED6CFD2C7
CED0C9CED0CED4D0C7CCCCD1CAD0CFD5CDC9CAC3CBCACEC9CCCBD2CCCACBC3C6D6CEC9BB
CDC5D1C3C6C1CBC6CFCECDCCC6CEC3CEC6C9C3C4B4BCB3C0AFBCBFC1BABABDBCC3C2C3BF
CEC0CFC4CCB6BDAECBD2DBD5D5D9D5DED6DCD2DCD2D9DADED7D9DCD8D8D5D2CCD1D3D2D6
D3D5D0CFD5D2D4D5DAC0CBB8BDC5CBC9D1D6CDCFC7CCC4C9B5C5C5CACBCBCAC8CAC9C8C8
CECBC8D1D1D3CCCCD5CCD4C4D6C5D5C2C4BAC2C5C9D1CED1C8D3C2D0C8DED2DBD5DCD1CC
CBD7D3D4D0D3CBD9D5CED2D1D1CED9CCD8CFD6CACFCBDAD0D0D4CDC7C8DCD3D5B4C8D0D4
CFD9CAD9D4DDD5D9D7D9D2D1D6D6D7D8D4D7E0D0DED3D8D3DED4DDD1DBD7D6D4D9D6D3E2
D7DCDAD7CAD6D4DAD2D2D1CECED6DCD5D3D2CDD6D5D8D8DAD6D7D8DCD5DADCD5E1D4DEDC
D7D7DED3D6DFD4DBD4DDD5D5D7D7D7D7D7D7DEDBDED5DADCD9D5CED6D4D9D6DADBE0DDDD
DCD9DAD4DED9DBDAD8D7D2D7D3DDCC986D575643
48494845474B4B463B3C3B3D413F3E463D404344434140403F46443F41403E403D3C3C3C
3D3F4143443D3B40423E3D413F3F4041434445464143403F45433D3F44423F3E3F3F3F3E
405F959C53363E42494E4F4A4442403F403E49535E565E645C5F636B555A5B5B4A49423E
49495248404140423E3A3E433B3B3A393A3C3E403F41423E373D393D3E3E384443434343
393C4042443E46474044434543545245454445474D46454A404045494E46474E4647545F
66646055605D596D616C555E4A524A4F47423C4247464944403F44403D42453F465C7277
7C878D8D8F95948D88917D927C9D849A899F869D879F949D9EA9A49DA292A392A996AD85
A57983635F4C557899AAB1C1B1CCB1C1B0B6A3BDA8B0ABB5ADBAB3B3B4B7B2B4B9B1B3AB
AF98A687B099B4A8AFA7B8BCC6CAD2D4CBD0CAD4C4C2B3B6A3AEA9AEA0A3A2B6C0C0CCCD
CCD0CDCCCBC4C2B6C1B3B2AEB9B2B8BEBEC5BDA2ACC6BEC7CBCDC9DAC7C7CAD3CDCFCECD
C6CACCCACACCCAC6C9CDD2CAD1C8C8C7CBC0C2BDB3B2B2B9C1C5C1CFC5CDC9D3C5C8C8C6
C8CDCFCEC5C7CECACACEC8C6CDCDCECFD7CFD6D1CEC8D1C6C9CFD0C3ACC6C3CDCFDED0D6
CCC8CECEC7CFD9D3D5D7D3CDD2DCDBD3CDD8D9D4DBD3CED3DAD2D8D3CEC2C6C5C7C8C8C0
BEB3B8C2B6BABCBFBCBBB7B7AEB6B8BFC3C5C3CBC1C7C7C9CDC9CCC6C5C4C6C8C6C1C3C8
C2C4CAC4CBC8CCC7CDC6CBC4D1C8D1CECDD0D1D2C9C4C3C9C6C8BDCAC3D4CDD2CBC8CFD1
CAC8CACEC9C6CDC9CAC8D1CED3C9D3C9CEC5D0C8C8D0D7CECCCECBD4BED1C8D5CBD4CFD5
CEC8CFCCD0CDCCD0CECDD2CBD0CACFCECCC4CDC1CAC6D2C7D1D2D1CCC3CDCAD1C3D2BFD5
BED2C8CEC4C8C7D0C7C3CCCCD4D3D2CFD4C1CFBDCEBCC6B6BBC0CCC6C7C5C5C7C4CAC1D1
BBC6BFCBB8CEC2C3BBC8DBD9DDD8DDDCD8DAD6DBDCDADBD6DBD6DBD3DBD1D5CFD2D2D4D5
CCD1CBD5CBD3CAD3C5C5C0C1B1C2CBCCCECECDD2CAC7D1C3B9B7C8C4DBCBD6C8C6C4CAC3
C4C8C5D3C8D5C4CBC0D1CFCDD1D1D0C9BFC1CCCFD4D8D3D5CFD2C9D5D6DBD8D4D9D3CBC6
CECBD6D2D7D2D0D5D1D7CFD6D1D7D5D6D6D4D7D0D8D3D1D5D8D7D5D5D6D7D6CCAFBCD1DA
D5D1D8D4D5D2D9D6D6D0D3D3D5DADAE2D4E0D7DBD7DAD7D7D1D2D9D7DDD9DEDDD6DDDDE2
D9DBD7DACDD5D2D8D6D6D6D1D5D3DED8DBD5D4D7D4D4D7DBD2D5D8D8D9D7DCD3DBD8E0DC
D1CED2DBDDD9D8DCCDD9D0D3D3D7D6D6D5D7DAD2D4D5DBDBD5D9D5D5D6D8D8DEE0DDE3D4
E4D4E2D5DCDEDDD9D8DBDBD8CCE0C39E69664742
474848474849494640424141423E3D44413F3E3F40413F3D4146433D3F403F42403F3E3D
3D3E4041413E414747403D403C3F42454644413F40423F3E43413D3E3A3A3B3D3F403E3D
343D505E4742403E3F42413D3B3F43443F3E5054595759524E4C5B554E47555147454541
49444841403D3B3A3C3C4144373D42403D3D3E3E3C3C473C403D3E3E38373D3C4738433F
3E4132423B3B4742434541424054564F424C4856575B585E596C596D5260517057555868
656E665D5D4D5F52675457545B556554604A413F414745483E4845444C61577A779B90A4
9AA7B1B1ADACABA8A495AF92AF9AADA6A9B1AFA7AEA6AEABAEB6B9B8B2BCB7B7A4B9A4BE
A4B3898A5350688FB1C3C5CFC7BFC0B2BBA7B5B1C1BBCAB4CAB8C6B9BEC7C0C9C1C2C3C4
BDC6B1C1AECDC5CFC6BECBCCD1D1D5D5CFC9D5D2D2C6C9C2C2BBB2A2A2989FA8A9A8BBC8
CCD3D2CFBAC2A8B8A3B8A4AEA5A8B3B9B9C2C8C0B7C9C9CDD6CCCCD5D9CFD8D0D3C6D1CF
C9CBCCCACACDCDCAC1CBC0D5C7D3C6D4CFC6C9C1B7B8B9BEC9C4C8C6CCC6C9C9C5C7C8C8
CBCFD0CDC6C7CCC7C6CDCDD2CDD1D3D1D6CFD9D5D8D2D7C9CCCECFCAC8D4CCCDC9D1C7CB
CDCACFD0CBD2D9D2D5D4D2D2D5D8D6D2C9D3CFD0CECAC0C8D1CCD1CBC9C0C5C1BFC2B9BD
B8BCB6BEB7B9BEBABBB3B4B2B1B4B8B1BCB9C0C3C7C8D0C5D6C6D4C8C7C8C9C8C5C3C7CD
C5CDC1CFBFD4CAD0C6C2BBC9C4CAC5CED1CCD0CBCFC5C7C6C5BDC8BED2C9D4CECAC2D1CD
C7CDC8D2C7CBC5D4C4D4D1D6CFCEC4D0C7D3CBCAC6CED3CCCCD0CED6D0D4D9CBDBC9D2C9
CCC3D1C6D3C9CDCDC7CEC2D3C3D5CBD3CACBC3CCC0D0CBCACBCFD0D0C8D1CACED0CED5C3
D2C0D0C5D1CDCFCCCBC0CFCDC9CFC5D7CED1D3CBC9C5C9CFC3D4D0CEC5CBC0C3C0C5C5CA
CBB8CDB3C4B5C9AFC7CDD8D4D8D2D6D2D4DCCBE1D1E0D5D7D3D4D1D6D4D9D5D5D1D0D3D8
D1D4CDD7D0CAD5BBCAAABDB1B0C0CACDD0CECCCFC5CAC4CFAFC1C0C6D0CDD1C9C3C9C6C5
AFAEB6B1B0ACA9ADB4C7CDCED1D3D6D0CCCBD2D2D4D8D3D6D3D6CDD8D7DBD8D5DCD8D3D0
D8D3DCD6D7D1CFD4D1DAD4DBD5DBD8DAD9D7D9D3D4D1D1D5D8D7D5D5D2D4D6D7C6D0DAE0
D7D3DBD8D9D4DBD6DAD4D7D6D7DAD9E0D7E2D7D9D4D4D1D1D2D2D9D6DCD8DEDDD0D5D5DE
DBE0DBDCD3D7DAD4DAD0D6CCD8D6E0D5D7D3D3D3D4D9D6E3D3DFDBDFD9DBDAD9D8DDDDDC
D3D1D4DCDDD9D9DDDBD8DCD1DDCFDCD2D3D1DCD1E0D9E1D9D4DED1DED2E1D8E4D9DED7DC
DCE0E2DCDCDCDCD9D8D9D9D7D9CCCB81624A4B47
464647494846454746494845433D3B4143403D3F4344403B42474642424342424342403E
3E3E3E3F4141454946403F433D41474B4B463F3A3F403E3D403F3C3E3D3C3B3C3D3D3C3A
3D403C423B3D3C454143423E3D3F403E4A475D56565B5B504C4A554E4843504E4F4A5049
4C44444345413F3B3E3F413F3B3D3F403D3A38383D3E413C394141463F453E463C3E3F42
4739423F424240404C514A534C666667626C7473837A86828D708D708A6A8D7C887B8684
8A8387746D665962556156615A6D4E6E4B5540455A5F7E705C56706798829C96AF9CB3A6
BDC0C3C6C5C2BDB9AEB2ABC1A3BBACB4ACB9ACBAACB7B1B9B8BDC6B6C5B1C5B6C4B0CCB8
D2B2B8907E7E8FA5BAC7C6CAC4D5B4D5C4DABECED0D5C9D5C8D7CCCFD4D2D7CED2C4CFCA
D5CED3BCD0CDDACDD5CDD7D5D6D4D3D4CBCCC0DBBBD6CFD6D0D3BFCBB6BA9F9F948EA7BF
C9D4D5D0CBBFC79CB79BAFA4ABAFB4B8BBC1C5C7BECCC1D7CBD1C7D2D6D0C7D7C8D0CAD1
CFCFCDCAC9CBCCCBCBC2CFBFD3B7C5C8CECACFC7BEC2C4C8CACCBFD1C4D3C5CBC3C5C6C7
CBCECDC9C3C6CFCCCBD0CFD3CAD3D6CFD0CAD5CFD5D1D4C8CECED2D9D0D0CBCCCACFCED1
D0CCD0D2CFD4D9D2D2CFD1D6D9D7D4D4D7DAD6D1CEBCB2B7D1CDD2CACAC4C9C2C6BFC5AB
BEA9B3ACB6BABBBBB6B4B3B5B8BFB2B3AAB8B4BBC2CBC3CCC2CBC9C6C3C6C6C1BEC0C6CB
CCC3CFB5CBBBCEC6D0BECCBED6BACAC9D1CFC4D0C8CFC3C5BFCBB6D7BBDBC2CDD0CDC8CE
C9C4CCC7CEC4D5C5D6C5D7CFD7C7D5B9DEC3D0BFCDD0D3CBCCCFCBD2CADDC1E1C4E0C9D0
CCCACDD1CDD1C8CED3C7D3BDD4C0CEC4D3C4D6B8D5BED3C2CCCDCCCCC7D3CFD3C8D4C0D3
BFD4CACECFD0C8D5C6CACACCD0CAD6C8DCC2D9C6CDC1DEC6DAC7D8C8D1CDCEC1BFD3C2CF
BACDA2C7AAD9B4C1CCCED4D0D7D4D8D4D5D0D5CCDED1DED4DED4DFCADDC9D5CCCFCBCED8
D4D6CDD7C4D4B8D0A8BCACB7B6C2CBCDCFCECED1CDC2D7C3CBB5CBC5D3D3DEC4D0C4C5B9
A3968F8C878D8F9BA0BACBD2D1D6DED8D7D4D8D5D6DAD7DAD7DBD3DCD8DAD9D6DAD8D7D5
DDD6DDD6DCD6D4D8D6DFD7DDD4DAD7D8D7D5D7D0D2D1D2D7D8D7D6D7D4D5D2D8D1D5D1D5
D9D7DFDCDDD7DCD7DED8DBD9D9DBD8DED6E0D7DCD9DCDBDEDBD9DDD6D9D2D7D5D6D7D4DD
DBDFD5D2D1DBD4DDD5DAD7D3DCDCE3D4D6D5D6D5D8D7DEDAD8D2D6D2DCD8E3D2E2D6E1D9
D7D6D9DDDCD8D9DFDBDDCDE4CEDED7D8D7D9D7DCDBE1DBD7DEDDE0D5DFD6DCDEDED6E4CD
EDD4EAD8DCDAD9DAD9D7D6D8C8DEA78450504B67
4644454746424347484E4D48453E3C42424142454847423E40474B4A4948444143424140
3F3E3E3F42434546413C3F4642464B4D4C47403B3E3E3E3D3E3E3D3E44413D3B3B3D3E3F
44413B41393E3E4343494E5051504C464B435855626A60544F524D5844525056554B5247
48403F453E3C423B4141403E433A363B403F3D3D3F4442463A4B444C44483E413C414647
3E3F3F435D485F56625F736380788E8584988C99919896988BA38CA9829B87A5979699AE
9FACA69EA58C9B708A61756A7F708A676F504A47578D9999868A8CAFA7B895C0A9CDAECD
C8C2BFC1C3C1BEBDC7BAD4B4C9A9BCAFB9B0C0A5BC9EB3ACB6BABFC2B1CCB7C7B1C0ABC1
C3D5B6B8A7A1AAB5C1C8C3C5D3C7CED5DBD4DCCBDBD4DACFDDD4DDD6D6D5CCDBCFD8D0D1
CED9C0D9C1E5CED1D4CED4D3D3D3D0D4D4C8DACCD5C5D5C9D9D1DBD0E2CAC6B4988BA1BA
C5D1D3CFC6D2B1B898B6A5B2B0B5B7BCC5C6C5CAC8C5C8CAD0C5D1D1D6C1D1C8E0CAD9CF
CFCECCCAC9CACBCCC2CABECCBCC7BDCCC6C7D0CAC4CBCECFD3D1CECECBC9C6C5C7C7C7C8
CBCDCBC9C7C8D0CFD0D2CED1CCD5D9D3D7D4DCD3D3D0D3C8CEC7C8D5D4CCCDD2CFCFD1CF
D4CFD1D3D1D5D8D3D0CFD1D4D5D2CFCED0D0D5D1D5BFBBBEC6C4CBC4C8C9D0C8BCC6B9B8
AAB4ACB3ACB3B3BCB5BEBDC4BEBCBFABB6B3BFB9C7C4D2BCD0BCD3C2C7CCCCC6C2C7CED1
C2D0B7D4B4DAC6D4C2C5B6D0BCCEC0CED0C6CAC3D1C5C9C2C9BCD5B8DBBBD0C1D4BFCBC5
C8D5C7CEC4CABFDAC2D8CBD3CBD4BCD3C6DBC2C9D2D1D1CACCCEC9CFD0C9DCBEDFBED6C3
CFC4D6C6D6C5CBC8CAD2B7D6B8DAC2CEC8CFBCD1BDD9C9CECDCCC9CAC7D6D2D7D2C5D9B2
DAB5D5C0CFC3C7BEC8C0D2D1C7D1C1DCC5D7CECFC5CDC9D9C3D9D0D4CCD4C1C4C2C5C7C5
CEB2CBADD1B8DAB8D3D4DAD6DAD4D7D4D4DFC4E2C8E2D2D9D9DBD0DACED9D0D4D5CDCDD6
D1D1C6CFCFC9D7B9CAA9C2B8C7CCCECECECFD3D8D4D6D0E0C6CFC7D0D1DAD8D6D0DAC9B8
8C656F5A7A6377778FB1CDD7D5D9E3DDD9D6DAD7D8DCDADED8DDD5DDD7D9D9D8DAD9D9D8
DFD8DED8E1DDDCE0DDE4D9DAD4DAD7D7D6D4D5CFD5D4D6D9D9D7D7D9D7D8D0D7D8DBD5DE
DCD8E0DCDDD7DDD8DFD9DCDADADAD7DCD6DFD5DAD6D8D8DBE0DDDED5D7CFD3D2D4D6D4DD
DADFD6D3D3D4DED3E4D5E3D7E0E1E7D6D7D9DCDAD6DED6E6D2E0D3D9DADEDADDD7DED9D9
DBDBDDDEDCD8DADFDFD0DBCDE4CBE1D4DED6E1D0E1D3DFD7D7E3D0E3CFE5D5E4DBE4D2E3
D6E6DDDBDCD9D9DBDBD6D5D8DBC8BF734541495B
4644444644404247484E4D4845403F4441434445454444443F4449494747444042424140
403F3F3F3F4143433E3B3E43444648494744403D3E3E3F403F3F3F3F403E3B3B3D414345
453D44524044443B494E52535556534E544B5B607975574A4F534B59485A555C524A5249
49413F45453F493D413E3F4142413E3F464F514E413E5B445B4751475B565A485D4F5E4F
46423E5560816982788B799F85AD9AAA9DA4A89AA698A39EB88FB392B996BB97A8A3B8B4
B8AFBDB3B4C2A8C89CAF8D95889B799E71785E5B8094BBB4B1A9C1C1CEBAD7BFD1B8D4C3
D8D6D6D8D6D2D4DBCDDEC8E2C2D9C2D1C2C6B2CBACC2B0BFBEC6C6BDCBB5D3C7CDBBD9BD
D1B9D4BBB8ABAEB8C4CAC9D1CCDEC2D4D6DECBDDDED9D4D5D6D7D5D5D4C8D4CFD9CED5CD
CBC6D6C5D7C2CDC4CCC8CACBCCCFCBD3C7D1BCD5B8D6C8D6CFD5CDE0D3E3D3D3B6A5AFBF
C7D0D1CFD2CCCBA6B3A5B5B1B4BDBEBFC4C2C1CBCCD1C3D9C6D2CED3D0CBC5D6CAD1CACE
CAC9C9CACACACBCCBEC3C8BDC7C4CBCCC1C3CFCCC7CECFCFC8CCCDCCC8C8C9CCCECCCACB
CCCCCCCCD1CBCCCACED3D1D5D2D8D9D3D9D3D5C6CDCBD2CAD0C6C4CFD4CACED5D1D0D2CF
D6D1D0D2D1D3D5D3D5D6D6D4D2D2CECABCC6C1D9CACEBDC9CBC9CEC7CACAD1C9C6C2CAAB
BDA9B7B1B8B4C1B1BFB0BDB9B7BFB6BCB2C6C1C1C2CCC3CBBAC8C8C3C1C7C8C3C0C4C9CA
C9C3D3BDD3C1D1C7CBC3D2BCD0BCCBC2C9CAC0CDC2CBC1C7C5D1BADAB9D7BEC9CDC9C2CB
CCCBD6D0D1C3D7C7DAC1D1C5D5CADCB9DFBBCBBFCFCDCDC9CED1CCD3C1D6BEDEBAD8C6D0
CCCACACFC7CBBFC5CFC3CFBBD5C3D3CAD5C6DAB6D9BCD2C2C9CACCCFCEDAD2D3CADBB7DB
B3D9C1CAC2C0BCCBC0CECACFCCC3D4C5D8C3D8CAD7CEE4C6DDC3DCCFD8CED3CDCBD7C2D3
C6DBB7D1C5DDC4D0CACEDAD9DED6DBDBE0D9DFCFE0CDDDD3E0D4E2CBE2CCDBD2CEC8C8D2
D2D9D2DCCBD9CBDDC5D1CCD5D7D6D5D4D3D4D9DDDCD6DFDBDCD0D7D7D9D3E1D0E2D8D7AE
84584E505A535C6886B1D1DCDADBE3DDD9D6DAD8D9DDDADED6DCD5DCD6D9DADADEDEDDDB
E1DAE1DCE2DFDDDEDAE3D9DBD7DDDADBDAD7D9D2DBD9D8DADAD7D8DAD7DAD0D6D7DAD5E2
DCD7DED9DAD5DCD8DDD7DAD9D8D9D5DBD7DFD4DAD6D6D6DADAD8DAD3D7D1D7D7D3D7D6DD
D8DCD6D7D6DED8DFDBDEDEDAE3E3E8D6D7D9DCDADBDBE0D9DDD4D5D2DBD7E3D0E1D3DED5
DEDEDFDEDBD8D9DEDCE3C9E2CFDDCCD5D5D9D6DBD3D8D8DFDFDCE0D1DDCFD7D7DCD5E4CD
ECD4EBD9DCD9D9DCDBD7D6D8C5DBA0664847536C
4746464645434446454B4A4443424246434342403E3F4347404144423E41434041404040
404040403A3E4243413E3D3E4141424241403F3E3F3F4344424143413E3D3D3F41414140
464354614543453D494A474343484B4C555665697560474845484A494445494D4C4B5654
584E49454B3D4639424147504D5D61585762655D617369856583677361715B745C72574F
483C5857A88AA594AF9FBA90BE94B4A8ADB5ADB1A9B2A9B1A6BBA3C0A7C5B2CBB7BDBDC8
B9C3C2C8C9CAD6CED5BDC2B7B696A685A196A6A5A7C2C7D5D3DAD1DDC5E2C8E3C6E7CEE5
DCDBDDE1E0DDDDE0E4E2EAD0E6C6D3CCD4C1CCC0CBBBC3C1C0C7C4CFBBD4C7D9BED1C0CF
C7D9C6D2BEB2B5BCC5CACAD3DCD2DDD0DFC6D7CBD8C8D7C1DEC7D8CDC6C2C6D3C2C8C2C7
B4BEB6D2C0D1BEC5C1C0BFC1C1C5BFC9BDBDCABDCDC0C9C4CBC8DCD0E2D4E1D5D4C5C6CA
CED3D0D0CDD1BFB8ACB7B3BAB3B8B6B6BFC5C9D0CDCFD1D0D2CAD0C9CEC1D4BFD0B8CFC9
CECCCCCCCAC6C3C4BCC5C3BBBEC1C1BFC2C2CDCDC9CDCBCAC6D2C8D2BAC7BDC6CBC8C7C7
C7C5C6C9D0C9CBCCD0D5D1D5D2D4D3CED4CCCBBCC9C6D1CDD4CDCACFCDC7C8D2CED3D6D7
D4D0D0D1D1D0D1D1C3C5C5C4C7CAC8C4C3BED3C7DABEC8C2D2CED3CCCDCBD2CCC7CCB8C2
B8C7B7BBB0BAADC2AFC3B6C0BCB9C2B7C1BEC6BCC2C0CFBAC6B8D0BDC9CCCDCBC9CBCDCF
BBCCB8D8B9DBC3CDC4D1C3D4BDD6C7CEC9C2C9C2CBC0C8C7CABED6B9DBBED5C9D1C5D5CD
C7D0CBD9CDCEC4DEC9D8CAD1C9D3C5D5C3D2C4CDD0CCCCCACFD0CAD1CBC6DEC0DABBDACA
D3C8D7C8D6C6CAC8C3D0B8D9BADCC8D6CCD5C4D0C0D3C5CCCDCECED0CEDAD2D4D6D0D8C2
D5C0D2C5CEC0C9C0C9C6D1D2C1CABFD9C1D9CED5CCD8D0DECDD9D4D5CED2C6D2D0CCCACF
DCD0D9CBDBC4DAC3CDD0DBD8D9CED1D2D0DDC9E5CDE5DCE6D9DBD4DDD5DFD8DBDBD5D2D6
D2DAD4DBDDE0E5DDDFD1DBD8E0DBDCDDDADADDDEDAD9DCDDDCDADDDFDDDAD5DBD6DFCFA9
86596355684B5A5C87B8D6DFDFDEE1DDDCD9DCD9D9DBD7DAD6DBD3DBD6D9DADBDEDDDBD7
DDD6DFDADFDDD8D7D2DED9DED5DBD8D9D8D6D8D1DBD8D8DADAD7D6D7D3D8D2D7D5D7D2DA
D9D5DBD6D7D3DBD7DCD6D8D7D6D7D4DAD8DFD5DCD9D8D7DCD8D6D9D2D7D2D8D8D6D9D6DB
D5D9D6D9D6D5E1D2E6D5E6D9E1E0E6D6D6D6D7D7CCD6CDDDD2E0D4DCD8DCD8DAD5DBD8D7
DEDEDEDDDAD8D8DBDCD9DDCDE6CDD9D3D4D2E1D3DDCBD9D9D3DECDDECCDFD2DFD9E4D3E4
D4E4DBDBDAD9DADBDAD7D6D6DFC6B75C5052656B
484A4A4A4A49474442484540414344474644413F3F404141414042403B3F444140404040
403F3F3F3C3E41434443413F3E3E4041414141414141474945454643424141434343413F
474446514648454345484845464B50534A556969654A434E414D545245424853565D696E
786D67595B4550495E636B7877888F867F83847F8B849E829C8A9B94989AA78C9A787755
4246649BAFCEB2B8B7C0A9C3AEC7B5C8BFBAC3B8C1BDB9C0CABCCBBACEBDCDBFCDCDD0C7
CCC3C5C5CCDBCDE3D0DED7DDD3C5A3A396A9BFCCD2D1E3E4E2D9E0DAE0D9E8D8DCD4E6DF
E4E3E3E5E6E5E3E2DDECD1EBCADBC6CDCBBDBDC9C3C7BEC3C5C9CEC9CAC3CED0D0B9D4B0
D5B3CBACAFB5C5CBCED0CACDC3D5BDD9C7D5BECAC7C5BBC9C2CDC4C8B9ACC0C1C2BEC5C7
C0B7CDB9D9C0CCB8BCBCBBBFBEC1B7C1BDC6BCCDBAD2CBD1CFD2D5DAD2DBDBD8DAD5D4D1
D5D5CCCDD0CEC5B7B5AEADAFBEBFB9B4B9C3C7C8C7D6CCD6CAD2CBCACFCDCECDC9CCCFCC
D4D0CECDC9C3BFC0B5BEBABCBDC3BCBDC7C2CACCCACCCACAC5C8CDC4C6C2C7C5C4C3C5C6
C4C1C3C7CCCAD0D1D1D1CDD2CFD0D1D1D9D2D7CED3CBD4CFD2CECCC9CCCDC9D2CAD2CFD3
CFCED0D2D1CDCBCDC7C5C7CDD4D6D5D4C5CFC7D9C5D1C3CAC7C2CAC8CAC7D1D1D3CEC8C4
CBC3BBB8B9B3C1B3C7B8C4BDC1C0BCC3BAC3C0BDC6CECDCFC1CBD2C6CBC9C8C9C8C8C9CB
CBCCD1CACFCBCEC8C7C6CCC2C8C0C5C2C9C7C1CAC5CAC6CAC6CDC4D4C6D5CBD1CCCACCD2
CFD0D9DBD8C9D3CCD7C7D2CDD1C7D7C2D5C1D2C8D0CDCECCCFCFC8CFC4CFC6D7C5D5D3D3
D3CED2D3D1D2CCD1CCCBD0C9CCC5CCCCD1CDD8BDD4C0CEC7D3D3D0CFCBD8D3D7CBD6C7D7
C5D5CFD2CDC8CBD2C8D0C9CFCEC9D3CBCEC7CFCACDD0DDCEDEC8D7CAD2D1D6D5D3DECEDB
D0DBC6CDD6D2CDCCCBCAD2D1D6CED3D4D9DBDED7DAD0DCDAE0D9E2D3E2D2DAD2DCDAD7D7
D3DFD9DEDDE4E1E4DFDDE0E1E4DDDDE0DDDDE1E1DBDEDBDDD8DEDDDFD9D4D6CEDED7D7B4
88675A5650565D638EC1DADEE2DFDFDEE0DDDFDAD9DCD8DBD8DCD3DBD6DADBDADCDBD9D4
D9D1DBD7DCDCDAD7D0DCD7DCD1D7D5D6D6D4D6CFD5D2D3D7D9D5D2D1CFD5D3D8D6DDD8DB
D6D2DAD6D7D3D9D5DED7D8D6D5D6D3D9D6DCD2D9D4D0CED2D8D6D9D3D7D1D7D6D4D4CED4
D3DCDBDDD1D6D7D6DCD9E0DADCD9E1D7D9D6D8DAD6DADAD9DFDDDBDEDBD8DFD1DDD4DED7
DDDEDDDBD9D8D7D7D1DCCFDDD2DCD4D5D9D9D9D9D4D0D1D6D6D7D8D2DAD6DADEDDDDE3D5
E1D3E0D6D6D8D9D8D7D7D5D2C7D59F8478918A9B
494D4E4D4E4F4A434146433D40434447484644454745403A414145443F43464141414140
403F3E3D42414041444645443D3F4244454544444242494C474748444443424345484949
4F4F40434448414B565D62605C5A58565E687A7A6F4F4745536E70805F6C6B8479838D95
A299958193757E799292959EA4A8ADAFADAAABAEA8AFB1B8AEBDB3BAA5B9B7BDAFAF9D8B
595693ADD1C1CBBBC9C1CABBD4C0CBCCD2CBD2CECFD2C2CFBDD1CCD7CCD2C6D5CDD3D0D4
DBDAD1D3D9DBE4D9E6D2E4DDE8D5D9BAB9ABC7CFD3DDD9E0EBE6DDE9DFE7DEE8DCE5DBE3
E5E8E9E5DFDFE3E8E5DAEBD4E9C6DEC7D6B9CFBCD2B4BBB1B4B6C3C5BBCCBFD1CBD5BDD2
BAD3B9BEAFBED1CFCCCFCCCECEC1C6C2C7BAC8BBC6B7C2B1C9B4C0B7C0B1BAC3BFC6C4C6
B7CAC0D2BBD2BEBFBEC0C0C5C4C7BAC4C4C2C7C8BEC5CAC2D0CEDBD4DAD5DDD2D3D6D6D2
D7D5C7C9D0CFC7C2C0BCB9BDB7C0C3BBB7C0CBCFC9DAD3D1D0D5D6D4D3C8D1C3D5CCD0BA
D0CCCBCCCAC6C4C6BCBEBFC0C8C4C1C1C9C0C8CCCBCDCCCFCBD1C9CDC1CCC3C4C5C6CACD
CAC6C8CED2CFD4D0CAC8CAD5D5D6D6D3D6CBD1CDD2C7D1CCD0D1D2CBC5CEC9D5CAD4CCD1
CBCCD0D4D2CBC7C9CBC3C4D0D6D2CFD2CBCCD3CACDC5CAC6D2CAD0CBCAC1CACBC8CFC4D5
C9CFBDC5BCBEBAC4C1C9C3C4C2BABDBFC1C3C9C6C7CAD4CAC9C7D8C6D1CBC9CBCCCACBCF
C9D1C4D1BFD1C6CAC6C9C3CEC2C7C0C8CDC6C4C5CCCBCBCACBC8D3C9D6CAD2CDD9CBCFD0
D2D9D4D4D4CAC6D0CACDCED3CDC7C9CCCACFD3CECBC9CBCCD1D1CBD3D1CCD2C8D1C6D4C5
CDC6D0C9D1CBCDCFC2CEC6D5C0D0C8D3C7CECCC7CACCCDD2D1D3D4D5D0D9D0D2D1CFDAC4
D7C0D4C7D1C8D2CECCCCCCCFCCCECCD5C6D1CBCFCAD4D3D6D7D2D6D0CCD5D4D4D2DCD6DB
D7D4C7C6D5C6CDBFD1CACDCCD5D0D4D5D1DCD4DFD0D6D7DED7D6D9D9DDDBDCDAD9DAD9D6
D2E0DBDEDFE3E0E1DFDBE0DFE7DDDBDCDADDE4E5E1E3E1D9DBDCDEDCDDDFD5D1D9D5D0BA
866555474B5E6B6894C8DBDCE3E1DEE0E2DEE0DBDADEDCE0DADDD4DBD7DADBDADFDEDCD8
DCD3DCD8DBDFE1DFD5DDD4D6D3D9D7D8D8D7D9D3CECCCED5D8D4CECCD1D4CFD1CCD4CEC9
D3D0D9D6D8D3D9D4E0D9D9D5D4D5D2D9CFD6CFDAD8D7D6DCD3D2D7D2D8D4DADADED8CDD1
D0D9D5D4D6D6DCD0DDCFDCD1D7D4DFD9DEDBDEE2D5DCD4DBD8DFD6DDDBDBDCD6D9D9DDDA
DDDDDCDAD9D8D6D5D2D4D7D4D3CFD6C9DDD5D6CFD7CFD8DBD0D8D1D9D6E1DDE7D5DED9DE
D8DCDEDDD4D8D8D5D5D6D4CFDAD2CEA9C4C3C4C0
4D5158735A57414747453F4445484E5359474945594A4F4B4C3F46453B43454042444140
3D414141434F3F52444F434B3D46414646434D484C4A604E52545D544F535D57575F6560
5F5D5D5B535C565F596B718E8A8C898A85818B796C4843516B87AD9EA89CA89DA9A2A9B2
BCC0B7B59FB29FB9A2BEAFC4C0BFC0C7C9C4C2C0C7C6D1C9C5BBCCC0CEC6CEC2CFBBB6A6
8C8A97C6D3D5CDD9D1D8D2D8D2D3DBDED6D9DADEE1D8CFCFCDD7D7D2D8CBDCD1DEDAE2D9
DEDDE0E3DCE0E0E9E5E9E4E4E2DDE0D9D9CBC9C6BFC7D9E8E3EBE3E4E3E2E2E3E5E5E5E4
E5E4E6E0E1E8E7E9DDE6D9E0CFD5D0CFC6BFC4C7BFBFBEB2B0AFB9BABEC4C3CCCDCDD2CE
D6C4C6B8BBC2CDC7C2C5C4C9C2BDBCC8BFC0BAB7ADB1B8BDBCBABDC2BBC4C7C7CED2CDCA
C7CCCDC9D1CDCFC0CFCECECEC9C5C8CEC9CAC5C5C5CECFCECBD6E0D1C9C3D2DAD5D7DBD4
D5D5CFDBD4CCC9C6BCBBBAB4BEBDC1BAB8BEC4CFCDD2D3D1D6D2D8D1CBC5D1CAD4C9C7D0
D4D4D0D1CDCDC5C1BEC5BACAC0C7BEBBC1C6C8CACACAD0D3D0CBCCBDCEC2C4BBBDC1D4C8
C5BACAC8C6CEC6CFC6D7CCDDCFDDD0D9D2D8D0D3D1D3D1C6CFCBCDCCCDC6CDCECEC2C7C9
C9CBD3C9D4C6C7C5C9D0D2D5CCD9D2D7C0C6C4D3C2C9C2D1C6CECECFCBCBCAC6C8CCD0C7
D1C0C8C5D1C7C8BFCEC7C9C0C0B2C0BCB7BFC1D5BECDC8D0CCCBCBD1D0CCCBCECFCBCACD
D0CECDCDC5BDBCC2CFC2C3BAC2B6C0C2C9CCCFCBCCCDCAD2C3D0C8D7CCD8CCD5CCCCD1D2
D1D7D5DCCECDCECAC1C0CABCBAB7C1C0CAC2D5CED2CDD2D1D1D1D0D8C8D0CBD7CFD1CFD0
CFCDCCCCCECFCFCECBCDCDD1C9D2D0CCCDCED5C4D0CDD7CED4CCCBD6D5D9CDD2CCD2CCD3
CECFD2D2D4CBCFD2D2D0CDD6D1D7D5D6CCD1CCCCD3CFD2CFD8D5D9D7D2CDD2D0CBDAD1DD
D1DECCC5D2CFCACDCAC9D2D1D0D1D0D8D0D9D5DBD3D3D7DADAD7DDD1D6D8D9D8D6D6D7DA
D1D9D8E5DDDFDCDEE1DDE4E1E5E6E6DDDCDCD9E3DBE2D3E0D0DBD9DED9D3D9DCD6D8D3A9
71544B3F45556E5C96C5E3E0E1DAE1DEE0DADED7D3DCDDDED1DDD4DFCFE0D5D9D4DCDFD7
D5D9DDDADFD8E2DAD6DAD3E0DED5D9D2DECDDBD3D7D1D7D5D6D3D0D4C4D5CEDFC4D4CBDA
D1D6D2CFD7DAD7D7D5D5D7D9D7D5D7DDDBD5DBD5DCCEDACDD8D2D7D0DDD6DBD6D7D9DAE0
D5DAD1DBCEDAD1DED2D7D1D5CED7DDD8E4E1E2E1DBDAD7DADADDDCDCDCDEE2D9E2D5DDD2
DFD9DCDAD5E1D3DAC8D5CBDFD0DDD6DAD0D7D9DAD2D5D5DAD2D1CFD5D7DCD9D8DED4E6DA
DDCEDED3D5D1DDDAD2D4D0D1C6D1C9D5CCD1D5D9
585366656D505C48423E51515D5C5B5F6053525057545B5B514A524F494C4D4B403B4240
463D464B45495D51564F3E3D464B4F48464B50545E726B8B72937B8E7B8787979298988C
988E9C848D7B7E7983889099A59EA9A7A5A5A2977359547592AFC5C9C4CACAC7C4C4C9C8
CFD6CFCACBC5D4B9D0B3C7C7CFCECED3D4D1D0D0CFD3D3D8C8CCD3CDCDCED5D5DAD3D0CA
AA9EA1B9D3DBDDDEDBDCDFD9E1D6E4E0DDDFDEE0E3DCD4D5CCD5C9D8CECDD1D2D9D6DFDA
E0E0E1E3E1E3E0E6E1E8E5E8E0DEE4E1E3D5D1CCB4BCCEE0DFEBE7EAE3E2E2E3E4E5E4E3
E3E2E6E1E2E8E5E7DDE5DBDFD2D4D0CDD1C4C3C7C3C2BCAEB0AAAEAFB2BABECBC8CEC9D5
D4D7D5D2C8C9CDC4BFC3C2C7B9B4B1BCB8BFBAB5B0B1B5BABCBDC1C7C7CFD0CED1D3D6DD
CBD0D2CDD6D3D9CECCCDD0D2D2CFCDCDBFCAC7D6CDDACECDCFD3DBD4D8D3D5D1D6D6D7CF
CECFCCD6CECDCBC3B5AFB2B4B5B2B6B3B7C1C6CFC9D5CCD9D0D9D4D2C6C3C7C9CDCFCCDB
DBD2D2C6D0C6CBC7BEC0C7C1CBBCC7C0C3C3C3C7CACCCCCAC3D1BAD2BCD8BEC6C7CBC9CC
BCC6C9CCC8CBCCCCCBD2CCD6D2D8D8D0DCD1D6CFD0D2D2C9D1CDCFCDC6CEC2D0C8D0C4D3
C2C9C3C9C5CBC5CDCACDD6D1D0D4D2D4CFCBD7C6D1C0C7C1C9CBD6C5CDD3D2CDC5D1C8D2
CBCFCDD4CCCCC5CFCCD4CAC8C7BFC2C1BCBFC7D0CFCBCDBFD6C4CFC7D0CCCACCD0D2D4D6
D0D6C6D2BCCEC2CAC4C4BABEB9C5C3C6CACCD0CED2D3CCD1C8C6D6C6DDCAD4CFD1CDD8CF
D6D3D5D7D7D4CACCB3AFAFA8959792A7AEC7D3D5D4D0D4D2D2D4D2D7CCD1D0D3D3CDD0CC
CBCACACBCDCFCFD0CCCECCD0C8D2D1CFD1CED5CAD7D1DCD8D9D2D1DAD8DBCED4CACAD0C9
D3C6D2CCD1C9CCCDCFD2D1DAD1D5CFD1CCD3CECDD5D2D6D2D9D4D7D4D0D0D4D7D2DCD4DB
D2DED5D6E2DDD8D8D4CFD5D6D5D4D1D8D6DBD0D7CED1D1D2D4D3DCD4DBDCDCDBD5D5D8DD
D5DAD5E0DCE0D6DED9DEE0E2DFE0E1DBDDDFDCE6DDE0D7DAD5D7DADBDED2E0D6DBCED1A3
72554A5455606B6990D0DDE5D8DFD8E6DCD7DDD7D4DBDBDAD2D2D7D6D8D5D9DBD6D4E2CD
DFD1DFD6DBD3DCD6D5D9D4E0D0E1C2E4CCE4CDDDD9D6D5D9D1D6CCD2CFCED8CED4C6CECE
D3CFDCC5E1D0DCD3D8D5D4D6D8D8D9DCCED6D1E1D1DADCDED5D5D1D6D5DAD7D8D9D6DCD9
D6D4D1D8D6D1DBD3D5C6D4C7CDD4DAD4DFDCDEDED7DDD1E0D2E1D6DCD4DDD6DFD8DFDEDB
DEDADDDAD2DDD1DBD4D2CECFD4CFD6D2D6D5DED6DCD1DADACBD1CBD9CFDDD6DCD5D3D5D4
D2D4DADBD8D0D5CDC5C9CBCFC8CECFD3D5CFD3CF
55515468526D54574F5B5063585657576C5C684F5E4A5F544C4C5852535151555B574E5B
4B4A495C567553784E54424A637872777472857F9A82B49CB88FAC9AAC9FB4ABB6B5B1AC
ACB7AEC5ACC2ABB59FA899AD9CAFAEBBC3B7C4A3915D6680BCC1E2C7DFC4D7C9D3D2D7D3
D4D8D3D2D1D9CBD9C2CEC4D6D9D7D9DAD9D8D8DBDAD5E3D4DDCDE4D6DDD6E3D3E5D1D9CF
BCBBAEC9CFEADFDEDEE5D7E5D5DFD8DBE0DFDBDADBD3CCCDCDC7C9C9D6C1D2D0DEDBE2DD
E1DEDAD9E3E5E0E5E0E7E5E8E0DFE6E5E9DDDBD7CBCEDAE4DDE6E0E3E2E1E1E2E4E4E3E2
E2E1E5E1E2E7E3E5DEE4DCDBD3D0CFCACEBFBCC2C0BDB8ADB0A5A6A8ACB0B8C7C3C2CEC6
DBCAD8CECDC8C5B8B2B5B4B9BAB6B0B9BBC7C1B9BBB8B8BBBFC2C7CDD1D4D1CECCC8CAD3
D2D5D3CCD1CCD4CAD0D1D2D3D4D1CCC7CBCDD4D1D5D1D3CFD8D4D6D3DEDCDBD2D9DADAD3
D1D1CDD2C8CCBABFAEB8AEB6BCB6B7B6BCC5C6CBD1D2D9D0DBCBD4C9D9CDD4C1D1C1CAD1
DDD9C6D2C1CBC0C9BDCFBDD8B8CCBFCACAC4C2C5CBCDC5BFC3BDCCB1D1BBCCC2D7CAD9BE
D5C4D9CDD3DBD1DECDDFCCD7D2E1CBE1CDDFCDD0CED1D4CDD5D0D2D0D3C2D3C6D0C3D6C8
D6CDD8B9CFB2C1BBCAD2CED9C8D9CBD4CDDDC3DDBCDCC0C2C2CFBDC8C4D2D6CED4D3DEC7
DCC2D7D3D6CBDDC8E1C6D1C2CAB9CABEBAC8BFCCC8D0B3CDBFD9CCD4D8D4CFCDD0D5D6D5
D6D2D7C1CBC0C9BFCDC8D6B8D4C6D6C3C9C9CAC8CED1CBD0C5D7C0E1C4E0C3D0CED0CFD6
CCD7CCD3D8CED1C2AF8887797D758786B7BCDCCCD5D3D6D1D2D7D3D5CCD6C8DACBD6CDCD
D3D3D2D1D0D0D0D1CECECBCFC8D2D3D2D5CED7D0DCD1D9D8D8D3D2D8D2D3C6CCD1D9CED9
CACFCACBD0CCD0CFD1D5D4D9D6D6CED0CCD4CECCD4D3D8D3DAD5D8D3D8D7D3D5D0DAD9E1
D4DAD6DDE4DDDAD7D9D0D1D3D3CFCAD0D8DACAD3C9D0CDCDC9CAD7D3DCDCDAD8D8D6D8DC
D5DBD4DCDADBE0DBE4D6DED6DEDDDEDADDE1DEE5DDE5D0E2CFDED5DADCDBD9E6D5E0CFA7
5D505B55675F665AAAC5E7D6E4D6E8D0DAD7DCD9D6DBD9D6D6DECBE7C6DAC8D9D5DBD1DD
CEDBD0D4D8D0D7D5D6DBD7E0DFCDE2CEE2C4DFC9DAD2DCD1D9D0D1D1D0D3CADBCDD6CBD1
CDD8CBDCCDE0D0D7DBD5D2D5D9DADBDCDAD3E7CFE4C6E1D5D7CEDCCAE0CFDED7D6D9D3E0
CDD8C8D3C4DBC0DBC7DAC4D3CDD1D6D1DAD7DBDBD7D4DBD3DCD4DCD9DED9E5CEE6CDE1D3
DAD9DEDCD2DAD0D9D2D8BBDCC6DFD0D9D4D7CEDECDD6CCD6D1D0D3CFD2CDD1D0DAD4E4CD
E5CEDDD5D6CFCDC4BDC1C5CBC5CEC4D5CBD7D3D6
4E4C465160576659695C6F5D655F5E6766695F6D556A62625361626E64736A7B7B71796E
6D525C65836C8A656949506F8992A8A2A1ABA1A3A7BFA7D0AEC29AB6B2BAAECAC0C3C7C1
C5BDD7C0DDC1D2C5CEC4C5A8AD9DB3B6C6C9C1C9A8A292AFC8D5CFDFCCDBCED3DBD5DADB
D8D4CFD7DCD6E7C9DBC3D9D5DBDADEDBDADBDADEDAE2D6E5CFDEDCDBDCD9D1D6D6DBD2CE
C3C4CCCCDADBDED6DED7E0D0E1D0DDD4DBDBD7D8DAD5D1D4C4CBB6D5C3D4CCD7DEDAE0DF
E2E3DDDDE1E4E1E7E2E6E1E3E3E0E5E3E8DFE1E0DFDFE4E9DFE6E0E2E1E1E1E2E3E3E2E0
E2E0E3E0E1E5E1E4DEE1DAD6D1CDCEC7C6BBBABEBAB7B8B6ABA1A0A6A9A8AEBCB7BFC4CE
D3CFD0CAC0BCBBB0AAADAFB7BCBAB3BDC3D3CDC5CAC4C0C2C6C9CDD0D2D0CFD4D8D0CBD0
CBCECEC8CEC9D2CCD1D3D3D0CFCECDCACCD4C8D7C6DAD3DDD9D5D7D3DCD9DBD5D0D4D5D2
D0CDC7C4C5C1BEA7AFA0A8ABB3AFB3B4BBC5C7CDCBD8C8E0CADBCED2CFCFC7CDCCD3D2DF
E1D0D6C6D4BBC2BEC8C5D8C1D8B9D1C5D1C9C8C8CDCEC2BBB8C3B3C3B7D0C7D3D3D9CAD8
C8DCD0D3D0CFD8CFD5D3D2D1D8D4DFCCE4CDDBCACFD0D6D2D8D2D5D2CDDEC0D4C3DBBFCF
CAD4C4D1C0CDBEC9CFCDD7CFD3D0D0D0D7CDDEBCDDBED3BCD0BDCCBED2D4D5DAD1E1CDE0
C8D8CEDBD1D9CFE0CDD9C8CBC2C3BFC5C4C4CEC6CCC3D0B5D3B9D8D1D4D3CFCED3DADAD5
CADAC7DEBDD7C1CAC6D3C6D2C5DDCDC7C6C8CBC9CED0CAD1D0CADCC4E2C6D1C6D0CAD9CD
D9D1D4D2C9CDC3C69A826D6767756B97A4D6D5D4D4D3D5CFD1D7D3D1CED0D0CED6D0D7CF
D5D6D6D4D2D1D2D3CFCECCD2CAD3D4D5D6D1D9D1DACACFCAC9C7CBD3CFD4CCD3C9CCCCCB
D0C9D2CFD4D3D7D4D4D7D2D4D3D6D1D4CFD7D4D3D2D2D6D1D8D6DAD6D6DAD5DBD4D9D8DB
D5D4D2DADCD7D9D7E1D3D1D2D3D1CBD2D3D0CEC9D2CAD3CEC9C9D7D5DEDCDAD8DED9D7D9
D4DAD4DDCFDBD5E8DFE7E0E0E2DEE0DCDEE2DDE0E0DEDAD7DDD7DED9E2D8E7CFDEC9C384
51474A6D685E506D9BDEDCE7D3E4D2E6DBD9DCDBD8DCDBD5D6CFDCCEDBCAD8D8DBCFE3C6
DEC0D5CDD6D0D5D6D9DCD8DDCEE5C6E2CEE1C7D7D5D6D2DBD0DCCFD7D6CADCCCE5CBDCD5
D1C7E1C3E9CAE1D3D9D5D4D8DADADADBD6E2CBE8CCE2D0D5D4D8D0DBD0DCD6DCD5D0DAD4
D8CEC9CAD1C2DAC8D9BFDDC6CFD0D7D3DAD5DAD9D3DDCDE2CAE0D1DCD5E0D0E3D2E0D8DB
D7D8DADCD5DBD1D6D6CBD0C8DCC7D5CED9CBD6CADBC5D0CED0D6CADACBDDD1D7D1D7D1DB
D1DDD5D7D4D1CFC9C5C7C9CDCBCAD1C7CFC4CECB
51464A5661705F71627162796D6E737484738E6A8F73917B89889C8198828D929CA5A3AD
96958A92879E759A625F6790A6B9B9C2C2B9BAA8C4B6D7C1D3B4CEBBD7C2D4C3CAC8CED8
CAD7C5E4CAE5D1DBD5DCD1D9BFC4AFB1C9C3D4C4D6C6D1D8DFD6EACFE9CEDFD4DDD7DDDF
DCD6D1DBD4E5D5E4C6E3D8E1DEDDE3DFDDE0DCE0DEDAE2D3E0D1E3D6DBD1D8CBDFD3DCD2
D2DAD0E0CFE0D7E0D8DCCFDFD1E4D8DFD9D7D1CFCFC7C0C2C3C1C7C0D3D0E0D9E2DEE1E1
E2E6DFE0E0E3E0E6E0E4E0E1E5E2E7E4EAE1E4E3E2E0E3E6DDE6E1E4E1E1E1E2E4E3E1DF
E4DFE2DEDFE2E0E5DEE0D7D3CECBCDC7CBC2BFBEBAB7B8B8A89F9BA3A5A2A8B3B5BDC2CA
CDC6C5BFB2B3BAB5B1B5BAC7B8BAB5BFC8D8D2CDCFC9C4C7CCCED0D1D0CFD1D9DDD3CBD0
CDD0D0CCD2CBD3CDC9CED3D2CFCFD3D7D4D2D6D0D3CCD1D0D4D2D8D6DDD6D6D2D5D9DAD8
D5D3CEC6B8C3A0B699B7A1B5B3B4BCBBBDC5C8D0D8D6D8D0D9CAD4CDD4CFD7C9E0CFDCDB
DEDBCBDDC9CFBDC4C8D7C1DFC3D9C6CCD3CDD0CECFD1C6C4C7C5CFBAD1C3D1CED3CBDFC2
DFC7DCD0D3D9D3DDCDE2D6DDD6E1CDE3CEE0D1CFD1D1D8D5D9D3D7D5D6C5D5C9D3C9D9C6
D0C8D8BAD8BCD0CAD0D5CEDCCADAC9D3C7D7BADDBCD9C7D0C2C6B0CAC6CBD0D0D5D5E0CC
E1C7DBD6DCD2E6C9E1C1D1C4CABECFC9CAD8CBCEC0D1BBD6B5D0C9D9D2D3D2D2D6DAD6CE
D3D0E2D3DEC7D4D3DFD3E3C5E3CBDAC7C7CCD4D3D5D4CED5D1DACCDBCCD8C4C9D3D5D2DC
D1DED1D7D7D4D3B69D706C5C65647779B3BEDDCED2D1D4CED0D6D0CECED9C8DACBDCD3D3
CDCFD0D1D1D2D4D7D0CFCED6CFD6D5D5D6D4DCCFD6C8C9BFD0CFD1D6D1D6CED5C9CBCBCA
D0CBD6D5D7D5D8D3D2D5D1D3D9E0DDDDD1D4D0D1D3D3D6CED5D4DAD7D7DBD5DAD3D6D5D8
D7D4D3DCDDDAE0DFDBCECCCCCFD0CED5C9D8C2DEC2D9CAD4D5D2DFDCE3E0DEDDDFDAD8DB
D6DDD6DDE1DFE3DBE7DAE7E0E5E0E2E0E0E3DEDEDDE4D2E3D5E3DCDFD3DBD4DFD5E7C690
4E4E5B4F5B4E566BC2CEEAD5E8D7E7C9DFDEDDDDDBDDDFD8CFDDCBE1C4E0D0DBD2DBCEDA
C0CEC6D4D3CED1D4D7D8D4D6D7CCDED4DBC9DEC9D6D0DCCFDAD3D7D4D1DEC7EAC5E2CADC
CCD5C7E1CCE3D3DAD5D5D8DCDAD7D7DADBD3E3CCE8C8DACAD9D0E0CBE2CEDFD7D4D5CBD9
C6D4C2CBC3DCC0DAC8DBC6D7D0D0D9D7DDD7DBD9D5D1DBCFDAD0DAD7D9D1E3CDE9CAE1D2
D8D6D3D6D2DBD3D6C6D1BBDBC1D6C9D4CDCBBCD2C3CFC3CECECDD3CDD2CDD4D5DECFDDC5
D5C9E1D3CECFCDCCCBCACCCDC4CFD0D7C5C7BCC2
4C4A58648D758E8C8A82988F9A97979E9CA88DAA8FB7A5B1A8B6A7B9A1BAA4B9BCBFC9BB
BFB5BEBBBBABC496917282A3C8C3D4CECFD7C4C5BFDBC9D7CEDCCDDBCED7CDE2D4D5DDDD
DED5E2CEE7CFE3D7DDD1DECBE1D2D5C7C1CEC9D7C8DAC8D5D9E2D7E6D4E5D9DFDBD9DFDD
DBDBD7DADBD9E8CFDBCFE1D6DFDCE4DDDCE2DBDFDBE5D4E4D1E1D9D9D6DBD6DBD1D7D4D9
D6D0CFCCD2CED1D2DDD3DFCFDFD4DBD6DBD9D3D1D1CBC6C9C0CFC3D0C7E6E0E0E7E4E4E4
E0E5DDE0E2E3DEE3DDE3E0E3E5E3EAE9EEE3E3E1E5E1E3E5DCE5E1E3E1E1E2E3E4E3E0DE
E5DFE1DEDEE1DFE5DEE1D5D4CDCDCDC7D1C9C2BDB9B5B0AAAEA69DA3A6A5AFB8BDBCC7BC
CBB6C3B9B4B6BEBCB8BBBFCBC1C5BFC6C9D3CDCDCDC7C4C8CED0D1D1CCCFD0D4D2C8C5CE
D3D3D3CFD3CAD0C8CBD0D6D8D3CFD3DBCED3CADACBD9CFD7D8D2D4D1DAD4D6D2D4D6D2D0
CCCBCBBFC3AEB693B79EB3A8BEC1CBC8C4C8CAD4D1DBC7E1CBDDD2DAD5DBD4DBDCDCD8DA
E1D5DBCFDECCD4CFD1C8D7C4E3C8DCCBD1CDD4D0D1D6CED2C0D1BFD8C2DCC7D2D1DDD4DD
CEDBD3DBDAD5DDCBCDCFD8D8DBD4E1CEE3CDE0CDD6D2DAD7D9D2D8D7CEDDC0D9C7DDC0D1
CCD3C3CBC0CFC9D6D6D1D9D4D7D3D1D3D3CCDBBFDCB6D4C4CCC0CFC2D1D3D2D4D2E3CEE4
CDDCCED8D1D8CFDBCBD8CED5CCCDC8D2D2CDD4C9CCC5D5C0D4BCD7CCD8D8D8D8D9D7D0C9
D5DFD1E9C9D8CADCD5D4C5D2C7D6CED3CED0D3CED0D3D1DAD6D5DBCEDCCCCECAD6CFDACE
D8D1D2CFCED8CAC19479615856685F8F9FCFCACED1D0D4D0D1D5D0D1D4D8D6D1D5D3D9D1
D1D2D3D3D3D4D6D8D1D0D1DAD3D8D5D5D6D5DDCED6CACDC3D1D0D1D5D1D9D3D9CFD7CBD7
CBD4D3D7D8D2D2CECED3D2D8DCE4E2E0D1D2CED0D6D7D9CED3D2D9D5DAD9D4D4CDD5D4DB
D8DAD8DEDED9DCD8DDD3D0C9C5C5C0C5CDCBD9CADCC5D7CEDAD6E0DDE3DEDDDDDCDADBE1
DCE1D7DDDEE5DBE8DFE6E3E4E4DEE3E2E1E5E1DFDEDDDDD9E1D9E4DEE1DAE3CDDECBBF81
5754566E666A6798B9E8DCE7D9E3D2E4E1E0DCDDDBDDE1D8D6D4E0CADACDDAD0D2CBDDBF
D2BBD4D2CFCBCACDCFCECDCEC3E1BEE4C4E4C4D7D3D6D3D7CCD9CDD1CCCED3D0D0CED4D7
D5C4DBC5E6CBE1D2D3D5DADDDAD4D4D7C8DDCAE7CBDECEDAD6D9D2DBD2DBD4D6D9CCCBC3
C7C6C8CCD1C4DBC7D7BCDAC7D0CED8D8DCD6DAD8D0D8CADCC8DBCED7CED6CBDFD2DAD3D6
D7D5CDD0CBD4D2D5D3CFD6C5D2BED0C8C9BCC3BACDC0CDCBC7D2CAD4BDC9C3D0D4D2C9CE
B6C8C7C2CACFCBCCCECACBCAC5C4D4C2C6B6BCBC
525B719C9AB4A9B6A8AFA7B7B6BAC1C4C6BFCBABCBB2C6C3CEC5D7C0D5C4D0CDD8DCD5D6
CDD7D7DCCAD9C0CDABA6AEC8D2D3D3D7D8D6D9DAD7DBE2DADCD0DCD3E2D7E4DCDFDDDFE0
DCE4D3E5D6E2DADCE1DFDEDFDCE7DCDBCACBD5D0D7CFC8CBE0E0EBD9E4D7E0D8E0DADEDD
DEE0DCDFD6DED0EACDE6D9E3E0DAE1D7D7E1D9DDDCDEDCD9DFDAE0D7CFD1DBD5DAD4DEE0
E0DFD1DCD3E1D6D7D7D7D5DBD0DACBD0D9D5CDC9C9C4C0C4CACED8C7D9DDE9DEE0E0E1E4
E0E8E2E7E2E4DFE5DFE5E2E4E3E1E7E6EBE0E1DEE3DFE2E6DEE9E5E7E2E2E2E4E5E3E0DE
E5DFE1E0DFE1DEE4DDE2D5DAD0D3CEC9C8CAC6BEB8B5ADA4ADA89EA2A7A9B6BBBFC5C0C8
C3C6C9CAC0BCBFBDBCBEBFC8CCD0C9CDC9CCC7D0CEC9C6CACFD0D0D1CBCECFD1D2CED0DA
CECDCDCCD4CCD3CCD4D2D4D7D3CCD0DBD8D4D2D2D4D3D5D8DBD2D3D0D8D4D9D9D9DBD4D2
CDCCCDBEADB1A3AD97ABABB8BBBFCAC9C9CED0D9D7D8D4D9D9D4D7D7DADBDDD5E6D6DFD8
DCDCD3DDD5DED5D8D4D8CAD8CED8D2D2D3CCD5CFD1D9D2D9CEC9DBBEDDC3D2C6D5D7E6D1
E4D0D9D4D5D5D0CABBCFD5DDD8DDD5DDD2DADAD4DBD5DBD8D7D0D8D8D9CCCFD1CFCBD0CC
D2CBD2BCD1C1D2D3D8D7D4DFD3DDCFD8CEDECAD9C8D0CCC6C7CDC3D1CCCFD3D5D4D8D9D5
E1D6DEDCDAD3DFCCDDCBD8D2D4C8CFD0CFD1CCCEC6CEC3D8C6D7D4D7D8D6D7DBDCDAD7D5
CFCFD8D3DAD3DADBDED4DDCADDCCD8D0D2CFCDC8CED3D0D7D5D7D8D4D8D2D0D2D4D3D1D4
CED7CDD0D0D4D4C1A26B5444464D5E7DB7CCDBD4D3D1D6D6D5D6D2D7D3DFD2DACDDAD7D5
DBDAD8D8D8D8D7D7D5D3D3DDD5D9D6D7DAD3D9CED7CAD1CFD8D5D2D2CBD2CACEC7C8CFCA
D7CDDBD7D8D0D2D2D2D4D3DCD1D9D8DAD2D9D7DAD7D9DCD1D4D4DAD6D2D2D5D7D1DAD1D8
D7DDD8D7D6D0CFCACECDD1CBCACFCDD1C9D7C3E0C7DCCBD0D8D2DDDAE0DBDADCDBDADDE3
DEE3DBE1E0E2E6E4E9DDE1D9E2DCE3E3E0E3E0DFDBE1D7E0D9DDDDDFE3E0D9E1DADACAAC
8C8F9D98A1A7A7BBDCDEE4D8E6D8E2D7DFDFDADCDADBDFD4D0D5CCD9CDDBD1D5CFD5CDCC
C1CCCBCECEC9C5C6C7C7CACDCFC9DAC8D5C1D6C3D0CDD6CAD0CECECBC4D1C3D2BDD7CDD5
D4CFC7D7CED9D1D0D5D5D7DAD9D4D1D2D1D6DBD1DCCBD6D4D7D0DBCDDECFD7CED3CBBDC3
B9C9C1CCBECFC3CEC5C9C5D0CCC8D2D4D7D0D7D5CFCDCFCCD1CED2D0D5CFD8CBDBC2D0C7
CDD1CDD1C7CBC9CEC8D3C4D0C2CEC8C5C6C4B8C0B9C6C3C9C1C2C3C1C1C0C4C6C4C2CDBF
C1BBC5B9BAC2BDC0C2BAB7B4B7B2B0A59A9B959B
696EA0B5C9C1D7C5CBC8CECFD4D4D4D7CCDBD0D4CED3CADCD6D6D5DBD4E0D7DCD6D7DAD9
DCDADBDAE1D9DFD9D3B9B9CDDCD5DDDAD7DAD7E4D3E3DDE3E3DCDCE0DEDDDBE2E0E3E3DC
DEDFDEDFE7DEE5DDDBDAE8D6DCDBE1E4E0DAD0D7D0D4C3CED1DDDFE0DAE2E0DFE2D3D4D9
DCDAD6E0E2CDE3D1E8C8DED6E4DCE2D6D7E3DBDFD7DFD4DFD9E1DCD9D1D5D7DBDADFDFE2
DFDDD3CFCED9D9D7D0CEDAD6DAD9D2D2D2CFC7C4C8C7C7CECFD5D9D1D6E0E4DEE1E2E3E6
DEE5DDE3DFE3E2EAE5E8E2E2E2DEE1DEE3DBDEDEE5E1E2E5DCE4DEE0E2E2E3E4E5E4E0DE
E4DEE2E1E1E1DDE3DCE4D6DFD2D8CEC9BCC9CEC5BCB9B4AEA2A1979DA3A6B2B4C3C3C7C0
C8BBC7C2C7BEBEBEC2C7C7CEC9CEC8CBC6C8C7D7D4CECACDD0D0D0D1D3D3D0D1D5D3D0D4
D6D3D0CDD4CCD2CBD8CECAD0CFCBD2DFD4D4CEDBD6DDD8DDD3D1D9D8DED5D9DAD5D8D2D2
CCC9C8B4BDB0BEA8B4A7C3C0C7C8D1D0D0D4D4DAD2D9CDE2D5DED7DCD6DCD6D8E2DDE3DF
D8D7D9D7DCD9D8D2DED9D8CDD7C9D6CFD7CED4CDD0D9D1D8D3DACCD3CAD8CED3CAD6DBD9
DBD4CAC6B8B5BAACABBDD2DADAD7DDD4DAD1E0D4DED6DCD8D5CED8D8D1D1C2D5C9D5CBD9
CED1CECACECDCFD4DAD6D8DCD9DBD3D9D5DEDCCDD9CAD5BBD3CACFD5D7D0D4E1DDE6D6E1
D9DED7DADADAD9D7D7D5D7D7D9D1CDD6D5D0D6D5D1D0D5D3D3CBD8D2E1DCDBDDDDD8D7D9
D0D8D4DFD7E3D8D4D6D9DBD9D9D7D3CDD0CED0D2DBDDCFCDD3D6D9D2DAD3D5D7D9D4D8D4
D9DBD8D9D4D6D0C9A26E5048464D4B7DA9D3D7D9D6D2D9DAD9D8D5DCD2DCD6D6D2D8DDD9
D8D6D5D6D7D9D8D7D7D4D4DED5D9D7D8DED1D4CCD6C7D2D6D9D6D1D0CAD3CBCFC9D1CED8
D5D7D9D9D9D2D7DBDCD9D4DBD6DAD4D6CFD6D2D3D4D9DED3D8D8DED9D4CFD4D2CDDCD3DF
D2DBD3CECFCCCCC9C8CCD3CBC7CBC9CACDCDCACFD7D4D6CDD8D2DEDCE3DEDDDFDEDCDCE1
DCE3DEE8DDE1DCE2E0E0E1DFE2DCE4E3DEE1DEDCDBDEDCDBDCD6DDDCE5D8DCDDE2D1D6C6
CAC5C6CAC8D4C8DEDBEADEDEDEDCDAE5DCDCD7DAD9D8DDD0D8D1D3D2D7CECECDD5D2D4C1
CAC6CDC3D0CBC4C4C4C4CBD0BFD2BFD6BFD5C8CEC9CACDCBC9D1CBCCCCCCD0C0C9C9D1CA
D9C9CFCAD6CCD3C8D8D4D3D6D8D5D0CFCED8C9D7D3DCD6DCD5D2D3D2D6D3D0CBCDC3BDBE
BDC4C0C6C6C7CFC3C5B4C3BEC9C3CDCED1CCD4D2CCCEC6CFC8D2CBCECCCCC9CECFC8CDCC
C1CED1D6C8C4C1C4BCC2C3BEC6C3C3B2BCB6B0A8ABACB2B1BAB4A6AEACB6ABA7A8AFAAA3
9A9F9D9C939F9BA1A2948D86908488787C767372
8097B6D1D7E0DFDCDADADFDAD5D6D4DAD7DCDDDCDAD3D9D8E1DCDEDAE2DFE1DDDDE0DCDF
D8DEDDE2D9DFDCDCD6D1D7D8D8DDDEDEE2E0DEE2DEDFE0DFE7DFE4DDE1DFE4E3E2E4DFE1
D8DEDCDFD9E2E0E3D5D9E3DEE1DBE1E3DFE0DBDFD5D6D1D7E1DDE0DCE3DEE0DDE0DDD6DE
DBE2E1E7D0DED2D6DADFDBDFE1DFDDDBDADBDDDED8D9D8E1DDDFDFD2D3D5DAD4DADAE0DD
D4D2CED1CFD4D4D8D1D6DBD4D7CAD5D1C7CAC5CBCCC8D1D3D1D5D4D4D4DDE1E5DFDDE5E7
E8E8E1E5E0E2DFE5E0E4DEDFE2DEE3DBE3DBE0DCE2E2DDE3DFE5DFE0DEE2E2E4E6DFE2DC
DDDAE1E1E0DFDBE1E0DEDFD5D7D4D9D6CEC8CDC3C4B1B0ABA9A49E9BA0B1B2C1BCC6BFC9
C1CFC8CDCDCAC4C3C6C7C9C6CCCBCBD1C9CBD5D0D5CBD7CDD5CECFD2CFCFCBD9D2D3CDD4
C5D8CAD6D2D3C6CECED0D6D2D2D8D6D8DBDAD5DCDCD8D9D8D7D9DFD3DDDADED3D4D7D1D5
C6C6BEC2A4BDA6C3B0C9BED6B9C3D0D8D8D5D4D5D6D4D4D8D6D2D2D6E3DDE0DBE2DAE7DD
DCD1DBE1D7E0D7E4D4DAD2D8D3D5D7D8CED2D6D9D8D6D3D1D5D7DAD4D7D6D8D4DCD8E4D8
DBC8B8A8A5A19A969DAFC7DCD0D4D0D6D6D8DDDDD9D7D9D1D1D8D4D3D3D1D0D0D1D1CFCD
D9D6D4CECEC9D3C7D4CDDBD9D6D7D2E2D8DFDDDCD8D5D7D0CDCECECED1D5DADDDAD8D8DA
DEE0DFDDDDD5D9D9DDD3D8DEDADADBDED5D9D2DAD4DADADEDDD9DDDAD7DEE1DCD7D7D9D9
D4D8D6DDD7DDDBDFDAD9DBD8D9D4D4D1D4CCCED7D1D7CED0D5D9D8CED9CED6D1D7D6DBD9
D8D9D2D3D1D5CDC495655051504B5976B4D2DEDDD8D6D7D3D6D6D1DCD7DDD5DDD5D7D6D5
DAD0DAD7D8DBCFD7D1D4D0DED1E6D4DDD4D0D2CFCBCCD3D3D3CDD1CACBCBC9CDD3D3DBCB
DDCDE0D7D7D8D8D4D9DBD5DDD2DACFDCCBDAD3DDD6DDD9DADFD8D9D9D8D5D5D0CED0D1D6
D8D2D7CDD1C0CBBECFCAD5C5C8C6CCD4C8C9BED3C4D5CFDBCDD4D6E1D9D9DBD7DCDFDDE8
E1DFDBDDDDE2E8DEE5D8E0D5E0DFE0E1E0DDDFE5DBDFDAE4D7DED9E2DAE3DBDED7D8DBD7
DFDCDBDCDCDCDFE4E0DDE8DCE8D7EAD8E5D6DDD3D6D8DAD8C6D9C8DBCADAC4D5C8D1D4D5
CDCFCCCDC8C6CABFBDCACACCCFCCCCCDCBBEC9C4C7C1CDCBC6CBCACBB8BCAFC0B9D2C1D7
C8CCC3CBC8D7C7CFD7DCD9D6D6CFC8C8D0D3D6D3DACCD5CDD5D2CECCCBCAC6C3C7BCBCBB
BEC0BAC0C1CDBEC8C2BEC6C4B7C2C8CBCEC8C3C6C1BFCCC7C8C0C8C3BEBEBFC0C1BDB6B1
B4B3B7C0B3A9AEA4A8A4B0A4A098989496968D8E8C858985947F86748778847385787A7D
7472726966666261625B565B535550544C4F494B
93A5CDD5DFDBE7DFE5DBD8D3D8DFDDDFCFD8D5E1DBE0E1E3DFDBDDD9E2DEE1DDDADDDAE1
DCE3E1E4DEE2DDDCD7D3DADADDE1E0DEE0DFDEE2DCDDDFDEE4DBE1DAE0DEE2E0E0E3E0E2
DBE0DDE0DAE1DFE0DAD9DEDAE0DCE0DFDCDDDAE1DADBD8DDE0DDE0DCE4DFE2DFDBD9D2D9
D5DAD8DCD7E4DADADDDAD5D5DBDBDBDBDCDDDFDFDADDDDD6DBD7DBCBCECDD2CED8DADFDB
D5DAD1D8C8D2CACFCACECCD3D5D2D0C8CDCDCBCECFCED4D8D4D5DBD4DCDBE4E3E3DFE4E5
E5E5E1E5DCDFDEE5E2E8E5E7E1E1E1E2E1E2E2E2E2E3DEE4DEE4DFE1DCDAE2D8E8D7E6DD
DCD9DFE0DFE0DDE3D9DFD3DCCDDDD3D7CDCCC8CCC4C0B7B8B0A7AA99AAADB8C2C8C2CFC6
CDC5CFC2C0C1C0C0C1C4C9CDC1D1C4D9C9D8D1DBD7D3D4D7D2D9D0D6D4D1D3D8D9D3D3D6
D0D5D8CDDBC9D1CFD1D3D8D4D4DAD8DAD6DDCDE6D7E5DCE2DCDFD9D9D6DEDBD9DBDDDBD3
CECAC5BDBAB6BCA8D0BACBC1C7CED4D6D6D7DBDED5DCCEDCC9DDD3DCDCDCD7DFDAE0E6E3
E2D6DDE1D8E0D3DADAD8DBCFDACAD9D3C9CED3D4D4D3D4D6D0D6D1DAD3DFD8D9D3D5D8D9
D0CBAC9C8C8A85828AA4C3D6D2D3D4D2DAD4E0DDD9D5D6D0D0D5D2D3D4CFCAC8CCD2D8DC
D5D3D4CFD2CED9CFD3CFDBD9D7DBD6E1DAE0DCDCDAD7DAD4D6D5D5D5D8DBDDDFD8DADCDC
DBDCDFE2DCD7DAD7DCD3D9DDDAD8D9DBD3D8D2DCD6DBDADDDBD6D9D7D7DCDEDAD6D6D8D9
D6D9D7DCD5DBD9DDDCD7DED1DBCED4CFCAC9D0D7CDD2CDD1CED8CED2D1D5D4D4D7D3D6D1
D0D2CED1CBCACDB1986466646959587CB8D1DAD8D6D5D8D5D7D6CFD8CFDCCBE3CEDFD5DB
D2CEDAD6D2D3CBD6D3CED5D3D8D9D5D7D0C8D9C9D7C7D9D2CDCDCCCFC9D3CCD1C8D6C6DD
C6DDD4D8D5D4D6D4D7DCD8DED5D6D9D5D4D1D5D6DBD9DFCEE4CFE0DADED5DCD2D0D8D2DC
D2D3C6D3C3CDCCCBC7CED0D2CECACBCBD1CDCEC8CEC7CBCCD4D1DDD8E4D4E1D5D7DAD9E3
DEE1DEE3DAE4DDE7DFE4E2E2DEDDDDDEDDDBDCE1DFDCE3DDE2D6DDDEE2E3E5D9E0D2DED5
DDDCDEE0DFDEE0E5DAE7DAEDD2E2DCDDDDD5E1DCDEDBD7D1CBCAD5C7D6C9D4D3CFCBD4C2
D0C3CDC4C7CBD0C7C8D0CCCFCBD3C8D7C5CECCCABFBDC6C5C3C6C3C6C1BBB6BBBECBC7D2
D3C8D4C2D8C6CBCCD3D9D2CED1CAC4CFC4C8C5CDCFCECFCACECDCAC4BEBBBCBFC0BCB9B5
B5B9B8B9C4C5B3B6ABABB2B0AEB5B5B3B1AAA4A6B1AAA8AAA7A6A19892939493918F8F8F
918A88918B85887B7E717770706A66626561585D5F5A5D5B5654545951524F4A49454C50
4843454241423F40433E3B4041413B403D423E3E
A4B0C0E3D4E4E0E3E7DAD4CFD6DFDCDDDDDDE1DCE5D8E1DADDDADDD9E1DEE1DDDEE0DCE2
DEE3DFE0E0E2DDDDDBD8DFDFE3E5E1DDDEDEDEE3DBDEE0DEE3DAE0DBE4E0E3DFDFE3E0E4
DEE3DFE1DAE1DDDEE0DADAD6E0DDDFDADBDDDBE4DEE0DDE2E4E1E4DEE3DCDEDAE2E0DAE1
DBDED9DDD3DEDBDBE2DBDAD8D9DADBDCDDDEDEDED4E1D2D4CDDBD5CED4D0D1CDD7D6D8D2
D0D3D6CCCDCDD3D0CCC7D0CADDCAD3C6D4D1D3D3D4D5D7DED7DFDAE2D9E5E0E3E7E1E4E2
E2E3DFE5E6E8E3E8E1E5E1E2E7E0EADBE9DAE4DEE2E4E0E5DEE3DFE1DEE4D9E4DCE3E1E3
DFDBE0DFDEDEDBE2E4DCE5D0E1D2DBD0D0C6D4C2D4BCC8BFB9BBABB1A7BEB8CABFD4BDD4
C3DBBDCAC2C3C5C2BEBFC6CED4C8D4C9C8BEDBD0DDD2DFCBDDCFD6CFD7DAD0E3D4DED2DB
D0DFC9E4C7DED2DED7D6DAD6D6DBDADDE2DDE2D9E7D6E3DBE2D9E5D0E4D3E2D9D8E2D4DB
CBDBC9C3C0CDB5C6C0D4C4C5C5CED4D4D4D8DBDBD9D7DFCCD8D1DED7E6DDE6D3E3CEE3D9
E3DBDEE0D8E0D1D3D0DACADFCADAD3D8CCCFD2D1CECED1D5D3CED6C7D7CED8CFE1D7E4C8
D9BFB1928B87868285A0C2D0CED4C9D6CED7D6D9D7D2D6D5D6D7D1D4D3D1D0D1D4D7D9DA
DBDADAD4D5CFD9D0D8D3DDDBDADDD7DFDBDFDBDCDCDADDD8D7D5D3D5D7D8D8D8D9DBDDDC
DADBDDE0DCD9DCD5D9D4DADADAD7D7DAD2D7D3DED9DFDDDEDBD5D9D7DEE0DFDCDADBDDDD
D9DCD8DCD5D9D6D9DCDCD6D6D0D2CFD0C9CAD0D3C9D3CFD2D3D3D9C7DCCAD9D0DDD8D9D4
D2D4D0D3CFD9BDB77D7264716B585384BFD2DCD8D6D4D7D5D6D5D0D8D8D6DFD2DFC9D7CE
D3D0DBD7D3D4CED7D0D5C5E1C6E0C7D5D0D2CBDBCBD8CECED0CCD6C6CECACBC7C8C6D2C8
D3C7DACDDAD4D8D5D3D7D6D8D2DFCDE6C7DEC9D5D5E0D2E2D7DFD5D8DCDFD7D7D5D2DBDA
D8CBD7BFD8BDD6C6D7C6DBBFCBC6C5CBC4D8BDD8BDDCC1D1D3DBCFE5D3E0D8D6E0E0DEE2
DBDED9DEE4DDE9D6E9CEE1D8DEDCDDDFDDDDDEE0DAE3D5EDD5E6D7E4D8E0D4E0D2DEDADC
DCDCDDDFDFDEE1E6E2DEF0D6E5CAE2D6DCD7DED9DADAD8D5C9D5C1DDBCDACAD8CBCEC0CB
C1D1C5C6C6CFD0C6C8CAC5CACAC5D1BBC6B3C4B3C3C5C9C6C6C4BDC0BFBBB4C1B3C7C2CC
CBC9C9D0CACABECBCECFC6C9D5CBBEC7C5BEC5BBCEBEC7BABABAB7B1AAA6A7A8A8ACA6A0
9DA0A5A3ACA296968A929592838684807D79767983747A6C7B6C7161666766605854575C
6158555A5755584D524448444441403F4B3F343B403C3C3C3D403B4537413C3E3C3C4043
3F3C3E41393B39393D3B393E3F3C373C3D423F3D
B79CB7C9E4D3E4DDE2DCDDD8D7DBD8DBDFE5D8E5DAE2DCDDDCD9DDD9E1DDE0DDE1E1DCE1
DDE2DDDDDEE0DBDDDEDDE3E1E3E5E1DDDEDDDDE2DBDFE2E0E5DBE3DFE7E3E6E1E0E3DFE3
DFE3DFE2DBE2DDDDE1DBDCD8E1DDDED8DEDFDDE5DFE1DCE0E4E1E4DEE2DADBD7DFDFDAE1
DADBD6D9D4DCDDDAE3D8DAD7DDDDDDDCDCDBDAD9D3D8D5C5D6CED8D0D3D0D3D0DAD8DDD9
D5DDCAD1BFD6CDD0D1D6CFD7CDCCCED3D8D3DAD9D9DCD9E1DEDEE8DDE8DFE6DFE9E2E4E1
E0E1DEE4E2E5E2E7E1E6E4E7DDE0DDE3DEE5E1E4E2E5E2E6DEE2DFE2E6DFEAD6ECD4E9DE
E5DFE2DEDCDBD9DFDDE6D0E7CDE9D3D8CFD1C7D1C4CCC1C4C3BABFA9BEB3C5C9D1BED9C2
D5C0D4B9CECCCEC9C4C4C7D1CBE4C8E0C9DDCADFD2D6CAD9CEE3D5D8DCD7DAD5D8CDCFCE
E0D5E7CDE1C5E3D6DBD8DBD7D8DCDBDEDAE7CFEED2EBDBE4DDE1D9E5D8E0D6DAE0DFE0D3
D5D0CEC3CBCAD1B7D6C2D1C0C8D1D6D4D3D5D6D4CADAC9E4C9E8D7E1E1E6D8E2D3DCDBE0
DFDDDEDED7DFD4D5D3CDDECCDFC6DACBD1D1D0CFCECFD1D2CACFC1D0C5DDD3D8D6D9D0D3
C8D1AB958681878C8DA6C7D3D0CED3CCDACEDBD3D5D1D8DCDEDCD4D6D9D8D6D6D7D9DBDC
D8DADBD6DAD5DFD9E0D8DDDFDEDBD4DCDCDED8DBDCDCDFDBDBD7D5D8DBDAD8D7DDDBD9DA
DCDCDAD7DADBDED4D8D5DAD7D9D6D7DBD4D8D3DFDDE2DFE0DDD8DCDADBDAD7D5D4D5D6D6
DBDEDADFD7DAD4D5DDD5DECCDBCAD5CFD2CFCECFC9D8D4D2CAD9C9D9CFDFD8DEDAD6D7D1
CFD0CBCDD2CBC79183576B666356668CCFCBE2D5D8D4D6D3D3D4D3DBD0DECDE5CBDBCED4
D7D2D7D5D6D8D1D4D3C8D5CADBC8D1CDD9C7DBC4E2C8D7C1CACEC8CBC0D1C5C8B9CDB1E1
B1E1CDD7DDD4D9D5CFD4D4D3D3D0DFD1DFCDD7D0D7D1E4CFEECEE1D0DCD2DFD3D1DBCEDA
CCD8C1E0C4DAC7CBCAD1C4CDC6C6C8C5C8CCD7BCD9C6CFC8D6CDE1CDE4C8E1D1DBDCDBDE
D7DDD7DDDDE6D2ECD4E2D7E1D8D5D7DAD9DADCDBDCD3E4D0E2C8D6CFDED7E4CEE3CEDFD7
DDD9D6D9DCDDDFE3DDE4DCE4D2DBD5DADCD9D8D2D2D5D7D6CACACFC7CBC3C9C9CEC3D5B8
D8BECEBCBCC7C2BAC0C4C4CFC1C7B5C9ADC2B6BBBABFBFBDC0BBB4B7B4A9BCB1B8AEC1BB
AFACBCB6BEB3B4B8BDAFA3ADBEB9AAA6A1A29AA0999C9492918E8C8B8986807B7A817B78
737179777A6B696A5C665E57545554514F4E4F524D4E4A4E464B4748434544413C3B3E43
433F40413B3B403C4039403C383B3E43503E3239403D3D403E3A3A393D3E403D3C3B3C40
433E39393A3C39383B39373B3C3B383A3C3E3C3B
C5AFA6D4D1E2D8DFE2E1E6E1DDDEDBE1DFDBDDD5E4DAE7E0DCDADFDBE2DDE0DDDDDED8DE
DBE2DFE1DDDFDBDFE0DDE1DDDFE2E0DDDEDDDCE0D9DDE1E0E5DCE4E0E2DFE3E0E0E2DEE1
DDE2DEE2DCE3DEDDE0DDE0DCE2DCDDD9DEDFDCE4DFE0DBDEDCDBE0DCE1DBDEDCDADBD7DF
D8D9D3D7D5DADBDAE0D6DBD9DFDFDDDCDAD9D9D9D7DECBD4CDD3CDD4D4D3D9D5DAD6DDDE
DBD7D3C5CFD2D5CBD4D1DBCBD4BDD4D6D9D6DEDEDEDFDBE1DFE7E1EADFEBE0E1E9E3E4E2
E1E1DDE2E3E6E2E6DFE3E0E4E6DFEADAEAD9E4DDE2E5E2E6DFE3E0E3DEE6D9E6D9E0DBDC
E6E0E2DFDCDCD9E0E4DCE3CEDECED5C9D5CBD8C1D8C2D0C4C3C9B4BFB1C4BDCAC2D7BDD5
C8E2C6D5D5CED1CFCED1D0DAD6CDDFD3D6C0D2BEC7BFCAC4DFD7E2D7D4DACFE3D4E3D8E1
D6E0CDEBC8E2DAE0DCD8DBD8D9DDDBDFDFDCE4D5E7D5E6DDDFD7E8D3E9D1DFD6D9E0D3E0
CDDBD1D9CADAC0D7C9E7D7D8DBDEDDD7D4D6D8D8D8D0DED0E1CEDBD8E7E0E8D1E5CDE3DB
DCDEDDDCD5DCD6DBCDD6C7E1C5D9D1D4D2CFCDCFD5D8D7D5CDC7D5C7DFD6E3D9D7D1E6CD
E4C6B1876A67778993ACCDDBD4DBD1E1D7DFD9D8D6D1D7DBDDDCD6D9D7D7D7D7D7D9DBDC
DADDDCD7DED8E0DAE4D7DAE2E1D8D3DEDCDCD6DADCDADEDCDCD7D5DADDDBD8D8DCDAD9DA
DBD9D5D1D9DBDED4D8D6DAD6D8D5D7DED7D9D3E0DBDEDADCDBD8DDDCE0DDDAD9D8D8D8D9
DBDEDBE1DADCD4D3D8D9D4D9D1D6D1D3D4D1D1D1CAD8D1CDD1D3D8CADECFDED6E1DCDCD5
D2D4D1D4D0DCBAB4828B818B798886BCC6D8D6D4D6D1D6D5D4D6D5DBD6D2E1CDE0C5D9CE
D3D0D2D0D1D4CFD0CDD5C1DEC4D9C5CFCACDC4D8C7DACECFD5CCD3BFC9C3C7C1CBBFD6B7
D5B8DAC7D9D1D6D4D0D5D6D5CBD9CAE6CBE3CED7D7DECDE1D0DFD6D7D4DAD4D8D6D0D6D1
D7D0DFC8E2C0D0BECCBAD4BACECBCACFBAD6BDD6BFE2C4D2CFDAD1E3CBD6D3D7D6D6D9DA
D4DDD5DBDED6E2D2E6CADDD6DCD7DADDDCE0E3DDD4DDD0E8D2E3D3DEDCDED6DED3DDD4D9
DED7D4D9DEDFDDDBD9D3DCD0DFD4DBD9D8DBD7D5D2D2CDC8C5D4C5D1BFC8B4BFB9C3B6C6
B3C6B8BDB9C1B7ADB1B0B0B9B7A1AF9AAB92A49F9AA19FA1A7A5A1A4A6A2A6B0A4A9ABA1
8D9A91A48AA998A5AB907F81878A8272706A786675646F6B5F5E5C5C5D5B56524F524E52
4E454C4D4E42474C414B4039414141403D3D3E3E3B394836453444433B3B3B3B3B3B3A3A
3E3C3E3D393C3E3D3B3B423D363F42455B473A3B3D37343837363B39413C3B37413F3C3D
3F3B393C3B3E3B383A3A383B363739393A383939
DAC5CDCCE2D7E2DCE2DEE0DDDDE1DEE1DEE2D4DFD8E1DFE0DEDCE1DDE3DDE0DDDFDFD9DE
D9E0DDE0DFE2DEE0DFDBDDD8DCE1DFDEDFDDDCE0D8DADDDDE3DAE2DDDBD9DDDCDDE1DDE0
DCE1DDE1DDE4DEDDDDDCE2DEE3DCDEDBDCDBD8E1DDE1DCDFDBDAE1DCE1DADDDBDDDEDCE4
DDDED9DDD5D9D9DCDED6DCDDDDDDDCDBDBDBDCDCDAD6D5D0DCCDD7D7D8D8DED8D9D1D8DC
D7DBCCD8CEE0D0CCCCCFC9D3CECBD0D5DAD9DEE1E0DFDDE1E3E2E9DFEAE2E7DFE8E2E4E2
E2E2DEE3DDE1E0E5DEE3E1E6E1E3E1E6E3E8E6E8E2E5E1E6E0E5E2E4DFDBE7D8ECD6E7DB
E2DDE1DFDEDFDEE5DBE5CEE5C9E6D0D7D4D7CED5CED7CFCED0CBCBBCD0C2D1CEDAC8E1C9
E0CDE6D0DCD1D5D3D5D8D3DCD4EBCFE3CED1ADB39AA39DC5C9E2D8DAE1DFE1DEE2DDDFDE
E2D6E8D1E6CAE4D3DDD8DBDADCDFDCE0D5E4CFE8D0E8DDE4DEE2DAE0D5DED9DDE2DFE1DA
D9D2D8DCDEDCE1CBDCCBDDD2DCDDDDDDDBDADBDCD7DCC9E4CBE0D2E3DFE6D8E0D8DFDEE3
DDDFD9DBD6DAD5DDE1D4DDCAD4C1D9CCD7D3D0D3D8DBD9D5CBD5CEDED3E3D5D5D2D7D7DE
D7D8AF966868778A98B2D0DED9D8DBD8E4D8DFD5DAD4D5D3D5D8D5DAD4D5D6D6D5D4D4D5
DDE1DDD7DFD8DDD6E0D5D6E0E1D8D7E2DCDCD6DBDBD8DCDBDBD6D5DADCD9D7D9D8DADCDB
D7D4D3D4D7D9DED6D9D6DAD5D8D4D7DFD8D9D2DFD5D7D1D5D7D7DBD9D7D5D4D5D4D2D2D3
D8DBD9E0DADCD4D3D8D2DDCEDCCDD8D1CED0D6D8CBD1C9C9C4D4C3D6CCDED7DDDCD5D2CA
C8CDCCD1CFCDD0AFB7A1B6ACB2B0CFC3E6C8E5D2D2CED6D7D4D5D3D6CBDAC9E0C6D8CED7
CED2D5D2CECED0D2CFCAD3C6D7C4D1C6CEC5DCC3D3BBD2C9CECAC3C8C1D1C8CFC4D3BAD2
B7D1C6CFD8D3D7D4D1D4D2D3D0CCDCCFE2D2DDD6D9CFDECCE5CCE1D0D8D0DFD6D4DBCCD5
CCDCC4DFC3D7C4CDC4CAC4CECBCACBC7C0C4D3BAD7C6D1C8D3CDE4CDE1C3E0D3D8D8DDDB
D5E0D6DDD2DDCBE4CCDDD2DADAD5D8DAD9DEE0D7DBD1E1CEE4CBDAD3DFD1E3CDE4CEDAD4
D3CFD0D6DAD7D0CCCACFBDD3BED6BDC9CDD4CAC9C5C3BAB0AAADB8A0B5989B999D99A48E
9E90A29D939A928F918D8D908C8273876F7D708070736F727674767580727F7484748065
6D6478596F687E756F5C5452505C5B45414447463E434149434444423F3F42453F3E3E43
423A3C3F3C363B423C48403F3C3A3D3E3B3C3D3B3C413D3F3B3E3B40403E3C3D3F3F3A36
3C383A3739403D3C38373C3B343C393A423635373A3A3840373E3E423E3E3A3F393B4042
3C36373A373B3835393A393C39393C3B3F3C3F3F
DDE0D6DFD8E0D8DFE0DADBD9DBE0DBDBD9D9DAD9E2DCE6E1E0DFE4DFE4DEE0DDE1E3DEE1
DADEDBDEDFE2DEE0DFDADEDADEE2E0DEE0DEDCE0DBDCDDDCE3DAE0DADDDADDDADBDFDDE0
DCE0DDE1DDE3DDDBDDDBDEDBE2DDDFDBDBDAD6DFDCE1DCE0DEDEE4DFE2DADCD9DCDEDCE3
DCDED9DEDEE1DDE3DCD5D7D8DADBDCDDDEDEDEDDD8DBD4DFD7DADBDAD7D4DAD8DDD7DEE1
DDDCDBDADAD7D1CAD0C9CFCFDFCFDCD8DDDDDDE1E1DEE1E3E2E5E0E4E0E9E3E2E8E2E4E2
E2E3E0E6E2E7E4E7DDDFDADDE7E2EBDFEBE0E8E3E2E4E0E6E1E7E3E5E0E5DFE6E2E2E2E0
E1DCE1E0E0E1E0E7E3E2E1DADBDBDCD9D8D2DCCCDED2DACFD6DCC9D4D1D9D5D8D3DFD3DB
D8E5DAE2E2D6DDD9D8D9D0DBDBDBE0DBD3AD92706A6E84ACD4DAE3DFD9DED5E0D4DFD7DC
DCE1D5E3D7DFDBDADED8DBDCDFE1DEE2DFE1E1D8DDD5E0DADFDDE7D4E1D7E4DCDCE1D7DF
D2E0D9DED1DFC8DBBAD0C9D7D8D6D9DEDDD8D8DBDEDADDD5DBD4DCDDE5E2E3D3E5D2DED8
DDDCD2DBDBDDD6DDDCDCD0DDC7D5D8D8DBD9D7D6D8D9D9D8CDCDD7D0DDD8DED8DBD1DCC8
D3BCA98F8084878A99B7D1DBD8DCD2DCD8DCD8D5DDD9D8D2D2D7D3D5D7D6D5D2D0D1D4D7
D5DAD6D4E2DEE2DCDBD7D6DBDBD9DBE1DDDDD9DDDCD6DBDBE0DADADEDEDAD9DDD8DADBDA
D7D5D7D9D5D6DDD8DCD6D9D5D9D3D5DDD6D6D0DFD3D2CBD0D5D6DAD6D5D5D7DBDBD8D8DA
D6D8D4DBD7DBD5D4D8D7D4D3D1D2D2D2D1D0D5DACDD0C8CBC9D0CECBD6D2D9D7DBD6D7D1
CFD3D1D5D0DACBD5C7D3CECDD2D9D3E6D3DFD7D7D5CDD3D3CED0D0D4D1D4D5CFCFC4CECC
CDD3D4D0CCCDD0D1CBD6C6D2C4CFC7C3C1C5C5CDC1CBCDD2D1C4C7C1C9C4C5C8C8CDCCBD
CDC0CBC9D8D7D9D4D4D4CDD0D1D8D0DED1DED4D8D3D5D0DED5DAD6CED6D8D7D7D5D2D4D3
D3D5D5C8D1BFC8C4CABDCEBAC5C2C2C6B8C5BCCCC0D4C7CBCDD1D0D7D1D0D4CFD1D0D5D3
CEDED5DED8D9D8CFD3C8D3CCD7D0D3D4D1D7D8CBCCCCC6CFC5CAC3C7CDC5C6C1BEB8AEAF
ACACAFB2B0AAA6A6A297A691A89397979FA6959593948C837C8D7A8E74856D7A71796570
576B5E6666696162615A5A56614C55474E4046464E4C464846444A454946434645444839
4742433E3C494B4B444245454C64664C4039463640383E3F3D3E3E3C3A3B3F433E3C3E3F
41423F403B3A3A3E373E383A38363A3C3A3D3F3C3D3B413444373D3B3C3A393B3E403F3D
3A393C3739413F413F3A424A3F3F3A423C39414240403C4440444A444C4345463F43545C
5146413B444845414548484A433D3D3942414440
DADBDAD9E1D7D6DDE0DDE0DEDEE0D8D8D9DDDAE0DFDFE2DFE1E0E6E1E5DEE1DEDCE0DEE3
DDE1DEE1DCE0DDDFDFDCE2E1E1E4E2DFE0DEDDE1E0E0E0DFE5DCE1D9E6E1E1DCDBDFDCE0
DDE1DDE1DCE3DCD9DED9DAD7E1DEE0DBDEDCD7DFDCE0DBDFDCDDE4E0E4DDE0DDDDDFDDE4
DDDEDADFDADFDBE6DDDBDCDFDADBDDDFDFDEDDDCDEE0E1E0DBD8DED2E0DADDDAE1D9DDDD
D7DBD7E0D7DBD6DAD7D4D3DAE1D9E2E4DFE1DCE1E1DCE4E5E2E2E2DEE2E4E6E2E8E1E3E1
E1E3E2E9DCE2E2E7DFE2DFE3E2E1E4E1E5E3E6E5E2E3DFE5E2E9E4E5E2E1E3DCE4D7E0D9
E2DEE2E1E0E1DFE6DAE2D5E0D0E3DAE0D8D7D7D3D7D7D5CED7D8CECFDBD6DAD5DCD9E3D7
E0D8E2D9E3D9E3DEDBDBD2DFD7E3D4DBC9AD7A615E6978B4D0DFDBDADDDFDCDFDCE0DEDF
E3DFE0D7E4D5DFD5DED8DCDEE2E3DFE4D7E1D7DFD5E0E0E2DAE1E5DEDEE0E1DCDDE0DAD6
D4DDD9D3D9CBD6BEDBC4E2D9E6DDD9DAD7D1D3DBD3DCD8DFD6E4DFE1DBDFD8D7E0DBDFDF
DCD8CCDAE0E1D8DDDBD6DBDBD7D3E0D6D6D8D8D7D6D8DDE1DCDED8D7D3DADBDDDAD4D7D0
CCBDA29087908A8193B9D4DCDEDCD7D8DCD9DDD8DFDDDFD7D5D9D2CFCAD0D6DBDBDAD9D9
D7DAD6D3E2DDDFD8D8DCD9D7D6D9DDDCDEDFDBDFDDD6DADBDCD6D5D9D8D2D2D8DCD9D6D6
D9DBDCDBD4D4DCD9DED6D8D5D9D3D3DAD3D3CFDED4D2CACFD5D7DBD6CFD0D5DBDCD9D8DB
D4D5D0D7D3DAD5D6DAD5D7CCD3CCD2D0DCD2D1D7CFD5CCCFC7D4C9D3D1DBD9DCD5D3D9D7
D6D6D0D1CCCECECED8D5DAD1E2D4E0D6DFD1D7CDDACED0CCC6CACFD4C7D3C6D5C2CECBD3
CBCDCAC8C9CBCCC8CCD2CFC7CAC5CABBD0C5CAC1CAC2C9BFCCC0BEC3C3C3BDC5BAD3B6CF
BDD5C3D3D2D5D6D3D7D7CED4D8D6D9D5DAD5D8D5D9D1D4CFD8D0DDD0D7D3D8D2D0D4CFD5
CCD9CBD3C5C6BDC3B2B5C1C2C6C2BFBDC4C2C8C2C5C0C3BCCCC5CFC7D7C7D5C5CDC9CCC4
BCCBC1C9BFC8BBC2B6C1C2C3B5ADAFB0ABB1B0A2A9A0A3979D8C908C9B8C9986917E7C78
7D7F817F7872757C6369637163715D6F616B5A5D5E61584E494650454C404A4741453F43
3E48444541413B3F3F3C403A433A3C3F3A443E4248443D403C3C463E393C40383A33453E
423A3C423E48424240423D35415D5C3E3D373D363B3E3C3F3B39383A3D3F3E3C3A383B36
3B443E3C363C3B403A3E3A3E3C383B3D3A3C3E3A363B3D39403C3D41403D3A3838383939
3F424A403D4547514A4754635149465A444754524B4841474B465E486F4E5747584F5558
4D4A4C454045413C3F4241435448423D4A494A42
E1E2DDD9DDDAE1DBE3DEE1DAD6DDDBD7D1DED9E5E5E8DEEBE0E2E4DFE1E2E1DBDDDFDEE1
DEE1DFE1DADDE2DAE3D9E4DCE7E0E1DFDDDDDAE0D8DED6E7E0E6E1E2D7D5DBDADDE2E0E3
DADEDAE0DEDDDFDDDFDBE1DDE4D8DBD8D7DBD3DAD4E2DDDEDEDEDEDEDFE0E1E2E0DDD8DB
DFDAD8E2DADCDAD7DCD7DDD5DCDADDDADADEDDE2D9DDD3E2D7DBD9DFD9D9DAD9DDDBE1E0
E0E0DCDDDBDFDFE1DFD6DBCFE7D4DDD8E3DEE3DDDADFDFE8DAE2DFE6DFDFE2E3DFDEE3E1
E2E6E2E5E2E1E2E8E4E1DFE3E5E0E6DEE8E1E8E4DDE0E2E3DBE2DDE6DEE5DEE0DCE0E3E1
DEDCE0DEDEE2DFE2E6E1DDD4D8D9DCD7DAD6D9CED4CED7D8D6D7D1DAD9DCDCEADBE0DFDE
D8DEE0E4DFDEE3DFDCDDD9DCDCD7DDDBCC976B5B636381B9D6DDE3DADCDEDADED9E0DEE2
D3DBD9D9D8D9E1DFDBD8DCD9DBE2E1E5D8DBD9DEDFDDE2DFD9D7DCD9E1DBDDD9DCDFD7DA
D8DFDBE2CBD0CBD6D7DCDDDCD9DADBDAD7D6D9DBDADCDBDEDFE3DDD8DFD9DFDEE1D6DADD
E2DBDEDDDEDDD7DAD9DFD8D5DDD8D9D6DCD8DEDBCACDDDE2D8DED3DBCED1CFD2CFC9D5CE
D0B0938A95937F7997BFDAE6DADEDED2E1D5DEDAD6D9D9D4D2D5D7D5D1DBD6DBD1DFD7D6
D0D8D2DBDAE0E1DDE1D7D8DBDDDBD6DCDCCEE2D4E1C6DBD9D9D7D6D2D5D5DADAD4DAD5DD
D1DCD8E1D5DAD1DBD5D3D6D8DAD7D1D8D4D8D5DAD9C8D8C8E7CDE5CADAD0D4CDCED4D7DA
C5D8CBE3C7E3D2DBCEDACBDAD1D9D0D6D2D1CACED5CFC9C7CFC9D9C0DDC9D5C7DAD2D5CD
CCD2D4D2C5C8C6CCCBDBCCDBC8D8D8D7D4DAD4D3CBCECECFD1CBCAD3D4CDD3C9D6C9CAC0
D5C7CDC8D0C7D0CBC7CEC7CCC4C5BDC9BAC0BDC7BEC7C1C6BFC1C7BBC0BEBFB7C7C1C8C0
CDC3CDCBDCD9D8CFD2D4CDD6CFD4C6DBCBDCCFD8D0D2CCD5CBD2CED6D0D4D4CCCEC8D0C9
D2C6D2B8C5B5AAA9A5ACAFABACB2B1ABA5AC9CB2A3AC9AAA9DA6A2AAA4A89FA595999697
94969C8D9F8394779481928489807F7F78747675716D666A60605D64565A525B4F564948
4A454853564D434042483C4644403E433B3E41403C3A3B3C383F383E42383A3C393B393F
3C4240423D383F423E3C3D3E3C38443A493B41393E4439423B3B3C3A3A3A3C353C3B353B
3E3E3E403C3A3B403C3C3A3C403D3C4338413A393B3B353E39403D42363C3B423F3D3C42
3B4345443D39393E363D3E393A3A3B3C3B393A3C3B393F3A3F45423E3B3C403D41414A4E
4251565A56525855595471536A52584B4F514F514847495253485463575552434453485C
40474B3F41493E3B3F3F45453F3C4A42464D5252
DDE4D6DFD6E0DDDCDDD6DBD8D7DEDEDCD6DADBDAE8E4E9F3E7DFE6D6E7DAE1D6E0E7E0EA
DBE3DBE1D3DCD7DEDBE1E5E4DED8DDDDDEE1DFE5DBDDE1DDE6DCE4DCDBD8DBD9DAE0DFE4
DCE5D6E7D8E3DADCD8D7D7DBDCDBDBDEDBD8D5CBD0D2DAD9DDD6E4D4E9DAE9E3E1DFDBDD
E0DCDBE2D3E2D9E5D4DDDADDDEDCE1DDDDDFDDE1D6D6DAD8E0D4DDD9DFDBE3D9E5D9E2DC
D8DED4E4D8E9DFE5D5DFD9DDDADED4D2DADAE1DEDBDEDCE3E0E0E8DEE9D8E5DFDFDEE3E1
E3E6E3E6DFE6DAE7D7E8E1E9E0E0DCE1E0E6E4E6E0E1E2E3DBE2DCE4E1E2E5DAE2D8E4DD
E1E0E6E2DFE2E1E8E2E4D8DDD5E2DBDCD5D6D6D6D5D6D8DBD5D8D5E0DEDDD7E1DADAE3DA
E6DFE5DEE1E0E5E2E0E2DEE2DCDFD8E0C39E64514A547CB6D2DAE4E1DEE0DBE0DBE1DDDF
E0E3DCDBDBDCE0DCDDD9DDDADCE2E1E5D8DCD9DEDFDDE1DFDCD9DEDAE1DBDDD9D9DDD6DA
D9DED8DDD8D6DAD4E2D6E1D9DAD8D7D7D9DADBDADBDEE6DDE1DDE3E1DDD7DDDDE2D6D9DB
DDD8DBDCDBDBD5D9D4DDD3D9D5D9D5D3D8D8DDD9CDCDD6D6D6D9DAD7D9D0D6D1D1CED5D4
CEB799949C989193A9C8D7D3CEDAD0D9D4D9D5D4D8D8D6D3D3D4D5D4D8D6D9CEDAD7D8CC
D7D7DFD5E4D8E6DBD7D1D6D7D8D7D3D9D3D1CADBCAD5CED4D6D8D3D9D3D9D5D8D4D1D7D1
DBD6DEDBD1CFD7D0DECCDBD5D7D4CCD4D1D6D3D8C3D7C2E1C7DFD2DFD0CCD2D9CFDAD4D5
D4CFE1CDE3CFDED3D9D2E1C4E4C1D6C9D2CCD0D1D9DCD1D8C5DAC6DAD0E7D0DED6D4D5D6
CCD8D1D1CFD2D3CDD7CEDAD8D1D5DECAD6C8CFCACFD0CDCDCFCCCDD5C7CDC7D4CAD4CACD
C9C7C8D1C9CDCBCACAC3D0BBCCB2BEBAB8B3C8B2C7AFC3BDC2BACBB6BAC4B8BCB7BCA6C7
ADC9BBD1D1D1CDC8CACBC8CEC8BFCBBFD0BFC8C2C7BBC9B5CBB3C3BCB9BBB9B2B4AAB1AA
A7ADA5A58B977F917F848684858887838174866D8B6A7B74707076697566696761635E5C
5B606A5F5D5C565B4B5E54564E494B4D48484A48464843443E423F413C403C453E463F41
433E3D4345413C3C3F44394243413C3C3C3E40403F3F4042383F3B3E3F3B3D39383A3C3B
38383B3E3A35383D3C3B3B3A3C3D3A424147403F3E4239403B3D3E3D38373A383A3F3A40
3B3B3F40403E434941413E3E413C393D3C3F3F3948424042393B404349494A49483F483D
4239453F403F473F3E3741403E3B3E45454041474242444745493E423F433B4840514E56
47504F514E4A4C4542454B524E564F564B4E444C3D45424E4E404B4C4B454D424546474F
4744524C444D46474C4C504F4D51556359726B71
DCDADFD1E1D5E3D8E2D8DCDAD6D8D6D6D7E1CEE0D3E4D7EAECE7DAE2DBE3DADADDDEE3DD
DCD5D9D9DFDCE4D2E2D2E5DBDEDADEDDDDDFDCE1D9EBDAEED5E8DCDFDFDBDCD8D8DEDEE3
E1DFE0DBE5DAE2DAE7DDE5D6E3D2DDDADAE1CEDBC7E0D9E4E0E4D9E5D7E3D9DFE1E2E0DF
E1DFDEE2DDDFECD7E4CEE2D9E1DFE4E1DFE0DCDFD5E3D2EBD6E8DADCDCDDDCE0DCE2DFE2
E1DDE3DBE5DBDED8DDD4E2B6CFB1C7C1D3DAE5E4E4E4E0E5DBE7D7EDDBEAE0E5E0DDE2E1
E3E6E3E7E3E3E8D9E1DDE6E1EAE0ECD8EDDBEAE2E3E2E1E2DCE4DCE2DAE5D8E6D7E4DFE2
E2E3EAE5E0E1E2EAE8E0E6D4E2D6DED4DDD7E1D0DECFDCD7DFDFD8E0DEDED7DFD9E0D6E6
DCECDFDEE1DFE4E2E2E4E0E4DEDCE1D2C88F64434F5F87BCD4D9E3E0E0E0DBE1DDE2DCDC
DFE1DBDDE0E0E1DADEDADDDBDCE1DFE4D8DCD9DEDFDDE1DEE0DDDFDAE0DBDDDAD7DCD5DA
D9DDD4D7DAE0D4E1D6DDD7D7DAD5D1D3D8DCDBD8D6DFDADED1DCDAE1DDD8DDDEE4D9DBDA
DDD9DDDEDBDCD6DCD4D5DBD3DACFDACFD7DBDDD8D3D4D7D6D1E0D0E2CDDFD4D6D6D2D9D1
D4BEB0AEB4ADB2BAC6DADED0D0CDDECEE4CEE0CFD9D5D2D4D6D6D5D5D2DFCFDEC5DBCACF
D3E0D1E2D0E0D7D9D9D6D8D4D1D2CFD5DCCFD8C9D9CCD6CBD2CED6CED8CED4D0DCE2CFE5
D0E5D1D6CED6C9DDCBD6CDD5D1CEC6CDCBD2CFD2DBC4D6CBDECDE4C8D0C4D4CDD1CFDAD2
D0D4CBDCD1DDD2D6D0E0C3E1C2DAC5D0CDD5CAD4DBD3DAD7D3C4E2C3DFC1DEC9D9D0DACA
CFCCD4D0D0D6CED8BDDCC9D5CCD9CADAC7D5C5D0D9D6D0CBCAC7C7CCD1C8DBBED4B4C5B9
C4BFD1C1CFBFCCC2B9C0B0C9ACC1AEB7B0BAA2BC9CBAA7B6ADB3AAA5A7A2ACA2B29BB295
B68EACABB3B4ACA8A7A3A4A5A0A698AE99A7949A979C869F869B87918D8B8885887C817C
8A788D5F74525E5A595A59575553504E4D4A474D494D4A484542493B4C3E45424647413F
3E444C46424451403F3F433F3F3E40403D3E3E3A3D423F3E3B423F3B40413E423D3F3E40
423F3D3E3F3E3D3D3C41393F4245403C3B3B3B3B3A3A3B3C3E3D3B3D3A383D38403B3C36
3D393D3B403A3A3F3F3F413D3C413D453C433E4241423A3E3C3E3F3D3B3A394036443D43
4041494949404447494946474A4641424A4C484854514A4A44473F5350615555504D424A
3C463F404346424243424046433E4049493F3F47494545424643404C4744413F42434646
4A4A424346484C474B404F44544853575952534A4F4A54575C5A57675F6E6F736F716885
6D827D88828885868A8B8E8D9D96B0A3BBB4C3BA
D6E1D0E1D2E2DADBDDD2D7DAD9DBDADDD8D6DED5E7DAE1E4EEDEE8D5EDD7E9E3E1E7DAE8
D5E4D9E0DAE5D4E2D1E2DFE3E3DEE1DDDCDEDADDDBDFEED6E8D4E8D9E2DDDED9D9DEDCE1
DCE6D2EBD6EADDE1E3E2DCE2DCE0DCE2E4E1E7D7E0D8E3DEE1D6EACFECD3E8DDE1E3E2DF
DFDFE0E0DCE9D3E7D0E7DDE4E4E2E6E1DFE0DCDFDDDBE8D6EEDAEAD9E5DAE5D1E1D4DFDC
DBE3D3EAD5EAD7DDD7DFC4C899A28CA5C5D3DFE1E2E1DEE2E5DEEAD7EFD5E7D9DFDBE0E0
E1E4E2E7D7E5D9EED8F0E1E8E2E5DBE7DEECE5EAE4E2E0E2DDE6DDE1E4E1E9DAE8D4E4DA
E1E1E8E4E1E2DFE5DDE4D6E3D2E4D6D9DBDBD4D8D2DBDBE1E4E4DCE1E0E1D9E0E0D9E2D1
E6DBE7DDDFDBE0DFDFE0DCE1DCE1D8D7BA8D5E484B608BC1DADCDDD4DDDED9E0DDE3DBDA
D8DCDADFE1DDDCD5DED9DCDADBDEDCE2D9DCDADDDEDCE0DDE3DFE0DAE0DADDDAD8DCD5D9
D8DCD3D5D3D5D6D6DBD3D8D2D9D4D1D2D6D9D8D6D7D4DBCCD8D1DBD6DFD9DDDDE4DBDDDB
DDDADBDDD6DAD4DCD4DBD2DECCD7D7D3D4D9D7D2D4D9DBDBD9DADDCFD9CEDACFD8D3DACC
D9C7CCCED6CDD2D4D7E0DDD4D2DDCFE7CDE0D5D3D5CFCDD2D5D3D1D1D1D0E1C8D8C3D5CD
D2CEDEC5DFC5DCCDDDD6D4CCCCD1CFD2CDD9BFDEC0E6CED6D5D7CFDACED7CFD5D8CEDDCB
E4D0DCD1D8CDE0C8E1C3D7CECFCDC6CDCBD3CFD0BFD6C1DFC8E0C6D6CCCBCEDDCAD8D5D2
DACFDCCEE0CAD4CEDCD3DCC4DBC1D6CBD5D0DAD2D6DDCFDBC7DDC7D8C8D9C1D5D8D7D1D3
C2D2CBCED0D1D0C1D3BCE0C4D0CADAC6DDC0CBC7CDCAC6C4C4C3C3C5BAC4B0C7A7BDA7B0
B1B9ADB7A5B5A9AAA596A794A38D9C8D968592799A8392828E8A8C807E827E7F79826F8F
6E826E817E807675726C706D6D5E75597955685A6F60665566525C5357535252584C524E
48473F4438483C463F3F404141403F3F43403E463F48464142433E3D3F3F3A3C4344413E
3C3F413D4241543E4538403D3E41413D3C3E3E3A3E403E3D3D403F3C3C3B3C3D3C3C3E43
403F3E3C3C3C3B39373B39393C4243403D3C3B3C3D3E3F40423B3B3F3A3C4342423D3F37
3F3A403E45413E413F40464246454B42463D424041403B3D3D3E3D3C433747384139443F
444F4F5E4B4C3D424948434247443F3F494A4A46524A46434F464A44575358504B423F3A
4240413B454D3F47434638424A47494E4E48484E4C494E434E494C5951525256575B5D5F
585C616B757B7C79747C6D8C7796899B9A9B8F9C93A5A2ABADAAB4ACBBB4BFBEC8BBCDC1
CBBEC8C4C8C9C4C3C4C5C9CACAD1C9E4CEE8D8DC
D9D6DFD1E4D5E4D8DDD3D9DCDBDDDCDED7E1D1E9D6E7D4DFE1E3DAE7DAE6E4F1E7DFDDD6
DEDADDD9E1DFE4D3E2D4E6DEE1DEE0DCDCE1DFE3D8EBDAEAD1E5DADBE2DEE1DCDCDFDCDF
E0DEE1DAE8DBE7DFE3DAE5D6E6D4DFDBD7E4D6EAD3EBDDE6DDE4D7E7D5E6DAE2E1E1E2DF
DCDDDFDFE7E1EBD3E8D1E6D8E6E3E5E0DDDFDCE0D9E7D3E8D4E9DCDDDBD9DADCD8E4DDE4
E2DCE3D8E4D9DFD9E2D3DA9F996E7F8BBED1DBDEE0DEDFE3D9E4D0EBD7EBDDE1DFD9DDDE
E0E1DFE6E2DEEAE3EDDEE4E1E6DBE8D2E9D4E4DBE3E1DFE2DFE8E0E3DCE7D8ECDAE6DEE3
E1DFE5E4E4E6DFDFE7E1EBD5E4D2DACFE4DAE2CEDDCDDBD5DCE1DCE5E3E3D8DADCE4D5E1
CFE3D9DFDFD9DDDDDDDCD7DCDADDD2D1AE7C58504B658FC0D7D9DBD5D9DAD6DEDCE2DBD9
D9DEDCDFDBD4D6D3DDD7D9D9D9DBD9E0DADDDADDDEDBDFDCE3DEE0D9DFDADDDADADDD5D9
D7DBD3D7CFD3D5D7DCD3D8D2D9D8D8D6D6D7D8D9D8DED5DCCFDCD5D8DED8DBD7DED8DBD9
D9D6D3D5CCD2CCD6D7D3D9CED3CADCD1CDD1D0CED1D5D7D7D2DFCBDFC7DBCCCECFD6CCD6
CED7D2DEDBD3D8D6D7DBD9DDE0D7E4CEDCC7DBC8D4CECDD1D2CECACACDD6C5D9C4DBCBD1
CDD8C8D8C7D6CED0D5CDCCC8CDD4D0D0CFC6DEBADDC1DACBDBD2D7CDD8CBD5D5D1DBCEE3
CDE0D0D7C8CFCADDCCD6C6CECBCCC7CCC9D0CBCBD0B4D4C5E1CBDCB9D3C9D4CBCFC8DAD1
CDD3C8DECAD8CBD7C9D2BAD2B8D0C7D0C9D5CAD1D4CBD3CED0BDD7C2CEB8D1BFCCC5D4C4
C9C0C2B9BFBDB0BBA4C6B2B2A8B1A0B7A2B19EAEA3A2A2A09E9C9A97A0919F839D808E7F
8F8A917D8E80877B76756D79667268655A5D4E635767504E565555504D504C4C41405143
51404C4648494345444148444A474548464440414A463E4441454144413D3D3F463B413E
453F4A3C443D45453E3D3E40403F3F40403C3940373F3B353F423D4041443D404243423E
3D3E3C3C3E38473A4335393C3B3E3C38393E3F3E3E3B3B3C3E3B3D403836373939383B40
4644413E3E3F3F3E4041433C3B42484A3A3A3A3C3E4143443E3D43423E44494541474C44
3E38424A464742433E3D484448444A41483C403A3B3A3D3E43464647474347493D464346
47455E5061424C434D4D4643484844444149454E494F474B4E5047524C5951545351534F
57565B5C5C5F715B7757656A787A7C7C7E81848685948F998C9E8E9B94A299B39EB6AAB6
AEB1B8BDC1C2BFBFC3BBCFB6D3BED4C7D6CDD2C4D2CAD4CED2D9D1DCD4E1D9E1D8DBDAE3
D1E7D9DFE2DEDDDBD9DADCDDDDD2E7D8EFDAEBDC
D6E1D3E3D6E4DCDBDAD3DADCDDE2E1E2E1DBDFD7E0D4D7D5DAD5E6D4E7D6EDEEF2F1DEEA
DCECDEE1D9E5D4E5D2E4DFE3E0DEE1DCDCE2E0E2E4E1EED7ECD7EADAE1DFE2DFDFE1DDDF
DFE9D7EBD6E6DCE1DDDDDCE3E0E2DFE3E1E0E6DAE2DCE3DEE6DBECD3EBD3E4DAE2DFE0DF
DAD9DEDFD9EADCEED7E6DDE1E5E2E4DFDCDFDDE1E3DDE7D3EAD4E8DBE1D7EBD9E8DDDEDC
DAE2D4E6D3E6D9E2D5E1BFAD68786385C0D7DEDFE1DEE1E5E0DBE4D6EBD5E5D8E0D9DDDE
DFE0DDE5DEE4D8F0DCEBDFEDDDDFD8E2DBE5DFE2E3E1DFE3DFE9E1E5E4E2E9DFEBD6E2DA
E3DFE4E4E7E9E0DFDFE6DCE6D7E5D8DAD8DAD7DCD8DCD7D7D7DCD8DEDDDFD7DBDBD9E5D4
E1D4DED6E1DADDDDDDDBD5DADBD7D0BDA462534C50739EC8D8D7DAD8D7D9D6DDDAE0DADA
DADDDADCD8D3DADCDCD4D7D8D8D9D7DFDADDDADDDDDADEDAE0DCDDD7DDD9DCDADADED6D8
D5D9D4DAD3DCD3E1D5DAD5D6D9DCDEDCD8D7DADDD6D8E2D4D9D0DAD8DAD5D7D2D7D2D6D4
D8D4CFD4C9D3CBD5D1D6C9D0C3CED0D0CCCDD1D3D1D1D1D1D5D5D7D1D8C7CBC0CBC8D7C2
E0C4DAD4D4CAD3D4D4D7D3DFD1DCC9E0C8E0D7DAD9D7D5D4D2CFCCCCCDC5D5C1D9C6D8D0
D5CEDCC2E0C6DECDD4CDCECED3D5CDCBC6D4CBD8CADDD4DCD9D7CDD7CCD2CDD6D3CCDDC7
DCC4D2C8BDB6D9C7E5C7D3C9CCCEC9CCC7CDC8C8B4CDCADEC3D3BFD5C3CBC7D5C6CAC6C5
CEC8D1C4D0BFC8C3C4B5C4A6C1A2C0B1BBBAC1B8B9BDAEB5A5B49BB6A1B8A0B1A5A4A1A6
97A396949C9694839B839C818B80867082697372777779766F6C69625F654E68506B545B
4D564756485744474541433F4240433D423E433C453D423D3E493A46433D483F41484645
3E42403E4342404240404542463E423C453C41403D3D38413D43404542414242483D443F
433B463B443A433D424342403F3F3E3D413F3D433F423D3B3739403D4A4142404646463F
40413E43403B404347423C47494A443F40434447454043434640454A413F3E4643444349
504A43414244474A4D484C424043494C4545464646464748434C554B444A474047504D4F
3F42434D45494447423F4B4340474B4B434142464542484246454546454847514050464E
515C4F6B4F624E5A60625D5B626666686D6284608E6A8B7E85839088978C969193A2A0A9
9DA7A7B7A8BDA8C7ADC1A7C0BDC1C1BDBDC3C6C6C6C3D9C0D3C6D2CBD1CBE3CBE5CADED5
D8D4D7D6D6DADBE3D6E2D5E2D5E5DCDADADCD6DCDBE6E3E3E7E3E6D9E3DBE2DEE5DDF0D2
E5DAE8E1E3DDE3E3E1E1DFE0D1D9CFEBD8E9DFE1
DADCE0DAE5DBE4D9E3DDE2DEDBDFDBD8DEE1D6E8DAE7DBE1D8DEDDDFDAE1E3E9EAE7E4E0
E0DEDDDBE0E3E2DBDCD5DCD6E1E0E4DEDDE0DBDBDBE0D6E1DDE4E1DEE1DFE3E1E1E3DFE2
E1E3E2DFE1D9E2E0E8E1E9DFEADBE2DFDEE6DBE7D9EBE0E3DDE0DBE3DCE5E1E4E5DEDFE0
D9D7DDE1E6E7ECDEE8D9E6DCE4E1E5E0DFE1DEE2E4E8DDE7DDE0DFE1DEDAE3DFDFE6DCE2
E1E0E3DCDDD7DADADCD3C384635B6E8EC0DBDEDCDCD7DBDFD7E0D4E6DBE6E0E2E3DBDEDF
E0DFDDE6E5E2E4DFE2DEE3E4E5DEE8DAEADBE4DCE4E2E1E4DFE8E0E4DDE3DBEADFE1DCDF
E0DEE2E1E2E5E0E1DFDEE5D8E0D7DCD6DBD7E0D6E3D6DAD3D7DDD6DAD7DDD9E0D9DFD9E2
D9E3D7D4E1D8DADCDCD9D3D8D5DDC4C49C7863646286B0D4E0DBD9D4D8DAD7DED9DED9DA
D7D8D5DBDBD8DDDFDCD4D7D8D9D9D7E0DBDEDADDDDDADDDADBD8DAD6DCD8DCD9D7DDD6D8
D3D7D3DAD9D8DBD2DACDD9D4D6D9DBDBD8D7D8DAD0D7D4D7CED6D4D8D7D5D8D1D5CFD3D1
D6D3CED6CDD8CDD6CFD1CCC4CCC7D0CCD0CCD3D8CFCBCFD0C7CDC0D8CCD5CCD1C6D2C4D1
C9D1CDD3D6C3CED3D0D2CCD2D5D8D8CFD8CDD3CCD3D5D4CFCBCCCFD2C6CCC8CFC5CECBD2
D2D4CBCECED1D1CBD3CCCECECDCAC3C7CACBD5C7D7C9D1CED2CBCFCCD1C5C9CACCCDC7D0
C9D1C8C9B3B5C0C8C7C7BDC0BFC2BBBBB3B9B7B8B5A2C4A8B7A0B5A7AAAEACA6ACA1ACAB
A7AC9AAD9AB09D9F919B82A17E998A918E989090918987808D6F8C6D8C68866D73686C60
656669625C5855544E5B4A524C51434D414A3E464243474641444742423C4238463D4641
3E414440463D3D404546423C3D3C3B3940403C3C3A3E42463E3C3F403C453D433E403E40
3C413F41403A3E3D393C3D3C3F3D393E3C3E3C3F43414A4247383D3C40434541463E443E
444342483F42424043474847494F514F473C513B5A3A4B43444A4F4F5149403E4B4B4D47
47463E45464E4359465840514E4D45404240404646464B45453E43443E3F3D4F4C524E56
4E453F414547494E50454D47484849474547494846454648464C534943433F45444B3D4F
3B4E4149474B464E4D4B524251555C5858535A5D5F5C67626A6E737A807A917A927F8C8A
9D93A494A993A29DA2A7A5A3AAAFB0B2A9B4A2BEA8C5B6C1B8BBBEC3C3C5C4C5BFC6D3C7
D1C6D3DADED3E1C9E4C0CCC9DDDEDDDAD8D8D9DADDDDD8E5CDE3DAE0DDE2D7E7D9E7DBDF
E3DDE2E1E1E2DCE1DBDCDBDAE1DAE2DADFDAE0D5E3DEE7E0DEDFDAE0DBE6E3E2DBDCE0DC
DBDEE1E6E0D8E0E1DDDEDBDDCECCDBDDEADAE8DE
DAE1DCE2E0E2E1DBDEDBE1DCDAE2DFDADEDCDCE3E1DFDAD9E0E0E6DAE2DEE6E0E0E5E1E6
DADFDADFD6E0D7E0D6DDDBDADDDEE4DFDEE0D9D7CBC6C9C9DCD4DED6E2DFE3E1E1E5E1E4
DCE4DCE5DADFE0E5DEDBDEDFE4E0E3E5DFE2E1E2E1E3DDD8E3DEE5DBE5DCE3E0E7DDDEE1
D9D5DDE3EDEDDEE1DFE7E7E2E2E1E6E3E1E3E0E3E3DFE2DCE4D3DEDCE6DAE5D4DBDCDAE0
D8DFDBE3D7DFDBE2D9D4B6945A636597C7E3E4E1E0D9DCE0DBDDDEDFE5DEE5E0E6DDDFE1
E1E0DEE6DDE5DFE3D9E5E1E2DFDEE0DFE2E0DFDDE5E4E3E4DEE6DFE4DFE0E1E3E4D8DCDA
DCDBE0DDDCDFDDE2D5D9D8D9D6DBD9D8DAD8DAD8DEDCDEDBD5DDDBE0DDE0DADFDDDADBD9
E1E1DDD3DED4D7D9DAD7D1D6D2D9CEC5B896948DA1B5C6D7DEDCDDD9DADDDADFD9DDD9DB
D6D6D3DCDFD9D8D4DCD4D7D9DADAD8E2DBDEDADDDDD9DCD9D8D5D9D4DCD8DBD8D4DBD6D9
D3D5D2DAD5D8CED1CACCD0D2D0D2D4D6D6D5D5D5D3D2D1CDD3D7D9D5D8D8DCD5D7D0D4D2
CFCEC9D5CCD8CBD3CED5C9C8CCCDCDCCD0C6CDD3C6C2CCD0DAD3C8CFCCC5C7CACDCDCCC2
D3C6D7D4CAADBFCCCBD5D3D4C2D2C6D1CBD1C7C9C2C7C6BFBCC2CBD0CDC5C9C1CFC8CEC8
D0C9CCBDD1C3CFC0C9C1C3C2BEBBBAC7B4C0B0C5B6C7B3BEB9B6B7BFBBB4AFB2B7ADAFA6
B3A8AA9FA298AA99A7979C9B9A9D9592888F8E917F887C906D8C798E737D7171716E737A
7666715676616C555B555E565E4F5E5254595B575A5A514F554B454B4B4D48434A424341
3F49433E42404739473C3F443D4145424B444240404145433D434A48464A404839423B41
3E463E45393C38483D433C373A3D3A3D3838393C40413F3D424A3B47413F45413F3C3E40
433F3F41413A42413E45444542433A473D473E443A42474F47444045434A4D484C464E46
4B4E5D524E41535353595B585B6366625A625369595F4B5A4B5C5469555E464B52555A55
544E40455251634F604F51504E4C46454845454F51565C4E4C444743444540544E554C53
4F46444C525150545C4C57565E5B5752555A5F626264676A6E696E6E6E686A87717F6E89
6E8A7A87878B859196949680A795A08DB19FAC9AA9A4AEA4AAADB4BDB4BFBCC4BCC7B9C6
C0C2BFCDC8CFC9CDCED4D1CDCFD1CFD0D6C6D6BDDCC6DBCEDAD6DAD3DBD5DBD8D3DAD6DA
DADDD8DEDAE0D8E1D1D0C9D9E0DEDEE0DEDADADEE0D1E2E1DEDAE1DDE4D6E0CEE7D7E1D4
DED4D8D8DCE1DCE1DDE5CAE9D1E4D7E0DEDCDCD6DBDDE0DCE0DDE1DFE0E1E2D7E1DCE9DD
E8D3DDDEE2D6DCDBD6D9D8DBCBD2D5E8E1DEDFDB
DBDFE0DFE5DEE1D6E4DBE3DDE4DEDDDED7E5DDE3DFE4DAE6DBDEE3E2E2DFE1E2DFDFE0E3
DCE4E5E0DCDFE2DBE4D9DFD5E2DFDCDADCDFD3BDA3A19EBFD8E2DEDCDFE3DEE2E3DFE5E2
E1E3E1E1E2DCE0DCE0DDDFD9DFDCE2E1E1E3DFE2DCE1E0E5E0DFE4E3DCDCE2E3DCDCDEDF
DCDADCE2DBE1E0E4E3E0E5E4E3E4E5E0E2E4DFE7D9E1D9DED8DDDFDEDFDCDFDBE2DDDEDA
DDDDD9DEDADFDADAE0CAAD7D5D6770A9D6DEE1E8DFE2DFE5DBE1DBE4E0E2E1E0E0DBE1E2
E2E0DDE4E1E4DEDFD9E3E1E2E6D7DEE4E7DADEDFDFE4E5E4DCE6DFE2DCE0DEE1E0DDE1DF
DBDCDDDCDDDEE0E0D4D4D9D9DFDCDCD8DAD5D7D9DFD9D9D8D7D7DAD9DBD9DAD9DAD8DBE0
DDD9D8DCDED8DBD4D3D7D3D7D3D9C9D5C3CABDCDCCD5D8DAD7DCD9D6DBD8DAD7D6D1D4D8
D8D2D8DBD6CDDED5D5D5E1D8D0D2CEDAD7DCD5DFD3DED6DCD5D2D3DAD5DAD9D4D1D7D7D5
D2CCD5D4D7D9D5CDD0C8D2CACECADBDEE5DAD4D6CAD1C0D3C7D8CEE1CDDDD6D4D1D4D2CF
CECECCCAD1D0CFD0D0C5D4C0D4BCCECAD2CBD0CBCECABED7C9C6C0C7BECAC3CFBDCABBD4
C3D4C2D3C0B3BECBC3C4C8BCC7B3CEB6C5B2C5B6BEB8B3B3B7BAB8B5A7B99DC5A0B8A7B7
A6ACABB0A7ABA8ADA2A4A1A3A498A698A589A2899B84998B968E8B909089858779797979
74786D7A5F6B5C725F705E6D5C605957594C5A53574955514F3E4E49494848464344494E
4D4A474647464340484C463F424646484543474F504945474F4641443F43454649414243
3C3B41443D41413F3B3F38423F403E3F3C3E3E403D3D3B44464042413B3F3E3A47474440
3B3A3A41404047404147433C3F3F3C3B413E44423E403E4A4948464444474C5043433F46
415444473E3E4147404351454F3D4C414A3E51464A5252534A4B464548484452564E514F
5B5D5251455A515F4E5F5B645C64666270636D5B644D5954595C5055535A554C465A5C57
5B5C4F535359556355654C535A6057535C555F596A626E6778676C646E62656F827F817F
7C7A7F7C7D8B8D987F9782A386A290AE95A19BACA2A2AEAAA9ABB1AAB3A5B0A8B2B0BCAA
B9B0C0BCC3BDC0C3CACCC0BAB7CDBEC6B8CECDD3C9C8D2CED1D3D6DBD7D5D7DCD5D8D8D5
D5D4DDDBDFD2DCD2D8D6DCD6D2DADAD8CDD9CFDBCEDAD0DCD4D5D1DBD8D7D8CED0D3D4DA
D5E0E0DCD8DBDBD4DCCCD0CAD9DBDDD9DDDDD5DBD6E3DFDCD7DFDCE0D8DAD0DBDFD8E2DD
DFD6DBDCDDE3DFDAD5DEDEDFE0DFDDD0DBD8DEDEE5DBDBD8DBE1E0E6E0E3DEE0D8DEDEE1
DFDADFDEDFDDDDDEDBD7D7DACCCED7E2DFE1E1E2
DBE6DBEADFEAE1DEDFD8E0DCE2E0E0E4DEE2DFD8E3DDDBE0E0DCE9DBE9DBE7E4DFE3DDE7
D8E7E1E0DBE2DBDFDBE0E5E5DDDCDFE0DFDFCBAB857D92AEDCD9E6DED8DCD8DEE0DFE5E2
DEE3DBE4DDDFDEDDDDDADED9E0DDE3E3E0E3DFE4DDE2DFE2E5E3E5E5E1E0E1DEDEDFE0E1
DEDADBDFDBDFDDE2E2E1E6E4E2E3E5DFE1E1DCE3DBE2DADFD9DEDFDEE0DDE1DDE3DEE0DC
DCDEDAE0DBE0DBDDDDC7AB7D637183BCD9DFDDDFD7DDDDE1DDE2DBE3DEE0E1E0E0DCE1E0
E0E1DEE3E0E3DEDFD8E1DFE1DFD4DADEE2D9DEDEDEDDDDDFD8DFD8E0DDDFDBDEDEDBE0DE
DDDCDDDFE0E0DFDFDCDAE2DBE4DADDD7D9D2DAD0DCCFD8D7D4D9D7DFD8DDD8DAD6D6DCDC
DFDADCDCDAD6D9D5D5D8D3D6D3D7D9D7DBD4D4D8DAD9E4D6DFD1D9D3D6D5CFD7D2D7D3D8
CCD0C6E0CDD9D5D5D8D8D5D4D3D4D9DBD6D4DED3DCCFD6D1DED7E0D8DDD3DBD3D0D7D3DF
D5D3D4DAC9D6C5D3C5D8D4D3D5D3E4E4E6D7CFD1CDCCD3C7DACFD7D4D0D6D7CBD6CACFC6
C7CCC5CCCDD5CFD4C8CDBCD1B9CDBFCCC7C1C3C3CBC6B8C8C9B6C7AAC1A8B6B1B1A7C1A7
C9A7BAB0B5A9ACB1AAACAFA6A1A98BAA7CAC97B08D8E91979994897F8D828F7792718778
7D7E797B74756E6E646466686B626D615E5A61685B625B5B5350525A5C5751504E4D4E4E
4D4C4148494F4251454F404A44464442473C4640433D474B49414845414242403F3E3D3B
434342403F3F40404346423D404341423F40474F4E464347433B3D3E3D3C4141403E4042
3F3D4040403D4739453D3E403F3F423D3F3B3F3F3A3E3E43433F444539403A3F3E453C3F
3E3E3E4444444C47454846414241454E444045424042434D4A4A4A48464445454A444E43
4F51524F4E4C484B4A4F5A51514C4C524B4C4F564950474C3E4B484E4A4C4B534F434648
6654604B575766604D595B5C5F60696261665C5F5C605B665C68566D5D746E75727F7C74
7E747C7886709473957A948394979A8D9390959997A594B99EB9A3B09DA39DB5A9B7ADB7
AEAFB3B1B7B1BDBEBDB6CBBED0BCD0CCC9CAC6CEC6CACECBC3CBC4D1CAD0CFD0CCD2D2D2
CED5D9DCD6D1D4D6DBDDD0CACCDAD8CED0D0D6D3D9D1DDD0DED8DEDDD5D7D2DFD0DED9DA
D7DAD7E0D7D7D9D5D7D3DAD7D2D7D5D4D1D6D4D3D4D4D3D9DAD5D5D4DBD4DED3D1D3D4DA
D4DFDEDBCED6D0D5D7D4D4D4DBDBDCD7DBDDD7DED9E4DEDCD7DFDBDDDADCD3DEE1D9DFD8
DDD7DEDDDBE0DEDED6DFDEDFE2E3E4DAD5D6DFDDE0D7DDE0DDE0DEE4DEE2DEE0DAE0DFE1
DEDADFDEDEDDDEE0DFDCDCDFCDCCDCE0E5DDE1DC
E4E2ECDBEEDAE8D9E2DCE2DDE0DEDEE2DFE7D0E0D4E6D4DFE0E3DCE4DBE5E0E6E3E0E4DF
E1DFE3DDDDDBE7D4E4D0E4D8DDDBE0DFDDDEC79E797C85C8CFE7DFE0E2E2DEE0E2E0E2DE
DDDDE0DAE4D8E2DBE2E0E2DCE0DADDDADFE0DCE2DCE1DBDCE1DDDEDFDDDEDDD6D8DADEE2
E1DFE1E5DDDFDBDFE1E0E4E1E1E1E4DFDFDFD9DFDDE4DBE0DBE0E0DDE2DFE2DEE4DFE1DE
DDE0DCE1DBE0DDE0DEC6A67A637288BBDEE4DFE0D8E0DDDEDEE3DAE2DCDFE0DFE0DEE1DC
DDE3E0E2DFE3DEDFD8DEDDE0E1D9DEDDE2DCE2DFE1DCDBE0D9DDD8E3E0E1DCDEDEDDE1DF
DDDADADFE1DEDBDCD3DAD5E2D6E0D7DBDFDDD7DBD7DAD7D9D9D7E0D7DDD0D5D0D6D6DED5
DED4D8D3D8D4D5D2D2D3CDCDCCDDCBE5CBE5CDD6DCE0DAE1D3D8D2D9DBD2D6CFDCD1D6D2
DACEDDCCE4C5D3C2D4CCD9D3D5DFD2DAD4DDC7DFC2DAC3CBD5D8CFDCCAD9D1D6D8D1D2CC
D0BDCACDD4CED8BED6C1D4C3D3D1E1DEDDCDC5C6C1CDB5CAB7D8C5CDC1CBBBCBBEC6BABC
C0BDC0B5C2B7BBB9BEAAC09BBE9AB5A9ACA9A6ADB8B1A7AC9DA08AA2829E8291818D749C
74967A87777578797575716770696D575E565F675F5B58575959565258544E4C524E4F45
4E4C46494648403D433E4342453E4239434648483F463F44454343464846424044444844
47403B4145473E443F41393F3F3F4240463F433E3F40414741433D3E3E41413F4144433D
3A3E4242403D3E3F40423E3C41423F403F3D4044423C3B3F423C4242423C413F3B3F3E3C
3D3C3B3C3C443E4539453845474A494A41413F423A444649464247454345454446404043
3D3F3D403F4048444444534854415058554D4F454541444A4E4D4B474444464849494A47
47504E504F4F48494E535751564D5F4963465B5E5F5D5F51595A696A62615F646460696F
6D7F65806F927081748178867C8C888895829B7E9580A1909D93A48EAD91ADA2ABAAABAD
A6B9ACB8AEC1A8C2AAC9ACC4BDC8BBB8BEB3C5BED1C9DAC9DAC1CCC5CDC8DEC8DDC4D5CE
D2CDD8DCD0DCC8D9CFE2CEE2D7E5CCDEE1DAD8D9D3D9D7D6D7D0DCCAE1C7DBCFDAD3E9CB
E3C9E0D7DAD4D8D9DCDCCEC8C9E4CEE4C8E2D1D7DED9D5D5D4DDD6DADCD7DBD7D8D5DAD6
DCD5E1D1E0CBE0D4D8D2DAD9D4D4D2D3D1DCC9DDC8DECCD9D6D8D3E0D8DDDAD4D2D4D4DB
D3DCDCDAD6D6D9CEDECCD6D1DCDADBD6D9DCD9E0DBE4DDDBD8DFD9DBD8DBD5DFE1DADDD6
DCD8DFDCD8DCDDE0DFE5E0DFDEDEE0D8DDDBE1DBDCD2D8DBDEDFDADFDBE1DEE0DDE1DEE0
DDD9DEDCDEDDDEE1E0DDDDE0D3D5D3E3D7E0DCE0
DBE9D6EDD7ECDFE2E4DFE4E1E0DFDBE0DFDBDED1E3D8DFDDE2D8E7D2E9D5E7DFE0E6DAE9
D7E7DBE0D4DCD4E3D6E0DCD7DFDBDBD7D4DAC69B786A9ABCE7D4EBD9EAE8E3E3E3E1DFDB
DCE3D7E5D9E1DCDDDDDBE0DCE2DCE0DDDDDDD8DDD8DDD8D8DFDDDFDFDDE0E1DCDFDEE0E2
E1DEDFE2E1E1DADDE0DFE2DDE0DFE4E0DFDFDADEDFE5DBE1DCE1E0DCE1DFE2DDE3DEE1DE
DFE2DEE2DBDFDDE0DBCAB59B929DACCCDBE3E1E3DDE4DCD8DBE1D9E2DDDFDFDFE1E0E2DB
DCE3E1E1DEE2DEE0D8DDDCE0E5E0E2DCE1DDE1DEE2DEDDE0DAE0D9E2DDDFDADDDDDBDFDB
E3DDDDE2E4E1DDDED2D3DCD8DFD9DEDCDFD3DCCEE2D2DACFD2D9D4DFD2DCD4DACED8D5D9
D7DFD8D9D8D5D4D3D3D3CFCDCFCFDAC6D7CCD6CBD8CEE0CBDFC4D7D4DADBD1DCCFD7CDD2
D1DCC6E4C7D9BDC5C4CFCBD4D2C9D2CBD3C7D8BCD6BED6CFD8CBD1BDCDBFCCC5CACDBDC8
B8BDBBC3B7C0A8C5ACC7B2BBB0ACB9B6BCB4B0B1B8A9B194B29FB0A1AAA5AD9FAC919C94
9BA1949B91988C93878F728E6A886F7B6E6F68707A7471716D5D6D536A545D545F53574D
4F474E464B4D4A47484C4A464A43513C4C3D43434845424142444545404339403C49423D
444240424344413E4139414046424641414345383E403E41484644434445434040414640
443B3E453F4241414340414A423F433E443F3F3B3B3F3A433D4C42484044433D3E464946
3F414242403E3F4043434041474745484E4A484947423E3E4644444C41424041464C463E
4143414440454A444242414C4A514B5341473F453C484B4D4C48484049454D454D3E474A
484D494946464D4A57605D68565A525E5D5D515848564F595959595857585B5D6B607654
725A7368707775767E7F7B797E88798D798C808E8A967C9073998E9D9C999AA1A5A3A2A1
AC98BBA0BA9FB597ADADB5ACB9B3BAB1ACC3A9BAABC7B3C7BCC2B3D1C8D7CDD1D6D3D2D1
DAC8DDCDD6C7DFD0D8C8DBCBE0D6DAC8D4DBD4D9D5D9D2E2D6DFD4DAD4E1CCE7CDEBD5DB
D5D4D9D9E2C9D7D3D9C9E2D2E0CCE0CDDFD9D9D7D2D6D6D5CFD7C3DDC8DACFD7CDD9D1DE
CAD9D1DBD9D4D8D7DAD8CAC3CBD4DECCDCCAD6CCE2D5E0CCDED4DDDAD6DBD0E1D1E2D6DC
D8DDD2DFCED6D5D5D9D1D9DAD5D4D2D6D4D1D5CADAD1D7D5D7CFDDD3E2D3DFD2D3D4D4DB
D3DAD9D8D4DED2DDD5DAD2D5DAD7D9D6D7DCD9DEDCE2DADBD9E0D9DAD5D8D4DCDFDCDED7
DCD8DBD8D7DBDADED8DEDADADBDCE0DADED8DAD7DED7DBDBDFDFD8DCD8E0DDDFDDE1DDDE
DBD7DCDBDEDDDEE0DEDAD9DBD8D0DBD5DFD6E3DF
E6E2EED8EDD5E7D9E1DDE1E2E1E3DEE3D9E5D4E8D1E5D4E1DDE1D9E5DAE4DBDFE0DEE2DC
E3DDE0DFE6D9E3D0E6D2E5CED9D7D8D3D0D3BC90787D8FDAD1E5DCDBE2DFDEDEE1E3E0DE
E0DEE2DAE4D6E1D9DBDAE0DCE2DDE0DDDEDED7DCD7DDD8DADCDEE1DDD7DBE1DFE3E1DFE0
DFDDDEE2E0DFD9DCE0DFE2DEDFDDE4E1DFE1DDDFDFE4DBE1DDE1E0DBE0DEE1DCE1DBDFDE
E1E3DFE2DADEDBDFD7D3D0CDD3D5D6DDD5DCDBE1DCE1D9D5D7DDD8E3DEE0DFDEE2E1E3DB
DAE2E0E0DEE0DCE0D9DDDBDFE1DFDFD6DDDADDDADBDDDCDCD7E1D8DBD6D9D7DADAD6D8D4
E2DCD9DCDEDCD9D9D2DBD2E3D1DFD3DAD0D4D2DBD8DDD5D3D7D2DACDD6CBD5D2D7D4E3C6
E4CBD9CED3D2CFCFD0CFCFCDC8D5BECFB3D5C6CBCED1C8D5C5CCC4CED4D0D8CCD2C1C9C9
D0C6DCC1DAB7C5BCC3BDC7BEBCC1B9C1B7C4AFC19DB5A8BBAAA8909D91A69AA0A2A4A89B
A3949D919F8A9C86A483928A94888B838984807F827B717974786E6C656F647B646B646E
676365555E4E524F5651564C564E544E464A42484D494E4D4B4A444B424E3F424D48444A
404A4A474044413E4246454443423D493E50444840414243444443414041413D3F43423E
47454542424142424C414643464044413C42403D434B404442413F3E4144434148474845
4F45454641494B4B48454B5A4C4648414641413E3F413F4945584D554A4F4D433E434746
514D474545474849474541454B4A4950505152524C4542434343424E4249474B484E4841
4547454747484844454A465050515C535A505959545B595D5F5F5F555B6356725B716574
6E7773706E6D747381778F6E8B70897C928892798C778A82898E959A9B99979696A789AB
84AC94A29AA5A9A7ADADA8ACAEA5B4A0B7AABBADBCB2BE9AB6A9C7BFC4BFBFC2C7CACACC
C1DBBDD8C0DCBFD2CCD1CCD6CEDBD0D1DACAE3C9D8C5E0CBD8C7DFC3EFC5E1CFDDD2D8E0
D2E7D7DECCE1CEDFD4E1CCDCDADDCCC8D4CEDCD4DED9D9DBDFDBD9D6E0D3E3C4E5D0E1CE
D9D0D9DFD1DFC9DFCCE1CDDFCEDFC9DBD9D9DAD9D3D0D7D5D5CCD7C8DEC5DAD2DCD4E9CD
E3C6DAD2D9D4D7D6D8D6C8C3C2DBC6E0C9E3D2DBD9D8D7D7D0DAD7DFDEDCDFD9DFD6D5D0
D9D0DFCDDEC6DDCFD7CED5D6D1D2D2D6CFD8C6DACBE0CFDADAD5D1D5CED7D8D9D3D4D5DC
D2D8D7D8D6D9DCD5E1D0D5CED7D4D9D7D7DBD8DBDBDFD7DADAE0D9DBD5D7D3D7DADADCD7
DDD7D7D3D7DCD8DBD6DBD8DADAD9DDD9DDD7DBD8DFD8DBDADFDED7DBD7DFDDDFDCDFDBDC
DBD7DBD9DEDDDFE0DEDAD8DAD0D3D3E6DAE4DBDC
DEECDBEEDAEBE1E4E1DCDDE1DFE3DCE1DEDEE6DCE1D5DAD9DFD9E9D8EBD7E4DBDDE3D7E6
D9E4D8E1E0DFD5E1D6DED8C9CDD4D9D7D4CCAC83857CAAC7E5D0E5D5DEDBDEDDE0E4E1E2
DDE4D9E4D9DED9D9DFDDE1DCE1DADDDAE0E0DADED8DEDBDEDBDEE0DAD1D5DCDAE1DDDCDD
DEDEE1E5DCDCD7DCE1E1E4E0E0DDE3E1DEE1DFE0DCE3DBE1DCE0DFDBDFDDE1DBDFDADEDD
E0E2DDE0D8DDDADDD9D8D8DCE5E0E0D9D7DAD8DFDBE0DBDDD4DBD7E3DFE1DFDDE2E0E2DB
D8DCDBDEDCDCD8DED9DDDADDDEDCDCD5DEDADDDCDADDDDDBD6E2D9D8D3D9D8DBD9D4D6D3
DCD9D7D5D6D6D4D2D6D5DCD6DDD6DBD8BEC1D3C8D7C9D3CCCDD0C8D1CAD6D3D8CCDCC5DB
C7DFC8D6D2D3CCCAC6C0C1BEC4BCC4ABB7AFC0B6BCB5BFB2BFB2BEBBBFC4BDC2AEAEA6AE
A3ABA2BA9DB19DAB9AA0919A9B90988C9E8F9D809A7F91848C7D7864786C726A6A75696D
606860585A594A6750624B5B5A4E50485253535256484B485349514D464450484F3B4D49
434B424A444C454D4549434A414A43434349434546454D4C44434645464D464641444348
424743403F43454547474442453D4540454545413F3F3E3D3C3D3F403E4241453B453C40
4442423C3E3C4142463F45474A434D4B5550574658515455544C444244484D4F58554F56
635B544B4E585454464443534F4C4B454A444A4745414A51515C5357525757504B4C4C4A
565452535554504C4F4C4A4E534F505B575A5C574F4D545D574964527059746B6B6E6E6E
7273706F7A7C6B7B7189747E70807191769485958E8E878B91959993A291A890AF91A595
98A5A29F9FA0A7A8A1AF9CB999BCA7ABA5B4A1BAA0B8ADB5B0B4BBBFC1BFBEBDBBB4C1AD
C9B6CBBDBDC6CAC5C7CAC9D1C7CEBBD4BDDCCBCCCAD8B1CAA1D5C4D5C9CBD3D3D0CEC8CB
DACCE7CBE0C3E2CAD7D1DED2E2DBE0DBCBE2C9E2CBE6CBDFD6E0CEE4CEDED7E0E2DEDAD5
DBCFE3D3E3D0E8CBE0C0E0C9DDD4DDC6CED6D3E1D8E0C8E8CAE5CCD7D1DCC9DDC7E4D5DD
D7D5D8D6DECEDEDDD8CAE3D1DACBE3D2D6D7DBD7D1CAD3D0C9D2BFDBC5D5CCD8D4DBD1E2
CFDDD2DCD6D2D5D4D5D4C8C4D3D7DECCDFCDDAD2D6CFE0CEDBD0DBDCD6DED2E2D7E3D2D6
D3D8D1DDCED4D3D1D2CCD2D1CCD0D0D3D0CED5CADDD3DAD7DBCDDECADACDDBD5D4D4D5DD
D3D7D7D9D3DFD2E0D3D6C9CBD7D3DBDAD8DBD8D8DADED6DAD9DFD9DCDAD9D5D5D7D9D9D5
DED8D5D2D8DDD7D9DADFDCDDDBD7DAD6DDDCE2DDDED3D8DADEDED8DDD8DFDCDFDADEDADD
DCD9DDDADEDDE0E2E1DDDBDED3CDDBDBE5DCE3DC
E4E5EBDFE9D9E5DBE0D9D6DBDAE2DAE0DEE4DAE7D5E0D3D8D9DDDDE2DCDDDADBDFDFDDDC
E0DBD9DEE0D8E3D8DECBD6BDCAD6DAD8D7C9A788838C9FD3D0DCDBDADFDCE0DDDEE2DDE0
DBDCDDD9DFD5DDD7DBDADFDBE1DCE0DEDDDFDADFD8DEDBDEE0E1E3DCD6DCE0DBE3E0DDDE
DDDBDCDFDCDDD9DEE1E0E3DEE2DDE3E1DCDFDEDFD9E1DBE1DBDFDFDCDFDDE1DBDED9DFDE
DEDED8DDD7DEDADDD7D8D7D8E0DAE3DCDBDAD7E1DCDFDDE4D5DCD7E1DDDFDEDDE0DDE0DB
D6D5D4DBD9D7D2DBD8DCD7DADDDBDBD5DFD8DADCDBDAD8DAD5DFD6D9D0D7D6D8D4CFD3D2
D5D7D6D1D0D2D0CBD1D2D0D5D1D5D1D1C2C5C6C7C8CBC8C4C4BEC0BAC2BFC4C1C0BDBEAE
C2B1B5B6B6B9B1AEA59B9C979A9F959B85948D8E888D7E8C7D91878E8D8A8E8684767979
76677C6E76656B63605F6162626058555A57495755655A595959494F4A54494E4A4B4A44
4C485148463C4E4153464C4A4C4449404848494A544A4843434249474347404F42494B4B
4143463F49424749494E494B434A45453E424141414245414340483D4442413E3C47434D
4650454848444445444447483E43444A464E434B454648474747494B4D46534952494A49
4E48464148484E4D4E4B4F55574957536A5E6D52655261635E554D4E505053585A5B505C
65635E595A6558604A4F44545254515157515F5B5C4F6364696C6A6D6868696A6C6C6966
676A6D7071706C6973717075776F6F7B8384837F7D818990838D7CA586A996A39E9B9EA3
A4A5A4A2AAA7A8A5ADB1ABAEACACB5B2BCBAC3C4C2C0B9BEC1C2C8C8BBC1B2D1BCD7BDB9
AFBFBEBBBBBCC3C5C6BFD0C3CFBDC5B7C2C4D2C1D2BBCEC2C8CACCCECECFD1D2C6D3B8D8
C1DECACBC9CACDC6C7CECCD3CECACACBD4CFD0D2D0C9CFAFC6C0D9D1CECFD7D4D4D8D6DC
CDDFCEDCD4DDD0D4D6D2D5D4D4DBD7DCDAD3DEDCDCD6DED8D7D7DCD1DBD0E0DCDDDBD9D6
CFE1DBDFD0E5C0E2C4E3CCDDD8DAD5C8CECDDAE0DED6E4D2E3CDDBD7DDD8E3D0DED0DFDA
D5D2D9D8D0DCD0DDD7E3D2E2D0E4D2D8DCD5DFD7D5D2D4D3D5D2D5D2D6C5D1D3DDD5DFD3
E0D0DAD7D9D5D8D7D9DAD0CDCFDDCFDBCFD9D2D6DBDADEDCDBDED9DDDADCD9D8DEDAD4D2
D6D1DBD0DBCADCD1D2CED5D1CDD1D1D0CDD5CDD8D3DDD2D9D9D2DED9D9D8D6D3D4D4D5DE
D3D7D7DBD1D8D6D8DCD4D3D0DAD5DDDDDADDDAD9DADED7DBD9DDD7DCDBDAD8D5D7DBD9D5
DDDBD9D5DADDD7DCD6DAD8DCDBD9DFDED8D8DFDDE0D8DFE3DCDFDBDFD9DFDCE0DADDDBDF
E0DDE1DDDEDEE0E2E0DBDADBD7D4D3E0DAE2E0E2
DCE5E0E5DEDFDFDCDAD2CED5D7E4DFE5DFDDDADDDCDED9D6D5D5DFD6DCD2D9D7DFE2D9E0
DBDDD4DDD9D7DBDBD4D4E0D4D0DCDBD6D7CAAD999C9FB8D3DDD6DFD8D8D5DBD8D8DDD8DC
D7DBD6DBD9D8DAD7E1DEE1DBDFD9DCD9D7DBD8DDD7DBD8DBDBDBDCD9D7DEE0D7DCDADADD
DEDEDFE2DFE1DDE0E1DDDFDAE3DDE3E0D9DDDDDDD7E0DAE1DADEDEDCDFDEE2DBDFD9DFDF
DBDBD5DAD7DEDBDDD4DADBDCDFD4DFD6D7D5D4E0DBDBD8E1D7DDD7E0DBDEDDDCDEDADFDA
D3D0CED8D7D4CED8D6DBD6D8DAD7D6D1DAD0D0D4D8D1CFD4D0D5CED6C8CFCECEC9C4CACA
C1C8C8C1BFC2BFB8C2BEC1B8BFB6B7B2B8ACA89FAFADAA9A9B9894989A9E9C9B8D947D8D
818E7B8C787F7A79716668645D5D66615E5A5F58595A4E4E46534F504D4D4D524F4E4C4F
51464E574A524743464E484A463F49474742473A463F4C4C474948424944444642454049
494746423F434747414E434542414B424645474A48484A474146494349444241423F463A
404542434445444A434647424344484742444646474A473F3D404343414A4547444E4B48
48494345423D424845424342434A50454E4948574F50505050545A5E5B4F5B525B504C4B
574C48414D4D524E4C4F535F6151625E6163696C5F605D6A5C595E6A6E6761616E756A76
777A7E85758070846E7F708070767478817A8D899880968D908A8E8F95908D92999B9692
98999A99999BA1A6A09E9FA4A49998A5ADACADB2BABDB8B2B9AEBFB8C9BCC8C0CDC3C5CB
C9C9CDCBBCC8C3CFBFCEC0CFCDD4C7D8C6D7CCD5D0D0CDD2D1CBD0D2D5CCD5D0DDD2CAAE
B7C9C8C3C4C3C9CBC7CAC1DAC0D0C5CDC0D0CCD5C8C9C7C3C7CACFD3D3D3D2D2D2CBD1C4
DFCBD7C1CFCBCEC7C8D0CCCECAD0C0D6CED2C2DAC8D3C4C9BCD7D2D4D5D1D6D4D7DCD3D4
E1DBDBD0DDD1DFCFE0D6DED1D9D7DADED3DACFE3D4E0D3E0D7E1D0DFCFDFD5D4D7DCD9D2
D5D8DDD7DFD7DBCDDBC7D7C9DCD4D6C3CED6D8E1D5E2D3EBCBDFD1E2D8DAD5D9D3D7D4D8
D5D7DDD9D9D7D8D9E2CEE7C8E7CCE3C8DFD1DFD4D7DAD6D7CFD5CEDFD1D3D4DED7D6D1D9
D5D8D5D9D8D4D7D6D8DAD2D0D5DBD9D3D9D1D5D2DCD5DDD5DED9D6D2D6DBD2DADAE0D5D8
D6D6D6D7D5D1DAD5D4D3DAD5D0D5D3D0CFD2D5D3DBD6D5D6DFD4E5D5DED5DBD7D4D4D5DE
D4D7D7DBDBE4D8E0D9D8D0D0DED8DFDFDADEDCDADBDFD8DBD8DBD5DBD9D8D8D6D9DEDCD9
DCDDDED8DBDCD7E0DADDD9DAD8D4DADAE1DBDDDBE1DBDEDEDBDFDCE1DBDFDCE0DADDDCE1
E3E0E3E0DFDEDFE1DDD7D4D5D7D2D9DFE2E0E1DD
E0E6E0DAE2DADCD7DCB890A1D9DAD9DDD9DDDDE4DFE2DBDBDBE0E1DDDDE0DBD1D4DAD0DD
D2E3DADDD9DBDBD8DBCFD8D2D6D5D9D5D5CFC1C8BECCCDD6DED7E0D3CFD3D8DAD9D8DADC
DBDBD7DBD9DDD8D7DAD9E1DCDCD2DADFD9DADDD9D9D7DCDFDCDDE1D4DDD8D8CBD5D4D7DC
DEDEE1E6D5DFDBE0DCE0E3E0DFDFDEDCDADBDEE2D8DADCD8E3DCE1D3D9DDDDD7D2D3D6D8
D0DACCD4CDDCD1D7D1D5D0D6D1DAD4D3D3D5D7D7D4D2D6DBD1D5DAD4D9D6D6CFD2D5D3D1
D3D1CFD2CACEBFC7BEC3C5C6C1C1C3C5C7C6C2BFBFBEBDBBC2B9BCB3B4B3BBA6A9A5A5A0
AA9B9B9B9A93878A828E858C818B8085797E73786B766B6B646B6258575E635953525952
56585C4D434A4E4F4F4F4C4845444E4B4746424C46423F40414143474443403E40434646
4846444241424446424041444342454B4242424840474748443E45444445424B49424541
4043414A4547504A474B4649474544525048504F4D464948504A4E4E464E474A484C444A
4D474D4E4F4F484B48454C4C444D554D404D48524D4E4C444548464A534B475654555357
4C5C4C4D444851514A484B4952465152535457605C52615E5F636E6C6C6A6B696D6B6B68
766C6A6A75656D6B6C6F767C7D7E848B7C8B7B8B808C87938A888E999B928B8B989CA1A0
A6A0A6B0B5ACB0AFAFA8ADA8ACA7AAA9ADB5B4B7ACB9ACBDBEC9BCB8BAB8BDC4C6BDCAB8
BAB6B2B4BBC0C0BEBEB4C5BCC9AAB6BCCBC7C4CBD2CECAD0C4D0C7D2C9D3C9D4C9CBD1CC
C7C9D0CDCCC9CFCCD0C5C8C8D2CBD6C7DACCD9D3C6CDD0CDC8D0C8D8C3D1CCDCCCD6CEC6
B9CACECFC8CCCCC9C6C4D0CFCCD0CCC6CDC8D3C8CEC1C9C3C9AFABCFD8D8D3D9CBD8D1D3
CCD4D5D2C7CACECBCECFCEC9C8D0CFD5D3CED1CECFC2C6BDCACBD8CDD7D6D6D6D6D8DBDD
CEDED1D9D2D8D4D9D6DCDCD5DAD6D9DDD8D9DAD6D9DBDDDADBD1DCCED5D6D9D4DBD6DAD9
D9D9D8E0D4DBD7DCD9DAD9D4D5DEDDCCCCD7D7DCD5DEDBDBD9D8DBD5DCD8DAD3DAD7DEDE
DCDED7D6D7DBD0DFD1DCD2D9DADEDADAD8D6D4D5DDD3DCD8D6D6CED0CAD1D1D5D8D4DBD7
D8D4DBD7D7D0D4DAE0DFD3D1CDE0D8D7D1D8D8D7D8D9DDD5DAD9DDD7D6D8D5DCD7DBD4D3
CFD1D3D8D3D3D3D9DAD6D8D4D4D8D6DAD2DAD0D1D5D6D6D4DBD9DDD8DEDADEDCD9DBDBDE
D3DBD4DCD6DAD7DFDEDACED1DFD8DCDDDEDCD5D9D8D5D9DBDFD9DBDCD6D4DEDADBD5E4D5
D6D7DBD6D8E0DDDED2E2D7DFD5DBD7DCDCDADBD9DFDDDEDCDBDCE0DCDDD9DEDFDEDEE2DB
E4D8E3DEE2DFDFD8D6D9D5D7D4D7D5DFD9DDE1DE
DAE6D8E2DCE5DEE0D5BC9EA6D2DAE3E8DEE1DEE4DEE1DBDCDFE1E0DCDCDFDCD6DDE0DBDC
D7DDDAD9D7DAD9D7DBD1D7D1D9D6D6D2D4D4CFD9D3E3D8E5D9DBDBD6D4D3D3D4D5D5D6D6
D4D1D9D0DAD2DAD8DDD7D9D6DAD3D5D5D6DAD8E1DCE1D9D8D6DADADBDBDDD5CCD8D6D7DB
DDDBD9D9DDDCDDD6E4DDE9DFDCDCDBDBDBDCDDDECEDED0E5CEDDD1D5DADDDAD2CBCBCED0
D2CECEBCCDC6D0CECFCAD5C0CFBDC4B8BBBDBFC1C3C5C6C5C4C6BCC4B6BEB6BAB5B9B8B8
BAB6AFAFA7A6A6A0A5969B92929191908F8B888588898A888C7F7E73717879796A6F5E5C
625F64615C584F51555D51564F5950534A4F474F46524A4A414843414042494541404743
47484D42444443424447433D464043414246454E47434040403F414547433F3E4144484B
494743403E3E3F4048474644403E40434243484E494A4845414046434448434545414445
484C5058504D504B4C5553554B484853524D534F4E4B5150564F5150545957605F5D545A
5452555654524F53564F524D454C52514B55525A5658585354595A5F6662606963656669
6371686C69686B6B64656C6F796177658575877F8079837D838791959294909996A09C9E
9A9F8EA99CAAA2A99CA0A7ACACACB2BAB3B0B4A8C1B4C7C3C0C0C6CFCFC7BFBCC0C9C4CF
C6CCC7D5CCCCC5D3C1CECBD2CAC5C7C4C6CCC9CCC2C8CDC4D3C5CEC8D0C6D0CDCDCACCC1
BCC5B8CDB6CAB9C1BCCAB7D0BCC0ACC9CAC6C3C9D0CDCBD1CAC4D1C6D6CAD4CCCBC6D5C5
D0C6D5CDC4CAC0D3C2D0C6D0C7CDCED5CED1CCCED0D5CBCFCBCECCD0D2D0D9CCD7C8D0BA
C1C3D9CAD1CBCBC9C6CBC4D7BFDACACFC6D1C8CFC8CEC2CCCBC0BFD4D0D0CDD4D2D2DAC9
D8C9D7C9CECAD4C4D3C6CEC4C6D2C3D9C7D4CCD0CBCAC2C7C1D1D2D4D5D3D1CFCFD0D1D1
D9DBDAD1DAD0D6CED7DDE4CFDBD3DAD6D1D7D3D9D4DDD9D9D6D2D5D6D1DED9D9D8D5D9D7
D7D9D7DDD8DADED6DFD3DBD1D6D8D5CACDD6D5DBD8E2D2E1CFDCD7DBD6D4D8D3DAD7DCDB
D9DBD4D5D6DACFDDD3DDD3D9D9DDDAD8DBD8D5D5DBD1D8D4D7D8D2D4CDD2CFD3D3CFD8D5
D7D3D9D5D5D0D6DAE0E0D3D0CEE0D9D8D3DADAD8DBDBE0DAE1DDE1DED5D7D3D9D6DEDCDF
D5CBD4D4D9D2DBD8DAD7D9D5D5D8D6D9CDDAC9D9D0E0D8DCDCDADED9DFDADFDDD7D7DFDC
DBDDDBE0DCD8E0D4E3CFD1CED9D5DADBDEE0DBDED9DCD5E2D7DED5DBD8DBDBE3D7DDE3DB
DDDBDDD9DAE0E0E3D8DFE0D7E1D6DEDADFD9E1D6E4D9E0DAD8DFDAE5DAE3DDE3DBE3DBE5
DEE2E2E3E2DEE0DDDBDCD7DAD8D4DFD9E4D7E6DB
DEE0E1D7E3D6DDD3DBD7CFCDE0DBDBD4DADCD9DED9DEDADDDBDBDBDADADAD7D4D7E0D3E1
CDE0D3D9D8DADADADDD6D9D3D2D1D3D1D3D4D1DAD8DCE1D5DECADDD3DEDAD5D4D7DBDBD9
D2DAD0DCCBD8D1DADCD7D6D4D8D4D5D4DCD5D9D2DFD6D8CED9D5E0D6E5D8DDD2D5D1D0D5
DADBD8D7D6D9C5D5CDDED7D5D9D7D4D4D4D3CFCCD0C7D5C3DDBFCFBFC2C8CCC9C4C2C1C0
C0C5A7B29AB3A4B1A6B0A0AD919F8A8D9E9F9D99999A948A93888B818979818181837F7D
7F79706F6D6763585D51585156565553504D4B4A5555534F52474C454749474B414B4147
47494D474445403F494C404240484144454842453F453E3D3F444245433F444445414442
433F413C4544413F40444542443E3F404243404348444141403F414549413C3E4041464C
4645434243474A4B434647444244484A56555E605F5B5951564E4A49556055484A4A4748
48474D50524E4D4A505A595956545359575557505253595A5C575B5D5E6166757670676B
686B6C6E6B666B6F746C706B6A6F70787078767B787B7D7C84898A8D8C8C898B989A9E9C
9B9F9B9DA29C9EA09A9AA2A8ABA5A2ABA4B4B0B3B5B2B9B1BBBCC0C6C3BFC4BEC7C2C8C6
D1CACAC1CEC3D0C9CACCD0D1CECCCFD5D3DAC1D6C8DBCED2D2D3D6D9D9D3CDC9D2D2DBD0
DECFD9DCE0D5E4CED7BFCFCACFCBCCC8C9CDCACDBFD4BED6BAD3C6D2D2D2CCD2D3C7D7C4
BFBDCFBAC6AFBDB9CAB7D2BBCBA5C0BDCCC8C4C7CECCCAD0CCD0BADAB8DAC5CBCACCC8D1
C6D2D0CFD0C6D4BED1BACBC5CFC7E1C0DDBBD3C9D8CCD3CCC4D4C6D0C5D2B8DABEE1CCC8
BCCFC6DCCDCCC8C5CAC1D5C1D2C7D3CAD3C1DCC3D6BBD4C1CECECED6CCCECBCECAD7C3DE
C7DCCDD0CED1C9CFC5CFC7C7D3CED3C7D5C5D1C9D2CBD8B9D1BDD4D0D5D3D0D0D2D4D4D4
D2DCC8E1CCE2D5D5D4E1DED7D2DAD6D3D2D2DBD1DCD5DCD5DED2E4CEDED1DDD1D8D8DCD8
D7DBD8DBD6E2D4E3D3DDD5D4DBD5D1CBD0D7D6DCDBDAD9D7DBD2DCDAD5D4DAD7DDD7DAD7
D9DAD4D6D6DBD1DED6DFD5DAD7DBD9D7DDD9D8D6DCD3D9D6D6D9D5D9D1D4D1D4D3D0D9D6
D7D2D7D2D4D2D9DADEE0D4CDD1E1D9D9D5DCDAD8D7D5DBD9E1DBDFDEDDDFD9DDD6DBD8DC
E1D5D2E0D3D8D4D1DBD7DAD7D6D8D5D9D9DBDAD1DCD3DBD3DDDBDFDAE0DBDFDDDCE2DDE8
D5E3D4DDDDE5D3E3CED9C6D1DCDADDD9DADED9D9E2DBE3D7E1D1D7D3DED6E6D6E4D1E8D8
DFDBDEDCDDE0DEE3D8E8D2E6D1E3D4DADFE0DCDFDBDFDBDCDEDAE5DAE6D9E0DBE1DCEAD5
EDD1E7DBE1DADEDFDEDCD7DDD6DFD2EBD5E6DDDD
DBE2DCE1DEDFDCD6D8D9DFDBE2DFE4DED9DBD6DBD5DAD7D9D3D4D8DBDBD6D1CFD2D5DBD4
D8D5D9D6DADBDDDFE1DDDCD9D6D5D6D7D7D4D3D8D7E3D2E5D2DED7DAD5D2CECBCDD1D2D0
D4CED9C8D7C5D2CCD2D2D3D2D1D0D3D6D2D2C7D4CEDDD4D5D5D6CDD7CDD6CED1D5CEC9C9
CDCECBC6C7BCBEB0C7B9C8BAC5C1BFBFC0BEB7B0A5B1A0B89BA2949D8D9599968F8A8683
8C81816B786B7672726F7A656F5D655C6164625D5C5F594F5353505751514C4E4C4C4747
4C4D494A555242453B444145434545454342434546464441463F494647414A4048424445
4A46423E3F43413F4648414041433F4247474446454744433F4341444442454246424346
47444445414647423E3F4345464345474846444649464545444345494B423E414341454C
4545434143474A4A43494C49484B4D4C58555F5F6460645D63594E494F5856514E524F54
55535A5967666564696F6F6D6D6A6B6E6E70716972757979797A828985888F9B9E9B9595
8F97979B97929EA3A19DA6A7A9ABA6B0A8ABAAACAAACB0B3C0C5C4C5BDC2BEBCC2C4CAC7
D0CDCAC8CBC4C8CECAC6CBD0D0C9CAC7C9CDD2CECECAD4CDD3D0D0D0D2D7CBD8C7D5C9CE
D6D9D1D1D0D3D6D0D7D4D4D5D4D2D2D4D4D3D2D1DCD2D6CDD7D7D6D5D4D3CFCCCCD9C9DD
CADCCCDAD4DCCEE4C7D5C2CBCAC7C9C7C8CCCACDCEC9D6B9D4B9D1C4D2C4D4CACDCFC9C7
C2D3BCD6AAC6B0C2BFCFBBC8BABBA9C9CFCDC8C9CDCBC9CED3C0D4B3D2B7D4C7D0C3D4C0
D7C5D7CACAD5BCD9B6D5C1D1C7D2C6DBC5DBCED9CFD2CAD1C3C5D2D1D1C3D4B5D7BCD6BA
CCBBD6BCD1C2CACFC4D2C0DDB9DCBDC7C1D5BFD2C5D7C0D2CECECBD3CFD5D0CFD1CADDC7
E2C0D6C8CEC4D3BDD6C4D5CCD0D9C2DEC4DFCBD4C9D5C3CCBFD4CCDBD9D5D2D3D7D9DAD9
D7CFDECDE1CFE4D0D5D6E3CEDED1DDD3D7DED6DED1DDD4D7D8DBD6E0D1E0D9D9DCDDE2DB
D9DDD9DAD5D5E0D1E1D0DFD3DFDAD8CFD1DADADFD6DCD3E2D7D9D5D9DBDAE0DBE0D8D9D5
DBDBD7DAD9DFD6E2D8E0D7DBD6DAD8D6DDD8DAD8DFD8DCDBD4D8D6DAD3D8D6DADBD7DED8
D8D1D6D1D7D6DBD9DCDFD3CCD4E2D9DAD7DCD9D6DBD7DDDEE5DDE1E2DBDEDCE0D8DBD7DA
DFCFDCD5E3D2DDD4DCD7DAD8D8D8D4D9D3E2CDE2CDE2D6DADDDBDFDADFDADEDCDCDAE4DD
E2DEDEDFDFD8E5CCE2C7D3CDD7D6DAD5D8E0DCDBD7DFD0E5D0E4D6DFDBDFD6E3D1DAD9D7
DAD5DBDDDDDDD9DFDCD8E2CEE5CEDFD0E0D9E4D4E5D5E1DAD4DDD0E7D4E9D9E1D5E0D3E7
D6E4DCE1E0D8DBDDDDD9D5DDDCD3E3D4EAD4EADA
D7DEDAE1DDDFDCD5DDD7DCD5D8D6DEDFDADBD5D8D1D4CFD1D5D7DBDEDDD9D5D4CED9D1DE
CCDBCFD3D2D4D7D9D8D8D4D3DBD6D2D2D0CED1D3D7CFD6C9DBC6CFC1CDCFCDC8C7C9C9C6
CBCFC0D0C0CEBDBFC4C6C6C5C2C4C5C7C3BDC4B9C4B7BCB5BFB8BCB1BBAFB5B1B0ACA7A8
ABACA6A09398849686948A8D787675777B7A756F6B6A72696F5763605A5E5D57504F5051
53524C524C524D4F4C524D4F454D484A4B52524C494E4E4A3C4242464247423F45443E3C
41403C3C44453E453D453C3F3E3F403F3E3F41433C3F424249404742443C443A423D3F40
4B453F3F403F414244474744474242464643434245434544424742444A4F524945424045
45413D40454C4F4C474546464749494A47464E564947484A4A484B504D47464C4F4C4E54
50525150545B5D5B51575C5B5C5F5F5B676774777F7E85806A6768737C7C7A767B83838A
8D8B918E9C9F9E9C9DA0A2A0A09B9EA1A3A9AAA6A9ADAFAFACB1B9C0B8BCC1C2C5C7C5BE
B7BFC0C6C1BCC8CFCBC9D0D2D3D1CAD1D0CECFCCCDCDD1D5D6DCD8D9CFD9D6D4D6D4D2CD
DBD0CDC8D4CDD1D9D6D2D5D8D6CCC5CBCFD8D8CED4CAD6D1D1D0D2CCCECDD1CDD1CBCECC
CED5D4D4D7D6D9CFD4CECBD0D5D6D5D5CFD6D1DBD3D5D2D0D3D3D3D2D2D0CCC8CFD0D7CD
DCD2D8D7D0C5D5C3DBC0CAC0CCC9CDCBCCD0CED2C4D3BDD8BBD6C9CFCED1CCCFD1C2CDBF
CBC3D2B9CCB4C6C0C8B9CDC1C6AFC6C5CFCFCBCBCFCECCD0C2D3BAD6B6D7C4D9CFCDC3D1
C5D2CACAD4CAD7BFD3C0D4CDD2C6E0C4E8C7D9C7D4C8D5CEC1D3C9D6BFCFB5D7B7DDCCCE
BECABED7CCC9CDCDCDC6DCC3DAC5CDC3D3BCDCBFD7B9D7BFC9C8C4D0D3D9D3D5C6D9C7E6
C5D9C9D5CACEC5D0C6D4D0D8DCD2DCCBDDCCD3C8D5CBD6B4D7C1D7D1DBD7D3D2D4D6D5D4
D1DDCFE7CBDFD7D7D6D8D5DCD5D9D5D7DBD9E0D1DAD1DBD7DCD3E6D0E4D1E4D6DDDFE3DB
D8DCD7D7D1DED0E1CEDCD4D6DEE0E1D2CEDADDDED5DBD2E2D7D9D5DADEDCE1DBDFD8D9D5
DBDAD8DCDAE0D8E2D9E0D9DED6DAD9D5DED7DAD7DDD7DADAD7D9D5DAD4DAD9DDDFDADED8
D7D1D8D3DCDADDD8D9DDD3CED5E2D9DCD8DBD7D5DDD8DDDDE3DADEDFDBDEDADED6DAD6D9
D6DAD6DDDCDCD4DBDCD6DAD9D9D9D5DAD8D8DED3DED2DFD5DCDADED9DFDADEDCDCE0D9E6
D5E7D8E3D7E3D0E3CCDEC9D2D6D6D9D4D6DEDAD9DFDBE1D5DED5DCD8DBD3E2D0E3CAE1D5
DAD4D8D9DBDBD9DFD9E4CFE4CEE2D4D4DADDD9DFD9DFDBDEDFDAE1D7E1D7DEDADFD8EAD2
EDCDE4D6E3DADCDDDCD9D5DED7DFCEEAD3E9DFE1
DCDADFD7E1D6E1D3DDD7DFDADED9DADCDADBD5D9D2D7D3D5D0D1D2D1D0D1D1D1CFD0D7CE
D5D0D5D0CDCED1D2CCCEC7CAC8C3BEC3C1BEC1BDB6B8ACC2BDCCBEBFB0B4B3ADA9AAA7A3
B3A8AEA0AF9D9F919B9C9798959994928B8F868C7F87818681877E88798275766C6D6F72
767670685F5A5F55624F5D564E4D4C4E504F4C48474A434A4644434244484A4541424647
444046494A4747434245434140434444464C4D453E3F42434141493B4741484040434142
47464242403D49414941403D414141403F3E3F40444445444A42494343423E413A483F45
40424144403B4145444448424A4144484D4648424A444948494D47474D52564C4B4C4B55
5B5D585C5356595A5D5F5C5761686A6B635B646B66676B6F6F6D6F74706E70777C7B7C7F
838687888F989A969295999CA0A2A09C9B9EAAAFB0AFB1ADB1A89EA7AFAEB0AEB7BEC0C2
C2C0C0BCC6C9C5C4C3C5CBC9D0C7CACAC9CFCFCFCBD0CFD0CCD1D2D5D2D2D5CED0D2D3C7
C5CACFD2CFCAD0D6D7D7D8DAD8D5D7D7DBD4D7D1D4D3D4D8D3DBD2D4CAD4CDD0CFCEC7C5
D6CED0CFD3CBCCD1CFCFD2D3D5C7CCC4D6CAD8CADCCED9D3D2D4DAD3CCD5C9DAC7D8CBD3
D7DFD0D9CDD9D6D6D6D0CDD1D6D7D6D5D2CEDCCCDAC4DAD0D4D5D8DBDBD6CFCBCAD8C7DC
CBE2CFD8D1D5C2D6C7D7C4CBCBC9CDCACACDCACECBC6DABFD4B8D3C4CCC3D6C8CACBC1C5
C3CFB9D6B8D3BCC7BFD3B7CFB6C5A9C8CACDCDCED2D1CED2CFCCE4C1E0BBD0CBD4C4D1C2
D6C4D2C6C9D7BFDBBADDC9D7CBD1C2DAC9DFCCD0D8D8CCD4CDD0D2CED0C6DBBDDBC0DBC2
C5B8D8C1D9C8D1D4CCDAC8DFC3E1C4D1C3D2C0D0C7D6C2CFC5C7C5D2D3D5D1DAD6D6E7CF
DFBFD3C7D2CAD8C5D8C5D9D7D1D8C9E0C9E2C9D1CCCFBEC7C1D8D2D9D8D5D3D2D5D7D8D7
D4D3E5D1E4CEE4D6DCD1DED3DFCDD9D4D4DBD4D8CDD9D6DBDDE2DAE2D3DBDAD6DBDADED8
D5D8D4D6D6D7DFD1DCCCDAD1DADEE2D2CAD7DBD9D9D8D8D6DAD2DCDBDAD8DDD9DED7DAD6
DAD8D7DCD8DED7DFD9DFDAE1D7DBDCD6DED6DAD4DAD4D3D5DBDBD5D9D3DAD8DCDDD7DCD6
D6D2DAD6DFDBDDD9DADCD4D2D4E2DADEDADCD9D8DCD8DCD8DDD7DBDADFDFD7D8D1D7D6DB
D9DBE3CCE4D0D8D6DDD6D9D9DAD9D6DDD1DECFE5CFE3DBDDDBDADED9E0DBDFDEE3DEE4DC
DFDDDCDDDAD7E2CDE3CFD6CDDBD8DBD7D7DBD5D5D9E2D0E4CDE6D7E0D6DBD3E1D7DCDCDF
DFD9DAD6D7DCDCE3DFD8E5D1E7D2E6D4DBD7E3D5E4D6E1DDDAE4D4EAD3EADBE5D8E3D8EA
DCE6E0E3E6DEE0DEDEDDDAE1DBD3E0D5EAD9ECDD
D8DBCFDBCEDCDDDADCD6DBCFD4D1CFD3D1D0C8CAC3C8C6C9C5C9C9C5C4C7CAC8B9BCB5B8
B2BCB8B9B3B5B7B4A9ABA2A89F99949D9D989A908A7F827D8B8286828285848080827D75
75756B72686D605E616561625C605A57645E5D51554E53524C50534E4E4C4A43474A4C4C
4C4B4640474A3E4C43474446484848474644434240484646403D444443484B4742404140
473D4642483D433D4443453F43424541414445423E3E414543473F473C47404345484645
47454042423E4B3F4640424340404041434444434544424049454E4944484749424F4241
424B4A4C4B4A54545B53534B5B53595B6860645D6A636D6D7A7D797B7B797D7A8487838D
93978D8E939496989EA2A09B9DA6A7A99E909496A0A2A8ADADAAABAFACACAFB4B8BABABA
BDC0C0BFC3CAC8C1C5C2C1C5C8C6C1BEC0C3C9CDC4C3C2C0C5C6C0C4C6C3C9C6C8CCD1CF
CFD1CECDCACEC9CCD0D1D6CFDACDD0CFCBCDCDD3D3D6D1D3CED5D3D3D8D4D8D2D4D3D5C8
C1C3CBCECDCACAD0D3D6D3D8D2D1DDD3DACFD4CDD4D1D0D3D2DCD0D5CDD4CAD2D1D6CCCC
D6CBCCCFD3CDCDCFCED0D3D0D1D1C6D8CCD1D1D2DDD2D9D2D4D4D8D5D3D5D2D4CFD4D4D8
DBD5D9C7D9CAE0D9D7D4D2D2D1CECFD3CED7CDE1CCDBD8DCD4D2D4D9D8D0CAC9CCD2D1D1
D6D9D5D4D4CDCFC1D0BEC1BECBCACECBCACCCACEC9D1C8D5C5CFCECAC6C9CEC8CAC1C7C7
CBC6CEC5D2C9D2CDC8BBCEBBCAADBDB7C9CECFD0D4D1CCCDC7D2CCDBCBD7CDD6D3CBC8D0
CBD0CDCBCFCFD2C8CCC8CDCAD3CAD3C3D6C9D5CED9D3D4D1CDD8C6CEC2CBC0D4CADDD6CD
B7C3C8D2D2CAD1CED1D1DCCCDAD1CFCCD2C4D7C5D6C3D3C3C5CBC9D2D1D4D0D9D2E1D3E1
CEDAD0CFD6D7D5D7CDCED0DADAD3DCD2D9D3D0CDD4C7CEB9CDC5D9D0D5D4D4D5D7DBDDDF
D9E4DAE1D8DBD5D3DAD6D7DAD5D7D8D7D5D6DBD2D6D3DBDADBD8E1D4E0D2E6DADAD6D9D7
D5D6D4D9D5E0D6DED1D7D5D5DBD9DDD2CCD7D9D7D4DFCFDFCEDCD7DCD9D8DEDADFD8DAD6
DBD8D8DDD8DED7DFD7DEDCE4D9DDDED8DFD6DCD4DAD5D3D5DCDAD3D8D4DCD9DBDED9DED8
D8D4DBD8DED8DCDBDDDDD6D7D3E1DCE1DDDEDDDFE0DEE1DADFDCE1DEDADAD2D6D2DBDBE0
D5DBD7CCD7DBDDDADDD5D8D9DAD9D7E0DBDDDFDDDBD6DFD6DCDADFDBE2DEE2E1DCDFDBE5
DAE9DCE4DCE3D5DDD3DECCCDD6D2D8D9DCDFDBDEE0E0DDD8D7DADBDAD9D6DFD7E7D3E3DD
E0DDDED7D7DDDBDEDADFD8E2D8E1E0DADCDEDEDFDDDDDDDFE0E2E3E2DEDDDDDEE0DEEADC
EDD7E7DCE3DEE1DFDFE1DEE2D9DED6EADEE9E3DF
D4CDC7BFBEBDC9C0C6C6CAB9BFBFBBBEB6B3A6A3989B979A91999B96959A9A95928E887E
7F80827F7E7F807C6C6E636B71675C636362675E5B544E514F5452584D4E4C4A4F555044
48484B494D4A4C4B48525353474B484A4C4C494C4B4C4745454E494A414E48453F424441
4245474645413C3F474147434243444442414345474B46424241453F3E43443F3C3F4447
4A4043434440464346484545444845414747474644424448484347474B424445494B4846
4A4B4B50494D50544A544A544F4F51565B5F606057595C606D6970686B686F606D757C79
737C77767C858F889E8F8B8198919999ADA1A499A599A4A3AFB2B2B9B6AEB6BBB9BDB8C2
C9CFC3C1C6C8C9C6C5C6C7C5C7CDC9CAC1B4BBBDBDC1C7CDCCC9C9CDC9CACBCDD0D2D1CF
C4C8C9C9CED5D3CBD3CCCAD1D7D7D4D3D1D3D4D8CACECFD2CED0C6CAD1D2D1C2D0D1D8D2
D1D6D1D2C2C7C3CCD4D5D5C8DACBCFD0CDD1D3DDD8D8CFCFCBD7D6D7D6CED5D5D9D4D6CC
BFBFCBCFCFD0CBD1D5DAD6DDD4D1E1CFDBCED4CED6D4D1D3C6D3C8D1CED5C8D6C9D5D0D4
D8CAC8CED2CFD0D2D1D4D4CDD2C2CBC8E1CCDFD2DED7DDD3DAD6D2D1CFD4CAD5C8D8D4DE
D3DAD1DCD2D5D1D1D0D2D4D2CDC9CED5D8D3DFD5DFCCDCCEDED7D5D9D8D0CDD0C8D3C7D4
CCDCCDD0C6CDCBD2D3D4CED6C8C7CDCAC9CCCACFD2CACCC5D0C7D1BED0CDD9CAC9C4C2CA
C6C9BFC8BECDCAD3BEC9BCCFC1C9B7C7CBD1D2D2D3CEC7C6D8CED7CBD1C6D2C9D4C8CECB
D4CCD3CDC2CDC3D1C0D4CAD0C6CBCBD4CFD6D3D6CED5D1D1CDCEC4CCCDC8CDC6D6CDD3B9
BABACEC1CEC2CFCFCCD7D4DAD0D8C2C5CECFCDCED1D0CCCBC6CFCAD0D1D7D1D5D7DBDAD4
DBD8DBCCD9D7DED4D5C8D4DADAD9D7DDD3DFD0D6D0C9C8C3C1CBD6D4D6D6D5D4D5D7D9DB
D7DBDCD4E6DBDFD7D7D2DAD2D8D7E1D8D8DDDCDAD5D8D9DBDEE0DDDCD8D5E0D8DAD4D8D8
D7D8D7DFD5DBDCD8D9D4DCD8DED5D8D4D2D9D9D8D2DAD8DAD8D8DBD6DDDCE2DEE2DADAD5
DEDBDBE0DAE1DAE0D6DDDCE5DBDEE0D9E0D6DED7DDDAD8DBD8D7D0D7D6DFDBDCE2DEE3DD
DDD7DCD7DBD5DBDEE0DFD8DAD1E0DDE3DFE1E1E5DDDDDFD6DBDBE1DDDFDED6DAD4DAD6D7
E0DBDBC3D5D6E0D0DDD4D7D9DADAD8E2D5DCD8E4D7E1E3DFDDDBE0DCE3E0E5E3E1E0E2E3
E0E5DCDFE3E2DDD3DBD6D0C8DAD5DADDDFDFDADEDAE1D5DED0E3DBE0DADCDBDEE0D6DADA
DCDCE1DAD9DDD7D5D8D6DED8DFD7E5D9E0DEE5DCE2DAE0DEDAE3DBE9D7E2D8DFDBE0E0E3
E4DEE2DFDDDCE0DDDEE2DEE0DDDCE0E6EBE4E8DB
9B97918F8695919E8995808C828E9089907B6D61626462656B6A6160595C595C5B55564E
4F464E54464E505457524848514A4D48484B4446474A494845494A4A4747474747474646
434746474145454844594F4649454648464549464C4451474442444D49433F4544464A44
4B414346494A424B3F443F484347424646424845464D473E4E41454746434A484C4C4745
4D4D4A4B4D49484F525053514C544E565C5A60625C5F66656E616064666D6C7B7C756F7C
7775707977757C82848B929185868E9596999C9A92969B9FA2A3A2A2A7A9AFB0A2A5B5AF
B8B9B9BCBEB6B6C2BFBFB6C9C5CBC0CBCCC8CBCEC9CAD2D7D9D1CED1CFC9CCD4D1CFCED5
D3D3DBD5D6D5D8D0CFD6D3D4D1D6D4DBC8C2BCC8C8C7CACFCFCCCDD2CFD2CDD4CBD3CED1
D1D3CAD0CFD1D3D0D5D9D9DADCDAD5CBD4D2D6D4D7D4D7D4DBCAC3C5CFCBCBCAD1D2CECD
CBCCC0B5BECCC3CBC1D0D1D1D1C9CACDD4D4CED9D6D2C4C0CCD6D3D4D6D0D5C6CECDD5C7
BBC6C8CDC7CFC6D2CBDBCFD7CED3CED2D6D2D4D1D1D4CFD0CECACDCAD0CDD0CCD1CADDC9
D5C6CBCAD0CED1D4D1DBD2D8C4D0C9DCCFD7D6DED4D2DDD8D9DBD8D0D6D6D2CFCFD4D7D8
D9D7D7C9D5D0DECFD5D0D0D0D2D4D4D8D3DCD1E0D4DCDBDFDCD9D4D7D4D5C3C8D7D2D2CE
D2CFCFCBD3C5CECCD7CDD4CCCCCCC7CDC7CDCFD7BDD6C8D5BACCC7D2C3C4CDC8C7C7C8CE
CBC8C5C2CBC4CCC5D4C1CEBFC8BCBFB9C9CBD1D2D4D1CAD2C8DAC8D9C5D1C8D5C6CDCDD3
D3D1CCD4CFCCC9CACDCFCECCD1CBD1CCDBD2D4CBD4D1D3D0CFC9C5D2CBCDCBD2D4CFCEC7
BFCBD5D4CECDD0D3D2D9D3D6D4DAD4D7D2D0D5CDCDCDD6D1D9CED5D0D3DAD3DED3DFD5DA
DADCD9D9DADBE1DBDDD7E0E3D5DED1DBD8DAD4D5D4CFCCC1C8CCD7D7D5D5DBD8D7DBDAE0
D8D9D7D7DCD6DAD3D6D5D7DDDFDCD9D9D4DBD2E0D9DED9D7D6DFE5DCDBD9DCD8D6D5DBD6
D5D8D9E0D6D8DED8E1D3DED8DCD9DCD6D2D4D5DED2DFD6E0D0E4DADDD9DADDDCDFDDDEDD
DCDDE0E2DFDAD9DCDCDCDFD7E3D9E1D6DDDEE4DDE0D9DEDEDADFD2E0D1E1D8E0D9DCE0DF
DCDADCDEDDDDDBE2DFE5DBDAD4DEE3D9E6D9E2E0E2E0E3DBDFDBE2E3DCE1DBE3D7DDD6D9
DAE3DCD8DCDADFE0DDD9D7D9DAD9DADCDBDDDCD9DFDBE2DAE0DDE3DBE3DAE0DCDFE4DDE0
E0E5E0E7DADFD4DBD6D1CBCFDDDADEDAE1DCDDD9D9DCDBE0DDDED9D7DCD8DED8E2DBE0DB
DFDADBD7D7DBD7D9D1E1D5E0D7E0DCE3DDDDE3DEE2DBDFDED8E1DFE4DFDFD5D9DDDCE2DF
E6E2E6E3E5DEE0DFDFE0DBE0DDE3DBEBE0E2DDDF
625E5D5A555E5B645C68545D535D5F5A534553485C4D4D45504A4F424C424A474D464746
4E484A49424B3F4C424F424A4B474644464A494B44464A4549494F4E4346494C4C4A4948
46434C444E454E4D3D4B444144454C504A4A464D49484F4B484B4152424C424D4653574D
504A52544A464B494E4950534E57585D5A5459575D645A5C605F60646162646C6A756B6F
7771696C797F82888E899587908A8F918D939C9E999AA0A4A39F96A59BAEA5B4ACA7A4B1
B2B6B5BDB6B5BCC2C0C2C3BFBABCC3C6C1C1C3C1C4C4C4C5C8CBCDCFC0C5CACDC6C8D5D0
CDCCC9CBD0CCCCD3CCCDC5D1D0D5CDD5D7D1D3D4D0D0D7DAD8CFCACCCECDCFD2CFCCC8CD
D0D4DCD3D5D3D7D2D2D5D0D0D0D3D8DBD0C5C3CACCCCCDCECECDD0D3D3D2D2D0CFCDCBC9
D1D0D2CBD4C9D5D0D3D5D5D5D6D6D2CAD2D6CFDACFD9D1D5CFCCBFCAC5D2CCD0D1CACBC7
D0CBCECACDD2D4CBD3CED9D0D3CECECED3D2CAD2D0DACAD9CAE0D4DDD7D4CBD1CAD8D2C9
C7CAD1CCCCC7C1C7CED6D7CDD6CBD4D1D7D3D6D2D1D3CED0CCD1C7D4C8D5CBD0C8C9D0D1
D0D6D1D6C9CECBD5D2D7D5D5D2CCD1C8D6C4D3CEDBD1DFCFD7D2D8D0D1DACCD9C7DDD2D7
CDDED0D7D2DCD5D9D3D6D1D5D1CAD4D8D9D7DBD3DDD0DCD6D9D6D0D2D1D6CBD4D1D5CED6
CAD3CDD2CECBC9D4CBD3D0D0CACAC5CBC5CACAD1D2CFD6C5C7BBCEBFC6C3D7C4CEC1CBCD
C2CFC2D6C4D2CED5C9C7C3CFBAC9BCC5C9CBD2D4D7D4CAD0CBCFD7D0E2D0D7CFD1CED2C9
D6CBD2D5D2D0CECDCDCCCBC9CFCFCAD2D1D8D3D2D1CED1D0D1CFCCDAD5D6D1D5D7D2D1C9
C4CBD1D3D3D5D4D2D1D9D4D7D4DAD4D7D5D2D8CFCFCDD5CFD4CBD3D1D4DCD5DEDAE2D8DC
D7D9D6D4DCDADED8DEDAE0E0DAE0DBDCE1DADAD8D4CFCCC2CACEDADBD4D3D9D7D8DCDCE1
D4DBD0DED7DFDBDAD4D2D4DADDDDDEDFD7D9D9DAE0D9DED9DCDCE5D4E0D9E1D8D7D6DAD7
D6DBDAE0D4DCD4E1DAE0E0E2E1DDDCD1CCD1D4DDD9DDDED6D8DBDFDCDDD8E5D7E6D7DFD8
DDDDDFE2DFDBDADDD7E0D7E2DBE2DDD8DCDBE0DADEDAE0E0D4D6DCDCDED9D9D6DAD6E6D5
E6D4E2DDDED8DEDDD9E4D2D8D5E2DBE4DDE2DFDFDFDCDFD8DCD8DFE0E0E0E3DCDDD7DAD9
DADBE1CDE2D0E2DCD9D8D9D9D8D5D8DDD5DFD3E2D8E7E2E2D9DCDAE0DEE5E4E7E0E5DEE2
E0E4DFE5DEDADBCCDBC2CCC7D8D5D9D6DED9DBD7D6DDD7E5DAE4DADDDDDDDBDDDEE0DFDE
DEDADCD8D9DDD8DBD7DDE1D5E2D4E0DCDEDCE1DBDFD9DEDDDEE4DDDFDBDDD8DFDFDEE4E0
E6E1E4E1E5DEE0DFDFE0DCE0E0E0E2E3E8DDE4E0
524E544C4F4C4E4F46534750474D4D484C48444B454D42474C4F464E414A424657504C44
434147484D4C4942454143464C4B4443444448484A4D4C4A474A4B4A4A4A4B494747484A
4A4C4252434E454F4A4F4E4F4E4E56595A515A56635669656E676D60695E6968627A7C6F
6C6A7979787F7488788B828E88939AA09C949695A7A3A69AA799A8A2A9A4B2AAB8B4B7B5
AEA69C9FAEB6B9BEBDC3BDC7B6C6BBC6C4C6C5C5C8C6C3C3C2BAC4B9C8C3CAC9C9C5C0C9
CBD0D0D4CECCCCCECBCFD2D2CFD0D6D6CECCCDCBD4D1CECED1D5D7D8CBD3D3D4D1CFD4D1
D3D0CACAD0D2D0D2D3D4CDCFD0D3CED0D8D2D0D0CCCDD2D3CFC7C0C0C6CBCBC9CED1CFD0
D0D3D9D0D7D1D3D1D2D4CED0CED1CED4C3BFB9C1D1D2D1CECDD0D3D4D7DCD0DDCDD9C9CB
C9D4C7D7C7D3D1D7D4D3D3D2D3D5D1CDD1CDD6CBD9CDD4D0D3CCD1C0CFC6D2CBD1CEC4D2
CBD4D0DACBDAC6DAC5DBCDCED0D0D2D0D5D6CFD5D8D1DBCDDAD0DACFDCC9D8C3E0CEDCC8
C1C8C5D3CAD4C4D1CADBC8DCC7DBD0D9D8D5D8D3D1D2CED1D6D0DBC9D7C5D1CAD5C8E0C3
E1C9D8CDD6CED4CEC8D7C8D5C9D2B5DBC0DDCAD4D4D3D8D9D0D8D1CFD4D3DDCBD8CFD8CD
DDD0E7CEDEC0DFCADAD0D9D4CFD0CADAD2DFC8E4C9E1D1D8DBDAD8D7D3D2C6CDD6D5DECD
D4C6D2D2D5CADCC3D8C1D4C7CAC9C4CAC4C8C7CEC9E0B4D3B7DDBFCDCACDCDD1C5CEC4CC
CBCAD8C5D4BBCEC6CEBFDBBCD1B2C8C1CDCDD2D2D6D5CCD1CFD9BBDAC6E0CBD1D0D5CAD9
CED8CAD2D6D7D7D5D3D0D0D0D9D0D8C7D8C9D4CDD4D1D3D2D3D1CDDAD4D5CFD3D6D3D2CA
C9CFD3D5D6D7D5D2CFD9D6D9D5DAD4D8D9D5DBD3D2CED3CDD9D1D7D5D7DBD4DBD8DDD6DC
D5DBDDD8DED9DBD7DFDCE0DDD7E3D4E5D6DED3D7D7D1CEC3CCD0DBDBD9D6DBD8D7DBD8DC
DCD8DED4E3D3E0D6DBD7D5D8DADBDCDFD7E3D2E8D4E3D9DFE0E1DADAD9E3DFDBD9D7DAD9
D8DEDBE0E3DCE6D2E8CFE2D6E0DDDBCECBD4D7DCDAE8D1E5C8E8D7E1D7DCD9E4DCE4DCDE
DEDDDEE1E0DDDCDEDEDBE8D4EAD2E1D0DDDBDED8DDDAE0E0D4E1D0EBCDE5D1DCD8DED6E4
D7E5DBE1DCE1D7DFD9D8D8D4DFDBEBD7EBD4E7D6E2E0E3DDE2DEE5E5E1E9DAE9D0E1D5DF
D8E4D3DED2DED9DED9DADCDCD8D5DAE0E3DFE7D5E8D5E5D7E6DDEAD6E9D7E6DFE1E5E0E4
E0E4DEE2E3ECD0E4C8D5C4CDD5D4D8D5DDD8DBD7DDDCE1DEE2DBDCD9E1DAE4D6E6DAE5DF
DEDADDDBDCDFDADCD6E9D2E8CEE4D5DDDEDCDFD9DDD8DDDCE1E5DDDEDADEDAE1E2E0E5E0
E6E0E2DFE5DEE0DFE0E1DDE2DFE6D8EDDEE8E0E5
4B5147544350434946524A51474C4D4B4B444C464C494B4F4C4B4D484B45474448494E4D
4A4A4D4A4A4A4C494D4B4F5057584F50504D54515058565C576361646B6E7273716F6E6F
6D606D657B6A7A7B7979818987868D8F8F8C879B919A99A19EA79AAA99AEA5AFA4BAB8AE
A7A5B3B6C4BDC7B8C8B9C5C0BFC7CDD1CFCAC9C7C6C9C1D0C4CFD0D0CFD1CED6CBD8CBD1
CAC8C3C4CDD0CFD2D1CDDCCAD8C7D4D1D6D6CECED7D7D1D1CDD6CBDAC9DDCED3D4CEC7C8
CACCCCCCCBCDCDD2CDD1CDCDCCCBCFD0CCCBCBC7CCCBCACCD0D2D0CED0D9D2D0D1CCCBC9
D1CFCBCACDD0D0CFCCCFC9C4CACDCBCBD9D1CFCECBCDD1D0CFCBC4C1C6CECFCAB1C3CCCE
CBCED6D1D9CFCFCED1D2CED3CFD3CAD3C1C8C4D1D3D6D4CFCFD3D4D3D1CDD0CBD3CDCDC7
CECBD4C6D8C6D9D2D7D4D6D4D5D7D3D2D0DBCBDFCCDFCDD7D1D3C3D2C3D7CDD4D4CED6CD
D8CBD4D3D1CDD9C7E0CDDECDD1D2D4D1D6DBD6DBD7DCC8E1C1DFCDD0D7D4C6DACBDED1D1
CFC9D3CAD7C9C7CBD7D6E1CBDFC7DACED8D5D8D3D0D2CFD4CEDAC8E1C4DDCAD6D2D7CBD9
CCDECED0CCD5CDD8D3D2D5D3D2C3D6C0E8C6DECCD1C9DFD0DDD0D8CFC6D8C7DEC4E7D4D9
D0E3C6D9C9D7C6D9DBD9CAD7D8CBD5D2DCD4E2C9E4C8DDCCD8D8DAD8D6D1C7CED0DCCCDD
C7DBCFDECFD6C8D5C3D8CCCDCDCBC5CBC6CACAD0D8C5CFC0D1C5DCC2D3C6D8C0D7C3CDC5
CBD4C6D8C7D2C9CCC4CAC3D3BFCBC2CDD4D1D1CDD2D5D0D6DBCBCBB7D3C3D7CAD4CBD7CB
E0CCD4CDD4D7D9D9D6D5D5D7D4D2D1CFD0D1D4D5D5D3D6D4D5D3CDD7D6D7D1D3D5D1CEC3
CAD3D9D7D3D1D1D0CEDAD8DBD6DBD5D9DBD6DCD6D6D0D4CDDFD7DAD8D9DBD6DBDEE0D9DE
D3D8DBD4DEDADCD7DEDADFDCD9DCDDD9DDD2D9D5D8D2D0C6CED1DAD8D5D2D7D6D9DEDCE0
DCE5D3E5D2DED4D7E0DBD8D8D9D9DADDDCDCE2DAE5D7E4DEE2DBE3D1E5DBE6DBDDDBDADC
D9E2DBDFDBE4CFE6D1E2D5D9D8D9DAD0D0DBDCDEE0DBE4D0E0D6E5DFE0D8E9D4EBD4E3D9
DFDDDDE0E1DEDEE0D6E5D3E9D4E7D9DBE1DEE0DADFDADFDDDED9E5D5E4D4E2DDDDD2E6CE
EDD5E9DDE2DAE3DCD5E3D0DCD5DFD3EED7EEE4E1E0DEE2DCE2DEE4E3E4E1E8D9E1D5E0E0
DED9E9CEEBD0E7D9DEDDDEDFDDDBDEE3DCE9D4EAD3E8DBDEE0E4DCE7DBE6DEE3E0E3E0E5
E1E4DEE0E3D9E5C8E2C0D5C7D9D8DDD9DFDADDDADDE5DAE9D6E3D4DADFE1DBE0DBE2E0E3
E0DCE0DDDEE0DBDCDADDE1D7E1D5E1DADFDDE0DADED9DDDCDFE4DEE2DEE1DADFE2E0E5E1
E6E0E3E0E5DEE0DFE0E2DFE4E0E1DCE3E4E2E5E5
5250544F564F534F5259545750565B5D5C58605B5B57575D58575C595F5A5D5A5B595C60
616C6F676871697B6A7C737B8085818688878E8C918F9E90A298A6A0A4A4A3A3A5AAB1B6
A5A496AEA2B3ABB9B4AFB9C1BDBCC1C2C8BCC7C4CCBFC8C8CDC8D6C3D4C2CFC8D4DED8D4
CEC8D0D8CED5CBDCD0E2D9E0D6D5D7D8D9D8D5D4D7D2DBD8DED5E4D8DDD6E2D3DDD4D7D6
CDCECACBD4D6D2D1D3DDD2E1CCD9CDD4CFD5D3D1D5D2CED3CBCBDAC8DACBD7CAD5CFCBCA
CDCED0D1C9CDC9CFC8CCC5C7D0CBCCD0D0D2D1CACECDCDD0D4D5D3D0CFD8CFCED4D1D0CF
C9CACBCCCCCFD2D1C7CBC6C3CAD1D1D0D3CDCBCAC8CDD0CDCFD0CCC6C6CCCFCDAFC3CBCD
CCCDD4D2D6CDCECFD2D4CFD4D9D4DACCCFC1CCCFD3D6D5D2D1D4D3D0D3D7C9DACCDCCFD3
D3D8C4D7C8D6CCCED7D3D7D5D6D9D2D5CFD0D5CAD9CED2D1DCCACEC2D7C5D1CCD0D9D2D9
CAD5CED1CDD9C5DECCE0D1D1D5D4D3CED4D9D4DAD6D1E3D2DCD0E3D9D8C7DCC4DFC6DDD0
C6C9C6D2CFDBCFDBCDDDCDE5CEE2D7D9D6D4D7D3D1D3D2D6D9D3DFCDDBCAD5D0D8CEDEC3
E0C9DAC8D8CFD9D2CCDED0E1CBD7BCE3C7E3CED8D6D1D3D7CFD9D4D8D2D0DDC8DACFDCD0
DEC6DEC5DFC0E3CBDDCED6D3D5D8CBD5CEDEC7E3CBE6D6D9DDDADAD2D2CECAD4D8D6D7C9
D7CCD2D2DCCFDDBDDCC4D3C1CFCCC5CBC6CDCCD3C8DCBED3CADCC8D3CFD2CDD3C4CFC2CA
C7C8CBC8D1C9D4CFCAC2CFC2D6C2CFCAD5D3D2CDD2D6D1D6D5D6C4D3C9D5D0CFD5D5C5D8
C9DACFD6CFD1D4D4D3D3D3D5D2D2D3D1D2D2D5D6D0D1D5D5D8D7D1D8D2D7D3D7D9D7D4C7
C9D2D8D6D2D0D0CFCFDBD9DCD8DCD7DBDBD5DCD8D9D3D7D1DCD5D6D6D8DBDAE0DDDFD9DE
D3D9DCD5DCDADED8DCD8DEDEDCE5D5E6D1DDD6DAD5D0CFC6D0D2D9D6DCD8DBD8D8DBD8DA
DCD8E0D2E2CFDFD6DDD9D7D9DBDBDCDFDBE8D5EDD5E6DBE3DDE1DDE1DBE2DEDFE0DEDBDF
DAE3DADDE1DAE4D3E9D0E0D2D8DADCD2D3DFE1E2DBE6D1E8CEEBDAE4D9DDD6E2D9E7E1E8
E1DEDEE0E1DFDFE1E3DFE9D4E7D0E2D4E1DFE2DDE2DDE0DDD8E5D3EDD1E9D5E0DBE0D3E5
D7E9DCE2DDE4D8E0DAD9DCDADFD8E9DAEDD9EBD6E1DFE3DFE5E1E5E3DFE8D8EBD1E6D9E5
D9E5D7E9D7E5DBDAE2DDDBDEE1E1E1E2E2DDE7D2EAD3E6D7DDD5E8D6EEDAEAE1DFE1E0E7
E0E5E0E0D8E5CDE9CADFCDD2DDDCE1DCE1DBDDDBDADBE1DCE1DADEDCE1DAE5D5E6D8E6E1
E3DFE2DFDFE1DBDCDAE4D8E4D5E0DCDCE0DEE2DDE3DDE0DDDEE4DFE4E1E4DBDFE1DFE5E1
E7E1E4E2E6DFE0DFE1E4E1E6DFDFDAE1E3E1E5E4
6E6A72677969786F70798088898D8F9194958D96859690A19398929E939D9497A5A7A9A8
A0ADB2ABADA2BBA1BBA2BBB1B8BDBFC4C6C6CAC9B8C4B9CDBAD2C6CDC0C1C3C6C9CBCDCE
D0C2C9BFD1C3CDCAD3CAD0D1CBCDCFD3D2CFCCDBCAD5CBD2CED4CFDCCFD8CFD4DDDBD4D6
CFCAC8D7D8D2DECDE1D3DFD6E0DADAD7DADDD8D9D6DBD2E2CFD7D1CDD4D5D3D8CEDAD1D8
D2CDC3C3D0D5CFCAD4D2DBCFDBC9D4CCCCD0D2D3D4D0CBCAC8D5CEDBD0DAD3D2D0C9C9C8
CDCAD0D3CDD2C9D0CBD4CFD6D0C9C9CDCFD1CFC7CFCDCBCBCED1D1D1CAD2CACAD1D0D0CE
C3C2C6CBCBCED2D3CCD0C8C7CAD2CECFCDC9C9C8C7CCD0CBCDD0CFC8C6C9CDCDC8D2CFCF
D1D1D4D0D3CED2D2D4D6CFD1C3D2C3DBBBD0C0CFD2D4D4D3D3D3D1CDD1CDCECAD0CDD0CD
D5CDCFC6DACDD9CDD5CFD6D3D3D7D0D6CBD9C6DAC8DCC7D5CDC6B7CDC7D6CDD7D0D2D9CA
D2CED9D5D5CFDAC8E2CADACAD2CECCCAD2D7D4DAD4E0D1E9CFE9D6DAD1D4CDDAC8D7D1D3
C8C5D3C8DDD6DBDDD6D2E3D2E6D0E3D2D6D3D6D1D1D5D3D7D0DBC9E3C8E3D0DCCBD7C8D8
CADDD4D4D4DDD6DFD7D6D7D6DBC9D7BDE0C0DCCEDBCCDCCFDCD0D8D2CFDAC8DEC6E1D1D9
CDDEC7DBD5E3D1D9D2D9D2DAD8CED7D2D5D1E2C9E6CEE4D2DDD9DBD2D3CDC9D0CDD8C0D5
C8DFCAD7D2D7C8D3CBD9CBCDCFCCC5CBC8CECDD3D6CFD6D5D1C9D5C6CFCAE1C8D3BFCCCC
C5CBCBCBC8C3CACBCECDC8CBD2CBCAC7D1D3D6D2D6D8CFD2D1D0CED3D4D4D9D3D7CBD4CB
DBCFDAD4D4D4D4D4D5D5D4D3D7D1DCCCDBCBD7D1D2D3D7D6D9D9D1D6CED6D4D7D7D5D2C5
C9CED3D4D5D7D5D1D2DCD9DCD9DFD9DDDBD4DAD9DBD5DAD5DBD5D3D4D6D7D8DCD6DBD5DD
D7DDE0DCDCDBE0D9DCD7DEDEDDDCDCDADAD3DCD6D2CDCDC6D1D4DBD7D7D5DAD8DADEDDE1
DAE2D4E2D2DBD5D9DEDAD8DADCDBDCDEDFDFE3DEE6DAE4DEDEDBE8D9E6D7E3DEE1E0DCE2
DAE5D9DED9E5D2ECD6E8D9DEE0DFDFD4D3DDE0E5DFD8E3D3E7D9E7E0E3DAE7D3E7D7E7E1
E3E0DFE1E0DEE0E3DAE8D4E9D2E7DCE1DEDDE3DEE4DFE3E1DED6E1D0E2D4E3DDE1D6E7D0
ECD6E8DDDFD7DFDBD5E4D2DDD6E4D4EED9EDDFDEE5E2E6E2E9E4E8E4E0DDE4DBE4DBE3E1
DDD7E8D4EBD2E6D2E1DBD8DCE0E1E0E0D9E4D3E7D5E8DEE0DEE3DEE8DEE5DCDEDFE0E0E7
DFE5E1E0DDD7E8D5EAD0E3D1DEDDE3DDE1DADDDADAE2DAE8D6E2D8DFDEE0DDE1DCE1E0E3
E4E0E2DFDFE2DDDEE0E5DDE3D8DDDDD8E1DFE3DFE6E0E3DFE1E5DEE2E1E5DEE2E0DFE4E1
E7E2E6E3E6DFE0DFE1E5E3E8DEE3D3E8DBE8E0E5
A7B09EB2A2AEA5A7A0A8B4BEC2C3C1C1CDC6CBC0C0BBC0C8C9C5CEC4CEC2C8C3CACCC8BF
ADBFCECFC2C9C4D8C3D6CED4D3D4D9D9D8D8D6D8D9D5E2CFDECEDAD1D6D3D0D0D2D4D5D4
D0D0C8D5D1DBD1D2D2CCD2D1D0D7D8DED6CED5D3D1D3D2D3D9D1DDD2DFCCD6D5DFD7D6D6
D0D0C6DAD7DAD7DAD8E0DCDADDD8DBD7D7DBD7DAD4D6D6DADAD6DBD5D9D4DDD3D8D6D9DB
D5D0C4C0CCD3D0CDCDD5CBD8CFD3CDCBCFCED1D4D4D5D5D1CCCDD7CDDAC8D6CCD2C9CBCA
CEC5CCD3BEC8C4D1CED7CDD4CFCBCDD0CECFCFCBD1CFCCCACBCDCFD0CCD2CED0D3D2D4CF
CEC6C8CFCFD0D4D4CFD3C7CBC8D0C8CCCFCECFCECCD2D5D0D2D3D2CFCDCED0D1CAD0CACB
D1CFD1D0D6D3D6D1D1D5D1D2C7CAD8CACEBFC9C9D2D0D0D2D3D1CECDD3D7CEDACEDAD0D4
D0D3C6D3CED7D4D3D6CDD4D0D0D5CFD9D4DBD6D5DBD9D4DACFC4C7C2D0CAD3D3D0D4D0D4
CCD4D4DADADED3DDD6D9D4D2D2CAC9CBD6D9D4DCDED9D9D2E1DDDAD0D3CCDCCADBCEDBCA
C6CED4D3D8E0D9DCD2D9D4E0D6DEDDD7D8D3D4D0D1D5D2D5D9D7D8D5D8D5D6D4D1D5DACB
D7CCDBCFD5D2DAD7D0DDD2DFD0CEB8CDC8D9D4D7D7CED4D9D7D9D2D0D9D4D8D2D9D0D5D3
DAD3E3D0E0CDE1CBD3D3DCD7D6D9D0D2CAD8D0DCD2E0DDDBD5D2D8D2D8D1CCD1D3D6CFCD
D6D5CFD3D7D1DBC8DCC6CFCCD2D0CAD1CDD2CED2CBD6CFD3D5D1CED2D0D2D6D5CBCFC9D0
C9D1CED5CECED0D1CACBC8CBD6CDCFCDCED3D8D4D6D7CFD1D0D1CAD7D0D7D9D5D4D2CEDE
D3DCD5D5DCD8D5D6DADBD9D5D3D4D0D5D1D8D5D7D6D7D9D5D9DAD3D8D3DCD9D6D2CDCABD
C9D0D6D8D8DAD9D7D5DDD9DCDBE1DCDFDCD3D9D9DCD6DBD7DDD9D5D7D7D6D8D9D7E0D7DC
D9DDDBDADFDCDED8DEDADEDCD8DCD3E3D3DBD7D4D7D1CEC5CFD3DAD7DBDADFDBD9DCDADE
DEDDDFD7DFD2DED9DFDBD8DADBDBDDE0DDE6D8EADBE6DDDEDEE0E0E1DEDEDDDEDEDFDCE3
DAE6DAE0E2E2E4DEE3D6DED8E3E0E1D9D5DADCE4DEE1D6E3D7E6DDE2DFE0DCE0DCE3E2E6
E4E2E1E1DFDDDFE4E0E3E5DDE2D9E3DBDEDEE3DDE2DDE2E2DFDFD0DBD0E2DDE4E0E2DBE1
DAE2DDE0DEE0D8DFDBDEDBDADBE0E4DEE9DDE1D8E0DDE1DDE4DFE1DDDCE2D8E8DAE7DADE
DDE2DBE5DAE1DFD7E0DCDADDE0E0E0E2E2E1E5D9E6D9E4D9E0DBE8DCECDDE7E0E2E1E0E7
DEE4E1DFD7E1D6E7D1DDD3CDDEDEE4DEE2DBDEDDDFE2E4E2DFDCDDDEE0DDE6DBE6DBE5E2
E3DEE1DEDFE3E0E2E2E3E0E2DCDCE1D8E2DFE3DFE6E2E5E2E2E6DEE3E2E6DFE3E0DFE5E1
E7E2E6E3E6DFE0DFE2E5E4EAE1DEDDDFE8E0E6E2
D3CED2C5D4BECBBECECFD3D3D3D3D2D5D8D6D0D3C5D2CEDECED0CFD4D1D5D1D2D1D4D3CE
BBC9CCC3CBC7DAD0D8C7D2C9D9D8DFDBD9DAD4D8D0D7D5DAD3DBD7D8D7D5D4D6D9D9D6D2
CFCDCFCFD7D4D1C8D0CFD5D1D2D8D3D8DCD8D7D8CBD7CFD2CFCACDD1D4CFD4DBDDD7DAD8
D0D6C9E0D6D4DBD1DCD7DCD4D5D3DAD6D4D8D4DAD2D9D0DBD4D9D6D6DAD8D9D5D0D4CFD5
CFD0C9C4CCD3D6D8D2D5D3D6DCD4D8CFD5D3D7D2C5C5CDD0D2D7D5D6D5CACFCBD3CACDCD
D0C4CBD4C4CDC4CFCBD6CED7CECED3D4CFCFD3D2D1D1CFCECCCCCDCECAD0D0D4D6D6D9D2
D9C9C6CDCECECECDCBCFC3CECAD6CCD3CBCBCDCCC9CED1CCCFCDCCCCCCCCCCCDCED6D2D3
D4CCCCCEDDD9D7CCCAD2D3D6C5D1CDD5C1CAC7D2D2CECDD1D2CFCCCDCFD2D2D7D4D7D4D4
D7D7D3D0D2CBD1CDD9CED5CFCFD6D0DDCDDACBD7D0DACBD7CBCDC9CBC9D2D5D9D5D2D4D5
D5CFD1D6D7D4D6D0DBCDD6CEDAD0CDD0DADAD1D8DBE1D2D7D6E3D8DDD1D2D5D4D6DBD7C7
C5CDDCD0DEDFDEDADCD9DFD7DCD1DCCEDAD4D4D0D0D4D1D3D6DBCFDECFDFD2D7C9D7D2D5
CFD6DCD9D5D8D9DBD1D5CFD3D6C6C2C0D9D0D9CCDACAD2CED8D5D8D5D3D4CEDCD3D9D2DA
CEDAD7D2D3D5DBD8D4D8D6D7DADAD5C9CCD3DBD0DCD4E1D6E0D9DACED3CBC8CED1DDCED9
D4E0D0DDCFD4D5D4D4CBCBD5D6D4D0D8D3D6D0D2D4D5D3D5D1CBCFC9D9CFD6CCD8D3D1CC
CECFCDD0D5CFD0C8CDD0CDCCD7C8CCCAD0D5D8D2D3D6CFD3D2D4CBDED2DDD8D1DDD3D5D5
D7D5DCDADCD6D1D3D9DDDAD5DCD5D9CED8CED5D1D4D5D7D4DADFDBE1CCD7D7D7D6D6D7CE
C9D6DFDED8D7DADDD7DED9DCDBE3DDE0DDD4D9D8DCD6DCD8DAD8D6DBDDDCDEDFD0DDD4DB
DCE0DEE0E2DCDBD7E0DDDFDADBDCDAE4DEDEDED5DFD7D0C5CED0D8D4D9D9DFDBDADDDCE2
D7DCD7DEDADCE1E2DAD6D4D7DCDFE3E8DEE2DDE3E3E1E0DBE2DDE2DBE3DBDFDBDCDEDBE4
DAE8DCE3D8E0D6E2D7DFDDE1DFDDE2DED9DAD9E1E2DDDED9E0DDE1DFE4E0E5DBE4DBE2DF
E5E3E3E2DFDCDFE5DBE6DDE7DCE3E0E0E1E0E4DCDED9E0E1DED9DAD7E1E0E3E0E3DEE4D9
E3D9E1DDE4DFDFE1DDE6D9DCD2E3D9E5E1E8DEDFE1DFE3DFE6E0E2DDDEDEDEE2E2E2DCD9
E4E0E4DDE4DCE8D9E0DEDFE1E1E0E2E7DAE1DAE1E0E6E7E3E1E1E3E2E5E3E5E4E4E2E1E8
DDE2E0DEE0E0E4DEDCD3D8C9DFDFE6E1E5DEE2E1DCE2E0E7DDE4E0E5E0E0E4E2E4E0E4E4
E1DDDFDDDFE4E2E5DFE3DCE5DAE2E3DCE3DFE2DDE5E2E7E4E0E5E0E5E5E8DFE1E1E0E5E1
E7E2E5E2E6DFE0E0E2E6E5EBE1E3D8E8E2E7E2E3
D8E0D8D6D3DBD3D2D0D5D7D5D5D8DAD9DADDD4D2CDDAD6D3D0D1D7D3D7D0D3D1D1D5D5D3
CED9CFCDC9CFCFD4D4D0D3D0D3D4DBDAD9DBD7DAD4D7D2D3D6D7DCD7DAD4D7D6D5D4D0D6
C7D0CFD7D5D3C9D1CED3DCCFD7D6D5D9CFD4D4DAD3D6D2D4CFD1D8D5D8D7DDE2E0D4D0CD
D0D5D4DAD2D9D8DAE2DBDDDBD9E0D7D1DADBD5D8D3DBD5D8D4D6D8D5D7D4DAD4DDD6D3D9
D2CECAC5CCC8CDD5D1D5D9D1D9CFD9D0CBD1DCD9D3D4D6E1CDD6CDD1C9CED0CECFCECECB
C9D2CCCCC4C5CAC6D0D1D1C9D1CCD9CAD8C9D5D0D5D0D4D3D3D3CFD5CCD5D0D9D5DAD9D5
D4D4D2CFCDCED1D4CED2CDC8CFD4CEC8D1C8D3C9DCCDD8D4D3D3D1D3CED0C6D0C5D4CDD8
D3DACCD5D2CFD9D2D7D4D4D5C9D4D6CCCDBFC8CDD3C9D0CEDACCD2D1D7D1CFD8D2D9D2DF
CDDBCFD7CAD3D3D9D4D9D4D8D6D0D5D2D9D5D7DAD5D6D6D2D7C8D3C5D1CDDECDD6D9D8D9
CFCDC7DBCDD9D7DCD4D6D8D6D0D2DAD7D4D6D7DFDCDCD9D7D2D2D0D2DAD6DACDDFD0DACB
CECCCFD9DAE3DCE3D8DED9DBD8D8D8D3CFD2D3D2CFCFD1D4D8D7D5D6D7D7D5D3D0D2DAD6
DAD3D8D7D9D4D9DAD7D6D6E2CCD0C6D5D9D8D6DED4D3D8D3D8D3DADAD3D4D1D9D6DBD3D1
D7D4DBD0DBD5DCD4D9D7DBD7D5D7D1D2CEDADBDCD8D6DEDED4D6D7D2D3C9C0D0D3DBD5DC
D3D2D2D2D6D3D7D1D7D2D7D5D8D7D3D5D6D4D3CFCBD2D4D1D3CED5D1DADBDFD4D3CCD2D2
CCD2D1DCD0D2C9CFC8D0CFD2CDCAC8D4D6D4D4D7D7D4D4D6D2D9DCCFD8C8D5D8D6D1D6D3
D9D4DADCD7D8D3E2D4E3D5E0DAD7D7D4D7D7DBDCD7D4DADADADBD8DFD9D7DADBDCD4D9CF
CDCBD5D2DAD0D9DBD3D9D4E0D6E0DBE0D4DFD8E0CEC8D4D2D5D1D7D8D7D7D6E0DBDAE2D9
DCD2E2D8E4DDE4D9E0DCDEDFD6E2DBE8D3E1DCE8D6D8CECCC8D9DCDFDDD8DDDEDEDED9DE
DADEE5DDE7DBE3D6DEDAE1DAE1E2E5E7E1E5DFE7DCE4DFE4E0DEDFDFE4E2E0DCDEE1DCE3
DFE4E2E4DDE2E4DFECDEE3DEE2DEE6DCDFDDE1E6DCD8D5E3E1E2DBDFE1E1E7E2E8E4E5DE
DBE1E0E6DFE3E1E5E0E5E3E3E4E0E4DDE2DDE4DCE2E0E1E2DDDEDDE5E0E4E2E9E0E6E5D8
E4E4E6E3DDDCE2E0E1E3DEE1DEE2E1E5E3DDDFDDE4DBE5E4E9E0E1E8D8E3DCDFE0E3DCE7
DAE1E0E4E2DEE3E2E5E3E2DEE2E6DFE4DFE2DFE3E5E3E6E3E3E2E7E2E9E4E9E8E2E3E5E7
E0E7E1E7D9E8E4DDE1D6D5D8E2E1E7E4E2E4E1E5DEE1DEE4DFE3DDDEE3E0E0DCDEDCE0E0
E1DDE1DEDEE2E0E3E3E3DADDDCDDDFDDE2E3E9DFE5E1E8E4DCDEDBE7DFE4E0E7DCE3E0E7
E2E2E4E3E5E2E4E1E2E6E4E8E2E3E2E2E9E2E8E2
D9E1D8D6D4DBD2D0D7DADAD6D5D9DDDDCFD6D4D6D0D8D4D3D3D2D7D1D5D0D4D3D7D9D4CD
C3D0CBCECAD0D0D6D6D3D6D4D6D6DCDAD9DBD8DBD5D9D5D5D7D7DBD6DAD4D7D7D7D7D2D7
CCCFCBD1CCCECAD1D0D3DBD0D7D4D4D9D2D6D5DBD4D7D2D4D2D0DBD0DCD3E0E0DBD5D5D1
D0D3D4DCD5DFD4E0DADDD4D6D6D2C0BCCFDBDADDD6D8DBD2DAD0DCD4D9D5DBD4DCD5D1D6
D0D3C8D1CBD3CBD5D2D9D4D9D5D8D9D6D3D3DAD7D6D9D7DBD8D6DCCBDACADAD0D6CFD3C5
CDCFD3D3C7CAC0D1CAD8CED1CBCECED3D2D6D5D8D2D0D5D3D1D1D0D9D1D1DACDDFD0DFD4
D8D5D2D2D3D3D3D2C8D6C3D3C5E0CFD5CFCDCBD2D2D3D1D4D2D2D0D2CED1C8D4D4CDDED7
DACFDAD0D4D1DBD3D8D5D5D6CDDAC9D7C4CFC9D3CCCBC7D5D1D7D2D8D5CFD6DADCD9D5DB
D7D2D9D0D5CCDED1D9DDD8DAD8D4D9D6D2D7CEE3CEE0D4D6D5CFCCCFCCD9DDD7DBD4D4DB
D2D2C5C9D6D7DFD3DFD1DCD1D4D5DBD8D5D8D7DDD7DDD1DECDDAD0D8D4D5D0D2D6D5D6CC
CDD1D8DDD3D7D4E0D9DCDDD7DCD4DBD2D2D4D5D4D2D2D5D8D6D4D4D5D7D9DAD9D0D1D9D6
DBD7DDDEDBD5D9DAD8D7D6E1D1CEC2D2D7DAD8DADCD9DBD3D7D4DDDFD6D7D2D9D7DCD5D4
D2D6D3D7D3DAD5D3D5D2D8D7D8DBD8DCD8DFDCDBDAD8DCD8D6D8D8D2D0C5BAC7D0D8D3DB
D3D4D5D7CFCDD3CFD7D4D9D8D6D4D2D3D5D4D2CFCCD7CFD9CDD5D3D3D7D4DAD5D4C9CED1
D3D2D7D4D4CBCDCED4D3D7C9D0C1CAD1DAD7D6D7D6D4D4D7CEDAD3DCD2D5D6DCDAD5D9D7
DDD7DDDEDED9DCDBDBDCD9DEDED7E0D1E0D3DFDAD9D6DBDBDADAD7DDD4D9D0E4D6E1DBD7
CFD2D7DCDBD9D9DEDAD9E0D9E0D7DCD9DBDBE0DAE1CCE0D2D7D5DBDAD9DCDBE2D1DAD7E2
D8E1E3E0E3E0E2E0DFE3DFE3DFE1E5DFDCD7DCDFDED6DAC2D4D0E3DDDDD9DEDEDEDFDADF
D4DFDAE6E0E6E3DFDEDAE3DDE6E6E8EADFDFE5E2E6E0E1DFE7DFE9DCEDDEE5DBE2E4E0E5
DFE3DFE0DAE4DDE6E5E5E1E2E4DFE5DBDFDEE2E6E4E0DDEAE8E9E2E6E2E2E7E1E8E4E6DF
E1E3DFE5E1E5E0E1DBE4DDE6E0E6E5E2E2DDE4DCE1DFE0E1DCDEDBE4DEE2E0E6E1E4E4DA
E4E3E4E1E1DFE4E1E1E2DEE0DCE2E0E3E1DEE1DEE3DCE6E2E7E0E0E5DBE4DEE2E1E3DCE3
DFE4E3E5E3DDDFDCE4E2E2DDE1E4DDE2DEE3E1E6E6E2E5E2E4E2E6E2E7E3E7E5E4E4E6E7
E0E7E0E6D4E5DDE2DCDDD9DDE2E0E5E3E2E5E1E4E1E4E1E7E1E5E0E2DFDAE3D8E5DBE4E0
DDDADEDBDCE0DEE2DEE6D6E8DAE5DCDDDBDFE0E0E0E5E6E5DEDEE0E1E1DEE1E5DEDDE2DC
E7DCE9E3E6E2E5E2E3E7E5E9DFE7D9EBE0ECE7E9
DBE1D8D8D6DCD1CED0D5D8D8D7D7D5D3C9D0D2D8D1D6D3D6D6D4D7D0D4CFD5D5D5D6D2CB
C2CFCDD4CBD1D1D7D8D6DAD8D9D8DCD9D9DBD8DBD5DBD8D8D8D6DAD6D9D3D6D6D8DAD5D8
D5D3D0D6CED1D1D5D4D2D9D1D7D2D3D9D5D9D6DCD4D7D1D3D3D6D3D6D1D7D9DDD7D5DAD5
D0D1D3DEDAD9DED3E5D1D9D0DBD2C0BCCFDCDBDDD6E1D2DECEDAD5D7DBD5DBD4DAD2CFD3
D6CFD3C8DACED6D5DED9E2CFE2CEDFD2D9D7DBD9D9DBD7DAD1DDC7DFC8E0D3D9D5D5D1D5
CDDBD1D6D0C3CEC6DDCEDAD5D9CEE1C6E2C7DACED1D0D7D4D0D0D2DDD0DECAE1CAE0D3D8
DBD7D3D4D8D9D5D1D4D1D9C0D7CAD6CED9CBDDC3DFC2D4C9D2D2CFD0CDD3CBD8CCDECDE6
CCE3CEDDD6D3DCD4D9D5D6D7DACFD9C5D7BFD4C8D9CDDDC5DDC4D4CBD6D5CFE0D1E0D1DE
D2E7C8DFCCE2CBD6D8DBD8D9D7D3D7D5D7D1DFD4DFD0D8CED8CADCC2E1CCE1D1D2C8CDDB
D7DDD4D2D3DECDE3D2E3D7D8D9D7DBD8D7DAD7DCDBD8DED3DAD0D6D4DAD3DDC9E4CEDFCD
CDD4DCDED0D1CEDCD9E2D6DFD4DBD7D4D7D8D8D7D5D5D9DCDBD8D6D6D7D9DADADAD9DED7
DBD5DBDCDDD6D9D9D9D9D6DED2CCC2D3D4D9DAD9DAD9DFDADED7DBD9D8D8D2D8D4DAD5D6
D4D0DCCDDFD1DAD0DCD5D9DADAD9D6DCD8DBD6D9DDDEE2DBDADADAD4D1C5BAC6D2D9D3DB
D3D5D7D8DAD8DBD4D7CFD0CCD5D3D3D4D6D7D4D2D3D5DED0DBCAD7CED6D1D7D7D8C9CED4
D2D8CADDC7D7CCD9D4DACDD4C4CCC8D8DFDBD8D8D7D4D5D8D7D2E3D1E4CBE1D5DDD8DBD9
DFD9DEDEE0E3D4E8D0E6D2E0D8DCD7E0D9E3DEE2E1DDE1E0DEDEDBE1E0D7E2D4E5D0DECB
D2D0E1D7E6D5DFDBDBE6D6ECD0E5D1DADAE1D0E9D8E4DCD6DBDADEDADADFDCDFDDD9E9D6
E9D2E5D3E2DAE9D8E8DDE5E2DDE9D6EECEE7D4E1DBE2CCD9C3E0D5DBDEDADEDFDFDFDBE0
E1DEECD9EFD5E6D6DFDBE4DFE7E5E6E8DCE5D9EDDAEDDCE2E5E7E0E9E1E9DFE0E4E6E2E6
DFE4DEE0E4E3EBDDEFD8E4DAE5DFE4DADFDEE2E5E4E2DFEAE7E9E2E5E4E4E8E1E8E5E7E1
E6E6E0E6E2E8E1DFE3E5E8DFE8DCE5DCE4DEE5DDE2DFE0E0DCDDDBE2DDE0DDE3E3E2E4DD
E6E1E2E0E6E3E6E2E1E3DEE0DCE4E2E1DFDFE3DDE2DEE7E0E4E0E0E2DFE4E1E6E1E3DDE0
DCE1E1E6E6E1E3DFE4E2E1DDE0E1DBE1DEE4E4E8E6E2E5E3E5E2E6E1E7E2E5E3E7E7E7E8
E1E7DFE5E1E7EADDE2D2DAD3E2E0E4E2E3E6E1E3E0E2DEE3DDE2DEE0DCDFDDE2DFE4E1E2
DFDBDFDDDEE3E1E5E3E2E4DFE9DEE6DFE7E2ECDCEBDDE6DDE2E8DFEDDBE8E0EAE5EBDBE7
DAE2DCDEE7E3E7E4E4E8E6EAE6E1E8DCEEDCECE2
DCE0D7D9D8DDD1CED2D6DADDDDDBD8D5CFD0CDD4D0D6D6DBD8D5D8D1D5D0D6D6D3D4D3D1
CBD6CFD1CCD2D2D8D9D6DBD9DBD8DBD8D7DAD7DAD2DAD8D9D8D6DAD6D8D2D4D3D7DCD7D9
D1CECED8CED2D0D0D7D1D9D3D8D2D3D9D7DAD6DBD4D6D0D1D5D0DCCFE0D6ECE3D6D4D9D4
CFD0D2DED5E1CFE2D6E1D3D7DADAD4D2DADBD7D8D9D8E1D0DFCDDDD2DBD5DBD4D8D2D0D3
D7DCC4D6C8DFD1DED9E0D2DFD4DEDBDDD9D9E0DCD9DAD8DDDCD2E0C6E4C7DFCFD7D0DCD0
DDD5D8D5D0D6C1E0CAE5D2DCD5DACDDDCEDED2D7D5D2D7D4D2D3D4DDD7D1E2C8E5CAE2D1
DAD7D5D6D9DAD8D5CEDDBEDBC0E5CBD7D1D6CBDACAD9CDD3D4D3CFD1CDD3CDDADCC8E7D1
DCC4E1CDD8D4DDD4D8D5D5D7CFD9C1E6C0DCCBD3CED5C9D9C9DCD2D8D2CDDAD9E0D8D5D5
DECEE4CFE2CAE7CCD7D9D9D9D7D5D5D5D5E1D0EBCAE0C7CFC8CFC5D9D1E3D4D8DED9DADF
D4D8D2D7DCD6E3CFE6CCDECFDBD6D9D6D8DCD8DBD3DDCEE3CCE2D3DEDDE2D4DED4DCD5D0
D1D2D7DCD3D7CFD8DCDCE0D4DFD2DDD3DADADAD8D6D6D8DBDEDCD9D7D7D9DBDCD9D7DCD6
DBD8E0E1DFD8DADADADBD7DCCFCDCAD8D2D6DCDBDCD9DCD5DAD6DCDBD7D7D1D5D1D7D4D5
D7D7D8D7DADAD9D6E2D9DBDBD9D6D2DADCDED8D9DBDDE0DADEDCDDD8D5CCC3CED8DED6DC
D3D4D5D5DBDADED8DCD4D5D1D7D3D5D5D8DBD7D6C7D8CDE0CEDDD5D8D8D4DAD9DBD0D4D9
D7D1D8CDD8CCD7D8D7CFDDC6D8C1D5D5DFDCDADBDAD7D8DBD2DBCEE9D0E4DDDFDDD8DBD9
DFD9DDDCE1D8E3D8E2D9DCDDE0D8E9D4EBD5E4DAE5E0E4E2DFDFDBE1D9E0CDE6CFE4D4D1
CFD5D6DFD9DDD8DAE0DAE7D6E6D4E1DADBCEDECEECD2E8D2DDDDDFD8D8DEDAD9D2E1D2EB
D7EBDFE1DDDDDEE1DCE4DCE1E8E0E9D7E4D3DDD7E0D1E0B8DBC6E3D4E0DBDFDFDFE0DCE1
DCE9D8EFD9EADCE0E2DCE4DEE4E0E0E3E4DFE6DAE8E0E9E3E4DBEBD7F0DCEAE0E6E5E2E4
DEE6E0E5DEE9DBEEDEE9DFE2E7DFE3D9DFDFE2E4E2E1DEE7E4E6E0E3E6E5E8E1E8E5E9E3
E7E8E2E7E3E8E2E2DFE9DEEADFE9E5E4E6E1E8DFE3E1E1E2DDDEDBE3DDDFDDE2E5E2E4E0
E7E1E3E1EAE5E7E3E2E4DFE1DFE8E5E1DFE0E4DCE4E1E9DFE3E1E1E1E2E4E2E7E0E4E0E1
E4E7E4E7E6E1E2DDE5E2E2DEE1E1DAE2DEE4E4E8E6E2E7E6E5E2E6E1E8E3E7E4EAE9E8E8
E1E8DFE4E0EBE1EAD8DEDAD8E3E0E3E2E4E7E2E3E6E8E3E7E1E6E3E5E4DEEADBECDCE7E1
E0DDE1DEDFE4E2E6E3EDD6EDD6E9DEE5E3E5E1E8E4EBE6E6E4E4EBE5E8E1E8E9E8E0E9D7
EED8EBDFE7E4E8E5E5E9E6EADBE8D2F1D9F1E1E8
DCE0D7DADADFD3D1D8D6D6D7D8DADBDDD8D5CDD4D2DBD8DAD8D6DAD4D8D2D6D5D7D5D3D4
D0D7CAC8CED3D3D8D8D6DAD8DCD8DAD6D6D9D6D9D0D7D7D9D8D7DBD6D9D3D4D1D4DBD8D9
CFCCCDD9D0D4D2D1D9D0D9D5D9D3D5D9D8DAD5DAD3D6D0D1D3D7CFD8D1DCE3DED7D2D4D0
CED1D3DDD9D8DFD3E9D5E0D8D6DBDCDDDEDAD6D8D4E1D3E3CFDCD3D4DBD3DAD4D8D3D3D5
D9D3D3C6D8D3DCDBE3DBE4CFE4CBE0D5D9D9E0DDDADCDADFD5E1C7E6CCE6D7DFDBD9D1D8
CEDDD3DCD6D1DDCEE2D7E2D7DFD2E3C9E5CCDFD3DCD5D6D5D6D8D5DBD1E3CCE8CBE3D1D5
D6D7D7D7D7D8DADCDBCFD8C2E4D3DED1DBD1E3C8E1C7D9CED7D6D2D3CFD4CDD9C8E1C8DE
CEE3C9E1D9D4DCD3D7D3D4D5DDD2E0CFDBC0D9D0DAD0E2C5E1C7DBD0D8D9D0DFCEE1D3DF
CFEACDE4D0E4CDDCD9DBDFDEDDDBD8D8D7D4E3D3E2CDD6CED4C8DAC3E5CDDDD1D9DCDCDE
D8DCD7E4CEDDCCE6CDDED3DCDAD5D6D4D7DDD9DBDDD9E1D5DED1D9D5DFD9E1CCE1CBDBCB
D4D3D5DCD7DCD2D7D9E2D6E0D4DDD8D8DCDCDAD8D6D5D6D8DBDAD9D8D9DCDFE1DAD8DBD6
DBD8DFE0E0D9DBDADBDDD8DACFD0CEDCD4D9DDDBDDD9DCD6DCD9DEDCD8D9D3D7D2D8D4D6
DAD7D7D6D9D9DAD9DED5D8DADAD8D5DED7DDDADADADBE1DEE3DEDEDAD7D0C9D3DCE1D8DD
D5D5D5D5D7D6DDD9DFD9DBD8D8D3D7D5D7DDD6D8D0D3E0D1E0CCDACED9D8DDD7DAD5DBDC
DBE1CEE2C8D9CAD5D6D9D4DDCDD1CBD3DDDBDBDEDEDBDBDEE1D8E6D5E5CEE5D5DED8DCDA
E1DBDEDCD9DDD4E9D4E9D5E2D6DDD8E5DBE7DEE2E1DCDFDDDADAD7DDE1D8E4D1E7D2E3CC
D2CFDFD1E3D3DFD7DBE7D2EBCEE8D6E3D4D8CDE1D1E1DADADDDCDFD9D9DFDCDBE0DDE8D4
EAD4E5D7E1D8E8D6E7DAE2DEDBE5D1EBD1ECD9E3DEE1C5CEBBDDD7E0E1DCE0E0E0E1DDE3
E3DEEAD9EED5E7DBE6DDE4DEE3DFE0E4E2EBD9ECD7F1E2E8E1E5DDE9DFEBE2E5E9E6E3E3
DCE7E0E8E0DDE7DDEDDCEBE0E7DFE4DADFDFE1E3E4E5E1E9E5E9E3E6E7E6E8E1E8E6E9E4
E4E8E5E9E1E6E3E7E4E5E9E0ECE1EDE4E9E3EAE1E6E3E3E4DFE0DDE5DEE1DEE4E7E2E6E3
E8E2E5E2EAE5E7E3E4E6E1E2DFE8E5E2E1E3E7E0E6E3EBE0E4E2E2E3E4E4E0E6DFE6E3E5
E8EAE5E7E5E1E4E0E7E4E4E1E3E1DCE5DFE4E3E6E4E2E9E9E5E2E6E2EAE6EAE6EBE9E7E8
E1E8E0E4E6E7ECDFE4D6E1D6E4E0E4E3E5E8E3E5E8EAE5E9E3E8E4E6E6E8E3E8E2E7E3E6
E1DEE1DEDFE3E0E4E7E3E6DBE6D8E6E0EAE1ECDDEFDEE9E1DEE8DFEFDCECE1E9E5EADEEB
E2E9E5E4E6E3E7E5E5E9E6E9E6E3EBDFF0DCE8DC
DDE0D8DCDBDFD5D5D5D3D2D5D7D8D9DBDCDAD2D8D7E0D8D5D8D7DCD6DAD3D6D4D6D2CFD1
CED6CACACED4D3D7D8D5DAD8DCD8DAD6D7DAD6D8D0D7D6D8D9D8DCD7D9D5D6D1D4DAD7D9
D4D1CDD6D1D7D6D9D8D1DBD6DAD6D8D8D8D9D5DAD4D8D2D3D7D2D8CEDBD1E8D5D8D1D2CF
CFD2D3DCD8E5D5E5D9E1D8DDE1DEDCDCDCDAD8D9D6D7DFD2DFCFDCD1DCD2DBD5D8D5D6D7
D0DCC7DACAE3D2DDD9DED4DFD5DADADFDCD8DCDBDDE1DCDDDFD5E1CDE5CADFD4DDD3DCD1
DBD4D7D7D1E1CEE5CAE9D5DCD8DED0E0D0E1D6DDDFD6D6D6D8DAD6D9D7D4E3CFE7CDE0D0
D6D7D8D8D7D8DBDED5DEC2E0CEEFD5DECFD9CFDFCEE1D7DDD8D8D5D7D3D6CDD8DBCFE6CD
E4CBE0D3DAD5DDD3D6D3D3D5CFDBC1E3BAD3C9DDD7DCD2DFD0DBD2DAD9D5DEDADFDCDADB
DBD0E8D1E2CAE8D1D7D8DEDDDCDCD8DAD6E4D2E7CCDEC9D5D3D3C4D8CCE2DAE1D9DDDADC
DCE0D3DCD6D3E0D1DFC7DAD5DBD5D6D4D7DDD9DBD4DED1E5D0E3D6DFDCE3D4DFD2DCD6D4
D4D6DBE0D8DAD2DADBDCDED5DFD5E1D8DDDDDBDAD8D7D7D7DCDDDDDCDBDBDDDEDDDBDED8
DCD7DCDADFDADDDBDCDED9DBD1D2CCDBDADEDDD8DCDAE0DDE4DEDFDBDCDDD8DDD7DCD8DA
DBD1DBCDDED0DCD8DBD5D9DADADAD7DED1DADADCDBDDE6E5E5DEDFDBD6CFC9D1DBE0D8DF
D8DAD9D8DAD8DED9DED6D7D4DBD3D7D2D5DCD4D8CDDCD2E1D1DCD5D7D8D8DCD4D9D6DDDB
DED8DDD5DBCFD4D2D8CEE4D1E2C7D8CFDCDADCDFE0DEDEE1D9E4D2EAD1E4DADFE0DADDDC
E5DEE1DFDAD2E2D9E7DCE0DFE0D9E9D7EAD5E1D8E2DDE0DDDBDBD8DFDBE5D4E9D5EADFD9
D2D7D8DDDAE0DCDCE0DBE4D6E2D5E1DDDBCEE5CEE7CEE7DADCDBDFDCDDE2E0E3DBEBD4E8
D2E5D8DFE2E1E1E2DEE5DEE2E3DBE5D5E7D7E3DBE0D0DFB9DFCCE9DBE3DDE1E0E1E2DFE4
DBE6D3EED8E9DDE5E7DDE4E0E6E2E4EAE2E3EADFE9E5EAE2E9E1EFDCF0DEEBE3EDE7E6E2
DBE6DDE6E1E9DAEFDAE8DFE0E6DFE5DBE0DEE0E2E4E5E2E9E5E9E5E8E7E6E9E1E8E6E9E4
E2E7E5E8E0E5E4E9E6EEE3EBE0E8E4E2E9E4EBE2E7E5E5E6E1E2DFE6E0E3E0E6E7E3E7E2
E6E3E8E2E9E4E6E3E5E8E2E2DCE4E3E3E4E5EAE5E8E3EAE2E5E1E2E5E4E5DFE3E0E7E4E8
E4E7E3E5E4E2E7E5E8E4E5E3E4E2DDE8E1E5E2E4E3E2E9E9E6E2E6E2EBE8EBE7EBE8E5E7
E1E9E1E6DEE9DEE6DCE2DEDEE2DFE4E2E4E7E3E5E5E7E3E7E1E5E0E2E5DFEADCEBDEEAE5
E6E2E5E1E0E3E0E4E2EEDDF2DCEADFE4E9E8E3E8E4E7E4E7E3E4E9E4E8E6EAE7EAE3EEDB
F1D8EBDEE4E1E6E3E4E7E4E7DDEBD5F5DBF2E0E6
E0E3DADDDBDED5D8D7D6D8DDDFDDDADADCDED8DBD7E0D9D4D9D8DDD7DAD3D7D5D4D2D0D2
CCD4CDD3CED4D3D8D9D7DDDBDDD8DBD8D9DDD8DAD5DAD7D9DBDADDD7DAD8DBD6D6DBD7D7
D1D0C8CECDD3D0D7D6D1DDD7DADADBD6D9DAD5DBD6DCD6D7D6D9D4DCDBE2F1E0D6D2D6D3
D1D3D4DEDADFE1D9E4D6DFDCE7E1DCDCDCDAD7D7D4DED3DCD1D8D6D6DFD4DDD7D9D6D9D9
D2D6D2D0D5DADADDDDDAE2D6E1CDDEDBDBD8DDDBDCDFDBDDD6DDCDE0CFDAD4DBDAD7D7DE
D7DCD0D5D3D5D9D5D7D6DBDDE3DDE4D3DECFD9D4DBD5D7D7D8D9D6DAD4E1D2E2D2DFD6D6
DAD9D9DADBDBDBDADCD6D7CBDCD3D8D5D5D3DFD0DDD4DFD9D7D9D8DBD6D9CED8D4DFD3DD
D9E1D3DCDCD7DED4D7D3D4D6D2D2D1CECFC0CCD3DBD2E1D3E5D0DEDCDADBD6DDD2E1D6DF
D6E4D3DCD6DDD4D7D6D4DBD8D7DBD7DBDCDDE1D5DCD0D3D5DDCBD3CBD9D1E1D9DBDAD9DD
DBE2D5D6D0D7CDDFD2D9D6DCDDD8D8D5D8DDD9DCD9D9DEDADDD9DCDBE2E1E2D7E0D5DFD5
D2D6DDE2D8DAD3DDD8E0D7DDD7DDDEDCDEDEDEDEDDDCDBDADEE0E1DFDCDAD9D9D8D7DCD9
E0DCE0DEDEDBDEDCDCDFDADCD0D5CCD8DADEDBD9E3DEDFD8DFDBE0DEDCDFDCE1DBDED9DA
D9D7D2D9D5D9D6DADDDADDDBDBDCD7DAD9E1DFE0DEDDE2DFE4DDDFDDD7D0C9CEDADFD8E1
DCDDDCDBD8D7DDD9DFD9DCD9E2D8DCD4D6DED6DBD9DCE0D5DCD1DDD6D9D6DBD7DCD6DBDB
DADDD2E2D2DDD1D9D7D4DADDD7D3D5D4DDDBDCDFE0DFE0E3DDE0E2DCE3D5DCD8DED9DCDC
E5DFE1DFDCDDDBE6DCE5D9E1DBDEDDE3DFE2DDDEE5E0E3E1DFE0DEE5E4E1E7D9E3D8E3D1
D2D2E0D6E5DCE2DAD9E2D6E7D3E3D6DEDBDADDE0DADEDDDCDCDADFDDDDDFDDE4DAE0E0D7
E1D7E1DEE3DBE7D9E6DEE4E3DDE1D7E4D8E6DCE1D8D9CECFCEDFDEDCE4DEE2E1E1E2E0E5
E4E1E2DEE5D7E0DBE6DCE4E1E8E2E4EADFEAE1EADBEDE2E3E6E8E5E8E4E8E5E7EBE5E7E4
DDE8DCE5DFDEE1E2E5E0E9E2E4E0E7DDE0DDDFE2E0E3E1E7E2E8E4E7E6E5E9E2E9E6E9E3
E4E6E2E6E0E6E4E7E1E4E5E0E8E2ECE5E8E2E9E1E7E4E5E6E1E2DFE7E1E4E1E7E5E2E6DF
E2E3EAE1E8E3E6E4E5E8E0E0DCE2E1E5E5E2E6E3E8E0E8E2E6DFE1E6E2E7DEE2E3E8E1E8
E5E8E5E5E1DCE0DEE7E3E4E3E5E2DDEAE3E6E2E5E4E1E6E4E7E3E5E2EAE7E9E5E9E6E4E5
E1EAE3E7E1E9E5DBE2D7DAD7DEDDE2E0E1E4E0E4E6E9E5EAE3E7E1E3DFE0E0E1E0E0DFDF
E5E1E3DEDCDEDADDDDE0E1E0E3DBE2DFEAE1E7DAE3D4DDDCE2E7DDE5DAE9E2E4E0E3DFE1
E2E0E6E5E2DFE4E2E2E5E2E4DFE0DEDFE3DEE3DE
E2E5DCDEDBDCD4D8DAD6D4D7D9D8D8D9DCE2DCDAD4DEDAD7DBD9DDD7DAD3D7D6D7D8D9D8
CCD1CBD4CED3D3D9DAD9DFDEDED9DCDADBDFDADBD9DDD9DADCDCDED7DADBDFDAD9DCD7D6
D3D5CCD1D2D6CFD8D5D1DFD8DBDDDED6DADAD6DCD8DED9DADBD9D7D5D8D4E6CED4D3DAD7
D3D3D5E0D6E1DBE0DDDBDCE0DCD9DBDEDDD7D4D4D6DAD7D3D5D2DBD7E1D5DED9D9D6D9D9
D3DCCDD5CBDFD9E3D9DCDCDEDCD4DDE1D8DAE2DED9DAD9DFDFDDDCDADED2DCDBE1D8DAD6
D8D7D4D8D0D6CCDECCD9D4E3DCDEDADCD5DAD9DDD5D3D8D7D6D7D5DCD8DBDBD6DCD6DDD6
DEDBD9DBDFDFDAD6CED3C7D0CAD7D2DDD0D6D6D9D4DDDCDED6D9D9DDD9DBCFD9DED3DFD7
DED4DDD0DED9E0D5D8D4D5D7CFDBCCE2D2D6CAD7DCD8DBE0DFD7D8DED5D4D7D8D5DBD4D7
DFDADBD2DED4DDCEDAD7DDD8D8DEDBE1D5DFD6DCD3DBD5E0D5C9CAD6CFD8DBD6DCD7DADF
D8E2DCDBD6D3D3D5DCD4DBD8E0DADBD7D8DDD9DCD4DAD6E1D8E1DCE1E1E5DBDCD6D7D6D1
D0D3DAE1D9DCD5DED9DCDAD8DBDAE1DDDEDFE0E1E2E1E0DEDADDE0E0DEDCDBDADCDBE0DC
E2DCDEDADDDBDFDCDCDFDBDDCCD8D0D7D6D9D8DEDEDBDFDAE0DADBD6DADEDCE2DBDDD7D8
DCD4DBD5E1D5DCDADCDBE0DCDCDFDADBDAE0DEE1E2E2E6E2E2DBE1E1DBD4CCCFDBE0DAE2
DDDFDDDBDCDAE0DCE1DCDFDCE9DEE1D8D9E2D9E0D8DFD8DAD5DAE0E1DBD5DBDCE1D6DADE
DEDCD9DCD8D7D4D6E1D6E3D6DCCAD6CFE0DDDCDEDFDEE1E4D5E4D9E5DCDFD7DDDBD5D9D9
E3DDDFDCE3DDE4DFE2DFDCDFE1DEE5DDE5DBDFDAE3DEE1E0DFE0DEE6D8DEDADED7DFE1D7
CDD3DBDBE1E0DFD8D5D9DCDFDEDEDCDCDFD5E5D8E6D8E1D6DED9DEDDDAD8D6DFD6E5D9E0
D7DEDADFDFDAE0DADFE0E1E4E3E0E2DCE0DBDDDBE0D3D2B9D0D0E5DFE4DFE2E1E1E3E0E6
DBE0D5E5DCE1DFE4E5DBE4E1E7DFDFE4E2E8E5DFDCE3E5E4E3E0E7DFE8E1E9E7E5E1E6E4
DFEBDDE6E3E5DEEADCE2E1DDE2DFE8DEE1DDDEE2E1E4E2E8E3E9E7E9E6E5E9E2E9E6E9E3
E6E6DFE4E1E8E3E4E2E8E2E3E1E2E5E1E6E1E8E0E6E4E4E6E0E2DFE7E1E4E1E7E3E0E5DC
DFE3EBDFE8E3E6E4E5E7DFDDDFE3E2E6E4DEE0DEE8DEE5E2E6DEDFE7E1E9DFE2E6E9DEE6
DCE2E1E4E1DCE1E0E6E2E4E3E5E1DDEAE5E7E3E6E5E1E4E0E8E3E5E1E9E5E7E3E8E5E2E4
E1EBE4E8D6E4DADADFDDDADEDBDBE1DFDEE1DEE3E1E4E1E6DFE2DCDDDEDCE2DBE1D7DAD5
DCD8D9D3D1D2CED1CED5CAD5CBD2D4D8D1CED0CFD3D0D7DCDDDDD5D4D2DBDAD9E4E0E5D6
E2D2E3DDE0DEE3E1E1E4E0E3D4DCCCDFD2E1DCE0
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{398.938, 198.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007b0000mb000`400?l00000o`00003ooooooooc
ooooo`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00oooooooc
ooooo`00ooooooocooooo`004?ooool01`1OGel0H61P05eMG@1LG5`0Fe]K065QH@1NGUh00P1MGEd0
101IFET0EUIF05ADE01JFUX305MGE`80E5AD00<0EeMG05QHF01GEeL00P1EEED0201ADE40De=C059B
DP1BDU80De=C05IFEP1EEED0E5AD0`1@D5004@1CDe<0EeMG05MGE`1@D500De=C055AD@1EEED0Cdm?
051@D01BDU80De=C055AD@1>CTh0De=C051@D01ADE40CTi>0080CDe=00@0EEEE055AD@1>CTh0BTY:
0P1@D50204m?C`0I051@D01=CDd0De=C04i>CP1=CDd0CTi>04m?C`1>CTh0EEEE051@D01<C4`0Bd];
04e=C@1;Bd/0B4Q804a<C01=CDd0Bd];04Y:BP16ATH0BDU904Q8B01:BTX0Bd];04i>CP0204Q8B009
04a<C01=CDd0D51@04e=C@1<C4`0BDU904e=C@1>CTh0AdM70080BTY:01X0BDU904e=C@1:BTX0Bd];
04U9B@1<C4`0BTY:04U9B@1>CTh0AdM704Q8B017AdL0BDU904E5A@16ATH0B4Q804Y:BP16ATH0CDe=
04M7A`16ATH0B4Q804U9B@18B4P0ATI604E5A@80B4Q801T0DE5A06i^KP21PH40Shn?0:>SX`2n_[h0
_;bl09VIV@1bLW80EUIF04a<C01>CTh0BDU904A4A016ATH0AdM704Q8B012@T80AdM704];B`17AdL0
ADE504I6AP13@d<0AdM70080ADE50200A4A404Y:BP1<C4`0DE5A04m?C`1FEUH0CDe=051@D01?Cdl0
D51@04];B`19BDT0C4a<04];B`1>CTh0DE5A04M7A`18B4P0AdM70492@P18B4P0BTY:059BDP15ADD0
ATI60492@P14A4@0ATI604Y:BP1DE5@0DU9B04a<C0<0ATI600H0ADE504=3@`13@d<0ATI604A4A016
ATH204];B`0L04e=C@1>CTh0DE5A055AD@1EEED0Bd];04a<C01=CDd0Hf=S08F5Q@2;Rh/0PH6106m_
K`1OGel0DE5A04];B`1?Cdl0H61P06a/K028R8P0S8b<08n?S`1oOgl0EUIF04];B`15ADD0@D5104A4
A080ADE500/0@d=30451@@13@d<0CTi>06i^KP2BTY80QXJ606i^KP1MGEd0DU9B04i>CP0204M7A`0>
04=3@`0m?Cd0KFe]04A4A013@d<0BDU905iNGP1JFUX0EEEE05YJFP1/K6`0NWYj08b<S02HV9P209JF
UP0?09VIV@2NWYh0Y:BT09jNWP2>SXh0LW9b06=SH`1QHF40Jf][08R8R02PX:00Vi^K06=SH`1=CDd0
@T920080?Cdm00/0>CTi0410@00o?cl0>SXj03dm?@0n?Sh0@T9203`l?00n?Sh0>c/k03`l?0020410
@00403`l?00m?Cd0?3`l04=3@`80?Cdm00h0>c/k03Ti>@0l?3`0?3`l03dm?@11@D40?clo03Xj>P0i
>CT0>c/k03Xj>P0k>c/0>SXj03dm?@<0?3`l0140?Cdm03`l?00k>c/0?Shn03dm?@0l?3`0?Cdm0451
@@0l?3`0>SXj03hn?P10@400>CTi03/k>`0m?Cd0?3`l03/k>`0203`l?080?Cdm0P0l?3`01`0n?Sh0
BTY:03`l?00l?3`0=cLg03Xj>P0h>3P00P0l?3`00`0i>CT0>3Ph03`l?00203Ti>@0303Ph>00j>SX0
>c/k0080=SHf00D0>3Ph03Xj>P0l?3`0?3`l03Xj>P0303/k>`<0>CTi00<0=cLg03Ph>00h>3P00`0i
>CT303/k>`0803Xj>P0h>3P0>CTi03Ti>@0j>SX0?3`l03Ph>00k>c/203dm?@0303`l?00j>SX0>SXj
0080>SXj0P0k>c/203Ti>@0:03Ph>00f=SH0>CTi03Hf=P0j>SX0>CTi03/k>`0i>CT0>3Ph03Xj>P@0
>3Ph00`0>c/k03Xj>P0g=cL0>CTi03Ph>00i>CT0=cLg03Ti>@0g=cL0>SXj03Lg=`0e=CD203/k>`03
03Xj>P0h>3P0>CTi0080>SXj00/0>CTi03Ph>00h>3P0=SHf03Ph>00g=cL0>3Ph03/k>`0j>SX0=cLg
03Ti>@0203Xj>P0>03/k>`0f=SH0>3Ph03Lg=`0i>CT0>SXj03Lg=`0f=SH0>CTi03Ph>00f=SH0>3Ph
03Ti>@0h>3P203Ti>@80>3Ph0`0g=cL0100h>3P0>CTi03Ph>00k>c/303Ph>080=SHf00<0>c/k03Ti
>@0h>3P03Oooool0013ooooo0P1DE5@02P1ADE40Cdm?055AD@1DE5@0DE5A051@D01BDU80CTi>055A
D@1=CDd2051@D004055AD@1BDU80Cdm?04i>CP80C4a<00L0DE5A04i>CP1;Bd/0C4a<04];B`1>CTh0
Bd];00@0C4a<0P1;Bd/0101CDe<0Cdm?04a<C01BDU8204i>CP0:04];B`1>CTh0BDU904];B`1:BTX0
C4a<04U9B@16ATH0Bd];04i>CP80Bd];00<0BDU904a<C01=CDd00P1:BTX02P18B4P0BDU904M7A`1>
CTh0BTY:04M7A`19BDT0C4a<04Q8B01:BTX205EEE@0K055AD@1>CTh0BTY:04Y:BP19BDT0B4Q804i>
CP1:BTX0AdM704I6AP1<C4`0CDe=04M7A`19BDT0B4Q804];B`1:BTX0ADE504i>CP15ADD0ATI604=3
@`16ATH0BDU904E5A@13@d<0ADE50080B4Q800T0@d=304A4A014A4@0ADE504=3@`1:BTX0Bd];04I6
AP17AdL00P18B4P01`1:BTX0BDU904A4A016ATH0@d=30492@P11@D400P13@d<0>`15ADD0AdM70492
@P13@d<0AdM70492@P16ATH0CDe=051@D01BDU80Fe]K04a<C01>CTh0Cdm?04U9B@1lO7`0Ti>C06MW
I`1=CDd0BDU904Q8B01;Bd/0BTY:04M7A`16ATH0@D5104M7A`12@T80@D5104=3@`12@T80@d=304M7
A`1:BTX0B4Q804];B`16ATH0B4Q804I6AP1=CDd0C4a<04i>CP1;Bd/0DE5A04e=C@1<C4`0Bd];04E5
A@19BDT0De=C05mOG`13@d<0@T9204];B`1=CDd0Bd];0492@P19BDT0ADE50080AdM700l0@D5104=3
@`12@T80AdM704A4A01:BTX0GEeM06QXJ01eMGD0KVi^06ATI01NGUh0EeMG04Q8B015ADD00P13@d<0
3`19BDT0AdM703lo?`14A4@0AdM704=3@`14A4@0@T9204=3@`10@400NWYj0:f][@33`l<0_kno0:^[
Z`020:>SX`0609VIV@27QhL0LW9b06QXJ01dM7@0VIVI0P2KVi/0202PX:00UIFE07MgM`1SHf<0E5AD
04Q8B010@400DU9B0P1kNg/02`2DU9@0OWin08:2PP2<S8`0WYjN09>CT`2RXZ80YJFU09JFUP1fMWH0
L71`0080HV9R01`0F5QH04m?C`1:BTX0DU9B04];B`13@d<0@T9204I6AP1@D500GEeM05iNGP1SHf<0
EEEE059BDP1ADE40F5QH05mOG`1eMGD0NGUi07moO`21PH40Kfm_06=SH`1NGUh0BDU90451@@0k>c/0
?Cdm0P0n?Sh01P0m?Cd0?3`l03Xj>P0l?3`0?Cdm03/k>`80>SXj0`0l?3`04P0n?Sh0>c/k03hn?P0i
>CT0?3`l03hn?P0j>SX0>c/k03dm?@0n?Sh0>SXj03hn?P0m?Cd0>3Ph03hn?P0m?Cd0?3`l03/k>`<0
>SXj00P0?Cdm03Ti>@0m?Cd0>CTi03Xj>P0k>c/0>SXj03lo?`80?3`l00D0>CTi03Xj>P0h>3P0>SXj
03/k>`0203Xj>P0<03hn?P0k>c/0>c/k03`l?00k>c/0>CTi03`l?00j>SX0>3Ph03hn?P0l?3`0>c/k
0P0i>CT0100k>c/0>3Ph03/k>`0g=cL303Ph>00303Ti>@0g=cL0>SXj00@0>CTi00L0>3Ph03De=@0g
=cL0>SXj03hn?P0l?3`0>SXj0080>c/k00H0=CDe03Ph>00m?Cd0>c/k03Xj>P0i>CT203Xj>P0<03Hf
=P0g=cL0?3`l03dm?@0j>SX0>c/k0410@00n?Sh0@41004I6AP17AdL0BDU90P0n?Sh0100k>c/0>3Ph
03Hf=P0g=cL203Ti>@0703Xj>P0o?cl0?Shn03Lg=`0f=SH0=cLg03Ph>00203Ti>@0403/k>`0j>SX0
>CTi03Xj>P80>3Ph00<0>c/k03Xj>P0l?3`00P0k>c/0100j>SX0>CTi03hn?P0h>3P203Xj>P0;03/k
>`0j>SX0>3Ph03/k>`0j>SX0=SHf03Xj>P0f=SH0=cLg03Ph>00g=cL00P0h>3P303Lg=`0:03Hf=P0h
>3P0=cLg03Lg=`0f=SH0>3Ph03Xj>P0i>CT0=cLg03Hf=PD0>3Ph00<0>CTi03Ph>00f=SH00`0f=SH0
1P0i>CT0>SXj03Lg=`0i>CT0=cLg03Xj>P80>CTi0`0j>SX0200g=cL0>CTi03Xj>P0j>SX0=cLg03De
=@0h>3P0?3`l3Oooool0013ooooo00P0DU9B055AD@1?Cdl0Bd];051@D01CDe<0C4a<04i>CP80CDe=
0P1@D50204e=C@0:04a<C01;Bd/0CDe=04];B`19BDT0BTY:04];B`1:BTX0Bd];04Y:BP<0BDU900T0
BTY:04U9B@1=CDd0Bd];04Y:BP1?Cdl0DE5A04Y:BP18B4P0101=CDd02`1:BTX0B4Q804I6AP19BDT0
B4Q804I6AP14A4@0B4Q804M7A`18B4P0BTY:00<0B4Q800D0BDU904I6AP14A4@0BDU904Y:BP0204A4
A00304I6AP1=CDd0B4Q80080B4Q800h0Bd];04M7A`16ATH0BDU90492@P17AdL0B4Q804I6AP1=CDd0
ATI60492@P14A4@0ADE504I6AP80A4A40P18B4P03`19BDT0AdM704A4A012@T80@D510492@P11@D40
@T9204=3@`11@D40AdM704E5A@12@T80BTY:04E5A@020492@P0404I6AP11@D40@d=304M7A`80ADE5
00D0AdM704I6AP14A4@0B4Q804A4A00204=3@`80@D510P10@4002P17AdL0A4A405=CD`1MGEd0CDe=
04=3@`14A4@0B4Q804E5A@1;Bd/2055AD@0804Q8B01;Bd/0DU9B05EEE@1GEeL0DU9B051@D017AdL2
04I6AP0l04a<C01LG5`0C4a<04I6AP0n?Sh0@d=30451@@14A4@0BTY:04I6AP1;Bd/0ATI604a<C01:
BTX0C4a<04Y:BP1@D500BTY:04I6AP1?Cdl0@T9203hn?P0o?cl0@41003`l?00m?Cd0ADE504U9B@13
@d<0@D5104m?C`1`L700NWYj069RHP1WIfL0Fe]K04];B`0k>c/0?Cdm04=3@`12@T80@d=30410@011
@D40ADE504=3@`1CDe<0JFUY08V9R@2TY:@0_;bl0<30`02SXj<0QHF507QhN01fMWH0PX:208N7Q`1h
N7P0J6QX0P1MGEd0@01HF5P0DE5A04Y:BP15ADD0D51@05mOG`1TI6@0IFEU06UYJ@1oOgl0P82008B4
Q026QXH0WYjN0:>SX`2KVi/0ZZZZ0;6a/@2b/[80]KFe0;^k^`2n_[h0/;2`09VIV@1/K6`0I6AT07Mg
M`2<S8`0VIVI0:>SX`2QXJ40P82008J6QP2=SHd0Ng]k07MgM`1lO7`0LG5a08>3P`21PH40V9RH09VI
V@2DU9@0OGem0820P022PX80Rh^;07QhN01NGUh0De=C04I6AP1FEUH0L71`06YZJP1`L700FEUI04=3
@`11@D40>SXj03dm?@0n?Sh0@T9203/k>`0l?3`303Ti>@0803Xj>P0k>c/0>c/k03Xj>P0l?3`0>SXj
03`l?00n?Sh303`l?00;03Xj>P0l?3`0?clo03/k>`0i>CT0?3`l0492@P0i>CT0>SXj03lo?`10@400
0P0m?Cd01@0o?cl0?3`l03Xj>P0o?cl0>CTi0080?3`l00H0>SXj03Ti>@0j>SX0>CTi03`l?00j>SX3
03/k>`0>03Xj>P0l?3`0?3`l03dm?@0h>3P0>c/k03Ti>@0j>SX0?3`l0410@00n?Sh0?Cdm03hn?P10
@40203hn?P0;03/k>`12@T80>c/k03Ph>00f=SH0=cLg03`l?00k>c/0>SXj03Ti>@0j>SX00P0i>CT0
2@0o?cl0>c/k03Xj>P0h>3P0=SHf03Ph>00i>CT0=cLg03/k>`0203Lg=`0B03Ph>00l?3`0>SXj03Ti
>@0j>SX0>3Ph03/k>`0j>SX0>c/k03Ti>@0g=cL0>SXj03`l?00k>c/0>SXj03/k>`0n?Sh0>3Ph0`0j
>SX02`11@D40HV9R07]kN`22PX80QHF5061PH01ADE40BDU904=3@`0h>3P0>CTi0080=cLg00<0>c/k
03Xj>P0i>CT00P0l?3`203Xj>P0303Lg=`0f=SH0>3Ph0080>3Ph00/0>SXj03/k>`0g=cL0=cLg03Ti
>@0g=cL0>SXj03/k>`0i>CT0?3`l03Ph>00203@d=00503Lg=`0j>SX0>3Ph03Ti>@0k>c/00P0j>SX0
0`0g=cL0>SXj03Ph>00203Ti>@0503`l?00m?Cd0>c/k03Hf=P0h>3P00P0g=cL0100f=SH0>CTi03Ph
>00e=CD203Ph>00503Ti>@0g=cL0<c<c03<c<`0f=SH0100g=cL02@0f=SH0=cLg03Xj>P0f=SH0=cLg
03Ti>@0g=cL0>SXj03Ti>@0203Lg=`80=SHf0P0g=cL203Ph>00703Ti>@0j>SX0>3Ph03Lg=`0h>3P0
>SXj03Lg=`0203Hf=P0303Ph>?oooooooooo00_ooooo000@ooooo`0:05=CD`1ADE40DE5A04i>CP1B
DU80De=C04];B`1=CDd0DE5A04e=C@80Bd];0P19BDT02018B4P0BDU904i>CP1@D500B4Q804M7A`1;
Bd/0B4Q81019BDT06@1;Bd/0BTY:04Q8B01<C4`0Bd];04I6AP19BDT0CDe=04i>CP1?Cdl0Bd];04e=
C@17AdL0A4A404];B`19BDT0B4Q804];B`16ATH0AdM704U9B@1FEUH0C4a<04E5A@17AdL00P15ADD0
3P17AdL0ATI604A4A016ATH0BDU904I6AP14A4@0@T9204U9B@1:BTX0ATI60492@P18B4P0A4A40P16
ATH01P14A4@0@T920492@P18B4P0@T9204U9B@80ADE500<0A4A40410@012@T800P14A4@02016ATH0
AdM704I6AP19BDT0AdM704E5A@16ATH0A4A40P12@T803@15ADD0@d=304=3@`12@T80A4A4055AD@10
@400@D5104E5A@17AdL0A4A404U9B@13@d<00P14A4@0:@15ADD0@T9204=3@`19BDT0B4Q804E5A@13
@d<0ATI60410@00n?Sh0ADE504I6AP1HF5P0N7Qh06a/K01CDe<0E5AD061PH01UIFD0HV9R04m?C`16
ATH0?clo04A4A00o?cl0?Cdm03lo?`12@T80@4100451@@0n?Sh0?clo04M7A`1ADE40JVYZ06EUI@1R
HV80Jf][06ATI01BDU80E5AD00<0EUIF00P0CTi>04=3@`14A4@0ATI604e=C@1EEED0AdM704E5A@80
B4Q80100?clo04=3@`19BDT0BDU904E5A@1ADE40Cdm?04Y:BP14A4@0@D5104Y:BP14A4@0ATI604A4
A019BDT0@4100P0o?cl04@0n?Sh0@4100451@@11@D40?clo04I6AP19BDT0A4A403hn?P15ADD0CDe=
05eMG@1YJFT0LW9b07EeM@1VIVH0GemO0080J6QX00d0H61P06EUI@1ZJVX0Ph>308^;R`1hN7P0K6a/
07EeM@1nOWh0N7Qh07YjNP24Q8@0Shn?0080YZJV00l0Xj>S08j>SP28R8P0UYJF09fMW@2IVIT0WYjN
0:^[Z`2a/K40^k^k0<C4a03?cll0alO70;2`/02?Shl00P25QHD01`1oOgl0Rh^;07YjNP1SHf<0IFEU
06MWI`1<C4`00P11@D402`0o?cl0Cdm?05YJFP1ZJVX0O7al06QXJ01mOGd0RHV9092@T02UYJD0[Jf]
0080^;Rh0180S8b<04m?C`1GEeL0O7al09BDU01ZJVX0BTY:04U9B@1GEeL0@41003dm?@0n?Sh0?Cdm
03Xj>P0n?Sh0>CTi03dm?@0k>c/203`l?00:03/k>`0m?Cd0>c/k03dm?@0o?cl0?Shn03lo?`0n?Sh0
>c/k03Ti>@80>SXj00<0>c/k03dm?@11@D400P0k>c/01`0l?3`0@41003hn?P0l?3`0?Shn03/k>`12
@T800`0k>c/0100l?3`0?Cdm03dm?@0n?Sh303Ti>@0503Xj>P0l?3`0?Cdm03dm?@0i>CT00P0k>c/0
7`0j>SX0=cLg03Ti>@0h>3P0>SXj03/k>`0h>3P0?Cdm04Q8B017AdL0?Shn03Ti>@0h>3P0@D5103Xj
>P0h>3P0>CTi03Xj>P0h>3P0>CTi03/k>`0m?Cd0>c/k03Ph>00j>SX0?3`l03Ti>@0h>3P0=cLg03De
=@0g=cL00P0j>SX07P0i>CT0=cLg03`l?00m?Cd0>SXj03Hf=P0g=cL0?3`l03Xj>P0h>3P0>CTi03dm
?@0k>c/0>CTi03Xj>P0i>CT0>SXj03Ph>00j>SX0?clo03/k>`18B4P0Hf=S07emO@2OWil0bl_;0<S8
b02][Jd0Ng]k04Y:BP80>CTi00D0=cLg03Ph>00l?3`0>SXj03Lg=`0203Ti>@0603Xj>P0o?cl0?Shn
03Xj>P0h>3P0=cLg100h>3P03P0g=cL0>CTi03Ti>@0h>3P0>CTi03Lg=`0j>SX0>c/k03Ti>@0h>3P0
=cLg03Ph>00k>c/0>CTi0`0k>c/0100l?3`0=cLg03Ti>@0h>3P203Ti>@80>SXj00<0>3Ph03Xj>P0j
>SX00`0g=cL203Hf=P80>SXj00<0=cLg03Xj>P0g=cL00`0f=SH01@0e=CD0=SHf03Lg=`0g=cL0=SHf
0080=cLg00/0>3Ph03Ti>@0f=SH0=cLg03Ph>00e=CD0=cLg03Hf=P0g=cL0>3Ph03De=@0203@d=080
=SHf0P0e=CD01P0g=cL0=SHf03dm?@0m?Cd0=SHf03Lg=`80=SHf00<0=CDeooooooooool02oooool0
013ooooo00T0DU9B04e=C@1@D500D51@04a<C01=CDd0Bd];04m?C`1<C4`00P1:BTX204e=C@0404Y:
BP1<C4`0D51@051@D080BTY:00/0Bd];04I6AP19BDT0C4a<04Y:BP17AdL0B4Q804];B`17AdL0BDU9
04Y:BP0204];B`80BTY:00l0BDU904Y:BP18B4P0Bd];04Q8B01:BTX0C4a<04Q8B01;Bd/0C4a<04A4
A018B4P0CDe=04a<C017AdL00P15ADD01P13@d<0ADE504E5A@17AdL0BTY:04U9B@80ATI60140A4A4
04M7A`1>CTh0Cdm?0410@013@d<0@D5104M7A`1:BTX0A4A404m?C`10@400@T9203lo?`19BDT0Bd];
04=3@`020451@@80ATI60P13@d<01`14A4@0ATI604A4A011@D40@41003lo?`18B4P00P0o?cl01P10
@400@D5103lo?`13@d<0A4A404=3@`80@D5100<0?Shn04A4A012@T800`10@4003`12@T80@4100451
@@0n?Sh0@d=304I6AP17AdL0?clo0451@@0o?cl0@4100451@@16ATH0B4Q804U9B@0204e=C@0>04Q8
B013@d<0BDU90492@P0n?Sh0@D5103lo?`11@D40@41004A4A013@d<0?clo04=3@`10@4020451@@08
03lo?`10@400@T9204I6AP1CDe<0GUiN06ATI01LG5`204m?C`0>05EEE@1>CTh0Cdm?04U9B@1>CTh0
Bd];04Y:BP1<C4`0ADE504Q8B01:BTX0B4Q8051@D018B4P204I6AP0B04U9B@1=CDd0CDe=04m?C`19
BDT0@d=30492@P10@400A4A404=3@`19BDT0BTY:04e=C@1CDe<0DU9B055AD@19BDT0@4100P12@T82
04=3@`0503hn?P0l?3`0@T920410@00o?cl00P0n?Sh02@16ATH0A4A404A4A016ATH0B4Q804U9B@1;
Bd/0A4A404=3@`0204I6AP0U04=3@`1:BTX0EUIF05aLG01XJ6P0MWIf08f=S@2HV9P0YJFU0:j^[P2l
_;`0_Kfm0:j^[P2DU9@0Q8B407alO01nOWh0LG5a0861P@2>SXh0TI6A09FEU@20P800N7Qh09FEU@2<
S8`0Lg=c06IVIP28R8P0QhN707YjNP1cLg<0K6a/06MWI`1GEeL0De=C06MWI`0205]KF`0<04m?C`1:
BTX0FEUI07EeM@1jNWX0PX:207QhN01fMWH0PH610820P01:BTX0?Shn0P17AdL01010@400ATI605=C
D`1DE5@404a<C00604];B`16ATH0>SXj03Xj>P0i>CT0>c/k0P0l?3`02@0k>c/0>SXj03Ph>00j>SX0
>c/k03Ti>@0k>c/0?Cdm03hn?P0203dm?@0703lo?`0m?Cd0?3`l03Xj>P0m?Cd0>c/k03`l?00303/k
>`0703lo?`0m?Cd0>c/k03dm?@0j>SX0>c/k03`l?00203/k>`0803`l?00j>SX0?3`l03dm?@10@400
>c/k03`l?00j>SX203Ti>@0@03/k>`0i>CT0?Cdm03/k>`0j>SX0?Cdm03Ti>@0h>3P0?3`l03lo?`0k
>c/0>SXj03dm?@0n?Sh0>SXj03`l?080?Cdm00P0>SXj03/k>`0j>SX0?Shn03`l?00i>CT0>c/k03Lg
=`80>3Ph0`0i>CT0200j>SX0?clo03Ti>@0i>CT0>c/k03Xj>P0h>3P0=cLg0P0i>CT01@0g=cL0?3`l
03`l?00m?Cd0>3Ph0080>CTi01P0=cLg03Ph>00k>c/0?3`l05YJFP1aLG40VIVI0:2PX02i^KT0/k>c
09BDU01eMGD0I6AT04M7A`0j>SX0=SHf03`l?00f=SH0>CTi03/k>`0h>3P0=SHf03Ph>00i>CT203Xj
>P0403Ti>@0j>SX0=CDe038b<P80=SHf0P0g=cL01@0i>CT0>c/k03Ph>00g=cL0>SXj0080>3Ph00@0
>c/k03Xj>P0i>CT0>SXj100k>c/02P0l?3`0>CTi03Lg=`0h>3P0?3`l03Ph>00g=cL0>c/k03Ti>@0k
>c/303Ph>080=cLg0P0f=SH203De=@0303Hf=P0j>SX0=SHf0080>CTi00T0=SHf03Lg=`0i>CT0=cLg
03Hf=P0h>3P0>SXj03dm?@0k>c/00P0e=CD203Ph>0@0=SHf0P0i>CT203De=@0903<c<`0f=SH0>CTi
03Hf=P0e=CD0=SHf03Lg=`0h>3P0=cLg0080=SHf0`0g=cL=ooooo`004?ooool204m?C`06059BDP1<
C4`0Bd];04e=C@1?Cdl0Bd];0P1<C4`0101?Cdl0D51@04Q8B01:BTX204m?C`0704U9B@17AdL0AdM7
04Y:BP1;Bd/0BTY:04];B`0204U9B@0304Y:BP18B4P0BDU90080Bd];0140BDU904Q8B018B4P0B4Q8
04a<C01;Bd/0CTi>04];B`18B4P0AdM704a<C017AdL0CDe=055AD@16ATH0B4Q804e=C@0204U9B@80
A4A401d0AdM704Y:BP11@D40@d=304U9B@17AdL0B4Q804a<C012@T80ATI604e=C@1:BTX0BDU904M7
A`12@T80ATI604U9B@18B4P0BTY:04=3@`11@D40ATI604A4A017AdL0ADE50492@P14A4@0ATI604=3
@`0203lo?`0404M7A`10@400?clo03lo?`80@41000h0A4A403`l?00o?cl0ATI604E5A@12@T80?Shn
0492@P17AdL0ADE503dm?@15ADD0?clo04A4A080?clo00P0@D5104Q8B00o?cl0ADE504A4A012@T80
?clo0451@@80A4A401@0@D5104I6AP19BDT0ADE50410@012@T80@d=303lo?`0n?Sh0@D5104I6AP0m
?Cd0?3`l04=3@`12@T80ATI604E5A@18B4P0@D510410@080@T9200P0@41003dm?@0o?cl0AdM705UI
F@1PH600Cdm?04a<C080DE5A00d0C4a<04];B`1;Bd/0BDU904m?C`1ADE40CDe=04m?C`1CDe<0CDe=
04A4A018B4P0Bd];0080DE5A00L0BTY:0492@P14A4@0ADE504Y:BP1;Bd/0@D510080ADE500@0Cdm?
04Q8B01;Bd/0BDU90P18B4P0101@D500Cdm?059BDP1IFET2059BDP0;05aLG01BDU80@T920410@00o
?cl0@41004A4A015ADD0A4A403lo?`15ADD00P11@D404P12@T80@D510410@015ADD0A4A404I6AP19
BDT0MWIf08:2PP1eMGD0JVYZ08N7Q`2PX:00Shn?07moO`1`L700J6QX05]KF`80FEUI00<0De=C059B
DP1NGUh00P1PH6004@1LG5`0I6AT06i^KP20P800SHf=0;Bd]034a<@0[Jf]07=cL`1ZJVX0UYJF09>C
T`2IVIT0QXJ6079bLP1lO7`0T92@0080Z:RX00P0ZZZZ0:>SX`2PX:00ZJVY08j>SP1OGel0D51@04E5
A@80BDU90200B4Q804e=C@1:BTX0EUIF051@D01PH600HV9R061PH01QHF40GUiN05eMG@1UIFD0H61P
06IVIP1bLW80NWYj06][J`1LG5`0E5AD055AD@1SHf<0G5aL065QH@1EEED0A4A403lo?`0m?Cd0>c/k
03dm?@0i>CT0>SXj03/k>`80@4100P0l?3`03@0n?Sh0?Cdm03/k>`0m?Cd0@41003dm?@10@400?Shn
03lo?`14A4@0@d=30492@P0m?Cd00`0l?3`01@0k>c/0>SXj03Xj>P0l?3`0@D510080>c/k0P0l?3`0
100j>SX0?3`l0410@00m?Cd203`l?00A03Ti>@0k>c/0>SXj03Ti>@0j>SX0>c/k03Ti>@0k>c/0>CTi
03/k>`0m?Cd0>c/k03`l?00k>c/0>SXj03`l?00i>CT00P0j>SX0400i>CT0>3Ph03Ph>00i>CT0>3Ph
03`l?00i>CT0>c/k03Lg=`0m?Cd0?3`l03/k>`0m?Cd0>c/k03Ti>@0k>c/203Ti>@0303`l?00o?cl0
>c/k0080?3`l00P0?Shn03`l?00j>SX0>CTi03/k>`0n?Sh0A4A405QHF080J6QX00P0De=C05MGE`1M
GEd0B4Q803Xj>P0k>c/0>CTi03Ph>080=cLg00/0>3Ph03Ti>@0h>3P0>3Ph03Xj>P0i>CT0?Cdm03/k
>`0i>CT0>c/k03Ph>00203Hf=P0803Lg=`0e=CD0>SXj03`l?00i>CT0=cLg03Ti>@0j>SX203Ti>@08
03Ph>00n?Sh0>c/k03Xj>P0l?3`0>SXj03dm?@0h>3P203/k>`0D03Lg=`0e=CD0>SXj03Ph>00i>CT0
=SHf03Lg=`0h>3P0>SXj03Ph>00i>CT0>SXj03Ti>@0j>SX0?Shn03lo?`0l?3`0>CTi03Ph>00g=cL2
03Hf=P0903Lg=`0d=3@0=SHf03Ph>00c<c<0>SXj03Ti>@0k>c/0>3Ph0080=cLg00P0=SHf03Ti>@0k
>c/0>SXj03Lg=`0f=SH0=cLg03Ph>080=CDe0`0f=SH00`0h>3P0>CTi03Hf=P0303Ti>@0603Lg=`0i
>CT0=3@d03De=@0h>3P0>c/k3Oooool0013ooooo00X0Cdm?04a<C01=CDd0BTY:04];B`1<C4`0Bd];
04a<C01;Bd/0BDU90P1:BTX09@19BDT0ATI604Q8B01;Bd/0CTi>04a<C01=CDd0BDU904a<C019BDT0
ADE504Y:BP18B4P0C4a<04Q8B017AdL0BTY:04Q8B01=CDd0A4A404U9B@14A4@0B4Q804M7A`16ATH0
BDU904Q8B016ATH0AdM704E5A@16ATH0A4A404M7A`1:BTX0ATI604M7A`16ATH00P18B4P00`19BDT0
C4a<04U9B@0204I6AP0604=3@`18B4P0AdM704Q8B01;Bd/0@T920`14A4@00`13@d<0A4A404M7A`02
04A4A00404=3@`10@400ADE504=3@`80AdM70P11@D405`16ATH0@d=303hn?P0o?cl0?Shn0492@P0l
?3`0AdM70410@011@D40?clo03dm?@11@D40?clo0410@014A4@0?Shn04=3@`14A4@0?clo04E5A@0n
?Sh0@4100080?clo0180@T9204=3@`17AdL0A4A40451@@0n?Sh0@41004=3@`0o?cl0@T9204A4A012
@T80@41004Y:BP1;Bd/0A4A404Q8B010@4020492@P0304=3@`16ATH0@41000<0?Shn00<0A4A403lo
?`13@d<00P10@4001@14A4@0AdM7051@D01OGel0G5aL0080E5AD00T0D51@04M7A`14A4@0AdM704I6
AP15ADD0@d=304M7A`15ADD00P0o?cl01P11@D40@d=303/k>`0m?Cd0?Shn0492@P<0@41000<0?clo
03/k>`10@4000P12@T804@0m?Cd0ATI60492@P16ATH0@d=30410@013@d<0?Shn0451@@0o?cl0@T92
0410@00l?3`0@4100492@P0n?Sh0@41000<0@D5100D0@T9204Y:BP1ADE40HF5Q06UYJ@0306ATI00>
05YJFP1EEED0GemO05IFEP1ADE40DU9B04e=C@15ADD0GemO08:2PP2FUYH0VYZJ0;jn_P3=cLd20=OG
e`0/0<g=c@33`l<0[:b/0:JVYP2HV9P0RXZ:07EeM@1VIVH0EUIF04m?C`16ATH0=cLg04=3@`11@D40
Cdm?06MWI`2?Shl0V9RH06ATI016ATH0CTi>055AD@1IFET0E5AD04A4A013@d<0ATI605YJFP1VIVH0
Kfm_065QH@1NGUh0K6a/079bLP1^KVh0HV9R04Q8B01<C4`0BDU904i>CP1XJ6P0PX:209VIV@2][Jd2
0<G5a@0P0<o?c`3@d=00/[:b09RHV01iNGT0LG5a06MWI`1]KFd0M7Ad08N7Q`28R8P0MWIf05UIF@1?
Cdl0Bd];06UYJ@23Ph<0NGUi08Z:RP27QhL0NGUi08B4Q01]KFd0A4A40451@@0o?cl0?Cdm03Ti>@0j
>SX0?Cdm03Xj>P0l?3`303Xj>P0:03`l?00h>3P0>SXj03Xj>P0k>c/0?Cdm03`l?00i>CT0>c/k03hn
?P80?3`l00@0>SXj03`l?011@D40?clo0P0n?Sh0200l?3`0@d=303dm?@0k>c/0>SXj03`l?00k>c/0
?Cdm0`0k>c/203Ti>@0<03/k>`0o?cl0?3`l03Xj>P0m?Cd0>c/k03dm?@0l?3`0>CTi03/k>`0m?Cd0
=cLg0P0i>CT02@0h>3P0>CTi03Ti>@0j>SX0>CTi03dm?@0n?Sh0?Cdm03/k>`0203Ti>@80?3`l00l0
>SXj03dm?@0n?Sh0>SXj03Ph>00j>SX0?3`l03/k>`0j>SX0>CTi03`l?00h>3P0=cLg03Xj>P0k>c/0
0`0i>CT0100l?3`0>CTi03/k>`0j>SX203/k>`0403Ph>00j>SX0>c/k03Xj>P80?Shn00H0>SXj03Ti
>@0i>CT0>CTi03Lg=`0j>SX203Ti>@0803/k>`0i>CT0=cLg03Ph>00k>c/0>SXj03Ti>@0h>3P203Xj
>P80>3Ph00<0>CTi03`l?00j>SX00P0j>SX02P0m?Cd0?Shn03Hf=P0j>SX0?3`l03/k>`0g=cL0>SXj
0410@00i>CT203De=@0303Ti>@0j>SX0>CTi0080>3Ph00H0>CTi03Ph>00g=cL0>3Ph03Lg=`0h>3P2
03Ti>@0303Ph>00g=cL0=cLg0080>3Ph00d0>SXj03Ph>00g=cL0=cLg03Ph>00g=cL0>CTi03Ph>00g
=cL0>SXj03Ph>00g=cL0>CTi0080=SHf00@0>CTi03Ph>00g=cL0>3Ph0P0g=cL01@0e=CD0=3@d03Hf
=P0h>3P0=cLg0080=SHf00L0=cLg03Hf=P0i>CT0=cLg03Hf=P0e=CD0=SHf00gooooo000@ooooo`80
CTi>00X0CDe=04U9B@1>CTh0C4a<04U9B@1;Bd/0B4Q804M7A`19BDT0BTY:0`17AdL01P1<C4`0Cdm?
04];B`1;Bd/0AdM704Q8B080ADE501@0Bd];04M7A`18B4P0BDU904a<C01=CDd0BTY:04i>CP13@d<0
ATI604];B`1?Cdl0ADE504=3@`15ADD0A4A404I6AP1;Bd/0B4Q804E5A@80ATI600X0B4Q804E5A@11
@D40ATI604U9B@15ADD0@D5104I6AP15ADD0@d=30P15ADD01`13@d<0@D5104A4A016ATH0@d=304E5
A@13@d<00P15ADD204A4A00I04E5A@11@D40@T920451@@14A4@0@D5104=3@`15ADD0A4A40492@P13
@d<0A4A404E5A@13@d<0A4A40451@@12@T80ADE50410@011@D40?clo0451@@10@400@d=30451@@02
0492@P030410@00n?Sh0?Shn0080A4A400H0@41003lo?`0k>c/0?Shn03lo?`11@D420410@00?03lo
?`13@d<0?clo04E5A@1<C4`0BTY:04E5A@1@D500Kfm_06EUI@1>CTh0@d=303lo?`14A4@0@T920080
?clo00D0?Shn03lo?`0m?Cd0?Shn04I6AP0304A4A00<05ADE01TI6@0JFUY06QXJ01TI6@0EeMG04Q8
B01;Bd/0C4a<0492@P0m?Cd0@4100P11@D401`15ADD0@D5103hn?P0o?cl0@D510410@012@T800`0n
?Sh01P0o?cl0@41004E5A@15ADD0@T920410@080@D5100d0@T9204I6AP15ADD0@d=304A4A017AdL0
@T9204E5A@11@D40?3`l0451@@0o?cl0?Shn00<0?clo0140?Cdm03Ti>@0l?3`0@41003hn?P10@400
ATI604Q8B016ATH0@T9204a<C01@D500FUYJ06IVIP1^KVh0MgMg06e]K@02065QH@0N07emO@21PH40
Ng]k071`L01VIVH0F5QH05IFEP1]KFd0PH6108n?S`2DU9@0Shn?08V9R@2EUID0WIfM0;Vi^@32`/80
_;bl0;^k^`2c/k<0Ti>C06YZJP1VIVH0Fe]K075aL@29RHT0Ph>308F5Q@1VIVH0MWIf0P2ATI402P2;
Rh/0RHV908^;R`2OWil0JVYZ04I6AP12@T80@d=303dm?@0k>c/20410@00X03`l?01<C4`0B4Q804];
B`1HF5P0B4Q804Y:BP1QHF40LG5a07]kN`1hN7P0OGem096AT@2g]kL0/K6a0:RXZ02PX:00W9bL09BD
U01nOWh0KVi^07]kN`2FUYH0WinO0;Rh^01lO7`0Bd];0451@@10@400ATI604=3@`1:BTX0GUiN06MW
I`1IFET0ATI60451@@0o?cl0?Shn03`l?080?Cdm00<0>SXj03Ph>00i>CT00`0k>c/0:`0h>3P0>c/k
03Ph>00j>SX0>c/k03`l?00m?Cd0@D5104E5A@12@T80?3`l03Xj>P0l?3`0@41003dm?@0j>SX0?Cdm
03`l?00m?Cd0>SXj03`l?00m?Cd0>3Ph03/k>`12@T80?Cdm03Xj>P0m?Cd0>c/k03hn?P0m?Cd0>c/k
03lo?`15ADD0C4a<04I6AP11@D40?Cdm03Ti>@0n?Sh0@T9203/k>`0j>SX00P0i>CT203Xj>P0403dm
?@0k>c/0>c/k03Lg=`80>CTi00D0?Cdm03`l?00k>c/0?3`l03Ti>@0203Ph>0<0>SXj00@0>3Ph03Ti
>@0h>3P0>CTi0`0j>SX02`0h>3P0>CTi03Xj>P0i>CT0>SXj03`l?00k>c/0>3Ph03Ti>@0m?Cd0?3`l
0080>SXj00d0=cLg03@d=00f=SH0>3Ph03Lg=`0h>3P0>SXj03Ti>@0g=cL0>CTi03/k>`0j>SX0>3Ph
0080>SXj00H0>3Ph03Xj>P0j>SX0=cLg03Hf=P0i>CT203Xj>P80=SHf00d0=cLg03Ph>00l?3`0@T92
03Xj>P0e=CD0>3Ph03Ti>@0k>c/0>SXj03Lg=`0m?Cd0?3`l0080=cLg00<0?3`l03Ti>@0h>3P00P0g
=cL0200f=SH0>3Ph03Ti>@0i>CT0=CDe03Xj>P0k>c/0=SHf100g=cL02`0j>SX0@41003/k>`0f=SH0
>3Ph03Xj>P0i>CT0>c/k03Ph>00i>CT0>3Ph00@0=SHf00L0=CDe03<c<`0e=CD0=SHf03Ph>00g=cL0
=SHf00<0=cLg00P0>3Ph03Ti>@0i>CT0>3Ph03De=@0f=SH0=CDe03Ph>080=cLg00<0>3Ph03Xj>_oo
ool03?ooool0013ooooo00<0DE5A04m?C`1<C4`00P1<C4`04`1;Bd/0CTi>04i>CP19BDT0B4Q804];
B`1<C4`0AdM704Y:BP18B4P0AdM704U9B@1:BTX0B4Q804Y:BP17AdL0ADE504U9B@17AdL00P19BDT2
04a<C00304I6AP19BDT0BDU90080BTY:00l0AdM704U9B@14A4@0ADE504A4A015ADD0ATI604Y:BP15
ADD0AdM704I6AP1<C4`0AdM70451@@15ADD00P16ATH06`18B4P0A4A404I6AP12@T80A4A404M7A`1:
BTX0BDU904I6AP11@D40A4A40451@@1;Bd/0BDU904I6AP12@T80A4A404=3@`12@T80A4A404Y:BP11
@D40ADE504I6AP13@d<0@D5104=3@`020492@P0<04A4A015ADD0ADE504M7A`13@d<0?clo03dm?@10
@400?Shn04A4A015ADD0A4A40P11@D4204=3@`050410@00l?3`0?clo03lo?`10@4000P0o?cl0>00n
?Sh0@D510451@@14A4@0ATI60492@P0o?cl0@T9204=3@`1<C4`0EeMG05iNGP17AdL0DU9B069RHP1C
De<0A4A403dm?@11@D40?Shn0492@P0m?Cd0?clo03dm?@15ADD0CTi>04];B`1=CDd0BDU904a<C01F
EUH0HF5Q05mOG`1IFET0DE5A04];B`17AdL0@T9204Q8B014A4@0@41003dm?@11@D40@T920451@@10
@400@d=303lo?`10@400?Cdm03`l?00o?cl0A4A40492@P0o?cl0?3`l0P0m?Cd01@14A4@0?Shn03dm
?@0m?Cd0@D5100@0?clo00T0?Cdm0492@P0o?cl0ATI60451@@12@T80ATI604E5A@16ATH00P1<C4`0
1`1;Bd/0CTi>04U9B@16ATH0E5AD07EeM@2DU9@00P2EUID05@2FUYH0T92@07IfMP1OGel0EeMG05EE
E@1GEeL0D51@04];B`16ATH0A4A404e=C@1@D500EEEE06UYJ@1`L700JFUY05mOG`1BDU80BDU904A4
A00204=3@`0L04A4A018B4P0CTi>05EEE@1SHf<0MGEe09>CT`2MWId0TI6A09JFUP2JVYX0YZJV0;Rh
^032`/80_[jn0;:b/P2GUiL0Vi^K0:ZZZP2e]KD0/K6a0;>c/`33`l<0aLG507EeM@1<C4`0A4A404E5
A@80?clo00H0BTY:05MGE`1=CDd0@T920451@@13@d<204U9B@0304=3@`11@D40AdM70080@d=300D0
AdM704Q8B017AdL0JFUY0:BTY0030=;BdP80clo?01T0]kNg09fMW@2_[jl0fMWI0=3@d02e]KD0N7Qh
04Q8B00j>SX0?Shn04a<C01NGUh0HV9R065QH@1VIVH0@41003lo?`0m?Cd0>c/k03dm?@0l?3`0>c/k
03Xj>P0i>CT0?Cdm0080>SXj00H0>3Ph03/k>`0j>SX0?3`l03Ti>@0l?3`503Ti>@0303/k>`0l?3`0
?3`l0080?Cdm00H0@41003Lg=`0j>SX0>SXj03`l?00i>CT203dm?@0C03lo?`0m?Cd0>c/k03`l?00g
=cL0?3`l04=3@`1NGUh0SXj>0:f][@2o_kl0/k>c08j>SP1RHV80BDU904a<C017AdL0@T9203/k>`02
03Ti>@80>c/k00L0>CTi03/k>`0h>3P0>c/k03`l?00m?Cd0@4100080>c/k0P0i>CT0100j>SX0>CTi
03Ti>@0h>3P203Lg=`0303/k>`0f=SH0>SXj0080>c/k0P0j>SX03`0h>3P0>CTi03Ti>@0m?Cd0>3Ph
03`l?00j>SX0=SHf03Ph>00f=SH0A4A403/k>`0l?3`0=cLg03Hf=P0203Lg=`0303Hf=P0j>SX0>c/k
0080>SXj00L0>CTi03Xj>P0j>SX0>c/k03Ti>@0f=SH0>3Ph0080=SHf00P0>SXj03/k>`0k>c/0>3Ph
03Hf=P0h>3P0=SHf03/k>`80>CTi00l0?Shn03Xj>P0f=SH0>3Ph03/k>`0l?3`0>c/k03Ti>@0f=SH0
>3Ph03Hf=P0k>c/0?Shn03Ti>@0f=SH00P0h>3P303Ti>@0403Lg=`0h>3P0>3Ph03Ph>080=CDe0P0f
=SH00`0g=cL0>CTi03Ti>@0203Ph>00303`l?00g=cL0>SXj0080>CTi00@0=cLg03Hf=P0i>CT0>3Ph
0P0e=CD01P0g=cL0=CDe03Lg=`0i>CT0=SHf03De=@@0>3Ph00<0=SHf03Ph>00h>3P00P0g=cL01P0e
=CD0=cLg03Lg=`0f=SH0=cLg03Ph>0gooooo000@ooooo`80Cdm?00<0D51@04i>CP1<C4`00P1;Bd/2
04a<C00304Y:BP1;Bd/0BTY:0080B4Q800D0BTY:04E5A@1<C4`0Bd];04Q8B00204U9B@0B04a<C017
AdL0DU9B05IFEP1:BTX0AdM704Q8B017AdL0ATI604M7A`16ATH0B4Q804A4A017AdL0A4A40492@P15
ADD0AdM70P19BDT01`16ATH0BTY:04I6AP18B4P0@d=304I6AP11@D400`13@d<304A4A080AdM700<0
ADE50451@@11@D400P15ADD00`0o?cl0@D5104=3@`020492@P0C0410@011@D40?clo0451@@13@d<0
?Shn0410@00o?cl0ATI60451@@12@T80BTY:0492@P13@d<0A4A404=3@`15ADD0@d=30492@P0203lo
?`0803hn?P13@d<0A4A404=3@`11@D40A4A403lo?`10@4020492@P0k04=3@`10@400?Shn04I6AP1@
D500BDU904E5A@16ATH0Cdm?055AD@1?Cdl0BDU9055AD@1:BTX0A4A404E5A@14A4@0?clo0451@@0n
?Sh0?Cdm03lo?`0m?Cd0?clo0451@@17AdL0@4100451@@16ATH0Fe]K05mOG`1?Cdl0@T9204A4A010
@400BDU904I6AP17AdL0ATI60492@P0o?cl0@D5104=3@`11@D40?Cdm03`l?011@D40@T9203hn?P12
@T80>CTi0410@00m?Cd0@41003lo?`12@T80@d=30410@011@D400P12@T803P10@400>c/k03lo?`0m
?Cd0@41003lo?`12@T80@D510410@00l?3`0?Shn03/k>`10@400?Cdm0P0o?cl08P0n?Sh0A4A4059B
DP2<S8`0Shn?05EEE@1QHF40JVYZ07UiN@1aLG40PX:208Z:RP29RHT0O7al07MgM`26QXH0U9BD08n?
S`28R8P0OWin07=cL`1SHf<0J6QX06e]K@1dM7@0K6a/065QH@1HF5P0C4a<03lo?`0l?3`0@d=303lo
?`11@D420410@00O0451@@14A4@0?3`l04i>CP2BTY80/[:b0;bl_02PX:00QhN70:FUY@2`/;00alO7
0;no_`39bLT0e]KF0=GEe@3@d=00^;Rh0<?3``2l_;`0[:b/0:^[Z`2DU9@0QhN70861P@1oOgl0NGUi
0820P02ATI40SHf=08:2PP0207QhN00/07YjNP1XJ6P0FUYJ06=SH`1YJFT0D51@04E5A@1:BTX0DE5A
051@D017AdL0BDU9055AD@1FEUH0DE5A05=CD`1WIfL0QhN708F5Q@2PX:00/;2`09^KV`2:RXX0QHF5
08R8R02g]kL0alO70<c<c03=cLd0W9bL06][J`1MGEd0BTY:04M7A`1EEED0MWIf08J6QP1lO7`0M7Ad
06e]K@1HF5P0BDU90451@@0l?3`203dm?@0403Xj>P0n?Sh0>CTi04A4A080?Shn0P0k>c/00`0g=cL0
?3`l03hn?P0203Xj>P0303Lg=`0n?Sh0>CTi0080>SXj00P0>c/k03Xj>P0g=cL0=cLg03`l?00h>3P0
?3`l03dm?@80?Shn0P0l?3`06`0m?Cd0>c/k04I6AP17AdL0IVIV07AdM01gMgL0Jf][061PH01DE5@0
Bd];04a<C01RHV80JFUY04E5A@0o?cl0>CTi03dm?@10@400>3Ph03lo?`0m?Cd0>CTi03Xj>P0l?3`0
?Shn03lo?`0303Ti>@0303`l?00m?Cd0?3`l0080>3Ph00l0>CTi03Ph>00j>SX0>CTi03Ph>00f=SH0
>SXj03lo?`0m?Cd0>CTi03hn?P0l?3`0>CTi03Lg=`0m?Cd00P0j>SX0400g=cL0>CTi0410@00i>CT0
=SHf03Ti>@0g=cL0>SXj03Ti>@0f=SH0>3Ph03`l?00k>c/0>SXj03Lg=`0k>c/203Ph>00603Xj>P0l
?3`0=cLg03De=@0f=SH0=cLg0P0i>CT04`0e=CD0>SXj03Ti>@0i>CT0>SXj03/k>`0h>3P0>CTi03Xj
>P0g=cL0>3Ph03Ti>@0j>SX0=SHf03hn?P0i>CT0>SXj03Hf=P0k>c/00P0h>3P01`0g=cL0>3Ph03Lg
=`0e=CD0=SHf03Ph>00i>CT00P0j>SX00`0i>CT0=3@d03<c<`0203Lg=`0303Hf=P0i>CT0?Shn0080
A4A400@0B4Q80492@P0i>CT0=SHf0P0g=cL06P0h>3P0=cLg03De=@0g=cL0>3Ph03Hf=P0g=cL0>CTi
03Hf=P0e=CD0=cLg03De=@0f=SH0=CDe03@d=00g=cL0>CTi03Lg=`0f=SH0=CDe03Lg=`0f=SH0=cLg
03Ph>00i>CT0>SXj3Oooool0013ooooo00T0CTi>051@D01?Cdl0CTi>04m?C`1;Bd/0CDe=04];B`1=
CDd00P1;Bd/02019BDT0C4a<04a<C01?Cdl0Bd];04e=C@1:BTX0AdM70P18B4P05@17AdL0BDU904a<
C01=CDd0ATI604Q8B019BDT0B4Q804Y:BP1=CDd0BDU904E5A@14A4@0B4Q804A4A016ATH0ADE504Y:
BP15ADD0A4A404E5A@0204Q8B0<0ATI600L0ADE504U9B@15ADD0B4Q804A4A015ADD0@d=30080A4A4
00X0@d=30410@012@T80ADE504I6AP14A4@0@T920451@@13@d<0ADE50P13@d<01010@400A4A404=3
@`13@d<203hn?P0A04M7A`12@T80ATI60492@P15ADD0@D5104Q8B016ATH0@41003dm?@0o?cl0@D51
03hn?P0m?Cd0A4A40451@@12@T800`11@D40100o?cl0@41004A4A016ATH20451@@0=04E5A@16ATH0
A4A40451@@13@d<0ADE504];B`18B4P0AdM70451@@12@T80?Cdm04A4A0020492@P0C04A4A016ATH0
@T920492@P15ADD0@d=30492@P15ADD0B4Q80410@011@D40?Cdm0451@@0n?Sh0@41003lo?`0n?Sh0
@D5103dm?@0204E5A@0<0410@00o?cl0?clo04=3@`0n?Sh0@d=303lo?`10@400@D5103lo?`0n?Sh0
BTY:0P0o?cl01`0n?Sh0@D510451@@10@400?3`l0492@P11@D400P10@4001@11@D40?Shn03hn?P13
@d<0A4A40080@T9200D0ATI604=3@`11@D40?clo0451@@0203hn?P0804=3@`12@T80Fe]K08:2PP2/
[:`0SHf=05QHF01:BTX204M7A`0V0451@@16ATH0B4Q804M7A`1;Bd/0@d=304I6AP1?Cdl0CDe=04Y:
BP1=CDd0B4Q804I6AP1=CDd0EUIF05eMG@1PH600I6AT05mOG`1FEUH0ADE50410@016ATH0De=C0492
@P17AdL0@d=304E5A@12@T80?Cdm04=3@`1;Bd/0Cdm?06QXJ01_Kfl0M7Ad08F5Q@1lO7`208:2PP0G
08^;R`2KVi/0[:b/0:FUY@2`/;00/[:b0;Fe]@2i^KT0/;2`09nOW`2:RXX0MGEe06ATI01BDU80Bd];
04Y:BP1EEED0H61P06ATI01ZJVX0KVi^08n?S`2l_;`00P3AdM40:@2XZ:P0JVYZ0451@@19BDT0DU9B
04a<C013@d<0EEEE0861P@28R8P0GUiN04Y:BP1=CDd0De=C06ATI01[Jf/0JFUY06EUI@1ZJVX0FUYJ
07EeM@23Ph<0ZZZZ0<O7a`30`<00b/[:0;Zj^P27QhL0PH6106m_K`1VIVH0Ng]k09FEU@2][Jd0_Kfm
0;>c/`2OWil0QXJ607IfMP1KFe/0C4a<0080>3Ph00L0>SXj0492@P0k>c/0?clo03Xj>P0i>CT0>3Ph
00<0?3`l00L0>3Ph03Xj>P0n?Sh0>3Ph03Xj>P0m?Cd0?3`l0080>3Ph0P0m?Cd03P0i>CT0>c/k03hn
?P0m?Cd0>SXj03Ti>@0o?cl0@D510410@00n?Sh0@D5103hn?P0m?Cd0>CTi0P0j>SX0200n?Sh0@T92
0410@011@D40@41003Lg=`0i>CT0>3Ph0P0i>CT02P0j>SX0?Shn03Ti>@0h>3P0>CTi03lo?`0i>CT0
>SXj03Hf=P0h>3P203Xj>P0F03Ti>@0j>SX0>c/k03`l?00m?Cd0>3Ph03`l?00j>SX0>CTi03Lg=`0k
>c/0>CTi03Ph>00m?Cd0>SXj03Ti>@0f=SH0>CTi03Hf=P0m?Cd0?3`l03Ti>@80>3Ph0280?Cdm03Ph
>00h>3P0=3@d03Lg=`0i>CT0?3`l03Ti>@0e=CD0=cLg03Xj>P0h>3P0>CTi03hn?P0j>SX0>CTi03`l
?00i>CT0>3Ph03Lg=`0h>3P0?Cdm03Xj>P0h>3P0>SXj03@d=00j>SX0>c/k03Xj>P0o?cl0?Cdm03Xj
>P0f=SH0=cLg0P0i>CT203Hf=P80>CTi0P0g=cL203Ti>@0603Lg=`0c<c<0=cLg03Xj>P0f=SH0=cLg
1@0h>3P04`0d=3@0>3Ph03/k>`10@400De=C061PH01FEUH0E5AD04E5A@0g=cL0=3@d03Ph>00l?3`0
>SXj03Ti>@0j>SX0=CDe03Ph>00i>CT00P0d=3@303Hf=P0303Lg=`0f=SH0=cLg0080=cLg00H0=SHf
03De=@0g=cL0=CDe03Lg=`0f=SH503Ph>0gooooo000@ooooo`09055AD@1@D500CDe=051@D01=CDd0
Bd];04m?C`1<C4`0D51@0080CTi>00D0Bd];04Y:BP19BDT0C4a<04];B`0204M7A`0L04a<C01>CTh0
BTY:04M7A`18B4P0BDU904a<C01:BTX0C4a<04U9B@18B4P0BDU904];B`18B4P0ADE504M7A`19BDT0
ATI604U9B@1;Bd/0BDU904a<C01:BTX0A4A404Q8B01>CTh0Bd];04E5A@80A4A400D0AdM70492@P17
AdL0@d=304A4A0030492@P0;0410@015ADD0A4A40451@@10@400B4Q804=3@`10@400@D5104Q8B014
A4@00P15ADD03@18B4P0@D510410@013@d<0BTY:04E5A@13@d<0@D5104=3@`0l?3`0@D5105IFEP15
ADD00P0k>c/03`0l?3`0@D5103lo?`0k>c/0?Shn03`l?013@d<0@41003lo?`11@D40?Shn03dm?@10
@400ATI604A4A0020451@@0:0410@00n?Sh0@41004I6AP1:BTX0AdM703hn?P15ADD0@D5103dm?@<0
@D5100H0>SXj04E5A@13@d<0@d=30410@012@T820410@00>0451@@13@d<0@41003hn?P0j>SX0?3`l
03/k>`0l?3`0>3Ph0410@014A4@0?Shn04Q8B017AdL203lo?`0403hn?P12@T80>SXj0451@@80?Cdm
00D0?Shn0410@00n?Sh0ATI604E5A@020492@P0;03hn?P11@D40@d=304=3@`18B4P0@d=30410@011
@D40@4100492@P0o?cl00P1=CDd06@0j>SX0@T9204=3@`11@D40?Shn0410@012@T80?Cdm0492@P1:
BTX0ATI605ADE01]KFd0MGEe08>3P`25QHD0OWin065QH@1ADE40De=C04m?C`1@D500GUiN061PH01C
De<00P12@T801017AdL0@D5104E5A@10@4030492@P0C04E5A@0l?3`0AdM704e=C@16ATH0B4Q80492
@P17AdL0CTi>04Q8B01?Cdl0ADE504U9B@18B4P0A4A403lo?`10@400?Shn03`l?00203dm?@0F03hn
?P0o?cl0@D5104A4A012@T80ADE504M7A`15ADD0CTi>04Y:BP1?Cdl0JFUY07moO`22PX80Ph>307al
O01mOGd0Lg=c06e]K@1ZJVX0I6AT051@D080DE5A0400K6a/0:6QX@3IfMT0eMGE0<k>cP31`L40Vi^K
075aL@1fMWH0GUiN05IFEP1=CDd0CTi>06YZJP27QhL0L71`0492@P0m?Cd0BDU907EeM@13@d<0ATI6
04M7A`1@D500ATI605=CD`1MGEd0LG5a08B4Q02;Rh/0U9BD09:BTP26QXH0/[:b09nOW`2:RXX0Lg=c
07inOP24Q8@0RXZ:08R8R02@T900QHF507YjNP1]KFd0LG5a04a<C00l?3`0=cLg03dm?@0g=cL0?3`l
03dm?@0l?3`0>3Ph03Ti>@0j>SX0?3`l03Ti>@0g=cL0>c/k03Ph>00l?3`0>CTi0P0j>SX203`l?003
03hn?P0j>SX0ATI600<0>SXj0`0k>c/01P0o?cl0?3`l03hn?P0i>CT0?3`l03Ti>@80>SXj00T0?Cdm
03lo?`0k>c/0?Shn03lo?`0l?3`0>3Ph03Xj>P0i>CT00P0h>3P203Ti>@0303Lg=`0l?3`0=SHf0080
>CTi00D0>c/k03Ti>@0d=3@0=SHf03Ph>00203/k>`0>03Ti>@0j>SX0>SXj03`l?00i>CT0=cLg03Ti
>@0l?3`0=SHf03Lg=`0n?Sh0>SXj03Ti>@0e=CD303Xj>P0<03Ti>@0f=SH0>CTi03Hf=P0i>CT0=cLg
03Hf=P0e=CD0=cLg03/k>`0j>SX0>3Ph0P0g=cL02`0m?Cd0?3`l03Lg=`0j>SX0=cLg03Ti>@0j>SX0
>3Ph03Ti>@0h>3P0=cLg0080>3Ph00<0>CTi03Ph>00i>CT00`0j>SX0200i>CT0>SXj03/k>`0f=SH0
=3@d03lo?`0j>SX0>3Ph0`0g=cL02`0i>CT0>3Ph03Lg=`0i>CT0>3Ph03@d=00e=CD0>3Ph03<c<`0e
=CD0=SHf0080=cLg00<0=SHf03Ph>00f=SH00P0i>CT203`l?00;03/k>`0f=SH0?3`l03Lg=`0e=CD0
=SHf03Lg=`0k>c/0>CTi03Lg=`0i>CT00P0h>3P01@0f=SH0=3@d038b<P0c<c<0=CDe0080=SHf00`0
=cLg03Hf=P0f=SH0=cLg03Ph>00d=3@0=SHf030`<00i>CT0?Cdm0451@@0h>3P303Lg=`gooooo000@
ooooo`06051@D01?Cdl0Bd];051@D01>CTh0Bd];0P1<C4`03`1=CDd0BTY:04];B`1:BTX0Bd];04Q8
B01;Bd/0C4a<04Q8B019BDT0AdM704I6AP18B4P0C4a<04Q8B00204U9B@0504Y:BP1<C4`0ATI604I6
AP15ADD00P16ATH02@15ADD0A4A404I6AP12@T80ADE504M7A`16ATH0B4Q804M7A`0204A4A00304I6
AP12@T80A4A40080@d=301H0A4A404Q8B01;Bd/0BDU904I6AP13@d<0@T920451@@10@400@T920451
@@0o?cl0@T9204E5A@14A4@0@T920451@@12@T80@D5104E5A@12@T80ADE50P11@D403014A4@0@d=3
04A4A011@D40@4100451@@15ADD0@d=306IVIP1SHf<0?Shn0492@P80@D5100L0@d=303lo?`11@D40
@41004A4A00o?cl0?Cdm0080?Shn00/0@T9203lo?`12@T80?clo0410@012@T80?clo0451@@0n?Sh0
@41004I6AP020492@P060410@011@D40@d=304=3@`10@400@d=30P14A4@01@0o?cl0ADE50451@@13
@d<0@T920080@41000@0ATI603lo?`0i>CT0?3`l0`13@d<02`0n?Sh0?Cdm03/k>`0m?Cd0@d=304A4
A00o?cl0?Shn0451@@0o?cl0>c/k00<0?Shn00T0?Cdm0451@@0o?cl0?Shn0451@@0n?Sh0@D510410
@012@T800P15ADD01`19BDT0A4A404=3@`16ATH0?Cdm03hn?P0k>c/00P13@d<01`0o?cl0@D510451
@@15ADD0?Shn0410@00n?Sh00`12@T808`16ATH0A4A404Y:BP1?Cdl0EeMG05eMG@1VIVH0JVYZ061P
H01CDe<0EUIF05YJFP1bLW80P82008V9R@1iNGT0I6AT055AD@1?Cdl0C4a<04e=C@1BDU80G5aL051@
D01BDU80CTi>04m?C`1EEED0E5AD05EEE@1;Bd/0@T9204=3@`1>CTh0De=C0080A4A400H0ATI604i>
CP1DE5@0CDe=04Y:BP11@D4203dm?@0A03lo?`18B4P0@T9204E5A@13@d<0?clo0410@011@D40@410
03dm?@0o?cl0B4Q8059BDP1ADE40BDU904A4A018B4P00P1:BTX07@1EEED0I6AT069RHP1UIFD0Hf=S
06IVIP1nOWh0WIfM09bLW02PX:00ZZZZ0:^[Z`2/[:`0ZJVY09nOW`2ZZZX0YjNW09fMW@2UYJD0[jn_
0;Bd]02UYJD0R8R805eMG@1GEeL0@41003hn?P18B4P0ATI60080ADE501H0@d=304];B`1FEUH0KVi^
07EeM@1cLg<0K6a/08R8R02<S8`0Shn?08b<S02GUiL0UIFE06][J`1MGEd0MWIf079bLP1KFe/0FEUI
05EEE@17AdL0@T920P0o?cl01@0l?3`0?clo0410@012@T80?3`l0080>SXj00<0?3`l03Xj>P0j>SX0
0P0k>c/02P11@D40?Cdm03Ph>00i>CT0?3`l03hn?P0o?cl0>c/k0451@@0j>SX203/k>`0U03Xj>P0m
?Cd0>CTi03/k>`0i>CT0>c/k03dm?@0l?3`0?Cdm03/k>`0n?Sh0?Cdm03hn?P0i>CT0?Cdm03Ti>@0k
>c/0=SHf03Ph>00j>SX0?3`l03dm?@0k>c/0?3`l03/k>`10@400>3Ph03lo?`0i>CT0>3Ph03`l?00o
?cl0>c/k03Ph>00l?3`0>c/k03Lg=`0203Xj>P80>CTi00L0>3Ph03Xj>P0l?3`0>3Ph03Ti>@0n?Sh0
?3`l0080>SXj00h0>3Ph03Xj>P0i>CT0?Cdm03/k>`0h>3P0>SXj03/k>`0h>3P0=CDe03Ti>@0h>3P0
>SXj03Ti>@80>SXj00H0>CTi03Ph>00l?3`0>SXj03Ti>@0g=cL203Ph>00@03Ti>@0l?3`0?3`l03/k
>`0j>SX0>CTi03dm?@0k>c/0?3`l03Ph>00i>CT0?3`l03/k>`0j>SX0?Cdm03/k>`@0>SXj00T0>c/k
03Ph>00g=cL0>CTi03Xj>P0h>3P0>CTi03Ph>00g=cL00P0j>SX00`0h>3P0>SXj03/k>`0203Lg=`09
03/k>`0i>CT0>CTi03/k>`0g=cL0>CTi03Ph>00f=SH0=cLg0080>3Ph00<0=SHf03Lg=`0i>CT0100h
>3P0100i>CT0=cLg03De=@0e=CD203Hf=P80=cLg00`0=3@d03Hf=P0h>3P0?Cdm04=3@`14A4@0>c/k
03Ti>@13@d<0A4A403lo?`0i>CT303Lg=`0303Ph>?oooooooooo00_ooooo000@ooooo`0=04a<C01?
Cdl0BTY:04a<C01;Bd/0BDU904Y:BP1@D500C4a<04Y:BP1<C4`0Bd];04Y:BP0204I6AP0704U9B@15
ADD0BDU904Y:BP19BDT0Bd];04a<C00204E5A@0604M7A`1:BTX0B4Q804E5A@14A4@0ADE50P17AdL0
2`1:BTX0ADE504U9B@15ADD0A4A404=3@`17AdL0ATI604M7A`13@d<0ADE50080ATI600L0ADE504A4
A016ATH0A4A403lo?`12@T80ATI600<0@d=30P11@D40300o?cl0@4100410@012@T80?clo04=3@`14
A4@0ATI60410@015ADD0ATI60410@080?Shn00D0@41004M7A`12@T80@d=30451@@020492@P0704=3
@`11@D40@41004E5A@0n?Sh0@d=30451@@0204=3@`0G0410@00o?cl0?Shn03hn?P0o?cl0@41003lo
?`11@D40A4A403hn?P12@T80A4A403lo?`10@400A4A404=3@`16ATH0?Shn03dm?@0o?cl0@D510492
@P15ADD00`16ATH0:00o?cl0@D5103dm?@10@400@D510492@P14A4@0?Shn0451@@0n?Sh0ADE50492
@P0o?cl0@4100451@@0o?cl0@T920451@@10@400?clo03`l?00o?cl0@d=30410@011@D40@41003lo
?`0n?Sh0?Cdm0451@@10@400?Shn0410@00m?Cd0?Shn03dm?@0o?cl0@T9203hn?P0l?3`20410@003
03`l?00m?Cd0?Shn0080A4A403<0@D510492@P0n?Sh0@4100451@@0m?Cd0>c/k04A4A011@D40ATI6
04=3@`17AdL0FEUI06UYJ@1OGel0Cdm?04Y:BP1=CDd0BTY:04M7A`1;Bd/0BTY:04E5A@16ATH0A4A4
0451@@18B4P0IfMW08R8R02;Rh/0OGem07AdM01MGEd0Hf=S08V9R@2FUYH0SHf=07]kN`1]KFd0JFUY
06YZJP1fMWH0PX:209:BTP2^[Zh0Ogmo04a<C019BDT0AdM704=3@`14A4@00`10@4008@15ADD0A4A4
04=3@`0l?3`0?Cdm0410@01:BTX0BDU904Y:BP1<C4`0Cdm?04M7A`1;Bd/0A4A404M7A`15ADD0?clo
0410@00l?3`0@D5104E5A@0k>c/0@41003hn?P1GEeL0G5aL04];B`13@d<0?3`l03Ti>@12@T80?Shn
0410@00204I6AP1704M7A`18B4P0D51@05aLG025QHD0Rh^;08n?S`2DU9@0UYJF09nOW`2PX:00Xj>S
09RHV024Q8@0FEUI03hn?P1KFe/0QhN707]kN`20P800RHV908Z:RP1oOgl0QHF509jNWP2@T900QhN7
096AT@1hN7P0Fe]K06UYJ@1aLG40Shn?08>3P`2?Shl0[jn_0:f][@22PX80S8b<08>3P`1oOgl0Fe]K
04M7A`10@400BDU904A4A01RHV80IVIV04=3@`0n?Sh0>SXj03Ti>@0m?Cd0>3Ph03dm?@0l?3`0ATI6
0492@P0k>c/0?3`l03lo?`0j>SX0?Cdm03lo?`0l?3`0>CTi03/k>`0l?3`0?Cdm03/k>`0h>3P00P0j
>SX02P0m?Cd0?Shn03`l?017AdL0@41003Xj>P0k>c/0>CTi03Xj>P11@D4303/k>`0303Ph>00i>CT0
?Cdm0080>CTi00<0?3`l03Ti>@0i>CT00`0i>CT00`0h>3P0>SXj03/k>`0203`l?00603dm?@0k>c/0
=cLg03`l?00j>SX0=CDe0P0m?Cd0100l?3`0>SXj03Ti>@0k>c/303dm?@0903hn?P10@400>SXj03Ph
>00i>CT0>SXj03Ti>@0n?Sh0>3Ph0080>SXj00X0?3`l03Ti>@0h>3P0>c/k03`l?00i>CT0>3Ph03Hf
=P0g=cL0=SHf0P0h>3P0200f=SH0>3Ph03Ti>@0h>3P0=cLg03Ti>@0j>SX0=3@d0P0i>CT01P0m?Cd0
?3`l03Ph>00h>3P0>c/k03Ph>080>CTi00T0?3`l03Hf=P0j>SX0>CTi03Lg=`0i>CT0>SXj03@d=00j
>SX00P0i>CT203Xj>P80>CTi00<0>3Ph03Xj>P0h>3P00`0h>3P203Lg=`0503Ph>00i>CT0=cLg03Lg
=`0e=CD00P0g=cL01P0i>CT0>3Ph03Hf=P0h>3P0=cLg03Hf=P80>3Ph0`0f=SH02P0d=3@0>3Ph03Hf
=P0b<S80=3@d03dm?@1FEUH0M7Ad07]kN`1TI6@204e=C@0404U9B@15ADD0>CTi03De=@<0=SHf0P0h
>3P=ooooo`004?ooool04@1ADE40DU9B04i>CP1;Bd/0DE5A04e=C@1?Cdl0C4a<051@D01<C4`0BTY:
04I6AP1<C4`0B4Q804M7A`19BDT0BTY:00<0C4a<00L0BTY:04I6AP17AdL0ATI604Q8B01<C4`0BTY:
00<0ATI602T0A4A404=3@`17AdL0ATI604Y:BP16ATH0@d=30410@018B4P0@d=304A4A019BDT0ADE5
04A4A01;Bd/0B4Q80492@P17AdL0A4A404=3@`15ADD0@d=304A4A019BDT0ADE50451@@10@400@d=3
0410@00o?cl0@D5103hn?P16ATH0ADE504I6AP0o?cl0B4Q804U9B@16ATH0@D510410@0020492@P0:
03/k>`11@D40A4A403dm?@0n?Sh0@T9204=3@`11@D40ADE504=3@`80@D5102P0A4A40492@P14A4@0
@D5103`l?00n?Sh0@D5103lo?`10@400ADE504U9B@0o?cl0ATI60410@00m?Cd0ATI604M7A`15ADD0
@T9204M7A`0l?3`0@41004=3@`0n?Sh0?clo04E5A@0o?cl0?3`l0492@P14A4@0AdM70451@@0k>c/0
?clo0492@P0o?cl0?Shn03lo?`14A4@0@D510`12@T803013@d<0@41003hn?P12@T80@4100492@P10
@400@D5103dm?@0n?Sh0@T9204=3@`80?clo00L0@d=30492@P10@400?clo03/k>`0i>CT0>c/k00@0
?Cdm00X0?clo03Ph>00m?Cd0?clo04E5A@13@d<0?clo0410@013@d<0?clo0P13@d<02`17AdL0B4Q8
04e=C@1ADE40C4a<059BDP1PH600Kfm_06=SH`1;Bd/0A4A40080@d=300D0?3`l03lo?`17AdL0@D51
03dm?@020451@@0M03/k>`11@D40DE5A05IFEP1ADE40EeMG05IFEP1DE5@0FEUI06ATI01YJFT0O7al
06UYJ@1;Bd/0EUIF071`L01iNGT0MWIf075aL@1gMgL0GemO05ADE013@d<0ADE50451@@0o?cl0@D51
04=3@`12@T800P0l?3`07010@400@d=30451@@17AdL0BDU904I6AP1EEED0E5AD059BDP1>CTh0EEEE
06=SH`2OWil0ZZZZ09bLW01fMWH0EEEE04a<C01CDe<0Fe]K06][J`1WIfL0J6QX05iNGP1EEED0GUiN
06IVIP1UIFD2065QH@0n05QHF01;Bd/0C4a<059BDP1<C4`0B4Q806UYJ@29RHT0UYJF0;:b/P32`/80
aLG50<S8b030`<00/k>c0:VYZ@2IVIT0PX:207=cL`1SHf<0H61P09ZJVP3;bl/0clo?0<W9b@2QXJ40
];Bd0:JVYP2?Shl0UYJF0:^[Z`2KVi/0HV9R04];B`1LG5`0IfMW06a/K021PH40TI6A0:f][@2YZJT0
_[jn0<_;b`2m_Kd0X:2P071`L01/K6`0ATI603hn?P15ADD0@41003hn?P0k>c/0=cLg03`l?00h>3P0
>c/k03Xj>P0l?3`0?Cdm03Xj>P0o?cl203`l?00503hn?P11@D40@d=303dm?@0i>CT00P0k>c/0300m
?Cd0>SXj03Xj>P0j>SX0?Shn03/k>`0i>CT0>SXj0451@@10@400>SXj03dm?@<0?3`l00@0>c/k03Ti
>@0i>CT0>c/k0P0g=cL05P0i>CT0>SXj03/k>`0k>c/0>CTi03`l?00k>c/0=SHf03/k>`0l?3`0=SHf
03Ti>@0l?3`0>SXj03`l?00i>CT0>3Ph03Xj>P0i>CT0?clo03/k>`0j>SX203Ph>080>c/k00T0?3`l
03dm?@0i>CT0=SHf03Lg=`0i>CT0>SXj03Ti>@0f=SH00P0k>c/02P0j>SX0>c/k03/k>`0j>SX0>3Ph
03Xj>P0k>c/0>CTi03Ph>00f=SH303Lg=`<0>3Ph0P0g=cL203Ti>@0803Ph>00f=SH0>SXj03/k>`0n
?Sh0>SXj03Lg=`0f=SH203Ti>@80?Cdm00T0>CTi03Lg=`0g=cL0>CTi03Xj>P0k>c/0>CTi03Ph>00f
=SH0100g=cL303Ti>@0<03Lg=`0i>CT0=cLg03Lg=`0i>CT0=CDe03Lg=`0f=SH0>CTi03Hf=P0e=CD0
=SHf1@0h>3P0100g=cL0=CDe03Hf=P0h>3P203De=@0?03Ti>@0f=SH0<S8b03Lg=`0f=SH0?Cdm05IF
EP1eMGD0QHF507EeM@1NGUh0A4A403dm?@0k>c/0>SXj0080>3Ph00@0=SHf03@d=00g=cL0=cLg0P0h
>3P=ooooo`004?ooool01P1ADE40DU9B05EEE@1@D500CDe=04a<C080Bd];00<0CDe=04Q8B019BDT0
0P1;Bd/00`18B4P0BDU904Y:BP0304Y:BP0=04a<C01;Bd/0B4Q804];B`17AdL0BDU904E5A@1;Bd/0
BTY:04M7A`19BDT0@T9204I6AP0204E5A@0@04I6AP15ADD0ATI604E5A@12@T80ADE504e=C@1?Cdl0
BTY:04I6AP14A4@0AdM704I6AP19BDT0A4A404I6AP80@T9200X0ADE504=3@`12@T80A4A404I6AP14
A4@0@4100492@P13@d<0A4A40P17AdL01015ADD0@T9204=3@`11@D4304E5A@080492@P11@D40@410
04A4A012@T80B4Q804M7A`11@D420492@P0404M7A`1:BTX0@T9204=3@`80A4A40P15ADD01013@d<0
?Shn03lo?`0m?Cd20492@P0304=3@`14A4@0BDU90080ADE500l0@T9204=3@`13@d<0?Shn03dm?@12
@T80AdM704A4A010@400@d=304Q8B012@T80@d=30492@P15ADD00P12@T803@0m?Cd0A4A404A4A012
@T80ADE50492@P15ADD0?clo04E5A@12@T80?Shn0492@P15ADD00P0o?cl01`0n?Sh0CTi>0492@P0o
?cl0A4A403hn?P0m?Cd00P0l?3`02@0m?Cd0@d=303hn?P0m?Cd0?3`l03lo?`10@400?Shn03`l?002
0451@@0=03dm?@0l?3`0?3`l03/k>`0o?cl0A4A40410@011@D40@d=304I6AP13@d<0CTi>04Y:BP02
051@D00604U9B@1>CTh0B4Q804e=C@18B4P0A4A40P0o?cl00`12@T80AdM703lo?`020410@00404A4
A00l?3`0@D5104=3@`80?clo03<0BTY:04I6AP10@400?clo04=3@`14A4@0CDe=05ADE01/K6`0OGem
09:BTP1hN7P0DE5A04=3@`1;Bd/0ATI603lo?`1;Bd/0H61P05YJFP1IFET0@T9203dm?@11@D40A4A4
03lo?`0l?3`0?clo0410@013@d<0?Cdm04A4A011@D40@T920451@@0i>CT0?Shn03lo?`11@D40?3`l
03/k>`0l?3`0C4a<05eMG@1WIfL0J6QX05eMG@1EEED0BTY:04=3@`17AdL00P15ADD0>P10@400?clo
04E5A@1:BTX0De=C05UIF@1XJ6P0Kfm_079bLP1[Jf/0LG5a07inOP22PX80Rh^;09>CT`2NWYh0UIFE
09JFUP2TY:@0^k^k0=GEe@3IfMT0g=cL0=3@d035aLD0/k>c0:b/[02a/K40UIFE0:>SX`3=cLd0d];B
0;bl_031`L40YJFU0:JVYP2>SXh0Ti>C0:ZZZP1OGel0CDe=08Z:RP2a/K40Vi^K0:BTY02_[jl0ZJVY
0:FUY@2FUYH0aLG50<o?c`3=cLd0`<3009jNWP1XJ6P0@d=303dm?@0o?cl20410@080>SXj00l0>CTi
03`l?00j>SX0?3`l03Xj>P0i>CT0?Cdm03/k>`0m?Cd0@41003`l?011@D40>c/k03`l?00o?cl00P0n
?Sh04P0k>c/0@41003Ti>@0i>CT0?Cdm03Xj>P0n?Sh0?clo0451@@0l?3`0>c/k03Xj>P0m?Cd0?3`l
03/k>`0j>SX0>3Ph03dm?@80>CTi00<0>SXj03/k>`0l?3`00`0l?3`02`0j>SX0=SHf03Ph>00j>SX0
>CTi03`l?00m?Cd0>CTi03Xj>P0m?Cd0>SXj0080>c/k00l0?3`l03Ti>@0k>c/0>SXj03Ti>@0g=cL0
>CTi03Ph>00j>SX0>CTi03`l?00i>CT0>SXj0410@00l?3`00P0j>SX01P0h>3P0>c/k03Ti>@0m?Cd0
?3`l03Lg=`<0>CTi00P0>SXj03Ph>00i>CT0>CTi03Ph>00k>c/0?3`l03Ti>@80>3Ph00D0>CTi03Xj
>P0j>SX0>SXj03Ti>@0203Xj>P0303Ti>@0h>3P0=cLg0080>3Ph00D0?3`l03dm?@0i>CT0>CTi03Ph
>00203Xj>P0403Ph>00d=3@0>CTi03Lg=`@0>CTi00D0>SXj03Ph>00i>CT0=cLg03Ti>@0203Ph>080
>CTi0P0h>3P203Ti>@80>3Ph00<0=SHf03Lg=`0h>3P00P0h>3P05P0k>c/0>SXj03De=@0g=cL0>SXj
03Lg=`0f=SH0=cLg03Xj>P0o?cl0A4A404e=C@1MGEd0EUIF04Y:BP0o?cl0?3`l03Xj>P0l?3`0>SXj
03Ph>00g=cL203Ph>00303Hf=P0h>3P0>3Ph0080>3Ph3Oooool0013ooooo00T0D51@04m?C`1?Cdl0
Bd];04m?C`1ADE40C4a<051@D01?Cdl00P1:BTX01@1;Bd/0BDU904Y:BP1<C4`0Bd];0080B4Q801@0
BDU904Y:BP19BDT0ADE504Q8B014A4@0ATI604M7A`1:BTX0Bd];04Q8B015ADD0A4A404E5A@16ATH0
B4Q804A4A017AdL0ADE504Y:BP<0@T9200D0A4A404Y:BP1<C4`0ADE504Q8B00204I6AP0304];B`16
ATH0@d=30080ATI600T0@d=304I6AP17AdL0ATI604=3@`12@T80ATI604A4A01:BTX00P15ADD03P12
@T80?Cdm0492@P11@D40A4A404=3@`15ADD0B4Q804I6AP14A4@0ADE504=3@`12@T80@d=30P11@D40
0`10@400ATI604Q8B00204I6AP0704E5A@13@d<0@d=303hn?P0o?cl0?Shn03lo?`020410@00U0451
@@13@d<0BDU903lo?`11@D40?Shn04M7A`18B4P0ATI603dm?@0l?3`0A4A403dm?@0l?3`0?Cdm03hn
?P11@D40@d=304E5A@0o?cl0@41004];B`15ADD0@41004E5A@0o?cl0@D510492@P10@400@T920451
@@13@d<0@41003lo?`16ATH0A4A403lo?`020410@00A04E5A@0o?cl0?Shn0492@P10@400>SXj03dm
?@0n?Sh0?clo0410@00l?3`0A4A404=3@`10@400ATI603lo?`0k>c/00P0n?Sh02@0o?cl0A4A40410
@00n?Sh0@T9203lo?`10@400@T9204A4A00204I6AP0904A4A013@d<0A4A404=3@`0m?Cd0@D510492
@P0m?Cd0@T920080@41002H0?clo03`l?00m?Cd0>SXj03hn?P10@400?clo03dm?@0o?cl0@41003hn
?P14A4@0B4Q804A4A01;Bd/0D51@04m?C`1GEeL0K6a/07]kN`2<S8`0UIFE09BDU01hN7P0I6AT04M7
A`0l?3`0@T9204E5A@14A4@0B4Q804=3@`15ADD0DU9B05MGE`1<C4`0B4Q804A4A080?clo00H0@410
04A4A01=CDd0GEeM05UIF@15ADD204=3@`80@T9200P0A4A404=3@`0n?Sh0?Shn03/k>`10@400?Cdm
04A4A0<0@41000<0BDU904Y:BP16ATH00P16ATH05014A4@0BDU904Q8B01DE5@0HF5Q069RHP1bLW80
MWIf079bLP1eMGD0Lg=c06YZJP1EEED0CTi>04m?C`1DE5@0G5aL06e]K@1dM7@0QHF50P2DU9@0:P2X
Z:P0]KFe0;fm_@34a<@0_kno0;Jf]P2g]kL0_kno0:RXZ028R8P0KVi^055AD@1CDe<0E5AD06MWI`20
P800IFEU092@T02^[Zh0WinO09JFUP2=SHd0Zj^[0:VYZ@2BTY80PH610::RXP2][Jd0Zj^[09>CT`2U
YJD0Shn?04i>CP0o?cl0>c/k03dm?@0o?cl0?Shn03lo?`0m?Cd0?clo0451@@<0>SXj00h0>c/k03dm
?@0n?Sh0@41003dm?@0o?cl0@T9203hn?P10@400?Shn03lo?`0n?Sh0@D5103Xj>P80?Cdm00l0?Shn
03lo?`0l?3`0@41003dm?@0n?Sh0>SXj03/k>`0l?3`0?Shn03`l?00j>SX0?3`l03Xj>P0n?Sh00P0j
>SX203/k>`0<03hn?P0j>SX0=cLg03Xj>P0h>3P0>CTi03Ph>00m?Cd0@D5103dm?@0k>c/0?3`l0`0k
>c/0200i>CT0>c/k03Ti>@0j>SX0?3`l03dm?@0i>CT0>3Ph0P0l?3`01P0g=cL0>SXj03dm?@0o?cl0
>CTi03/k>`<0?3`l00<0>SXj03`l?00m?Cd00P0i>CT203Ph>0<0>SXj0P0k>c/00`0m?Cd0?3`l03Ph
>00203Ti>@0403Xj>P0k>c/0>SXj03`l?080=cLg0P0i>CT203/k>`0403Ti>@0m?Cd0>CTi03Ph>080
>SXj00H0>CTi03dm?@0h>3P0>SXj03Lg=`0e=CD503Lg=`0503Ph>00g=cL0>3Ph03Xj>P0i>CT00P0j
>SX0100i>CT0>SXj03Ph>00i>CT203Xj>P80>CTi0P0f=SH303Ph>00A03Lg=`0h>3P0>CTi03Ph>00i
>CT0?3`l04I6AP15ADD0A4A404a<C01ADE40CDe=04];B`0o?cl0>SXj03Ti>@0f=SH00P0i>CT01@0h
>3P0=SHf03Ti>@0g=cL0=SHf00<0>3Ph0P0g=cL=ooooo`004?ooool02@1>CTh0D51@04i>CP1?Cdl0
CTi>04Y:BP1=CDd0B4Q804e=C@0204a<C00604U9B@16ATH0BTY:04a<C018B4P0AdM70P1:BTX01017
AdL0A4A404E5A@1:BTX204M7A`0904E5A@18B4P0Bd];04Q8B015ADD0B4Q804=3@`14A4@0AdM700<0
ATI600D0BDU904Q8B014A4@0ADE50492@P0204=3@`090492@P1=CDd0D51@04U9B@15ADD0A4A404Y:
BP16ATH0A4A400<0ATI601T0BTY:04=3@`13@d<0A4A40451@@0n?Sh0@T9204I6AP18B4P0ADE504Q8
B012@T80AdM704U9B@14A4@0?Shn04A4A016ATH0A4A40492@P14A4@0@T9203lo?`13@d<0?clo0080
ADE500P0ATI604A4A016ATH0@4100492@P14A4@0@D5103lo?`80@41000`0?clo0410@016ATH0BTY:
04A4A00o?cl0@41004=3@`14A4@0@T9204U9B@13@d<30410@00804=3@`10@400?clo0451@@0o?cl0
@D510410@013@d<203lo?`0303dm?@12@T80ADE50080?clo00@0?Cdm0451@@10@400?clo0`13@d<0
2011@D40?Cdm03lo?`0o?cl0?Shn03dm?@0n?Sh0@D510P0n?Sh01P0l?3`0?Cdm0410@015ADD0ATI6
04A4A080ADE50`0o?cl01011@D40@41004E5A@13@d<203hn?P0Z03/k>`0l?3`0?Shn0410@013@d<0
ADE503lo?`0m?Cd0A4A404I6AP0n?Sh0?Cdm03hn?P0m?Cd0@T920410@00n?Sh0?clo0410@00n?Sh0
@T9204M7A`14A4@0?clo04M7A`14A4@0@41003hn?P17AdL0ATI604A4A017AdL0ADE504I6AP1?Cdl0
I6AT0861P@20P800Jf][06IVIP1@D500ADE50P1;Bd/0:P15ADD0B4Q804Q8B015ADD0AdM704I6AP19
BDT0DE5A04I6AP17AdL0ATI604Y:BP1?Cdl0CDe=05eMG@1`L700NWYj06a/K01KFe/0De=C055AD@1=
CDd0CTi>05ADE01IFET0H61P05IFEP1QHF40K6a/07MgM`27QhL0KVi^05]KF`1FEUH0GUiN06MWI`1K
Fe/0BTY:0492@P13@d<0@D510492@P80BTY:00h0AdM705=CD`1HF5P0GemO069RHP1`L700M7Ad07em
O@1iNGT0MWIf06YZJP1WIfL0DE5A04];B`80A4A403@0@D510492@P15ADD0EEEE06EUI@1eMGD0SXj>
0:j^[P38b<P0_kno08>3P`1>CTh0?clo04I6AP13@d<0@41003hn?P15ADD0HV9R08n?S`2JVYX0UIFE
07]kN`1mOGd0LG5a05=CD`1BDU80FEUI075aL@2>SXh0UiNG06MWI`1VIVH0IFEU05ADE01=CDd0EeMG
055AD@1;Bd/0@d=30410@011@D40A4A403dm?@0o?cl0?Shn0492@P10@400?3`l03Xj>P0n?Sh0?Cdm
0P0o?cl03P0m?Cd0?clo03`l?011@D40AdM704a<C01NGUh0KFe]06m_K`1RHV80EEEE04M7A`0k>c/0
@4100P0l?3`0300j>SX0?3`l03Xj>P0j>SX0>3Ph03/k>`0g=cL0>c/k03Xj>P0i>CT0?3`l03/k>`<0
>CTi00L0?3`l03/k>`0k>c/0>c/k03hn?P0o?cl0?Cdm0080>CTi00<0=cLg03/k>`0j>SX00P0k>c/0
200j>SX0>CTi03dm?@0j>SX0>c/k03dm?@0j>SX0?Cdm0P0i>CT01P0n?Sh0?3`l03`l?00n?Sh0?Cdm
03Ph>080>SXj0P0k>c/203Xj>P0=03Ph>00j>SX0>CTi03Xj>P0l?3`0>c/k03hn?P0l?3`0>3Ph03Xj
>P0k>c/0>SXj03/k>`0203Ti>@0503Ph>00i>CT0>CTi03Ph>00j>SX00P0m?Cd0200o?cl0?3`l03Ph
>00g=cL0>CTi03Ph>00i>CT0>SXj0P0i>CT01@0j>SX0>c/k03dm?@0k>c/0>3Ph0080=cLg0P0j>SX0
1`0l?3`0>c/k03Ti>@0g=cL0>SXj03Ph>00e=CD00P0i>CT00`0l?3`0=SHf03Ti>@0303Ph>00703Ti
>@0g=cL0>3Ph03`l?010@400DU9B05UIF@0205EEE@0:04e=C@11@D40@D510410@00m?Cd0?3`l03Ti
>@0g=cL0<S8b03Ti>@80>3Ph00@0>CTi03Xj>P0h>3P0=cLg0P0f=SH0100h>3P0=cLg03Lg=`0h>3P=
ooooo`004?ooool0501@D500DE5A04m?C`1?Cdl0C4a<04];B`1=CDd0C4a<04i>CP1;Bd/0BTY:04a<
C01>CTh0C4a<04Q8B017AdL0Bd];04U9B@18B4P0BDU90P18B4P01`17AdL0ATI604E5A@14A4@0B4Q8
04I6AP18B4P00`19BDT03P18B4P0BDU904M7A`15ADD0BTY:04e=C@1:BTX0A4A404=3@`15ADD0@d=3
04A4A019BDT0A4A40P16ATH01P14A4@0AdM704U9B@12@T80ADE504U9B@80A4A401<0@4100492@P15
ADD0ADE504=3@`12@T80ADE50492@P15ADD0@d=30410@012@T80?clo04A4A013@d<0?clo0492@P14
A4@0ADE50080@T9200H0?Shn0410@011@D40?3`l03lo?`12@T820451@@0704A4A00o?cl0@T920410
@00m?Cd0?Shn0451@@020492@P0:0451@@0o?cl0@T920492@P16ATH0@T9204A4A013@d<0ADE504A4
A080@D5101X0@41003dm?@12@T80AdM703lo?`0n?Sh0?clo0451@@0o?cl0ATI603hn?P0m?Cd0?Shn
0410@012@T80?Shn03lo?`0k>c/0?3`l03dm?@10@400@D5104=3@`0k>c/0?Cdm03`l?0<0?clo00D0
@D5103lo?`0l?3`0?Shn0451@@020492@P070410@011@D40ADE504U9B@17AdL0ATI60492@P030451
@@0?04=3@`0m?Cd0?Shn03lo?`0l?3`0>c/k03lo?`0k>c/0?Cdm0410@00m?Cd0?Shn03`l?011@D40
ADE50080?Shn0`13@d<05010@400A4A40451@@11@D40?Cdm0451@@15ADD0@41003`l?011@D40@410
03`l?013@d<0?Shn04U9B@18B4P0ATI60451@@1BDU80IfMW0P1lO7`206UYJ@1606a/K01WIfL0L71`
06e]K@1_Kfl0J6QX069RHP1KFe/0FEUI04Q8B014A4@0@D5104=3@`0o?cl0?Cdm0410@016ATH0@410
0451@@16ATH0@d=304U9B@18B4P0C4a<055AD@1DE5@0GemO06YZJP1gMgL0NWYj09VIV@2PX:00YJFU
0:j^[P2TY:@0]kNg0:NWY`2FUYH0WIfM0;:b/P2h^;P0]KFe0:^[Z`26QXH0LW9b06m_K`1VIVH0F5QH
05]KF`1GEeL0Jf][0820P02FUYH0Z:RX0:ZZZP2SXj<0UiNG08n?S`2=SHd0MgMg071`L01bLW80OGem
08:2PP1YJFT0Cdm?04A4A012@T80?Cdm0492@P80@D5102`0@d=3061PH028R8P0/;2`0:JVYP2EUID0
Vi^K08B4Q01]KFd0I6AT05mOG`1SHf<0Kfm_07MgM`29RHT0RXZ:079bLP24Q8@0VIVI08^;R`20P800
JVYZ096AT@2@T900WYjN08B4Q028R8P0WIfM09NGU`2MWId0Zj^[0:FUY@25QHD0K6a/07emO@2>SXh0
LW9b05]KF`1MGEd0Fe]K05EEE@1@D500?clo0410@080EUIF01h0@d=304Y:BP1@D500HV9R09BDU02l
_;`0`L710<c<c02m_Kd0Vi^K05YJFP1:BTX0?Shn03dm?@10@400>CTi03`l?00k>c/0?3`l03Ph>00l
?3`0>c/k055AD@0m?Cd0=cLg03Xj>P0i>CT0?Shn03`l?00k>c/203`l?00503Xj>P0h>3P0>CTi03`l
?00j>SX00P0i>CT0100h>3P0>CTi03Ph>00h>3P203Ti>@0703Ph>00i>CT0>CTi03dm?@0l?3`0>CTi
03Ph>00203Xj>P0503/k>`0i>CT0=SHf03Ti>@0h>3P00P0n?Sh00`0f=SH0>SXj03Xj>P0203/k>`04
03Ti>@0l?3`0>3Ph03Xj>P80>CTi00H0>c/k03Ti>@0l?3`0>SXj03Ti>@0l?3`203Xj>P040410@00j
>SX0=cLg03Xj>P80?Cdm00P0>c/k03Xj>P0l?3`0?3`l03Ti>@0h>3P0?Cdm03Ti>@<0>3Ph0P0l?3`0
4@0k>c/0>CTi03Lg=`0j>SX0?Cdm03Lg=`0j>SX0>3Ph03/k>`0l?3`0>c/k03Xj>P0l?3`0>CTi03Hf
=P0i>CT0=3@d0080>3Ph0100?3`l03/k>`0h>3P0>3Ph03Ti>@0l?3`0?clo0410@019BDT0EEEE05QH
F01?Cdl0@D5103Xj>P0k>c/0>CTi0P0f=SH203Ph>0D0=cLg00D0>CTi03Ph>00d=3@0=SHf03Lg=`02
03Hf=P80=cLg00<0>CTi03Xj>P0h>3P03Oooool0013ooooo00H0Cdm?04i>CP1@D500CDe=04Y:BP1>
CTh204Y:BP0404a<C01@D500Cdm?04];B`80CDe=00<0CTi>04Y:BP1:BTX00P19BDT01@1:BTX0ATI6
04U9B@1;Bd/0AdM70080ADE500d0AdM704=3@`17AdL0Bd];04E5A@17AdL0A4A404Q8B015ADD0@T92
04I6AP1:BTX0B4Q800@0ADE501@0ATI604A4A01<C4`0B4Q804E5A@14A4@0AdM704];B`16ATH0BTY:
04i>CP12@T80ADE504A4A019BDT0A4A40492@P10@400@d=304A4A080@D5100D0?Shn0410@013@d<0
A4A404e=C@030492@P80@41000@0?Shn0410@012@T80@d=30P12@T8204A4A080@d=30280@T9203dm
?@11@D40@D5103lo?`0n?Sh0@D5104E5A@12@T80@41003hn?P11@D40ADE50492@P0n?Sh0?Cdm03`l
?00o?cl0@4100492@P0o?cl0>SXj03hn?P11@D40A4A403hn?P11@D40@d=30410@011@D40@41003dm
?@0o?cl0@D510P10@4003P0i>CT0>SXj03hn?P14A4@0?clo03/k>`0n?Sh0@T9203lo?`0m?Cd0?clo
03dm?@0i>CT0>c/k0P0n?Sh00`0m?Cd0?Shn03dm?@0203hn?P0D03dm?@0o?cl0A4A404=3@`12@T80
?clo0451@@10@400?Shn0451@@17AdL0?Shn0492@P10@400@d=304M7A`11@D40?Cdm03`l?010@402
03dm?@0:03/k>`0m?Cd0@d=304A4A00n?Sh0A4A404=3@`11@D40>c/k04A4A080?clo01D0@D5104I6
AP0n?Sh0?clo03hn?P11@D40?Cdm0492@P14A4@0?Cdm0492@P13@d<0H61P08N7Q`2FUYH0Rh^;08B4
Q01eMGD0HF5Q05]KF`1RHV800P1<C4`02012@T80?Shn0410@012@T80@4100451@@10@400A4A40P12
@T800`0m?Cd0>c/k04A4A0020451@@1R03hn?P10@400Bd];05IFEP1`L700NWYj0861P@1kNg/0PX:2
08N7Q`29RHT0QhN708n?S`2IVIT0ZZZZ0:BTY02BTY80WIfM07emO@2<S8`0W9bL0:>SX`2JVYX0R8R8
07AdM01aLG40Q8B409^KV`33`l<0clo?0=;BdP3=cLd0alO70;no_`2l_;`0_Kfm0;Fe]@2j^[X0b<S8
0=CDe03GemL0fm_K0<K6aP34a<@0`L710<W9b@2[Zj/0VIVI07moO`1KFe/0BTY:04I6AP0m?Cd0?clo
03dm?@11@D40?clo055AD@1]KFd0UIFE0;Fe]@39bLT0a/K60;Vi^@33`l<0c<c<0=?Cd`3De=@0g=cL
0=[JfP2l_;`0XJ6Q07emO@1UIFD0HF5Q05QHF02GUiL0Ti>C09:BTP23Ph<0N7Qh08N7Q`2@T900WinO
0;6a/@2_[jl0]kNg0;Rh^02i^KT0[Jf]06UYJ@1<C4`0A4A40451@@1:BTX0B4Q804E5A@10@40204i>
CP0I04];B`1ADE40ADE504M7A`1JFUX0R8R809>CT`1eMGD0DE5A0492@P10@400?Shn03`l?012@T80
?3`l03/k>`0j>SX0>CTi03dm?@0k>c/0?clo03Lg=`0m?Cd0>3Ph03Ti>@0203/k>`80>SXj00@0>c/k
03Ph>00l?3`0>CTi0P0h>3P03`0k>c/0>SXj03Ti>@0l?3`0?clo03Xj>P0f=SH0=cLg03Xj>P0i>CT0
>SXj03Ti>@0k>c/0>SXj03De=@0203Ph>00303/k>`0g=cL0>CTi0080>CTi00@0?Shn03Ti>@0h>3P0
>3Ph0P0j>SX00`0i>CT0>3Ph03Xj>P0403/k>`80>SXj00`0>c/k03Xj>P0j>SX0>c/k03`l?00n?Sh0
?clo03Xj>P0k>c/0>CTi03Ph>00g=cL303Ti>@0403Ph>00g=cL0=SHf03Ph>0@0=cLg00L0=CDe03Ph
>00g=cL0>CTi03Ph>00i>CT0>c/k0080>SXj00D0=cLg03Ph>00h>3P0>CTi03`l?00203Xj>P0G03`l
?00h>3P0=CDe03Ph>00d=3@0>CTi03Lg=`0i>CT0>3Ph03/k>`0n?Sh0?clo04A4A018B4P0@D5104=3
@`12@T80>SXj03Ph>00f=SH0>c/k03Lg=`0d=3@00P0h>3P00`0e=CD0=3@d03Hf=P0303Ph>00:03Lg
=`0j>SX0=CDe03`l?00k>c/0?clo03Hf=P0d=3@0>c/k03Lg=`<0>3Ph3Oooool0013ooooo0`1ADE40
1P1?Cdl0CDe=04m?C`1?Cdl0BDU904a<C080BTY:00D0C4a<04];B`18B4P0B4Q804Y:BP0204];B`07
04a<C01>CTh0Bd];04Q8B014A4@0ATI604U9B@0204I6AP0E04A4A017AdL0BDU904Y:BP19BDT0AdM7
04Q8B019BDT0B4Q804M7A`18B4P0ATI604A4A016ATH0AdM704=3@`16ATH0CTi>04M7A`15ADD0@d=3
00<0Bd];0P18B4P02@11@D40@d=304A4A013@d<0@T9204=3@`10@400ADE503lo?`020492@P0G0410
@00o?cl0@d=30410@00o?cl0?Cdm04E5A@1:BTX0ATI60451@@0o?cl0?Shn0451@@1:BTX0ADE504A4
A011@D40@d=303lo?`0n?Sh0@T9204=3@`0o?cl00`13@d<01`10@400?clo0492@P11@D40@d=30451
@@12@T800P11@D408@10@400?Shn03/k>`0o?cl0?3`l03hn?P10@400@D5103dm?@0o?cl0@d=304A4
A00o?cl0@T920410@011@D40@41004=3@`0m?Cd0>c/k04A4A010@400?clo0410@012@T80@d=304A4
A011@D40@T9203`l?011@D40@41003lo?`0203`l?00@0410@00o?cl0?Cdm03dm?@11@D40@41003dm
?@0n?Sh0?clo04A4A013@d<0?Shn0451@@0n?Sh0@d=30492@P80@D5100H0@d=303hn?P0n?Sh0@T92
0451@@14A4@20451@@0A0410@011@D40@D5103Xj>P0o?cl0@T9203lo?`12@T80A4A403`l?00k>c/0
@41003hn?P13@d<0@D5103dm?@0n?Sh00P0k>c/0P`0o?cl0?Cdm0451@@0n?Sh0@T9204I6AP1>CTh0
GEeM06e]K@28R8P0WIfM09jNWP2=SHd0IfMW04a<C015ADD0?Shn04A4A015ADD0B4Q80451@@0m?Cd0
@D5104A4A017AdL0?3`l0410@013@d<0@D5104=3@`0n?Sh0@T920410@013@d<0?clo03/k>`15ADD0
AdM70410@019BDT0CTi>05UIF@1CDe<0Hf=S07AdM01hN7P0OGem07IfMP1aLG40KVi^07]kN`21PH40
RHV909>CT`2MWId0R8R806UYJ@1KFe/0F5QH04m?C`1>CTh0FUYJ07MgM`2IVIT0[Zj^0<W9b@3Hf=P0
gMgM0=SHf03Bd]80d=3@0<30`02e]KD0^;Rh0;fm_@30`<00^;Rh0;:b/P2d];@0a<C40<G5a@39bLT0
]KFe08R8R01UIFD0Bd];05YJFP1iNGT0FEUI05ADE01MGEd0B4Q804M7A`1OGel0NWYj0:JVYP3=cLd0
eMGE0<_;b`3EeMD0clo?0<W9b@3?cll0e]KF0=CDe03Hf=P0eMGE0<K6aP2f][H0YJFU07AdM01BDU80
IFEU071`L01hN7P0IfMW04Y:BP19BDT0C4a<05ADE01OGel0KFe]07alO02:RXX0QXJ609:BTP2NWYh0
TI6A09NGU`2EUID0LW9b0080FEUI01H0D51@05=CD`10@400@D5104E5A@10@400@D5104=3@`10@400
@D5103lo?`16ATH0CDe=05=CD`14A4@0?Shn03Xj>P0n?Sh0?Cdm03`l?00n?Sh0>c/k0P0l?3`203dm
?@0603/k>`0h>3P0>c/k03Ti>@0j>SX0>CTi0P0h>3P303Xj>P0303/k>`0i>CT0>CTi00D0>CTi00D0
?Cdm03Ti>@0j>SX0>3Ph03Ti>@0203Lg=`0403/k>`0n?Sh0?Cdm03Xj>P<0>CTi00D0>c/k03Ti>@0j
>SX0?3`l03hn?P0203Xj>P80>CTi00@0?clo03Ph>00i>CT0>c/k0P0i>CT02@0k>c/0>SXj03Ti>@0h
>3P0>CTi03/k>`0m?Cd0>CTi03/k>`0203Xj>P0303/k>`0n?Sh0>c/k0080>3Ph00H0=cLg03Hf=P0h
>3P0>c/k03Xj>P10@40203Ti>@80>c/k00T0?3`l03Lg=`0f=SH0>SXj03`l?00i>CT0>SXj03Ph>00i
>CT00P0k>c/04@0i>CT0>3Ph03Xj>P0i>CT0>c/k03Xj>P0g=cL0>CTi03Ph>011@D40HF5Q07UiN@1h
N7P0J6QX05=CD`16ATH0>CTi0080=CDe00@0=3@d03Ph>00h>3P0?Cdm0P0h>3P0400e=CD0>3Ph03`l
?00i>CT0=cLg03Ph>00j>SX0>3Ph03Lg=`0j>SX0=CDe03dm?@0n?Sh0>SXj03Ti>@0h>3P403Lg=`03
03Ph>?oooooooooo00_ooooo000@ooooo`0704i>CP1ADE40DE5A04m?C`1<C4`0BDU904e=C@0304Y:
BP0B04a<C01:BTX0C4a<04e=C@18B4P0BDU904];B`1?Cdl0CDe=04Q8B01>CTh0BTY:04Q8B015ADD0
ATI604Q8B01;Bd/0AdM70P18B4P01P1ADE40ATI604I6AP16ATH0BTY:04Q8B0<0AdM70P19BDT0<`17
AdL0B4Q804Q8B019BDT0C4a<04U9B@14A4@0CTi>04];B`17AdL0BTY:04U9B@13@d<0A4A404E5A@1;
Bd/0@D5104I6AP11@D40ADE503lo?`11@D40@T920451@@0n?Sh0@D5104E5A@10@400@D5104E5A@17
AdL0A4A404I6AP13@d<0A4A40451@@13@d<0@D5104M7A`12@T80A4A404=3@`11@D40@T9204I6AP14
A4@0@D510410@012@T80@D5103lo?`020451@@<0?clo00@0@41003lo?`12@T80@T920P11@D400`14
A4@0?clo03hn?P020451@@80ATI60140AdM703hn?P11@D40?Shn0451@@10@400AdM704E5A@0n?Sh0
>c/k03`l?012@T80@D510492@P13@d<0A4A40492@P020451@@0K03`l?011@D40@41003`l?00n?Sh0
@D5103lo?`0n?Sh0@d=304I6AP0o?cl0?Shn0492@P11@D40A4A40451@@13@d<0@D5104A4A015ADD0
?clo03dm?@10@400?clo0451@@10@400@D510080ATI600X0@d=304A4A012@T80A4A40451@@0o?cl0
@41003lo?`0m?Cd0?clo0P12@T801P11@D40>SXj03Ph>00l?3`0@D510410@0<0@D5101H0@4100492
@P13@d<0@D51055AD@1jNWX0Hf=S05mOG`1FEUH0J6QX07EeM@1lO7`0KFe]05IFEP1=CDd0ADE50492
@P18B4P0ADE50492@P11@D40?clo0P11@D401P14A4@0?Cdm03`l?00n?Sh0@4100492@P80?Cdm00D0
@D510410@010@400ATI6059BDP0206i^KP0607IfMP23Ph<0Shn?08V9R@2FUYH0YZJV0P2WYjL0402>
SXh0OGem06MWI`1QHF40GEeM05mOG`1hN7P0SHf=0:2PX02VYZH0WinO08B4Q025QHD0T92@06ATI01<
C4`204U9B@0W05IFEP1NGUh0MgMg092@T02OWil0Y:BT0:NWY`2l_;`0alO70<k>cP38b<P0V9RH06i^
KP1SHf<0Kfm_07IfMP27QhL0Shn?08>3P`1ZJVX0?clo03hn?P16ATH0D51@07IfMP2SXj<0Ti>C07em
O@29RHT0TY:B0:b/[033`l<0aLG50;Zj^P2o_kl0bLW90<?3``39bLT0alO70080b<S80280d];B0=GE
e@3Hf=P0clo?0;Vi^@1oOgl0PH6108F5Q@1lO7`0Kfm_05]KF`1LG5`0DE5A04i>CP1NGUh0M7Ad08:2
PP1nOWh0O7al08R8R02ATI40U9BD0<G5a@3Ogml0b<S80;^k^`2g]kL0]KFe0;Jf]P2QXJ40MgMg05=C
D`1?Cdl0@D510P10@4000`1=CDd0JFUY09JFUP020;Vi^@090:ZZZP2CTi<0MgMg055AD@0o?cl0?3`l
03dm?@0n?Sh0?Cdm0080>SXj00<0?3`l03Xj>P0d=3@00P0j>SX01P0m?Cd0>c/k03/k>`0j>SX0>c/k
03Xj>P80>c/k0180?Cdm03Xj>P0h>3P0=cLg03/k>`0m?Cd0>CTi03`l?00k>c/0>CTi03Xj>P0i>CT0
>c/k03Ti>@0h>3P0=cLg03Ph>00g=cL203Xj>P0703/k>`0i>CT0>CTi03Ti>@0j>SX0@T9203Xj>P02
03`l?00C03/k>`0m?Cd0>CTi03Xj>P0k>c/0>CTi03/k>`0l?3`0>c/k03`l?00k>c/0?3`l0492@P0l
?3`0>CTi03Xj>P0i>CT0>c/k03`l?00403Xj>P0=03Ti>@0h>3P0=SHf03Lg=`0i>CT0>c/k03Hf=P0g
=cL0>CTi03/k>`0j>SX0>3Ph03Lg=`0203Ti>@0603dm?@0j>SX0?Cdm03Ti>@0l?3`0>CTi0P0f=SH0
300k>c/0>SXj03lo?`1>CTh0F5QH05eMG@1VIVH0OGem09nOW`27QhL0HV9R04E5A@<0>3Ph00D0=cLg
03Ph>00f=SH0=SHf03Ti>@0203Lg=`0303/k>`0g=cL0=CDe00<0>3Ph00@0>CTi03/k>`0h>3P0>CTi
0P0h>3P0100c<c<0>CTi03De=@0f=SH203Lg=`0403Hf=P0i>CT0=SHf04Q8B0gooooo000@ooooo`03
04i>CP1=CDd0CTi>0080Cdm?00L0C4a<04];B`17AdL0B4Q804];B`1?Cdl0C4a<0080CTi>00L0BTY:
04M7A`1;Bd/0BTY:04Q8B019BDT0D51@0080BTY:00D0B4Q804Y:BP19BDT0B4Q804E5A@0204Q8B007
04I6AP17AdL0ADE504I6AP19BDT0A4A404E5A@0304Y:BP0M04A4A015ADD0A4A40492@P14A4@0ADE5
04A4A010@400BDU904I6AP15ADD0BDU904E5A@16ATH0@d=30492@P16ATH0A4A40492@P13@d<0@410
03lo?`12@T80@41004A4A012@T80@d=30492@P11@D400P12@T8204I6AP0604M7A`12@T80@d=304=3
@`12@T80@D510`16ATH02P0n?Sh0@D5104=3@`0n?Sh0@d=30492@P0m?Cd0@4100451@@0l?3`503hn
?P070410@011@D40@d=304=3@`11@D40ADE504M7A`020451@@0303lo?`12@T80AdM70080ADE500h0
?clo0492@P0n?Sh0?Shn03`l?013@d<0ATI603lo?`11@D40@T920410@00n?Sh0?clo0492@P80?clo
00@0@41003lo?`11@D40@T920P0k>c/04@0o?cl0?Cdm0451@@0o?cl0@T9203lo?`0m?Cd0@41004U9
B@12@T80>SXj03/k>`0m?Cd0@T9203lo?`10@400@T9200@0?Shn00D0@T9204E5A@0o?cl0@41004=3
@`0203dm?@0i0410@00k>c/0?Cdm0492@P11@D40?clo03dm?@16ATH0@41003hn?P0m?Cd0?clo0410
@014A4@0@T920410@011@D40@41004E5A@12@T80>c/k04U9B@1jNWX0[jn_08R8R01kNg/0Hf=S05EE
E@18B4P0CDe=0492@P14A4@0@41004=3@`0j>SX0A4A40410@014A4@0@41003`l?00j>SX0?Cdm04A4
A00k>c/0?clo04=3@`14A4@0?clo04=3@`16ATH0@d=304A4A013@d<0ATI604Q8B01DE5@0C4a<0080
Cdm?00`0DU9B05MGE`1LG5`0IVIV06i^KP26QXH0O7al06i^KP1[Jf/0K6a/07EeM@1[Jf/3055AD@08
05=CD`1KFe/0B4Q804i>CP1CDe<0B4Q804Y:BP14A4@204E5A@1604Y:BP15ADD0?Shn04M7A`18B4P0
BDU904i>CP1DE5@0FEUI06ATI01WIfL0Kfm_07alO02LW9`0[Jf]0;Vi^@2SXj<0Ng]k07emO@1kNg/0
JFUY04m?C`18B4P0ADE505EEE@20P800TY:B09jNWP2^[Zh0^[Zj0;bl_039bLT0dM7A0=SHf03=cLd0
Vi^K08b<S021PH40Ng]k075aL@1iNGT0P82009^KV`2VYZH0^;Rh0;^k^`2o_kl0`<300;Ng]`2[Zj/0
X:2P08F5Q@1ZJVX0J6QX07QhN02@T900bLW90=OGe`3Hf=P0dm?C0;Jf]P2@T900YJFU0<K6aP3>c/h0
bl_;0;bl_02i^KT0^;Rh0;>c/`80`L7101`0^k^k09JFUP2<S8`0Ti>C0:RXZ02_[jl0Xj>S08B4Q023
Ph<0Rh^;09JFUP2/[:`0XJ6Q0861P@1<C4`0?Cdm0492@P0l?3`0>c/k03`l?00m?Cd0?3`l03/k>`0m
?Cd0?Shn03lo?`0l?3`0>SXj0P0k>c/02`0h>3P0?Cdm03dm?@0k>c/0>CTi03`l?00i>CT0>3Ph03/k
>`0h>3P0>SXj0080>c/k00@0>3Ph03/k>`0m?Cd0?3`l0P0j>SX00`0k>c/0>3Ph03/k>`0203dm?@05
03/k>`0i>CT0>SXj03dm?@0l?3`00P0i>CT0200j>SX0>c/k03Ti>@0h>3P0>c/k03`l?00k>c/0>CTi
0P0k>c/01@0g=cL0?3`l03Xj>P14A4@0>SXj0080?Cdm00<0=cLg03Xj>P0k>c/00P0j>SX09`0i>CT0
=SHf03Ph>00i>CT0>c/k03Ph>00j>SX0?3`l03Ph>00j>SX0>c/k03Ti>@0k>c/0@D5103Ti>@0k>c/0
>SXj03Ph>00j>SX0>c/k0410@00n?Sh0=SHf03Ti>@0m?Cd0DE5A08>3P`2_[jl0bl_;0=gMg@3EeMD0
a/K609fMW@1dM7@0C4a<03`l?00i>CT0=cLg03Hf=P0203Lg=`0303Xj>P0g=cL0=SHf00@0>3Ph0`0g
=cL01@0h>3P0=SHf03Ph>00m?Cd0>3Ph0080=cLg00/0>3Ph03Lg=`0i>CT0=CDe03Lg=`0h>3P0>CTi
03Ph>018B4P0CDe=05UIF@0=ooooo`004?ooool0101=CDd0DE5A055AD@1=CDd204Y:BP0404i>CP1<
C4`0BDU904Q8B080BTY:00d0Bd];04U9B@1;Bd/0ATI604U9B@17AdL0CTi>04e=C@16ATH0AdM704Q8
B015ADD0AdM700@0B4Q800<0ATI604A4A015ADD00P16ATH01017AdL0ADE504E5A@17AdL204A4A080
AdM700P0Cdm?04U9B@15ADD0AdM704Q8B013@d<0Bd];04A4A080@T9200D0@D510492@P11@D40@D51
04Q8B0030492@P0404=3@`0o?cl0@d=30451@@80@d=300@0A4A404E5A@13@d<0@T920P16ATH04@15
ADD0@d=30451@@10@400@D510492@P0o?cl0@D5104E5A@14A4@0@T920410@00o?cl0?Cdm0451@@0o
?cl0?Shn0080@41000T0@d=304E5A@11@D40?clo03hn?P12@T80@D5103hn?P11@D400P14A4@06015
ADD0@d=304A4A010@400?clo0451@@14A4@0?clo04A4A011@D40@41003hn?P0m?Cd0?Shn04E5A@12
@T80?3`l04E5A@10@400@d=30492@P13@d<0ADE503lo?`80>c/k00P0?3`l03hn?P10@400?Shn0410
@00o?cl0@41004A4A080?clo01L0@d=30492@P12@T80ADE504Q8B00o?cl0@41003dm?@12@T80?3`l
03/k>`11@D40?Shn0492@P16ATH0ADE504m?C`19BDT0?clo0410@00n?Sh0@T920451@@0203hn?P04
03dm?@0n?Sh0?Cdm0410@080?3`l0P10@40203`l?00403hn?P15ADD0?clo03hn?P80@T9201@0ADE5
0451@@1=CDd0MGEe07YjNP1MGEd0AdM703hn?P12@T80@41003hn?P12@T80?clo0492@P0o?cl0AdM7
03lo?`11@D40@4100492@P80@41001<0?Cdm03hn?P0l?3`0@T9204=3@`16ATH0@D510410@00o?cl0
A4A404=3@`0o?cl0ADE504=3@`12@T80ADE5051@D01IFET0Jf][0080NWYj00D0MWIf05iNGP17AdL0
B4Q804I6AP0204Y:BP0404=3@`0o?cl0ADE504A4A080ATI601D0DE5A071`L02:RXX0WYjN09VIV@2L
W9`0XZ:R09VIV@2>SXh0QhN708J6QP1iNGT0MGEe06=SH`1>CTh0AdM704A4A015ADD0B4Q804=3@`12
@T800P18B4P02P19BDT0Cdm?061PH01ZJVX0O7al09nOW`2m_Kd0^KVi09:BTP1DE5@20410@00Q03lo
?`1<C4`0De=C06EUI@1lO7`0MGEe07inOP25QHD0Q8B408R8R01VIVH0JVYZ07emO@1VIVH0MWIf08f=
S@1oOgl0SHf=09BDU02FUYH0RXZ:07moO`1mOGd0S8b<092@T02DU9@0VYZJ0:6QX@39bLT0^KVi08:2
PP1`L700UIFE0080[Zj^01X0LG5a05QHF01ZJVX0NWYj07inOP20P800OWin07YjNP22PX80RHV908^;
R`2a/K40`<300<?3``2l_;`0[:b/07inOP29RHT0/;2`09ZJVP1`L700DU9B06ATI01PH600I6AT07Ui
N@80T92@00H0JVYZ04M7A`0k>c/0?3`l03hn?P0m?Cd403/k>`80?3`l01<0>c/k03Xj>P0k>c/0>c/k
03Xj>P0i>CT0>SXj03/k>`0f=SH0>3Ph03Xj>P0h>3P0>CTi03dm?@0j>SX0>c/k04=3@`0k>c/0>SXj
0080>c/k0100>CTi03Xj>P0j>SX0>c/k03Lg=`0j>SX0?3`l03dm?@0n?Sh0>CTi03`l?00k>c/0?clo
03`l?00j>SX0>c/k0P0l?3`0300k>c/0>3Ph03Ti>@0k>c/0?3`l03/k>`0i>CT0@41003`l?00h>3P0
?3`l03hn?P80?Cdm00<0?Shn03/k>`0i>CT00`0i>CT03`0n?Sh0=cLg03Ti>@0i>CT0?clo03Ti>@0h
>3P0>c/k03Xj>P0h>3P0=CDe03`l?00j>SX0>c/k03Xj>P0203/k>`0A03Ti>@1:BTX0K6a/0::RXP37
alL0g]kN0=cLg031`L40WYjN09>CT`1/K6`0Cdm?03lo?`0j>SX0=cLg03Xj>P0h>3P00P0g=cL01P0h
>3P0>CTi03Lg=`0g=cL0>3Ph03Lg=`80>3Ph00<0=cLg03Ph>00g=cL00P0f=SH01P0h>3P0>SXj03Xj
>P0h>3P0>CTi03Hf=P<0>3Ph00L0=cLg03Ph>00j>SX0B4Q805eMG@0j>SX0>CTi00gooooo000@oooo
o`0404i>CP1?Cdl0D51@05=CD`<0CDe=00D0Bd];04Q8B01<C4`0CDe=04E5A@0304Q8B080BTY:00D0
ADE504];B`19BDT0ADE504U9B@0204M7A`0<04A4A019BDT0Bd];04Y:BP15ADD0ATI604M7A`15ADD0
B4Q804M7A`16ATH0BTY:0P16ATH00`1:BTX0AdM704Q8B00204];B`0704Q8B01;Bd/0ADE504I6AP14
A4@0AdM704Q8B00204A4A00:0451@@13@d<0@d=30492@P1:BTX0BDU904I6AP12@T80B4Q804U9B@80
@T920P0o?cl07@12@T80A4A40492@P15ADD0@T9203hn?P11@D40BDU904E5A@14A4@0@d=30451@@12
@T80?Cdm0410@011@D40?clo0410@013@d<0?clo0410@013@d<0@4100451@@10@400@d=30492@P15
ADD0?clo00<0@41000L0?Cdm0451@@13@d<0@d=30410@00o?cl0@D510080?Cdm00`0?3`l04=3@`0n
?Sh0?clo0451@@13@d<0?Shn03lo?`12@T80ADE50451@@0m?Cd20451@@0304=3@`15ADD0@D510080
@D5100@0?clo0492@P0n?Sh0>SXj0P0m?Cd0:010@400@d=303lo?`0o?cl0@T9203dm?@11@D40?Shn
0451@@15ADD0B4Q803`l?010@400?clo0410@00l?3`0@41004A4A019BDT0@T920451@@0o?cl0@T92
04I6AP10@400?3`l04=3@`14A4@0@41003hn?P10@400?clo0451@@0k>c/0@41003hn?P0o?cl0?Cdm
03Ti>@0m?Cd203hn?P0?04I6AP11@D40A4A404Q8B013@d<0@41004I6AP13@d<0@T9204=3@`17AdL0
A4A40492@P14A4@0?clo0080?Shn00H0@41003hn?P0l?3`0@D510492@P0l?3`203/k>`0303hn?P0l
?3`0?Shn0080@D5100X0?Cdm04M7A`11@D40@d=304M7A`18B4P0?clo0492@P13@d<0>c/k0P0o?cl0
1P11@D40ATI604a<C01;Bd/0AdM704I6AP80CDe=00P0@D5104A4A012@T80Bd];04U9B@18B4P0CTi>
04];B`80CDe=0100EeMG069RHP1lO7`0VIVI0:ZZZP2MWId0UYJF08J6QP1aLG40J6QX06EUI@1[Jf/0
IVIV075aL@1gMgL0P8200P26QXH04`2NWYh0/k>c0:6QX@2:RXX0PH6106m_K`1/K6`0Ng]k06ATI01L
G5`0De=C05QHF01KFe/0EUIF051@D01BDU80B4Q804=3@`11@D400P13@d<0>012@T80IFEU07UiN@2D
U9@0[jn_0:b/[031`L40alO70<S8b03Fe]H0YZJV09FEU@25QHD0K6a/06IVIP1gMgL0OGem075aL@28
R8P0V9RH08R8R029RHT0[Jf]0<W9b@2m_Kd0`L710;fm_@2d];@0WinO06][J`1?Cdl0IVIV065QH@1a
LG40K6a/071`L01YJFT0MgMg06QXJ01FEUH0HV9R075aL@1TI6@0Q8B409VIV@2XZ:P0QXJ606MWI`1E
EED0IfMW08>3P`2;Rh/0Lg=c05]KF`1WIfL0NGUi0P2CTi<01`2IVIT0U9BD0:VYZ@2c/k<0OWin04I6
AP0n?Sh00`0j>SX01`0k>c/0>CTi03/k>`0n?Sh0?Cdm03Ti>@0m?Cd00P0n?Sh01P0i>CT0?3`l03/k
>`0i>CT0?3`l03Ti>@80>c/k00<0?Cdm03`l?00k>c/00P0m?Cd01P0i>CT0?Cdm03Ti>@0f=SH0>c/k
03`l?080?Cdm00L0>CTi03`l?00l?3`0>c/k03Ti>@0g=cL0>CTi0080>c/k00X0?3`l03/k>`0k>c/0
?Cdm03`l?00k>c/0>SXj03Ti>@0l?3`0>3Ph0`0j>SX0100n?Sh0=SHf03/k>`0j>SX203Ph>00703Ti
>@0k>c/0?3`l03Xj>P0h>3P0>SXj03Lg=`0203Ph>00I03Ti>@0k>c/0>SXj03Lg=`0k>c/0>SXj03Ti
>@0e=CD0>CTi03dm?@0h>3P0>CTi03hn?P1>CTh0SHf=0:j^[P2OWil0UiNG08>3P`1SHf<0BDU903lo
?`0m?Cd0>SXj03Ti>@0203`l?00403Ti>@0j>SX0=cLg03Hf=P80=cLg00<0=CDe03Lg=`0j>SX00P0i
>CT00`0h>3P0=cLg03Lg=`0203Lg=`80=SHf0100>SXj03Ph>00h>3P0>SXj03Ti>@0g=cL0>3Ph03Lg
=`0i>CT0=cLg03Hf=P0g=cL0>3Ph03Xj>P0f=SH0>3Ph3Oooool0013ooooo01@0C4a<051@D01?Cdl0
DE5A04e=C@1<C4`0CDe=04];B`1<C4`0B4Q804];B`19BDT0AdM704Q8B017AdL0CDe=04Q8B016ATH0
BTY:04U9B@80B4Q800D0BDU904];B`17AdL0B4Q804I6AP0204E5A@0704i>CP16ATH0BTY:04Y:BP13
@d<0A4A404M7A`0204=3@`0704M7A`11@D40AdM704a<C017AdL0A4A404M7A`0204=3@`0604M7A`16
ATH0B4Q804I6AP1;Bd/0ADE50P18B4P02014A4@0@D5104=3@`12@T80AdM705IFEP19BDT0?clo0P15
ADD01P0o?cl0@d=303lo?`0o?cl0@T9203dm?@80?Shn0P0o?cl03P13@d<0@D510410@012@T80@D51
03lo?`15ADD0@4100492@P0o?cl0?Cdm0410@00o?cl0@T920P0o?cl01P12@T80@D510410@00n?Sh0
@41003`l?080?clo00T0@41003hn?P0m?Cd0?clo0410@011@D40@41003dm?@0l?3`00P0o?cl01P10
@400?Shn03lo?`12@T80?Cdm0410@080@T9200H0@d=304M7A`17AdL0@D5104Q8B016ATH203lo?`08
04E5A@1:BTX0@d=303hn?P15ADD0@d=303dm?@0o?cl20410@00903lo?`12@T80?clo0492@P13@d<0
ATI604=3@`0o?cl0@T920080@D5100@0>CTi0492@P0n?Sh0@T920P10@4001`14A4@0ADE503hn?P11
@D40?Shn0451@@0o?cl00P11@D400`13@d<0@41004A4A00203lo?`0803dm?@0o?cl0?clo03hn?P0k
>c/0@D510410@012@T8204E5A@0A0492@P0o?cl0@D5103dm?@1;Bd/0G5aL05YJFP1=CDd0ATI60451
@@0n?Sh0?Cdm0451@@0l?3`0>c/k03hn?P0o?cl00`11@D400`0n?Sh0ADE504=3@`0203lo?`0E03hn
?P15ADD0ATI605ADE01TI6@0IfMW05MGE`14A4@0>CTi0451@@12@T80@41003/k>`0n?Sh0@T9203`l
?00m?Cd0@T9203lo?`0l?3`0?clo0080A4A400T0AdM70451@@10@400?Cdm03lo?`13@d<0Bd];06=S
H`1dM7@00P2<S8`208R8R01U08b<S01gMgL0PX:208N7Q`29RHT0Ogmo065QH@1?Cdl0A4A404M7A`1D
E5@0DU9B06ATI01mOGd0Ph>308^;R`22PX80OGem08b<S028R8P0UiNG0:n_[`2b/[80Zj^[09:BTP1m
OGd0Lg=c06YZJP1aLG40Ph>309JFUP2NWYh0UIFE08F5Q@1KFe/0BDU903lo?`12@T80@d=304A4A018
B4P0EEEE06a/K01oOgl0Y:BT09jNWP2EUID0KVi^051@D01>CTh0B4Q804I6AP1LG5`0JFUY08>3P`2T
Y:@0YZJV08j>SP2:RXX0VYZJ09fMW@2ATI40SHf=09BDU028R8P0KVi^06MWI`26QXH0ZJVY0<C4a03>
c/h0cLg=0=?Cd`3<c<`0aLG50;Bd]02[Zj/0WYjN08V9R@1fMWH0OWin09bLW02MWId0IfMW06EUI@21
PH40MWIf05mOG`1JFUX0Fe]K05eMG@1UIFD0P8200:VYZ@2n_[h0^k^k0;Bd]02HV9P0Hf=S05EEE@1:
BTX00`10@400300k>c/0>CTi03dm?@10@400AdM705MGE`1WIfL0Lg=c04Y:BP0o?cl0@41003hn?P80
?3`l00d0?Cdm03/k>`0k>c/0=cLg03`l?00m?Cd0?3`l03Xj>P0m?Cd0>3Ph03Lg=`0i>CT0>c/k0080
>CTi00L0>SXj03Ti>@0h>3P0>CTi03Hf=P0h>3P0?3`l0080>c/k0140?3`l03Hf=P0i>CT0?3`l03/k
>`0h>3P0>CTi03Xj>P0f=SH0=cLg03Xj>P0m?Cd0=cLg03`l?00g=cL0>CTi03`l?00203Xj>P0503`l
?00k>c/0>SXj03/k>`0i>CT00P0j>SX00`0i>CT0>c/k03Ph>00203Ph>00403Ti>@0f=SH0>3Ph03Lg
=`80>SXj0P0h>3P01@0g=cL0=CDe03dm?@13@d<0@T920080?Cdm00L0>CTi03/k>`0h>3P0>CTi03/k
>`0j>SX0>3Ph0080>CTi01H0?3`l03Ti>@0f=SH0=SHf03Ph>00i>CT0=CDe03Hf=P0j>SX0=SHf03Ti
>@0g=cL0=CDe03Xj>P0h>3P0>SXj03Lg=`0f=SH0>CTi03Hf=P0e=CD0>3Ph0P0i>CT203Ph>0<0=SHf
0P0g=cL00`0i>CT0<c<c03Lg=`0=ooooo`004?ooool01P1ADE40Cdm?051@D01=CDd0CTi>04Y:BP80
C4a<00D0HF5Q06ATI01;Bd/0C4a<04M7A`0204Q8B00304a<C016ATH0ATI600<0B4Q800@0ATI604M7
A`19BDT0ATI60P18B4P06P15ADD0B4Q804e=C@16ATH0A4A404a<C017AdL0B4Q804M7A`13@d<0ATI6
04E5A@12@T80Bd];04M7A`16ATH0AdM704Q8B011@D40A4A404M7A`12@T80A4A404=3@`14A4@0@410
0`13@d<01@16ATH0ADE504=3@`12@T80B4Q80080@D5100T0B4Q80492@P0o?cl0@41003hn?P12@T80
?Shn03lo?`10@4000`11@D400`15ADD0ATI604A4A00203hn?P0;0410@013@d<0@T920492@P0n?Sh0
?Cdm0410@00n?Sh0@D5104A4A011@D400P0j>SX0400l?3`0@41003lo?`10@400?clo04=3@`12@T80
?clo0410@00l?3`0?clo03dm?@0l?3`0?Cdm0451@@10@40303lo?`0903hn?P10@400?Shn03`l?014
A4@0ADE504A4A016ATH0@T9200<0?clo0P12@T801P11@D40?clo03hn?P10@400?Cdm03lo?`80@410
01D0@D5103lo?`10@400@d=30410@011@D40?Cdm04=3@`15ADD0@T9204E5A@13@d<0@41003lo?`12
@T80@D5103/k>`0j>SX0?Cdm0451@@12@T800P0n?Sh06P0l?3`0?Shn03`l?00m?Cd0>c/k0492@P14
A4@0@d=30410@00l?3`0?Shn03Xj>P0m?Cd0?3`l0410@014A4@0@D5103lo?`0n?Sh0@T9204E5A@14
A4@0FUYJ07EeM@1bLW80FUYJ0P0n?Sh0100i>CT0?3`l03lo?`0m?Cd203/k>`0803dm?@0l?3`0?clo
03lo?`0m?Cd0?Shn03`l?00o?cl203`l?080?clo04/0A4A4051@D01GEeL0EUIF04i>CP1;Bd/0?clo
03`l?013@d<0C4a<04A4A01EEED0Cdm?05MGE`1LG5`0FEUI05]KF`1RHV80J6QX06=SH`1@D500A4A4
03hn?P0o?cl0@41004=3@`12@T80@D510410@013@d<0ADE504Y:BP1;Bd/0@d=304M7A`1HF5P0Hf=S
07=cL`28R8P0TY:B08F5Q@1eMGD0IVIV06e]K@1SHf<0J6QX079bLP1kNg/0PH61071`L01VIVH0Jf][
05QHF01=CDd0D51@04m?C`1FEUH0JFUY07]kN`20P800H61P04a<C01FEUH0Fe]K05ADE01IFET0Lg=c
08V9R@2/[:`0W9bL05iNGP10@400AdM704Y:BP0o?cl00P0n?Sh03@10@400B4Q804a<C01?Cdl0J6QX
05IFEP1=CDd0C4a<04I6AP0o?cl0@T9206YZJP2;Rh/00P2FUYH05P26QXH0FUYJ04a<C01ADE40E5AD
05iNGP1nOWh0TY:B09NGU`24Q8@0KFe]06][J`1bLW80M7Ad092@T02`/;00dM7A0=gMg@3QhN40g=cL
0=OGe`3Bd]820<30`00T0;Vi^@2ATI40HV9R04i>CP1FEUH0FEUI05aLG01]KFd0JFUY05YJFP1DE5@0
@d=305ADE01WIfL0P82009fMW@2FUYH0V9RH0;>c/`2WYjL0Ng]k05UIF@13@d<0?Cdm03`l?01:BTX0
N7Qh0:JVYP34a<@0dM7A0;Fe]@2:RXX0EeMG04U9B@0n?Sh0?clo0P0k>c/0100m?Cd0>CTi03Ti>@0j
>SX203`l?00603/k>`0h>3P0>SXj03Ti>@0g=cL0>CTi0P0j>SX01P0l?3`0>c/k03Ph>00j>SX0=cLg
03Xj>P80?3`l0`0k>c/00`0j>SX0>CTi03Ti>@0203Ti>@0903Xj>P0h>3P0?3`l03dm?@0g=cL0>3Ph
03`l?00n?Sh0?Cdm0080?3`l00<0>SXj03Ti>@0i>CT00`0i>CT0100j>SX0>3Ph03Ti>@0j>SX203Lg
=`0303Ph>00i>CT0>CTi0080>CTi0P0h>3P01@0l?3`0=CDe03Lg=`0k>c/0>SXj0080>CTi00@0?Cdm
03`l?00i>CT0=cLg100h>3P00`0j>SX0>3Ph03Lg=`0203Ph>00403Lg=`0f=SH0=cLg03Ph>0<0>CTi
00L0>3Ph03Xj>P0i>CT0=cLg03Xj>P0g=cL0>CTi0080>3Ph00L0>CTi03Lg=`0e=CD0>3Ph03Ti>@0g
=cL0=SHf0080=cLg00<0=SHf03De=@0e=CD00P0f=SH00`0d=3@0=cLgooooo`0<ooooo`004?ooool0
2P1@D500CTi>051@D01?Cdl0Bd];04e=C@1>CTh0C4a<04e=C@1@D50204e=C@0504m?C`1=CDd0BDU9
04Q8B019BDT00P16ATH01018B4P0AdM704E5A@18B4P204];B`0804e=C@18B4P0B4Q804a<C01=CDd0
Fe]K04e=C@17AdL304];B`0804I6AP1;Bd/0B4Q804M7A`16ATH0A4A404=3@`16ATH404A4A00504I6
AP13@d<0A4A404M7A`1:BTX00P15ADD01P1CDe<0C4a<04U9B@14A4@0AdM704=3@`80@T9200@0C4a<
04i>CP12@T80A4A40P13@d<04P16ATH0@d=303lo?`0o?cl0ADE50451@@13@d<0B4Q804E5A@13@d<0
@D5104E5A@13@d<0A4A403lo?`14A4@0@4100451@@80?Shn00H0ATI60492@P14A4@0ADE503lo?`10
@40203lo?`050451@@13@d<0@D510492@P14A4@00P12@T801010@400?Shn03lo?`12@T8203lo?`80
?Shn01<0?3`l0410@00o?cl0?clo03`l?00o?cl0A4A40451@@0m?Cd0@D510492@P0o?cl0@T9204M7
A`15ADD0A4A403lo?`0m?Cd0?clo0080@41000X0?Cdm04=3@`14A4@0@4100451@@0o?cl0@d=304E5
A@11@D40BTY:0P13@d<07P16ATH0@D5104I6AP1=CDd0@D5103dm?@11@D40@d=30492@P0n?Sh0?3`l
03dm?@0l?3`0@D510492@P0o?cl0?Shn04E5A@18B4P0@T9203`l?00n?Sh0@T9204A4A016ATH0A4A4
04M7A`13@d<0A4A404I6AP80@T9200T0?Shn04M7A`1HF5P0DE5A04=3@`0o?cl0?Shn03`l?00o?cl0
0P0m?Cd02P0o?cl0>c/k03/k>`10@400@D510492@P11@D40@41003lo?`0n?Sh30451@@0I03`l?00m
?Cd0AdM70492@P13@d<0?Cdm03Xj>P0o?cl0ADE503lo?`16ATH0ADE504i>CP1FEUH0Fe]K07IfMP2<
S8`0Shn?08R8R01hN7P0IFEU05QHF01=CDd0ADE503dm?@020410@00L0492@P11@D40@41003hn?P14
A4@0@D5104=3@`16ATH0Bd];05iNGP21PH40Vi^K09bLW02SXj<0Zj^[0:JVYP2PX:00T92@08N7Q`1l
O7`0SXj>09ZJVP2SXj<0/;2`0;Vi^@2o_kl0aLG508^;R`80BDU900D0C4a<051@D01=CDd0CDe=04a<
C00205=CD`07059BDP1DE5@0EUIF05mOG`1SHf<0GUiN05UIF@0204e=C@0H04M7A`18B4P0?Shn0451
@@0o?cl0@d=304Q8B01=CDd0DE5A051@D01>CTh0ADE503lo?`0n?Sh0@d=303hn?P13@d<0ATI604E5
A@1CDe<0FUYJ05IFEP1ADE40BTY:0P14A4@0401<C4`0GEeM08^;R`2h^;P0b/[:0;^k^`2l_;`0];Bd
0:>SX`2:RXX0Ogmo08N7Q`2IVIT0ZZZZ0<K6aP3AdM420<O7a`0A0<g=c@3Hf=P0emOG0;no_`2QXJ40
Kfm_05QHF018B4P0CDe=04a<C017AdL0ADE503lo?`18B4P0De=C04m?C`1CDe<00P1GEeL04P1aLG40
Rh^;09JFUP2ZZZX0Ph>304m?C`10@400?Cdm04U9B@1KFe/0UIFE0<G5a@2h^;P0JFUY04A4A00n?Sh0
ADE50410@080>SXj0100?Shn03`l?00k>c/0>SXj03dm?@13@d<0>c/k03Xj>P0n?Sh0>SXj03dm?@0j
>SX0>3Ph03Hf=P0j>SX0>c/k0P0i>CT203Ph>00603Ti>@0l?3`0?clo03Xj>P0o?cl0>SXj0`0k>c/0
1@0j>SX0>CTi03Xj>P0m?Cd0>SXj0080>3Ph00<0=SHf03Ph>00m?Cd00P0l?3`01@10@400?3`l03Xj
>P0i>CT0>3Ph00<0>SXj00D0?3`l03Ti>@0i>CT0>CTi03Xj>P0203`l?00:03/k>`0i>CT0=cLg03/k
>`0h>3P0=CDe03Ti>@0l?3`0>CTi03Xj>P80>c/k00P0>SXj03Ti>@0i>CT0>SXj03Lg=`0h>3P0>CTi
03Ph>0<0=cLg0`0f=SH203Lg=`80>c/k00@0>3Ph03Lg=`0i>CT0>CTi0`0h>3P0100f=SH0=CDe03Hf
=P0g=cL203Hf=P0:03Ph>00i>CT0=cLg03Ph>00f=SH0>3Ph03Hf=P0g=cL0>SXj03Lg=`<0=SHf3Ooo
ool0013ooooo0100E5AD059BDP1=CDd0CTi>04];B`1>CTh0C4a<04Y:BP17AdL0BTY:04e=C@19BDT0
De=C051@D01<C4`0ATI60P18B4P04`17AdL0B4Q804U9B@1<C4`0BTY:04U9B@1=CDd0DE5A04Y:BP16
ATH0BDU904M7A`16ATH0@D5104Q8B019BDT0B4Q804M7A`1:BTX00P17AdL03018B4P0C4a<04];B`18
B4P0ATI604E5A@13@d<0ADE504Q8B015ADD0CDe=04I6AP80@D5102@0A4A40492@P14A4@0ADE504M7
A`16ATH0AdM704E5A@12@T80?Shn04A4A012@T80@41004A4A013@d<0@41004E5A@0n?Sh0@D5103dm
?@11@D40?3`l04I6AP11@D40@41003lo?`13@d<0?clo0410@014A4@0@41004I6AP12@T80@4100451
@@0o?cl404=3@`060410@00n?Sh0?clo03lo?`11@D40ADE50P12@T805P10@400@D510410@011@D40
@4100492@P10@400?3`l03hn?P12@T80A4A403lo?`0j>SX0ADE50410@011@D40@T9204E5A@10@400
?Shn0410@00o?cl203`l?0060451@@10@400?clo03/k>`0l?3`0@4100P0o?cl02P10@400@T9203lo
?`0m?Cd0@T9204A4A012@T80?clo04I6AP1=CDd203/k>`0503hn?P0l?3`0@D5104=3@`0n?Sh00P0o
?cl20410@00503hn?P0i>CT0>SXj03Ti>@0l?3`00P0n?Sh04`0o?cl0@41004I6AP0o?cl0>SXj04=3
@`0n?Sh0A4A403lo?`0k>c/0?Shn04A4A00m?Cd0?Shn0492@P0n?Sh0>c/k03dm?@10@4000P0m?Cd0
1@0j>SX0>c/k03Ph>00o?cl0>SXj0080>c/k00`0?Cdm0492@P15ADD0ADE50451@@0l?3`0>c/k03hn
?P0m?Cd0@T9203lo?`0j>SX203lo?`0603/k>`11@D40@T9203dm?@0n?Sh0?Cdm0P0o?cl08@0n?Sh0
@41004A4A01<C4`0IFEU06i^KP1QHF40EEEE04I6AP13@d<0>SXj03lo?`11@D40?Cdm03hn?P0o?cl0
A4A40410@00m?Cd0@d=304E5A@16ATH0CDe=05mOG`1hN7P0UIFE0::RXP2^[Zh0Z:RX09FEU@1mOGd0
Lg=c06a/K00206][J`0`07emO@2DU9@0UYJF08^;R`29RHT0Rh^;07emO@1dM7@0QhN708^;R`2:RXX0
VIVI09NGU`1mOGd0JVYZ05mOG`1SHf<0L71`07alO023Ph<0TI6A0:JVYP2d];@0c<c<0=;BdP2DU9@0
JFUY05aLG01;Bd/0ADE50492@P10@400@D510410@012@T80?Shn0410@01:BTX0De=C055AD@1;Bd/0
ATI60451@@15ADD0B4Q804=3@`1;Bd/0?clo0P17AdL02P1:BTX0C4a<061PH01fMWH0PX:208B4Q021
PH40UYJF0<C4a03Ng]h20>?Sh`0=0>3Ph03Lg=`0c/k>0<;2`P2`/;00QXJ607alO01fMWH0PH6109>C
T`2LW9`0WIfM0;6a/@020<c<c00^0<S8b02f][H0/;2`0:BTY02BTY80Shn?07moO`1TI6@0Kfm_06MW
I`17AdL0ADE504Y:BP14A4@0B4Q804E5A@14A4@0H61P071`L01aLG40MgMg08B4Q02=SHd0JFUY04];
B`1GEeL0TY:B0:n_[`2KVi/0K6a/0410@013@d<0>SXj03`l?00k>c/0?Shn0410@00h>3P0>c/k03`l
?00m?Cd0>3Ph03Ti>@0k>c/0=cLg03Ti>@80>SXj01@0=cLg03Ti>@0h>3P0>CTi03hn?P0l?3`0>c/k
03dm?@12@T80B4Q804e=C@1>CTh0FEUI07inOP28R8P0HF5Q0410@00j>SX0>c/k03Xj>P80?3`l00<0
>c/k03lo?`0n?Sh00P0j>SX203hn?P80>c/k0P0j>SX203dm?@0403`l?00j>SX0?3`l03/k>`80>SXj
0P0k>c/0500j>SX0=cLg03Ph>00h>3P0>c/k03Ph>00i>CT0=SHf03Xj>P0i>CT0>SXj03Ti>@0h>3P0
=cLg03/k>`0f=SH0=cLg03Xj>P0h>3P0=cLg0P0h>3P0200e=CD0=SHf03Ph>00h>3P0=cLg03Ph>00i
>CT0>3Ph0P0f=SH0100g=cL0>3Ph03Ph>00j>SX303Hf=P0@03Lg=`0f=SH0=CDe03Lg=`0h>3P0=cLg
03/k>`0h>3P0=cLg03Hf=P0h>3P0?3`l03De=@0i>CT0=cLg03Hf=Pgooooo000@ooooo`0404i>CP1?
Cdl0Cdm?04i>CP80C4a<0P19BDT06@18B4P0BTY:04];B`1:BTX0ATI604U9B@1<C4`0B4Q804Y:BP18
B4P0Bd];04I6AP15ADD0BDU904];B`19BDT0ATI604Y:BP1;Bd/0AdM704U9B@1:BTX0ATI604A4A015
ADD00P16ATH03`15ADD0BDU904I6AP17AdL0ATI604=3@`16ATH0BDU904E5A@13@d<0AdM704=3@`14
A4@0@d=304I6AP020492@P0S0451@@14A4@0@D5104I6AP11@D40A4A404=3@`10@400?clo0410@016
ATH0BDU904Q8B00m?Cd0@41004I6AP18B4P0AdM703hn?P13@d<0B4Q804E5A@0j>SX0@D5103`l?013
@d<0@D5104M7A`12@T80@4100451@@12@T80A4A40451@@0l?3`00`13@d<20492@P0E04A4A011@D40
@d=303lo?`14A4@0@d=30410@012@T80AdM704=3@`11@D40@4100492@P13@d<0@D5103lo?`11@D40
?clo03hn?P12@T80A4A400<0?clo00<0?3`l03lo?`10@4000P0o?cl01`14A4@0?Shn0451@@15ADD0
?clo0492@P0m?Cd00P0n?Sh01@11@D40@41003hn?P10@400?3`l0080?Shn00@0@D5104M7A`15ADD0
@4100P12@T80300m?Cd0?Shn03dm?@10@400?Shn0410@00m?Cd0@T9204E5A@0o?cl0@41003lo?`80
?Shn00H0@41003hn?P12@T80?clo0410@00m?Cd20451@@050410@019BDT0?clo04=3@`15ADD00P11
@D402P0o?cl0?Cdm04=3@`18B4P0>SXj03lo?`11@D40?Shn03`l?012@T8203lo?`030410@012@T80
ADE500<0?clo01l0@d=30492@P10@400@D5104Q8B014A4@0@T9204=3@`11@D40?Cdm03hn?P10@400
?3`l03/k>`0m?Cd0@d=303lo?`0m?Cd0@41003lo?`12@T80?clo04I6AP1;Bd/0ATI604=3@`0o?cl0
@D510410@013@d<0?clo0080@d=301X0@41003dm?@0k>c/0?3`l0410@011@D40?Shn04U9B@1OGel0
Lg=c0861P@28R8P0N7Qh06i^KP1VIVH0Hf=S06YZJP1YJFT0I6AT06i^KP20P800TY:B09fMW@2KVi/0
XJ6Q09nOW`80V9RH01@0Ng]k06i^KP1UIFD0JVYZ07alO02EUID0[jn_0:VYZ@2NWYh0VYZJ09:BTP2K
Vi/0[jn_0<?3``37alL0b<S80=3@d03Cdm<0e]KF0=_Kf`80gmoO0280d=3@0<?3``2GUiL0Ng]k08b<
S02LW9`0Shn?07inOP1aLG40HV9R05]KF`1CDe<0Cdm?04A4A01;Bd/0@T9203hn?P16ATH0B4Q80492
@P19BDT0K6a/069RHP19BDT0GUiN09FEU@2RXZ80VIVI0;6a/@3>c/h0iNGU0>[ZjP3Ph>00^;Rh0P2W
YjL07`2TY:@0YZJV0:FUY@2h^;P0cLg=0<k>cP3:b/X0alO70;Zj^P2f][H0V9RH09FEU@2<S8`0Jf][
05eMG@1VIVH0NGUi0861P@2FUYH0`<300=7Ad@2k^k/0V9RH07]kN`1_Kfl0JFUY06=SH`1GEeL0Cdm?
0410@00o?cl00P0n?Sh05P1:BTX0HV9R08V9R@2XZ:P0YjNW096AT@1JFUX0AdM704m?C`1[Jf/0O7al
05ADE00o?cl0>c/k03hn?P0m?Cd0?Shn0451@@0k>c/0?Shn03dm?@0j>SX203Ti>@0303/k>`0i>CT0
>c/k0080>SXj0`0h>3P04@0k>c/0A4A405]KF`1oOgl0Vi^K0;Jf]P38b<P0bl_;0<71`@2f][H0YjNW
07IfMP17AdL0?Cdm03`l?00k>c/0?3`l0080>3Ph00<0>SXj03Ph>00j>SX00P0m?Cd303Xj>P0:03`l
?00j>SX0>3Ph03`l?00k>c/0>CTi03Xj>P0l?3`0>CTi03dm?@80>SXj00@0>CTi03Ph>00j>SX0>CTi
0P0h>3P0100n?Sh0>c/k03Lg=`0i>CT203Hf=P80=cLg0P0h>3P01P0f=SH0>CTi03Ti>@0g=cL0=3@d
03Lg=`80>SXj00P0=cLg03`l?00h>3P0>3Ph03Lg=`0j>SX0>c/k03Lg=`80>3Ph00T0>CTi03Hf=P0f
=SH0=cLg03Ti>@0f=SH0=cLg03Hf=P0e=CD00P0h>3P0100e=CD0>CTi03Ti>@0e=CD303Lg=`0403De
=@0i>CT0=SHf03Ph>0gooooo000@ooooo`@0CTi>0`1;Bd/04018B4P0Bd];04a<C01=CDd0CTi>04U9
B@1;Bd/0C4a<04M7A`1=CDd0C4a<04Q8B015ADD0ATI604U9B@1;Bd/204Q8B00:04];B`1:BTX0BDU9
04U9B@16ATH0AdM704Y:BP13@d<0ATI604M7A`80ATI600D0Bd];04U9B@18B4P0A4A40451@@0204I6
AP0304A4A012@T80@D510080@41000D0A4A40451@@13@d<0@41004=3@`020492@P0N04];B`1<C4`0
AdM704A4A015ADD0DU9B04Y:BP14A4@0?Shn0492@P14A4@0@D5104A4A018B4P0@T9204=3@`16ATH0
@d=30451@@12@T80@41004A4A011@D40@41004=3@`14A4@0@41003lo?`12@T80@d=30P11@D404013
@d<0AdM70410@00m?Cd0?Shn0410@014A4@0?Shn0451@@16ATH0@T920410@015ADD0@D5104=3@`14
A4@20451@@0N03/k>`0n?Sh0ADE503hn?P0o?cl0@D5103hn?P14A4@0?clo0410@00o?cl0@41004A4
A00o?cl0?3`l0451@@0j>SX0@D5104E5A@12@T80@4100492@P13@d<0?Shn0410@00m?Cd0>c/k03hn
?P0m?Cd0?clo0P10@4001P0m?Cd0?clo0410@011@D40?Shn03/k>`80?Cdm00`0@T9203hn?P14A4@0
B4Q80492@P11@D40?Cdm0492@P0o?cl0@41003dm?@0n?Sh20451@@0904=3@`11@D40?Shn03lo?`14
A4@0@d=303dm?@0o?cl0@T920080?clo00@0@41003`l?00o?cl0@4100P0n?Sh203Xj>P060410@00o
?cl0AdM704I6AP0m?Cd0?Shn0`10@4002P11@D40?Shn03dm?@0n?Sh0@d=30410@015ADD0BTY:0492
@P0o?cl203/k>`0503Xj>P0i>CT0?3`l03dm?@10@4000P0m?Cd01@11@D40ATI603dm?@10@400?Shn
0080?Cdm00`0?3`l03Xj>P0i>CT0@41003Xj>P10@400@D5104A4A00o?cl0?Shn03dm?@0j>SX203lo
?`0L04E5A@1QHF40Shn?0:j^[P2g]kL0Z:RX09FEU@29RHT0PH6108>3P`1mOGd0NGUi07QhN01nOWh0
S8b<08f=S@28R8P0MgMg06UYJ@1LG5`0Hf=S061PH01XJ6P0KVi^08>3P`1eMGD0L71`0861P@80TI6A
06@0Rh^;08j>SP2IVIT0WIfM09BDU02GUiL0X:2P0::RXP2XZ:P0[jn_0;Jf]P2i^KT0]KFe0;:b/P2[
Zj/0XJ6Q09bLW02CTi<0QXJ607emO@23Ph<0O7al07]kN`20P800PH6108N7Q`2IVIT0];Bd0;Fe]@2f
][H0Ogmo09JFUP35aLD0]kNg0:NWY`2`/;00d=3@0<o?c`39bLT0alO70=[JfP3UiND0g]kN0=CDe03E
eMD0fm_K0=cLg03Bd]80]kNg0:f][@2@T900SXj>08^;R`25QHD0PH6108f=S@2GUiL0/k>c0<W9b@3;
bl/0cLg=0;bl_02i^KT0[jn_0:>SX`28R8P0Hf=S04m?C`18B4P0A4A405IFEP20P800VIVI07moO`1d
M7@0JVYZ05]KF`1YJFT0U9BD0:^[Z`24Q8@0Fe]K04Y:BP15ADD0@T9203lo?`12@T80CDe=06=SH`2B
TY80WinO065QH@0m?Cd0>c/k04];B`1DE5@0?Cdm03/k>`0g=cL0?Cdm0`0k>c/203dm?@80>SXj1P0i
>CT303Xj>P0?05aLG02=SHd0XJ6Q09nOW`2@T900Rh^;08V9R@1`L700Fe]K04E5A@11@D40>SXj03De
=@0i>CT0?3`l0080>3Ph00<0>SXj03/k>`0i>CT00P0k>c/01@0i>CT0>SXj03Ph>00j>SX0>3Ph00<0
>CTi00/0=CDe03Ph>00j>SX0=cLg03lo?`1NGUh0KFe]04];B`0j>SX0>3Ph03Lg=`0203Ti>@0703Hf
=P0h>3P0>3Ph03lo?`0i>CT0>SXj03Lg=`0203Ph>080>CTi00h0>3Ph03@d=00e=CD0=CDe03Xj>P0h
>3P0>SXj03Lg=`0f=SH0>CTi04M7A`0k>c/0>3Ph03Lg=`80>3Ph00H0=cLg03Ti>@0j>SX0>SXj03Ph
>00f=SH203Ph>00403Hf=P0g=cL0=cLg03Hf=P80>CTi00H0=SHf03Lg=`0f=SH0=CDe03Hf=P0e=CD2
03Hf=P0303Ph>00e=CD0=cLg00gooooo000@ooooo`0<055AD@1>CTh0D51@04i>CP1=CDd0BDU904e=
C@1:BTX0CDe=04Q8B01:BTX0Cdm?0`1<C4`01`18B4P0AdM704U9B@19BDT0Bd];04U9B@1>CTh00P18
B4P01P1<C4`0B4Q804I6AP17AdL0BDU904M7A`<0B4Q800L0BTY:04I6AP16ATH0ADE504Q8B01:BTX0
ATI60080ADE500/0@T9204=3@`1;Bd/0ADE50451@@10@400@T920451@@12@T80A4A40410@00204A4
A00M04Q8B019BDT0Bd];04I6AP11@D40AdM704U9B@14A4@0AdM704A4A010@400@T9204=3@`12@T80
@d=30492@P14A4@0@D5104=3@`11@D40?Shn04A4A010@400?clo04=3@`15ADD0@d=30410@00n?Sh0
0P10@4002`16ATH0?clo03dm?@0n?Sh0@4100451@@10@400?Cdm0451@@0l?3`0?Shn0080ADE500D0
@4100451@@0n?Sh0@41004=3@`020410@080?clo00@0@D5103lo?`14A4@0AdM71@0o?cl01@12@T80
A4A403hn?P12@T80@D510080A4A400@0@T920410@00o?cl0@d=30P10@4001@16ATH0A4A403dm?@0m
?Cd0@4100080?Cdm0`0o?cl00`11@D40ATI604M7A`0203hn?P0?03dm?@15ADD0@41003dm?@0o?cl0
@D5104A4A00n?Sh0@D5103lo?`12@T80?clo03hn?P11@D40@T9200<0@41000X0@D510410@013@d<0
?Shn03dm?@0o?cl0?Cdm03/k>`13@d<0?clo0P0k>c/303hn?P0E03lo?`0m?Cd0?Shn03hn?P0o?cl0
@4100492@P0n?Sh0?3`l03lo?`0l?3`0?Shn03/k>`13@d<0A4A40451@@14A4@0@41004A4A00i>CT0
>c/k00<0?Cdm00H0>SXj03lo?`11@D40@D510492@P0n?Sh203lo?`0<0410@00o?cl0>c/k03Ph>00j
>SX0>c/k03`l?00j>SX0?Cdm03`l?010@400@T920P11@D40600l?3`0?Cdm03dm?@17AdL0Cdm?05]K
F`1RHV80Fe]K05MGE`1@D500EeMG06i^KP1fMWH0QhN706a/K01EEED0IFEU075aL@1oOgl0N7Qh07=c
L`1SHf<0FEUI04a<C080B4Q800@0@d=30492@P0o?cl0?Cdm0P12@T800`10@400?Shn03lo?`0204E5
A@0:04=3@`0o?cl0BDU905EEE@1XJ6P0MGEe06YZJP1QHF40G5aL059BDP80CDe=00L0ATI605IFEP1R
HV80KFe]07UiN@1lO7`0J6QX0080I6AT01P0H61P05mOG`1VIVH0S8b<0;Vi^@3@d=00cLg=0<W9b@3H
f=P0c/k>0:VYZ@25QHD0NGUi0::RXP3Bd]80h>3P0>CTi03Shn<0bLW908J6QP20P800S8b<0:FUY@2g
]kL20<71`@0<0;2`/02HV9P0Ph>307IfMP25QHD0VIVI0;2`/02o_kl0^KVi0:RXZ02JVYX0TY:B0P28
R8P0101[Jf/0GUiN05=CD`1;Bd/204A4A00S0492@P14A4@0@d=304E5A@1;Bd/0C4a<04i>CP1OGel0
PH610:RXZ03?cll0c<c<0;Bd]02IVIT0K6a/05aLG013@d<0ADE50451@@0m?Cd0A4A404I6AP0l?3`0
>c/k04U9B@1^KVh0IfMW03lo?`0n?Sh0>SXj03Ti>@0o?cl0?3`l03/k>`0i>CT00`0j>SX01@0h>3P0
?Shn03`l?00j>SX0>3Ph00@0>CTi00T0?Cdm03/k>`0k>c/0>c/k03Xj>P0m?Cd0>c/k03`l?00h>3P0
0P0j>SX203Lg=`0303Xj>P0i>CT0>3Ph0080>CTi0P0k>c/01P0j>SX0=cLg03Lg=`0g=cL0>c/k03Ti
>@80=cLg0100>3Ph03Ti>@0h>3P0>CTi051@D029RHT0PX:205aLG00k>c/0=cLg03Hf=P0i>CT0=SHf
03Ti>@0f=SH0=cLg0P0f=SH00`0e=CD0=cLg03Hf=P0303Ph>00A03Lg=`0f=SH0=SHf03Ti>@0e=CD0
>3Ph03Ti>@0j>SX0=cLg03Ti>@0e=CD0=SHf03@d=00f=SH0=3@d03Hf=P0g=cL00`0f=SH01`0e=CD0
=SHf03Hf=P0f=SH0=CDe03@d=00e=CD00P0f=SH203Lg=`0303@d=00e=CD0=3@d0080=CDe0P0c<c<0
100h>3P0=cLg03@d=00f=SH=ooooo`004?ooool404i>CP80CDe=01H0Bd];04e=C@1<C4`0C4a<04m?
C`1:BTX0BDU904Q8B01:BTX0Bd];04Q8B019BDT0ATI604M7A`15ADD0AdM704Y:BP18B4P0AdM704Q8
B016ATH0B4Q80P19BDT01P1:BTX0ATI604Q8B018B4P0BTY:04Q8B080AdM70100ATI60492@P13@d<0
AdM704U9B@18B4P0AdM704I6AP15ADD0A4A404E5A@14A4@0AdM70451@@10@400@d=30P18B4P01`1F
EUH0AdM704Q8B016ATH0A4A40492@P10@4000`12@T803P17AdL0A4A40410@013@d<0@T920451@@10
@400?clo0492@P13@d<0B4Q804=3@`10@400@D510P15ADD01@12@T80@41003lo?`0l?3`0?clo00<0
?Cdm00<0?clo03hn?P0n?Sh00P10@40203lo?`0304=3@`0o?cl0@D510080@4100P0n?Sh00`0m?Cd0
?clo03lo?`0203hn?P080492@P11@D40@d=304A4A011@D40@4100451@@10@4020451@@0`0492@P13
@d<0?Shn0451@@14A4@0@d=303hn?P11@D40@T9204E5A@12@T80ATI604E5A@17AdL0@41003lo?`0m
?Cd0?3`l03lo?`10@400@T9204E5A@17AdL0BDU903hn?P16ATH0@T9203hn?P11@D40?Shn03lo?`0n
?Sh0?3`l0410@013@d<0AdM70410@00o?cl0@T9204=3@`15ADD0?Cdm0410@011@D40?Shn04E5A@1;
Bd/0@T920P10@4005P11@D40?3`l03`l?00l?3`0@41003hn?P0o?cl0@d=303`l?00m?Cd0@4100492
@P0m?Cd0?Shn04A4A012@T80?Cdm03/k>`0o?cl0@D5103hn?P0k>c/203lo?`0<0410@015ADD0@410
03lo?`0n?Sh0?clo0451@@10@400?3`l04=3@`12@T80@D510P0o?cl03010@400?3`l0410@00n?Sh0
?clo03hn?P0i>CT0?3`l03dm?@10@400>CTi0410@080>c/k00L0?3`l03hn?P14A4@0@41004=3@`14
A4@0?Cdm0080A4A401`0@T92059BDP1]KFd0Ogmo07emO@1`L700FUYJ05QHF01ADE40Cdm?04i>CP1;
Bd/0AdM70410@012@T80@D510492@P13@d<0@41003lo?`13@d<0?clo03Xj>P10@400?3`l0451@@0o
?cl0?Cdm0P11@D40<P0o?cl0@4100492@P14A4@0BTY:05=CD`1KFe/0HV9R06MWI`1bLW80S8b<09nO
W`2EUID0R8R807inOP22PX80RXZ:08N7Q`1kNg/0E5AD059BDP1OGel0Jf][071`L01dM7@0Ogmo08N7
Q`2>SXh0V9RH08j>SP27QhL0QXJ609NGU`2QXJ40Xj>S0:6QX@29RHT0Ph>308:2PP24Q8@0Ph>307em
O@1fMWH0LW9b071`L01eMGD0TI6A0;2`/03<c<`0fMWI0P3GemL07P3EeMD0f=SH0=OGe`3Fe]H0f=SH
0=_Kf`3Shn<0gmoO0>;RhP3Shn<0gmoO0=cLg03<c<`0/k>c0:BTY02@T900MgMg075aL@1jNWX0Ogmo
08>3P`1dM7@0HV9R05EEE@1@D500GEeM071`L02@T900]KFe0<?3``80cLg=01l0YJFU09ZJVP2?Shl0
O7al06e]K@1ADE40?Cdm03hn?P0o?cl0ATI607AdM01oOgl0CDe=03Xj>P0g=cL0?Shn03/k>`0m?Cd0
?Shn03/k>`0i>CT0>SXj03`l?00m?Cd0?Shn03Xj>P0k>c/0>SXj03Ti>@0j>SX0?Cdm0080>3Ph00T0
=cLg03`l?00i>CT0=cLg03Xj>P0i>CT0>3Ph03Xj>P0m?Cd00P0k>c/02P0h>3P0>SXj03Ti>@0j>SX0
=cLg03Hf=P0j>SX0?3`l03Ph>00j>SX203Ti>@0@03/k>`0j>SX0>3Ph03Xj>P0k>c/0?Shn04E5A@1P
H600DU9B0451@@0i>CT0>c/k03Lg=`0e=CD0>SXj03Lg=`80>3Ph00@0=cLg03Ph>00g=cL0>CTi0P0j
>SX203Ph>00=03Lg=`0f=SH0>SXj03Lg=`0i>CT0>3Ph03Xj>P0g=cL0>SXj03Ph>00i>CT0=SHf03@d
=00203Hf=P0803De=@0g=cL0>3Ph03Lg=`0h>3P0=cLg03Ti>@0g=cL203De=@0403<c<`0d=3@0=3@d
03Hf=P80=cLg00P0=CDe03@d=00f=SH0=SHf03De=@0f=SH0=CDe03Hf=P@0=cLg3Oooool0013ooooo
00<0CDe=051@D01ADE400P1?Cdl0101@D500BTY:04i>CP1=CDd204Y:BP0R04a<C01:BTX0C4a<04];
B`1?Cdl0Bd];04e=C@1>CTh0B4Q804a<C019BDT0ATI604M7A`13@d<0ATI604Q8B019BDT0AdM704E5
A@14A4@0AdM704];B`17AdL0A4A404Q8B019BDT0B4Q804I6AP18B4P0CTi>04e=C@16ATH0ADE504Q8
B080ADE50200ATI604Q8B018B4P0BTY:04E5A@11@D40@4100492@P10@400A4A403lo?`16ATH0ADE5
03lo?`11@D40@41004=3@`15ADD0@d=304E5A@1FEUH0CDe=04=3@`14A4@0?clo0451@@0n?Sh0@T92
04E5A@12@T80@D5103lo?`80@41000H0A4A404=3@`11@D40?Shn03dm?@0l?3`203lo?`0;03hn?P10
@400@d=30410@011@D40@41004=3@`0n?Sh0ADE503hn?P12@T800P0m?Cd203lo?`0403`l?00n?Sh0
@41004A4A080?clo01H0A4A404=3@`13@d<0A4A403lo?`11@D40@T9203hn?P0m?Cd0?3`l03/k>`0o
?cl0@41004Y:BP16ATH0@D5103lo?`10@400CTi>04A4A012@T80@D51100m?Cd02@0o?cl0@41003lo
?`15ADD0@d=304M7A`19BDT0?clo0410@00203hn?P0803lo?`0j>SX0?Cdm04A4A00l?3`0@T9204E5
A@1EEED203lo?`80@d=300X0?clo0451@@10@400@D5103lo?`16ATH0ADE503lo?`12@T80?clo0P0n
?Sh02P0l?3`0?clo0451@@10@400@D5104=3@`18B4P0C4a<0410@00l?3`203lo?`040451@@13@d<0
@d=303hn?P80@41000P0?Cdm03hn?P0l?3`0@T9203dm?@0l?3`0?clo03Xj>P80@41000H0@T9203lo
?`10@400A4A403lo?`0j>SX303hn?P060492@P0n?Sh0?3`l03lo?`10@400?Cdm0P11@D400`0l?3`0
?Cdm03`l?00203Xj>P0O03Ph>00j>SX0@41003dm?@0l?3`0@D5103lo?`16ATH0@d=30410@012@T80
@D5104E5A@0o?cl0?Shn03`l?00k>c/0?3`l03dm?@0o?cl0?Shn03lo?`0k>c/0?Shn04=3@`0o?cl0
?3`l03lo?`0k>c/0?3`l0492@P0203/k>`0503hn?P0m?Cd0?Shn03`l?00o?cl00P0n?Sh05`0o?cl0
?Shn0410@01>CTh0GUiN07UiN@2MWId0YZJV09RHV02EUID0R8R805iNGP1CDe<0C4a<051@D01FEUH0
HF5Q06ATI01hN7P0R8R80861P@1hN7P0MWIf0080NGUi0100I6AT06e]K@1NGUh0F5QH05iNGP1QHF40
DE5A059BDP1KFe/0Lg=c08B4Q021PH40LG5a071`L01HF5P0Cdm?0P11@D40AP17AdL0BDU905ADE01V
IVH0PX:209>CT`2][Jd0Z:RX09ZJVP2NWYh0X:2P0:JVYP2a/K40_Kfm0<?3``3=cLd0bl_;0<c<c03?
cll0cLg=0=SHf03Ng]h0gmoO0=_Kf`3GemL0eMGE0=WIf@3Hf=P0g]kN0=cLg03MgMd0d=3@0:b/[01g
MgL0QhN70::RXP25QHD0O7al0:NWY`34a<@0cLg=0=SHf03Kfm/0eMGE0<?3``27QhL0E5AD04a<C010
@400?clo03Xj>P1^KVh0TY:B06a/K01>CTh0?clo03/k>`0m?Cd0?Shn03`l?00m?Cd0?3`l03Xj>P0h
>3P0?Cdm03/k>`0o?cl0?Cdm03hn?P0k>c/203`l?00903Ti>@0j>SX0>SXj03Ti>@0o?cl0=SHf03dm
?@0g=cL0?3`l00<0>CTi00/0=cLg03Ti>@0h>3P0>CTi03`l?00j>SX0>CTi03Xj>P0i>CT0>c/k03Xj
>P0203Ph>00;03hn?P1GEeL0I6AT06e]K@1JFUX0?Shn03Ti>@0k>c/0?3`l03Ti>@0h>3P00P0i>CT0
1@0k>c/0>SXj03Hf=P0h>3P0=CDe0080>3Ph00<0>CTi03Ph>00h>3P00P0j>SX203Ph>00<03Lg=`0h
>3P0>CTi03Ph>00i>CT0=cLg03Ph>00g=cL0>3Ph03De=@0f=SH0=CDe0P0g=cL01P0e=CD0=cLg03Ph
>00e=CD0=cLg03Ph>080=SHf00D0=CDe03<c<`0f=SH0=SHf03Lg=`0203Ph>080=CDe00P0=cLg03Ti
>@0f=SH0=cLg03De=@0g=cL0=SHf03Ph>080>CTi3Oooool0013ooooo01T0CTi>04a<C01>CTh0CDe=
04];B`19BDT0BTY:04m?C`1<C4`0CDe=04Q8B01:BTX0Bd];04e=C@19BDT0Bd];04U9B@1:BTX0C4a<
04M7A`18B4P0BDU904M7A`1@D500@d=300<0BDU900d0Bd];04Y:BP17AdL0BTY:04e=C@1:BTX0AdM7
04a<C01;Bd/0CTi>04];B`18B4P0BDU90080ATI600<0BTY:04Q8B016ATH00P13@d<04@16ATH0Bd];
04];B`18B4P0@D5104E5A@14A4@0@d=304U9B@14A4@0@T9204A4A012@T80@D5104=3@`12@T80?clo
0080@41000<0@T920451@@15ADD00P13@d<06`14A4@0@d=304M7A`15ADD0@d=304A4A010@400AdM7
0492@P11@D40@T9204e=C@12@T80?3`l03/k>`0m?Cd0@D510492@P0o?cl0?Cdm03Ph>010@400@D51
0410@00n?Sh0@d=303lo?`0203dm?@0503lo?`0m?Cd0?Cdm0451@@13@d<00P0n?Sh05011@D40?Shn
0492@P0o?cl0@T9204U9B@13@d<0@D5104=3@`11@D40ADE50492@P0l?3`0?clo04=3@`0n?Sh0>c/k
03hn?P0m?Cd0?Shn0P13@d<01@0o?cl0B4Q803lo?`13@d<0@4100080?Cdm00T0@D510492@P0l?3`0
>CTi03hn?P19BDT0>c/k03lo?`11@D400P12@T801`0n?Sh0>c/k0410@012@T80@4100492@P14A4@0
0P10@400200m?Cd0@T9203/k>`0l?3`0?Shn0451@@0o?cl0?Cdm0P13@d<03P17AdL0@D5103dm?@0k
>c/0?3`l03lo?`11@D40ATI60492@P0o?cl0@41004Q8B010@400?3`l0P0n?Sh02`15ADD0?Cdm03dm
?@0n?Sh0@D510410@00n?Sh0@41003dm?@0o?cl0>SXj0080?3`l0P0m?Cd03P0l?3`0?clo03dm?@0o
?cl0@D5103lo?`0h>3P0>CTi03`l?00n?Sh0>c/k03dm?@0l?3`0?clo0P0m?Cd0100o?cl0?Cdm03/k
>`0h>3P203dm?@0903/k>`0i>CT0?3`l0492@P14A4@0@D5104Q8B00l?3`0@T920080?clo00D0@D51
03dm?@0l?3`0?clo03hn?P0203dm?@0303`l?00o?cl0@d=30080@41002D0?Cdm03lo?`0o?cl0?Cdm
03lo?`0k>c/0?clo03`l?00n?Sh0?clo03/k>`0n?Sh0@D5104A4A018B4P0De=C065QH@1ZJVX0NGUi
08j>SP2KVi/0ZJVY0;6a/@2ZZZX0ZJVY09^KV`2ATI40UIFE09BDU02>SXh0Ogmo07IfMP1^KVh0LW9b
06IVIP1QHF40GEeM0080EEEE02X0E5AD05EEE@1OGel0J6QX06IVIP1/K6`0Lg=c079bLP1hN7P0MgMg
075aL@2>SXh0Zj^[0:ZZZP2PX:00Shn?05aLG01BDU80IfMW07alO01cLg<0FUYJ04a<C014A4@0@D51
03lo?`16ATH0De=C07=cL`28R8P0/K6a0;Rh^02`/;00WinO09VIV@29RHT0QXJ608N7Q`2:RXX0UIFE
09jNWP2MWId20:6QX@0T0:BTY02KVi/0Y:BT0;bl_036a/H0d=3@0=SHf03IfMT0d];B0=CDe03IfMT0
eMGE0<71`@3?cll0eMGE0<[:bP2a/K40VYZJ08n?S`2a/K40bLW90<_;b`3Jf]X0cLg=0;6a/@2TY:@0
S8b<065QH@1@D500@D5105]KF`24Q8@0RHV907YjNP1GEeL0@4100P0n?Sh03`0i>CT0?Shn03`l?00i
>CT0>c/k03`l?00n?Sh0@D5103hn?P14A4@0?Cdm03lo?`0h>3P0>SXj03dm?@020410@0050451@@0l
?3`0?Cdm03`l?00n?Sh00P0k>c/01`0j>SX0?3`l03Xj>P0k>c/0?Shn03dm?@0g=cL00P0f=SH02P0g
=cL0>SXj0492@P1TI6@0ZJVY0=?Cd`3>c/h0alO709>CT`1=CDd203Xj>P0303`l?00j>SX0=SHf00D0
=SHf00<0>c/k03dm?@0n?Sh00P0i>CT0100h>3P0>CTi03Xj>P0k>c/303Ph>080=cLg00<0=SHf03De
=@0d=3@00`0d=3@02@0c<c<0>3Ph03Ti>@0h>3P0=SHf03Lg=`0i>CT0>c/k03Ti>@0203Lg=`0403De
=@0i>CT0=SHf03Lg=`80=CDe0`0g=cL0300e=CD0=cLg03Ph>00h>3P0=3@d0410@018B4P0=cLg03De
=@0d=3@0=CDe03Ph>0gooooo000@ooooo`0:04];B`1>CTh0CTi>04U9B@17AdL0ATI604U9B@1=CDd0
BDU904];B`80AdM70P1<C4`304Y:BP0704Q8B016ATH0@41004=3@`1<C4`0ATI604M7A`0204A4A009
04=3@`14A4@0A4A404E5A@14A4@0ADE504M7A`1<C4`0CDe=0080BDU900L0Cdm?04Q8B00o?cl0?3`l
04A4A013@d<0B4Q800@0AdM700H0ATI604A4A013@d<0@D5103dm?@13@d<204A4A00304Q8B01:BTX0
@d=30080@41000D0@D5103dm?@10@400@T9203/k>`0203lo?`0:0410@00l?3`0?clo04A4A018B4P0
CDe=04];B`17AdL0?Shn04=3@`80?clo01l0@d=304A4A00l?3`0@T9203/k>`0l?3`0?clo03Xj>P10
@400?Shn0410@011@D40>c/k03Xj>P0m?Cd0?3`l03lo?`14A4@0@D5103dm?@0n?Sh0?clo03Ph>012
@T80?Cdm03hn?P0j>SX0?Cdm04=3@`0l?3`0@D510080?Shn00`0@T920410@010@400@D5103lo?`15
ADD0A4A40451@@0m?Cd0>c/k03dm?@0l?3`203Ti>@0603/k>`12@T80?clo03lo?`18B4P0@d=30P10
@4000`14A4@0@d=303lo?`0204=3@`0303dm?@0o?cl0DU9B0080?clo00`0?Shn03Xj>P11@D40>c/k
03lo?`17AdL0@41003lo?`0j>SX0?clo04=3@`0l?3`203hn?P0D0410@00k>c/0?Cdm03`l?00k>c/0
=cLg04E5A@0l?3`0@D5103lo?`10@400?Shn0451@@0l?3`0>3Ph03dm?@0n?Sh0?Cdm03Ti>@0m?Cd2
0410@00503`l?00j>SX0>c/k03Hf=P0l?3`00P0n?Sh203Ti>@<0?Shn00l0>SXj03hn?P0m?Cd0>SXj
03lo?`0n?Sh0@d=303Xj>P0l?3`0?Shn03`l?00m?Cd0>c/k03`l?00k>c/00`0j>SX01`0i>CT0?clo
03/k>`0j>SX0>c/k0451@@0k>c/00P0j>SX02`0o?cl0@4100492@P0o?cl0>SXj03dm?@16ATH0?Shn
04A4A00m?Cd0>CTi0080?clo00L0?Shn0451@@0o?cl0>SXj03/k>`0i>CT0>SXj0080?Shn00P0@D51
03hn?P11@D40?clo03Ti>@0k>c/0>SXj03/k>`80?3`l0200>CTi04U9B@1:BTX0HV9R07]kN`2DU9@0
V9RH0:ZZZP2d];@0^KVi0;>c/`2OWil0Shn?07inOP1RHV80DE5A04E5A@12@T80ATI604M7A`12@T80
ATI603dm?@0i>CT0@d=303Lg=`0l?3`0>3Ph03/k>`0j>SX0@41004I6AP80@41000d0?clo04=3@`0j
>SX0?Cdm04A4A01CDe<0J6QX0:2PX03GemL0c/k>0:2PX02EUID0J6QX0080ADE505d0EeMG06i^KP20
P800QHF5065QH@1YJFT0PX:207EeM@1MGEd0Fe]K05=CD`23Ph<0[jn_0=7Ad@3Cdm<0c/k>0;6a/@2>
SXh0PH6108R8R02TY:@0alO70=SHf03MgMd0h>3P0=oOg`3IfMT0d=3@0<g=c@39bLT0`L710;fm_@37
alL0fm_K0=GEe@3?cll0e]KF0<S8b03Kfm/0hN7Q0>CTi03EeMD0/;2`07AdM01KFe/0N7Qh08J6QP2]
[Jd0a/K60<W9b@38b<P0a<C40:f][@2FUYH0H61P04I6AP1:BTX0@d=3051@D01>CTh0AdM704E5A@0m
?Cd0>CTi03`l?00n?Sh0?clo03`l?00o?cl0@T9203lo?`11@D40@d=30410@015ADD0Cdm?05IFEP1Y
JFT0M7Ad05iNGP1DE5@0GemO079bLP1YJFT0J6QX04e=C@0o?cl0<S8b03Xj>P0i>CT0>SXj03/k>`0l
?3`00`0j>SX04@0i>CT0?Cdm04];B`21PH40^;Rh0;6a/@2MWId0JVYZ05IFEP0k>c/0=cLg03Xj>P0g
=cL0>3Ph03`l?00j>SX0=SHf00<0=3@d0P0g=cL0100e=CD0>CTi03/k>`0j>SX203Ti>@0D03/k>`0f
=SH0>CTi03Lg=`0e=CD0=SHf03De=@0d=3@0=SHf03De=@0d=3@0=CDe03Hf=P0h>3P0=cLg03Hf=P0e
=CD0>3Ph03Xj>P0f=SH203@d=00503De=@0c<c<0>3Ph03Lg=`0m?Cd0100e=CD0100f=SH0=CDe03De
=@0g=cL303De=@0604];B`0e=CD0=CDe03<c<`0d=3@0=cLg3Oooool0013ooooo00/0DE5A05=CD`1A
DE40D51@04e=C@1>CTh0CDe=04a<C017AdL0BDU904Q8B00204U9B@0>04Q8B01:BTX0BDU904Y:BP18
B4P0BDU904I6AP19BDT0AdM704Q8B012@T80@d=304I6AP19BDT204Q8B080BDU90P16ATH04019BDT0
BTY:04U9B@18B4P0Bd];04Y:BP14A4@0@d=304M7A`19BDT0BTY:04A4A015ADD0BDU904Q8B012@T83
04E5A@0:04I6AP11@D40ADE504E5A@13@d<0@T9204I6AP11@D40A4A404=3@`80@41000L0?Shn04I6
AP13@d<0?clo04I6AP12@T80?3`l0080?clo00L0@d=304Q8B015ADD0@D510410@00m?Cd0@T920080
@D5100/0@d=303lo?`0o?cl0?Cdm03hn?P0m?Cd0@D5103lo?`11@D40A4A40410@00203hn?P0<0410
@00n?Sh0@D510410@00o?cl0@41003hn?P12@T80@d=303dm?@0k>c/0?clo0P0n?Sh01P12@T80?clo
03lo?`0o?cl0?Shn0492@P80@d=300H0?clo0492@P11@D40?clo03dm?@0i>CT303`l?080?Shn00X0
@T9204=3@`0o?cl0ATI604M7A`11@D40?Cdm0451@@10@400?clo0P0n?Sh01@0k>c/0ATI604I6AP0n
?Sh0?clo0080@d=30P12@T80201:BTX0?clo0410@010@400@d=304A4A018B4P0BTY:0P13@d<04@11
@D40?Cdm0451@@0n?Sh0A4A40451@@1>CTh0ADE50410@00o?cl0?Shn03/k>`0n?Sh0@D5104A4A00n
?Sh0@d=30080?clo0P0l?3`203lo?`0;03hn?P0m?Cd0?Cdm03lo?`11@D40A4A403hn?P0k>c/0?3`l
0410@012@T800P0l?3`0200j>SX0?clo04=3@`12@T80@41003`l?00n?Sh0B4Q80P0o?cl00`10@400
@D5103dm?@0203Xj>P0P03`l?00o?cl0?Shn0492@P11@D40?Shn0492@P11@D40?Cdm0410@012@T80
@41003lo?`0l?3`0>SXj04=3@`11@D40?Shn04E5A@16ATH0?Shn03`l?00k>c/0@4100451@@0n?Sh0
?Cdm03lo?`0n?Sh0?clo04A4A013@d<203dm?@80@D5102D0?Shn0492@P16ATH0EUIF05ADE01MGEd0
KVi^07inOP1lO7`0Q8B408F5Q@1mOGd0OWin08V9R@2ATI40MgMg069RHP1FEUH0D51@04I6AP0n?Sh0
@T920451@@0n?Sh0?Cdm04M7A`15ADD0@d=303hn?P0o?cl0@41003hn?P15ADD0?Shn0451@@10@400
?clo00<0@d=301d0B4Q805]KF`1[Jf/0JVYZ05iNGP1WIfL0LG5a096AT@2^[Zh0Shn?05iNGP1FEUH0
Fe]K05YJFP1GEeL0Fe]K06a/K021PH40Ph>307]kN`1bLW80RXZ:08b<S02>SXh0U9BD09:BTP2GUiL0
YJFU0;jn_P030=?Cd`0l0<71`@2e]KD0[Jf]0;Bd]03=cLd0f][J0=cLg03Kfm/0eMGE0=SHf03IfMT0
g=cL0<[:bP2^[Zh0VYZJ08n?S`2b/[80cLg=0=7Ad@3Bd]80[:b/09jNWP2d];@0e=CD0>7Qh@3Ph>00
bLW909FEU@2JVYX0[Jf]09NGU`2UYJD0a<C40=3@d035aLD0][Jf0;Ng]`2OWil0HV9R04A4A01IFET0
HF5Q05iNGP1FEUH0IfMW07MgM`1kNg/0H61P04M7A`1=CDd0MWIf08J6QP2DU9@0[Zj^0:NWY`2YZJT0
/K6a0;jn_P2i^KT0_kno0P32`/802`2k^k/0]KFe0;>c/`2SXj<0R8R808N7Q`1mOGd0K6a/059BDP10
@400>3Ph0080?3`l00/0>c/k03Xj>P0l?3`0>c/k03Ph>00i>CT0?3`l04E5A@1:BTX0@T9204E5A@02
03`l?080>SXj00H0>c/k03Ti>@0h>3P0>CTi03Xj>P0h>3P203De=@0<03/k>`0i>CT0>CTi03Ti>@0h
>3P0>SXj03Ph>00i>CT0>3Ph03Ti>@0g=cL0>3Ph0`0f=SH00`0e=CD0=3@d03De=@0203@d=00903De
=@0h>3P0=SHf03Hf=P0d=3@0=CDe03Lg=`0h>3P0=CDe0080=cLg00L0=3@d03<c<`0h>3P0=SHf03Xj
>P0d=3@0=SHf0080<c<c00<0=CDe03Hf=P0c<c<00P0d=3@01@0g=cL0<c<c03Xj>P0h>3P0=SHf0080
=cLg00<0=SHfooooooooool02oooool0013ooooo0100CDe=055AD@1?Cdl0Cdm?04a<C01?Cdl0C4a<
04m?C`1;Bd/0BDU904Q8B019BDT0Bd];04Q8B01<C4`0B4Q80`1:BTX01@15ADD0BDU904Y:BP19BDT0
BTY:0080AdM700P0BTY:04M7A`18B4P0Bd];04a<C014A4@0ADE504Q8B080Bd];01X0B4Q804U9B@1@
D500BDU904I6AP13@d<0B4Q804Y:BP18B4P0AdM704Q8B017AdL0A4A404E5A@16ATH0ADE504Y:BP14
A4@0@T9204E5A@1:BTX0B4Q804Y:BP15ADD0@d=30410@080@D5100D0@d=304];B`19BDT0A4A40451
@@020410@00J04M7A`12@T80A4A404A4A012@T80@4100492@P0n?Sh0?clo0410@013@d<0?clo0451
@@12@T80@41003`l?00o?cl0@D5104=3@`0n?Sh0@41003hn?P10@400?3`l03hn?P15ADD20451@@0<
03lo?`0l?3`0?Shn0451@@0o?cl0?3`l03/k>`0l?3`0>c/k03Xj>P0l?3`0?Shn0P10@4001@0n?Sh0
@41003hn?P13@d<0@D5100<0@41000<0?Cdm03hn?P0m?Cd00P13@d<02P0n?Sh0?Cdm04E5A@11@D40
@41003`l?012@T80@D5103`l?00m?Cd303hn?P0504E5A@0o?cl0ADE50451@@0j>SX00P10@4002@0m
?Cd0?clo03dm?@0m?Cd0?Shn0451@@15ADD0B4Q804=3@`020492@P0=04Q8B013@d<0?Cdm03lo?`11
@D40?Cdm03hn?P0o?cl0A4A404=3@`0m?Cd0?clo03`l?00403lo?`060492@P11@D40?Cdm0492@P0n
?Sh0>SXj0`11@D402@0n?Sh0>c/k0410@010@400@D5104I6AP0o?cl0>CTi03/k>`020410@080@T92
00h0?clo03dm?@0o?cl0>CTi03`l?00o?cl0@T9203hn?P11@D40?clo0492@P0o?cl0@41004A4A0<0
@D5100<0A4A40492@P13@d<00P13@d<01@16ATH0ADE503`l?00k>c/0?3`l0080?clo00H0?Cdm03hn
?P0m?Cd0>c/k03dm?@0n?Sh303dm?@80?Shn01/0?Cdm03/k>`0k>c/0?clo0410@00n?Sh0>c/k0410
@00o?cl0Cdm?06=SH`28R8P0SXj>08V9R@1kNg/0IFEU05aLG01IFET0Bd];04Q8B01:BTX0FUYJ071`
L01cLg<0L71`06IVIP1NGUh00P1BDU80101>CTh0@D5103hn?P0o?cl20451@@0U0492@P0o?cl0?Cdm
03dm?@0l?3`0@T9203/k>`0o?cl0?Shn0492@P11@D40?Shn0410@012@T80EUIF07]kN`2m_Kd0fMWI
0<C4a02`/;00ZZZZ0:FUY@2MWId0XJ6Q0:f][@2/[:`0[Zj^0:6QX@2@T900Jf][051@D01QHF40MgMg
07inOP1^KVh0IFEU065QH@0205MGE`0T05eMG@1^KVh0M7Ad06MWI`1RHV80IVIV06a/K01gMgL0U9BD
0;2`/02_[jl0W9bL08j>SP2UYJD0`L710;no_`2OWil0TY:B09JFUP2^[Zh0ZJVY096AT@2>SXh0N7Qh
07AdM026QXH0TY:B09RHV02@T900MWIf07=cL`20P800[Jf]0<?3``34a<@0a/K60P2j^[X01P2ATI40
UiNG0:>SX`2UYJD0/K6a0:b/[080[jn_02@0XZ:R0;6a/@3<c<`0e]KF0<C4a036a/H0f=SH0>[ZjP3W
inL0eMGE0<W9b@3<c<`0eMGE0=SHf036a/H0alO70=KFeP3Ti>@0g=cL0;Vi^@26QXH0Jf][05MGE`1?
Cdl0B4Q804I6AP14A4@0@41003hn?P0k>c/0?Shn03/k>`0n?Sh0?clo03/k>`0j>SX203`l?00303Xj
>P0k>c/0?Cdm00<0>SXj00P0=SHf03Lg=`0h>3P0?clo03`l?00j>SX0>CTi03`l?0<0>3Ph100i>CT0
100h>3P0=cLg03Lg=`0i>CT203Hf=P0803De=@0c<c<0=SHf03Lg=`0f=SH0>CTi03Lg=`0d=3@203Ph
>080=CDe00<0=SHf03Lg=`0g=cL00P0f=SH02P0b<S80=SHf03Lg=`0i>CT0=cLg03Hf=P0g=cL0>3Ph
03Hf=P0e=CD203Lg=`80=CDe00L0=SHf03Xj>P0i>CT0=cLg03De=@0i>CT0>SXj0080=SHf0P0d=3@0
1P0h>3P0=SHf03Ph>00f=SH0=CDe03Lg=`gooooo000@ooooo`0604i>CP1@D500Cdm?04e=C@1<C4`0
CDe=0P1<C4`07019BDT0Bd];04a<C01<C4`0B4Q804Y:BP1<C4`0B4Q804M7A`1;Bd/0B4Q804E5A@18
B4P0BTY:04e=C@17AdL0ATI604E5A@19BDT0ATI604Q8B019BDT0AdM704I6AP1;Bd/0BTY:04a<C01:
BTX204U9B@80A4A40180B4Q804U9B@19BDT0GEeM05QHF015ADD0AdM70492@P14A4@0?Shn0410@015
ADD0@D5104E5A@14A4@0AdM7059BDP16ATH204Q8B00904M7A`15ADD0A4A404I6AP15ADD0B4Q804A4
A012@T80?Cdm0080?Shn0100?clo0451@@13@d<0A4A404I6AP0o?cl0AdM703lo?`11@D40?Cdm0492
@P0m?Cd0?clo0492@P0m?Cd0?clo0P10@4004`0l?3`0@D5103hn?P0n?Sh0?Cdm03hn?P10@400@d=3
03hn?P0m?Cd0?3`l03/k>`0l?3`0>c/k03hn?P0k>c/0@41003lo?`0l?3`00P0m?Cd04`0j>SX0?Shn
04=3@`0m?Cd0?clo0451@@0o?cl0?Shn03/k>`12@T80@D5104E5A@0l?3`0?Shn0410@00o?cl0@D51
0410@00l?3`00P0k>c/00`17AdL0?clo0451@@020410@00;03hn?P11@D40?Cdm03dm?@0o?cl0@d=3
03lo?`0n?Sh0?clo03hn?P10@4000`0n?Sh02@0o?cl0?3`l0410@010@400?clo03hn?P12@T80BTY:
03lo?`0403hn?P0303`l?00o?cl0ATI60080@D510140>c/k03hn?P13@d<0@D510410@012@T80A4A4
03hn?P12@T80?Shn03`l?00i>CT0@D5104=3@`0m?Cd0>c/k0492@P0203hn?P0803`l?010@400?Shn
03hn?P10@400?clo03hn?P0o?cl303dm?@0803lo?`10@400>c/k0410@00o?cl0?3`l03Xj>P0k>c/2
03lo?`0503dm?@14A4@0@T9204=3@`0n?Sh00P10@4005011@D40@41004A4A010@400ATI60410@00n
?Sh0@T9204=3@`0j>SX0?3`l0492@P18B4P0>CTi03lo?`0j>SX0?clo03/k>`0n?Sh0ADE50P0m?Cd0
200i>CT0?Shn03lo?`10@400?Shn03dm?@10@400AdM70P1eMGD02P1OGel0F5QH04a<C016ATH0ADE5
0410@00m?Cd0AdM705ADE01XJ6P207AdM00M071`L01YJFT0EeMG04m?C`19BDT0@D510410@00o?cl0
>SXj03`l?013@d<0ADE50492@P0j>SX0?3`l03hn?P0m?Cd0@D510410@012@T80ADE505ADE01XJ6P0
PX:209:BTP2WYjL0[Zj^0:2PX02@T9000P2ATI40202KVi/0[:b/0;Rh^02k^k/0YZJV09bLW02ATI40
Ng]k0P1]KFd02@1MGEd0E5AD05eMG@1MGEd0FUYJ05mOG`1SHf<0IFEU065QH@0206e]K@0J07=cL`1m
OGd0GemO055AD@1:BTX0De=C05aLG01`L700P82007]kN`1`L700DE5A069RHP2FUYH0][Jf0;Bd]02U
YJD0VIVI09:BTP2>SXh0UYJF0::RXP2TY:@0XJ6Q0:ZZZP2/[:`20:ZZZP0[0:>SX`2a/K40]KFe09bL
W027QhL0LG5a07moO`1ZJVX0Hf=S04e=C@14A4@0Cdm?065QH@1eMGD0MWIf06e]K@1fMWH0RHV90::R
XP2k^k/0f][J0=GEe@3GemL0inOW0=KFeP2j^[X0`l?30=GEe@3Cdm<0_[jn0;^k^`2b/[80_[jn0=KF
eP3EeMD0a<C40;>c/`2/[:`0YjNW08n?S`1fMWH0H61P04M7A`0203hn?P80?3`l0180?Cdm03`l?00i
>CT0>3Ph03Ti>@0h>3P0>CTi03`l?00k>c/0>3Ph03Lg=`0h>3P0>c/k03Xj>P0h>3P0>CTi03Xj>P0i
>CT203Ph>00803/k>`0i>CT0?Cdm03hn?P0i>CT0>SXj03Ti>@0h>3P203Xj>P0H03/k>`1CDe<0HF5Q
04A4A00f=SH0=CDe03@d=00i>CT0>3Ph03Ti>@0g=cL0>CTi03Xj>P0g=cL0>3Ph03De=@0d=3@0=SHf
03Ph>00i>CT0=SHf03Ph>00d=3@0=CDe0`0f=SH00`0e=CD0=3@d03De=@0303Hf=P80=CDe0P0f=SH0
200i>CT0=cLg03Ph>00h>3P0>SXj03Ti>@0e=CD0>3Ph0P0g=cL01P0k>c/0=SHf03@d=00h>3P0>CTi
03Xj>Pgooooo000@ooooo`80Cdm?00<0CDe=04Q8B01;Bd/00P1;Bd/204U9B@80Bd];0P19BDT204M7
A`0N04Q8B017AdL0B4Q804M7A`15ADD0B4Q804A4A016ATH0AdM704U9B@1;Bd/0ADE504I6AP18B4P0
BTY:04Q8B017AdL0Bd];04Y:BP18B4P0ATI604Y:BP17AdL0A4A404E5A@14A4@0CTi>04Y:BP17AdL0
ATI60P17AdL20492@P0804=3@`16ATH0BDU904=3@`1:BTX0@D5104Q8B017AdL204];B`0P03lo?`11
@D40@T920451@@15ADD0B4Q8055AD@17AdL0ADE503dm?@0o?cl0@T9204E5A@10@400?3`l04M7A`0o
?cl0@T920451@@13@d<0@41003lo?`12@T80?Cdm03lo?`14A4@0?clo03hn?P0o?cl0@41003hn?P10
@40203`l?00>0451@@12@T80?clo03hn?P0m?Cd0@41003dm?@0n?Sh0?Cdm04=3@`16ATH0@D5103hn
?P12@T8204I6AP0=03hn?P0m?Cd0?3`l0410@00m?Cd0?clo03dm?@0n?Sh0>c/k04=3@`17AdL0?Shn
0410@00203lo?`0503`l?00k>c/0@T920410@00m?Cd00P0o?cl03@0m?Cd0@d=303/k>`14A4@0?clo
0451@@0n?Sh0?Cdm03/k>`11@D40?Cdm0492@P10@4000P0n?Sh03011@D40@4100410@00m?Cd0@T92
0410@012@T80?Shn03dm?@10@400?Cdm04=3@`80@D5101<0?Shn03`l?01ADE40@d=30451@@10@400
A4A40451@@10@400@d=304E5A@13@d<0ATI604A4A013@d<0A4A404M7A`13@d<0?Shn0080@D5100H0
?3`l03Xj>P12@T80ADE50451@@10@4020492@P0303hn?P0m?Cd0@d=30080@41000<0?Cdm0410@011
@D400P0n?Sh02`0k>c/0@T920451@@0m?Cd0?3`l03hn?P0m?Cd0?3`l03dm?@0o?cl0ADE50080A4A4
00L0ADE503dm?@10@400A4A403lo?`16ATH0GUiN0080@d=300<0?Cdm03`l?00l?3`00P0l?3`03P0m
?Cd0C4a<04=3@`10@400?3`l03lo?`0k>c/0?clo04=3@`10@400?Shn03Xj>P0m?Cd0@d=30P0l?3`0
6`0k>c/0?Shn0492@P14A4@0B4Q804M7A`10@400@d=30492@P0o?cl0@T9204M7A`1ADE40DU9B04];
B`14A4@0?Shn03lo?`0m?Cd0@D5103lo?`10@400@D5103hn?P0o?cl0?Shn03`l?0020492@P0E03lo
?`0n?Sh0ADE504a<C01DE5@0BDU9069RHP2CTi<0[:b/0;^k^`3?cll0d=3@0<O7a`2c/k<0VYZJ07al
O01iNGT0Rh^;09JFUP2ATI40Shn?0080P82000@0UIFE0:FUY@2XZ:P0XZ:R0P2][Jd05`2XZ:P0YjNW
08J6QP1iNGT0MgMg08j>SP2JVYX0U9BD08V9R@27QhL0Ph>306QXJ01JFUX0HF5Q05eMG@1XJ6P0MGEe
092@T02>SXh0RHV908:2PP1]KFd0IfMW0080JVYZ00l0H61P05iNGP1]KFd0MGEe06a/K01bLW80KFe]
07=cL`1eMGD0MgMg07]kN`1hN7P0U9BD09NGU`2e]KD00P39bLT04P38b<P0_Kfm0<30`031`L40^KVi
0:>SX`2@T900Ogmo06QXJ01NGUh0IVIV06UYJ@1_Kfl0T92@0;Vi^@2f][H0ZJVY0<30`080aLG502D0
clo?0;fm_@25QHD0Fe]K06e]K@1nOWh0YZJV0<k>cP3AdM40cLg=0<K6aP3?cll0a<C40<[:bP3GemL0
e]KF0=CDe03IfMT0clo?0:RXZ01hN7P0F5QH03hn?P0l?3`0@41003hn?P0m?Cd0>SXj03Ph>00i>CT0
>SXj03/k>`0i>CT0=cLg03Ph>00g=cL0=SHf0080>SXj0P0h>3P00`0k>c/0>3Ph03Xj>P0203`l?00<
03Xj>P0l?3`0>3Ph03Ph>00l?3`0>3Ph03Xj>P1?Cdl0UIFE0=3@d02NWYh0CTi>0P0i>CT04@0l?3`0
C4a<06IVIP1lO7`0KVi^05UIF@1NGUh0Fe]K04U9B@0k>c/0=cLg03@d=00e=CD0>3Ph03Xj>P0f=SH0
=cLg0080=SHf00@0=CDe03@d=00d=3@0=CDe100f=SH0300g=cL0>3Ph03Hf=P0e=CD0=cLg03De=@0g
=cL0=3@d03Ti>@0h>3P0=SHf03De=@80>3Ph0P0j>SX0100o?cl0Cdm?08j>SP2;Rh/=ooooo`004?oo
ool01P1>CTh0C4a<04];B`1;Bd/0Cdm?04Y:BP<0Bd];0140AdM704U9B@19BDT0CTi>04e=C@1:BTX0
ADE504=3@`16ATH0AdM704I6AP18B4P0A4A404M7A`1<C4`0CDe=04];B`0204E5A@0304I6AP19BDT0
BDU90080ADE500T0A4A404I6AP18B4P0Cdm?04I6AP1;Bd/0B4Q804U9B@1:BTX00`18B4P0301=CDd0
Bd];04Q8B016ATH0B4Q804E5A@11@D40A4A404=3@`14A4@0AdM704=3@`80BTY:00<0@D5104E5A@14
A4@00P15ADD01@10@400@d=303lo?`15ADD0@D510080@4100P13@d<01`10@400@D510451@@0m?Cd0
?Shn03lo?`10@4000P0o?cl03@12@T80?clo03dm?@10@400?3`l0451@@0o?cl0?Cdm03lo?`11@D40
@41003lo?`12@T800P0n?Sh01`14A4@0?Cdm0410@00j>SX0?clo04E5A@11@D400P12@T800`11@D40
?Cdm03dm?@0303`l?00803lo?`0k>c/0?clo03lo?`10@400?clo0451@@0n?Sh30410@00803dm?@0l
?3`0?Cdm03hn?P0m?Cd0?Shn0451@@10@40203dm?@0503`l?00k>c/0@41003`l?011@D400P10@400
301IFET0?clo04=3@`13@d<0@T920451@@0m?Cd0?3`l03lo?`0n?Sh0@T9203hn?P<0?clo00h0?3`l
03/k>`0n?Sh0?3`l0451@@0m?Cd0?clo05mOG`12@T80?Shn04=3@`11@D40@41003lo?`80@41000`0
?clo0492@P14A4@0@d=304Y:BP11@D40A4A40410@013@d<0@41003dm?@0l?3`204A4A00704=3@`10
@400A4A404A4A010@400?Shn0492@P0204=3@`0:03lo?`11@D40A4A40492@P10@400?Shn0410@00n
?Sh0>SXj03dm?@80@41000<0@T920410@00o?cl01010@4002014A4@0?Shn0451@@10@400?Cdm04];
B`16ATH0@4100P0o?cl01P0n?Sh0?Cdm03dm?@0m?Cd0@d=303hn?P80?clo01P0?Cdm03Ti>@0j>SX0
?3`l0451@@0o?cl0?Cdm03`l?011@D40?3`l0410@014A4@0@41003hn?P0l?3`0@D510492@P11@D40
A4A404=3@`12@T80ADE503hn?P14A4@203`l?0040451@@0l?3`0?Cdm03Ph>080?clo00d0?Cdm03/k
>`0n?Sh0@41003dm?@11@D40A4A404M7A`1OGel0S8b<0:VYZ@2][Jd0YjNW0080VYZJ0100YJFU08j>
SP2?Shl0R8R809NGU`2_[jl0]kNg09FEU@1aLG40RHV909BDU02MWId0[:b/0<71`@30`<00aLG50P3@
d=002@3Ph>00gmoO0=OGe`3=cLd0]kNg0:JVYP2BTY80Shn?0:>SX`020=KFeP080:6QX@2WYjL0ZJVY
0:NWY`2JVYX0R8R808Z:RP2?Shl20:2PX00F0:RXZ02][Jd0VIVI07moO`1eMGD0Lg=c079bLP1cLg<0
FUYJ05]KF`1nOWh0T92@08B4Q01MGEd0Cdm?04e=C@18B4P0Bd];04A4A01<C4`0AdM704a<C080GemO
02<0EEEE05eMG@1SHf<0MgMg092@T02_[jl0]kNg0<71`@3Bd]80b/[:0:VYZ@1/K6`0De=C04e=C@1D
E5@0OWin0:ZZZP2/[:`0R8R806QXJ01^KVh0RXZ:09NGU`2<S8`0P82006EUI@1ADE40BTY:05eMG@24
Q8@0YZJV09RHV02ZZZX0[Zj^0<G5a@020=?Cd`0:0=7Ad@3MgMd0emOG0=[JfP37alL0UYJF08:2PP28
R8P0IfMW03dm?@80?3`l00L0>SXj03Ti>@0i>CT0>3Ph03Hf=P0g=cL0>CTi0080=cLg0P0h>3P0100g
=cL0=SHf03Lg=`0h>3P203Xj>P0F03/k>`0f=SH0>CTi03Xj>P0k>c/0>CTi059BDP1mOGd0/;2`0;Bd
]01mOGd0?clo03hn?P0l?3`0>CTi03/k>`1=CDd0GUiN06QXJ01ADE40?clo03Ti>@80>SXj00<0>c/k
03Hf=P0i>CT00P0h>3P00`0j>SX0>3Ph03Hf=P0203Ph>00403Lg=`0e=CD0=CDe03Hf=P80=cLg00<0
=SHf03De=@0f=SH00P0h>3P01`0f=SH0=cLg03Lg=`0k>c/0>SXj03Hf=P0h>3P00P0i>CT0200j>SX0
?clo04Y:BP1kNg/0Zj^[0;Bd]029RHT0CDe=3Oooool0013ooooo00`0CDe=04a<C01<C4`0Bd];04i>
CP19BDT0BTY:04Q8B019BDT0ATI604];B`1:BTX204Q8B00404M7A`16ATH0A4A404A4A080B4Q801T0
ATI604A4A015ADD0A4A404Q8B016ATH0B4Q804=3@`15ADD0ATI604=3@`12@T80ATI604E5A@19BDT0
ATI604A4A013@d<0@T9204U9B@1:BTX0B4Q804M7A`18B4P0Cdm?0080AdM70180ADE504A4A012@T80
?clo04a<C013@d<0@T9203lo?`15ADD0@D5103lo?`19BDT0BTY:04=3@`11@D40@T9204E5A@12@T82
0451@@070410@014A4@0@D510410@00o?cl0@T920451@@0203lo?`0603`l?010@400?Shn04A4A00m
?Cd0?3`l0P0m?Cd01@0o?cl0@D5103dm?@0o?cl0?Cdm0080?Shn01P0ADE50492@P0o?cl0?Cdm03hn
?P0m?Cd0@41003hn?P0o?cl0?Shn0492@P10@400>c/k03lo?`10@400@D5103hn?P0o?cl0@41003/k
>`0i>CT0?Cdm03hn?P0l?3`203lo?`0B0410@017AdL0@D510492@P0m?Cd0A4A403dm?@0k>c/0@410
0451@@12@T80?clo0410@00o?cl0>c/k0451@@0o?cl0@410100k>c/01011@D40@41003`l?00o?cl2
03hn?P0=0410@00l?3`0?Shn04=3@`12@T80?Cdm03hn?P0k>c/0?clo03dm?@0o?cl0?Shn03lo?`02
03dm?@080492@P0l?3`0>c/k04E5A@13@d<0@T920451@@13@d<20451@@0404I6AP17AdL0?Shn04E5
A@80B4Q800X0?Shn04E5A@10@400AdM703dm?@11@D40@41004=3@`0n?Sh0A4A40`0n?Sh01011@D40
@T920410@012@T820410@00903/k>`0m?Cd0?clo03/k>`0m?Cd0@41003hn?P0j>SX0?3`l0080B4Q8
00l0CDe=04I6AP13@d<0?Cdm03`l?00n?Sh0@41003lo?`0k>c/0?clo03hn?P14A4@0>CTi0492@P0m
?Cd00P0n?Sh04@0m?Cd0?clo03hn?P0l?3`0>c/k03Ti>@0n?Sh0?3`l03/k>`10@400?Cdm03Ti>@0m
?Cd0>SXj03`l?010@400?clo0080@d=301<0@D5103hn?P0m?Cd0?3`l03hn?P0l?3`0@41004E5A@0j
>SX0?Shn03Xj>P0k>c/0>3Ph03/k>`0h>3P0?Shn03Ti>@0n?Sh0>SXj0080>c/k04/0>SXj0451@@10
@400?clo03Xj>P17AdL0FEUI096AT@2f][H0XZ:R0:JVYP2?Shl0QHF506m_K`1OGel0H61P06YZJP1g
MgL0MGEe08^;R`2:RXX0UYJF0<G5a@3;bl/0_kno0:f][@2b/[80_kno0<;2`P2m_Kd0`<300;no_`2l
_;`0`L710;no_`3Cdm<0eMGE0<W9b@2WYjL0QHF507alO02HV9P0/K6a0<S8b03:b/X0d];B0=?Cd`3;
bl/0_;bl0;2`/02QXJ40RXZ:08V9R@2<S8`0U9BD09nOW`2f][H0c<c<0;fm_@2VYZH0WIfM0820P01L
G5`0Fe]K04e=C@1JFUX0I6AT05UIF@1HF5P0AdM704Y:BP1=CDd0A4A404=3@`1HF5P00P1QHF405@1S
Hf<0KVi^075aL@1YJFT0F5QH05MGE`1>CTh0EUIF069RHP1lO7`0NWYj08V9R@2EUID0WinO0;no_`2i
^KT0/;2`0;jn_P3AdM40aLG50:BTY00209>CT`0>07=cL`1]KFd0KVi^07alO02IVIT0VYZJ06MWI`1B
DU80A4A40451@@19BDT0E5AD05]KF`1eMGD209:BTP0:09^KV`2RXZ80Z:RX0;Fe]@2][Jd0/[:b0<g=
c@38b<P0P82004e=C@80>CTi00@0>c/k03Xj>P0i>CT0>CTi0P0h>3P02@0i>CT0?3`l03Ti>@0g=cL0
>SXj03Ti>@0f=SH0>3Ph03Xj>P0203Lg=`0G03Ti>@0j>SX0>c/k03Xj>P1FEUH0Rh^;07alO01VIVH0
B4Q803Xj>P0k>c/0>CTi04A4A01EEED0D51@03`l?00j>SX0>c/k03Lg=`0d=3@0>CTi03Lg=`0k>c/0
0P0h>3P0300i>CT0<c<c03Xj>P15ADD0Bd];04i>CP1FEUH0@41003/k>`0j>SX0=cLg03Hf=P80=cLg
0P0f=SH0200g=cL0=SHf03Hf=P0f=SH0>SXj03Ph>00j>SX0?3`l0P0j>SX02P0l?3`0B4Q807alO02c
/k<0d=3@0>7Qh@36a/H0U9BD06][J`1BDU8=ooooo`004?ooool01@1>CTh0CDe=04];B`1=CDd0C4a<
0080BTY:0P17AdL204U9B@0904Y:BP16ATH0B4Q804M7A`1<C4`0CDe=04M7A`1:BTX0AdM70080B4Q8
00`0A4A404Y:BP1:BTX0ATI604Q8B014A4@0AdM704I6AP13@d<0A4A404E5A@14A4@204E5A@0404U9
B@14A4@0A4A404E5A@80AdM700H0ADE5051@D01>CTh0@T9204U9B@16ATH204A4A00604E5A@18B4P0
@T920492@P15ADD0Bd];0P12@T801`16ATH0B4Q803lo?`11@D40ADE504=3@`0o?cl00P0m?Cd01`16
ATH0?Cdm03lo?`0n?Sh0@41004=3@`12@T800P11@D400`12@T80?Shn03/k>`0203hn?P0903/k>`10
@400?Shn03lo?`0n?Sh0A4A404Y:BP0n?Sh0>c/k0080@41000L0?clo03dm?@13@d<0A4A40451@@10
@400>c/k0080?Shn00<0>c/k03dm?@0l?3`00P0l?3`00`0m?Cd0@41003hn?P0203`l?00<03/k>`0l
?3`0@T9203/k>`0m?Cd0@D5104=3@`15ADD0@41003/k>`0m?Cd0?clo0P0l?3`02@0n?Sh0?3`l03hn
?P0m?Cd0A4A40451@@12@T80?3`l03dm?@0303hn?P060410@00k>c/0?3`l03hn?P11@D40@T920P0l
?3`01`0o?cl0@D5103lo?`16ATH0?clo03hn?P11@D400P14A4@09P15ADD0@d=30492@P0n?Sh0?clo
0410@014A4@0?clo04A4A011@D40ADE50451@@19BDT0@D5104=3@`11@D40@4100492@P0o?cl0@D51
0492@P1FEUH0BTY:0492@P10@400@T9203dm?@0n?Sh0A4A40451@@0j>SX0?clo0451@@0n?Sh0?Cdm
0410@00k>c/0?3`l0`0o?cl03P13@d<0>SXj03Xj>P11@D40@41004=3@`12@T80G5aL07UiN@1ZJVX0
BTY:03`l?014A4@0@T920P0n?Sh204=3@`0;0410@00j>SX0?3`l03/k>`12@T80@D510492@P0l?3`0
>CTi03lo?`10@4000P0n?Sh00`10@400>SXj03dm?@0203/k>`0A03dm?@10@400@d=305UIF@18B4P0
AdM705iNGP22PX80HF5Q04U9B@10@400?Cdm0410@012@T80AdM704=3@`0n?Sh00P0o?cl00`0l?3`0
@d=303lo?`020410@00>03/k>`0m?Cd0=cLg03Xj>P0i>CT0>c/k03Ti>@11@D40?Shn0410@011@D40
?Cdm061PH02=SHd2071`L01J08>3P`1mOGd0N7Qh08:2PP1jNWX0GEeM04m?C`1=CDd0EeMG069RHP1X
J6P0H61P0:>SX`2f][H0VYZJ07YjNP1/K6`0IFEU06MWI`1bLW80I6AT05UIF@1MGEd0K6a/07moO`2E
UID0^;Rh0=CDe03Kfm/0aLG507moO`1LG5`0GemO06EUI@1YJFT0LG5a0:FUY@2n_[h0[jn_07MgM`1A
DE40BTY:04E5A@11@D40A4A404M7A`1<C4`0Fe]K07]kN`2][Jd0`<300;no_`2/[:`0TY:B08V9R@26
QXH0TY:B09VIV@2JVYX0WinO0;^k^`2c/k<0_Kfm0;Bd]02NWYh0T92@09bLW02XZ:P0XZ:R08F5Q@1l
O7`0QhN708j>SP1bLW80MWIf06MWI`1[Jf/0Fe]K05eMG@1GEeL0Bd];04i>CP1NGUh0KFe]07inOP2g
]kL0g=cL0>WYj@3Ti>@0h^;R0P3IfMT0;03Lg=`0e]KF0<C4a02^[Zh0Ti>C0<;2`P3Fe]H0c<c<0:j^
[P26QXH0HF5Q05mOG`18B4P0@D5104E5A@18B4P0BDU905IFEP1VIVH0Ng]k0:>SX`2o_kl0/K6a0:ZZ
ZP32`/80/[:b07inOP14A4@0>SXj03`l?00i>CT0=cLg03Ph>00g=cL0>3Ph03Ti>@0h>3P0@T9203dm
?@0h>3P0=3@d03Lg=`0j>SX0>3Ph0P0f=SH01P0g=cL0?3`l03/k>`0h>3P0A4A40410@080>c/k00d0
A4A407IfMP2IVIT0WIfM06ATI012@T80>CTi03Ph>00i>CT0=SHf03Lg=`0e=CD0>3Ph0080=SHf0P0h
>3P0400i>CT0ADE505aLG01IFET0Bd];03hn?P0i>CT0>3Ph03Ti>@0g=cL0>SXj03Ph>00f=SH0=3@d
03De=@0g=cL403Hf=P0?03/k>`17AdL0A4A40451@@1^KVh0YZJV0=;BdP3Rh^80jn_[0=cLg02n_[h0
S8b<06YZJP1ADE40E5AD00gooooo000@ooooo`0605UIF@1JFUX0CDe=04e=C@19BDT0Bd];0P1:BTX0
1`1;Bd/0C4a<04i>CP1:BTX0Bd];04U9B@16ATH00P13@d<05`15ADD0Bd];04a<C01<C4`0ATI604=3
@`19BDT0B4Q804=3@`12@T80BDU904M7A`1;Bd/0BTY:04M7A`18B4P0@T9204M7A`1:BTX0BDU904];
B`17AdL0@d=30080ADE500@0A4A404I6AP10@400ATI60P17AdL01@13@d<0@T9204A4A014A4@0@d=3
0080Bd];00<0BTY:04A4A012@T800P13@d<01010@400?clo03dm?@0n?Sh20410@00303hn?P13@d<0
?clo0080?clo0P11@D403`10@400@T920492@P12@T80@41003`l?00k>c/0?clo04E5A@11@D40?Shn
03dm?@14A4@0?Shn03`l?00203hn?P0=03`l?010@400@41003`l?010@400ADE503hn?P0l?3`0>SXj
03`l?010@400>SXj03hn?P0203`l?080?Cdm00d0?clo0410@012@T80?clo03hn?P11@D40ADE503lo
?`10@400@D5103hn?P13@d<0ADE50080?clo0P11@D403010@400?Cdm03dm?@0o?cl0ADE50451@@14
A4@0ADE503lo?`0l?3`0>CTi03/k>`80?3`l0140?Cdm04=3@`10@400?Shn0410@00m?Cd0@4100451
@@13@d<0A4A40492@P13@d<0?Shn03lo?`11@D40>c/k03lo?`020492@P0503lo?`0m?Cd0?clo04A4
A012@T800P15ADD20492@P0>04I6AP10@400?clo03`l?011@D40A4A40451@@0n?Sh0>c/k05ADE015
ADD0@D5103lo?`11@D430410@0030451@@0o?cl0?clo0080?Cdm00<0?Shn03`l?00k>c/00P0m?Cd0
1@10@400@D5103hn?P12@T80?clo0080>c/k00P0De=C06][J`2CTi<0K6a/04M7A`0m?Cd0>CTi0410
@080?Cdm00T0@D5103dm?@15ADD0?clo03`l?00n?Sh0?clo03dm?@0n?Sh00P0i>CT05@0l?3`0@d=3
03dm?@0m?Cd0>CTi03Xj>P0i>CT0=cLg03dm?@0k>c/0?clo05MGE`1dM7@0OGem05iNGP1ADE40F5QH
04i>CP0m?Cd0@41003`l?0020410@00703lo?`11@D40@41003lo?`0m?Cd0@41003hn?P0203`l?005
03dm?@0k>c/0?clo03`l?00k>c/00P0j>SX02P0l?3`0>c/k0451@@0j>SX0?3`l04A4A01DE5@0MGEe
08j>SP2LW9`20;Jf]P0809JFUP1dM7@0L71`07QhN01cLg<0KFe]061PH01OGel205IFEP0Y055AD@1F
EUH0CDe=04I6AP17AdL0A4A40492@P0o?cl0ATI604M7A`1CDe<0M7Ad09jNWP2f][H0`L710=;BdP3E
eMD0cLg=0<C4a032`/80`L710;Jf]P2WYjL0SHf=0861P@1bLW80G5aL04Y:BP16ATH0@T9204=3@`0n
?Sh0@D5103dm?@0o?cl0AdM704=3@`1@D500DU9B05IFEP1PH6000P1LG5`0501OGel0I6AT06a/K01l
O7`0RXZ:0:RXZ02l_;`0emOG0>3Ph03De=@0[Jf]08R8R01fMWH0QXJ60;2`/02l_;`0_Kfm0<?3``2n
_[h0bLW90P3Bd]80;@2m_Kd0]kNg0:^[Z`24Q8@0KVi^06MWI`1YJFT0IFEU05UIF@1_Kfl0Ti>C0=_K
f`3/k>`0j^[Z0=GEe@2a/K40^k^k0<S8b034a<@0clo?0=3@d038b<P0`l?30<S8b039bLT0`l?30<[:
bP38b<P0][Jf09fMW@1oOgl0I6AT05mOG`17AdL0?Shn04U9B@1/K6`0UYJF09NGU`2HV9P0YZJV0;jn
_P3=cLd0V9RH05eMG@0203dm?@80>3Ph00D0>c/k03Ti>@0j>SX0>c/k03Xj>P0203/k>`0J03Hf=P0m
?Cd0>CTi03Hf=P0h>3P0>CTi03Ph>00i>CT0=cLg03Ti>@0m?Cd0>c/k03dm?@1lO7`0`/;20=KFeP2E
UID0G5aL03/k>`0h>3P0>CTi03Ph>00i>CT0<c<c03Lg=`0i>CT403Ph>00603Hf=P0m?Cd0@D510492
@P0i>CT0>3Ph0P0i>CT00`0n?Sh0=CDe03@d=00203Hf=P0303@d=00e=CD0=SHf0080=cLg0100>c/k
03Lg=`0h>3P0@D5104Q8B01mOGd0^k^k0=oOg`3Shn<0inOW0=SHf02l_;`0OGem05IFEP13@d<0@D51
0P0l?3`=ooooo`004?ooool00`1?Cdl0Bd];04a<C00204e=C@0604i>CP1;Bd/0Bd];04];B`19BDT0
BTY:1019BDT04017AdL0ATI604A4A018B4P0AdM704Y:BP19BDT0BTY:04U9B@16ATH0Bd];04Q8B01:
BTX0B4Q804E5A@14A4@204E5A@0404A4A018B4P0@d=304=3@`80AdM700P0A4A404E5A@12@T80A4A4
0451@@14A4@0ATI604];B`<0ADE500H0ATI604Q8B00o?cl0A4A404I6AP15ADD20492@P050451@@12
@T80ADE50492@P0o?cl00P12@T802P10@400?clo04=3@`12@T80@d=30492@P10@400@D5103hn?P10
@40304A4A0050492@P10@400?clo0451@@10@4000P0o?cl01`13@d<0@D5103`l?00n?Sh0@41003`l
?00n?Sh00P0o?cl0300m?Cd0>SXj03lo?`0l?3`0@D5103`l?00n?Sh0?Cdm04=3@`0k>c/0>CTi03hn
?P80?Cdm00@0ADE503hn?P0m?Cd0>c/k0P0n?Sh0100j>SX0@41003/k>`0l?3`20410@00:03dm?@0j
>SX0>c/k03hn?P0m?Cd0>c/k03hn?P0o?cl0A4A40451@@80?clo0P0n?Sh02@0l?3`0?clo03lo?`0o
?cl0@D5103lo?`0l?3`0?clo0451@@0203lo?`0@0410@015ADD0?Cdm03hn?P1:BTX0ATI60451@@10
@400?clo0410@00n?Sh0>c/k03dm?@10@400?3`l03hn?P80?clo00X0B4Q80410@011@D40@D5103lo
?`0k>c/0?Shn0410@016ATH0?Shn0P0m?Cd01011@D40AdM703/k>`0n?Sh30492@P0603dm?@0l?3`0
?Shn04=3@`10@400?Cdm0P10@400100o?cl0?3`l03hn?P0n?Sh403Xj>P0V03/k>`15ADD0De=C04Y:
BP15ADD0?Cdm03/k>`10@400?Cdm03Xj>P0k>c/0>CTi03hn?P0m?Cd0?3`l03dm?@0n?Sh0?clo03`l
?00m?Cd0>c/k03`l?01:BTX0>CTi03Xj>P0l?3`0>c/k03`l?00o?cl0>SXj03hn?P0k>c/0?clo04Q8
B01DE5@0Cdm?04I6AP11@D4203lo?`0403`l?00m?Cd0?clo03hn?P80?clo04d0@41003lo?`0k>c/0
?3`l03dm?@14A4@0@D5103/k>`0o?cl0@41003hn?P10@400?3`l03Xj>P0n?Sh0ATI604=3@`15ADD0
>c/k04=3@`1?Cdl0JVYZ08V9R@2PX:00/k>c09VIV@24Q8@0N7Qh06QXJ01HF5P0D51@04I6AP14A4@0
@D510410@00o?cl0@D5103`l?011@D40>SXj03hn?P12@T80@d=303lo?`10@400ADE504e=C@1UIFD0
T92@0:VYZ@2VYZH0[Zj^0;Rh^02f][H0Y:BT09RHV02@T900OGem06i^KP1RHV80EeMG04Q8B011@D40
@T9204m?C`1eMGD0Shn?08Z:RP1gMgL0IVIV06UYJ@1mOGd0PX:207inOP24Q8@0S8b<092@T00209VI
V@180:JVYP2n_[h0a<C40<K6aP2[Zj/0S8b<0861P@1gMgL0M7Ad07YjNP2LW9`0_;bl0<?3``37alL0
/k>c09>CT`1kNg/0Ogmo08F5Q@29RHT0T92@09JFUP2OWil0X:2P0:NWY`2QXJ40VIVI09JFUP2LW9`0
[Zj^0=GEe@3Kfm/0g=cL0<O7a`2d];@0][Jf0;bl_038b<P0c<c<09JFUP1cLg<0Kfm_07IfMP2CTi<0
W9bL09^KV`2MWId0]KFe0<c<c03Kfm/0f][J0=KFeP3IfMT0f=SH0<o?c`3>c/h0cLg=0:n_[`1iNGT0
DU9B06EUI@2<S8`0Rh^;09fMW@2`/;00b/[:0<g=c@32`/80VYZJ061PH012@T80@4100`0m?Cd07@0l
?3`0>SXj03/k>`0j>SX0>3Ph03`l?00n?Sh0>SXj03Ti>@0h>3P0>CTi03Ph>00i>CT0=SHf03Ti>@0m
?Cd0A4A409:BTP3EeMD0`<30071`L00m?Cd0>CTi03Ph>00i>CT0=SHf03Ph>00m?Cd0=cLg0080>3Ph
00T0=SHf03Lg=`0h>3P0=CDe03Lg=`0f=SH0<S8b03Lg=`0e=CD00P0i>CT0100g=cL0?Shn03De=@0i
>CT203De=@@0=SHf01<0>SXj03Ph>00h>3P0CDe=08R8R036a/H0hn?S0>[ZjP3Shn<0d=3@0:FUY@1S
Hf<0AdM703/k>`0l?3`0>CTi03Xj>P0h>3P0>SXj00gooooo000@ooooo`80CDe=00L0C4a<04];B`19
BDT0BTY:04a<C01:BTX0AdM700@0BTY:00P0Bd];04U9B@17AdL0BDU904A4A017AdL0ATI604U9B@80
BTY:00h0ATI604M7A`17AdL0ATI604A4A016ATH0ADE504M7A`15ADD0B4Q804E5A@16ATH0@T9204=3
@`80ADE500d0AdM704Q8B012@T80B4Q80451@@13@d<0@D5104I6AP15ADD0@D510492@P14A4@0@d=3
0080@D5100T0@d=304E5A@11@D40@T9203dm?@11@D40@T9204M7A`11@D400P14A4@01@0o?cl0@T92
0451@@0m?Cd0?Shn0080?clo0P0n?Sh20410@0030492@P16ATH0A4A40080@T9200<0@4100451@@0m
?Cd00P0n?Sh01@0o?cl0?Shn03hn?P0j>SX0@D510080@41000D0?clo03hn?P10@400@41003`l?002
03hn?P060451@@14A4@0?Shn03`l?00m?Cd0@4100P0n?Sh02`0o?cl0?3`l0451@@0m?Cd0@41003dm
?@0n?Sh0?Cdm0451@@10@400?Cdm0080?3`l0P0k>c/0100m?Cd0>c/k03Ti>@0n?Sh203`l?0030492
@P0o?cl0@4100080@41000`0>c/k03lo?`0l?3`0?Cdm0451@@0n?Sh0@4100451@@0n?Sh0?clo0492
@P13@d<203lo?`0903dm?@10@400?Shn0410@00m?Cd0ATI60451@@0o?cl0?Cdm0080@4100P11@D40
2P13@d<0?Shn04];B`10@400?Shn03lo?`0m?Cd0>SXj03`l?015ADD303`l?00303dm?@14A4@0@d=3
0080?clo00/0?Shn04A4A012@T80?Cdm03`l?00k>c/0?3`l03dm?@0l?3`0@d=303hn?P020410@005
03/k>`0o?cl0?clo03Xj>P0k>c/00P0m?Cd00`0k>c/0?Shn03/k>`0203hn?P0=03dm?@0o?cl0?clo
03/k>`0g=cL0>CTi03/k>`0l?3`0?Shn03lo?`0m?Cd0@D5104=3@`0203hn?P0B03/k>`0l?3`0?Shn
03hn?P0k>c/0@41003hn?P10@400>c/k03hn?P0m?Cd0ADE50492@P16ATH0>CTi03`l?00n?Sh0>3Ph
0P0l?3`01@0h>3P0?clo03Xj>P0l?3`0?clo0080@41002D0?Cdm03/k>`0j>SX0?Shn04A4A010@400
?Shn03/k>`10@400?Cdm03hn?P0k>c/0@41004];B`16ATH0EEEE05IFEP1HF5P0EUIF065QH@1oOgl0
OGem05IFEP18B4P0@4100492@P0m?Cd0?clo0451@@0j>SX0ATI603`l?00n?Sh0@T9203dm?@0n?Sh0
@4100080?clo01<0?Shn03lo?`11@D40DE5A08F5Q@2k^k/0clo?0=_Kf`3Hf=P0d];B0<K6aP2/[:`0
TY:B07QhN01YJFT0E5AD0492@P0o?cl0@T920080?Cdm0P0n?Sh06@1>CTh0J6QX07IfMP2=SHd0Vi^K
09JFUP2>SXh0XJ6Q0:2PX01mOGd0JFUY069RHP1MGEd0FUYJ05iNGP1_Kfl0R8R80:ZZZP34a<@0fMWI
0=kNgP3Ph>00cLg=0:JVYP2JVYX00P2NWYh0502ATI40X:2P0:^[Z`2_[jl0_kno0<k>cP3De=@0f][J
0=GEe@2g]kL0X:2P08f=S@24Q8@0Ph>30820P01jNWX0PH6107moO`2DU9@0];Bd0P3Fe]H0;@3@d=00
^k^k0;jn_P2f][H0YZJV0;6a/@2c/k<0XJ6Q08N7Q`22PX80UiNG0;6a/@2XZ:P0MWIf06=SH`1_Kfl0
TI6A0:>SX`2g]kL0`L710;Rh^02g]kL0[Jf]0:^[Z`2^[Zh0TY:B08R8R02b/[80/;2`08N7Q`1iNGT0
X:2P0;Rh^02YZJT0U9BD09bLW01nOWh0BTY:0410@00n?Sh0BDU905=CD`1:BTX0>c/k03`l?00203Xj
>P0403`l?00h>3P0>CTi03Ti>@80>3Ph00d0>c/k03Ti>@0l?3`0IfMW0;no_`3Fe]H0OGem04Q8B00h
>3P0?Cdm03Ti>@0l?3`0=SHf00<0>CTi00@0=SHf03Lg=`0g=cL0>3Ph0P0j>SX01@0h>3P0=cLg03Ph
>00d=3@0=cLg00<0=SHf00@0=3@d03Ph>00e=CD0>3Ph0P0e=CD203@d=00=03De=@0g=cL0?Shn04m?
C`2ATI40cLg=0>?Sh`3]kNd0jn_[0>CTi033`l<0H61P0410@00203Xj>P0603Lg=`0m?Cd0?3`l03Lg
=`0h>3P0A4A43Oooool0013ooooo00T0Cdm?04Y:BP1;Bd/0BTY:04M7A`1:BTX0BDU904Q8B015ADD0
0P19BDT03@15ADD0ATI604Q8B018B4P0BTY:055AD@15ADD0BTY:04M7A`18B4P0ADE504A4A016ATH0
0`15ADD204M7A`0<04];B`18B4P0ADE504E5A@18B4P0ADE504A4A018B4P0BDU904];B`18B4P0BDU9
0P17AdL06015ADD0Bd];04I6AP15ADD0BDU904Q8B01:BTX0B4Q80492@P16ATH0?clo0451@@13@d<0
@41003dm?@0n?Sh0@D510410@011@D40A4A40451@@10@400?Cdm03lo?`80@T9200@0@4100492@P0n
?Sh0@D510P0o?cl00`13@d<0ADE50451@@020451@@0=0410@011@D40?clo03lo?`12@T80?clo0451
@@0m?Cd0?Shn0492@P0o?cl0?3`l0410@00203hn?P0503lo?`10@400@41003/k>`0l?3`00P11@D40
1P0m?Cd0@D5103hn?P0m?Cd0?Shn0451@@80?Shn0100@d=30410@00n?Sh0@d=30492@P11@D40@410
03hn?P0l?3`0@D5104I6AP0l?3`0>3Ph03Xj>P0m?Cd0?Shn0`0m?Cd203hn?P0303Xj>P0m?Cd0?Shn
0080?Cdm00L0?Shn03lo?`0l?3`0?Cdm0410@00o?cl0?Shn0080?clo0100?Shn03dm?@0j>SX0@D51
03lo?`0m?Cd0?3`l03hn?P13@d<0@T920410@013@d<0@D5103lo?`10@400?Shn0P0l?3`20451@@0>
03`l?00m?Cd0?Shn0451@@10@400?Shn04A4A013@d<0@T9203hn?P1:BTX0@4100451@@0l?3`203lo
?`0@03hn?P0l?3`0>CTi03`l?00j>SX0@T920451@@0l?3`0@D5103dm?@0k>c/0?3`l0410@00l?3`0
?clo03Xj>P80?Cdm00T0?3`l03lo?`0m?Cd0?clo0410@00k>c/0@D5104=3@`11@D400P0n?Sh0300i
>CT0?Cdm03hn?P0m?Cd0@D5104M7A`0m?Cd0>SXj03hn?P0l?3`0?Cdm0410@080?clo00P0@T920451
@@19BDT0BTY:04E5A@0m?Cd0>c/k03`l?080>SXj00<0?Cdm0451@@0j>SX00P0n?Sh0200k>c/0>SXj
03lo?`0m?Cd0?clo03hn?P0h>3P0?Cdm0P0n?Sh02`0i>CT0?3`l03Ti>@0m?Cd0>SXj03lo?`12@T80
@4100451@@1@D500EEEE0080De=C00H0E5AD04Y:BP19BDT0BTY:04A4A013@d<203lo?`0Q03hn?P0m
?Cd0?3`l0410@00m?Cd0>SXj03`l?00k>c/0?clo03hn?P0m?Cd0@T9203dm?@0n?Sh0?Cdm0492@P1=
CDd0LG5a0:VYZ@3@d=00gMgM0=CDe038b<P0/[:b08Z:RP1TI6@0C4a<04I6AP0m?Cd0@41003dm?@0n
?Sh0?Cdm0080?clo05H0BDU905YJFP1[Jf/0NWYj079bLP1OGel0D51@04a<C01ADE40GEeM05mOG`1`
L700PX:208J6QP2SXj<0[jn_0:f][@2SXj<0UiNG09ZJVP2NWYh0WinO0;:b/P2j^[X0]kNg0:VYZ@2c
/k<0ZZZZ0:^[Z`2g]kL0`L710<30`032`/80_Kfm0;Rh^02NWYh0V9RH09NGU`2][Jd0]kNg0;>c/`2_
[jl0`L710<S8b03:b/X0YZJV0:2PX02HV9P0TY:B09BDU02/[:`0ZZZZ0;2`/02l_;`0_[jn0;Vi^@2f
][H0^;Rh0:^[Z`2WYjL0Rh^;09BDU02TY:@0XZ:R0:j^[P2g]kL0Xj>S09:BTP2MWId0Y:BT092@T01W
IfL0E5AD04a<C01HF5P0IfMW071`L01jNWX0RXZ:0:FUY@2i^KT0WinO08j>SP2HV9P0Shn?06MWI`80
OWin00/0[:b/08J6QP2PX:00/[:b0;fm_@2VYZH0L71`03Xj>P0n?Sh0>3Ph03Xj>P0203/k>`80?3`l
00/0>c/k03Lg=`0l?3`0?Cdm08Z:RP37alL0`<3006e]K@1>CTh0>SXj03/k>`0203Ph>00@03Ti>@0h
>3P0>SXj03De=@0i>CT0>3Ph03/k>`0f=SH0=3@d03Xj>P0i>CT0=CDe03Ph>00i>CT0>c/k03Lg=`<0
=SHf0P0e=CD0100f=SH0=3@d03Hf=P0f=SH203De=@0>03Hf=P0j>SX0HV9R08J6QP1oOgl0PX:209JF
UP3;bl/0d=3@0;^k^`1lO7`0@41003Xj>P0g=cL203Ti>@0503/k>`0j>SX0@D5104e=C@1DE5@03Ooo
ool0013ooooo00@0JFUY04i>CP1;Bd/0Cdm?0P1<C4`01P19BDT0B4Q804];B`1:BTX0B4Q804I6AP80
B4Q800D0BTY:04E5A@19BDT0B4Q804U9B@0204Y:BP0404U9B@14A4@0ADE504Q8B080AdM700D0BDU9
04Y:BP1=CDd0BDU904M7A`0204E5A@80A4A400T0Bd];04Q8B016ATH0B4Q804m?C`19BDT0ATI604E5
A@19BDT00P14A4@02`17AdL0A4A404=3@`13@d<0@T9203hn?P10@400ADE504I6AP12@T80B4Q80080
@d=300@0?clo04A4A011@D40?Shn0P0o?cl20410@0030451@@0o?cl0@D5100<0@41000@0@D5103lo
?`16ATH0@T920P11@D420410@00<0451@@0n?Sh0?3`l03lo?`12@T80?Cdm03/k>`0n?Sh0?clo03/k
>`0m?Cd0>SXj0P10@4020451@@0;0410@00o?cl0?3`l0451@@12@T80@41003/k>`0j>SX0?Shn0451
@@0j>SX00`0m?Cd02P0l?3`0?Shn0451@@0n?Sh0>c/k03dm?@14A4@0@41003`l?00i>CT203hn?P0K
03`l?00n?Sh0?Cdm03`l?00m?Cd0?3`l03dm?@0j>SX0?3`l03hn?P0l?3`0@41003lo?`0m?Cd0?3`l
0451@@0n?Sh0@T9203`l?00m?Cd0?Shn03dm?@0k>c/0?Shn04A4A013@d<0@T920080@d=300D0A4A4
0492@P10@400@d=30451@@030410@0<0?clo00d0?Cdm03lo?`0m?Cd0@D510410@00o?cl0?Shn03lo
?`0n?Sh0@T9203hn?P11@D40?Cdm00<0?3`l01P0@D5103lo?`0m?Cd0?clo03hn?P0l?3`0@T9203`l
?00k>c/0>SXj03lo?`0k>c/0?clo03`l?00k>c/0>3Ph03/k>`11@D40>c/k0410@00m?Cd0?clo03Xj
>P0i>CT203Xj>P0403`l?00o?cl0?Cdm03`l?080?Shn0180@D5103dm?@12@T80A4A403lo?`10@400
?Cdm03/k>`0n?Sh0?3`l04=3@`0n?Sh0B4Q804i>CP18B4P0@41004A4A00o?cl203/k>`0:03Xj>P10
@400?Shn03lo?`12@T80C4a<03hn?P0j>SX0?3`l03lo?`80?Cdm00/0?clo03Xj>P0k>c/0?3`l03/k
>`0n?Sh0>SXj03lo?`0m?Cd0BDU9059BDP0204e=C@0A04i>CP1ADE40CTi>04Y:BP12@T80@41003`l
?00j>SX0?clo03hn?P0l?3`0>CTi03lo?`0k>c/0>CTi03`l?00k>c/00P0j>SX203`l?0030410@00l
?3`0@4100080?clo00d0@d=3069RHP21PH40YJFU0<?3``37alL0/K6a09fMW@29RHT0JVYZ055AD@15
ADD0?Cdm0080@d=30`0n?Sh02@15ADD0F5QH06QXJ01aLG40NWYj07MgM`1UIFD0FEUI059BDP0205QH
F00<069RHP1_Kfl0P82008j>SP2/[:`0alO70<W9b@3Hf=P0gMgM0=WIf@3De=@0f][J0P3Ph>000`3F
e]H0d=3@0<W9b@020<;2`P050<_;b`3Hf=P0e=CD0=KFeP3Kfm/00P3Ogml03`3QhN40e=CD0;^k^`39
bLT0alO70<S8b03:b/X0_kno0<K6aP2o_kl0U9BD09^KV`2f][H0`/;20<30`0020<W9b@0X0:n_[`28
R8P0H61P07QhN027QhL0UYJF0:RXZ02c/k<0`l?30<30`035aLD0c/k>0=?Cd`3;bl/0XJ6Q06QXJ01T
I6@0Lg=c096AT@2[Zj/0[Zj^0:VYZ@2^[Zh0XJ6Q0<71`@3Cdm<0^;Rh08:2PP2CTi<0UIFE09^KV`2F
UYH0MgMg06EUI@1`L700H61P04a<C01WIfL0Ti>C08F5Q@80Zj^[00D0N7Qh0861P@1lO7`0F5QH04e=
C@020492@P0C0410@00m?Cd0>SXj03Ti>@0k>c/0>SXj03/k>`1dM7@0dm?C0;Ng]`1VIVH0?Shn0492
@P0k>c/0=cLg03hn?P0j>SX0=cLg03Ph>00203Lg=`0>03Ph>00f=SH0=CDe03Xj>P0g=cL0>SXj03De
=@0c<c<0=cLg03Hf=P0h>3P0=cLg03Ti>@0g=cL203De=@0L03Lg=`0e=CD0=cLg03Ph>015ADD0Hf=S
03lo?`0g=cL0>CTi0410@018B4P0G5aL06YZJP1XJ6P0H61P05UIF@16ATH0>SXj03Lg=`0l?3`0>c/k
03Ph>00g=cL0BTY:075aL@27QhL0GemO03`l?0gooooo000@ooooo`80Cdm?0`1<C4`01P1=CDd0C4a<
04i>CP1:BTX0AdM704Q8B080Bd];00`0B4Q804Y:BP18B4P0BDU904M7A`19BDT0Bd];04Y:BP18B4P0
A4A404=3@`16ATH204A4A00504I6AP18B4P0B4Q804Q8B015ADD00P16ATH04018B4P0@d=304Q8B018
B4P0A4A404I6AP1=CDd0Cdm?04M7A`13@d<0AdM704=3@`14A4@0BDU904m?C`19BDT204E5A@0504=3
@`17AdL0ATI604E5A@16ATH00P14A4@01@15ADD0@41004I6AP10@400?Shn0080@41000h0?clo03dm
?@10@400@T9204A4A011@D40?Cdm0451@@0o?cl0?Cdm0410@014A4@0AdM704E5A@80@41000<0?Shn
0410@013@d<00P0n?Sh01@0o?cl0?3`l03`l?00o?cl0>c/k0080?Cdm00T0?clo0451@@12@T80?Cdm
0451@@0m?Cd0@41003dm?@0n?Sh00P0o?cl02P0m?Cd0>c/k03`l?00o?cl0>c/k03`l?00n?Sh0?Cdm
03hn?P10@40203/k>`0703`l?00n?Sh0?3`l03dm?@0i>CT0>3Ph03`l?00204E5A@0603hn?P0l?3`0
?Shn03Xj>P0n?Sh0>SXj0P0n?Sh00`0k>c/0@41003hn?P0203`l?00303lo?`0j>SX0@D510080@D51
00d0?Cdm03Xj>P0m?Cd0?3`l03dm?@0o?cl0@41003lo?`0l?3`0?clo0410@011@D40@T920080@410
00L0@T9203hn?P0n?Sh0@D510410@00m?Cd0@T9200<0?clo00@0?Shn03lo?`0o?cl0?Shn0P0o?cl0
1P13@d<0A4A403dm?@0j>SX0?3`l03dm?@80?clo00D0?Cdm03`l?00l?3`0@41003`l?00203hn?P07
03lo?`0j>SX0?3`l03dm?@12@T80@41003dm?@020451@@0A03dm?@0k>c/0?Shn03Ti>@0j>SX0>c/k
03hn?P0o?cl0?3`l03/k>`0l?3`0@D5103dm?@11@D40?3`l03hn?P0k>c/00P0n?Sh0100k>c/0?Shn
03hn?P0o?cl20451@@0:03hn?P12@T80@T9203hn?P10@400@d=303`l?00j>SX0>c/k03lo?`<0?Shn
00H0?3`l03Ti>@0m?Cd0?3`l03dm?@0n?Sh20410@00:03/k>`0j>SX0?Cdm03lo?`0j>SX0>CTi04E5
A@1KFe/0Kfm_06=SH`80ATI60240@T9203lo?`0n?Sh0?Cdm0410@00k>c/0?Cdm03/k>`0h>3P0?Cdm
03`l?00n?Sh0?Cdm0451@@0l?3`0>CTi03Xj>P0i>CT0>c/k03`l?00j>SX0?Cdm03`l?017AdL0F5QH
07alO02MWId0/K6a0;Rh^02ZZZX0SXj>069RHP1<C4`00P12@T80800l?3`0?Shn0451@@10@400@T92
0410@013@d<0@D5104A4A01MGEd0MgMg08:2PP1gMgL0MGEe07inOP2=SHd0X:2P0;Ng]`2TY:@0]KFe
0<30`02_[jl0ZZZZ0:f][@2f][H0/K6a0;:b/P2TY:@0WinO09JFUP2>SXh0TI6A0P2HV9P0K`2RXZ80
XJ6Q09>CT`1iNGT0Jf][06=SH`1eMGD0Q8B408f=S@2LW9`0WIfM09jNWP2EUID0Q8B4075aL@25QHD0
PH6107=cL`1gMgL0Lg=c07IfMP1_Kfl0GEeM059BDP1FEUH0KVi^071`L022PX80V9RH08R8R021PH40
HV9R051@D017AdL0C4a<079bLP27QhL0RXZ:08>3P`1YJFT0KVi^07]kN`1mOGd0MGEe065QH@1VIVH0
TI6A0;6a/@2g]kL0]KFe0:j^[P2h^;P0aLG50=OGe`3Cdm<0`l?30:JVYP3:b/X0a<C40:JVYP2UYJD0
_[jn0<O7a`2b/[80Vi^K08B4Q01`L700LG5a07moO`2FUYH0YJFU09RHV022PX80Ti>C0;bl_031`L40
YJFU09NGU`2EUID0P82007alO01OGel0H61P05]KF`20P800^KVi0>3Ph034a<@0[:b/09RHV01nOWh0
B4Q803dm?@0o?cl0>3Ph03Hf=P0h>3P0>SXj03Ph>00f=SH0>3Ph03`l?00g=cL0=SHf03Ti>@0e=CD0
=SHf03Ph>00f=SH0>3Ph03De=@0303Hf=P0M03Lg=`0d=3@0=SHf03Ti>@1:BTX0[jn_0;>c/`1SHf<0
Bd];04m?C`1<C4`0AdM703lo?`0g=cL0>CTi03Lg=`0f=SH0>CTi03/k>`0f=SH0=cLg03Ph>015ADD0
R8R809nOW`2?Shl0Hf=S03hn?P14A4@03Oooool0013ooooo00@0Cdm?059BDP1=CDd0Bd];0`1:BTX0
3P1=CDd0B4Q804M7A`18B4P0Bd];04U9B@18B4P0BTY:04M7A`1;Bd/0ATI604U9B@14A4@0ATI60P17
AdL04@16ATH0ADE504=3@`13@d<0ATI604Q8B014A4@0B4Q804E5A@19BDT0A4A404U9B@15ADD0B4Q8
04Y:BP16ATH0A4A40080ADE500D0AdM70492@P12@T80B4Q804E5A@020492@P0=04E5A@12@T80@D51
0410@013@d<0A4A404=3@`11@D40AdM704I6AP11@D40@41004E5A@0204=3@`0D0492@P13@d<0@D51
0410@014A4@0@d=303lo?`0n?Sh0?3`l04I6AP10@400?clo03/k>`18B4P0@d=30410@011@D40@T92
0410@00o?cl20492@P0D03dm?@0k>c/0>c/k03dm?@10@400>c/k0451@@17AdL0@41003`l?00o?cl0
?3`l03dm?@0n?Sh0?Cdm0410@013@d<0?Shn03lo?`0n?Sh203dm?@<0>c/k0P0l?3`203lo?`0C03/k
>`0n?Sh0>SXj03Ti>@0o?cl0@D5103Xj>P0n?Sh0?Cdm03hn?P0m?Cd0>c/k03dm?@10@400>CTi04=3
@`0k>c/0>SXj03hn?P0203dm?@0803/k>`0m?Cd0?Cdm03lo?`10@400?clo03hn?P0o?cl204A4A004
03hn?P17AdL0?3`l03lo?`80?Cdm00<0?clo0451@@0m?Cd00P11@D404`0o?cl0@41004=3@`0o?cl0
?Shn03lo?`0n?Sh0?Cdm03hn?P0m?Cd0?Shn0410@00l?3`0?clo0492@P0l?3`0ADE504Q8B013@d<0
0P0o?cl02@0n?Sh0@T9203hn?P0m?Cd0@41003dm?@10@400?Cdm03hn?P0203lo?`0303dm?@0i>CT0
@D510080?Shn0P0j>SX02@0o?cl0@d=303`l?00m?Cd0?Shn03dm?@0i>CT0>c/k03hn?P0203lo?`04
03`l?00n?Sh0>SXj03/k>`80?clo00/0?Shn03dm?@0m?Cd0?clo03hn?P0l?3`0>SXj03`l?00n?Sh0
@d=303`l?0020410@00504I6AP15ADD0?clo03hn?P0m?Cd00`10@4001`0l?3`0@4100492@P0k>c/0
?Cdm03Xj>P11@D400P0l?3`0<`0k>c/0?clo03lo?`0j>SX0?3`l03hn?P0f=SH0?Cdm04A4A01:BTX0
Bd];03lo?`0l?3`0?Cdm03Xj>P0m?Cd0@41003`l?00n?Sh0>SXj03dm?@0n?Sh0?3`l0410@00j>SX0
?clo03Ti>@0m?Cd0>SXj03dm?@0l?3`0?Cdm03lo?`0m?Cd0>SXj04E5A@1MGEd0O7al09nOW`2LW9`0
TY:B071`L01HF5P0ADE503`l?00o?cl0?3`l03dm?@13@d<0@D5103hn?P0203`l?00c03dm?@13@d<0
@41003hn?P11@D40@41003hn?P12@T80@D5104=3@`1:BTX0KFe]09:BTP2][Jd0];Bd0;Zj^P30`<00
SHf=06IVIP1iNGT0Ogmo08N7Q`2;Rh/0SHf=096AT@2JVYX0S8b<08Z:RP2?Shl0SHf=08R8R02;Rh/0
RHV90:b/[038b<P0/[:b0861P@20P800WYjN0:BTY02_[jl0[Zj^0:VYZ@2][Jd0YJFU07IfMP1DE5@0
G5aL05iNGP1TI6@0H61P0080IfMW01/0IFEU07=cL`1mOGd0P82009BDU02UYJD0Y:BT09NGU`23Ph<0
Lg=c05]KF`1UIFD0aLG50=?Cd`3=cLd0_Kfm09nOW`1]KFd0G5aL07MgM`1fMWH0Ph>307IfMP1XJ6P0
IVIV065QH@1JFUX00P1GEeL08@1UIFD0Lg=c07emO@2>SXh0R8R80:VYZ@35aLD0`/;208Z:RP2RXZ80
^;Rh0;Ng]`2RXZ80MGEe06YZJP1`L700Hf=S05aLG01gMgL0WYjN0;Rh^034a<@0e=CD0=?Cd`36a/H0
^KVi0;Rh^02XZ:P0YJFU0:RXZ03>c/h0eMGE0=cLg0020>3Ph00:0=7Ad@2l_;`0Q8B405ADE00n?Sh0
>SXj03Lg=`0i>CT0>SXj03Ph>080>CTi00<0>3Ph03Ti>@0e=CD00P0e=CD0200h>3P0=CDe03Hf=P0h
>3P0=3@d03Lg=`0e=CD0>CTi0P0h>3P02P0j>SX0=CDe03Ph>01EEED0W9bL0::RXP1TI6@0@T9203`l
?00j>SX203Hf=P80=CDe00l0=SHf03<c<`0f=SH0=CDe03Ph>00i>CT0=SHf03Lg=`0n?Sh0DE5A04i>
CP0m?Cd0A4A407EeM@2`/;003Oooool0013ooooo0100GemO069RHP1DE5@0Bd];04i>CP19BDT0CTi>
04Q8B016ATH0AdM704U9B@1;Bd/0B4Q804];B`16ATH0B4Q80P16ATH204Q8B00504I6AP14A4@0BTY:
04M7A`18B4P00P14A4@02`16ATH0B4Q804Q8B016ATH0ADE505eMG@18B4P0BTY:04Q8B015ADD0@d=3
0080BDU900/0A4A40451@@17AdL0ADE50492@P13@d<0ADE50492@P15ADD0@T9204=3@`020492@P0:
03lo?`11@D40BTY:04Q8B01:BTX0DE5A0410@00n?Sh0ATI604e=C@<0@D5100D0ATI60492@P12@T80
?clo03`l?00203hn?P0504I6AP12@T80@41004=3@`12@T800P10@4020451@@070492@P10@400@410
0492@P0l?3`0?Cdm03/k>`0203`l?00303hn?P13@d<0A4A40080?3`l00<0?Shn0451@@0n?Sh00`0m
?Cd05011@D40>c/k03dm?@10@400?clo0492@P11@D40?Shn03dm?@0o?cl0>CTi0451@@0l?3`0@410
03hn?P0o?cl0@41003dm?@10@400@D510P0n?Sh0200m?Cd0?3`l03Xj>P10@400A4A40492@P0o?cl0
@T920P0m?Cd02@0j>SX0?clo0492@P0l?3`0?Shn0410@00n?Sh0?clo03`l?00203lo?`050492@P0m
?Cd0@41004M7A`10@4000P0n?Sh01@10@400ATI603dm?@0m?Cd0?3`l0080?Cdm00T0?Shn03lo?`0o
?cl0@T9203`l?00o?cl0@41003lo?`0m?Cd00P0n?Sh01010@400@d=30492@P15ADD20492@P80@410
00L0?clo03`l?00l?3`0?clo03hn?P0j>SX0?3`l0080>c/k0P0n?Sh303lo?`80>c/k0P0n?Sh03P0i
>CT0?Shn0410@010@400@D5103lo?`11@D40ATI60492@P0o?cl0?Cdm03/k>`0l?3`0?Cdm0P0o?cl0
1`0h>3P0?3`l03dm?@10@400@D5103Xj>P0l?3`00P0n?Sh00`0k>c/0@4100451@@0203Xj>P0D03lo
?`12@T80?Shn03hn?P0o?cl0@T920451@@14A4@0>c/k03`l?00o?cl0?Shn03`l?00k>c/0>SXj03lo
?`0m?Cd0>SXj03hn?P0k>c/203Ph>00?03`l?00g=cL0?3`l03`l?00k>c/0=SHf03Ph>00m?Cd0>c/k
03hn?P10@400?3`l03lo?`0j>SX0?3`l0080?Cdm00h0>c/k03`l?010@400@41003Ti>@0k>c/0>3Ph
03hn?P0j>SX0?clo03/k>`0o?cl0@d=304e=C@80Fe]K01d0E5AD04U9B@13@d<0?Shn03`l?00k>c/0
@T9203dm?@11@D40?Cdm03hn?P12@T80@D5103`l?00i>CT0>c/k03`l?00m?Cd0?Shn03/k>`13@d<0
?Cdm03hn?P1KFe/0L71`0861P@1jNWX0PX:208n?S`0208Z:RP0D07moO`1jNWX0U9BD09FEU@24Q8@0
MGEe06MWI`1^KVh0Ogmo09RHV02a/K40b/[:0<_;b`30`<00_[jn0<_;b`3Kfm/0iNGU0>3Ph03>c/h2
0<C4a00n0;Jf]P2XZ:P0[jn_0;6a/@2XZ:P0T92@07inOP1ZJVX0F5QH04i>CP1GEeL0CTi>05YJFP1F
EUH0De=C05UIF@1QHF40GemO069RHP1YJFT0LG5a09RHV02d];@0XZ:R08b<S01oOgl0RXZ:0;Rh^03:
b/X0a<C40;^k^`2PX:00MgMg07YjNP2b/[80_Kfm0<O7a`33`l<0]KFe071`L01LG5`0E5AD06EUI@1e
MGD0OGem08J6QP2;Rh/0N7Qh07IfMP1cLg<0NGUi07QhN01gMgL0U9BD08N7Q`1dM7@0IfMW06e]K@1h
N7P0HV9R06QXJ02FUYH20;Rh^00D0;Ng]`38b<P0^k^k0:JVYP1jNWX0GEeM05EEE@17AdL0B4Q805UI
F@2GUiL0bl_;0;bl_02JVYX0LW9b05UIF@1<C4`0?clo03`l?010@40203`l?00503/k>`0i>CT0?Cdm
03`l?00k>c/00P0m?Cd02@0i>CT0=CDe03`l?00j>SX0>c/k03Ph>00e=CD0=cLg03/k>`0203Ti>@09
03Xj>P0h>3P0>SXj03Ti>@0g=cL0@41004];B`0m?Cd0>3Ph00<0>CTi00D0=cLg03Hf=P0g=cL0=CDe
03@d=00203De=@0<03<c<`0e=CD0=cLg03Lg=`0f=SH0=cLg03Ti>@0o?cl0Kfm_0;Ng]`3@d=00_;bl
3Oooool0013ooooo0P1BDU803P1>CTh0Bd];04a<C018B4P0BDU904Y:BP1<C4`0AdM704U9B@18B4P0
Bd];04a<C01:BTX0BDU91016ATH03@1:BTX0BDU904Q8B016ATH0A4A404I6AP18B4P0BDU904M7A`18
B4P0A4A404I6AP1?Cdl00P14A4@03`16ATH0DE5A04M7A`15ADD0?Shn0451@@13@d<0ATI604U9B@16
ATH0@D5104=3@`12@T80@d=30492@P020410@00=04A4A012@T80ADE50410@00o?cl0EeMG05EEE@16
ATH0?clo03dm?@12@T80?clo04=3@`020451@@0303hn?P10@400@D510080?clo00H0?3`l0451@@10
@400@d=304A4A010@40203lo?`090492@P11@D40?clo03lo?`0m?Cd0?Shn03dm?@0n?Sh0>SXj00<0
?Cdm00X0@D5103hn?P0j>SX0@41003`l?013@d<0?Cdm03hn?P0m?Cd0>c/k0P0l?3`203hn?P090410
@014A4@0?clo03Xj>P0k>c/0@T920451@@10@400@D5100@0?Shn00<0?3`l03hn?P0n?Sh00P0l?3`6
03/k>`0;0410@015ADD0?3`l03`l?00i>CT0>SXj03`l?00j>SX0?Shn03dm?@0k>c/00`0l?3`04@0j
>SX0>c/k03dm?@11@D40@T9204A4A013@d<0@41003dm?@0o?cl0>c/k03Ti>@0l?3`0?clo0451@@0k
>c/0?3`l0080?Shn00D0?3`l03dm?@0m?Cd0?Cdm03`l?00203dm?@0703hn?P0o?cl0@41003dm?@10
@400?clo0492@P0303lo?`80?3`l0P0k>c/02@0l?3`0?Cdm03Xj>P0l?3`0@41004A4A00m?Cd0>SXj
03`l?00203hn?P0903/k>`0m?Cd0@41003`l?00n?Sh0?Cdm03`l?011@D40?3`l00<0?Cdm0P0j>SX2
03dm?@050451@@0n?Sh0?3`l03/k>`0f=SH00P0k>c/02`10@400?clo0410@00j>SX0?Cdm03hn?P0m
?Cd0?3`l03/k>`0n?Sh0>3Ph0080?3`l00X0?clo03`l?00m?Cd0>SXj03/k>`0m?Cd0>c/k03Ti>@0k
>c/0?3`l0P0n?Sh20410@00803hn?P0j>SX0>CTi03Ti>@0k>c/0>CTi03Ph>00j>SX203Ti>@070410
@00h>3P0>c/k03lo?`0n?Sh0?clo03/k>`020410@00603`l?00m?Cd0>SXj03dm?@0j>SX0@d=30P0m
?Cd20410@00403`l?00k>c/0@d=303lo?`<0>c/k01L0@D5103dm?@0o?cl0>c/k03lo?`10@400>SXj
03Ti>@0n?Sh0@41003hn?P0l?3`0>c/k0451@@0o?cl0>c/k03hn?P0k>c/0>SXj03/k>`0o?cl0F5QH
09>CT`020<c<c0100;Ng]`2VYZH0R8R807EeM@1ZJVX0GemO04m?C`1>CTh0B4Q80410@013@d<0ADE5
05mOG`2:RXX0[jn_0<[:bP2^[Zh0X:2P0:6QX@2PX:00WYjN0:JVYP2[Zj/0Y:BT09nOW`2c/k<0`L71
0;^k^`2b/[80W9bL07inOP1gMgL0IfMW061PH01UIFD0H61P05iNGP1RHV80EUIF04Q8B016ATH0B4Q8
059BDP1dM7@0MGEe0861P@1lO7`0Ph>309FEU@2YZJT0^k^k0<?3``3;bl/0^[Zj0:j^[P2f][H0];Bd
0<G5a@3;bl/0_;bl0:ZZZP1gMgL0CTi>069RHP80IfMW00L0Hf=S05YJFP1VIVH0E5AD0820P02o_kl0
g]kN0080fm_K02`0dm?C0<c<c02c/k<0Ph>306ATI01VIVH0S8b<09NGU`2][Jd0VYZJ07emO@1hN7P0
Rh^;09VIV@2LW9`0YjNW0;2`/03;bl/0/k>c0:NWY`2VYZH0Y:BT0:ZZZP2UYJD0Ogmo079bLP1jNWX0
Ti>C0:^[Z`2HV9P0I6AT05QHF01QHF40JVYZ07UiN@25QHD0Ogmo07UiN@23Ph<0Ogmo07EeM@1XJ6P0
EUIF04A4A080ADE500<0JFUY05ADE019BDT00P0j>SX01`0k>c/0?3`l03Ti>@0g=cL0>3Ph03Ti>@0h
>3P00P0f=SH203Lg=`0<0492@P1>CTh0>3Ph03Hf=P0g=cL0=SHf03Lg=`0e=CD0<c<c03De=@0i>CT0
>3Ph0P0e=CD303Lg=`0903Hf=P0i>CT0>CTi04m?C`1oOgl0Z:RX09fMW@1`L700ADE500gooooo000@
ooooo`0704i>CP1?Cdl0Cdm?04a<C01;Bd/0C4a<04];B`0204Y:BP0<04];B`17AdL0ATI604M7A`16
ATH0BDU904Q8B016ATH0B4Q804M7A`15ADD0B4Q80P19BDT01P18B4P0A4A404E5A@15ADD0ATI604M7
A`<0ATI60`13@d<05@14A4@0ATI604I6AP18B4P0ATI60492@P14A4@0B4Q804Y:BP15ADD0@d=304I6
AP12@T80@d=304I6AP12@T80@4100451@@14A4@0@D5104=3@`020410@00E0451@@14A4@0?Shn03lo
?`0m?Cd0B4Q804A4A00o?cl0@d=30451@@0m?Cd0@d=30451@@13@d<0?3`l03Ti>@0n?Sh0@T920451
@@12@T80A4A40080ADE500D0A4A40492@P0m?Cd0?3`l03dm?@020451@@<0?Shn00<0?Cdm03hn?P0l
?3`00`0l?3`403/k>`0403Xj>P11@D40?Shn03dm?@80@41000X0?Shn03`l?00l?3`0?Shn03dm?@10
@400?Shn04=3@`10@400@D510P0o?cl20492@P0803dm?@0k>c/0>c/k03dm?@0o?cl0?Shn03Ph>00i
>CT203dm?@0303`l?00i>CT0>SXj0080>SXj00P0?3`l03/k>`0o?cl0?Cdm03hn?P0l?3`0?clo03`l
?080>c/k0`0o?cl01010@400?clo03lo?`0m?Cd20451@@0303dm?@10@400?Cdm0080?Cdm00H0?3`l
0410@010@400@41004E5A@11@D4203`l?00;03dm?@0l?3`0?Cdm0410@014A4@0@T9203lo?`0l?3`0
@T920410@00m?Cd00P0n?Sh0200o?cl0@D5103lo?`0j>SX0?3`l03Lg=`0j>SX0?3`l0P11@D401@0n
?Sh0?Cdm03lo?`0m?Cd0>SXj0080?Cdm0P0n?Sh00`15ADD0@T9203`l?00203dm?@0703/k>`0n?Sh0
?clo03`l?00o?cl0?Shn04A4A00203hn?P0=03lo?`0n?Sh0>c/k03Ti>@14A4@0?Shn03dm?@0j>SX0
?clo0410@00m?Cd0?3`l03hn?P0203Ti>@80?3`l00<0?Shn03Xj>P0i>CT00P0l?3`203/k>`0;03dm
?@0l?3`0>c/k03`l?00i>CT0@41003dm?@0l?3`0?clo0410@00m?Cd00`0j>SX0300g=cL0>CTi03dm
?@0j>SX0>CTi03/k>`0l?3`0?Shn03/k>`0l?3`0@d=30410@080?3`l01D0>CTi03`l?00m?Cd0?clo
03Xj>P0l?3`0?Shn03Ph>00n?Sh0?Cdm03lo?`0l?3`0>c/k03lo?`0k>c/0?3`l03dm?@0k>c/0@T92
03dm?@11@D400P0m?Cd05@0i>CT0@41003/k>`0j>SX0A4A40410@00k>c/0?3`l03hn?P0k>c/0?Shn
04m?C`1lO7`0[Jf]0;Jf]P2FUYH0MGEe069RHP19BDT0@d=303`l?0020451@@0T0410@011@D40@T92
04];B`1HF5P0Jf][0820P02RXZ80[jn_09>CT`1ZJVX0JFUY06YZJP1SHf<0KVi^07moO`2<S8`0ZZZZ
0;Zj^P2f][H0WYjN09bLW02YZJT0_;bl0;fm_@2/[:`0TY:B08N7Q`1jNWX0Ph>30:j^[P2n_[h0/;2`
09nOW`2SXj<0[:b/0P2l_;`01@2h^;P0^[Zj0<G5a@38b<P0`l?30080^[Zj00D0^k^k0<C4a02_[jl0
T92@0:BTY0020:^[Z`0Z0:RXZ02GUiL0PH6106m_K`1TI6@0D51@05ADE01FEUH0B4Q804m?C`17AdL0
BTY:0:JVYP3Fe]H0g]kN0=OGe`3:b/X0gMgM0=oOg`3Jf]X0d];B0:j^[P2;Rh/0Ng]k07IfMP2<S8`0
YZJV096AT@1_Kfl0G5aL07emO@2HV9P0UiNG07inOP1aLG40QHF50:2PX02EUID0YJFU0;>c/`33`l<0
gMgM0P3Ng]h09@3GemL0`L710<71`@2k^k/0XZ:R0;Ng]`34a<@0^[Zj0;jn_P2^[Zh0a<C40=kNgP3L
g=`0clo?0<?3``2n_[h0_kno0;bl_036a/H0fm_K0;fm_@2PX:00T92@09>CT`2;Rh/0Q8B407emO@1U
IFD0ADE503Ph>00g=cL0>c/k03Ph>00f=SH0=3@d05YJFP1<C4`00`0g=cL503@d=00403De=@0d=3@0
=3@d03Lg=`80<c<c00P0=CDe03Lg=`0i>CT0Bd];07moO`1dM7@0DU9B03/k>`80>CTi3Oooool0013o
oooo00l0CTi>055AD@1ADE40Cdm?04e=C@1>CTh0Cdm?04e=C@1JFUX0B4Q804U9B@1:BTX0BDU904E5
A@19BDT00P16ATH01`1:BTX0Bd];04I6AP17AdL0BDU904I6AP18B4P00P17AdL204E5A@0704I6AP14
A4@0BTY:04A4A015ADD0BDU904I6AP0204U9B@0504m?C`18B4P0A4A404I6AP12@T800P15ADD09`18
B4P0@D5104Y:BP14A4@0BDU904A4A015ADD0@d=30451@@17AdL0@D5104=3@`17AdL0@T9203lo?`10
@400@d=30451@@14A4@0Bd];0451@@12@T80?Cdm04=3@`0o?cl0?Shn04E5A@1:BTX0@D5104I6AP14
A4@0@T9204I6AP13@d<0@T9204A4A016ATH0A4A40410@00203hn?P0503`l?010@400?Shn03lo?`0m
?Cd00P0n?Sh01@0l?3`0?Shn03/k>`0n?Sh0?3`l00<0>c/k00l0?Cdm03lo?`0m?Cd0?3`l03/k>`11
@D40@41003lo?`14A4@0@D5104=3@`0l?3`0@T9203hn?P12@T800P0n?Sh0400o?cl0?Shn04A4A014
A4@0?clo03hn?P0l?3`0?Cdm03`l?00m?Cd0>CTi03/k>`10@400?Cdm03Xj>P0k>c/203dm?@0G03Xj
>P0l?3`0>SXj03`l?00k>c/0?Shn03Xj>P0m?Cd0>SXj03hn?P0l?3`0?Shn03Ph>00o?cl0?3`l0410
@00l?3`0?clo0492@P10@400@D5104A4A00n?Sh00P0l?3`203/k>`040451@@0l?3`0@T9203lo?`<0
?Shn00X0?3`l03dm?@0n?Sh0?Cdm0451@@0l?3`0>c/k03dm?@11@D40@4100P0l?3`0100m?Cd0?3`l
03`l?00h>3P203`l?00>0451@@0l?3`0?Shn0451@@10@400?Shn03lo?`0m?Cd0>SXj0410@00m?Cd0
?Shn04U9B@12@T8203dm?@0303/k>`0i>CT0>SXj0080?clo00h0@T9203dm?@0j>SX0>c/k0410@00o
?cl0?Cdm0410@012@T80@4100492@P13@d<0?clo03Ti>@80?3`l00d0?Cdm04i>CP0j>SX0>CTi03Ph
>00j>SX0>CTi03/k>`0h>3P0=cLg03dm?@0h>3P0>c/k0080?Shn00X0?Cdm03/k>`0o?cl0>c/k03hn
?P0m?Cd0>c/k03Xj>P0k>c/0>3Ph0P0j>SX04@0l?3`0>CTi03Ti>@0i>CT0>SXj03/k>`14A4@0?Shn
03lo?`0j>SX0?Cdm04=3@`0n?Sh0?3`l03Xj>P0i>CT0=cLg0080>c/k0100>CTi03Xj>P0k>c/0=cLg
03/k>`0m?Cd0@d=30492@P10@400?Shn03/k>`10@400>CTi03/k>`0m?Cd0?3`l0P0n?Sh04@0k>c/0
?3`l03lo?`0m?Cd0>SXj03dm?@11@D40?3`l03Ph>00l?3`0?clo04Q8B01CDe<0IfMW06=SH`1=CDd0
@d=30080@T9200D0@D5103lo?`12@T80?Shn0410@00204E5A@0^05iNGP1ZJVX0J6QX05iNGP1@D500
ADE504=3@`10@400@d=304Q8B01WIfL0Lg=c09FEU@2KVi/0O7al07inOP21PH40Rh^;08F5Q@1jNWX0
IVIV065QH@1HF5P0Cdm?04I6AP14A4@0?clo04=3@`1<C4`0De=C05]KF`1SHf<0GUiN069RHP1PH600
GemO05aLG01IFET0FUYJ05QHF01MGEd0FUYJ069RHP1/K6`0N7Qh08f=S@80Ti>C0180QhN708Z:RP2<
S8`0UYJF0:JVYP2i^KT0b/[:0<30`02:RXX0Lg=c06a/K01hN7P0Ph>307moO`1fMWH0TI6A09JFUP2g
]kL20:BTY0050;Vi^@3?cll0gmoO0=KFeP2e]KD00P2n_[h07P2`/;00][Jf0:VYZ@2g]kL0[Jf]09ZJ
VP21PH40M7Ad07QhN01fMWH0JFUY06QXJ01YJFT0MGEe08f=S@2?Shl0[Zj^0<C4a036a/H0`L710;6a
/@39bLT0gMgM0>7Qh@3Rh^80hN7Q0>3Ph03Shn<0f][J0=oOg`80gMgM00<0dm?C0<?3``38b<P00P2e
]KD04P3@d=00emOG0=;BdP3;bl/0b/[:0=gMg@3Ti>@0gmoO0=WIf@39bLT0YjNW06e]K@10@400>CTi
03Lg=`0a<C40>3Ph03/k>`80=SHf0P0d=3@303Hf=P0303De=@0d=3@0=3@d0080=SHf00/0<c<c03@d
=00d=3@0=CDe03Ph>01>CTh0HF5Q05=CD`0h>3P0=CDe03Ph>00203Lg=`gooooo000@ooooo`0I051@
D024Q8@0Rh^;09^KV`22PX80KFe]061PH01IFET0D51@04a<C01=CDd0C4a<04M7A`19BDT0B4Q804U9
B@17AdL0Bd];04e=C@1;Bd/0AdM704i>CP17AdL0ATI604U9B@0204M7A`0F04E5A@18B4P0BDU904U9
B@18B4P0ADE504=3@`17AdL0@T9204M7A`18B4P0@T9204=3@`17AdL0@D5104A4A012@T80ADE50451
@@15ADD0B4Q804A4A0<0@41000T0@T9204E5A@12@T80@d=304U9B@13@d<0BDU90492@P14A4@00P15
ADD07`10@400@T920451@@0m?Cd0@d=303lo?`14A4@0@D510410@017AdL0BTY:04A4A016ATH0@d=3
04I6AP13@d<0?Cdm03lo?`14A4@0@41003`l?010@400?clo04=3@`10@400>c/k03`l?00m?Cd0@410
03`l?00n?Sh00P0l?3`01@0n?Sh0?Cdm03dm?@0o?cl0@T920080@4100P0m?Cd03`0k>c/0?Cdm03hn
?P14A4@0@D5104E5A@0o?cl0A4A403hn?P12@T80@D5103`l?00j>SX0?Shn03/k>`020410@00903`l
?00m?Cd0?3`l03Xj>P0n?Sh0>SXj03dm?@0i>CT0?Shn0080?Cdm00T0?3`l03dm?@0k>c/0?3`l03dm
?@0k>c/0>SXj03`l?00o?cl00P0n?Sh20451@@0?0492@P0k>c/0?3`l03hn?P12@T80?clo03hn?P13
@d<0@D5104=3@`0o?cl0A4A404I6AP11@D40?clo0080?Cdm00l0>3Ph03dm?@10@400?clo03/k>`0o
?cl0@D5103lo?`11@D40@4100492@P0n?Sh0?3`l03hn?P0o?cl00P0n?Sh01010@400?3`l03dm?@0l
?3`203Xj>P0?03dm?@0l?3`0?Shn0492@P0n?Sh0?clo03dm?@10@400?clo0410@01ADE40C4a<04U9
B@14A4@0?Cdm0080?clo0P0m?Cd04P0n?Sh0@D510410@00n?Sh0?Cdm0410@00l?3`0>SXj03Ti>@0l
?3`0@D5103`l?00n?Sh0?clo03hn?P0l?3`0?Shn03`l?080>c/k00X0?Shn03dm?@0m?Cd0>c/k03Xj
>P0h>3P0?3`l03Lg=`0l?3`0>SXj0P0l?3`00`0n?Sh0?Cdm03Xj>P0203`l?00603dm?@0k>c/0?Cdm
03`l?00i>CT0?3`l0P0k>c/03`0j>SX0>c/k03`l?00h>3P0>SXj03dm?@11@D40@d=303dm?@0k>c/0
?Shn03dm?@0j>SX0?3`l0451@@0203Xj>P0:03/k>`0n?Sh0>c/k03/k>`0l?3`0@T9204a<C013@d<0
A4A404M7A`<0?Cdm00<0@41003/k>`0j>SX00P0l?3`203dm?@030410@00k>c/0>CTi0080?3`l00@0
@D5103Xj>P0o?cl0@4100`0n?Sh00`14A4@0AdM704A4A00204M7A`0804=3@`10@400@41003/k>`0n
?Sh0@D5103/k>`11@D4204=3@`030451@@13@d<0?clo0080@4100140ATI605UIF@1TI6@0N7Qh08J6
QP2GUiL0RXZ:09BDU021PH40O7al05]KF`1CDe<0@d=30410@015ADD0>SXj0451@@0203`l?080?clo
00X0?Shn0451@@0k>c/0?clo03hn?P11@D40@41003hn?P10@400?clo0P0n?Sh07@11@D40AdM704e=
C@1BDU80KVi^07UiN@20P800QhN70:2PX02c/k<0^;Rh0;bl_02k^k/0a<C40<W9b@3AdM40f][J0=oO
g`3MgMd0hN7Q0=OGe`38b<P0XZ:R09>CT`2KVi/0T92@0:VYZ@2[Zj/0TI6A0080L71`03@0IFEU09FE
U@2SXj<0UiNG0:ZZZP2GUiL0VYZJ09fMW@1aLG40JVYZ08V9R@2ATI40V9RH0:2PX02_[jl0/k>c09fM
W@2@T900LW9b059BDP1eMGD0WYjN0;bl_03=cLd0clo?0<[:bP33`l<0^[Zj0<?3``3=cLd0f=SH0=[J
fP3GemL0gMgM0>;RhP3AdM40ZZZZ0;bl_02o_kl0Zj^[0<_;b`3Bd]80]KFe0<71`@2l_;`0^k^k0<;2
`P34a<@0cLg=0=GEe@31`L40PH610P1VIVH02`1jNWX0IFEU03Ti>@0e=CD0=SHf03Ti>@13@d<0CDe=
03Hf=P0d=3@0=CDe00@0=cLg00d0=SHf03@d=00g=cL0>3Ph03De=@0g=cL0=CDe03Lg=`0m?Cd0>CTi
03Xj>P0f=SH0=cLg00@0>3Ph3Oooool0013ooooo0200VYZJ08:2PP1aLG40PX:208j>SP2^[Zh0^[Zj
0:^[Z`2a/K40Xj>S07]kN`1SHf<0Cdm?04e=C@1<C4`0FEUI065QH@1NGUh0Hf=S05aLG01BDU80DE5A
04Y:BP14A4@0B4Q804M7A`15ADD0BDU904];B`17AdL0BTY:04I6AP<0B4Q80P15ADD03@13@d<0ADE5
04=3@`15ADD0A4A404=3@`10@400A4A404=3@`14A4@0C4a<04E5A@14A4@00P13@d<02`12@T80@410
0492@P15ADD0CTi>04I6AP15ADD0@d=30451@@18B4P0A4A40080@T9200<0@41003`l?00k>c/00P12
@T80100o?cl0ATI604M7A`11@D420410@00;0451@@13@d<0@T9204=3@`11@D40@41003dm?@0l?3`0
>c/k03hn?P0m?Cd00P0n?Sh01P0l?3`0>CTi03/k>`0k>c/0@D510410@080>c/k01H0>SXj03lo?`0n
?Sh0?clo03/k>`15ADD0A4A403/k>`0j>SX0?Cdm03Xj>P0m?Cd0?clo0451@@10@400@d=303lo?`0m
?Cd0@41003/k>`0l?3`0@d=30P0m?Cd303hn?P0D03dm?@0k>c/0?Shn03Xj>P0n?Sh0>c/k03`l?00k
>c/0=cLg03/k>`0o?cl0?3`l03dm?@0o?cl0?Shn03Xj>P0k>c/0?Cdm03hn?P0o?cl203dm?@0H03`l
?00m?Cd0?Shn0410@012@T80@4100492@P0k>c/0?Shn04M7A`10@400>c/k03dm?@0n?Sh0@D5103lo
?`13@d<0?Shn03Ti>@0n?Sh0?clo0410@011@D40?Cdm0`0o?cl03`0m?Cd0?clo03lo?`0o?cl0?Shn
03`l?00o?cl0@D5103hn?P18B4P0@41003/k>`0m?Cd0@41004=3@`0203dm?@0503Xj>P0n?Sh0A4A4
04E5A@10@4000P0n?Sh00`11@D40?Shn03`l?00203dm?@060492@P11@D40?clo03hn?P10@400?3`l
0P0n?Sh01@0k>c/0?Cdm03`l?011@D40@d=30080@41000/0?3`l03hn?P0m?Cd0@41004=3@`12@T80
?Cdm03`l?014A4@0>c/k03hn?P0203dm?@0603Ph>00n?Sh0?3`l03`l?00n?Sh0>c/k0`0l?3`06P0m
?Cd0?clo03`l?011@D40@41003/k>`0j>SX0>3Ph03Xj>P0i>CT0@D5103Xj>P0k>c/0?3`l03Xj>P0h
>3P0>CTi03dm?@0j>SX0=SHf03Xj>P0i>CT0?3`l03Xj>P0m?Cd0@4100P0o?cl03011@D40?3`l03hn
?P13@d<0?Cdm0451@@14A4@0@D5103Ph>00o?cl0>SXj0410@080?Cdm00X0?3`l03Ti>@0j>SX0?Cdm
03hn?P0k>c/0@41003/k>`0l?3`0@4100P0l?3`0300m?Cd0@41003hn?P0k>c/0@41005YJFP1_Kfl0
PH610820P01`L700BTY:03`l?080@41000/0CTi>04=3@`0l?3`0ADE503dm?@13@d<0ATI604m?C`1K
Fe/0IFEU07inOP020:^[Z`030:RXZ02IVIT0SXj>0080R8R800h0KVi^05IFEP13@d<0@41003dm?@0o
?cl0?3`l03dm?@11@D40?clo03`l?00m?Cd0?3`l03hn?P80?3`l0P0m?Cd02@0l?3`0?Cdm03Ti>@14
A4@0@D5103lo?`10@400?Shn0451@@0204U9B@0X0492@P14A4@0AdM704E5A@17AdL0BTY:05IFEP1V
IVH0LW9b07emO@27QhL0UYJF09RHV02GUiL0X:2P0;2`/02l_;`0cLg=0=gMg@3EeMD0bLW90;^k^`2Q
XJ40KVi^06MWI`20P800V9RH09BDU01kNg/0NWYj06e]K@1OGel0J6QX07inOP1lO7`0UYJF0;Fe]@2f
][H0ZZZZ0:NWY`80UiNG03D0QXJ6069RHP1FEUH0Kfm_0::RXP2XZ:P0R8R8069RHP1PH600MgMg09ZJ
VP2YZJT0_kno0;Bd]02SXj<0OGem071`L01jNWX0SXj>0:b/[02d];@0f][J0<W9b@2^[Zh0^KVi0;bl
_02[Zj/0ZJVY0<G5a@37alL0^[Zj09fMW@1TI6@0BTY:04U9B@1QHF40PX:209JFUP2>SXh0Cdm?03Hf
=P0m?Cd0@4100451@@17AdL0>c/k0410@01hN7P0OGem03/k>`0j>SX0=cLg03Xj>P0203Ph>00703Ti
>@0g=cL0>CTi03Lg=`0e=CD0=cLg03Ph>00203Hf=P090410@00i>CT0>SXj03Lg=`0f=SH0=CDe03Hf
=P0g=cL0>3Ph00gooooo000@ooooo`0M0<;2`P2o_kl0_;bl0;Bd]02[Zj/0ZZZZ0;no_`3?cll0bLW9
0;Ng]`2CTi<0MgMg05YJFP1@D500Lg=c08j>SP2][Jd0^KVi0;Ng]`2`/;00Zj^[09>CT`1cLg<0Jf][
05ADE019BDT0B4Q804Y:BP17AdL00P1;Bd/01@16ATH0B4Q804M7A`1:BTX0A4A40080AdM700l0ATI6
0492@P13@d<0ADE504=3@`14A4@0ATI604M7A`14A4@0?clo04E5A@13@d<0@D5103lo?`11@D400P13
@d<01P12@T80@D5104A4A011@D40ADE504A4A080@41001D0@d=30492@P0m?Cd0@D5103`l?013@d<0
@D5104=3@`16ATH0@T9204M7A`12@T80?clo0492@P10@400AdM70410@013@d<0@D5103lo?`11@D40
0P0m?Cd02P0l?3`0>c/k03`l?00n?Sh0>c/k03hn?P0o?cl0A4A403dm?@10@4020492@P0803dm?@0n
?Sh0@d=303dm?@0n?Sh0@D5103dm?@0o?cl303hn?P0C03`l?00k>c/0?Cdm03hn?P0l?3`0@41003/k
>`0h>3P0>c/k0451@@0m?Cd0?clo03`l?00m?Cd0?3`l03/k>`0o?cl0@d=303dm?@0203`l?00603Xj
>P0l?3`0@D510451@@10@400?Shn100l?3`303/k>`80>CTi00<0>c/k03`l?00n?Sh00P0o?cl00`0n
?Sh0@D5103hn?P020410@080?Cdm00D0>c/k0451@@0n?Sh0@T920451@@0204A4A00903lo?`10@400
@41003hn?P11@D40?clo04=3@`10@400?clo0080@4100`0n?Sh04@0m?Cd0?Shn03lo?`0l?3`0@410
03hn?P10@400@d=303lo?`13@d<0@41004M7A`13@d<0?Shn0410@00o?cl0?Cdm0080@41000H0ADE5
0451@@0k>c/0>c/k03dm?@12@T8203lo?`0703/k>`0m?Cd0?Cdm03`l?00i>CT0?3`l03/k>`0203`l
?00503hn?P0l?3`0>3Ph03/k>`0n?Sh00P0l?3`203/k>`0303dm?@11@D40@T920080?clo00H0@410
03dm?@0k>c/0?Shn03`l?010@40203`l?0090451@@0n?Sh0?clo03dm?@0j>SX0?Shn0451@@0h>3P0
=SHf0080>3Ph00L0>SXj03Ti>@0j>SX0>SXj03`l?00h>3P0>SXj0080>3Ph00`0>CTi03Lg=`0m?Cd0
?Cdm04=3@`0g=cL0>3Ph03hn?P0o?cl0>SXj03lo?`0j>SX203dm?@0604=3@`0i>CT0?3`l03Xj>P0h
>3P0>SXj0P0n?Sh30410@080?Cdm01H0>3Ph0492@P10@400@4100492@P0m?Cd0?3`l03dm?@0n?Sh0
>SXj03hn?P1?Cdl0Hf=S07EeM@1dM7@0KVi^05mOG`1BDU80ATI603hn?P11@D40?Cdm0P0n?Sh05@17
AdL0?Shn03dm?@10@400?Cdm04];B`1=CDd0Hf=S08b<S02VYZH0bl_;0<C4a02ZZZX0VYZJ07AdM01D
E5@0@T9203lo?`10@400?3`l03/k>`0203`l?00V0410@00l?3`0?Shn03hn?P0k>c/0>SXj03hn?P0l
?3`0?Shn03`l?00k>c/0>SXj03hn?P10@400?Cdm0492@P0l?3`0?clo0451@@10@400@T9203`l?013
@d<0ATI604Q8B01<C4`0CTi>04m?C`1BDU80HF5Q06e]K@1dM7@0PX:209:BTP2TY:@0];Bd0<;2`P35
aLD20<c<c0130=GEe@3Bd]80][Jf07alO01aLG40MGEe07moO`2=SHd0TY:B09jNWP2LW9`0QhN709ZJ
VP2b/[80^KVi0:n_[`2d];@0/k>c09bLW02n_[h0b/[:0=_Kf`3Ph>00h^;R0=kNgP3Ti>@0inOW0=SH
f02f][H0TI6A06YZJP2WYjL0XJ6Q0;no_`33`l<0_Kfm0;Rh^02[Zj/0aLG50;no_`2h^;P0X:2P08b<
S027QhL0K6a/051@D01HF5P0N7Qh0861P@2GUiL0WIfM0:f][@2o_kl0`<300:ZZZP2`/;00^[Zj0<?3
``2k^k/0T92@07IfMP1JFUX0@d=304M7A`1_Kfl0QhN705ADE00203`l?00603/k>`13@d<0DE5A09JF
UP2ZZZX0H61P0P0i>CT00`0j>SX0>CTi03Ph>00303Lg=`80>CTi00h0<S8b03/k>`0n?Sh0?3`l03Ti
>@0g=cL0>CTi04E5A@0j>SX0=CDe03Hf=P0g=cL0>3Ph03Ti>@gooooo000@ooooo`0I09>CT`2OWil0
YjNW0<_;b`2XZ:P0Ng]k07moO`2^[Zh0dM7A0<;2`P2LW9`0T92@08V9R@1TI6@0GEeM055AD@1IFET0
L71`08>3P`1lO7`0Ph>309NGU`2TY:@0Vi^K07EeM@0206MWI`0904M7A`18B4P0Fe]K051@D016ATH0
B4Q804Y:BP1HF5P0BTY:0080CDe=0P16ATH204U9B@80B4Q80P16ATH204A4A0080492@P18B4P0CDe=
04E5A@13@d<0A4A403lo?`13@d<204A4A0060451@@14A4@0@d=304=3@`0n?Sh0?clo0P14A4@03@15
ADD0@41003hn?P13@d<0@T9204U9B@14A4@0ATI604E5A@0o?cl0@T9204E5A@11@D400P12@T802P14
A4@0@41003hn?P10@400>SXj03`l?00k>c/0?Cdm03lo?`0j>SX403`l?00903lo?`0l?3`0@41003lo
?`0j>SX0@41003lo?`0n?Sh0?Cdm0080@41000/0?clo03hn?P0k>c/0>CTi03`l?00m?Cd0>SXj03`l
?00m?Cd0>CTi03/k>`0303Xj>P0303lo?`0l?3`0?Shn0080?Cdm00/0?clo0492@P11@D40?clo03dm
?@0j>SX0>CTi03`l?00m?Cd0?3`l03/k>`0303Xj>P0@03hn?P0l?3`0?3`l03`l?00j>SX0>c/k03Ph
>00g=cL0>SXj03`l?00n?Sh0?Cdm03lo?`0l?3`0?Shn0451@@80?Cdm0P0l?3`02@10@400@D510451
@@10@400?Cdm03Xj>P0l?3`0@D5103hn?P020410@00303/k>`0l?3`0?3`l00<0?Cdm00@0@41003lo
?`0l?3`0?3`l0P10@400200h>3P0?Shn03lo?`17AdL0@41004I6AP11@D40?clo0P0m?Cd20451@@04
03`l?00n?Sh0?3`l03/k>`80?clo01<0?Cdm03/k>`0j>SX0?Cdm0451@@0m?Cd0>c/k03Ti>@0h>3P0
>c/k03Lg=`0h>3P0>c/k03Hf=P0i>CT0>3Ph03dm?@12@T80?3`l0080>SXj01<0>CTi03`l?012@T80
@D5104A4A00l?3`0?Cdm03Ph>00k>c/0>SXj03dm?@0n?Sh0A4A403`l?010@400=cLg03/k>`0n?Sh0
?3`l0080>CTi00P0>c/k03Ph>00h>3P0>SXj03Ti>@0j>SX0=SHf03Ph>080>c/k0P0h>3P203Xj>P<0
>3Ph00l0>SXj03dm?@0g=cL0>3Ph03dm?@0i>CT0>SXj03`l?012@T80@41003/k>`0n?Sh0>CTi0451
@@0d=3@00P0i>CT00`0m?Cd0>SXj03lo?`0203hn?P0I03/k>`0j>SX0?Shn03dm?@0o?cl0>CTi03/k
>`0i>CT0>c/k03lo?`1IFET0KVi^08F5Q@1gMgL0IfMW04e=C@12@T80?3`l03hn?P0l?3`0>3Ph03Xj
>P0l?3`0>c/k03hn?P0203/k>`0<03dm?@0j>SX0?Shn04M7A`1JFUX0H61P071`L01aLG40IFEU05IF
EP18B4P0ADE50P0o?cl00`11@D40?Cdm03Xj>P0203Xj>P80?Cdm00/0>CTi03Xj>P12@T80?Cdm03Ph
>00l?3`0?Cdm03Ph>00k>c/0?Shn03/k>`0203dm?@0;03lo?`14A4@0Cdm?05iNGP1eMGD0PX:207Yj
NP20P800W9bL0:NWY`2XZ:P00P2/[:`0H02b/[80/k>c0;:b/P2h^;P0_[jn0;fm_@32`/80alO70<W9
b@32`/80`<300;Jf]P2a/K40[jn_0:NWY`2DU9@0S8b<08R8R021PH40L71`06a/K01YJFT0JVYZ06e]
K@1lO7`0R8R80:>SX`2TY:@0XJ6Q0:NWY`2_[jl0_;bl0<?3``2e]KD0YjNW0:f][@2n_[h0^k^k0<[:
bP3EeMD0emOG0<W9b@38b<P0_kno0<;2`P2YZJT0];Bd0;Zj^P2VYZH0U9BD0:>SX`2l_;`0WIfM092@
T02YZJT0[Zj^0;Fe]@2b/[80[:b/09bLW02b/[80^KVi0:FUY@2>SXh0[Zj^0<G5a@2][Jd0^k^k0;Rh
^03;bl/0aLG50<;2`P2ZZZX0Y:BT0:b/[02k^k/0/k>c092@T02HV9P0NWYj09^KV`2l_;`0KFe]04e=
C@0j>SX0>c/k03Ti>@1:BTX0EeMG04m?C`0o?cl0>SXj03Ph>00k>c/0>SXj03Ti>@80=cLg00P0?Shn
05UIF@1]KFd0GEeM04Y:BP0i>CT0=CDe03Ph>0<0=cLg1@0f=SH=ooooo`004?ooool0901fMWH0Ng]k
07emO@2<S8`0ZJVY0:BTY02CTi<0WYjN0;Ng]`2@T900HV9R05mOG`1XJ6P0LG5a07moO`1]KFd0E5AD
05eMG@1[Jf/0L71`08f=S@37alL0bl_;0:JVYP2:RXX0KVi^07alO01kNg/0H61P04e=C@19BDT0B4Q8
04Y:BP1?Cdl0C4a<051@D080BTY:00@0B4Q804A4A016ATH0CDe=0P18B4P03P17AdL0A4A404=3@`18
B4P0@41004Y:BP1<C4`0@D5104A4A011@D40@d=30451@@10@400@D510P17AdL0100o?cl0>c/k0492
@P0l?3`203Ti>@0@0492@P0o?cl0?3`l03hn?P11@D40B4Q804A4A018B4P0ATI603dm?@10@400?3`l
04=3@`11@D40@T920410@080?clo01X0?Cdm03Ti>@0m?Cd0@T9203/k>`0o?cl0>CTi03`l?016ATH0
?Shn03/k>`0h>3P0?Shn03lo?`0n?Sh0>c/k03`l?011@D40?Cdm03/k>`11@D40>CTi0492@P0n?Sh0
>CTi03dm?@80?clo00D0>SXj03Lg=`0g=cL0?Shn03lo?`0203/k>`0403Xj>P10@400?Cdm03`l?0<0
?Cdm00h0>SXj03/k>`0l?3`0?3`l03dm?@0k>c/0?3`l03Ph>00j>SX0?3`l03dm?@0j>SX0>CTi03/k
>`80>3Ph00T0>SXj03Hf=P0h>3P0>SXj03/k>`0l?3`0?Cdm03`l?00k>c/00`0n?Sh01@0o?cl0>c/k
03/k>`11@D40?3`l0080@D5100@0?Cdm0410@00k>c/0>c/k0P0n?Sh03@0i>CT0>c/k03hn?P14A4@0
?clo03Xj>P0n?Sh0?3`l0410@00m?Cd0?clo0410@00l?3`00P0k>c/0600l?3`0>c/k03lo?`16ATH0
@D510410@00n?Sh0@D5103`l?00j>SX0?Shn03`l?011@D40?Shn03/k>`0j>SX0?Shn0410@00n?Sh0
?3`l03Ph>00m?Cd0@4100451@@80>CTi0140>SXj03hn?P0k>c/0>c/k03Ti>@0h>3P0>c/k0410@00m
?Cd0?3`l03Ph>00k>c/0?Cdm03/k>`0i>CT0?clo0451@@0203dm?@0>03/k>`0h>3P0?Shn03Xj>P0m
?Cd0?3`l03Xj>P0l?3`0>SXj03Lg=`0i>CT0@d=30451@@10@40303Xj>P0803Ph>00j>SX0>SXj03/k
>`0l?3`0>SXj03Ti>@0m?Cd203/k>`0;03Xj>P0m?Cd0>SXj03lo?`10@400>CTi03Xj>P0n?Sh0@D51
03Xj>P0k>c/00P0l?3`02`0j>SX0>CTi03hn?P0k>c/0>SXj03Ti>@0f=SH0?Shn03dm?@0j>SX0?Shn
0080@4100`0l?3`04@0o?cl0?3`l0410@011@D40?clo04=3@`1EEED0LG5a07]kN`1WIfL0Cdm?03dm
?@0o?cl0@41004A4A00l?3`0@d=30080>c/k01L0?Cdm03hn?P0i>CT0>SXj03dm?@0i>CT0?Shn05IF
EP1^KVh0PX:207QhN01JFUX0ATI604U9B@0o?cl0@41003`l?012@T80?Cdm0451@@0i>CT0>c/k03dm
?@020492@P0303/k>`0i>CT0=SHf0080?Shn02/0ATI603Xj>P0h>3P0@T9203/k>`0h>3P0?clo03hn
?P18B4P0GUiN07YjNP2VYZH0[:b/0:f][@2ZZZX0/k>c0:JVYP2MWId0YjNW0:ZZZP2HV9P0QHF5079b
LP1KFe/0GemO05ADE01BDU80CDe=04i>CP1KFe/0Hf=S06e]K@1dM7@0Q8B40820P02>SXh0UYJF08B4
Q01QHF40EUIF04];B`1BDU80D51@0080De=C0500FEUI04Y:BP13@d<0@D5104E5A@1:BTX0CDe=04];
B`1=CDd0M7Ad09^KV`35aLD0emOG0<S8b02TY:@0RXZ:09VIV@2e]KD0/[:b0:JVYP2?Shl0M7Ad06IV
IP1RHV80JVYZ07UiN@2IVIT0clo?0=SHf031`L40S8b<07]kN`24Q8@0T92@09nOW`3EeMD0fMWI0;>c
/`2/[:`0`L710:2PX02ZZZX0^k^k0<C4a037alL0aLG50;>c/`2b/[80/;2`0;Ng]`2o_kl0Y:BT08N7
Q`2?Shl0U9BD0:FUY@2j^[X0d=3@0=WIf@3Lg=`0bLW909BDU01=CDd0?3`l03Ti>@12@T80AdM706IV
IP1bLW80MWIf05]KF`0n?Sh0=CDe03Ph>00j>SX0Fe]K08n?S`1oOgl0LW9b03lo?`80=cLg00X0>3Ph
03Lg=`0c<c<0=CDe03@d=00e=CD0=3@d03Ph>00d=3@0>3Ph3Oooool0013ooooo02/0IFEU06e]K@23
Ph<0WinO0;Bd]03;bl/0[Zj^071`L01eMGD0H61P05QHF01RHV80SXj>0:NWY`2^[Zh0Ti>C07YjNP1a
LG40MgMg08:2PP28R8P0W9bL0:BTY023Ph<0QHF507=cL`2@T900][Jf0;Zj^P2c/k<0TY:B08b<S02H
V9P0Xj>S09^KV`1fMWH0IfMW04Y:BP1@D500A4A404Q8B01<C4`0ADE50080A4A400@0Bd];04I6AP17
AdL0BDU90P14A4@07P16ATH0@D510410@013@d<0A4A40492@P0n?Sh0ATI60451@@10@400?Shn0410
@00o?cl0BDU903hn?P11@D40B4Q804];B`14A4@0?3`l03lo?`12@T80@d=304M7A`13@d<0@D5103hn
?P12@T80@41003lo?`80@D5100H0A4A40451@@0k>c/0?Shn04I6AP0o?cl203`l?00:03/k>`0l?3`0
?3`l03hn?P0k>c/0?clo03`l?00n?Sh0?Cdm03`l?080?clo00T0?Cdm0492@P11@D40@d=303hn?P0i
>CT0=cLg03Ph>00m?Cd00P0l?3`01P0k>c/0?Cdm03hn?P0m?Cd0?Shn03Xj>P<0?3`l00@0>c/k03dm
?@0l?3`0?Shn0P0m?Cd0100o?cl0?Cdm03Xj>P0m?Cd203`l?00503/k>`0j>SX0>3Ph03Ti>@0k>c/0
0P0l?3`01P0j>SX0?3`l03/k>`0k>c/0>CTi03lo?`80@41000<0@d=303/k>`0n?Sh00P10@4001P0l
?3`0>c/k0451@@0m?Cd0@4100451@@80?clo00<0?Cdm0492@P0k>c/00P0k>c/04`0l?3`0?Cdm03hn
?P0n?Sh0A4A40451@@0n?Sh0>CTi03/k>`0m?Cd0?3`l03/k>`0l?3`0?clo04=3@`12@T80?clo03`l
?00i>CT00`0l?3`0600m?Cd0A4A40451@@0k>c/0?Cdm03/k>`0l?3`0>CTi03`l?00m?Cd0?Shn03lo
?`0k>c/0>CTi03`l?00o?cl0?Shn03lo?`0l?3`0?Cdm03hn?P0o?cl0@41003lo?`80?Shn00L0>SXj
03/k>`0l?3`0@41003/k>`0l?3`0?Shn0080@D5100D0?3`l03/k>`0k>c/0>CTi0410@0020451@@0=
03lo?`0j>SX0>CTi03dm?@16ATH0D51@04Y:BP0k>c/0>CTi03Ph>00k>c/0>SXj03Lg=`0303Ti>@0P
03Xj>P0l?3`0=cLg03/k>`0j>SX0>c/k03lo?`0n?Sh0EEEE05=CD`11@D40?Cdm03Xj>P0k>c/0?clo
04I6AP12@T80?Shn03/k>`0m?Cd0?Shn03lo?`0n?Sh0>c/k03Xj>P0l?3`0>CTi03/k>`0l?3`0>CTi
03dm?@0n?Sh203`l?00303Ti>@0j>SX0>SXj0080?clo00P0?Cdm04a<C01>CTh0BDU90492@P0o?cl0
@41003Ti>@80?Cdm00@0?3`l03Lg=`0n?Sh0>SXj0P0l?3`02`0j>SX0?Cdm0410@013@d<0L71`08F5
Q@1bLW80HF5Q04e=C@16ATH0@T920080?Shn00@0>SXj03dm?@11@D40@T920P0n?Sh00`0l?3`0>c/k
03hn?P0203hn?P0L03Xj>P10@400?Cdm03lo?`0n?Sh0?3`l03Ph>00n?Sh0@41003hn?P0o?cl0De=C
071`L02>SXh0/;2`0;:b/P2OWil0P820079bLP1RHV80HF5Q05ADE01;Bd/0B4Q804=3@`14A4@0@T92
03lo?`80@T9200/0?3`l04A4A010@400AdM705EEE@1TI6@0PH6109:BTP2LW9`0YZJV09>CT`0209RH
V00R096AT@28R8P0OGem08F5Q@28R8P0UiNG0:VYZ@2[Zj/0VIVI08Z:RP23Ph<0R8R808:2PP2<S8`0
Q8B408b<S02HV9P0XZ:R0:j^[P2n_[h0c<c<0=;BdP33`l<0/k>c0;jn_P3?cll0b<S80<[:bP37alL0
`/;20:^[Z`2OWil0V9RH0:6QX@80_[jn00`0]kNg092@T01jNWX0U9BD0:f][@2m_Kd0c/k>0=OGe`34
a<@0^KVi0<K6aP2j^[X20;Rh^0040=CDe03GemL0h>3P0<k>cP80`L7101h0YJFU09fMW@2EUID0QhN7
08F5Q@1nOWh0Ti>C09RHV02NWYh0_[jn0=3@d034a<@0_kno0;6a/@2HV9P0TY:B0:NWY`2l_;`0b/[:
0<k>cP3<c<`0aLG50:b/[01cLg<0IFEU07]kN`1PH600FEUI0410@00i>CT203/k>`0303Xj>P0g=cL0
>c/k0080=cLg00<0?Cdm03Hf=P0h>3P00`0g=cL=ooooo`004?ooool2055AD@0U05EEE@1RHV80J6QX
06e]K@1NGUh0HV9R09NGU`2TY:@0][Jf0;jn_P3<c<`0`<300:b/[03@d=00dM7A0<_;b`2l_;`0YZJV
0:>SX`2:RXX0RHV907QhN01YJFT0HV9R06ATI01kNg/0Q8B407=cL`1/K6`0Q8B408Z:RP23Ph<0VYZJ
09bLW02ATI40I6AT05QHF00204U9B@0;04e=C@1/K6`0NWYj07inOP29RHT0TI6A08B4Q01aLG40M7Ad
061PH018B4P00P17AdL05P11@D40@T920492@P15ADD0@d=304I6AP10@400?Shn04=3@`11@D40AdM7
04E5A@10@400Fe]K04Q8B012@T80?clo04A4A011@D40?Cdm04E5A@17AdL203dm?@0403hn?P11@D40
?3`l0451@@80?Shn00H0@D510492@P0k>c/0?clo0410@00o?cl20451@@0803lo?`0n?Sh0A4A40451
@@10@400?Shn03lo?`10@40203`l?0<0?Shn00H0@41004I6AP0n?Sh0>c/k03Xj>P0l?3`203dm?@08
0410@00o?cl0?3`l03`l?00m?Cd0?clo03`l?010@40203/k>`0303`l?00o?cl0?Shn0080?3`l00@0
>c/k04=3@`17AdL0?Cdm0P0l?3`0100o?cl0?Shn03/k>`0k>c/203Xj>P0<03/k>`0l?3`0>SXj03Xj
>P0k>c/0?Cdm0410@00n?Sh0@T920451@@10@400?Cdm0`0o?cl02`0m?Cd0>c/k0451@@0l?3`0?Cdm
03lo?`10@400?Shn03Xj>P15ADD0@T920080?clo00@0?Cdm03lo?`0k>c/0?Shn0P11@D402P0o?cl0
?Shn03`l?00k>c/0?3`l03hn?P0m?Cd0?clo04A4A011@D4203lo?`0603/k>`0n?Sh0A4A403`l?014
A4@0>c/k0P0l?3`203hn?P0503/k>`0m?Cd0?Shn03`l?00m?Cd00P0k>c/00`0j>SX0@41003hn?P03
0410@00303/k>`0o?cl0?clo0080>c/k00@0?Shn0410@00m?Cd0?3`l0P0k>c/02`0l?3`0?Cdm03dm
?@0k>c/0?Cdm03hn?P0l?3`0>SXj03Ti>@0k>c/0>CTi0080?3`l00P0@41004A4A013@d<0?Shn03Xj
>P0l?3`0?Shn03Xj>P80>3Ph02H0>CTi03Ph>00i>CT0?3`l03dm?@0k>c/0?clo03Ti>@0l?3`0>SXj
03hn?P14A4@0BTY:05MGE`0o?cl0@41003/k>`1@D500HF5Q05=CD`1@D500>SXj03/k>`0l?3`0@410
03Ph>00l?3`0?Shn03Xj>P0h>3P0?Cdm03/k>`0i>CT0>SXj03/k>`0m?Cd0?Shn03/k>`80>SXj00D0
>3Ph03/k>`0m?Cd0>c/k03Xj>P0203`l?00303hn?P0h>3P0>3Ph0080?Shn00@0?Cdm03lo?`0l?3`0
?3`l0P11@D403`0m?Cd0@D5103`l?013@d<0DU9B05mOG`1CDe<0AdM703/k>`0m?Cd0@41004=3@`0o
?cl0@41003`l?00203hn?P080410@00n?Sh0@d=304=3@`0l?3`0>SXj0410@012@T8203/k>`0A03lo
?`10@400>c/k03dm?@0l?3`0>3Ph04A4A01>CTh0GUiN07MgM`21PH40NGUi06MWI`1KFe/0CDe=0451
@@0n?Sh00P0m?Cd0100o?cl0?3`l03hn?P0m?Cd30410@00304U9B@1BDU80IFEU0080RHV902L0TI6A
09jNWP2XZ:P0ZZZZ0;Rh^035aLD0_;bl0;Fe]@2WYjL0]KFe0;bl_02g]kL0Z:RX07]kN`1BDU80Bd];
05EEE@1PH600J6QX071`L021PH40W9bL09nOW`2NWYh0[Zj^0;Bd]02e]KD0/k>c0:BTY02HV9P0WYjN
0;:b/P30`<00_;bl0;Ng]`2VYZH0UYJF09BDU02^[Zh00P2i^KT02P2g]kL0_;bl0:f][@2OWil0WYjN
09JFUP2JVYX0WIfM09jNWP2/[:`20<71`@0:0;Rh^02c/k<0_;bl0<S8b03>c/h0b/[:0<O7a`32`/80
bl_;0<O7a`80dM7A01X0g=cL0>7Qh@3MgMd0a<C40;:b/P2ATI40KFe]05UIF@1hN7P0Ph>308Z:RP2N
WYh0Zj^[0:2PX02DU9@0VIVI0:j^[P2k^k/0a/K60=KFeP3=cLd0]kNg0<?3``30`<00Z:RX06YZJP80
E5AD00@0GUiN06a/K01JFUX0ADE50P0n?Sh02`0h>3P0>CTi03dm?@0i>CT0>3Ph03Lg=`10@400@T92
03Xj>P0k>c/0>SXj00gooooo000@ooooo`0m05]KF`1NGUh0EUIF05MGE`1MGEd0IVIV05eMG@1FEUH0
DE5A05EEE@1XJ6P0SXj>0;no_`31`L40WYjN08F5Q@2LW9`0]KFe0<30`033`l<0cLg=0<71`@2l_;`0
^[Zj0<W9b@33`l<0[jn_0;Jf]P2][Jd0UYJF08^;R`1lO7`0JFUY071`L02FUYH0^;Rh0:^[Z`2BTY80
PH6108R8R02HV9P0WinO0<O7a`3Bd]80^;Rh0:f][@2d];@0VYZJ06QXJ01>CTh0BDU904E5A@13@d<0
?clo04E5A@17AdL0ADE50451@@14A4@0@D5103lo?`020492@P0?0410@013@d<0?3`l0410@013@d<0
A4A40451@@0o?cl0@41003dm?@10@400?clo0492@P0l?3`0?Cdm0080?Shn0P0o?cl01P0n?Sh0?clo
0451@@0m?Cd0>SXj03lo?`80?3`l00d0?Cdm03lo?`0o?cl0?Cdm03hn?P0o?cl0?Shn03/k>`0n?Sh0
?Cdm03lo?`0m?Cd0?3`l0080?Shn00D0?3`l0492@P0o?cl0?Cdm03hn?P0203lo?`0803`l?010@400
?clo03dm?@0l?3`0>SXj03hn?P0m?Cd303hn?P0503`l?00n?Sh0?Cdm03dm?@0n?Sh00P0l?3`01P10
@400>SXj03hn?P10@400?clo03`l?0<0>c/k0P0h>3P203`l?00803Xj>P0i>CT0>SXj03dm?@0o?cl0
@T920410@00o?cl203hn?P80?clo00D0?3`l03Ph>00n?Sh0>SXj03/k>`0203hn?P0=0410@00k>c/0
>c/k03hn?P0l?3`0A4A403hn?P0m?Cd0?Shn03lo?`0k>c/0?3`l03Xj>P0203hn?P80@41001/0?Shn
03dm?@0l?3`0?clo0410@013@d<0?Cdm03hn?P11@D40>c/k03`l?01JFUX0?clo03Xj>P0n?Sh0?3`l
03/k>`0j>SX0?clo03hn?P0l?3`0?Cdm0492@P14A4@0?Cdm03Xj>P0h>3P00P0k>c/0200n?Sh0>SXj
03`l?00i>CT0?Shn03`l?00m?Cd0@4100P0n?Sh00`0o?cl0?3`l03Ph>00203Ti>@0303/k>`0m?Cd0
?3`l0080?Shn00<0>c/k03Xj>P0n?Sh00P0j>SX01`12@T80>c/k03/k>`0l?3`0?Shn03Ti>@0j>SX0
0`0i>CT0300k>c/0?Shn03`l?010@400@D5103dm?@0l?3`0?clo03hn?P0j>SX0?Cdm0410@080?Cdm
0200@D5104m?C`1/K6`0QXJ605MGE`16ATH0?clo03hn?P0k>c/0>3Ph03Ti>@0g=cL0?3`l03hn?P0l
?3`0?Cdm0410@00h>3P0>SXj03dm?@0i>CT0?Cdm03`l?00k>c/0?Cdm03hn?P0k>c/0?3`l03/k>`0l
?3`0?Shn03Ph>080?3`l00P0>CTi03hn?P12@T80@T9204E5A@0n?Sh0?Cdm03hn?P80>3Ph00d0?Shn
03dm?@11@D40?Shn03dm?@0k>c/0ATI60410@00l?3`0?Shn0492@P10@400>SXj0080?3`l01T0@410
03Xj>P0l?3`0?3`l03Xj>P0k>c/0?Shn059BDP1@D500>c/k0410@00k>c/0?Shn0410@012@T80?Shn
0492@P19BDT0E5AD05UIF@1KFe/0EEEE04I6AP0l?3`0@D510080>c/k03X0@D5103hn?P0m?Cd0@D51
04A4A01:BTX0GEeM06EUI@1mOGd0S8b<09>CT`2BTY80UYJF0:b/[030`<00`l?30<;2`P37alL0][Jf
0:RXZ02EUID0UYJF0::RXP2XZ:P0YZJV0:RXZ02VYZH0X:2P09ZJVP2][Jd0/;2`0:b/[027QhL0OGem
07=cL`25QHD0SHf=0;Fe]@35aLD0b/[:0<;2`P2EUID0O7al06UYJ@1lO7`0Xj>S0;bl_03<c<`0f=SH
0=kNgP3Kfm/0g=cL0=kNgP3Lg=`0gmoO0>;RhP3Ogml0g]kN0`3Kfm/0@@3IfMT0b/[:0<K6aP2c/k<0
[:b/0:RXZ02a/K40^[Zj0<W9b@3=cLd0dm?C0=[JfP3Lg=`0f=SH0=KFeP3=cLd0a/K60;jn_P2d];@0
^;Rh0:b/[02e]KD0b<S80<o?c`3;bl/0a<C40:n_[`2UYJD0`<300;jn_P2WYjL0R8R807alO02BTY80
YjNW0:>SX`2ZZZX0_Kfm0;Zj^P2PX:00XZ:R0;>c/`2f][H0^KVi0<;2`P2b/[80Rh^;0<O7a`3Bd]80
alO70;Rh^030`<00YJFU08^;R`1iNGT0EEEE03lo?`0j>SX0>3Ph03Xj>P0k>c/0?Cdm04=3@`14A4@0
?Shn00gooooo000@ooooo`0;04i>CP1ADE40DU9B05ADE01EEED0EeMG05=CD`1GEeL0EUIF05QHF01D
E5@00P1PH6008`1`L700QHF508f=S@1JFUX0E5AD059BDP1TI6@0UIFE0<o?c`36a/H0/[:b0:>SX`2X
Z:P0VYZJ08N7Q`2MWId0_Kfm0<g=c@38b<P0_Kfm07]kN`1MGEd0Hf=S09VIV@2_[jl0/[:b0:n_[`2o
_kl0bLW90;6a/@2d];@0_Kfm0;Vi^@2d];@0XZ:R0080QHF500<0SHf=07QhN01IFET00P15ADD204A4
A0060492@P11@D40@D510410@00n?Sh0A4A40P17AdL05@10@400@d=30492@P15ADD0@D510410@012
@T80?clo0492@P0k>c/0@D5103lo?`10@400?clo03`l?010@400@D510410@00n?Sh0@T920410@002
03`l?00503/k>`0n?Sh0?clo03hn?P0k>c/00P0m?Cd01@12@T80ADE50410@00l?3`0>CTi0080@410
0`0o?cl02@10@400?Cdm03lo?`0n?Sh0>CTi03Xj>P10@400?clo0451@@0303dm?@0303Xj>P0l?3`0
>c/k0080?Cdm00@0?3`l03Ti>@0j>SX0?3`l0P0m?Cd203hn?P0603Xj>P0k>c/0?Shn03dm?@0k>c/0
?Cdm0P0n?Sh0100o?cl0?3`l03Ti>@0n?Sh203Ph>00:03Ti>@0h>3P0>c/k03/k>`0m?Cd0?clo03dm
?@0j>SX0?Shn03lo?`80?Shn00h0>3Ph03/k>`0k>c/0>SXj03dm?@0l?3`0@D510410@00n?Sh0?Cdm
0492@P14A4@0?Cdm03Ph>080?Cdm0P0k>c/0100o?cl0?Shn03`l?00k>c/203dm?@80>c/k00X0?3`l
03dm?@0m?Cd0>c/k03dm?@0n?Sh0?clo03dm?@0n?Sh0?Cdm0`0k>c/0100m?Cd0>c/k03dm?@0j>SX3
03`l?00803dm?@0k>c/0>CTi0410@011@D40>CTi03Hf=P0h>3P203Ti>@80=cLg0P0l?3`0100i>CT0
?Cdm04E5A@15ADD203Ti>@80>c/k00<0?Cdm03lo?`0i>CT00P0l?3`01@0j>SX0?3`l0410@01>CTh0
C4a<0080>CTi01d0?3`l03/k>`0j>SX0>SXj03Hf=P0k>c/0@41005]KF`1ADE40@D5103`l?00n?Sh0
?3`l03Ti>@10@400?3`l03Ph>00j>SX0>3Ph0492@P1;Bd/0GEeM05QHF016ATH0>c/k03Xj>P0k>c/0
>CTi03dm?@0203Ph>00603Ti>@0j>SX0=cLg03Ti>@0k>c/0?3`l0P0h>3P203Ti>@0903Xj>P0i>CT0
>CTi03/k>`0m?Cd0?Shn03Xj>P0n?Sh0>3Ph0080>c/k00T0>SXj03dm?@0h>3P0?clo0410@00m?Cd0
>c/k03`l?00k>c/00P0m?Cd08P0k>c/0@D510451@@0l?3`0?Shn03/k>`0j>SX0@41003hn?P14A4@0
?Shn03/k>`0i>CT0?Cdm03Xj>P0f=SH0?3`l03lo?`0i>CT0>SXj0451@@0k>c/0?3`l03dm?@0o?cl0
@D5104Q8B01ADE40GUiN07AdM01_Kfl0KFe]05mOG`1@D50204=3@`0703dm?@10@400?Shn0451@@0l
?3`0>c/k03dm?@0203hn?P0W04a<C02@T900[Jf]0:f][@2e]KD0aLG50;Rh^02b/[80WinO09JFUP2X
Z:P0`l?30=cLg03Ogml0c/k>0;Bd]02WYjL0^;Rh0=SHf03?cll0_Kfm0<;2`P39bLT0];Bd0;2`/02/
[:`0[Jf]0;>c/`2/[:`0WIfM096AT@1lO7`0MGEe06a/K01cLg<0L71`07EeM@23Ph<0UiNG0080XZ:R
00P0VIVI09JFUP2@T900U9BD09RHV02RXZ80YjNW0:j^[P80^[Zj04X0_Kfm0<O7a`36a/H0`l?30<K6
aP3?cll0d=3@0=GEe@3Lg=`0emOG0>3Ph03Ti>@0h^;R0=3@d038b<P0`<300<c<c03Bd]80c/k>0<S8
b03<c<`0c/k>0<[:bP3>c/h0dM7A0=CDe03GemL0d];B0<k>cP2j^[X0UIFE09fMW@2NWYh0][Jf0<c<
c03Fe]H0f][J0=GEe@3Ng]h0hn?S0=oOg`3<c<`0_kno0<;2`P2[Zj/0VIVI0;Bd]03AdM40`/;20;2`
/02WYjL0U9BD08Z:RP2@T900Y:BT0:j^[P3:b/X0e=CD0<k>cP30`<00a/K60<c<c03>c/h0gMgM0;^k
^`2UYJD0RHV908B4Q01iNGT0P82008n?S`30`<00b/[:0:f][@gooooo000@ooooo`0604e=C@1>CTh0
CTi>04e=C@1;Bd/0CDe=0P1@D500?`1:BTX0BDU905=CD`1[Jf/0HF5Q059BDP1IFET0L71`06MWI`1C
De<0D51@05IFEP1[Jf/0OGem07=cL`1KFe/0Cdm?04];B`1CDe<0Cdm?04i>CP1PH600PX:209VIV@2`
/;00];Bd0;2`/023Ph<0EEEE06=SH`1`L700KFe]07QhN01gMgL0IFEU05IFEP1RHV80PX:20;Bd]03=
cLd0alO709FEU@1TI6@0PH610:BTY02?Shl0MGEe05UIF@1?Cdl0BTY:04E5A@10@400A4A404=3@`12
@T80@41003hn?P0l?3`0A4A40492@P16ATH0BDU904=3@`020410@0040451@@0o?cl0@41004=3@`80
@T9200<0?Shn03`l?00n?Sh00P0n?Sh01P11@D40A4A403dm?@0k>c/0?Shn03`l?080?Cdm00D0?3`l
03hn?P0l?3`0>c/k03dm?@0203`l?00P03Xj>P10@400?clo0451@@0k>c/0?Cdm03/k>`0o?cl0@T92
0451@@0n?Sh0@d=304E5A@0o?cl0?Cdm03`l?00n?Sh0?clo03hn?P0o?cl0>c/k03Xj>P0o?cl0?Shn
03`l?00m?Cd0?Shn03dm?@0j>SX0>c/k03Xj>P0l?3`403dm?@0303Xj>P0i>CT0?Cdm00<0?Cdm00P0
@T9203dm?@0j>SX0?Shn03dm?@0o?cl0?Cdm03`l?0<0?clo0180?Shn03dm?@0l?3`0?Cdm03/k>`0j
>SX0@41003`l?010@400?clo04=3@`0m?Cd0>c/k03dm?@11@D40?Shn03/k>`0j>SX203lo?`0703hn
?P0o?cl0@d=30410@00o?cl0?Shn03dm?@0203`l?00<03dm?@0i>CT0@41003lo?`0l?3`0>SXj03hn
?P13@d<0?Shn03Xj>P0o?cl0?3`l0`0k>c/203Ti>@0<03Xj>P0k>c/0?Cdm03`l?00i>CT0>SXj03`l
?00n?Sh0?clo03Ti>@0h>3P0=SHf0P0j>SX0200i>CT0>c/k03lo?`0k>c/0>SXj03`l?00n?Sh0?3`l
0P0j>SX203hn?P0:03Ph>00i>CT0>SXj03lo?`0n?Sh0A4A404U9B@1PH600EEEE04M7A`@0?3`l00/0
>SXj03Ti>@0h>3P0>SXj0451@@1ADE40DU9B051@D012@T80?Cdm03Ti>@0203Ph>00903lo?`0l?3`0
?Shn03hn?P12@T80@D5103Xj>P0f=SH0?Shn0080?3`l00D0>CTi03/k>`0m?Cd0=SHf03Ti>@0203hn
?P0603dm?@0k>c/0@4100410@00n?Sh0?Cdm0`0k>c/203Ti>@0>03`l?00o?cl0@D510492@P0o?cl0
?Cdm03`l?00n?Sh0?clo03hn?P0l?3`0?Cdm03lo?`0m?Cd303/k>`0703`l?00j>SX0>3Ph0410@013
@d<0@41004=3@`0203dm?@0J03Xj>P0o?cl0@4100410@00k>c/0>CTi03`l?011@D40>SXj03`l?00o
?cl0@41003/k>`16ATH0?3`l04=3@`1>CTh0Hf=S07=cL`1iNGT0NWYj071`L01RHV80EEEE04U9B@14
A4@203/k>`0603hn?P0l?3`0@4100451@@0o?cl0>c/k0P0l?3`0@P0o?cl0BDU907IfMP22PX80Ph>3
07]kN`1/K6`0J6QX05aLG01VIVH0MGEe09JFUP2e]KD0_Kfm0=CDe02n_[h0YJFU0:NWY`2;Rh/0OWin
07moO`1RHV80D51@04i>CP1<C4`0D51@071`L02<S8`0WinO0:RXZ02LW9`0Shn?08>3P`2ATI40VYZJ
0:BTY02h^;P0`<300;jn_P39bLT0c<c<0<30`033`l<0`<300;Vi^@2g]kL0_Kfm0;Zj^P34a<@0b<S8
0<;2`P33`l<0`L710<K6aP34a<@0][Jf09RHV02@T900W9bL09fMW@2RXZ80/;2`0;>c/`35aLD0clo?
0=cLg080hN7Q00<0h>3P0>KViP3Ti>@00P3Vi^H01@3WinL0hn?S0=oOg`3Fe]H0clo?0080`L710140
]kNg0:n_[`2ZZZX0WYjN07UiN@1]KFd0[Jf]0=?Cd`3Rh^80h>3P0=SHf03Bd]80`<300;fm_@33`l<0
^[Zj0:BTY0020:JVYP0;0;jn_P3MgMd0j>SX0>SXj03Vi^H0g]kN0<c<c02XZ:P0SHf=05aLG02>SXh0
0P38b<P03`2YZJT0TY:B0;Jf]P3?cll0e]KF0<c<c03EeMD0emOG0=SHf03Fe]H0cLg=0<[:bP3Lg=`0
a<C408^;R`0=ooooo`004?ooool01`1?Cdl0CTi>04m?C`1=CDd0D51@055AD@1BDU800P1<C4`02P1=
CDd0DU9B05aLG01]KFd0LW9b07=cL`21PH40KFe]05ADE01@D502055AD@0805=CD`1?Cdl0CTi>05=C
D`1ADE40GEeM051@D019BDT204e=C@0P051@D01ADE40CTi>05eMG@1SHf<0DE5A04a<C01PH600F5QH
06=SH`1ZJVX0MgMg0820P027QhL0N7Qh06YZJP1iNGT0Zj^[0;Bd]02][Jd0UiNG07moO`1eMGD0];Bd
0<_;b`2m_Kd0[:b/08Z:RP1`L700FUYJ04a<C012@T8303hn?P040451@@0n?Sh0ADE504U9B@80@d=3
00<0A4A40410@012@T800P12@T801@0n?Sh0?clo0451@@11@D40?clo0080?Cdm00<0?clo0410@00m
?Cd00P0m?Cd203hn?P<0?Cdm0P0l?3`03`0i>CT0?3`l0410@00k>c/0?Cdm0410@011@D40?Shn03Ti
>@0l?3`0?Cdm0410@00n?Sh0?Cdm0410@00203lo?`0303dm?@11@D40?Cdm0080?3`l00`0@41003lo
?`0k>c/0?3`l03dm?@0o?cl0?Shn03`l?00n?Sh0>CTi03Xj>P0h>3P203hn?P0303dm?@0k>c/0>c/k
0080>c/k00L0>SXj03/k>`0h>3P0>SXj03dm?@0l?3`0?Cdm00<0?clo01@0?3`l03dm?@0n?Sh0>c/k
0410@00n?Sh0?3`l03Ti>@0j>SX0?3`l03Ti>@0o?cl0?Cdm03lo?`0l?3`0?clo03dm?@0i>CT0?3`l
03dm?@80?Shn01D0@41003lo?`0m?Cd0ADE50410@00o?cl0?Shn0410@00n?Sh0?clo0492@P0k>c/0
@41003hn?P0l?3`0?Shn03`l?00m?Cd0?Shn0410@00o?cl00P0l?3`403Xj>P0703hn?P0l?3`0?Shn
03hn?P0m?Cd0?Shn03Ti>@0203Xj>P80>CTi00D0>c/k03Ti>@0k>c/0>c/k03Ti>@0203Xj>P0403dm
?@0l?3`0?3`l03hn?P80?3`l00<0?Shn03Xj>P0k>c/00P0n?Sh01`19BDT0Bd];04A4A011@D40@d=3
04E5A@0k>c/00P0n?Sh204Q8B080?Cdm00D0?3`l03Xj>P0l?3`0?3`l03Ti>@0203lo?`0903Xj>P0i
>CT0>SXj03Xj>P0n?Sh0>SXj03dm?@0j>SX0?Cdm00<0>CTi01@0>3Ph03Xj>P0k>c/0?3`l03Xj>P0i
>CT0>c/k03Xj>P0n?Sh0>c/k03`l?010@400?3`l03/k>`0m?Cd0?3`l03/k>`0m?Cd0>c/k0451@@<0
>c/k00<0?3`l03lo?`13@d<00P0m?Cd03P0k>c/0?Shn03/k>`0j>SX0?3`l03Ti>@0k>c/0>CTi03`l
?00j>SX0?Shn03dm?@0j>SX0?3`l0P0k>c/00`0i>CT0@41003lo?`0203`l?00503/k>`10@400>CTi
03/k>`0m?Cd00P0j>SX05@0n?Sh0?Cdm03/k>`0l?3`0@D5104E5A@1ADE40FEUI061PH01OGel0FEUI
04Y:BP18B4P0@d=303/k>`12@T80?Shn03lo?`0n?Sh0?Cdm0410@0020451@@0603/k>`0j>SX0?Shn
0410@013@d<0@T920P1BDU806P1ADE40AdM704i>CP1TI6@0O7al09ZJVP2a/K40_kno0<k>cP3=cLd0
_;bl09bLW01jNWX0FEUI04Q8B010@400@D510410@00n?Sh0@T9204=3@`15ADD0JFUY092@T02i^KT0
fMWI0P3Shn<00`31`L40Xj>S0;>c/`020<g=c@0R0<K6aP3;bl/0d=3@0=OGe`3Hf=P0b<S80<71`@34
a<@0_kno0;Fe]@2c/k<0`L710;jn_P2c/k<0Zj^[0:BTY02RXZ80YJFU09^KV`2PX:00[Zj^0::RXP2S
Xj<0]KFe0<S8b039bLT0bl_;0<G5a@2l_;`0_[jn0;Ng]`33`l<0bl_;0=WIf@80f=SH00@0e=CD0=3@
d03De=@0f=SH0P3AdM409@38b<P0`l?30<;2`P2n_[h0^KVi0<?3``32`/80a/K60<S8b03<c<`0bLW9
0=3@d037alL0bl_;0<W9b@2h^;P0W9bL0:j^[P3?cll0emOG0>7Qh@34a<@0^;Rh0<_;b`3Hf=P0h^;R
0>3Ph03QhN40d=3@0<?3``3De=@0^KVi09>CT`28R8P0YZJV0;fm_@31`L400P39bLT02`2j^[X0UYJF
0:FUY@2^[Zh0b<S80;bl_02RXZ80Ogmo06UYJ@1FEUH0@D5100gooooo000@ooooo`04051@D01>CTh0
C4a<04e=C@80C4a<02T0CDe=04m?C`1EEED0IfMW079bLP1aLG40J6QX05YJFP1HF5P0DE5A05UIF@1?
Cdl0CTi>04m?C`1DE5@0CTi>059BDP1NGUh0JFUY05YJFP1GEeL0DE5A04a<C01=CDd0D51@05=CD`1G
EeL0CDe=04];B`1NGUh0GemO05IFEP1ZJVX0MgMg09bLW02XZ:P0];Bd0;^k^`2LW9`0MWIf06EUI@02
061PH00O05mOG`1eMGD0R8R808F5Q@1PH600IfMW06e]K@1iNGT0VIVI09FEU@2:RXX0IfMW04Q8B011
@D40?Shn0410@015ADD0A4A40451@@17AdL0A4A40492@P15ADD0A4A40410@012@T80@d=30451@@12
@T80@d=30492@P0203lo?`0D03hn?P0m?Cd0?3`l03hn?P15ADD0A4A403lo?`10@400?Shn03`l?00o
?cl0@41003hn?P10@400?clo0451@@12@T80?3`l03/k>`10@40203hn?P0304=3@`10@400?3`l0080
?3`l00D0>SXj03lo?`0o?cl0?Shn03/k>`0203dm?@0?03hn?P10@400@T9203dm?@0l?3`0@4100451
@@0o?cl0?3`l03Xj>P0l?3`0>c/k03Ti>@0l?3`0?Cdm0080?3`l0P0k>c/01`0o?cl0?Shn03Xj>P0m
?Cd0@41003lo?`10@4000P0n?Sh01P0m?Cd0?3`l03dm?@10@400>SXj03/k>`80?Shn00<0?Cdm03`l
?00k>c/00P0l?3`04`0m?Cd0>c/k03/k>`0n?Sh0>SXj03`l?00k>c/0?Shn0492@P13@d<0?Shn03lo
?`18B4P0ATI60492@P15ADD0ATI604A4A012@T800P0n?Sh01P10@400?Shn03lo?`15ADD0?Shn03Xj
>P<0?Cdm0P0o?cl01011@D40?Cdm03Ti>@0k>c/203`l?00303/k>`0n?Sh0?3`l0080?3`l02H0?Shn
03/k>`0j>SX0?Cdm03Xj>P0k>c/0>CTi03/k>`0i>CT0?3`l03hn?P0k>c/0>SXj03Ti>@0j>SX0?3`l
03dm?@10@400?3`l03lo?`0m?Cd0?Shn03/k>`13@d<0FUYJ07UiN@1YJFT0A4A403`l?00m?Cd0>c/k
0410@00o?cl0@D5104a<C01?Cdl0AdM703lo?`80?Cdm00L0?3`l03hn?P0i>CT0@41003Xj>P0k>c/0
?Cdm00<0?3`l00@0>SXj03Ti>@0k>c/0@T920P0l?3`02`0n?Sh0>c/k03/k>`0i>CT0>SXj03`l?00n
?Sh0@41003dm?@10@400?clo0080?3`l00<0?Cdm03hn?P0m?Cd00P0k>c/203`l?080>SXj0P0k>c/0
3`0j>SX0>c/k04=3@`0l?3`0?Cdm03`l?00o?cl0?3`l03/k>`0o?cl0>3Ph03lo?`0k>c/0?Cdm03Xj
>P0203dm?@0T03`l?00n?Sh0@T920451@@0m?Cd0?3`l03Xj>P0k>c/0>CTi03`l?00j>SX0>3Ph03Xj
>P0f=SH0=cLg03Xj>P0m?Cd0@D5103hn?P13@d<0@T920410@012@T80ATI60410@00m?Cd0?Shn03dm
?@0k>c/0?clo0492@P0n?Sh0@41003Xj>P0k>c/0?3`l0P0m?Cd0:00o?cl0?3`l03Xj>P0n?Sh0@T92
04i>CP15ADD0B4Q8051@D01dM7@0Vi^K0<71`@3EeMD0d=3@0;>c/`2NWYh0Rh^;07=cL`1PH600C4a<
0492@P16ATH0@41003dm?@0o?cl0?Cdm03lo?`13@d<0CTi>079bLP2OWil0alO70=KFeP3@d=00e]KF
0=_Kf`3?cll0_[jn09BDU02:RXX208n?S`0[09bLW02WYjL0Xj>S09NGU`2=SHd0Q8B40820P01hN7P0
IFEU05=CD`1:BTX0ATI603lo?`11@D40?clo0451@@1;Bd/0DE5A05iNGP1iNGT0S8b<08J6QP2EUID0
SHf=0820P01bLW80G5aL05iNGP1EEED0DE5A05=CD`1BDU80JVYZ08F5Q@2;Rh/0T92@09>CT`2KVi/0
YjNW0;^k^`2o_kl0e=CD0=OGe`020<g=c@0_0<71`@2l_;`0/k>c0:ZZZP2TY:@0];Bd0<g=c@3Fe]H0
gMgM0=OGe`3Bd]80cLg=0<K6aP2e]KD0bl_;0=WIf@3Lg=`0hn?S0=WIf@2j^[X0]kNg0;Fe]@2i^KT0
^k^k0;Zj^P2_[jl0]kNg0;jn_P2h^;P0];Bd0:NWY`2PX:00[jn_09fMW@2QXJ40[:b/0:2PX02HV9P0
Vi^K0;bl_039bLT0dm?C0;Rh^02?Shl0Ng]k069RHP1HF5P03Oooool0013ooooo0`1=CDd01`1?Cdl0
CDe=04Y:BP19BDT0D51@04a<C01;Bd/00P1<C4`06@1DE5@0FUYJ05YJFP1RHV80J6QX05aLG01PH600
D51@04U9B@1:BTX0AdM704Q8B019BDT0C4a<04Q8B019BDT0AdM704Y:BP1=CDd0EEEE06EUI@1JFUX0
EUIF05eMG@1XJ6P00P1MGEd0601RHV80NGUi08:2PP2BTY80_[jn0<o?c`3@d=00clo?0<S8b02d];@0
Z:RX0:ZZZP2HV9P0UiNG08:2PP1MGEd0U9BD0;6a/@2PX:00Ph>308:2PP1iNGT0Fe]K051@D0<0@d=3
0180ATI604A4A015ADD0@D5104=3@`14A4@0ATI604A4A016ATH0@T920410@016ATH0A4A40410@012
@T80@d=30492@P10@40303hn?P0303lo?`10@400@T920080@4100`0m?Cd08`0o?cl0@D510410@00o
?cl0?Shn03dm?@0o?cl0?Shn055AD@2OWil0?Shn03`l?00o?cl0?Cdm03`l?00m?Cd0?clo0451@@0m
?Cd0?clo04=3@`12@T80?Shn0451@@0l?3`0?Shn0410@012@T80?clo03dm?@0k>c/0>SXj03`l?00i
>CT0@D510080>c/k0140?Cdm03hn?P0o?cl0?clo03`l?010@400?clo04I6AP10@400?3`l0410@00o
?cl0>SXj03dm?@10@400?3`l03/k>`020410@0030492@P0m?Cd0?Shn0080?Cdm00T0>SXj0451@@0n
?Sh0?3`l0451@@0m?Cd0?clo0410@013@d<00P12@T801`13@d<0@41004E5A@13@d<0C4a<04M7A`13
@d<00`0n?Sh01@0m?Cd0?clo0451@@0n?Sh0?Cdm0080?Shn00T0?clo03hn?P0j>SX0>SXj04A4A011
@D40?3`l03dm?@0j>SX00P0m?Cd01P0n?Sh0?Cdm03hn?P0k>c/0?Cdm0410@080>c/k00<0?Shn03lo
?`0m?Cd00P0j>SX03`0i>CT0=SHf03dm?@0m?Cd0>SXj03`l?00m?Cd0>3Ph03/k>`0o?cl0>CTi03`l
?00g=cL0?Shn0410@00204e=C@0C04M7A`0k>c/0?3`l03dm?@13@d<0?3`l0410@00j>SX0?Shn03lo
?`0l?3`0AdM703lo?`0j>SX0?3`l03Ti>@0j>SX0>3Ph03/k>`0203Ph>00503/k>`0l?3`0?Shn03`l
?00i>CT00P0l?3`02@0k>c/0>CTi03/k>`0m?Cd0?3`l03hn?P0i>CT0=cLg03Ph>00203/k>`0603Xj
>P0k>c/0>CTi03Xj>P0n?Sh0?3`l0P0j>SX00`0h>3P0=cLg03Ph>00203/k>`80?3`l0P0k>c/01@0h
>3P0>c/k03Xj>P0g=cL0>SXj0080>CTi00@0?3`l03lo?`0i>CT0>c/k0P0i>CT02P0l?3`0>c/k03Xj
>P10@400@D5103lo?`11@D40?clo03/k>`0j>SX203/k>`0603Ti>@0j>SX0@41003lo?`0h>3P0>SXj
0P0k>c/01@0n?Sh0?Cdm0492@P0o?cl0>SXj0080?3`l02D0>c/k03hn?P11@D40?Shn03Ti>@0m?Cd0
?3`l03/k>`0o?cl0?Shn03Ti>@0l?3`0@41003lo?`11@D40@d=304a<C01ADE40F5QH06a/K02;Rh/0
/[:b0<o?c`3Lg=`0e]KF0;Zj^P2=SHd0IFEU04e=C@13@d<0@D5103hn?P0m?Cd0@D5103`l?00m?Cd0
?Shn0080?3`l00l0?Cdm06i^KP2UYJD0][Jf0;fm_@2c/k<0XJ6Q09VIV@28R8P0O7al071`L01JFUX0
CTi>04I6AP11@D400P0o?cl0D@13@d<0@T9203hn?P12@T80?clo03hn?P10@400?clo03dm?@0k>c/0
>CTi03hn?P0m?Cd0?Shn03`l?00m?Cd0@D5104M7A`1FEUH0LW9b08V9R@1nOWh0Ph>308J6QP27QhL0
Shn?09ZJVP2QXJ40ZJVY0:ZZZP2VYZH0O7al05MGE`1ADE40ATI604E5A@1HF5P0KFe]07]kN`26QXH0
ZJVY0<o?c`3MgMd0iNGU0>SXj03Ng]h0`<3009bLW02ATI40Vi^K08f=S@2BTY80ZJVY0<C4a03AdM40
alO70=?Cd`3EeMD0bl_;0<S8b033`l<0_kno0;6a/@32`/80_Kfm0:n_[`2RXZ80W9bL08:2PP1kNg/0
LW9b07UiN@22PX80W9bL0;Rh^03<c<`0d=3@0=;BdP3@d=00alO70;no_`020;fm_@090:^[Z`2UYJD0
_[jn0=;BdP3Hf=P0`/;20<G5a@3Bd]80b/[:00gooooo000@ooooo`0@051@D01>CTh0Cdm?04i>CP1<
C4`0CTi>04Y:BP17AdL0CDe=04a<C01:BTX0BDU905ADE01;Bd/0C4a<04i>CP80C4a<00H0De=C05AD
E01KFe/0EUIF05EEE@1IFET205=CD`0V04m?C`1OGel0DU9B04a<C016ATH0AdM704];B`1?Cdl0GUiN
06IVIP1ZJVX0EUIF05MGE`1<C4`0GemO05QHF01CDe<0GEeM06m_K`1bLW80QHF509^KV`2TY:@0];Bd
0=3@d03:b/X0`l?30=;BdP30`<00]KFe0;Jf]P34a<@0`/;20;Jf]P2c/k<0][Jf0:j^[P2ATI4208:2
PP0A08J6QP25QHD0R8R807moO`1fMWH0Lg=c075aL@1[Jf/0HV9R05IFEP1CDe<0CDe=04Q8B015ADD0
@D5104E5A@1IFET00P1/K6`03P1DE5@0?Shn03dm?@11@D40A4A404=3@`17AdL0@T920451@@10@400
@d=30410@00o?cl0?Cdm0P0k>c/03P0n?Sh0?Cdm04Y:BP2f][H0ADE503`l?00o?cl0>SXj03dm?@0o
?cl0?3`l0451@@0l?3`0>SXj0P0l?3`01`0i>CT0?3`l03`l?00o?cl0?Cdm03hn?P0j>SX00P0k>c/0
5`0j>SX0>CTi03`l?011@D40>SXj03`l?00o?cl0>SXj0410@00o?cl0@41003lo?`0j>SX0?Shn03/k
>`0g=cL0>SXj03/k>`0h>3P0?3`l03/k>`0n?Sh0?3`l0080>c/k00L0?clo03dm?@0o?cl0@41003hn
?P0k>c/0?Cdm0080>SXj00`0@T9203hn?P0j>SX0@D5103hn?P11@D40@T9203/k>`0m?Cd0?Shn03/k
>`13@d<203dm?@80?Shn00h0?Cdm03Xj>P0m?Cd0@D5103hn?P0k>c/0?3`l03hn?P12@T80?clo03Ti
>@0l?3`0@T9203hn?P80?3`l01D0>c/k03`l?00l?3`0>CTi03`l?00m?Cd0?3`l03hn?P0l?3`0?Cdm
0410@014A4@0?3`l03hn?P0m?Cd0>c/k03hn?P0i>CT0>SXj03/k>`0h>3P00P0l?3`0100o?cl0>CTi
03`l?00i>CT203`l?00304=3@`1?Cdl0@T920080>SXj00L0?3`l03dm?@0l?3`0@41003/k>`10@400
?Cdm0080>SXj0P0m?Cd02P0o?cl0>SXj03hn?P0k>c/0>SXj03Ph>00l?3`0=cLg03Hf=P0i>CT203Xj
>P0403lo?`0m?Cd0>CTi03Lg=`80>c/k01@0>SXj03Ti>@0f=SH0?3`l03Lg=`0i>CT0>c/k03Ph>00l
?3`0?clo03`l?00j>SX0>c/k03hn?P0o?cl0>SXj03Ti>@0h>3P0>SXj03/k>`80?Cdm0P10@4002P0l
?3`0>SXj03Xj>P0l?3`0>CTi03Hf=P0g=cL0>3Ph03lo?`0j>SX203Ph>00903/k>`0l?3`0?Cdm03`l
?010@400?clo03/k>`0o?cl0>SXj0080?3`l0P0k>c/02P0l?3`0?Shn03/k>`0k>c/0?3`l03Ph>00i
>CT0?Shn03Ti>@0j>SX203`l?00803/k>`0h>3P0>c/k03`l?00j>SX0>c/k03hn?P12@T8303hn?P0L
0410@00n?Sh0?Shn03`l?00n?Sh0?Cdm0492@P0l?3`0AdM705mOG`2JVYX0`L710=;BdP3De=@0dM7A
0<_;b`2f][H0UYJF07alO01GEeL0@d=303lo?`0l?3`0>c/k03dm?@0l?3`0>SXj03dm?@80>c/k00d0
>SXj0492@P1<C4`0GemO07UiN@1`L700F5QH04e=C@1:BTX0BDU904E5A@12@T80?Shn0080?Cdm00L0
?Shn03`l?00m?Cd0@T9203lo?`0n?Sh0?3`l0080>c/k00@0?Cdm03`l?00k>c/0?3`l0P0m?Cd0?00k
>c/0?3`l03hn?P0m?Cd0@4100492@P10@400@d=304A4A01;Bd/0EUIF05QHF01XJ6P0N7Qh08R8R029
RHT0T92@08^;R`2?Shl0TI6A09jNWP2VYZH0[Jf]0:NWY`2UYJD0Zj^[0:n_[`2e]KD0e=CD0=[JfP3R
h^80hN7Q0=kNgP3De=@0b/[:0<K6aP31`L40^k^k0<?3``3@d=00fMWI0<o?c`3<c<`0a<C40=3@d03<
c<`0d];B0<c<c02n_[h0[Zj^09:BTP28R8P0KFe]06ATI01/K6`0M7Ad08J6QP27QhL0SXj>0:^[Z`80
][Jf0P2UYJD02P2b/[80dM7A0=_Kf`3Lg=`0gmoO0>3Ph03QhN40h^;R0=_Kf`3@d=020<[:bP060<O7
a`30`<00`L710<W9b@35aLD0`L713Oooool0013ooooo00L0Cdm?04a<C01<C4`0Bd];04i>CP1;Bd/0
AdM700H0BDU90P1=CDd02017AdL0B4Q804M7A`15ADD0B4Q804U9B@17AdL0B4Q80`1=CDd0?P1;Bd/0
DE5A04U9B@1;Bd/0BDU904Q8B019BDT0CTi>05mOG`1HF5P0DU9B04];B`1<C4`0AdM704Q8B01=CDd0
EUIF065QH@1YJFT0EUIF055AD@1MGEd0HV9R05MGE`1RHV80G5aL06UYJ@1lO7`0TY:B096AT@1WIfL0
FEUI055AD@1>CTh0FEUI07YjNP2@T900ZZZZ0;Fe]@2k^k/0`L710;2`/02/[:`0];Bd0:VYZ@2VYZH0
Z:RX0;Zj^P2XZ:P0TI6A0;Jf]P2TY:@0OGem07UiN@2=SHd0/[:b0<K6aP3>c/h0bl_;09bLW01]KFd0
BTY:0P12@T802`17AdL0?clo0492@P0o?cl0@T9204I6AP11@D40@T9203lo?`0l?3`0>c/k0080?Shn
00<0>SXj051@D00k>c/00P0l?3`0200j>SX0?Cdm03/k>`0h>3P0>c/k03Ti>@12@T80@4100`0h>3P2
03hn?P0503/k>`0o?cl0>c/k03Xj>P0g=cL00P0j>SX03`11@D40?Cdm03dm?@11@D40?Cdm03`l?011
@D40>c/k03hn?P0l?3`0?Shn0410@00n?Sh0>CTi03Xj>P0203Ti>@0803`l?00j>SX0?clo03lo?`0j
>SX0?3`l03lo?`0n?Sh303dm?@0E03/k>`0m?Cd0?Cdm0410@00m?Cd0?Shn03lo?`1;Bd/0@D5103lo
?`0k>c/0@D5103/k>`0j>SX0?Cdm04=3@`0n?Sh0?clo03dm?@0o?cl0>c/k0080>SXj01D0ATI604M7
A`13@d<0@d=30451@@0k>c/0=cLg03`l?00n?Sh0@41003lo?`0l?3`0>c/k03hn?P0o?cl0@D5103Xj
>P0n?Sh0?Cdm03`l?00o?cl00P0l?3`04@0n?Sh0@41003`l?011@D40?Cdm03Lg=`0o?cl0>SXj03/k
>`0j>SX0>CTi04=3@`0n?Sh0?clo0410@012@T80@D510080?clo00@0@d=30492@P11@D40=SHf0P0h
>3P04P0g=cL0>SXj03Ti>@0i>CT0ADE503Xj>P0i>CT0?Cdm03`l?00j>SX0@D5103lo?`0j>SX0?3`l
03lo?`0k>c/0>CTi03Lg=`80>SXj00H0>CTi03Ph>00m?Cd0?3`l03Xj>P0k>c/303Lg=`0=03Ti>@0m
?Cd0?Cdm03Hf=P0k>c/0?3`l03/k>`0j>SX0?Cdm03hn?P0l?3`0>c/k03`l?00203Lg=`0503Ph>00l
?3`0?Shn03dm?@0n?Sh00P0l?3`0300o?cl0?Cdm03dm?@0n?Sh0?Cdm03hn?P0i>CT0>SXj03Hf=P0l
?3`0>c/k03hn?P80>CTi00h0>c/k03Ph>00j>SX0>c/k03Xj>P0i>CT0AdM70451@@0m?Cd0?3`l0410
@00o?cl0?Shn03dm?@80?3`l00D0>c/k03dm?@0j>SX0>CTi03hn?P0203/k>`0303Lg=`0i>CT0>SXj
0080>c/k01/0>CTi03`l?00l?3`0?clo03dm?@0h>3P0?Shn0451@@10@400>c/k0410@016ATH0@410
03hn?P1ADE40RXZ:0;:b/P2h^;P0Y:BT096AT@1fMWH0GUiN059BDP1;Bd/0@T9203lo?`10@4000P0m
?Cd04P0n?Sh0?3`l03Ti>@0h>3P0>c/k03Ph>013@d<0CTi>05MGE`1XJ6P0Kfm_065QH@15ADD0ATI6
0451@@0o?cl0?Shn03dm?@80?3`l00P0>SXj03Ti>@0l?3`0?3`l03Ti>@0k>c/0?Shn03dm?@80>CTi
00<0>3Ph03<c<`0k>c/00P0i>CT0E@0n?Sh0AdM705MGE`1KFe/0IFEU07AdM02BTY80WYjN0:BTY02S
Xj<0W9bL0:6QX@2d];@0a<C40=OGe`3Ph>00iNGU0>KViP3Hf=P0c<c<0=WIf@3Jf]X0e]KF0=CDe03M
gMd0gmoO0>3Ph03Fe]H0/[:b09NGU`2NWYh0/k>c0<G5a@3;bl/0e=CD0=_Kf`3Ng]h0g=cL0=KFeP2`
/;00LW9b061PH01^KVh0MgMg07UiN@2FUYH0WIfM0:ZZZP36a/H0f][J0=OGe`3Lg=`0g]kN0=OGe`3E
eMD0dm?C0<[:bP2n_[h0Z:RX09NGU`2BTY80Ti>C09:BTP21PH40PX:209FEU@2SXj<0RHV908:2PP2L
W9`0^k^k0<g=c@37alL0_[jn0<?3``3IfMT0e=CD0<g=c@3@d=00a/K60<S8b02][Jd0UIFE08Z:RP2U
YJD03Oooool0013ooooo00T0DE5A04i>CP1?Cdl0Cdm?04a<C01?Cdl0CDe=04];B`1<C4`00P19BDT0
201:BTX0B4Q804E5A@1?Cdl0DU9B04e=C@15ADD0C4a<0P1?Cdl2051@D00305=CD`1KFe/0EeMG0080
DE5A01P0E5AD05EEE@1ADE40C4a<04];B`17AdL0BTY:04I6AP17AdL0BTY:04U9B@1BDU80CTi>051@
D01DE5@0Jf][06m_K`1DE5@0BDU9059BDP1DE5@0DE5A05=CD`1BDU8204];B`0;05iNGP1MGEd0GUiN
04m?C`16ATH0B4Q805MGE`1KFe/0L71`07YjNP25QHD00P2>SXh0801gMgL0Lg=c08J6QP2ZZZX0^KVi
0:ZZZP2VYZH0TY:B07alO02:RXX0OGem07EeM@1mOGd0T92@0:^[Z`1oOgl0OWin08F5Q@2NWYh0^;Rh
09jNWP1nOWh0De=C04=3@`0n?Sh0ATI60410@00o?cl0@d=30492@P11@D40@4100P0m?Cd00`11@D40
?Cdm03hn?P0203`l?00403dm?@0k>c/0?3`l03/k>`80?Cdm00T0@41003lo?`0o?cl0>SXj0410@00j
>SX0>3Ph03`l?00k>c/00P0m?Cd02@0k>c/0?clo03Xj>P0o?cl0?Shn03lo?`0k>c/0?Shn0492@P02
0451@@80@4100P0n?Sh0300k>c/0?Shn03/k>`0i>CT0?clo03`l?00n?Sh0>SXj03dm?@13@d<0@T92
03`l?080?Cdm00H0>c/k03hn?P0n?Sh0>CTi03`l?00n?Sh203dm?@0403lo?`10@400?Shn04=3@`<0
?3`l00D0?Cdm03`l?00j>SX0>c/k03lo?`0303/k>`0403lo?`10@400?Cdm0410@080B4Q801<0@d=3
0451@@0n?Sh0>CTi0410@014A4@0?Shn03/k>`10@400?Shn0451@@14A4@0ATI60410@00i>CT0?3`l
03/k>`0j>SX0?Shn0080>SXj01D0>c/k03`l?00g=cL0?Cdm03/k>`0m?Cd0>SXj03/k>`0j>SX0?3`l
03Xj>P0l?3`0?Shn04A4A01>CTh0?Cdm03Xj>P0o?cl0@T9203hn?P0m?Cd00P0l?3`02@0n?Sh0?Cdm
03/k>`0j>SX0?Cdm03/k>`11@D40>SXj03/k>`0203Ti>@0903hn?P0h>3P0>c/k03`l?00m?Cd0@T92
03dm?@0l?3`0>SXj0080>c/k00h0?3`l03hn?P0m?Cd0>SXj03Ti>@0k>c/0>CTi03Ph>00j>SX0?Shn
03/k>`0o?cl0>c/k03lo?`80?3`l00H0=cLg03Ph>00f=SH0>3Ph03/k>`0n?Sh203/k>`0I03dm?@0k
>c/0?Cdm03Xj>P0k>c/0?3`l03Ti>@0k>c/0?3`l03dm?@0k>c/0>3Ph03hn?P0j>SX0?Shn04M7A`16
ATH0?Shn03`l?00g=cL0>CTi03`l?00h>3P0?3`l03Xj>P0203/k>`0503hn?P0m?Cd0=SHf03Ti>@0l
?3`00P0m?Cd02`0l?3`0?Shn03`l?00m?Cd0>c/k03dm?@0o?cl0?3`l03Ti>@0o?cl0>CTi0080?3`l
00/0?clo03dm?@0j>SX0?3`l0410@00o?cl0?Shn03Xj>P12@T80@D5103lo?`0203Ti>@0803`l?016
ATH0CDe=07AdM021PH40J6QX051@D016ATH204=3@`050410@00l?3`0>SXj03hn?P0m?Cd00P0k>c/0
3P0l?3`0?Cdm03Xj>P0f=SH0>CTi0492@P1FEUH0LW9b06][J`1QHF40FUYJ04e=C@0o?cl0>SXj0P0l
?3`303dm?@0503`l?00m?Cd0?3`l03Xj>P0o?cl00`0j>SX07P0m?Cd0@D5103`l?00l?3`0?Cdm03Xj
>P0n?Sh0Cdm?06MWI`2:RXX0ZZZZ0<O7a`38b<P0d=3@0<K6aP34a<@0`/;20;Vi^@2h^;P0_Kfm0<O7
a`3:b/X0dm?C0>;RhP3YjNT0k>c/0>OWi`3Ti>@0g]kN0=cLg080i>CT01h0hN7Q0>?Sh`3UiND0h^;R
0=WIf@3<c<`0b/[:0=?Cd`3MgMd0h^;R0>7Qh@3Rh^80gMgM0=OGe`3:b/X0clo?0=;BdP3?cll0bl_;
0<71`@32`/80WYjN075aL@1OGel0DE5A06ATI02LW9`0clo?0=[JfP3@d=020<30`0040<W9b@3Hf=P0
gMgM0>7Qh@80hn?S00`0gmoO0=OGe`2m_Kd0[Jf]0;Bd]03>c/h0dm?C0<c<c038b<P0]KFe0:j^[P30
`<020=CDe00:0<C4a038b<P0^[Zj0;fm_@2OWil0Ph>309RHV02n_[h0a<C40;Rh^0gooooo000@oooo
o`06059BDP1CDe<0De=C055AD@1?Cdl0C4a<0P1=CDd0401;Bd/0BDU904U9B@1=CDd0D51@05EEE@1T
I6@0EeMG055AD@1;Bd/0AdM704Y:BP1;Bd/0DU9B05YJFP1@D50204a<C00304Q8B017AdL0ADE50080
BTY:0P18B4P05`1>CTh0CDe=04Q8B017AdL0CDe=05aLG01QHF40KFe]069RHP1HF5P0G5aL05mOG`1G
EeL0J6QX07YjNP1aLG40JVYZ06m_K`1GEeL0GEeM05aLG01ZJVX0EEEE00<0B4Q800@0A4A404e=C@1@
D500BDU90P16ATH02013@d<0B4Q804M7A`16ATH0B4Q806ATI01fMWH0U9BD0P2OWil02@1lO7`0De=C
059BDP1mOGd0]KFe0<O7a`3:b/X0Zj^[06i^KP0206EUI@0407]kN`2[Zj/0`L710;2`/080Ti>C00`0
RHV907AdM01<C4`0@41004=3@`0m?Cd0?clo03`l?00n?Sh0@d=30492@P10@40203dm?@0L0410@00l
?3`0?3`l03dm?@0l?3`0?Cdm03lo?`10@400?Cdm03lo?`0l?3`0>SXj03`l?00m?Cd0>c/k03lo?`0m
?Cd0@4100492@P0j>SX0?Cdm03`l?00i>CT0?Cdm0410@00l?3`0?Cdm0451@@@0>c/k00X0?3`l03hn
?P0i>CT0?3`l0492@P0n?Sh0@41003/k>`0j>SX0?clo0P0n?Sh03P10@400?Shn03dm?@0o?cl0>CTi
03hn?P10@400?Cdm03Ti>@0m?Cd0@41003hn?P0o?cl0?Cdm0P0i>CT0200n?Sh0@D5103`l?00k>c/0
?Shn0410@00i>CT0?Shn0P0j>SX01P0k>c/0>CTi03dm?@0n?Sh0?clo03Xj>P80>c/k0100>SXj03lo
?`0o?cl0@41003hn?P13@d<0?3`l03Xj>P0n?Sh0ATI603hn?P0k>c/0?Cdm03Ph>00j>SX0@D510P0l
?3`03@0i>CT0>3Ph03`l?00m?Cd0?3`l03lo?`0m?Cd0?Shn03dm?@0l?3`0>c/k03`l?00o?cl0100m
?Cd0100h>3P0>SXj0492@P0o?cl203Ti>@80>SXj00H0?3`l03dm?@0k>c/0?Shn04=3@`0j>SX203`l
?00903/k>`0i>CT0?Cdm03Xj>P0o?cl0>CTi03Xj>P0k>c/0>CTi0080>SXj00D0?Cdm03hn?P0n?Sh0
>c/k03Ph>00203Ti>@0903Ph>00f=SH0>SXj03Xj>P0f=SH0?Shn03/k>`0o?cl0?Shn00<0>SXj00@0
>c/k03Ph>00i>CT0?Cdm0P0g=cL05@0j>SX0>c/k03`l?00k>c/0?3`l03hn?P0k>c/0?clo03Hf=P0k
>c/0?clo03dm?@1<C4`0MWIf08b<S01ZJVX0@41003Xj>P0i>CT0=cLg03`l?00203/k>`0703`l?00k
>c/0>c/k03Ti>@0g=cL0>CTi03Lg=`0303Ti>@80>c/k01H0>3Ph03De=@0i>CT0>c/k03dm?@0j>SX0
@41003hn?P0i>CT0>c/k0492@P0o?cl0@D5103dm?@0k>c/0?3`l03dm?@0k>c/0?Shn03Xj>P11@D40
?Shn0P12@T802`10@400ATI605aLG01MGEd0DE5A04=3@`0o?cl0?Shn0451@@0l?3`0?Cdm0080>c/k
00<0@D510410@00k>c/00P0i>CT02`0h>3P0>CTi03Xj>P0h>3P0>c/k0492@P10@400?Shn03/k>`0o
?cl0@T920080?Shn00@0?3`l03hn?P0l?3`0?Cdm0P0l?3`203dm?@80?3`l01P0>SXj03Ti>@0m?Cd0
>SXj03dm?@0o?cl0>CTi0451@@1ADE40JVYZ07]kN`2<S8`0QHF507MgM`1RHV80GemO05iNGP1OGel0
Lg=c09:BTP2ZZZX0`l?30=KFeP3Kfm/20=OGe`0<0=SHf03GemL0fm_K0=kNgP3Kfm/0f=SH0=?Cd`3H
f=P0i^KV0>GUi@3Lg=`0fm_K0P3Ng]h03@3Jf]X0fm_K0>?Sh`3YjNT0kNg]0>k^kP3[jn/0hn?S0=oO
g`3Cdm<0clo?0=;BdP3GemL00P3Kfm/0:`3GemL0bLW90;2`/02PX:00UIFE09VIV@2FUYH0UiNG0:JV
YP31`L40b<S80<K6aP2k^k/0];Bd0;no_`3>c/h0c<c<0<g=c@37alL0_;bl0;Jf]P2VYZH0WYjN0:FU
Y@2d];@0/k>c0;Bd]02/[:`0X:2P0:ZZZP2m_Kd0f][J0>KViP3Rh^80e=CD0<G5a@2ZZZX0SXj>07If
MP1iNGT0/k>c0=KFeP3MgMd03Oooool0013ooooo00P0DE5A05MGE`1IFET0E5AD04a<C01:BTX0CDe=
04Y:BP80B4Q800D0ATI604Q8B01<C4`0@d=304];B`0204M7A`0404];B`1<C4`0C4a<04];B`80C4a<
00D0B4Q804E5A@16ATH0AdM704Q8B00204Y:BP0L04Q8B019BDT0DE5A05aLG01IFET0FUYJ04a<C01>
CTh0DE5A04=3@`18B4P0BTY:04i>CP1CDe<0I6AT061PH01LG5`0GEeM04i>CP17AdL0Bd];04Y:BP1F
EUH0LW9b07MgM`23Ph<0JFUY055AD@80D51@02D0E5AD04U9B@18B4P0B4Q804E5A@1:BTX0ATI604M7
A`15ADD0A4A404U9B@1;Bd/0EUIF05MGE`1OGel0LW9b07alO01TI6@0Fe]K06][J`2?Shl0/[:b0<C4
a036a/H0`<300:>SX`2PX:00^KVi0<71`@2m_Kd0]kNg0<G5a@20P800Ogmo09NGU`1]KFd0B4Q80080
?clo00D0>SXj03hn?P0o?cl0?3`l03/k>`0203hn?P030410@00k>c/0?Shn0080?clo0180?Cdm03lo
?`0n?Sh0@41003`l?00j>SX0?3`l03Xj>P0k>c/0>SXj03dm?@0n?Sh0@D5103lo?`0l?3`0?Cdm03/k
>`0j>SX203`l?0<0>c/k00P0?3`l03Xj>P0k>c/0>CTi03`l?00j>SX0>CTi03`l?0@0@D510140@410
03hn?P0l?3`0>SXj03dm?@0l?3`0>SXj03dm?@0j>SX0@4100451@@0n?Sh0?3`l03dm?@0o?cl0AdM7
03/k>`0203dm?@0;03Xj>P0k>c/0?Shn03`l?00m?Cd0>SXj03`l?00k>c/0@41003/k>`0m?Cd00P0o
?cl02@0k>c/0?Shn0492@P0k>c/0>3Ph03/k>`0j>SX0?clo03dm?@030410@00303Xj>P0l?3`0?Cdm
0080@D510P0l?3`0100i>CT0>c/k0410@00n?Sh203Xj>P0:03`l?00k>c/0>c/k03dm?@0o?cl0>c/k
03dm?@0n?Sh0?3`l03/k>`80>CTi00`0=cLg03Xj>P0j>SX0>SXj03`l?00n?Sh0ADE50410@00l?3`0
?Cdm03`l?00j>SX203`l?00303Xj>P0i>CT0?3`l0080?Shn00T0>CTi03Ph>00j>SX0?Shn03/k>`10
@400>SXj03Ti>@0m?Cd00P0k>c/00`0i>CT0?Cdm03hn?P0203`l?00603hn?P0g=cL0=cLg03Ti>@0m
?Cd0@4100`0k>c/00`0i>CT0?clo03/k>`0203Ti>@0303Xj>P0m?Cd0>CTi0080>SXj01H0>3Ph03Xj
>P0i>CT0>c/k03Lg=`0k>c/0>CTi03hn?P11@D40ADE504Q8B01;Bd/0E5AD06=SH`1`L700XJ6Q09fM
W@1`L700CDe=0492@P0n?Sh0>SXj0P0n?Sh0100k>c/0?3`l03/k>`0j>SX303/k>`0A03`l?010@400
?3`l03Ti>@0k>c/0>SXj03Lg=`0i>CT0?Shn0410@00l?3`0?Shn0451@@0m?Cd0?Shn03lo?`11@D40
0P0m?Cd01010@400?Cdm0451@@14A4@20410@00=03dm?@13@d<0B4Q804Y:BP1ADE40D51@04Q8B017
AdL0A4A403lo?`10@400@T9203`l?00203/k>`0604A4A00o?cl0>c/k0410@013@d<0?clo0P0l?3`0
2@0i>CT0?3`l03/k>`0l?3`0>c/k03`l?00k>c/0?Shn03`l?00203dm?@0603`l?00m?Cd0>SXj03Xj
>P0i>CT0>c/k0P0l?3`203dm?@0G03/k>`0m?Cd0?Cdm03`l?010@400Fe]K071`L023Ph<0UiNG0:>S
X`2?Shl0NGUi05ADE017AdL0?Shn0492@P1=CDd0N7Qh09jNWP2f][H0aLG50<K6aP2g]kL00P2WYjL0
2`2KVi/0SHf=09JFUP2QXJ40/K6a0=WIf@3QhN40i>CT0>GUi@3QhN40h>3P0080i>CT00T0h>3P0=kN
gP3GemL0cLg=0=7Ad@3EeMD0c/k>0=CDe03Hf=P00P3Kfm/0<`3IfMT0d];B0=;BdP3EeMD0e=CD0=3@
d039bLT0b/[:0;no_`2g]kL0][Jf0;:b/P2_[jl0[:b/0:f][@2_[jl0`l?30<g=c@3Bd]80emOG0=;B
dP32`/80_[jn0=;BdP3MgMd0emOG0=GEe@3<c<`0a<C40;fm_@31`L40^k^k0<K6aP3:b/X0bl_;0=7A
d@3?cll0e]KF0=_Kf`3UiND0i>CT0>7Qh@3Rh^80gMgM0=SHf03Bd]80_Kfm0:>SX`2WYjL0_Kfm0<O7
a`0=ooooo`004?ooool0201@D500DU9B059BDP1?Cdl0Bd];04Y:BP1<C4`0BDU90P18B4P204M7A`0<
04Y:BP1<C4`0BTY:04E5A@1;Bd/0CDe=04U9B@16ATH0B4Q804U9B@1:BTX0BDU90`18B4P03P17AdL0
BTY:04Q8B014A4@0AdM704e=C@1<C4`0ATI604M7A`18B4P0BDU904M7A`16ATH0CDe=0P1:BTX0301?
Cdl0CDe=051@D01HF5P0GUiN04i>CP17AdL0ATI604M7A`1;Bd/0FEUI061PH080Hf=S00P0EeMG05mO
G`1[Jf/0Lg=c069RHP1ADE40G5aL075aL@80Ogmo02/0KVi^04e=C@16ATH0Bd];04e=C@1<C4`0Cdm?
05IFEP1:BTX0EUIF06MWI`1EEED0B4Q804I6AP1>CTh0GemO07inOP2ATI40Xj>S0:b/[02`/;00^[Zj
0;bl_02k^k/0_;bl0;6a/@2FUYH0HF5Q04e=C@1EEED0B4Q803hn?P1EEED0K6a/07=cL`1[Jf/0Fe]K
05UIF@1CDe<0ADE503hn?P10@400A4A40080?clo00P0@T9203`l?00o?cl0?Cdm03`l?00m?Cd0?3`l
03dm?@80@41000D0@D5103hn?P0l?3`0?3`l03/k>`0203`l?00<03Xj>P0l?3`0>CTi03/k>`0o?cl0
>SXj03`l?00o?cl0>SXj03`l?00i>CT0>c/k0P10@4001P0o?cl0?3`l03`l?00m?Cd0@D510410@080
>c/k00<0?3`l03Xj>P0l?3`00P0l?3`04011@D40?Shn03`l?00m?Cd0?Shn03lo?`14A4@0?Shn03dm
?@0j>SX0?3`l03lo?`0n?Sh0?3`l03dm?@0n?Sh203dm?@80?clo00`0@d=30492@P0k>c/0?3`l03hn
?P0l?3`0?Cdm03`l?00h>3P0?Cdm03lo?`11@D4203`l?00403Ti>@0n?Sh0?Shn03`l?080>c/k01<0
?3`l03hn?P0l?3`0?Shn0451@@0k>c/0?3`l03/k>`0i>CT0?3`l03dm?@0k>c/0?Cdm03hn?P0h>3P0
>SXj03dm?@0j>SX0>c/k0080>3Ph00H0=cLg03Xj>P10@400@41003lo?`0j>SX203hn?P0603/k>`0j
>SX0>c/k03/k>`0m?Cd0?Shn0P0l?3`203/k>`0503Hf=P0k>c/0>c/k03Ph>00k>c/00P0i>CT0300j
>SX0>CTi03/k>`0j>SX0?Cdm03hn?P0m?Cd0>SXj03/k>`0l?3`0>3Ph03Xj>P80>CTi00<0>c/k03Lg
=`0k>c/0100k>c/06P0l?3`0>CTi03Xj>P0j>SX0?3`l03/k>`10@400?3`l03Xj>P0n?Sh0>SXj03Ph
>00i>CT0ATI607UiN@24Q8@0F5QH05ADE01`L700QhN707AdM01^KVh0Fe]K04Y:BP0m?Cd0>SXj0P0h
>3P20410@00603`l?00j>SX0>c/k03Ti>@0h>3P0>SXj0P0h>3P203lo?`0A03Ti>@0g=cL0?3`l03Xj
>P0i>CT0>SXj03hn?P0j>SX0@T9204A4A00m?Cd0?Shn03`l?00n?Sh0?Cdm0410@00o?cl00P0k>c/0
200o?cl0@41004U9B@1GEeL0Hf=S06m_K`1NGUh0DE5A0P0o?cl04P10@400?Cdm03/k>`0m?Cd0>c/k
03Xj>P0l?3`0>c/k03lo?`0k>c/0>CTi03`l?00o?cl0?3`l03/k>`0h>3P0>CTi03Xj>P80>c/k00d0
>3Ph03dm?@0l?3`0?Cdm03`l?00m?Cd0?3`l0451@@0n?Sh0>c/k03hn?P0g=cL0>SXj0080?Cdm02D0
?3`l0451@@11@D40?Shn05iNGP23Ph<0^[Zj0<O7a`2d];@0UYJF07emO@1JFUX0D51@059BDP1LG5`0
KFe]0861P@2XZ:P0^[Zj0;Fe]@2FUYH0Ng]k05eMG@1=CDd0BTY:04M7A`1>CTh0IVIV08J6QP2c/k<0
b<S80=gMg@3Ogml0fMWI0<k>cP2o_kl0[Zj^0080Zj^[03d0/K6a0;Vi^@3?cll0f=SH0>?Sh`3Ph>00
b<S80;Ng]`2j^[X0_;bl0;:b/P2n_[h0clo?0=SHf03Jf]X0c/k>0;no_`2h^;P0]KFe0;Jf]P2o_kl0
[Zj^0:n_[`2l_;`0alO70=7Ad@3Ng]h0g=cL0=gMg@3Lg=`0f][J0=GEe@3Bd]80e]KF0=3@d03AdM40
fm_K0=?Cd`3>c/h0`L710:f][@2VYZH0[Jf]0:JVYP2[Zj/0YZJV0:^[Z`2o_kl0_Kfm0;Vi^@30`<00
b<S80<G5a@33`l<0a<C40<?3``2k^k/0`<300<S8b03;bl/0cLg=0080e=CD3Oooool0013ooooo0P1>
CTh01@1;Bd/0BDU904a<C01=CDd0C4a<00<0BDU90180BTY:04M7A`1;Bd/0AdM704I6AP19BDT0AdM7
04Q8B019BDT0ATI604M7A`19BDT0B4Q804M7A`18B4P0BDU904E5A@14A4@204I6AP0L04A4A019BDT0
Bd];04E5A@18B4P0BTY:04A4A016ATH0ADE503hn?P13@d<0@T9204U9B@15ADD0ATI604E5A@16ATH0
Bd];04I6AP13@d<0AdM70410@014A4@0AdM705EEE@1NGUh0IVIV051@D080ATI603H0Bd];04i>CP1F
EUH0IfMW07YjNP1lO7`0IVIV05EEE@1UIFD0N7Qh09NGU`2LW9`0I6AT04Y:BP11@D40@T9204Q8B015
ADD0?Shn04=3@`12@T80AdM704I6AP1@D500BDU905MGE`22PX80[Jf]0;^k^`2][Jd0UiNG0;Bd]02c
/k<0[Zj^09fMW@25QHD0Y:BT09jNWP1gMgL0IVIV05ADE01WIfL0P8200;Fe]@2d];@0TY:B08Z:RP1e
MGD0I6AT0492@P11@D40?clo0451@@10@40403dm?@80>c/k0`0o?cl01`0l?3`0?clo03dm?@0j>SX0
?3`l03dm?@0k>c/00P0i>CT203Xj>P0503Ti>@0j>SX0@D5103hn?P10@4000P0n?Sh01P10@400?clo
03`l?00j>SX0>CTi03/k>`80?Cdm00<0?clo03hn?P0l?3`00P0k>c/06`0l?3`0?Shn03dm?@0k>c/0
?Cdm03Ph>00k>c/0A4A404E5A@10@400>c/k03`l?00m?Cd0?clo0451@@0k>c/0?clo0410@00m?Cd0
?Shn04M7A`0m?Cd0@4100451@@0l?3`0?Shn03/k>`0303lo?`0603`l?00j>SX0?3`l03hn?P0i>CT0
?3`l0P0k>c/01@0m?Cd0?3`l03Xj>P0k>c/0?3`l00<0?Cdm0`0l?3`203Xj>P0803dm?@0k>c/0>3Ph
03Xj>P12@T80?Cdm03Ph>00n?Sh203/k>`0903Ti>@0m?Cd0>SXj03/k>`0o?cl0?3`l03lo?`10@400
@D5100@0>c/k01L0?3`l03Ti>@0h>3P0>c/k03Ph>00i>CT0>c/k03Ph>00k>c/0>SXj03Ti>@0k>c/0
=cLg03`l?00h>3P0=cLg03/k>`0l?3`0?Cdm03lo?`0n?Sh0?clo0451@@0203Xj>P<0?Cdm00T0>CTi
03Lg=`0o?cl0?3`l03/k>`0l?3`0>c/k03dm?@0j>SX00P0i>CT07P0l?3`0?Cdm03dm?@0h>3P0=CDe
03`l?00h>3P0?Cdm04I6AP1dM7@0UIFE08N7Q`1kNg/0NWYj07]kN`1[Jf/0Bd];03Xj>P0l?3`0>SXj
03Ph>00l?3`0>SXj03/k>`10@400>SXj03Ti>@0k>c/0>CTi03Lg=`80>CTi00d0>SXj03dm?@0m?Cd0
>CTi03/k>`0i>CT0>3Ph03Lg=`0j>SX0>3Ph03lo?`0k>c/0@4100080@D5102<0?3`l03Xj>P0l?3`0
>c/k03dm?@0k>c/0?3`l0410@013@d<0G5aL06i^KP1/K6`0I6AT04m?C`0l?3`0?Cdm03`l?00o?cl0
?Cdm0451@@0k>c/0>CTi03/k>`0o?cl0?Shn03`l?00o?cl0?Shn03dm?@0l?3`0>c/k03Xj>P0k>c/0
>SXj0410@00203dm?@0=03Ph>00k>c/0?Cdm03/k>`0m?Cd0>SXj03`l?00k>c/0?3`l03/k>`0j>SX0
?Cdm03Xj>P0203Ti>@0e03Xj>P12@T80G5aL08Z:RP2][Jd0/K6a0:VYZ@2=SHd0O7al07emO@2:RXX0
V9RH0:b/[02e]KD0^[Zj0<K6aP3>c/h0]KFe08^;R`1MGEd0DU9B0492@P11@D40BDU9065QH@22PX80
Vi^K0;^k^`3AdM40f][J0=cLg03<c<`0`<300:RXZ02ATI40O7al08N7Q`2;Rh/0X:2P0;6a/@2o_kl0
b/[:0<71`@2ZZZX0SXj>07]kN`1hN7P0P82009jNWP2j^[X0cLg=0=_Kf`3UiND00P3Ogml0203Ti>@0
h>3P0=cLg03MgMd0g]kN0>3Ph03MgMd0hN7Q0`3Shn<09@3Ti>@0hn?S0=kNgP3GemL0dM7A0=GEe@3H
f=P0g]kN0>7Qh@3Ng]h0fm_K0=3@d033`l<0^[Zj0:VYZ@2SXj<0/;2`0;fm_@2o_kl0[jn_0:6QX@2V
YZH0/[:b0;6a/@2i^KT0][Jf0:n_[`2][Jd0[Zj^0:RXZ02e]KD0a/K60<O7a`2o_kl0^KVi0<G5a@3K
fm/03Oooool0013ooooo00P0DE5A051@D01=CDd0CDe=04U9B@1=CDd0Bd];04M7A`<0B4Q800H0ADE5
04M7A`1:BTX0B4Q804A4A015ADD304I6AP0904M7A`19BDT0B4Q804I6AP15ADD0A4A404E5A@17AdL0
B4Q80080AdM700H0BTY:04];B`18B4P0Bd];04U9B@15ADD204I6AP0604Q8B016ATH0@T920451@@10
@400@d=30P17AdL07`16ATH0A4A40451@@18B4P0BDU904a<C018B4P0Bd];055AD@1HF5P0E5AD05MG
E`1TI6@0MWIf09NGU`2FUYH0M7Ad05EEE@19BDT0Cdm?05mOG`1]KFd0OWin08j>SP1oOgl0H61P06EU
I@1KFe/0EUIF05aLG01PH6000P1FEUH0:@1ADE40Bd];04Y:BP1;Bd/0BTY:04m?C`1CDe<0I6AT06EU
I@1SHf<0Ogmo08N7Q`2EUID0Y:BT0:VYZ@33`l<0emOG0<_;b`2b/[80TY:B09bLW02f][H0ZJVY08J6
QP24Q8@0MGEe08V9R@2JVYX0UiNG079bLP1ADE40@41005ADE01/K6`0MgMg075aL@1WIfL0HF5Q05iN
GP1ADE40B4Q80080?Shn0P0m?Cd01`0o?cl0?3`l03hn?P1=CDd0?Cdm03`l?00n?Sh00P0m?Cd03@0k
>c/0?Cdm03/k>`0j>SX0?Cdm03lo?`10@400?3`l03lo?`12@T80@D5103`l?00j>SX00P0k>c/02@0j
>SX0=cLg03Ph>00i>CT0>SXj03`l?00o?cl0?3`l03Xj>P0203dm?@80?3`l00D0?Shn0451@@0m?Cd0
?Shn03Ti>@0203lo?`0803Ph>00k>c/0?Cdm03hn?P0o?cl0AdM70410@011@D4203`l?00303dm?@0j
>SX0?Shn00<0?Cdm0P0k>c/00`0n?Sh0>SXj03Ti>@0203/k>`0603Lg=`0j>SX0>c/k03/k>`0i>CT0
>3Ph0`0k>c/00`0m?Cd0>SXj03Ti>@0203Xj>P0;03hn?P0l?3`0>CTi03`l?011@D40BTY:04=3@`10
@400?3`l03Xj>P0l?3`00`0n?Sh203dm?@0=0410@013@d<0?Shn04A4A00o?cl0>SXj03dm?@0l?3`0
?Shn03dm?@0g=cL0?Cdm03/k>`0203`l?00:03/k>`0j>SX0>c/k03Lg=`0j>SX0=CDe03Xj>P0m?Cd0
>SXj03/k>`80>SXj00@0@41003hn?P0n?Sh0?clo0P0i>CT0300j>SX0>3Ph03Ph>00k>c/0?Shn03lo
?`0k>c/0?Cdm03`l?00j>SX0>CTi03/k>`80>SXj0140?Cdm03`l?00i>CT0?clo059BDP1SHf<0Ph>3
09JFUP2PX:00SHf=06MWI`1:BTX0?Shn03dm?@0h>3P0?Cdm03Ti>@0303`l?00C03Ti>@0l?3`0?clo
03/k>`0l?3`0?clo03dm?@0k>c/0?3`l03Ph>00i>CT0?Cdm03Xj>P0h>3P0>SXj03Hf=P0l?3`0?Cdm
04E5A@0203Ti>@0K03`l?00o?cl0?Shn03hn?P13@d<0?Shn03dm?@0k>c/0?3`l03Ph>00k>c/0ATI6
04M7A`12@T80?Cdm03Ti>@0m?Cd0>SXj03/k>`0n?Sh0>SXj03lo?`0m?Cd0?clo03dm?@0n?Sh0>CTi
0080>c/k00@0?3`l03dm?@0h>3P0>3Ph0P0m?Cd04P0l?3`0>CTi03Xj>P12@T80?3`l03hn?P0j>SX0
?Shn03Xj>P0i>CT0>3Ph03Ti>@0j>SX0>3Ph03Xj>P0i>CT0>SXj03`l?080>c/k02H0ADE506MWI`2V
YZH0W9bL08B4Q01/K6`0EEEE05=CD`1bLW80U9BD09NGU`2@T900Q8B408J6QP2>SXh0N7Qh06i^KP1C
De<0AdM703lo?`18B4P0GemO071`L02OWil0a<C40<G5a@39bLT0[:b/09NGU`27QhL0O7al06m_K`1h
N7P0TY:B0;no_`3>c/h0b/[:0=7Ad@80d=3@00`0a<C40:JVYP2CTi<0QXJ6096AT@2MWId0`<300<g=
c@3EeMD0g]kN0=WIf@3Kfm/20=kNgP0N0=GEe@3De=@0g=cL0<_;b`2a/K40Zj^[0;Vi^@3:b/X0f=SH
0=OGe`3MgMd0g]kN0=OGe`3EeMD0e=CD0=7Ad@2m_Kd0[:b/09jNWP2CTi<0WIfM0;Bd]03EeMD0f][J
0=OGe`3Cdm<0clo?0<S8b03@d=00e=CD0P3Bd]804P38b<P0_[jn0;^k^`33`l<0bl_;0<c<c034a<@0
`L710<W9b@36a/H0/k>c0:NWY`2LW9`0QXJ60820P01hN7P0PH6109FEU@gooooo000@ooooo`<0CTi>
00D0CDe=04a<C01>CTh0CTi>04];B`0504Y:BP80BDU900@0B4Q804E5A@15ADD0ATI60P14A4@03P16
ATH0AdM704E5A@15ADD0A4A404E5A@1<C4`0CDe=04U9B@1;Bd/0AdM704I6AP17AdL0B4Q80P15ADD0
1`14A4@0ADE504I6AP17AdL0BDU904Y:BP15ADD00P12@T801017AdL0CTi>05=CD`18B4P204m?C`0L
04Y:BP1;Bd/0DE5A05ADE01HF5P0DE5A059BDP1ADE40G5aL07=cL`1oOgl0MWIf06EUI@1]KFd0JFUY
05mOG`1?Cdl0C4a<04Y:BP1>CTh0ADE5055AD@1EEED0BDU904I6AP1<C4`0E5AD04m?C`80DE5A00L0
C4a<04i>CP1?Cdl0CDe=04m?C`1VIVH0JFUY0080ATI602h0C4a<05ADE01GEeL0CTi>05QHF01VIVH0
KFe]06a/K01PH600Ng]k0:RXZ02QXJ40Zj^[0;no_`2WYjL0Ph>307IfMP1NGUh0PH6106QXJ017AdL0
G5aL09>CT`2m_Kd0`L710:n_[`27QhL0Ti>C08^;R`1oOgl0L71`04Q8B010@400BDU903hn?P10@400
@T9204A4A00n?Sh0?Cdm03`l?00k>c/0?Cdm03hn?P0m?Cd0?Shn0P0k>c/00`0l?3`0>c/k03Ti>@02
03/k>`0303dm?@0l?3`0>CTi0080?3`l00<0>SXj03hn?P0j>SX00P0j>SX04@0l?3`0@T9203/k>`12
@T80@D5103dm?@10@400?Cdm04=3@`15ADD0?Shn03lo?`0m?Cd0>c/k03dm?@0l?3`0>CTi0080?Shn
01P0?3`l03lo?`12@T80?Cdm03lo?`11@D40?Cdm03hn?P0k>c/0?3`l03hn?P0l?3`0?Cdm03hn?P0j
>SX0?Shn03/k>`0j>SX0?Cdm03Ph>00k>c/0>SXj03`l?00k>c/203`l?080>c/k00@0?Shn03dm?@0l
?3`0>c/k0P0j>SX0100m?Cd0>c/k03/k>`0l?3`203lo?`0=03`l?00o?cl0>3Ph03/k>`0j>SX0@T92
03Ti>@0l?3`0>SXj03dm?@12@T80@D5103hn?P0204=3@`0803`l?00h>3P0>c/k03`l?00k>c/0@T92
03Ph>011@D4203`l?00803Ti>@0j>SX0>SXj03/k>`0i>CT0>3Ph03`l?00m?Cd303/k>`0<03Xj>P0k
>c/0?Cdm03hn?P0k>c/0?3`l03Xj>P0m?Cd0>c/k03dm?@0k>c/0?Shn0P0i>CT203/k>`0>03Ph>00l
?3`0>SXj03`l?00n?Sh0>c/k04a<C01VIVH0Lg=c06=SH`1VIVH0KFe]05]KF`13@d<203Ti>@0H03dm
?@0h>3P0?Shn03`l?00i>CT0=SHf03/k>`10@400?Shn03Xj>P0h>3P0>CTi03/k>`0l?3`0?clo03`l
?00i>CT0?3`l03Ti>@0l?3`0?Shn03Xj>P0h>3P0>c/k0P0j>SX01@14A4@0?3`l03Ti>@0o?cl0@T92
0080>c/k00X0?clo03hn?P0l?3`0>SXj03Ti>@0n?Sh0@41004=3@`10@400@D510P13@d<05P0n?Sh0
?Cdm03lo?`11@D40?Cdm03/k>`0l?3`0?Shn03Xj>P11@D40>SXj03dm?@0l?3`0?Shn03dm?@0k>c/0
?3`l03lo?`0n?Sh0?3`l03Xj>P0l?3`203lo?`0603`l?00k>c/0?clo03lo?`0l?3`0>3Ph0P0i>CT0
4P0h>3P0>c/k03Ti>@0i>CT0?Shn04i>CP1WIfL0OGem06YZJP1;Bd/0@D5104a<C01MGEd0MgMg07in
OP1YJFT0DE5A0492@P<0?clo0180>SXj03lo?`0l?3`0?3`l0492@P13@d<0E5AD071`L01nOWh0Ogmo
07=cL`1KFe/0DE5A051@D01ADE40EeMG05IFEP1NGUh2061PH080IFEU0140JFUY06a/K02;Rh/0WYjN
0;Bd]03<c<`0f=SH0>3Ph03Ng]h0gmoO0=kNgP3Hf=P0d=3@0<O7a`30`<00]KFe0:JVYP0209>CT`0:
09BDU02ATI40TI6A09RHV02UYJD0][Jf0<_;b`3MgMd0h^;R0>?Sh`80i>CT00T0hN7Q0>3Ph03Kfm/0
fm_K0=KFeP3?cll0`l?309jNWP2XZ:P00P33`l<06P39bLT0`L710:RXZ02MWId0WYjN0:ZZZP2XZ:P0
aLG50=3@d03<c<`0^;Rh0;Bd]032`/80d=3@0=SHf03>c/h0/k>c09FEU@2:RXX0Q8B409>CT`2HV9P0
XZ:R0:JVYP2LW9`0SHf=3Oooool0013ooooo00H0BTY:04a<C01@D500CDe=04a<C01:BTX204];B`06
04I6AP17AdL0BDU904Y:BP18B4P0ADE50P16ATH01013@d<0ADE504E5A@14A4@304E5A@0704A4A015
ADD0ATI604E5A@19BDT0CDe=04I6AP0204E5A@0304I6AP15ADD0ADE50080A4A40P15ADD02014A4@0
@d=30492@P16ATH0A4A404=3@`18B4P0ATI60P18B4P02`15ADD0@D5104=3@`16ATH0AdM704I6AP14
A4@0ADE50492@P13@d<0@4100080ATI600/0ADE504Q8B01ADE40EEEE06=SH`1bLW80GEeM04];B`1:
BTX0C4a<04M7A`020492@P0504];B`18B4P0B4Q804e=C@1;Bd/00P1>CTh01P1GEeL0GUiN06EUI@1S
Hf<0Fe]K05aLG080IFEU00h0FUYJ04Q8B011@D40BTY:06QXJ01cLg<0J6QX05QHF01:BTX0CTi>04e=
C@1HF5P0DE5A05QHF080MGEe01/0FEUI05ADE01ADE40DE5A06IVIP1/K6`0HV9R04i>CP1ADE40I6AT
05aLG01GEeL0Fe]K06IVIP1dM7@0QhN709NGU`24Q8@0M7Ad06a/K01DE5@0AdM703`l?00o?cl0?Shn
04M7A`1ADE400P1BDU803@13@d<0?Shn03/k>`0k>c/0?3`l03/k>`0l?3`0?Cdm03/k>`0l?3`0?Cdm
03Ti>@0g=cL00P0h>3P00`0l?3`0>c/k03/k>`0203/k>`0;03lo?`0m?Cd0?clo03/k>`0m?Cd0@T92
03`l?00o?cl0@d=303lo?`10@4000P0k>c/01@0n?Sh0?clo03`l?00k>c/0?3`l00<0?Cdm00`0?Shn
04E5A@0m?Cd0>c/k03lo?`0k>c/0?clo03dm?@0j>SX0>c/k03Xj>P0f=SH203/k>`0503Ti>@0k>c/0
=cLg03hn?P0m?Cd00P0k>c/203`l?00703hn?P0m?Cd0?Shn03hn?P0m?Cd0@D5103lo?`0203hn?P80
?3`l00@0?Shn03`l?00k>c/0?3`l0P0m?Cd01`0j>SX0?Shn04=3@`16ATH0?Cdm03/k>`0l?3`00P10
@4003@0n?Sh0@T9203dm?@0n?Sh0>3Ph03Ti>@10@400@D5103lo?`0j>SX0?clo03`l?00j>SX00`0i
>CT203hn?P0=03/k>`0l?3`0>CTi03Ph>00k>c/0?3`l03hn?P0i>CT0>SXj03/k>`0o?cl0?Shn03`l
?00203Xj>P0:03hn?P0j>SX0>c/k03Ph>00n?Sh0>c/k03hn?P0h>3P0ADE504e=C@80@d=300@0>SXj
03hn?P0o?cl0?clo0P13@d<0200k>c/0>SXj03De=@0h>3P0>SXj03dm?@0n?Sh0?3`l0P0h>3P03`0k
>c/0?Cdm03/k>`0j>SX0>c/k03`l?00i>CT0>3Ph03Ti>@0g=cL0>SXj03/k>`0m?Cd0>CTi03Xj>P02
03hn?P0S03Xj>P0l?3`0?3`l03/k>`10@400?Cdm03Lg=`10@400>c/k03Xj>P0l?3`0?Shn04=3@`15
ADD0A4A40410@012@T80>CTi03/k>`0n?Sh0?3`l04U9B@1TI6@0GemO05QHF018B4P0?Cdm03/k>`0i
>CT0>SXj03/k>`0g=cL0?3`l03De=@0m?Cd00P0h>3P02@0j>SX0?3`l03/k>`0m?Cd0@41003hn?P0j
>SX0A4A403hn?P0303Xj>P0603/k>`0h>3P0=SHf03Ti>@0h>3P0>CTi0`0k>c/03@1<C4`0NWYj07em
O@1DE5@0@D5103Xj>P1>CTh0GemO07=cL`1YJFT0GEeM04M7A`0k>c/00P0n?Sh04`0o?cl0>c/k03dm
?@0l?3`0@D510410@017AdL0B4Q804=3@`1;Bd/0De=C05]KF`1bLW80OGem07AdM01UIFD0C4a<04I6
AP0n?Sh00`0l?3`07@16ATH0DU9B05MGE`1NGUh0KVi^092@T02TY:@0ZJVY09^KV`2?Shl0Ogmo07Mg
M`1bLW80IVIV05aLG01BDU80ATI60410@012@T80AdM705YJFP1hN7P0TI6A0:BTY02k^k/0bl_;0=KF
eP3Bd]80c/k>0080b/[:01/0alO70<71`@30`<00_[jn0<_;b`3Bd]80d=3@0;Vi^@33`l<0emOG0=cL
g03Hf=P0dM7A0<30`031`L40`<300;Vi^@2n_[h0`<300<k>cP3?cll0e=CD0=KFeP33`l<0];Bd0:VY
Z@2OWil00P2^[Zh02@2KVi/0Ogmo06IVIP1MGEd0LG5a09>CT`2IVIT0UiNG0:NWY`020:^[Z`gooooo
000@ooooo`<0C4a<00D0Bd];04a<C01:BTX0BDU904];B`0404U9B@80B4Q800P0AdM704I6AP15ADD0
A4A404=3@`14A4@0ADE504I6AP<0ADE500<0AdM704I6AP15ADD00P17AdL02P1;Bd/0AdM704I6AP14
A4@0ATI604A4A013@d<0A4A40451@@12@T8304E5A@80@T9201h0A4A40451@@0o?cl0@D510492@P15
ADD0BTY:04I6AP13@d<0@D510410@014A4@0ADE504=3@`14A4@0@d=304E5A@0o?cl0?Shn0492@P15
ADD0@41004Q8B014A4@0@41004=3@`15ADD0A4A40451@@12@T820410@00804=3@`0n?Sh0@41003lo
?`14A4@0@T920451@@16ATH20492@P0A04e=C@1PH600KFe]06YZJP1XJ6P0IfMW06a/K01fMWH0OWin
07YjNP1iNGT0Kfm_069RHP1WIfL0IVIV06YZJP1bLW800P1iNGT06@1eMGD0KVi^07=cL`1WIfL0Ogmo
09FEU@2MWId0Vi^K08R8R01OGel0GEeM05]KF`1TI6@0IfMW05QHF01WIfL0[Zj^0;Rh^01kNg/0EeMG
04a<C013@d<0?Shn03lo?`0m?Cd00`10@4001`11@D40?clo03dm?@0m?Cd0?3`l03hn?P0k>c/00`0l
?3`01P0m?Cd0?3`l03/k>`0l?3`0?Cdm03`l?080>SXj00D0?3`l03hn?P0n?Sh0?clo03`l?00203dm
?@0;03lo?`14A4@0@41003hn?P12@T80?3`l03dm?@0l?3`0>SXj03Ti>@0h>3P00P0j>SX04@0i>CT0
>3Ph03`l?00j>SX0?Cdm0492@P0o?cl0?3`l03/k>`0m?Cd0>c/k03lo?`10@400?3`l03Ph>00j>SX0
>CTi0080>SXj0P0l?3`03`0o?cl0>c/k03Xj>P0n?Sh0>3Ph03/k>`0l?3`0?Cdm03/k>`0m?Cd0?3`l
03/k>`0n?Sh0?clo03/k>`0203dm?@0?0410@00j>SX0>c/k03lo?`0l?3`0@D5103dm?@10@400>SXj
04A4A010@400>SXj03`l?00n?Sh0>SXj0080?3`l01<0?Cdm03`l?00j>SX0?Shn0410@00l?3`0>CTi
03`l?00j>SX0?3`l03Xj>P0k>c/0>3Ph03`l?00j>SX0>CTi03Xj>P0i>CT0>SXj00<0?Cdm00L0>c/k
03Ti>@0j>SX0?Shn03Ti>@0k>c/0?Shn0080?3`l00`0@d=303hn?P0m?Cd0>3Ph03hn?P0g=cL0B4Q8
04I6AP1>CTh0@41003`l?00n?Sh203Xj>P0503lo?`0j>SX0?Shn03lo?`0l?3`00P0k>c/203Xj>P03
03Ph>00j>SX0=cLg0080>SXj00l0>c/k03Xj>P0m?Cd0?Shn03Xj>P0n?Sh0?Cdm03Ti>@0k>c/0>SXj
03Ph>00g=cL0>SXj03Lg=`0i>CT00P0l?3`08`0k>c/0>CTi03lo?`12@T80?clo0451@@0l?3`0?Cdm
03`l?00k>c/0=cLg0410@016ATH0Bd];04=3@`0l?3`0?Cdm0492@P1;Bd/0EUIF06EUI@1WIfL0GEeM
05=CD`12@T80>c/k03Ti>@0j>SX0>CTi0451@@0n?Sh0>SXj03`l?00k>c/0@T920080>c/k00D0?Cdm
03hn?P0j>SX0>CTi03lo?`0203`l?080>CTi00<0?Cdm03lo?`0n?Sh00P0l?3`05`0i>CT0>SXj03Ti
>@0i>CT0>SXj03Ti>@15ADD0JFUY04];B`16ATH0Cdm?05eMG@1SHf<0Fe]K04E5A@0n?Sh0?clo03/k
>`10@400>c/k03`l?00j>SX0@4100080?Cdm00@0?Shn04=3@`12@T80E5AD0P1[Jf/04P24Q8@0RXZ:
08>3P`1dM7@0GUiN04M7A`0o?cl0>CTi03hn?P14A4@0ATI604U9B@1ADE40FEUI05=CD`1<C4`0@d=3
0451@@80>c/k00<0?Shn03`l?00n?Sh00P0n?Sh08P10@400ADE503`l?00o?cl0@D5104I6AP1HF5P0
N7Qh09RHV02[Zj/0YjNW08n?S`1gMgL0L71`06UYJ@1`L700NGUi07moO`2:RXX0Ti>C09fMW@2k^k/0
alO70<k>cP3EeMD0clo?0;no_`2e]KD0/K6a0;:b/P2d];@0_;bl0<o?c`3AdM420=?Cd`80f=SH01D0
e]KF0=[JfP3EeMD0a/K60<;2`P38b<P0eMGE0=KFeP3@d=00cLg=0<;2`P2m_Kd0_;bl0;Vi^@3=cLd0
bl_;0<71`@2n_[h0^;Rh0;Ng]`2c/k<03Oooool0013ooooo00P0DU9B055AD@1<C4`0CDe=04];B`1<
C4`0BTY:04a<C080B4Q80P17AdL01018B4P0A4A404I6AP14A4@204I6AP0404Q8B014A4@0B4Q804M7
A`80ADE500D0A4A404I6AP17AdL0AdM704U9B@0304M7A`0704Q8B017AdL0ATI604I6AP11@D40ATI6
04Y:BP0204I6AP050492@P14A4@0@T920492@P10@4000P15ADD04016ATH0A4A40410@013@d<0@T92
04E5A@17AdL0ADE504=3@`15ADD0@T9204I6AP10@400@d=30492@P0n?Sh20410@00603dm?@17AdL0
@41003`l?00n?Sh0@4100P14A4@02`0o?cl0?Cdm04E5A@12@T80?Cdm03`l?010@400?clo03hn?P10
@400@d=30080@D5102`0?Shn0492@P11@D40?clo04I6AP12@T80ATI60492@P13@d<0@D510410@01A
DE40LW9b06i^KP1DE5@0Fe]K061PH01VIVH0HF5Q075aL@1dM7@0N7Qh07IfMP1gMgL0PH6109FEU@28
R8P0M7Ad075aL@1iNGT0IFEU05iNGP1IFET0BDU905QHF01]KFd0KVi^059BDP16ATH0J6QX06m_K`20
P800I6AT04];B`<0AdM700h0Bd];05IFEP1QHF40Lg=c08N7Q`24Q8@0M7Ad05iNGP16ATH0?Cdm03lo
?`0k>c/0?3`l03lo?`<0?3`l01`0>c/k03`l?00m?Cd0?Cdm03`l?013@d<0B4Q80410@00n?Sh0@D51
03hn?P0l?3`0>c/k0410@00n?Sh0>CTi03/k>`0j>SX0?Cdm03hn?P0l?3`0=SHf03`l?00j>SX0>3Ph
03/k>`0l?3`0?Shn0P0l?3`04P0o?cl0>CTi03`l?00o?cl0>3Ph03Ti>@0n?Sh0>c/k03`l?00k>c/0
?Cdm03Xj>P0k>c/0?Cdm03hn?P11@D40>c/k03hn?P<0>SXj00<0>c/k03lo?`0m?Cd00P11@D406018
B4P0@41003lo?`0m?Cd0>CTi03/k>`0o?cl0@T9203lo?`0n?Sh0@D510410@012@T80ADE503/k>`0i
>CT0>SXj03Ph>00n?Sh0>SXj03/k>`0o?cl0>SXj03Lg=`80>SXj0240?3`l03Ph>00l?3`0>c/k03dm
?@0l?3`0>3Ph03dm?@0j>SX0?Shn0451@@0i>CT0>SXj03/k>`0j>SX0>CTi03Xj>P0l?3`0>SXj03Ph
>011@D40?Cdm03`l?00j>SX0?Cdm04A4A00h>3P0>c/k03hn?P0o?cl0D51@06ATI00n?Sh00P0j>SX0
1P0o?cl0>SXj03Hf=P0f=SH0?Shn03Xj>P80>c/k00d0?3`l03hn?P0l?3`0>3Ph03Xj>P0l?3`0=cLg
03Xj>P0f=SH0>3Ph03Ti>@0l?3`0?Shn0080>CTi01<0?Cdm03`l?00j>SX0>3Ph0451@@0o?cl0?Cdm
03Xj>P0f=SH0>CTi03dm?@0g=cL0=SHf03Xj>P0k>c/0>SXj03Ti>@0j>SX0>CTi0080?Cdm00H0>SXj
0410@00n?Sh0?Shn0492@P11@D420492@P0:04U9B@1:BTX0?Shn03/k>`0m?Cd0>SXj03/k>`0h>3P0
?clo0410@080>c/k00L0@d=303hn?P0k>c/0>SXj03/k>`19BDT0?clo0080?3`l00D0?Cdm03`l?00j
>SX0?Shn03Xj>P0203Ti>@0703Xj>P0f=SH0>SXj03Lg=`0k>c/0@D5103dm?@0303Xj>P0@03/k>`15
ADD0Cdm?05iNGP1mOGd0Xj>S092@T01WIfL0A4A403Ph>00j>SX0?3`l03dm?@0k>c/0>CTi03dm?@80
?3`l01/0?Cdm03/k>`0k>c/0CTi>061PH01hN7P0OGem0861P@1]KFd0Fe]K059BDP11@D40>CTi03Xj
>P0h>3P0?clo03dm?@0l?3`0BTY:04Q8B010@400>CTi03Xj>P0i>CT0>3Ph03Xj>P0f=SH00P0j>SX2
03`l?00c03dm?@0h>3P0?Shn03`l?00m?Cd0@d=304];B`1KFe/0JVYZ06IVIP1bLW80Kfm_07IfMP1i
NGT0Q8B409^KV`2c/k<0^;Rh0;no_`3@d=00e]KF0=GEe@3Fe]H0dM7A0<c<c02l_;`0b<S80=_Kf`3L
g=`0e=CD0=GEe@38b<P0^k^k0;fm_@2g]kL0[:b/0:FUY@2XZ:P0Y:BT0;2`/02b/[80a/K60<k>cP3:
b/X0_[jn0;bl_037alL0c<c<0<C4a02l_;`0/K6a0080^[Zj00T0];Bd0;6a/@2b/[80eMGE0>?Sh`3A
dM40TI6A06e]K@1LG5`03Oooool0013ooooo0P1?Cdl01P1>CTh0Bd];04Y:BP1:BTX0B4Q804Y:BP80
BDU90P16ATH04014A4@0ATI604a<C018B4P0AdM704U9B@1:BTX0@T9204I6AP13@d<0ATI604E5A@13
@d<0AdM704];B`1:BTX504M7A`0T04U9B@17AdL0AdM704M7A`13@d<0A4A403lo?`13@d<0ATI604A4
A016ATH0Bd];04Q8B017AdL0ADE504=3@`14A4@0ADE504I6AP11@D40@41004=3@`16ATH0B4Q804=3
@`1:BTX0B4Q804A4A012@T80@d=30492@P0o?cl0?Shn03lo?`11@D40?3`l0P0o?cl01`13@d<0ADE5
04A4A011@D40?Shn04=3@`10@4000P12@T802011@D40?clo03lo?`10@400?clo04M7A`15ADD0@d=3
0P10@40203hn?P0L04E5A@19BDT0ATI604U9B@1CDe<0J6QX06i^KP1[Jf/0C4a<04M7A`14A4@0@T92
04=3@`11@D40BTY:04Q8B01GEeL0Hf=S07IfMP1ADE40@T9204=3@`12@T80CDe=06EUI@1RHV80IFEU
07=cL`80KVi^00<0P82007QhN01YJFT00P1LG5`05P1HF5P0NGUi0:b/[02o_kl0_Kfm0:j^[P2ATI40
S8b<0:NWY`2k^k/0clo?0<[:bP32`/80dm?C0;jn_P1gMgL0Bd];04A4A00l?3`0?clo04A4A00n?Sh2
0410@00404e=C@1:BTX0@T9203lo?`80?3`l00d0@41003lo?`0l?3`0AdM704A4A00k>c/0?Cdm04=3
@`0m?Cd0?3`l03hn?P0j>SX0>CTi0080>c/k00d0?Cdm0410@00i>CT0?3`l03/k>`0l?3`0?Cdm03lo
?`0n?Sh0>SXj03`l?00n?Sh0?Cdm0080>CTi00L0?Cdm03Xj>P0j>SX0>c/k03dm?@0h>3P0>CTi0080
>SXj00@0?3`l03Xj>P0l?3`0>c/k0P0n?Sh00`0j>SX0>CTi03Xj>P0203lo?`0<0410@00l?3`0?3`l
03`l?00o?cl0>c/k03hn?P11@D40?clo03dm?@0o?cl0@D510`0j>SX01`0k>c/0>CTi03Ph>00i>CT0
>3Ph03`l?00o?cl00P0k>c/02@0j>SX0>3Ph03Lg=`0i>CT0=SHf03Xj>P0m?Cd0>c/k03`l?00203Xj
>P0403Ti>@0j>SX0?Shn03/k>`80>3Ph01T0=cLg03Ph>00h>3P0>CTi03De=@0h>3P0?Cdm03lo?`0n
?Sh0DU9B04=3@`10@400>CTi03Xj>P13@d<0D51@04M7A`10@400>SXj03Ti>@11@D40>CTi03Lg=`0k
>c/0>SXj0080?3`l00`0>c/k03`l?00j>SX0>SXj03`l?011@D40?clo03Ph>00j>SX0=SHf03Lg=`0k
>c/203Xj>P0903Hf=P0i>CT0>c/k03/k>`0l?3`0>SXj03dm?@0l?3`0>c/k0080=cLg00/0>CTi03dm
?@0k>c/0?Cdm0492@P13@d<0>SXj03dm?@0o?cl0?3`l03Xj>P0203`l?00I03Xj>P10@400?clo0410
@00o?cl0>c/k03Ti>@0j>SX0>CTi03Xj>P0i>CT0>c/k03`l?011@D40>c/k03`l?00n?Sh0>SXj03hn
?P0j>SX0>CTi0451@@13@d<0?Shn0451@@0203/k>`80>3Ph00D0>SXj03`l?00l?3`0>c/k03Xj>P02
03`l?00;03/k>`0l?3`0>3Ph0410@00l?3`0>c/k03dm?@1>CTh0Jf][092@T02MWId00P2LW9`06@25
QHD0F5QH04A4A00j>SX0?Cdm03Ph>00i>CT0>SXj03/k>`12@T80@41004M7A`13@d<0A4A404];B`1C
De<0Jf][07QhN01]KFd0GemO055AD@18B4P0@T9203hn?P0g=cL00P0f=SH04@0k>c/0>SXj03Xj>P0k
>c/0>SXj03lo?`14A4@0?3`l03Ti>@0g=cL0>SXj03`l?00h>3P0>CTi03Ph>00i>CT0>3Ph0080>CTi
0P0l?3`07`11@D40?Shn0492@P12@T80CDe=06ATI023Ph<0Y:BT0=7Ad@3Ti>@0gMgM0<_;b`2f][H0
X:2P096AT@1lO7`0Jf][069RHP1KFe/0EEEE05ADE01JFUX0KVi^08b<S02YZJT0/;2`0;Fe]@2_[jl0
XJ6Q08R8R01gMgL00P1/K6`06P1hN7P0O7al07moO`2PX:00]KFe0<S8b03AdM40clo?0=?Cd`3GemL0
fMWI0=KFeP3?cll0bLW90=3@d039bLT0`l?30<S8b034a<@0_[jn0;Vi^@31`L40b<S80:n_[`2IVIT0
Xj>S3Oooool0013ooooo00D0CTi>04a<C01>CTh0CDe=04a<C00204U9B@0904a<C018B4P0BDU904Q8
B017AdL0BDU904M7A`13@d<0BDU90080BTY:00`0B4Q804I6AP1<C4`0AdM704=3@`15ADD0ATI604M7
A`18B4P0ATI604A4A015ADD204=3@`0F04A4A015ADD0A4A404I6AP14A4@0@d=305]KF`1CDe<0ADE5
0492@P16ATH0Bd];04E5A@11@D40?clo0492@P14A4@0@T920410@012@T80@d=30492@P80@D5100T0
@T9203lo?`15ADD0A4A404=3@`0n?Sh0@41003lo?`0l?3`00P0n?Sh00`11@D40@T9203lo?`0203hn
?P0:03lo?`10@400@D510492@P10@400?Shn03dm?@0l?3`0?clo0492@P80?Cdm1010@4003013@d<0
@D5104e=C@1SHf<0LG5a05ADE01CDe<0H61P05EEE@1@D500?Shn0410@080?clo02H0?Cdm03`l?00l
?3`0@41004=3@`1ADE40J6QX09fMW@2/[:`0Ng]k06IVIP1aLG40KFe]069RHP1FEUH0CDe=04m?C`1B
DU80E5AD05YJFP1aLG40WinO0;fm_@2j^[X0];Bd09VIV@1lO7`0Ng]k08b<S02;Rh/0NWYj08F5Q@2R
XZ80Zj^[0;2`/02e]KD0^;Rh0:NWY`80Rh^;00d0S8b<071`L01YJFT0IVIV071`L01bLW80RHV908^;
R`2<S8`0YjNW08F5Q@1TI6@0@T920080@4100P0m?Cd204A4A00:04=3@`0m?Cd0?Shn03dm?@0l?3`0
?Shn0451@@0m?Cd0?3`l03dm?@80>c/k0100?Cdm03Ph>00k>c/0>c/k03dm?@0l?3`0=CDe03Ph>00i
>CT0>c/k03dm?@0i>CT0>SXj03Hf=P0j>SX0>CTi0P0j>SX01P0k>c/0>CTi03/k>`0k>c/0>3Ph03Ti
>@80>3Ph01D0?Cdm03hn?P0l?3`0>c/k03Ti>@12@T80?Cdm03Ti>@0m?Cd0>3Ph03`l?00n?Sh0@T92
03hn?P0o?cl0?Cdm03Xj>P0l?3`0>3Ph03/k>`0m?Cd00P0k>c/06P0i>CT0?3`l03lo?`0j>SX0>3Ph
03`l?00o?cl0?3`l03/k>`0l?3`0>c/k03dm?@0k>c/0>CTi03`l?00m?Cd0=cLg04I6AP10@400?clo
03dm?@0j>SX0?3`l03Xj>P0n?Sh0>3Ph0P0g=cL00`0j>SX0?Shn03`l?00203hn?P0D03/k>`0m?Cd0
?Shn03`l?00k>c/0?Cdm03hn?P13@d<0>c/k04M7A`12@T80>SXj03Ti>@0l?3`0?Cdm03Xj>P0l?3`0
>3Ph03Lg=`0h>3P203Ti>@0503Ph>00m?Cd0?clo03Xj>P0h>3P00`0i>CT02@0h>3P0>SXj03Xj>P0m
?Cd0>SXj03Lg=`0j>SX0?3`l03Xj>P0203hn?P0Z0410@00j>SX0>CTi03Ph>00i>CT0>SXj03dm?@0j
>SX0>c/k03Xj>P0o?cl0?3`l03dm?@0n?Sh0@41003/k>`0m?Cd0ADE50451@@0l?3`0?clo03dm?@0l
?3`0>CTi03De=@0i>CT0@41003/k>`0j>SX0=cLg03/k>`0m?Cd0?Shn03dm?@0l?3`0?Cdm03Ti>@0m
?Cd0@T9203dm?@0g=cL0=3@d0P0j>SX07@0i>CT0?Shn03dm?@0m?Cd0>SXj03Ph>00j>SX0?3`l03dm
?@0l?3`0>c/k03`l?00i>CT0@D5104a<C01hN7P0a<C40=WIf@3;bl/0YZJV06EUI@13@d<0?Shn04A4
A013@d<0?3`l03hn?P0o?cl0?3`l0080?clo00d0BDU905EEE@1`L700Ng]k08Z:RP1nOWh0G5aL05MG
E`11@D40=SHf03Xj>P0i>CT0=cLg00<0>CTi00d0=cLg03Hf=P0g=cL0>CTi03Lg=`0k>c/0?3`l03Xj
>P0k>c/0=SHf03/k>`0l?3`0>CTi0080>c/k01L0>CTi03Ph>00i>CT0>3Ph03Xj>P11@D40DU9B06EU
I@1YJFT0MgMg096AT@2SXj<0`L710=7Ad@3Shn<0i^KV0<W9b@2VYZH0QhN705mOG`18B4P0@41003`l
?00303dm?@0F03/k>`0h>3P0@D5104a<C01ADE40CDe=05ADE01TI6@0Ph>308f=S@2TY:@0_kno0<K6
aP3<c<`0dm?C0=[JfP3IfMT0c<c<0<W9b@2n_[h0`<300=3@d080g=cL0140h>3P0=_Kf`2n_[h0Z:RX
0:FUY@2i^KT0/k>c0:^[Z`2][Jd0VIVI09ZJVP2e]KD0/;2`0:RXZ02PX:00YjNW0:>SX`0=ooooo`00
4?ooool0401?Cdl0CDe=04i>CP1>CTh0CDe=04];B`1<C4`0CDe=04I6AP17AdL0BTY:04U9B@18B4P0
BDU904M7A`18B4P304I6AP0304M7A`18B4P0AdM70080BDU90P18B4P01017AdL0ATI604I6AP17AdL3
04I6AP0K0492@P13@d<0A4A404A4A011@D40D51@04a<C010@400A4A40492@P19BDT0@d=304A4A015
ADD0ATI604A4A019BDT0ATI604E5A@12@T80?Shn0451@@15ADD0B4Q803hn?P0o?cl0@d=300<0@410
0P0o?cl01@13@d<0@D5104I6AP1<C4`0AdM70080@D5100<0ADE504=3@`10@4000P0n?Sh04P14A4@0
@41003lo?`17AdL0ADE50451@@10@400ADE504I6AP11@D40?Cdm03hn?P0k>c/0@41004A4A00m?Cd0
>CTi0410@080@D5103T0DU9B0451@@0o?cl0?Shn03Ti>@0l?3`0DU9B06IVIP1ZJVX0MgMg092@T02:
RXX0Shn?08R8R02CTi<0TY:B0:6QX@2CTi<0QHF508J6QP20P800Ogmo096AT@2PX:00XZ:R09VIV@2F
UYH0O7al079bLP21PH40YJFU0<G5a@2c/k<0WYjN0:ZZZP2NWYh0Shn?09^KV`2FUYH0MgMg05eMG@1F
EUH0FUYJ04Y:BP1_Kfl0Y:BT0;Bd]02o_kl0YZJV08b<S02;Rh/0[Zj^0=CDe03?cll0a/K606=SH`13
@d<00`10@4002P0k>c/0@d=304e=C@15ADD0@T9203Ph>011@D40?Shn0410@015ADD203dm?@040451
@@13@d<0@41003Xj>P80?Cdm00@0>CTi03De=@0m?Cd0?clo0P0j>SX00`0i>CT0?Cdm03lo?`0203/k
>`0>03Ph>00i>CT0>3Ph03`l?00i>CT0>c/k03`l?00n?Sh0?3`l03Ph>00i>CT0>c/k03`l?011@D42
03/k>`0703`l?00n?Sh0?3`l03hn?P0j>SX0>3Ph03Ti>@0203`l?00:03hn?P0m?Cd0@D5103hn?P0g
=cL0>3Ph03dm?@0l?3`0?Cdm03/k>`80?clo00L0?Shn03lo?`0j>SX0>c/k03dm?@0j>SX0>c/k0080
?clo00d0>c/k03lo?`0n?Sh0@d=303`l?00i>CT0=SHf03dm?@0h>3P0>c/k03Xj>P0g=cL0>3Ph0080
>CTi00<0=cLg03hn?P0j>SX00`0l?3`02@15ADD0?clo03Ph>00k>c/0?3`l0410@012@T80@41003Xj
>P0203/k>`040410@00n?Sh0>c/k03lo?`80?3`l00X0>SXj03dm?@0n?Sh0=SHf03Ti>@0k>c/0?3`l
03Ph>00i>CT0>c/k0P0g=cL203/k>`0503hn?P0l?3`0?Cdm03Ph>00j>SX00P0i>CT01P0l?3`0>SXj
03Ph>00n?Sh0?3`l03lo?`80>SXj00D0?3`l03hn?P0n?Sh0>c/k03Ti>@0303/k>`0=03dm?@0i>CT0
>3Ph03/k>`0l?3`0?Shn0410@00i>CT0>c/k0410@00o?cl0>SXj03hn?P0203Ti>@0<03/k>`0i>CT0
?Cdm03Xj>P0n?Sh0@T9203lo?`0i>CT0?clo0451@@0l?3`0>c/k0`0l?3`01@0j>SX0>c/k03dm?@0k
>c/0?clo0080?3`l0P0i>CT203Xj>P80?3`l00`0>c/k0410@00k>c/0FUYJ0:VYZ@3Fe]H0bLW909>C
T`1bLW80Bd];03lo?`12@T8204U9B@0504=3@`0n?Sh0@T920492@P10@4000P11@D40201CDe<0LG5a
0861P@1`L700FEUI04E5A@0h>3P0>c/k0P0i>CT203Xj>P0<03Hf=P0i>CT0>3Ph03@d=00k>c/0>3Ph
03Ti>@0j>SX0>CTi03Hf=P0i>CT0?Cdm0P0l?3`0>00k>c/0=cLg03dm?@0o?cl0CTi>051@D01<C4`0
@D5104m?C`1PH600Ng]k0:6QX@2o_kl0WYjN0;Zj^P3Ph>00i>CT0>_[j`3MgMd0dM7A0;Bd]01iNGT0
Lg=c05iNGP1:BTX0?Shn03Xj>P0n?Sh0>SXj03hn?P10@400BTY:05YJFP1[Jf/0MWIf08>3P`2JVYX0
]KFe0<?3``3Hf=P0gMgM0>CTi03Ogml0c<c<0<;2`P2j^[X0`<300;^k^`2m_Kd0`<300;Ng]`2o_kl0
c/k>0<G5a@2b/[80c/k>0P3Cdm<0303Shn<0g=cL0=cLg03Jf]X0g=cL0=OGe`3?cll0c/k>0=GEe@3G
emL0cLg=0<W9b@80clo?3Oooool0013ooooo00`0CTi>051@D01=CDd0CDe=04a<C01;Bd/0CDe=04];
B`19BDT0AdM704Y:BP1;Bd/304Y:BP0:04I6AP18B4P0C4a<04a<C01;Bd/0B4Q804M7A`1:BTX0Bd];
04Q8B080BDU901@0ATI604M7A`15ADD0@d=304I6AP17AdL0ADE504U9B@15ADD0A4A404];B`15ADD0
?clo04M7A`1<C4`0BDU9059BDP1>CTh0@D5104M7A`80B4Q800d0ADE504=3@`14A4@0A4A404=3@`15
ADD0A4A40492@P16ATH0AdM704E5A@0n?Sh0@4100080?Shn00@0?clo0492@P13@d<0?Shn0P13@d<0
6@10@400?Cdm0410@011@D40?clo0492@P10@400@T920451@@0m?Cd0@D5104M7A`11@D40?clo04E5
A@12@T80@d=303hn?P0o?cl0@D5103dm?@11@D40?Shn03/k>`0n?Sh00P0m?Cd0>`0o?cl0@D5104=3
@`0n?Sh0@T9204A4A01RHV80N7Qh071`L01TI6@0GemO05IFEP1CDe<0I6AT08f=S@2<S8`0JFUY06=S
H`1BDU80FEUI05eMG@1JFUX0GEeM061PH01dM7@0L71`06IVIP1KFe/0C4a<061PH01iNGT0Q8B407em
O@2NWYh0^;Rh0<g=c@3>c/h0c<c<0<o?c`37alL0[Zj^08B4Q01/K6`0GUiN08n?S`2n_[h0b<S80=;B
dP3;bl/0a/K608j>SP1cLg<0Ogmo0:VYZ@2SXj<0LG5a05aLG01>CTh0BDU90080BTY:00D0@4100451
@@0l?3`0@D5103/k>`0203`l?00>0492@P14A4@0@T9203`l?00o?cl0@41003dm?@0k>c/0?3`l03dm
?@10@400=cLg03/k>`11@D4203`l?00E03dm?@0l?3`0>SXj03hn?P0k>c/0?3`l03/k>`0i>CT0?3`l
03Xj>P0n?Sh0?3`l03/k>`0l?3`0>c/k03Ti>@0o?cl0?Shn03Ti>@0m?Cd0@D510080?3`l00P0@410
03lo?`0j>SX0>3Ph03Ti>@0l?3`0>c/k03`l?080?Shn00D0?3`l03lo?`0k>c/0>c/k03Xj>P0203Ti
>@0@03`l?00k>c/0?3`l03lo?`0l?3`0?Shn03dm?@0i>CT0>c/k03dm?@0k>c/0?Cdm03/k>`11@D40
@41003`l?080>3Ph0`0j>SX203Ti>@0803Xj>P0k>c/0>SXj03`l?00k>c/0>CTi03/k>`0i>CT203hn
?P0803dm?@0i>CT0?clo03hn?P10@400@d=304E5A@0l?3`203dm?@0@03Ti>@0o?cl0>3Ph03dm?@0j
>SX0?3`l03dm?@0j>SX0>c/k03Ph>00j>SX0>c/k03Xj>P0g=cL0>3Ph03Ti>@80>3Ph00H0?Cdm03hn
?P0m?Cd0>CTi03dm?@0j>SX203Ti>@0403Xj>P0l?3`0>SXj03Ph>080>c/k00D0>SXj03Ti>@0i>CT0
?3`l03dm?@0203Xj>P0;03Lg=`0k>c/0?Shn03dm?@0o?cl0>CTi03lo?`14A4@0@D5103hn?P0k>c/0
0`0j>SX203Ti>@0303hn?P0h>3P0?3`l0080>SXj00D0?clo03Xj>P12@T80@T9203`l?00203lo?`03
0451@@12@T80?Cdm0080?3`l02h0>SXj03lo?`0k>c/0@41003Ti>@0n?Sh0>c/k03`l?00m?Cd0?3`l
03Xj>P0i>CT0?Cdm03lo?`0n?Sh0@41006e]K@2EUID0WIfM07moO`1IFET0AdM704A4A01:BTX0GEeM
065QH@1HF5P0G5aL055AD@1:BTX0@d=303`l?00k>c/0>SXj03`l?01<C4`0CDe=04Q8B00o?cl0?Shn
03/k>`0h>3P0=cLg03Ti>@0j>SX0>CTi0P0h>3P0B@0i>CT0=SHf03Hf=P0l?3`0=SHf03Xj>P0e=CD0
>CTi03Ph>00g=cL0>3Ph03/k>`0f=SH0@T9205ADE01OGel0JFUY06MWI`1ADE40C4a<04Q8B017AdL0
DE5A061PH026QXH0YZJV0=3@d03Ng]h0emOG0<O7a`2VYZH0TI6A075aL@1HF5P0ATI604E5A@0o?cl0
@41003`l?010@400A4A405mOG`1VIVH0PH610;Ng]`36a/H0cLg=0<O7a`33`l<0`/;20;Fe]@2TY:@0
WYjN0:2PX02RXZ80Ti>C07moO`2KVi/0Zj^[0<K6aP3;bl/0e=CD0=KFeP3Cdm<0a/K60;^k^`2`/;00
UIFE09:BTP2DU9@0V9RH09VIV@2DU9@00P2FUYH02P2IVIT0Vi^K0;fm_@32`/80]kNg0;bl_02k^k/0
/;2`0:>SX`2HV9P=ooooo`004?ooool0101;Bd/0CTi>04e=C@1<C4`304];B`0804i>CP19BDT0BDU9
04U9B@1<C4`0AdM704Y:BP18B4P204E5A@0G04m?C`17AdL0B4Q804U9B@14A4@0C4a<04Q8B01;Bd/0
BDU904Q8B017AdL0A4A404=3@`17AdL0BDU904A4A013@d<0BDU904Y:BP18B4P0AdM704=3@`11@D40
0P12@T800`19BDT0ATI604E5A@0304=3@`0404I6AP14A4@0ATI60492@P80@D5100T0@T9204=3@`11
@D40@D510410@013@d<0@T9203lo?`10@4000P11@D403@10@400CTi>04E5A@0o?cl0?Shn04I6AP13
@d<0?clo03hn?P11@D40A4A404E5A@13@d<00P11@D402`0o?cl0@d=304U9B@16ATH0A4A40492@P11
@D40@T9204I6AP0l?3`0?clo0080@D5100@0?Shn0492@P18B4P0@d=30P16ATH01@17AdL0ATI60492
@P0n?Sh0?clo0080ATI600/0C4a<065QH@1IFET0BTY:061PH025QHD0T92@06e]K@1bLW80HF5Q04Y:
BP0204a<C00[05ADE01HF5P0CDe=04m?C`1FEUH0FEUI061PH01NGUh0I6AT08:2PP1^KVh0I6AT08F5
Q@2PX:00/K6a0:n_[`2c/k<0[jn_0;Vi^@31`L40b<S80;bl_02^[Zh0Xj>S09RHV027QhL0Lg=c09RH
V02WYjL0X:2P07alO01^KVh0RXZ:0;Bd]034a<@0`<300;>c/`2i^KT0^;Rh09nOW`1HF5P0AdM70410
@00204E5A@0:0451@@12@T80CTi>0410@00k>c/0@T9204E5A@0o?cl0?3`l03Ti>@80?clo00@0BTY:
03hn?P0n?Sh0?3`l0P0j>SX02P0n?Sh0>CTi03dm?@0j>SX0?3`l03Xj>P0k>c/0?3`l03Xj>P0h>3P2
03Ti>@0=03hn?P0m?Cd0?Cdm0410@00i>CT0?3`l04=3@`11@D40?3`l03hn?P10@400?Cdm0410@002
03dm?@0G03/k>`0j>SX0?3`l03/k>`10@400@T9203lo?`0j>SX0?Cdm03`l?00n?Sh0>c/k03Ti>@0k
>c/0@41003hn?P0k>c/0?3`l04A4A00k>c/0>CTi03`l?00n?Sh00`0l?3`00`0j>SX0=cLg03`l?002
03dm?@080451@@0l?3`0>CTi03hn?P0j>SX0?Cdm03/k>`0g=cL203Xj>P0703hn?P10@400?clo03/k
>`0n?Sh0?3`l03Ti>@0203lo?`0<04=3@`0o?cl0>c/k03dm?@0j>SX0>c/k03dm?@0i>CT0>SXj03/k
>`0h>3P0>SXj0P0l?3`03@0h>3P0?Cdm03Ph>00j>SX0>CTi03dm?@0j>SX0>3Ph03Xj>P0k>c/0>CTi
03Xj>P0l?3`00P0j>SX0100o?cl0>CTi03Ti>@0h>3P203Xj>P0603/k>`0l?3`0>CTi03`l?00m?Cd0
?Shn0P0h>3P02P0j>SX0>c/k03hn?P0m?Cd0>c/k03Ph>013@d<0?clo0410@00o?cl303/k>`0403Xj
>P0m?Cd0?clo03Xj>P@0>c/k00`0>CTi03lo?`13@d<0@D5103`l?00k>c/0@41003lo?`0j>SX0?3`l
03Ti>@0j>SX203Ph>00404=3@`0j>SX0>CTi03Xj>P80>c/k00@0>SXj03/k>`0n?Sh0?Shn0`0l?3`0
400j>SX0ADE505UIF@19BDT0@41004M7A`1KFe/0NWYj0:>SX`2d];@0]KFe0:NWY`2CTi<0KVi^04a<
C00n?Sh203Ti>@0803Xj>P0h>3P0>CTi03Ti>@0g=cL0?3`l03Ti>@0f=SH303Ti>@80>3Ph00<0=cLg
03Hf=P0i>CT00P0h>3P06`0i>CT0>c/k03Ph>00i>CT0>SXj03Lg=`0k>c/0?3`l03/k>`11@D40EUIF
05mOG`1DE5@0C4a<04M7A`0n?Sh0>3Ph03`l?00j>SX0A4A4065QH@2VYZH0`L710;>c/`2EUID0R8R8
06i^KP0206=SH`0f05YJFP1HF5P0Cdm?03lo?`0j>SX0>CTi03`l?00j>SX0?clo04E5A@1LG5`0GUiN
06m_K`1aLG40LW9b07=cL`1UIFD0E5AD04Y:BP1?Cdl0BDU904M7A`11@D40A4A404I6AP1DE5@0Lg=c
08Z:RP2CTi<0UiNG08^;R`21PH40JVYZ05QHF01>CTh0ADE504I6AP17AdL0Cdm?059BDP1CDe<0IVIV
08>3P`2EUID0Y:BT0:>SX`2OWil0];Bd0:f][@2l_;`0/;2`0:n_[`2YZJT0Xj>S3Oooool0013ooooo
0P1>CTh01@1<C4`0BTY:04M7A`18B4P0BTY:0080AdM700<0A4A404];B`1:BTX00P18B4P02`17AdL0
ADE504Q8B01:BTX0AdM704=3@`18B4P0AdM704=3@`16ATH0B4Q80080BTY:00T0B4Q804I6AP14A4@0
ADE504M7A`19BDT0AdM704E5A@17AdL00P16ATH01@14A4@0@d=304E5A@1;Bd/0B4Q80080AdM700<0
A4A404Y:BP19BDT00P15ADD00`14A4@0ATI604E5A@0204A4A01104I6AP18B4P0A4A404=3@`0o?cl0
@41004=3@`11@D40ATI60492@P15ADD0DE5A04U9B@12@T80?clo0492@P0o?cl0@D5103lo?`10@400
@D510492@P11@D40?clo04=3@`12@T80ATI6059BDP1DE5@0Fe]K059BDP14A4@0ADE503Xj>P0m?Cd0
>c/k03`l?010@400?clo05MGE`1VIVH0H61P065QH@1ZJVX0P82007UiN@1:BTX0@d=30451@@16ATH0
BDU904e=C@1ADE40GUiN06i^KP24Q8@0QXJ608^;R`22PX80KFe]05ADE014A4@0ATI604A4A010@400
0P0n?Sh0:016ATH0BDU904I6AP12@T80A4A404Q8B01UIFD0Kfm_05IFEP1NGUh0N7Qh08N7Q`2?Shl0
LG5a079bLP2<S8`0WYjN092@T02;Rh/0U9BD09VIV@2<S8`0JVYZ06a/K02BTY80Xj>S0:^[Z`2=SHd0
QHF506i^KP2JVYX0YjNW09NGU`1iNGT0LW9b09FEU@2m_Kd0]kNg096AT@1VIVH206ATI007065QH@1J
FUX0IFEU04I6AP0k>c/0AdM703Xj>P0203lo?`0704E5A@1]KFd0O7al09NGU`2CTi<0GEeM03lo?`02
03`l?00503Ph>00j>SX0>SXj03hn?P0k>c/00P0j>SX203Ti>@0503dm?@0n?Sh0>CTi03lo?`10@400
0`0o?cl01@11@D40@d=303lo?`10@400?3`l0080?clo00<0?Cdm03Ti>@0j>SX00`0i>CT0900o?cl0
>c/k03Ph>00j>SX0>CTi03Xj>P0i>CT0>SXj03hn?P0m?Cd0>c/k0451@@0i>CT0>3Ph03dm?@0l?3`0
?Cdm03Ph>00j>SX0?clo0410@00k>c/0>SXj03hn?P0o?cl0?Cdm03lo?`0h>3P0?Cdm03/k>`0o?cl0
>c/k03Ti>@0l?3`0?Cdm03`l?080>SXj00L0>CTi03dm?@0m?Cd0>3Ph03/k>`0j>SX0>c/k0080?3`l
01D0?clo03Hf=P0k>c/0?3`l03dm?@0g=cL0>CTi03`l?00i>CT0>SXj03/k>`0l?3`0>c/k03Xj>P0m
?Cd0?clo03/k>`0j>SX0>3Ph03Lg=`0h>3P00P0f=SH203Ti>@0Z03Ph>00i>CT0?Shn03Ph>00g=cL0
>CTi03Xj>P0k>c/0>SXj03Ph>011@D40>3Ph03dm?@0o?cl0?Shn0410@00j>SX0>c/k03dm?@0j>SX0
?Cdm03hn?P0i>CT0@41003`l?016ATH0@d=30410@00n?Sh0@D5103lo?`10@400>c/k04U9B@0n?Sh0
>c/k03Xj>P0k>c/0?3`l03/k>`0n?Sh0?Cdm0P0l?3`01@0k>c/0@41004E5A@0l?3`0>SXj0080>3Ph
00D0>c/k03Xj>P0n?Sh0>CTi03/k>`0203Ti>@0:03Xj>P0k>c/0?3`l03`l?00j>SX0?Cdm03/k>`12
@T80@41005=CD`80Jf][00d0QhN70:f][@2c/k<0`/;20<30`02OWil0NGUi05UIF@15ADD0?clo03Lg
=`0k>c/0>3Ph0080>CTi0`0k>c/02@0f=SH0=cLg03Hf=P0l?3`0=cLg03Hf=P0h>3P0>CTi03Xj>P02
03Ti>@0403Xj>P0k>c/0>CTi03Ph>080?3`l00`0?Cdm03Xj>P0e=CD0>CTi03dm?@0l?3`0@D510492
@P10@400?Shn03`l?00m?Cd203Xj>P0?04];B`1NGUh0OWin0820P01eMGD0KVi^06IVIP1ZJVX0GemO
05ADE011@D40?3`l03Xj>P0l?3`0>CTi0080=cLg0P0h>3P0;`0i>CT0@41003lo?`0m?Cd0>3Ph03Ti
>@0k>c/0>3Ph03Xj>P0n?Sh0>c/k03hn?P0l?3`0>c/k03Xj>P0o?cl0BTY:05YJFP29RHT0XZ:R0:RX
Z02MWId0QXJ607IfMP1oOgl0PX:209jNWP2WYjL0WIfM09RHV02b/[80bLW90<O7a`33`l<0c<c<0<G5
a@3:b/X0bLW90;no_`2k^k/0bl_;0=?Cd`3De=@0b<S80<[:bP3=cLd0f=SH00gooooo000@ooooo`09
04a<C01=CDd0BDU904a<C019BDT0BTY:04a<C017AdL0BDU90080B4Q800h0Cdm?04M7A`16ATH0AdM7
04Q8B017AdL0@d=304I6AP15ADD0BDU904Q8B014A4@0BDU904E5A@80AdM700L0ATI604Q8B016ATH0
ATI604Q8B016ATH0A4A40080ATI600@0A4A404I6AP15ADD0ADE50P14A4@01010@400A4A404I6AP11
@D4204=3@`0404A4A017AdL0ADE504I6AP80A4A40`13@d<03010@400ADE504E5A@15ADD0B4Q804U9
B@14A4@0@41003`l?013@d<0@D5104A4A080?Shn00@0?Cdm04=3@`0o?cl0?Shn0P0m?Cd01P0n?Sh0
?3`l0410@010@400?clo04E5A@80@d=300h0@D5104I6AP10@400?Shn0410@00o?cl0?3`l03dm?@0o
?cl0?3`l0410@012@T80@41005EEE@80LW9b04L0HF5Q06EUI@1QHF40MgMg08>3P`1^KVh0FEUI05YJ
FP1ZJVX0I6AT05YJFP1BDU80CDe=0492@P0o?cl0>CTi03lo?`11@D40?clo03hn?P0o?cl0@T9204=3
@`14A4@0@T920410@00m?Cd0ATI604A4A018B4P0CTi>05EEE@1GEeL0D51@04=3@`19BDT0C4a<05aL
G01YJFT0Jf][07QhN02CTi<0YjNW0:VYZ@25QHD0Ph>30:6QX@2b/[80YJFU07UiN@1PH600OGem09FE
U@2`/;00^k^k0;Bd]02DU9@0PX:2096AT@2m_Kd0X:2P07=cL`1/K6`0MGEe08n?S`2VYZH0SHf=05IF
EP10@400?Cdm03`l?00203hn?P0=05ADE01@D500B4Q804=3@`12@T80@41003Xj>P0k>c/0?clo0492
@P0k>c/0?Shn03`l?00203lo?`080410@00n?Sh0>c/k03hn?P0j>SX0?Shn03dm?@0n?Sh403/k>`07
03Xj>P0n?Sh0>c/k04M7A`0o?cl0?Cdm0451@@0303hn?P0603`l?00n?Sh0?3`l03`l?00m?Cd0?3`l
0`0k>c/01010@400?Shn0451@@10@40203lo?`060451@@0m?Cd0>c/k03`l?00k>c/0>CTi0`0j>SX0
200k>c/0?3`l03Hf=P0j>SX0=SHf0451@@0l?3`0?Cdm0P0l?3`02@0k>c/0@4100451@@0o?cl0?Shn
03Xj>P0l?3`0>c/k03Ph>00203Xj>P0303`l?00j>SX0>CTi00<0>SXj00D0?3`l0451@@0k>c/0>c/k
03lo?`0303Xj>P0>03dm?@0k>c/0?3`l055AD@10@400>CTi03De=@10@400>CTi03Xj>P0i>CT0?Shn
03dm?@0j>SX203Lg=`0903hn?P0j>SX0>c/k03dm?@0j>SX0?Shn03lo?`0j>SX0@D510080>SXj00@0
>CTi03Ph>00o?cl0>SXj0P0m?Cd03@0i>CT0>c/k03`l?00k>c/0?Shn03Xj>P0m?Cd0>CTi03`l?010
@400@D5104A4A018B4P00P0o?cl02@0l?3`0>SXj03Xj>P0l?3`0?Shn03/k>`0l?3`0>c/k03lo?`02
03`l?00603hn?P0j>SX0>CTi03/k>`0m?Cd0>CTi0P0m?Cd00`0j>SX0=cLg03Ti>@0203dm?@0F03hn
?P11@D40@D5104U9B@1@D500G5aL06MWI`23Ph<0S8b<0861P@2EUID0Ti>C0;Zj^P2IVIT0JVYZ05AD
E017AdL0@D5104=3@`0k>c/0>CTi03/k>`<0>CTi01<0>SXj03Ph>00i>CT0=cLg03Ph>00i>CT0>c/k
03Ti>@0g=cL0=SHf03Ti>@0k>c/0>SXj03Ph>00g=cL0>3Ph03Xj>P0k>c/0?clo0080@41000<0?3`l
03Ti>@0j>SX00P0i>CT0600m?Cd0?3`l03hn?P0k>c/0?Shn0410@011@D40DE5A06][J`21PH40Ti>C
09JFUP1lO7`0M7Ad06UYJ@1XJ6P0Fe]K04=3@`0h>3P0>SXj03Ph>00j>SX0>CTi03/k>`80>CTi00P0
>c/k03Ti>@0h>3P0=cLg03Ti>@0k>c/0>CTi03`l?080>c/k0P0j>SX07@0k>c/0>CTi0410@00l?3`0
?Shn03lo?`1CDe<0JVYZ07IfMP2CTi<0P82006UYJ@1/K6`0OWin09jNWP2j^[X0c/k>0<;2`P2`/;00
Vi^K08j>SP2UYJD0^;Rh0<g=c@3GemL0dm?C0<o?c`3De=@0f][J0080e]KF00L0e=CD0=WIf@3Cdm<0
d];B0=3@d03Kfm/0f][J00gooooo000@ooooo`0;04e=C@1HF5P0C4a<04];B`1:BTX0Bd];04U9B@18
B4P0AdM704U9B@18B4P00P1:BTX00`17AdL0B4Q804U9B@0204I6AP0;04E5A@13@d<0ADE504=3@`15
ADD0BTY:04Q8B016ATH0A4A404M7A`18B4P00P13@d<02@17AdL0B4Q804A4A012@T80AdM704Q8B014
A4@0ADE504I6AP020492@P0904=3@`16ATH0ATI604Q8B015ADD0@D5104A4A013@d<0AdM70080ADE5
0`12@T820410@00;04E5A@16ATH0?Shn03lo?`11@D40A4A403lo?`0n?Sh0BDU903Ti>@0j>SX00`0o
?cl04011@D40?Cdm0410@011@D40?Shn0451@@0l?3`0?Shn03dm?@0n?Sh0@41004=3@`0m?Cd0?clo
0492@P11@D420492@P0B04A4A016ATH0@T920410@00m?Cd0BDU903dm?@1:BTX0D51@05]KF`1HF5P0
Fe]K05IFEP1LG5`0GUiN05QHF01=CDd0ADE50P13@d<0A`0m?Cd0?Shn03/k>`12@T80?Shn03/k>`0m
?Cd0?3`l03/k>`0o?cl0?Cdm04E5A@1FEUH0I6AT06QXJ01YJFT0Jf][07MgM`1fMWH0N7Qh079bLP1P
H600Hf=S06IVIP1PH600GEeM071`L020P800WinO0:>SX`1mOGd0IVIV05ADE017AdL0C4a<04m?C`1J
FUX0M7Ad08V9R@2?Shl0MgMg06QXJ01UIFD0K6a/07=cL`1hN7P0MgMg06m_K`1CDe<0EeMG05UIF@1_
Kfl0O7al065QH@1:BTX0BDU905IFEP1]KFd0Ogmo08J6QP1SHf<0FEUI06YZJP2CTi<0^k^k0<71`@2]
[Jd0RHV906ATI011@D40@d=30080@41000@0>3Ph03`l?00k>c/0>c/k0`0l?3`0100k>c/0>3Ph03/k
>`0j>SX20410@00403`l?00k>c/0?3`l03lo?`80>SXj00L0=cLg03`l?00o?cl0>SXj03lo?`10@400
>c/k0080?3`l01@0>SXj03Ti>@0j>SX0>SXj03/k>`0l?3`0>CTi03/k>`0h>3P0?3`l03lo?`0k>c/0
@D5103lo?`0n?Sh0?3`l0410@00o?cl0@41003dm?@80>c/k00P0?Cdm03/k>`0k>c/0@41003Ti>@0k
>c/0@41003hn?P80?clo00@0@D5103Xj>P0i>CT0>SXj0P0i>CT203Ph>00D03Xj>P0k>c/0?3`l03Ti
>@0n?Sh0?3`l03Xj>P0o?cl0>SXj03dm?@0j>SX0?3`l03hn?P0j>SX0=cLg03/k>`0j>SX0?Cdm03Xj
>P0m?Cd303Ti>@0903Xj>P0k>c/0?3`l03/k>`0j>SX0?3`l03Ph>010@400?clo0080?Cdm00L0>c/k
03Xj>P0j>SX0?Shn03`l?00i>CT0?3`l0080?Cdm00H0?3`l03Ti>@0l?3`0?Shn03Xj>P11@D4203Xj
>P0603lo?`0l?3`0?Shn03hn?P0k>c/0?clo0P0j>SX06`0o?cl0>c/k03/k>`0i>CT0@d=303lo?`13
@d<0?3`l03/k>`0n?Sh0@T9204A4A00k>c/0?3`l0410@00m?Cd0@41003hn?P0k>c/0?clo0410@00l
?3`0>CTi03`l?00j>SX0?Cdm03hn?P0203`l?00A03Xj>P0k>c/0?Shn04A4A01RHV80VIVI0:VYZ@2F
UYH0QHF50861P@1iNGT0KVi^05mOG`1QHF40EEEE04I6AP0o?cl00`0k>c/00`0o?cl0?Shn03Ti>@02
03Xj>P0703Ti>@0j>SX0?3`l03Ti>@0j>SX0>CTi03Xj>P0303Ph>0<0>CTi00L0=cLg03Ph>00g=cL0
>3Ph03Ti>@0j>SX0@T920080?Cdm01/0?clo03Xj>P0h>3P0>3Ph03Xj>P0m?Cd0?3`l03dm?@0l?3`0
?clo0492@P1JFUX0QHF50:NWY`2][Jd0VIVI08N7Q`1fMWH0Lg=c05]KF`1@D500?Shn03dm?@0j>SX0
>CTi03/k>`0i>CT00P0k>c/01P0n?Sh0>CTi03Xj>P0g=cL0>c/k03hn?P80>3Ph0P0l?3`203lo?`05
03`l?00h>3P0>SXj03/k>`0m?Cd00P0n?Sh08`0m?Cd0@4100410@013@d<0A4A40410@011@D40IVIV
09bLW02/[:`0WinO09JFUP28R8P0QHF508N7Q`2HV9P0/;2`0<30`03EeMD0d=3@0=CDe03Cdm<0b/[:
0;Rh^02_[jl0]KFe0<71`@3>c/h0d];B0=GEe@3Cdm<0g=cL0=_Kf`3QhN40gMgM00gooooo000@oooo
o`0404m?C`1BDU80CDe=04a<C080CDe=0P19BDT01`17AdL0B4Q804I6AP19BDT0AdM704I6AP1:BTX0
0`18B4P01P17AdL0ATI604Q8B014A4@0ATI604Q8B0<0A4A40200AdM704Y:BP17AdL0ATI604M7A`18
B4P0ADE504Q8B017AdL0ATI604A4A013@d<0@T9204=3@`11@D40@T9204A4A015ADD0B4Q8055AD@1>
CTh0@T920410@014A4@0ATI604M7A`12@T80@d=304A4A011@D40@41004Q8B080@D5100D0?Shn04=3
@`13@d<0@T920451@@0303hn?P050451@@0m?Cd0?Shn0410@00o?cl00P10@4000`0n?Sh0?clo03lo
?`0303lo?`0K0451@@13@d<0ATI60410@00n?Sh0?clo04I6AP10@400@d=303dm?@10@400?Shn03dm
?@15ADD0Bd];05EEE@1?Cdl0De=C04=3@`10@400@D5104I6AP0o?cl0?3`l03/k>`11@D40>SXj0080
>c/k00D0?Shn03`l?00n?Sh0>c/k03Ti>@0203`l?00303Xj>P0k>c/0?Cdm0080@T9201D0ATI603hn
?P1:BTX0JFUY06e]K@1VIVH0IfMW05YJFP1BDU80EUIF05ADE015ADD0@D5104M7A`1=CDd0Bd];04E5
A@11@D40?Shn04A4A00h>3P00P0n?Sh0500o?cl0@d=30451@@13@d<0A4A405EEE@28R8P0UYJF08:2
PP1JFUX0EeMG05eMG@1GEeL0GUiN06a/K01ZJVX0MGEe07MgM`1XJ6P0CTi>0P18B4P0101]KFd0YJFU
0;jn_P3AdM420=?Cd`0=0<K6aP30`<00/k>c0;2`/02LW9`0Shn?0:NWY`2OWil0O7al05aLG00m?Cd0
@T9205YJFP0206e]K@0405MGE`11@D40?Cdm03hn?P80@41000/0>SXj03dm?@10@400?Shn0410@00k
>c/0>3Ph03/k>`0m?Cd0>CTi03/k>`020410@00@03/k>`0j>SX0?3`l03`l?00k>c/0>SXj03`l?00m
?Cd0>CTi03dm?@0l?3`0>c/k03Xj>P0l?3`0@4100451@@80?3`l00H0>c/k0492@P0n?Sh0?Cdm03hn
?P0k>c/203Xj>P0I03dm?@0j>SX0>SXj03Ph>00l?3`0AdM70451@@0j>SX0>c/k03hn?P0k>c/0>CTi
03/k>`0l?3`0>c/k03Lg=`0i>CT0?3`l03hn?P0h>3P0>c/k03Xj>P0l?3`0>SXj03dm?@0203hn?P09
03`l?00m?Cd0?3`l03lo?`0i>CT0>SXj03/k>`0m?Cd0=CDe0080>3Ph00X0?clo03`l?00h>3P0>c/k
03Xj>P0l?3`0?clo03hn?P0k>c/0>3Ph0P0i>CT00`0k>c/0?Shn03`l?00303Ti>@0803Ph>00m?Cd0
?Shn03Xj>P0i>CT0>SXj03/k>`11@D4203hn?P0H04=3@`0n?Sh0@T9204Q8B013@d<0@T9204=3@`11
@D40>SXj03lo?`10@400?3`l03Xj>P0k>c/0>CTi03Xj>P0i>CT0?3`l03Hf=P0h>3P0?3`l03hn?P0j
>SX0?3`l0P0n?Sh00`0l?3`0@D510451@@020492@P0J04E5A@1JFUX0EEEE03lo?`0h>3P0?Cdm03lo
?`0j>SX0>CTi03hn?P10@400EUIF08B4Q01nOWh0K6a/05MGE`19BDT0De=C06ATI01^KVh0PX:208F5
Q@1TI6@0A4A403`l?00i>CT203`l?00503Xj>P0k>c/0>c/k03Xj>P0h>3P01@0k>c/0100i>CT0?3`l
03Ph>00g=cL203Ti>@0<03Lg=`0j>SX0>3Ph03Lg=`0h>3P0=cLg03Ti>@0h>3P0>SXj03Lg=`0i>CT0
=cLg0P0j>SX203Ph>00C03Ti>@0n?Sh0@41005=CD`1jNWX0ZZZZ0=kNgP3EeMD0[Jf]09FEU@2<S8`0
JFUY05MGE`0j>SX0>c/k03Ph>00j>SX0>c/k03dm?@0203Xj>P0@03Ti>@0h>3P0=cLg03Xj>P0h>3P0
=cLg03Ti>@0m?Cd0>SXj03`l?00k>c/0?Shn03`l?011@D40@41003`l?080>SXj02L0>c/k0451@@12
@T80>c/k03dm?@0n?Sh0@D5104e=C@1WIfL0NWYj08Z:RP2<S8`0QXJ607alO02IVIT0Z:RX0:ZZZP2e
]KD0/K6a0;fm_@33`l<0[Zj^09>CT`1fMWH0G5aL04i>CP1EEED0Cdm?05QHF01IFET0GUiN065QH@1l
O7`0YJFU0=7Ad@3Ng]h0gmoO0=SHf03>c/h03Oooool0013ooooo00D0CTi>04a<C01<C4`0CDe=04Y:
BP0204Q8B080ATI60P17AdL01019BDT0BTY:04Q8B018B4P304E5A@80ATI600@0B4Q804E5A@15ADD0
AdM70P16ATH00`17AdL0ADE504I6AP0204M7A`0304E5A@17AdL0AdM70080ATI600X0B4Q804A4A013
@d<0A4A404E5A@18B4P0BDU904E5A@0o?cl0ADE50P13@d<01`14A4@0B4Q804I6AP15ADD0@T9204A4
A011@D400P13@d<03@11@D40@T9204=3@`0o?cl0AdM704E5A@14A4@0?Shn03lo?`0m?Cd0@41003hn
?P0o?cl00P10@400600n?Sh0?clo04=3@`13@d<0@D5104E5A@16ATH0A4A403lo?`10@400@d=30410
@012@T80?Cdm03hn?P12@T80@41004=3@`15ADD0@4100451@@0m?Cd0@4100451@@<0>c/k00D0?Cdm
03`l?013@d<0?Cdm03/k>`0203Xj>P070410@011@D40?3`l03`l?00k>c/0>SXj03/k>`0203dm?@0^
03Xj>P0n?Sh0>c/k03dm?@15ADD0CDe=04M7A`16ATH0@D5103dm?@0k>c/0?Cdm0492@P10@400?Shn
0492@P0o?cl0?Cdm0410@00o?cl0ATI604=3@`0m?Cd0?clo04Q8B016ATH0Cdm?04=3@`0o?cl0DE5A
05MGE`1>CTh0De=C04m?C`1NGUh0K6a/061PH01MGEd0HF5Q04a<C018B4P0Bd];051@D01>CTh0H61P
06e]K@80Ng]k00/0P82007moO`21PH40VIVI09^KV`1gMgL0LG5a07moO`29RHT0T92@0;Fe]@020;Ng
]`0V0<O7a`32`/80/;2`0:6QX@2][Jd0^KVi0;jn_P2ZZZX0IfMW04];B`1PH600Q8B409VIV@2BTY80
N7Qh06i^KP1WIfL0EEEE04Q8B011@D40?3`l03dm?@12@T80@D5103dm?@0n?Sh0?Cdm03hn?P0m?Cd0
?3`l0410@00j>SX0?3`l03hn?P0m?Cd0>c/k03Ti>@0k>c/403`l?00>03hn?P0i>CT0?Cdm03dm?@0n
?Sh0?3`l03/k>`10@400?Cdm03/k>`0i>CT0>c/k03`l?00k>c/203Xj>P0703lo?`0k>c/0>c/k03/k
>`0g=cL0?3`l03hn?P0203Xj>P0303/k>`0i>CT0>SXj0080>SXj00<0?3`l03Xj>P0j>SX00P0j>SX0
3`0l?3`0?Cdm03Xj>P0h>3P0>SXj03/k>`0l?3`0>CTi03Xj>P0h>3P0>c/k03Xj>P0m?Cd0>CTi03Lg
=`0303Ti>@0503Xj>P0i>CT0>c/k03Xj>P0k>c/00P0h>3P01@0i>CT0>SXj03Xj>P0i>CT0=cLg0080
>CTi00@0=cLg03Ti>@0k>c/0>SXj0P0h>3P05@0l?3`0>c/k03Lg=`0h>3P0=cLg03hn?P0i>CT0@410
03hn?P10@400>c/k04A4A015ADD0@41003lo?`10@400?Cdm03Xj>P0l?3`0@d=303`l?00203dm?@06
03`l?00k>c/0>CTi03Xj>P0l?3`0>3Ph0P0j>SX403`l?00M03dm?@0l?3`0@D5105ADE022PX80Ti>C
09jNWP1JFUX0?clo03dm?@0i>CT0?clo03`l?00o?cl0?Cdm03lo?`1:BTX0Cdm?05ADE01UIFD0PX:2
08F5Q@27QhL0VYZJ079bLP1OGel0De=C04=3@`0n?Sh00P0l?3`00`11@D40>c/k03/k>`0203dm?@0A
03/k>`0l?3`0?3`l03Xj>P0i>CT0?Shn03Ph>00f=SH0=cLg03Xj>P0h>3P0>SXj03Ph>00e=CD0=cLg
03Ti>@0h>3P00P0f=SH00`0g=cL0>SXj03Ti>@0203/k>`80?Shn00L0?3`l03Ti>@14A4@0GemO07al
O02SXj<0d];B0080iNGU0100f][J0=SHf03=cLd0Z:RX0820P01bLW80G5aL04M7A`0o?cl0?3`l0492
@P10@400?Cdm03Ti>@0f=SH0>CTi0P0g=cL01P0f=SH0?3`l03/k>`0j>SX0=cLg03Hf=P<0>3Ph00h0
>CTi03Xj>P0l?3`0>SXj03lo?`0n?Sh0@D5104a<C01TI6@0MGEe09:BTP2MWId0[:b/0<71`@80fm_K
01d0_kno0:6QX@21PH40T92@0:NWY`2e]KD0_;bl0<30`02XZ:P0TI6A07]kN`1UIFD0H61P05EEE@1G
EeL0Cdm?051@D01CDe<0GEeM06QXJ01nOWh0SXj>0:FUY@2WYjL0^;Rh0<C4a03;bl/0c/k>0=KFeP0=
ooooo`004?ooool204a<C00904i>CP1;Bd/0CDe=04];B`1<C4`0BTY:04i>CP19BDT0AdM70080BDU9
00D0BTY:04U9B@17AdL0ADE504I6AP0304E5A@0B04I6AP17AdL0ATI604A4A018B4P0BTY:04M7A`16
ATH0ADE504A4A016ATH0B4Q804];B`17AdL0ATI604M7A`18B4P0AdM70`15ADD05016ATH0@d=304I6
AP15ADD0ATI604E5A@13@d<0@T9203lo?`11@D40@41004=3@`11@D40@d=304I6AP14A4@0ADE504=3
@`10@400@d=30`0n?Sh303dm?@0?0492@P11@D40?clo03dm?@0n?Sh0?clo0410@012@T80@4100451
@@12@T80@d=303hn?P12@T80@d=300<0?Cdm01X0>c/k03hn?P0l?3`0>c/k03lo?`11@D40@d=303dm
?@10@400?clo0410@015ADD0?Shn03Lg=`0j>SX0>c/k03dm?@0j>SX0?clo0492@P15ADD0@41003`l
?00j>SX0?clo03`l?080>SXj02@0?Cdm03Xj>P15ADD0BDU905mOG`1_Kfl0N7Qh07moO`1UIFD0J6QX
079bLP1WIfL0E5AD04];B`11@D40?Cdm0410@00o?cl0@41003lo?`0n?Sh0@d=304Y:BP1XJ6P0L71`
06EUI@1@D500F5QH05UIF@1NGUh0IFEU06UYJ@1ZJVX0Lg=c07AdM01LG5`204Y:BP0704Q8B017AdL0
Bd];04E5A@16ATH0@41004E5A@0204U9B@0k04i>CP1@D500HV9R07YjNP2>SXh0W9bL0:6QX@2^[Zh0
/K6a0;:b/P2IVIT0LG5a07=cL`1eMGD0N7Qh06ATI01VIVH0IFEU06m_K`23Ph<0UYJF09RHV02ZZZX0
^KVi09RHV01nOWh0NWYj07alO01gMgL0KFe]06a/K02KVi/0][Jf0;Fe]@2PX:00S8b<06m_K`1@D500
@d=303hn?P0l?3`0?clo03`l?00k>c/0@D5103Xj>P12@T80@d=303Xj>P0n?Sh0?Cdm03/k>`0n?Sh0
?Cdm03hn?P0m?Cd0?clo03Xj>P0m?Cd00P0l?3`02`0k>c/0?3`l03hn?P0j>SX0?3`l0451@@0m?Cd0
?clo03hn?P0l?3`0?Shn0080?3`l00<0>CTi03Ph>00l?3`00P0l?3`04`0h>3P0?3`l03`l?00i>CT0
?3`l03Xj>P0h>3P0>SXj03`l?00f=SH0=CDe03Hf=P0h>3P0>CTi03/k>`0l?3`0>CTi03Ph>00k>c/0
0`0j>SX0100i>CT0@4100410@00j>SX203Lg=`0<03Xj>P0k>c/0>CTi03Xj>P0g=cL0>3Ph03/k>`0j
>SX0>3Ph03Lg=`0f=SH0=cLg0P0i>CT0200m?Cd0@41003`l?012@T80>SXj03hn?P0l?3`0=SHf0`0h
>3P03P0k>c/0?Cdm03Hf=P0n?Sh0E5AD04m?C`13@d<0@41003/k>`0l?3`0>c/k03Xj>P0l?3`0?Shn
0`0k>c/03@12@T80>c/k03/k>`0i>CT0?Cdm03`l?00i>CT0>SXj03Ti>@0j>SX0>c/k03Xj>P0l?3`0
0P0k>c/06P0l?3`0?clo03lo?`11@D40EUIF05MGE`1=CDd0@D5103hn?P0j>SX0?3`l03Xj>P0n?Sh0
?Cdm04I6AP1WIfL0MgMg08J6QP2ATI40Ogmo07MgM`20P800GUiN05=CD`10@400?Shn0P0k>c/0100n
?Sh0>SXj03Ti>@0i>CT303dm?@80?3`l00@0?Cdm03Xj>P0j>SX0>SXj100k>c/08`0h>3P0?Cdm03Xj
>P0k>c/0>SXj03Ti>@0k>c/0>3Ph03Xj>P0n?Sh0>c/k03Ti>@12@T80CDe=05IFEP1:BTX0AdM705AD
E01IFET0N7Qh0;Ng]`3Lg=`0jNWY0>SXj03WinL0i^KV0=oOg`3GemL0a/K60:FUY@21PH40FUYJ051@
D01=CDd0A4A40080?Cdm00<0@d=303`l?00j>SX00P0h>3P0>@0j>SX0?clo04U9B@18B4P0?Cdm03/k
>`0i>CT0>3Ph03Ti>@0h>3P0>SXj04I6AP1;Bd/0H61P07emO@23Ph<0Rh^;096AT@2NWYh0Zj^[0;no
_`2g]kL0bl_;0=gMg@3Ph>00i>CT0>;RhP3Cdm<0^KVi0:JVYP2ATI40SXj>08F5Q@26QXH0UIFE09ZJ
VP2EUID0RXZ:08:2PP1iNGT0OGem06m_K`1TI6@0KVi^07moO`2XZ:P0_kno0<c<c03Bd]80clo?0<c<
c035aLD0`L710;Fe]@2QXJ40VYZJ09NGU`0=ooooo`004?ooool2051@D00904m?C`1<C4`0BDU904Y:
BP18B4P0BDU904e=C@18B4P0AdM70080B4Q800L0BTY:04Q8B01;Bd/0B4Q804E5A@16ATH0AdM700@0
ATI600L0@d=304Q8B018B4P0@d=304E5A@16ATH0ADE50080A4A400P0BTY:04I6AP13@d<0@41004A4
A013@d<0@D5104Q8B080@T9200P0?clo04A4A011@D40@D5104=3@`15ADD0@D5103hn?P<0A4A400H0
ADE50451@@14A4@0@4100451@@17AdL20410@00904=3@`12@T80@d=303dm?@11@D40?Shn0492@P11
@D40?Shn00<0?Cdm0P0n?Sh20451@@0A03hn?P12@T80?3`l04=3@`12@T80?3`l03/k>`0j>SX0?clo
03Xj>P0o?cl0@41003lo?`11@D40@d=30451@@16ATH00P19BDT01`15ADD0@D5103Xj>P12@T80?3`l
03hn?P0o?cl00P12@T80?00o?cl0?3`l03hn?P0l?3`0?clo0410@00k>c/0?3`l05IFEP1HF5P0E5AD
04m?C`1DE5@0F5QH05YJFP1LG5`0C4a<04m?C`1>CTh0BDU903lo?`11@D40@T9204M7A`0n?Sh0ATI6
069RHP1ZJVX0IVIV069RHP1`L700Ti>C08N7Q`1LG5`0CDe=05UIF@1QHF40JFUY06QXJ01VIVH0L71`
06IVIP1MGEd0B4Q804=3@`14A4@0@T9204I6AP1;Bd/0F5QH05UIF@15ADD0AdM704a<C01OGel0HV9R
07=cL`1mOGd0SXj>08n?S`80NWYj0P23Ph<0=P2;Rh/0R8R80820P025QHD0QXJ60861P@1dM7@0GemO
05=CD`1EEED0NWYj0;Rh^02`/;00SHf=0:b/[034a<@0W9bL07emO@1VIVH0EUIF05=CD`18B4P0BTY:
05=CD`1SHf<0MGEe08F5Q@2NWYh0^k^k0::RXP22PX80JFUY04M7A`10@400@d=304Q8B01BDU80ADE5
0492@P0m?Cd0?3`l0451@@12@T80@D5103hn?P11@D40>c/k03hn?P10@400?3`l03hn?P0m?Cd0>c/k
03`l?0<0?Shn00<0?clo03/k>`0m?Cd00`0l?3`03P0i>CT0?3`l03/k>`0j>SX0>CTi03Ph>00m?Cd0
?Shn03/k>`0i>CT0>SXj03hn?P0g=cL0=SHf0P0j>SX03`0h>3P0=SHf03Hf=P0i>CT0=cLg03Ti>@0l
?3`0=cLg03Xj>P0n?Sh0>3Ph03Ti>@0n?Sh0>CTi03Xj>P0203Lg=`0;03Ph>00i>CT0>SXj03/k>`0h
>3P0>CTi03Xj>P0f=SH0>c/k03Lg=`0i>CT00P0h>3P203Lg=`0803/k>`0j>SX0@D5103dm?@11@D40
?Cdm03`l?00j>SX403Ti>@0=03Ph>00i>CT0A4A405=CD`14A4@0?3`l04A4A00m?Cd0>CTi03`l?00m
?Cd0>3Ph03lo?`0203dm?@0303/k>`0l?3`0>c/k00@0?Cdm0180?3`l03Xj>P0l?3`0>3Ph03/k>`0h
>3P0?Cdm0410@00l?3`0>SXj03/k>`0l?3`0?Shn03dm?@0n?Sh0>3Ph03hn?P0m?Cd203`l?00D03lo
?`1DE5@0H61P07IfMP1oOgl0UiNG07YjNP1/K6`0Fe]K04Y:BP12@T80?Shn03dm?@0l?3`0?Cdm03/k
>`0i>CT0>c/k03Xj>P0i>CT203`l?00303Ti>@0j>SX0?Cdm0080>CTi00D0?Cdm03Ti>@0h>3P0>CTi
03Xj>P0203/k>`0703Ti>@0j>SX0>3Ph03Lg=`0j>SX0>CTi03Hf=P0203Lg=`0X03Xj>P0l?3`0DE5A
07]kN`1iNGT0Kfm_075aL@1bLW80Ti>C0:VYZ@2d];@0d=3@0>;RhP3Ti>@0h>3P0=kNgP3=cLd0ZJVY
07YjNP1JFUX0CTi>0410@00l?3`0>c/k03hn?P0h>3P0>c/k03Ph>00i>CT0=cLg03Hf=P0j>SX0>c/k
0492@P1=CDd0@D5103hn?P0j>SX0=cLg03/k>`<0?3`l0P0m?Cd0101?Cdl0PX:20;no_`3Fe]H20=OG
e`0X0=;BdP3Cdm<0b/[:0<g=c@38b<P0d=3@0<k>cP2b/[80W9bL08b<S01dM7@0GemO055AD@18B4P0
C4a<059BDP1OGel0GEeM06][J`1dM7@0MGEe07MgM`1cLg<0Hf=S069RHP1[Jf/0RXZ:0:>SX`2XZ:P0
VYZJ08J6QP1hN7P0J6QX055AD@18B4P0A4A404I6AP0o?cl0@41004A4A0gooooo000@ooooo`0804];
B`1=CDd0CDe=04e=C@18B4P0BDU904Y:BP1=CDd204I6AP0704a<C019BDT0ADE504I6AP18B4P0BTY:
04M7A`0204E5A@0304I6AP1:BTX0AdM70080ADE500h0@d=304E5A@16ATH0AdM704Y:BP17AdL0BDU9
04M7A`18B4P0AdM704I6AP15ADD0A4A404E5A@80ATI600L0AdM704A4A013@d<0@T9204=3@`12@T80
@D510080A4A400X0@T920451@@13@d<0@D510410@013@d<0A4A40451@@0n?Sh0@4100P12@T805@10
@400A4A40410@011@D40?Shn04I6AP0n?Sh0@41003dm?@0l?3`0?Cdm03/k>`0o?cl0?Shn0410@00l
?3`0@4100492@P0m?Cd0>SXj03dm?@0203hn?P0403/k>`0i>CT0?clo0451@@80?3`l00d0@D5103hn
?P10@400@T9203dm?@10@400?clo03dm?@0j>SX0?3`l03dm?@0i>CT0>c/k0080?Cdm00@0@D5103Ti
>@10@400>SXj0P10@4003@0n?Sh0@D5104];B`1MGEd0D51@03lo?`0l?3`0@4100451@@0m?Cd0A4A4
03lo?`12@T800P10@4005P14A4@0@D5103dm?@14A4@0C4a<05IFEP1RHV80Hf=S05eMG@1HF5P0De=C
061PH01HF5P0@d=30451@@1;Bd/0De=C061PH01LG5`0EeMG065QH@1XJ6P204m?C`1504a<C01JFUX0
Cdm?04e=C@1UIFD0NGUi08J6QP1IFET0C4a<06EUI@1TI6@0LG5a06QXJ01KFe/0EeMG05EEE@1;Bd/0
CTi>05=CD`1DE5@0F5QH04a<C01;Bd/0CTi>04A4A013@d<0@4100451@@13@d<0@D5104e=C@1^KVh0
TY:B06YZJP1YJFT0WYjN0:6QX@2IVIT0WinO0:j^[P2XZ:P0Zj^[0;:b/P2PX:00SHf=075aL@1LG5`0
DU9B07]kN`1lO7`0S8b<09RHV02UYJD0UIFE08f=S@2>SXh0Z:RX0;6a/@2RXZ80RHV906i^KP1OGel0
A4A40451@@0m?Cd0>c/k03Ti>@10@400?3`l0080?Cdm00@0>CTi03/k>`0l?3`0>c/k0P0m?Cd02010
@400?3`l03dm?@0j>SX0?clo03Xj>P0l?3`0>c/k0P0l?3`01P0k>c/0?3`l03/k>`0k>c/0?Cdm03Ti
>@80@4100P0h>3P01P0m?Cd0>CTi03/k>`0l?3`0=SHf03`l?080>CTi00h0?3`l0410@00j>SX0?clo
03Ti>@0k>c/0>CTi03Ph>00i>CT0>3Ph03Lg=`0f=SH0>3Ph03`l?080>CTi00P0>c/k03hn?P0i>CT0
?Shn03Lg=`0o?cl0=SHf03/k>`<0>CTi0P0n?Sh03@0m?Cd0@D5103Ti>@0m?Cd0>3Ph03/k>`0h>3P0
>SXj03dm?@0n?Sh0@T9204E5A@10@4000P0i>CT03@0l?3`0?Cdm03dm?@0k>c/0>CTi03/k>`0n?Sh0
?Cdm03hn?P0j>SX0?Shn03/k>`0m?Cd00P0o?cl0100j>SX0>CTi03/k>`0n?Sh303Xj>P0303/k>`0l
?3`0>SXj0080?3`l0`0m?Cd03`10@400>c/k03`l?00j>SX0>c/k05EEE@1^KVh0PH6108B4Q02LW9`0
KVi^059BDP11@D40@4100451@@0203lo?`0403`l?00g=cL0>CTi03/k>`80>3Ph00T0?Shn03`l?00j
>SX0>CTi03hn?P0f=SH0>CTi03Xj>P0k>c/00P0j>SX05@0h>3P0>SXj03Ti>@0i>CT0=cLg03dm?@14
A4@0ATI603`l?00k>c/0>3Ph03/k>`0i>CT0>SXj04=3@`1CDe<0IVIV075aL@1ZJVX0HV9R079bLP02
07=cL`0@07YjNP2>SXh0Shn?07AdM02?Shl0_kno0:JVYP1oOgl0DE5A04E5A@0n?Sh0>c/k03hn?P0m
?Cd0>c/k03Xj>P80>c/k00P0=cLg03Ph>00h>3P0=cLg03Ti>@0j>SX0=SHf03dm?@<0>SXj00@0?3`l
03Hf=P0k>c/0>c/k0P0m?Cd04017AdL0F5QH08n?S`2n_[h0dm?C0=GEe@3Bd]80a<C40<;2`P39bLT0
bl_;0;^k^`2FUYH0N7Qh05IFEP14A4@203hn?P0:0451@@1?Cdl0K6a/08j>SP2@T900U9BD092@T01`
L700FEUI04];B`80?3`l00<0?clo03Xj>P0n?Sh00P1ADE403@18B4P0?Shn0410@00l?3`0?Shn03/k
>`10@400?Cdm04E5A@1;Bd/0FEUI06m_K`2?Shl03Oooool0013ooooo0`1?Cdl0401=CDd0B4Q804Q8
B01;Bd/0BDU904e=C@18B4P0BDU904M7A`18B4P0AdM704Q8B01;Bd/0BTY:04I6AP17AdL204E5A@0=
04M7A`18B4P0ADE504=3@`14A4@0ADE504Q8B01;Bd/0BDU904I6AP15ADD0BDU904Q8B00204A4A007
04M7A`16ATH0ADE504I6AP18B4P0Bd];0492@P020451@@0604=3@`14A4@0@d=303lo?`10@400@D51
0P14A4@02@11@D40@d=304A4A012@T80@41003lo?`12@T80@41004=3@`020451@@050492@P0l?3`0
@D510410@012@T800P0n?Sh01`10@400?3`l03lo?`10@400?clo03`l?00m?Cd00P0o?cl0400l?3`0
?Shn03hn?P0n?Sh0?Cdm03lo?`0n?Sh0A4A403`l?00n?Sh0?clo03`l?00n?Sh0?3`l04=3@`11@D42
03hn?P050410@00m?Cd0?Cdm03/k>`11@D400P0n?Sh02@16ATH0@d=30492@P0o?cl0?Shn04a<C014
A4@0@T920451@@0203hn?P080410@012@T80@41003lo?`0n?Sh0@D5104I6AP13@d<204e=C@0Q04a<
C01EEED0GUiN06IVIP1TI6@0G5aL05IFEP1DE5@0Fe]K05IFEP1?Cdl0D51@04A4A013@d<0@D5103hn
?P16ATH0BTY:0451@@13@d<0ADE504Y:BP15ADD0AdM70492@P1<C4`0A4A404I6AP10@400@D5104M7
A`15ADD0A4A40080@D510240A4A40451@@0l?3`0@41003hn?P0m?Cd0@T9203dm?@0n?Sh0@T9203`l
?012@T80@41003hn?P0m?Cd0BDU904Q8B01;Bd/0AdM704I6AP15ADD0E5AD06MWI`1jNWX0VIVI07Ui
N@1^KVh0NWYj08:2PP2HV9P0_;bl0<[:bP31`L400P34a<@0:02c/k<0XJ6Q09NGU`2>SXh0UYJF09^K
V`2LW9`0Xj>S0;:b/P3Bd]80f=SH0=gMg@3Ng]h0bLW90;Jf]P2SXj<0Ti>C07YjNP1:BTX0ATI604U9
B@15ADD0B4Q804U9B@0m?Cd0>c/k03`l?00i>CT0?3`l03dm?@0l?3`0@d=303hn?P0l?3`0?Shn03/k
>`0j>SX0>c/k0410@00m?Cd303Xj>P0403`l?00j>SX0>3Ph03hn?P80>c/k00@0?Shn03Xj>P0i>CT0
>CTi0P0o?cl01@0m?Cd0>c/k03/k>`0m?Cd0?3`l00@0>CTi00D0>c/k03Ti>@0g=cL0>3Ph03Ti>@02
03Ph>00403Xj>P0m?Cd0>CTi03dm?@80>c/k00<0>SXj03Ti>@0h>3P00P0j>SX02`0m?Cd0=cLg03Ti
>@0k>c/0?Cdm03`l?00h>3P0>CTi03Ph>00k>c/0=SHf0080>CTi00<0?3`l03/k>`0i>CT00`0j>SX0
1@0k>c/0?3`l03/k>`0j>SX0>3Ph0080>CTi0100>3Ph03Lg=`0i>CT0?3`l03Ph>00g=cL0>SXj03Ti
>@0j>SX0?3`l03hn?P0m?Cd0>SXj03Lg=`0k>c/0?3`l0P0i>CT01P0m?Cd0>c/k03Xj>P0i>CT0>c/k
03`l?080>SXj0P0m?Cd02`0o?cl0BDU905EEE@1JFUX0CTi>04a<C015ADD0>c/k03`l?00k>c/0?Cdm
0080?Shn00@0?Cdm03Xj>P0j>SX0>c/k0P0l?3`00`0k>c/0?3`l03Ti>@0203Ti>@0703Ph>00e=CD0
>CTi03/k>`0i>CT0>SXj03Ph>00203Xj>P0K03/k>`0i>CT0CDe=05]KF`1<C4`0A4A40410@00k>c/0
?3`l04M7A`1EEED0FEUI05YJFP1ADE40BDU9065QH@20P800SHf=09:BTP1YJFT0HV9R05ADE01GEeL0
EUIF05aLG01TI6@0Cdm?0080@D5100/0?Cdm03Xj>P0k>c/0>SXj03/k>`0l?3`0?clo03`l?00h>3P0
=SHf03Xj>P0203Ti>@0403Xj>P0i>CT0?3`l03Ph>0<0>SXj0280?3`l03Xj>P0o?cl0@D5104m?C`1Y
JFT0R8R80:f][@3<c<`0gMgM0=kNgP3Fe]H0f=SH0=GEe@3IfMT0d=3@0;>c/`25QHD0FEUI0451@@16
ATH0@D5103`l?011@D40Bd];06EUI@2ATI40TY:B07YjNP1KFe/0AdM70451@@0i>CT0=cLg0P0i>CT2
03Lg=`0A03De=@0h>3P0?3`l03hn?P0j>SX0?3`l03dm?@14A4@0F5QH06MWI`2=SHd0XZ:R0;6a/@30
`<00c/k>0=SHf03Lg=`03Oooool0013ooooo00@0CDe=04a<C01>CTh0Bd];0P1:BTX01P1;Bd/0B4Q8
04Y:BP18B4P0AdM704E5A@80AdM700<0ATI604Q8B01;Bd/00P18B4P02016ATH0AdM704U9B@1:BTX0
AdM704I6AP14A4@0ADE51018B4P01015ADD0ATI604E5A@1ADE4204M7A`0;04A4A015ADD0ATI604U9
B@16ATH0A4A404M7A`16ATH0@T9204I6AP14A4@00P11@D401013@d<0A4A403lo?`10@4030492@P04
0451@@0o?cl0@D5103hn?P80?Cdm00d0@D5104=3@`13@d<0@d=304E5A@16ATH0@D5103dm?@10@400
?Shn03lo?`10@400?Cdm00<0?3`l00<0?Cdm03lo?`10@4000`0l?3`01@0m?Cd0>c/k04=3@`0k>c/0
?Cdm00<0?clo00T0?Cdm03Xj>P0o?cl0?clo0410@00o?cl0?Cdm03hn?P0k>c/00P0n?Sh06P0k>c/0
?Cdm0410@012@T80?Cdm03lo?`10@400?Shn0492@P13@d<0@4100451@@1GEeL0Fe]K04I6AP10@400
@d=304A4A01>CTh0FEUI071`L01YJFT0HF5Q05UIF@1?Cdl0CDe=0`13@d<01014A4@0@D510451@@15
ADD204A4A0050451@@0o?cl0@d=303/k>`10@4000P0l?3`203hn?P0703`l?00o?cl0@4100410@012
@T80?Shn03`l?00203lo?`0/04M7A`0m?Cd0@41003`l?00o?cl0?3`l03hn?P0o?cl0@T9203lo?`0n
?Sh0>c/k03hn?P0o?cl0?3`l03dm?@11@D40ATI6069RHP1^KVh0M7Ad07]kN`2@T900UiNG08J6QP21
PH40JFUY05YJFP1mOGd0Shn?08f=S@29RHT0U9BD0:BTY02VYZH0UIFE08^;R`27QhL0PH6107UiN@1V
IVH0Hf=S07MgM`2<S8`209:BTP0;08n?S`1hN7P0P82008N7Q`26QXH0OWin06m_K`1SHf<0F5QH06IV
IP2HV9P00P2a/K402@2;Rh/0XZ:R0:^[Z`2b/[80SXj>06a/K016ATH0?Cdm03/k>`0203Xj>P080410
@00l?3`0?clo04e=C@1<C4`0>SXj03hn?P10@40203dm?@0503/k>`0m?Cd0?clo03/k>`0j>SX00P0n
?Sh01`0m?Cd0>CTi03`l?011@D40>CTi03/k>`14A4@00P0l?3`203/k>`80>SXj00<0>CTi03Lg=`0i
>CT00P0j>SX01P0h>3P0=cLg03Ti>@0h>3P0>CTi03Xj>P80>c/k00D0>CTi03Ph>00k>c/0>SXj03Lg
=`0303Ph>00303Xj>P0g=cL0>CTi0080=SHf00H0>3Ph03Lg=`0e=CD0>CTi03hn?P0k>c/203Ti>@06
03`l?00j>SX0?3`l03hn?P0l?3`0>c/k0P0i>CT02P0k>c/0?3`l03`l?00j>SX0?Cdm03/k>`0m?Cd0
>c/k03`l?00k>c/203`l?00603Ti>@0l?3`0?3`l03hn?P0m?Cd0?3`l0P0j>SX0100l?3`0>c/k03`l
?00n?Sh203Ti>@0<03dm?@0l?3`0>c/k03dm?@0o?cl0@d=303lo?`0n?Sh0>SXj03dm?@0k>c/0>SXj
0P0i>CT01@0o?cl0?Cdm03/k>`0j>SX0>CTi0080?Cdm00X0>c/k03Ti>@0m?Cd0@41003`l?00m?Cd0
>SXj03Lg=`0j>SX0>3Ph0P0i>CT04P0l?3`0>3Ph03`l?00g=cL0>c/k03Lg=`0j>SX0?clo0410@00l
?3`0?clo03/k>`0i>CT0>SXj03dm?@13@d<0D51@0451@@80B4Q801<0J6QX07]kN`29RHT0_;bl0<?3
``30`<00/[:b08Z:RP1VIVH0AdM703hn?P10@400>SXj03dm?@0l?3`0>c/k03Ph>00i>CT0>3Ph0080
>SXj00H0>CTi03dm?@0k>c/0>CTi03Xj>P0i>CT203Ph>080>CTi01H0>3Ph03/k>`0i>CT0>c/k0410
@01=CDd0IVIV08^;R`2/[:`0d=3@0=KFeP3IfMT0e]KF0=3@d03Kfm/0h>3P0=SHf02n_[h0V9RH07em
O@1UIFD0De=C0P14A4@0200l?3`0@41004=3@`15ADD0D51@04];B`19BDT0@T920P0i>CT203/k>`0H
03Ti>@0h>3P0=cLg03Ti>@0f=SH0>SXj03Ti>@0h>3P0?Cdm03`l?01=CDd0GEeM0861P@2VYZH0_Kfm
0=KFeP3QhN40hn?S0>OWi`3Vi^H0h>3P0=WIf@3Bd]80d=3@3Oooool0013ooooo00l0Bd];04Y:BP1?
Cdl0Bd];04e=C@1;Bd/0B4Q804U9B@17AdL0ATI604M7A`1<C4`0B4Q804Y:BP18B4P00P14A4@00`16
ATH0B4Q804A4A00204Q8B00504I6AP15ADD0ATI604E5A@16ATH00P17AdL02P14A4@0ATI604M7A`1;
Bd/0AdM704=3@`1;Bd/0ATI604A4A013@d<20492@P0304A4A011@D40@D510080A4A400@0AdM704=3
@`12@T80@d=30P10@40203lo?`<0@4100P11@D40300o?cl0?Cdm03dm?@0o?cl0@T9204=3@`14A4@0
@d=30451@@10@400?Shn03Xj>P80?clo00<0?Shn03lo?`0l?3`0100n?Sh01@0m?Cd0?Shn03lo?`0m
?Cd0?3`l00D0?Cdm00X0?3`l03lo?`0n?Sh0?clo03hn?P0m?Cd0?3`l03lo?`17AdL0@4100P0o?cl0
200j>SX0?Cdm03`l?00n?Sh0>c/k03Ph>00l?3`0>3Ph0P13@d<203lo?`0703dm?@13@d<0BTY:0451
@@0l?3`0?clo04=3@`0204E5A@0404e=C@1>CTh0AdM705QHF080GemO00P0E5AD04I6AP17AdL0DU9B
05]KF`1MGEd0EEEE04a<C080@41000H0@d=303hn?P0m?Cd0?Shn0451@@0j>SX303lo?`0:03`l?00m
?Cd0>SXj03/k>`0o?cl0?3`l03dm?@0k>c/0?clo04A4A080?Shn00T0@D510410@010@400?3`l03lo
?`0k>c/0?Cdm0451@@0o?cl00P10@400100n?Sh0?clo03dm?@0m?Cd204=3@`0505ADE01jNWX0S8b<
08^;R`1`L7000P1mOGd01P1eMGD0KVi^05iNGP1CDe<0EEEE05]KF`80DE5A02<0ADE5055AD@1NGUh0
GUiN06QXJ01PH600J6QX08^;R`21PH40SXj>08J6QP2?Shl0I6AT055AD@1bLW80V9RH09fMW@20P800
MGEe06=SH`1=CDd0Bd];06MWI`23Ph<0VYZJ0<K6aP2n_[h0VIVI08R8R02>SXh0Shn?07moO`1QHF40
FUYJ04I6AP020410@00907AdM02QXJ40Ng]k06EUI@1IFET0CTi>04Q8B014A4@0@D510080?Cdm00l0
>SXj03hn?P0l?3`0?Cdm03/k>`0m?Cd0?clo04A4A00m?Cd0>SXj03`l?00k>c/0?Cdm03`l?00k>c/0
0P0i>CT01`0j>SX0>c/k03Xj>P0i>CT0?3`l03Ti>@0e=CD00P0h>3P01P0i>CT0>SXj03Xj>P0j>SX0
?3`l0410@0<0>CTi00D0=cLg03Xj>P0k>c/0?3`l03Hf=P0203Ti>@0503/k>`0i>CT0=cLg03Ph>00j
>SX00P0k>c/303Ti>@0J03Xj>P0i>CT0>SXj03/k>`0i>CT0=cLg03/k>`0n?Sh0?Cdm03Ti>@0h>3P0
>CTi03Hf=P0l?3`0?Cdm03lo?`0n?Sh0>c/k03`l?00j>SX0?Shn03Xj>P0k>c/0>3Ph03Lg=`0i>CT2
03`l?080>c/k00/0>SXj03Ti>@0l?3`0@D5103lo?`0j>SX0?Cdm03Ti>@0j>SX0>CTi03Xj>P0203`l
?00703Xj>P0l?3`0?Cdm03lo?`1;Bd/0CDe=0492@P0203hn?P040492@P0n?Sh0?clo03`l?080BTY:
00D0>CTi03hn?P0k>c/0>CTi03`l?00203Ti>@0703Ph>00o?cl0>SXj03Ph>00l?3`0C4a<03Ph>003
03Xj>P0R03`l?00h>3P0>SXj03Ph>00n?Sh0@T9205aLG01GEeL0G5aL07=cL`1`L700RXZ:0;:b/P2K
Vi/0TI6A06][J`1HF5P0AdM70410@00o?cl0ADE503hn?P0m?Cd0?3`l03Ph>00l?3`0>SXj03Ph>00k
>c/0>3Ph03Ti>@0k>c/0>CTi03Xj>P80>CTi0140?Cdm03Xj>P0k>c/0>c/k03Xj>P0i>CT0?Cdm0492
@P1IFET0MgMg0:VYZ@3Bd]80hN7Q0>KViP3Ti>@0d=3@0<C4a0020<30`00_0<k>cP3AdM40a/K609BD
U01_Kfl0CTi>03lo?`0l?3`0A4A405mOG`23Ph<0UYJF08n?S`23Ph<0JVYZ04e=C@0o?cl0>c/k03`l
?00i>CT0>SXj03/k>`0i>CT0>3Ph03hn?P0h>3P0=cLg03Ti>@0j>SX0@41006MWI`2<S8`0ZZZZ0<C4
a03Cdm<0b/[:0;Bd]02`/;00`L710=_Kf`3Ti>@0j>SX0>CTi03Shn<0i>CT0>GUi@3YjNT03Oooool0
013ooooo00@0Bd];04a<C01:BTX0Bd];0P1:BTX00`18B4P0BTY:04I6AP0204M7A`0604Y:BP17AdL0
BTY:04Q8B015ADD0ATI60P15ADD04@1<C4`0ADE504E5A@12@T80ATI604E5A@16ATH0A4A404I6AP13
@d<0A4A404M7A`16ATH0A4A40492@P18B4P0A4A40080@T9200`0A4A40451@@14A4@0@D5104I6AP13
@d<0A4A404I6AP13@d<0@T9204I6AP18B4P204A4A00>04=3@`14A4@0@T9203dm?@10@400@d=304A4
A015ADD0@41003`l?012@T80@d=30410@00m?Cd20451@@030410@011@D40?3`l0080?Shn00T0>c/k
0410@010@400?3`l03/k>`0m?Cd0@T9203dm?@0n?Sh00`0l?3`01P0m?Cd0>CTi03hn?P0j>SX0?3`l
03dm?@<0?Shn00@0@41003hn?P0l?3`0>CTi0P0k>c/01P10@400?Cdm03Xj>P0i>CT0?Shn03dm?@80
>SXj00D0>CTi03hn?P10@400?Cdm03/k>`0303dm?@0<04=3@`17AdL0A4A40451@@12@T80@41003hn
?P0o?cl0@D510492@P17AdL0A4A40P15ADD01P14A4@0ADE504Q8B019BDT0ATI60492@P80@4100P0o
?cl01P13@d<0?Shn04U9B@16ATH0BDU903lo?`80@41000d0>SXj03dm?@0n?Sh0?3`l03hn?P12@T80
?clo03/k>`0l?3`0>SXj03lo?`10@400?3`l0080?Cdm0P0k>c/03`0l?3`0?Shn03`l?00m?Cd0>SXj
04A4A00n?Sh0>c/k03dm?@0k>c/0?Shn03dm?@19BDT0D51@04i>CP0304A4A0<0?Shn01<0@T9204M7
A`19BDT0B4Q805mOG`1fMWH0KFe]08f=S@2ZZZX0[Zj^0;Bd]02WYjL0WIfM09^KV`2FUYH0RHV90861
P@1gMgL0QHF50080W9bL0300QhN706i^KP1OGel0FEUI04e=C@10@400ADE504a<C016ATH0ADE506YZ
JP2EUID0/K6a0;Ng]`31`L40/K6a08J6QP2IVIT0YjNW0:JVYP2SXj<0ZZZZ0<G5a@2i^KT0];Bd09jN
WP2IVIT0UiNG0:BTY02RXZ80V9RH07MgM`1NGUh0@D5103dm?@0k>c/0?Cdm03hn?P0m?Cd0?clo03hn
?P0o?cl0=cLg03dm?@0k>c/0Bd];03`l?00k>c/203Xj>P0403Lg=`0l?3`0?3`l03dm?@<0>3Ph00L0
>CTi03/k>`0l?3`0>SXj03Ti>@0k>c/0>CTi0080>c/k00@0=cLg03Ph>00i>CT0=CDe0P0g=cL0100j
>SX0>CTi03`l?00k>c/203Xj>P0B03Hf=P0j>SX0>CTi03Ti>@0h>3P0>SXj03Ph>00j>SX0>3Ph03Lg
=`0h>3P0?3`l03/k>`0j>SX0>3Ph03Ti>@0m?Cd0>CTi0P0g=cL02`0k>c/0>SXj03`l?00l?3`0?Shn
03/k>`13@d<0?Cdm03Ti>@0h>3P0>SXj00@0?3`l00H0@41003/k>`0h>3P0>SXj0410@011@D4203`l
?0<0>c/k0P0i>CT01@0h>3P0>SXj03`l?00l?3`0?clo0080?Shn0P0j>SX08P0n?Sh0>c/k03dm?@0j
>SX0?3`l03dm?@1@D500BDU903Ti>@0k>c/0@41003`l?00k>c/0?3`l03dm?@0k>c/0=cLg03Ti>@0f
=SH0>SXj04=3@`0h>3P0>CTi03/k>`12@T80?Shn0492@P1;Bd/0F5QH079bLP22PX80NGUi04a<C01R
HV820:>SX`0@08Z:RP1gMgL0GEeM04U9B@0n?Sh0?3`l0492@P1;Bd/0Cdm?04Y:BP0n?Sh0?3`l03dm
?@0k>c/0?Cdm03`l?080>c/k02/0>3Ph03/k>`0l?3`0>CTi03Ph>00j>SX0>CTi03`l?00m?Cd0@410
04];B`1OGel0PX:20:2PX02`/;00fMWI0>?Sh`3Xj>P0jNWY0>SXj03MgMd0dm?C0<W9b@2f][H0/;2`
0;Zj^P3;bl/0/[:b08R8R01hN7P0H61P051@D01GEeL0KVi^07UiN@2CTi<0T92@07IfMP1QHF40BDU9
0451@@0g=cL0>CTi0080>SXj01`0>3Ph03/k>`0k>c/0>SXj03Lg=`0k>c/0>SXj0410@01>CTh0S8b<
0;Zj^P3Ph>00dm?C0:j^[P2:RXX0QXJ608V9R@2b/[80d=3@0>CTi03Rh^80i^KV0>GUi@3QhN40f=SH
0=?Cd`3;bl/0`/;23Oooool0013ooooo00d0D51@04a<C01<C4`0C4a<04U9B@1:BTX0AdM704Q8B01:
BTX0B4Q804U9B@17AdL0BDU900<0AdM700T0B4Q804U9B@16ATH0AdM704I6AP17AdL0BDU904Q8B016
ATH00P15ADD00`14A4@0ADE504A4A00304A4A00D0492@P15ADD0@d=304=3@`11@D40@d=30492@P11
@D40@41004I6AP14A4@0ADE504M7A`12@T80@D510410@016ATH0AdM704=3@`14A4@204=3@`040451
@@14A4@0@T920410@080@D5101d0ADE50410@00n?Sh0?Shn03`l?011@D40@T920410@013@d<0@T92
03hn?P0o?cl0@D5103lo?`0k>c/0?Shn03lo?`0m?Cd0>c/k03hn?P0m?Cd0?Shn03`l?00m?Cd0?clo
03/k>`0l?3`0>SXj03/k>`0203hn?P80?3`l0P0m?Cd203hn?P0>03`l?00k>c/0?Shn03/k>`12@T80
>SXj03/k>`0m?Cd0?Shn03`l?00n?Sh0?clo03hn?P0j>SX203Ti>@0804=3@`0o?cl0?Shn03/k>`0m
?Cd0>SXj03lo?`0l?3`203lo?`0A0451@@10@400@D5103hn?P0o?cl0?Shn03dm?@0l?3`0?clo04=3
@`14A4@0?Shn03/k>`0n?Sh0@41003lo?`11@D400P0m?Cd04`11@D40?Shn03hn?P0m?Cd0@T9203lo
?`0m?Cd0?3`l04=3@`1@D500Cdm?0451@@0m?Cd0?clo03hn?P0l?3`0@41003Xj>P0i>CT00`0l?3`0
E`10@400Bd];05]KF`1CDe<0CDe=04Y:BP12@T80?clo0410@00o?cl0A4A404a<C011@D40?clo0410
@013@d<0@D510492@P0j>SX0>c/k03Xj>P0o?cl0BDU9059BDP1QHF40KFe]07IfMP1mOGd0RHV90:6Q
X@2[Zj/0_[jn0;no_`2e]KD0VYZJ08J6QP1gMgL0MGEe07AdM01`L700IVIV05]KF`1=CDd0@T920451
@@0l?3`0AdM705ADE01VIVH0L71`06i^KP1`L700UIFE0::RXP2^[Zh0][Jf0;fm_@2b/[80SHf=08R8
R02YZJT0b<S80<71`@39bLT0bl_;0;Fe]@2o_kl0/K6a08V9R@1NGUh0DU9B06=SH`1WIfL0I6AT08N7
Q`25QHD0P82008n?S`2DU9@0K6a/05=CD`10@400>SXj03lo?`0l?3`0?Cdm03`l?00203/k>`0403Xj
>P0k>c/0?Shn03Xj>P80>3Ph00P0>c/k03Ph>00f=SH0=cLg03Xj>P0k>c/0>CTi03Xj>P<0>CTi00<0
>c/k03Xj>P0k>c/00P0h>3P01@0i>CT0>3Ph03Ti>@0j>SX0=cLg00<0>CTi00@0=CDe03Lg=`0l?3`0
>c/k0P0i>CT0200l?3`0=cLg03/k>`0h>3P0>SXj03Lg=`0i>CT0>c/k0P0j>SX0100k>c/0>3Ph03/k
>`0i>CT203Lg=`0;03dm?@0k>c/0?Cdm03/k>`0i>CT0=cLg03Xj>P0g=cL0>CTi03`l?00h>3P00P0i
>CT03`0h>3P0=cLg03`l?018B4P0?3`l03Xj>P15ADD0?Shn03`l?00k>c/0?3`l03/k>`0j>SX0>3Ph
03Ti>@0203Xj>P0503Ph>00g=cL0>SXj03`l?00k>c/00P0j>SX01`0n?Sh0?Cdm03Hf=P0f=SH0?3`l
03/k>`0m?Cd00P0l?3`00`0n?Sh0>SXj03Ph>00203Lg=`0303Xj>P0i>CT0>CTi0080>SXj00@0?Shn
0451@@1<C4`0GemO0P17AdL04P1CDe<0KVi^06YZJP1_Kfl0PH6107IfMP29RHT0TI6A08^;R`1oOgl0
Lg=c07EeM@1^KVh0F5QH0410@00l?3`0?clo03dm?@80>SXj00X0>c/k03`l?00l?3`0>c/k03Ph>00g
=cL0>SXj03hn?P0m?Cd0>CTi0P0k>c/08`0n?Sh0Bd];069RHP1`L700W9bL0;Bd]033`l<0d];B0<[:
bP2o_kl0dM7A0=KFeP3Bd]80d=3@0=gMg@3Ph>00fm_K0=WIf@3Hf=P0clo?0=;BdP3;bl/0[:b/08j>
SP2MWId0WinO07moO`1PH600BDU904];B`10@400?Cdm03/k>`0n?Sh0ADE50080>SXj0200>CTi03`l
?00g=cL0>CTi03/k>`0f=SH0>SXj03Ti>@0o?cl0DE5A07alO02LW9`0`<300=KFeP32`/80YJFU09RH
V02SXj<0_kno0=WIf@3Xj>P0h>3P0=WIf@3EeMD0dM7A0<71`@2QXJ40SXj>07AdM01VIVH0GemO05MG
E`gooooo000@ooooo`0304m?C`1=CDd0CDe=00<0BTY:0`17AdL03P18B4P0BTY:04U9B@19BDT0ATI6
04M7A`1:BTX0Bd];04Y:BP19BDT0AdM704Q8B017AdL0BTY:0`16ATH204M7A`0304U9B@15ADD0A4A4
0080@d=300@0@T9204=3@`15ADD0@d=30P10@4003@13@d<0?clo0410@013@d<0@41004A4A012@T80
?clo0410@00o?cl0ADE504=3@`16ATH00P12@T802@13@d<0@T9204=3@`12@T80@D5103lo?`11@D40
@41003hn?P0204=3@`030492@P11@D40?clo00<0?Shn0P0m?Cd03`0n?Sh0@D5103lo?`0l?3`0?Cdm
0410@00i>CT0>c/k03lo?`0l?3`0?Shn0492@P0o?cl0?Cdm0410@00203`l?00:03dm?@0n?Sh0?clo
0451@@13@d<0@T9203hn?P0m?Cd0@41003hn?P80?Cdm00D0@T9203hn?P0k>c/0>CTi03Ph>00203/k
>`0403dm?@0j>SX0>SXj03hn?P80?clo0P0m?Cd0200k>c/0?3`l0451@@0l?3`0@d=30492@P14A4@0
@D510P10@4004`11@D40ATI604=3@`13@d<0ADE504=3@`0n?Sh0@T9203hn?P0l?3`0?Shn03dm?@0l
?3`0@T9204];B`11@D40AdM704I6AP0o?cl00P11@D4203hn?P030451@@0i>CT0?Shn0080@T9201h0
AdM704E5A@15ADD0CTi>04A4A012@T80?Shn04e=C@1JFUX0D51@05aLG01iNGT0RXZ:08R8R01jNWX0
G5aL04M7A`19BDT0CDe=04a<C01?Cdl0EeMG06=SH`1RHV80Cdm?04E5A@10@400@T9203`l?010@402
0451@@0704I6AP17AdL0D51@05YJFP1QHF40J6QX08F5Q@020;Bd]00T0:JVYP24Q8@0JFUY05EEE@19
BDT0ADE503dm?@10@400?Shn0410@00o?cl0@4100451@@12@T80@D5104M7A`1JFUX0GemO05]KF`1H
F5P0FEUI06=SH`1jNWX0XJ6Q0<K6aP2g]kL0MgMg096AT@2PX:00XZ:R0:JVYP2KVi/0/k>c0;Bd]02;
Rh/0Shn?0P2KVi/03P2GUiL0NWYj04];B`1UIFD0OWin06MWI`29RHT0T92@09:BTP2ATI40Ph>306e]
K@18B4P0?Cdm0P0o?cl04@0n?Sh0>SXj03`l?00j>SX0?Cdm03`l?00k>c/0?3`l03/k>`0l?3`0>SXj
03/k>`0l?3`0>c/k03Ph>00l?3`0>SXj0080?3`l00/0?clo03`l?00h>3P0>CTi03Lg=`0n?Sh0>SXj
03Hf=P0g=cL0>3Ph03Lg=`0203Ti>@0803Lg=`0j>SX0>CTi03Ti>@0j>SX0?3`l03dm?@0g=cL203Xj
>P0303/k>`0g=cL0>SXj0080>3Ph00<0?3`l03Ti>@0h>3P00P0j>SX01`0i>CT0>3Ph03Ph>00i>CT0
?Shn03/k>`10@4000P0m?Cd01@0l?3`0>c/k03hn?P0k>c/0?Cdm0080>SXj00X0?Cdm03Ti>@0i>CT0
H61P05MGE`0n?Sh0>SXj03/k>`0m?Cd0>c/k0P0l?3`203Xj>P0303Ph>00i>CT0>SXj00@0>SXj0P0h
>3P01P0k>c/0>3Ph03dm?@0m?Cd0?3`l03Ti>@80>c/k00<0?Shn03Xj>P0l?3`00`0k>c/07`0j>SX0
=cLg03dm?@0j>SX0CTi>04a<C01CDe<0KVi^08J6QP2=SHd0L71`051@D01KFe/0FUYJ05aLG01GEeL0
Ph>308R8R01iNGT0Lg=c06=SH`1WIfL0JFUY05IFEP1OGel0D51@03hn?P0i>CT0>3Ph03Xj>P0h>3P0
0`0g=cL203/k>`80>CTi0P0h>3P303Xj>P0M05=CD`1fMWH0YJFU0;^k^`3Fe]H0f][J0=_Kf`35aLD0
UiNG07AdM01oOgl0[Jf]0<g=c@2b/[80Vi^K09fMW@33`l<0/[:b09^KV`2FUYH0V9RH09NGU`2VYZH0
NWYj05EEE@1;Bd/0B4Q80492@P0i>CT00P0k>c/01`0m?Cd0>SXj03Ti>@0i>CT0>c/k04A4A00i>CT0
0P0h>3P00`0l?3`0>3Ph03`l?00203Xj>P0J04A4A01/K6`0W9bL0<k>cP3Ng]h0d];B0<_;b`2h^;P0
];Bd0<S8b03Ogml0hn?S0=CDe039bLT0XJ6Q08R8R01[Jf/0EUIF04U9B@16ATH0@D5104E5A@17AdL0
Bd];04Y:BP1@D50=ooooo`004?ooool00`1<C4`0Bd];04U9B@0204];B`0404a<C019BDT0AdM704E5
A@80BDU90P18B4P02`19BDT0BTY:04];B`1:BTX0A4A404M7A`16ATH0AdM704E5A@16ATH0@d=30080
AdM70180ADE504M7A`16ATH0AdM704I6AP13@d<0A4A404M7A`11@D40A4A40492@P14A4@0@T9204I6
AP14A4@0@d=304E5A@11@D4304=3@`050451@@12@T80@D5104=3@`12@T801011@D400`10@400ADE5
04=3@`0203lo?`0:0410@00o?cl0A4A404=3@`0n?Sh0?clo0451@@10@400?Shn0410@080?Shn01d0
@T920410@00m?Cd0?Shn03`l?00j>SX0?clo03dm?@10@400?3`l03lo?`11@D40?Shn04=3@`11@D40
?3`l03hn?P0j>SX0>c/k0410@011@D40?3`l03dm?@0n?Sh0?Cdm0451@@0n?Sh0>c/k03`l?00203hn
?P0E03/k>`0h>3P0?Cdm0492@P0l?3`0>c/k03lo?`0l?3`0?clo03Xj>P0l?3`0>c/k03lo?`11@D40
?clo03`l?00i>CT0?3`l03lo?`14A4@0@T920080?Shn00P0?clo03hn?P0k>c/0@D5103dm?@0n?Sh0
?clo03dm?@80?Shn00h0?3`l03/k>`0l?3`0?Cdm04U9B@12@T80@D510410@00m?Cd0@D5103hn?P0m
?Cd0@D5103hn?P80>c/k00X0@41003hn?P0m?Cd0ATI604M7A`1CDe<0Bd];05IFEP1OGel0E5AD0P1@
D5001@1GEeL0EUIF05IFEP1@D500FEUI0080Bd];01d0BTY:0492@P15ADD0ATI604Q8B01FEUH0GemO
06EUI@1DE5@0BDU904=3@`12@T80A4A404E5A@12@T80B4Q805ADE01BDU80BDU905=CD`1PH600M7Ad
08B4Q01SHf<0C4a<04I6AP15ADD0@41004A4A00303hn?P050410@00l?3`0>c/k03/k>`0l?3`00P0n
?Sh02016ATH0FEUI071`L01`L700G5aL06m_K`1lO7`0NWYj0P23Ph<0901`L700IFEU079bLP2@T900
];Bd0;Fe]@2h^;P0a<C40=3@d036a/H0];Bd09nOW`2KVi/0Z:RX0;bl_02QXJ40Lg=c06e]K@1RHV80
Jf][0:6QX@31`L40^;Rh0;Vi^@2e]KD0[Zj^08b<S01cLg<0K6a/07=cL`1_Kfl0Fe]K03dm?@0o?cl0
@4100451@@80>c/k00<0?Cdm03/k>`0j>SX00P0k>c/203Ti>@0;03`l?00k>c/0?3`l03lo?`12@T80
?Shn03Xj>P0g=cL0>SXj03Hf=P0j>SX00P0h>3P0400g=cL0>SXj03Ph>00l?3`0@D5104Q8B00n?Sh0
?3`l03/k>`0m?Cd0>3Ph03`l?00h>3P0=cLg03Hf=P0i>CT203Xj>P@0>CTi00l0?3`l03Xj>P0g=cL0
=cLg03Xj>P0m?Cd0>c/k03`l?00j>SX0>c/k03Ti>@0j>SX0>CTi03Lg=`0i>CT00P0k>c/0300j>SX0
?Cdm03lo?`13@d<0?Cdm03lo?`10@400>SXj03dm?@0j>SX0?Cdm03`l?0<0>CTi0P0h>3P203Ti>@07
03Ph>00g=cL0>CTi03Ti>@0g=cL0=SHf03dm?@0203Xj>P0W03Hf=P0g=cL0>c/k03/k>`0l?3`0>SXj
03Ph>00g=cL0>CTi03Lg=`0i>CT0DU9B09>CT`2^[Zh0/k>c08f=S@1iNGT0JFUY05EEE@1<C4`0Cdm?
04e=C@1?Cdl0F5QH05iNGP1HF5P0EEEE04Q8B017AdL0CTi>04=3@`11@D40>CTi03`l?00j>SX0>3Ph
03Ti>@0k>c/0?3`l0080>3Ph01l0>c/k03Ph>00h>3P0>CTi03Hf=P0i>CT0>SXj03`l?013@d<0EEEE
079bLP2NWYh0_;bl0;Vi^@2][Jd0WinO09BDU01UIFD0I6AT08N7Q`2ZZZX0`/;20<G5a@2h^;P0VYZJ
08J6QP1QHF40E5AD04];B`15ADD0?clo0080?Shn00P0?clo03Xj>P0j>SX0=cLg03Xj>P0h>3P0?3`l
03Ph>080>SXj0P0k>c/00`0j>SX0=cLg0492@P0303/k>`0G03hn?P10@400DU9B06m_K`2EUID0alO7
0>CTi03Xj>P0inOW0>7Qh@3WinL0j>SX0>OWi`3Ti>@0d];B0:^[Z`22PX80HV9R05IFEP16ATH0@T92
03/k>`0m?Cd00P0j>SX00`0k>c/0?Cdm03dm?@0203`l?00303hn?_oooooooooo00_ooooo000@oooo
o`80CDe=00<0Bd];04Y:BP18B4P00`19BDT204Q8B080CDe=0180AdM704E5A@1<C4`0BTY:04I6AP17
AdL0ADE504A4A018B4P0BDU904E5A@1:BTX0B4Q804E5A@14A4@0@T9204M7A`16ATH404A4A00404=3
@`1;Bd/0AdM704I6AP80ADE500<0ATI604Q8B012@T800`12@T804014A4@0@41004A4A013@d<0A4A4
04=3@`14A4@0@41003lo?`12@T80AdM70492@P0m?Cd0@T9204A4A010@40203lo?`0K0492@P0n?Sh0
@D5103lo?`10@400?clo03hn?P0k>c/0?Shn03/k>`0j>SX0?clo0451@@0l?3`0?Cdm03lo?`0l?3`0
@D5103dm?@13@d<0@41003`l?00n?Sh0@D5103Xj>P0k>c/0?clo0080?Shn00/0?Cdm03lo?`0m?Cd0
?clo03/k>`10@400>c/k03Xj>P12@T80?Cdm03lo?`0203dm?@0803/k>`10@400@T9203`l?00n?Sh0
?clo0451@@12@T8303`l?00403lo?`12@T80@D510492@P80?Cdm01D0?3`l03hn?P0o?cl0?Cdm03lo
?`0l?3`0>3Ph03/k>`0m?Cd0>SXj03lo?`0l?3`0?clo03Ti>@0k>c/0>SXj03/k>`0m?Cd0>SXj03hn
?P0k>c/00P0m?Cd00`0k>c/0?clo03`l?00203hn?P0504=3@`10@400@T9204Q8B014A4@00P19BDT0
2P1:BTX0EUIF05mOG`1SHf<0EeMG04=3@`14A4@0@d=303lo?`0n?Sh20451@@0903Xj>P0n?Sh0?Cdm
03hn?P0j>SX0?3`l03lo?`15ADD0?clo00<0AdM700/0@41003lo?`0n?Sh0DE5A05ADE01=CDd0BDU9
04Q8B012@T80DE5A04m?C`0204i>CP0T04];B`12@T80@D5103/k>`0o?cl0?Shn03dm?@0k>c/0?Shn
03dm?@0n?Sh0>3Ph03hn?P1@D500H61P06i^KP28R8P0WIfM09^KV`26QXH0JFUY05EEE@1BDU80AdM7
04E5A@14A4@0CDe=055AD@1FEUH0De=C04a<C018B4P0CTi>05IFEP1ZJVX0Ng]k0P22PX80702EUID0
_;bl0=OGe`31`L40J6QX05ADE01SHf<0M7Ad0:>SX`36a/H0fMWI0<K6aP2TY:@0PX:205eMG@1RHV80
N7Qh06EUI@1OGel0LG5a07emO@1`L700DU9B03hn?P0i>CT0>SXj03Lg=`0j>SX203/k>`0403`l?00k
>c/0=cLg03Xj>P80>c/k00X0>3Ph03Xj>P0m?Cd0?3`l03Lg=`0k>c/0?3`l03Ph>00j>SX0>CTi0P0l
?3`01@14A4@0JFUY08J6QP1VIVH0?clo00<0>c/k00X0>SXj03/k>`0g=cL0?3`l03Xj>P0l?3`0>CTi
03/k>`0i>CT0>SXj0P0i>CT00`0m?Cd0>3Ph03Ti>@0203Xj>P0303Ph>00j>SX0>c/k0080>3Ph0P0m
?Cd02P0j>SX0>CTi03/k>`0n?Sh0?3`l03/k>`12@T80?3`l03/k>`0o?cl203/k>`0503dm?@0k>c/0
>c/k03dm?@0n?Sh00P0k>c/0:P0h>3P0=CDe03Xj>P0h>3P0=SHf03Ti>@0h>3P0?Cdm03Lg=`0f=SH0
>c/k03dm?@0i>CT0=cLg03hn?P0m?Cd0=cLg03/k>`0j>SX0?Cdm03Ti>@0l?3`0?Cdm03hn?P1UIFD0
QhN70:NWY`2OWil0L71`05=CD`15ADD0>c/k05ADE018B4P0BDU904i>CP1YJFT0GEeM05YJFP0n?Sh0
?Cdm03`l?080>SXj00H0?Cdm03/k>`0i>CT0=cLg03Ti>@0j>SX303/k>`0303Ti>@0j>SX0?Shn00<0
>c/k01D0?Shn04E5A@1_Kfl0OGem096AT@2DU9@0P82006ATI01>CTh0BDU904E5A@1<C4`0EeMG08:2
PP2d];@0bLW90;jn_P2IVIT0JVYZ05EEE@13@d<00P0m?Cd203hn?P80?3`l00T0>SXj03`l?00j>SX0
>CTi03Ph>00i>CT0=cLg03/k>`0g=cL00P0h>3P0300l?3`0>CTi03`l?00l?3`0>SXj04=3@`19BDT0
Cdm?06EUI@1mOGd0Y:BT0<O7a`80c<c<00h0hn?S0>SXj03Vi^H0j>SX0>_[j`3WinL0f][J0;>c/`1h
N7P0CTi>0410@00l?3`0>c/k03dm?@80>CTi0P0j>SX0200g=cL0>SXj03`l?00l?3`0>CTi03lo?`0j
>SX0?3`l3Oooool0013ooooo00T0Cdm?04i>CP1;Bd/0BTY:04U9B@18B4P0AdM704Q8B01:BTX00P18
B4P01`16ATH0BDU904U9B@1;Bd/0ATI604M7A`16ATH00`15ADD01017AdL0@d=304M7A`16ATH204E5
A@0304I6AP19BDT0ADE50080ADE50240@d=304A4A013@d<0AdM704I6AP19BDT0AdM704A4A015ADD0
@T9204A4A016ATH0@T9204E5A@13@d<0A4A404=3@`12@T80ATI604E5A@16ATH0ADE504A4A012@T80
@D5103lo?`10@400ADE504=3@`0o?cl0@4100451@@0m?Cd00`0n?Sh303dm?@0903hn?P10@400?Shn
0410@00o?cl0?Cdm04A4A00n?Sh0?Cdm0080@T9200<0>c/k03dm?@0l?3`00P0k>c/05P0n?Sh0>SXj
03`l?00j>SX0>c/k03hn?P0m?Cd0?Shn0410@00o?cl0?Cdm03lo?`0n?Sh0?Cdm0451@@0n?Sh0@D51
03dm?@0l?3`0?Cdm03lo?`0n?Sh203/k>`0;0492@P0m?Cd0@41003dm?@0n?Sh0>c/k03Ti>@0l?3`0
?Cdm03hn?P0m?Cd00`0o?cl01@0n?Sh0?Cdm03hn?P0n?Sh0?Cdm0080@D510P0j>SX00`0k>c/0?Shn
03hn?P0203`l?00]0451@@0l?3`0?Cdm03`l?00h>3P0>CTi03`l?00k>c/0?Shn03dm?@0k>c/0@d=3
04e=C@16ATH0BDU904];B`15ADD0@d=304a<C016ATH0AdM704A4A019BDT0B4Q80451@@0j>SX0?Cdm
03`l?012@T80?3`l0451@@0k>c/0>CTi03lo?`12@T80>c/k0410@00l?3`0?clo03`l?00m?Cd0>SXj
0410@00k>c/0@4100080?Cdm0P10@4001P0n?Sh0?clo0410@010@400>c/k03lo?`80?Cdm00H0?clo
0451@@0k>c/0@D5103dm?@11@D420410@080?3`l00`0A4A405aLG01ZJVX0Lg=c06m_K`1dM7@0Lg=c
06EUI@1]KFd0MgMg071`L01DE5@20492@P0B0410@011@D40?clo03lo?`13@d<0@T920410@014A4@0
AdM705IFEP1`L700K6a/07QhN02ATI40`l?30<[:bP2a/K40UYJF0P2;Rh/05`2ATI40SXj>09BDU02;
Rh/0O7al06][J`1MGEd0G5aL069RHP1QHF40GEeM07]kN`2KVi/0TI6A0:>SX`2d];@0Lg=c055AD@0j
>SX0@41003Ph>00l?3`0?clo0080?3`l0P0k>c/203lo?`0C03hn?P0k>c/0?Cdm03/k>`0g=cL0?3`l
03dm?@14A4@0LG5a04=3@`0j>SX0>c/k04U9B@1SHf<0@D5103lo?`0k>c/0?Cdm03Xj>P0203`l?0<0
>c/k00`0>SXj03Ti>@0k>c/0>3Ph03dm?@0o?cl0?3`l03Ti>@0h>3P0?Shn03/k>`0j>SX203`l?003
03Xj>P0i>CT0?Shn0080?Shn00P0?Cdm03Xj>P0l?3`0>3Ph03hn?P0j>SX0?Cdm03hn?P80?3`l00D0
?clo03Xj>P10@400?Cdm03Xj>P0303/k>`0403Ti>@0h>3P0=cLg03Hf=P80?3`l0P0k>c/203Ti>@0:
03Lg=`0f=SH0>CTi03Ti>@0h>3P0?Cdm03Ti>@0l?3`0>3Ph03Xj>P80>c/k0180>CTi0451@@1XJ6P0
QhN709fMW@22PX80GemO04];B`0m?Cd0@41004i>CP1QHF40FEUI04M7A`1<C4`0AdM703lo?`0m?Cd2
03Xj>P0403Ti>@0h>3P0=cLg03Ti>@@0>SXj02D0>c/k03Ti>@0g=cL0>SXj03Hf=P0n?Sh0?3`l03/k
>`0i>CT0@T9205eMG@1/K6`0M7Ad0;fm_@2a/K40Ph>3065QH@16ATH0@D5104A4A01KFe/0JFUY07em
O@2GUiL0/;2`0<30`02IVIT0JVYZ04];B`10@400?3`l03/k>`0l?3`0>SXj03Ti>@0k>c/0?Cdm00@0
>3Ph00<0=SHf03Ti>@0h>3P00P0i>CT04@0h>3P0>c/k03`l?00o?cl0ADE504];B`1OGel0RXZ:0:n_
[`30`<00/k>c08^;R`1fMWH0RXZ:09VIV@2][Jd0bl_;0080k>c/00L0gmoO0<g=c@2j^[X0Ti>C06EU
I@17AdL0>CTi00<0>SXj00@0>3Ph03Ti>@0j>SX0>SXj0P0h>3P0100i>CT0>3Ph03Ph>00i>CT203Xj
>P0303Ph>00i>CWooooo00cooooo000@ooooo`80CDe=00P0C4a<04Y:BP1=CDd0BTY:04M7A`16ATH0
A4A404E5A@80BDU90P17AdL00`1:BTX0B4Q804Q8B00204M7A`0H04Q8B016ATH0B4Q804I6AP17AdL0
ATI604U9B@1;Bd/0BTY:04E5A@17AdL0ADE504I6AP18B4P0ADE504I6AP13@d<0ADE504U9B@17AdL0
A4A404E5A@16ATH0@d=30`15ADD05@12@T80A4A404=3@`10@400@d=30410@00n?Sh0ATI60492@P11
@D40@T9203hn?P10@400@D5103hn?P12@T80@41003lo?`0n?Sh0@D5103lo?`0203`l?00903lo?`0n
?Sh0@4100451@@0m?Cd0@T920451@@0k>c/0@T920080@41002H0@T9203hn?P0l?3`0@D5103hn?P0l
?3`0>SXj03dm?@0l?3`0?clo03Ti>@0j>SX0?Shn03/k>`0m?Cd0?Shn03`l?012@T80?clo03dm?@0k
>c/0?clo03hn?P0o?cl0ATI603lo?`0n?Sh0?clo04E5A@0n?Sh0?3`l03hn?P12@T80@D5103/k>`0m
?Cd0?Shn03Xj>P80>c/k00H0?Shn03/k>`0n?Sh0@D5103hn?P0k>c/203hn?P0903lo?`10@400@410
03lo?`11@D40?Cdm03`l?00k>c/0?clo0080>c/k00@0?Cdm03Ti>@0l?3`0>c/k0P0j>SX0500k>c/0
?Cdm04=3@`16ATH0Bd];04I6AP14A4@0@T9204=3@`0o?cl0@D510492@P1FEUH0ATI603lo?`0m?Cd0
@4100451@@15ADD0>c/k0P11@D404@14A4@0@T920451@@0n?Sh0?Cdm03lo?`13@d<0?3`l0492@P16
ATH0@d=303/k>`0j>SX0@d=303/k>`0l?3`0>SXj0080>c/k03X0?Shn03dm?@0n?Sh0A4A403/k>`0o
?cl0?Cdm03/k>`12@T80?Cdm0451@@10@400?Cdm04A4A01=CDd0DE5A05IFEP1TI6@0FUYJ055AD@1/
K6`0Lg=c07]kN`21PH40JFUY05]KF`1NGUh0Cdm?059BDP19BDT0@D5103lo?`12@T80@D5103lo?`1>
CTh0HF5Q07]kN`2=SHd0QHF509NGU`2HV9P0Ti>C08b<S02XZ:P0V9RH08:2PP1eMGD0LW9b071`L01H
F5P0Cdm?04];B`18B4P0@41004I6AP17AdL0@4100P0o?cl03`14A4@0AdM704e=C@1DE5@0HV9R06i^
KP1eMGD0PH6108N7Q`2TY:@0^;Rh0;no_`1hN7P0Cdm?03hn?P0203lo?`0804E5A@1HF5P0DU9B05AD
E01<C4`0ATI604M7A`0o?cl204U9B@0<04=3@`0n?Sh0?Shn0492@P1LG5`0@d=303`l?012@T80?Shn
03Lg=`0l?3`0>CTi0P0k>c/01`0j>SX0@41003`l?00k>c/0?Shn03`l?00k>c/00P0m?Cd02@0i>CT0
ADE504E5A@0m?Cd0>CTi03Lg=`0j>SX0>CTi03/k>`0203hn?P0=03/k>`0l?3`0@d=303`l?00i>CT0
>SXj03Lg=`0i>CT0>c/k04M7A`13@d<0>c/k03Xj>P0203`l?00703lo?`0m?Cd0A4A403hn?P0j>SX0
>c/k03Ti>@0203/k>`0703Ti>@0h>3P0>CTi03/k>`0i>CT0>c/k03Ti>@0203Lg=`0303Ph>00g=cL0
>CTi00<0>SXj00<0>c/k03hn?P0l?3`00P11@D402@12@T80Fe]K096AT@2CTi<0LW9b04e=C@0n?Sh0
EEEE05mOG`0203`l?00>05QHF01PH600De=C04A4A00l?3`0>3Ph03/k>`0l?3`0>CTi03De=@0g=cL0
>3Ph03Ti>@0j>SX203Lg=`0D03Xj>P0i>CT0?Cdm03Xj>P0h>3P0?Shn04A4A01NGUh0Kfm_06][J`1>
CTh0DE5A04i>CP1:BTX0C4a<055AD@17AdL0?Shn04e=C@1aLG4208n?S`0:09nOW`27QhL0QHF509>C
T`21PH40FEUI04M7A`0m?Cd0?3`l03dm?@80>3Ph00P0>SXj03Ph>00i>CT0>c/k03Lg=`0h>3P0>c/k
03Xj>P80>3Ph00@0>c/k04E5A@1FEUH0GemO0P1FEUH07P19BDT0@d=305QHF02EUID0_kno0;jn_P2[
Zj/0Ng]k06ATI01_Kfl0XJ6Q0=7Ad@3MgMd0h>3P0=kNgP3Hf=P0/[:b08>3P`1LG5`0A4A403Xj>P0i
>CT0>SXj03/k>`0g=cL0>CTi03Xj>P0h>3P0>CTi03Lg=`80>3Ph00<0>CTi03Ph>00g=cL00P0g=cL2
03Ti>@0303Lg=`0i>CWooooo00cooooo000@ooooo`0804];B`1<C4`0C4a<04a<C01:BTX0Bd];04Y:
BP18B4P204M7A`80BDU900P0AdM704E5A@1:BTX0B4Q804M7A`18B4P0BDU904];B`80B4Q800H0ATI6
04M7A`15ADD0AdM704I6AP1;Bd/204M7A`0804Y:BP18B4P0A4A404I6AP1:BTX0@d=304E5A@16ATH2
04E5A@0704I6AP17AdL0@T9204I6AP1;Bd/0ADE504=3@`020451@@040492@P16ATH0A4A40451@@80
@d=300H0@T920410@015ADD0@T9203hn?P0l?3`20492@P0B0410@011@D40?Shn0451@@0o?cl0?Cdm
0492@P0n?Sh0@41003hn?P0m?Cd0?Shn03dm?@0k>c/0?3`l0451@@0n?Sh0?Cdm0P0k>c/02012@T80
@41003lo?`0k>c/0?Cdm0410@013@d<0>c/k0P0l?3`01`0k>c/0?Cdm0410@00j>SX0?clo03dm?@0n
?Sh00P0l?3`01P0k>c/0@4100410@00m?Cd0>c/k03dm?@80>c/k00/0?3`l03/k>`0n?Sh0?Shn03/k
>`0l?3`0?clo03dm?@0j>SX0>CTi0410@00203dm?@0>03lo?`0l?3`0>SXj03hn?P0o?cl0?Shn03lo
?`0n?Sh0>CTi03dm?@0l?3`0?Shn03/k>`10@40203dm?@0303`l?011@D40@D510080@41000L0?clo
03Xj>P0o?cl0@d=304I6AP13@d<0@T920080?Cdm0P0n?Sh01`0m?Cd0?3`l03/k>`0k>c/0>CTi03lo
?`0n?Sh00P0l?3`01P0m?Cd0@D5103`l?00n?Sh0?Cdm03hn?P80?clo00/0?3`l03hn?P0m?Cd0?clo
03hn?P0m?Cd0?3`l03/k>`0i>CT0>SXj03lo?`0203`l?00703Ti>@0m?Cd0?3`l03dm?@0l?3`0@d=3
0451@@0203/k>`0303dm?@12@T80?Shn0080?clo00h0?Cdm04=3@`1DE5@0EUIF05QHF01CDe<0FEUI
05aLG01DE5@0BDU90451@@0n?Sh0>3Ph03/k>`<0@D510P0m?Cd05P17AdL0DU9B06EUI@1`L700Lg=c
06i^KP1dM7@0RXZ:0;2`/02SXj<0OGem06MWI`1?Cdl0ADE50451@@0m?Cd0@d=30492@P15ADD0BTY:
04Q8B01>CTh205UIF@0J061PH01GEeL0BTY:04];B`1<C4`0EEEE061PH01VIVH0Ng]k09BDU02RXZ80
ZJVY0<O7a`3Cdm<0emOG0;Fe]@2DU9@0Rh^;07]kN`1MGEd0DU9B071`L02XZ:P0/;2`0:j^[P2RXZ82
09:BTP06096AT@2KVi/0QHF506a/K01CDe<0BDU90P17AdL07P0o?cl0@T9206=SH`1RHV80JFUY06MW
I`1>CTh0?Cdm04i>CP1RHV80MGEe07]kN`1dM7@0IfMW05UIF@1CDe<0EEEE0451@@0j>SX0?clo03/k
>`0j>SX0?Cdm03hn?P0i>CT0>c/k03dm?@0n?Sh0?Cdm03Xj>P80?3`l0P0k>c/01`0o?cl0?3`l03dm
?@0i>CT0?Shn03Ti>@0h>3P00P0i>CT0100j>SX0>c/k03dm?@0m?Cd203Xj>P0803/k>`0j>SX0?3`l
03hn?P0m?Cd0>SXj03/k>`0l?3`203Xj>P0703/k>`0j>SX0=cLg03Xj>P0g=cL0>CTi03Xj>P0203dm
?@0505QHF01RHV80CTi>04E5A@1CDe<00P1;Bd/04P1?Cdl0?Cdm03Xj>P0j>SX0@41006ATI01?Cdl0
=cLg03Xj>P0i>CT0?Cdm03Ti>@0h>3P0=3@d03Hf=P0h>3P0=cLg03Xj>P80>CTi0P0h>3P08P0i>CT0
=cLg03Ph>00h>3P0=SHf03Xj>P0g=cL0B4Q807=cL`2?Shl0RHV907=cL`1GEeL0AdM704E5A@0n?Sh0
@41003Ph>00g=cL0@410065QH@2VYZH0`L710;:b/P23Ph<0Hf=S04m?C`0n?Sh0?clo03dm?@0h>3P0
>c/k03Ti>@0h>3P303Xj>P0403Lg=`0i>CT0>c/k03`l?080>SXj02H0>CTi03`l?00l?3`0?Shn05MG
E`1UIFD0GemO04];B`10@400@d=3071`L02DU9@0[Zj^09nOW`1`L700IFEU06m_K`2=SHd0ZZZZ0;Bd
]03>c/h0fm_K0=3@d02][Jd0TI6A06IVIP14A4@0?3`l03/k>`0j>SX0>c/k03De=@0g=cL0=SHf03Ph
>00i>CT0>3Ph03Lg=`80>3Ph100g=cL203Ph>00503Lg=`0i>CT0>CTi03Xj>P1:BTX03Oooool0013o
oooo00T0DE5A04a<C01>CTh0CDe=04];B`1<C4`0BDU904a<C01;Bd/00P18B4P01017AdL0ATI604=3
@`15ADD204U9B@0404I6AP18B4P0ATI604M7A`80ADE500L0Bd];04I6AP17AdL0AdM704Q8B014A4@0
B4Q80080ATI600D0A4A404M7A`1:BTX0ATI60451@@0204A4A00504=3@`18B4P0ATI604E5A@11@D40
0`13@d<01P10@400@D510492@P16ATH0@D510492@P80?Shn00D0@D5104A4A010@400@41003lo?`02
03hn?P0604I6AP0m?Cd0@D5103lo?`12@T80?Cdm0P12@T80100o?cl0@d=30451@@11@D4203lo?`0:
03hn?P0k>c/0?3`l03hn?P0m?Cd0ATI603Xj>P0l?3`0>c/k0451@@<0?clo00D0?Cdm03/k>`0i>CT0
>3Ph03dm?@0203hn?P0503Ph>00o?cl0>CTi03/k>`0g=cL00P0i>CT03`0m?Cd0>CTi03Ti>@0n?Sh0
>c/k03dm?@0k>c/0>SXj03lo?`0l?3`0?Cdm03Ph>00m?Cd0?clo0492@P0303`l?00@03lo?`14A4@0
ATI603Xj>P0l?3`0>c/k03hn?P0j>SX0>c/k0451@@0j>SX0?Shn03dm?@0l?3`0>SXj03hn?P80?clo
00`0A4A404=3@`14A4@0B4Q80451@@10@400?clo03hn?P0l?3`0?Cdm03lo?`0l?3`203dm?@0403hn
?P13@d<0?3`l03/k>`80>CTi00X0>SXj03lo?`10@400?Cdm03Ti>@11@D40@T9203lo?`0h>3P0?clo
0P0l?3`05`0o?cl0A4A403dm?@11@D40?clo03Xj>P0k>c/0?Cdm03`l?00i>CT0?clo03dm?@0l?3`0
?clo0410@00m?Cd0>SXj03`l?00o?cl0@41003hn?P0m?Cd0A4A400@0BTY:01L0CTi>04e=C@17AdL0
FEUI04i>CP14A4@0?clo0451@@0n?Sh0@T9203`l?015ADD0C4a<04M7A`16ATH0DE5A05=CD`1@D500
De=C05YJFP1?Cdl0GemO05ADE00205=CD`0J04m?C`1BDU80CDe=04Q8B011@D40@T920410@00n?Sh0
?clo0451@@1KFe/0JFUY07inOP22PX80R8R808B4Q02KVi/0/;2`0:>SX`2o_kl0d=3@0:BTY02IVIT0
ZJVY0<S8b03?cll20=7Ad@140;Zj^P2a/K40a<C40<k>cP3<c<`0clo?0<[:bP3?cll0e=CD0=OGe`2m
_Kd0FUYJ04a<C01VIVH0Ng]k08V9R@2KVi/0U9BD079bLP23Ph<0PX:204I6AP11@D40CTi>05eMG@2B
TY80Zj^[09JFUP1QHF40Lg=c08Z:RP2][Jd0`<3008^;R`1VIVH0De=C05MGE`1TI6@0Ph>30:BTY02S
Xj<0Zj^[0:j^[P2WYjL0VYZJ07UiN@1EEED0?Shn03`l?00i>CT0?clo03/k>`0j>SX0>c/k03dm?@0n
?Sh0@41003Ti>@10@400?Cdm03`l?012@T80?3`l03Ph>00m?Cd0>c/k03Xj>P0g=cL203Ti>@0;0410
@00l?3`0?Cdm03/k>`11@D40>SXj03Ph>00l?3`0>c/k03Ti>@0j>SX0100k>c/203`l?00303Ti>@0h
>3P0>SXj0080>SXj00X0?Cdm04a<C01EEED0IVIV055AD@0k>c/0>SXj03Ph>00g=cL0?Shn0P0m?Cd0
1@0k>c/0@D5103hn?P0n?Sh0>3Ph0080>SXj00@0>c/k03Xj>P0n?Sh0>c/k100j>SX01@0h>3P0=cLg
03Ti>@0k>c/0?3`l00<0>c/k01P0>SXj03Ph>00j>SX0ADE506IVIP1cLg<0GUiN04A4A01:BTX0B4Q8
03lo?`0l?3`0>SXj03Ti>@17AdL0GemO0861P@24Q8@0PX:206QXJ01FEUH0?3`l03Xj>P0h>3P203Lg
=`0303Hf=P0i>CT0>CTi0080>c/k00@0?3`l03Ti>@0i>CT0>CTi100h>3P08@0m?Cd0>3Ph03hn?P0i
>CT0A4A403dm?@0l?3`0EeMG08^;R`2IVIT0[Zj^0<k>cP2j^[X0W9bL09ZJVP2^[Zh0bl_;0=cLg03Q
hN40bl_;0;fm_@2][Jd0QXJ605aLG01:BTX0?Shn04U9B@16ATH0A4A404=3@`15ADD0?Shn03dm?@03
03hn?P0703Ph>00j>SX0>SXj03Xj>P0h>3P0>CTi03Lg=`0203/k>`0703Ti>@0h>3P0?Shn04i>CP1/
K6`0Xj>S0;jn_P0=ooooo`004?ooool0101PH600D51@04a<C01;Bd/204Y:BP0304Q8B016ATH0Bd];
0080BDU900<0AdM704U9B@16ATH00P15ADD01016ATH0AdM704I6AP19BDT204M7A`0904A4A018B4P0
B4Q804I6AP17AdL0ATI604Y:BP15ADD0ATI60080A4A40180AdM704U9B@16ATH0ATI604Y:BP17AdL0
@d=304E5A@14A4@0ATI604Q8B013@d<0ADE50451@@15ADD0@d=304I6AP12@T840451@@040492@P14
A4@0@D5103lo?`80@T920P10@4002`0n?Sh0?clo03lo?`11@D40?Shn03dm?@0o?cl0@4100451@@0n
?Sh0@T920080?clo01<0@T920410@011@D40@d=303hn?P12@T80?clo03Xj>P0n?Sh0?Cdm03lo?`0m
?Cd0>c/k03hn?P0k>c/0>SXj03dm?@0l?3`0?Shn0080?3`l00D0@D5103`l?00j>SX0>3Ph03Hf=P02
03/k>`0403Ph>00k>c/0?3`l03Ti>@<0?Cdm00P0>CTi03/k>`0n?Sh0?3`l03/k>`0o?cl0@41003dm
?@<0?3`l0180>SXj0410@00i>CT0@41003dm?@0l?3`0?clo03/k>`10@400>c/k03Ti>@0m?Cd0@T92
03hn?P10@400@T920410@00o?cl303hn?P80?clo00L0?Cdm03lo?`0n?Sh0?3`l03dm?@0k>c/0?Shn
0080?3`l00P0>3Ph03/k>`0n?Sh0>c/k03Xj>P0l?3`0?Cdm03hn?P@0?Cdm00@0>3Ph03Ti>@0o?cl0
@4100P0m?Cd03@12@T80@D5103lo?`12@T80>c/k03Ti>@0k>c/0>SXj03/k>`0n?Sh0>c/k03`l?00m
?Cd0100n?Sh01015ADD0@D510492@P16ATH2059BDP0404U9B@1<C4`0Bd];04M7A`80@D5100<0A4A4
03hn?P10@4000`12@T80200k>c/0@41004Y:BP1KFe/0CTi>04a<C01CDe<0FEUI0P17AdL01`16ATH0
@T9204I6AP15ADD0@D5103dm?@0l?3`00P10@400=00j>SX0@T9204I6AP1?Cdl0FUYJ071`L02=SHd0
XZ:R09^KV`2EUID0U9BD08N7Q`1cLg<0OWin08N7Q`23Ph<0SXj>0:2PX02CTi<0T92@09BDU02OWil0
W9bL09fMW@2@T900MGEe06IVIP1ZJVX0J6QX06i^KP29RHT0UiNG0:RXZ031`L40`l?30:j^[P2e]KD0
^KVi0;:b/P2^[Zh0];Bd0;2`/02^[Zh0Zj^[0:NWY`2BTY80OWin0:RXZ02k^k/0_;bl0;:b/P2UYJD2
0:^[Z`0M09^KV`2HV9P0Ti>C09FEU@2UYJD0ZZZZ09>CT`2TY:@0[:b/0:RXZ02YZJT0UYJF0;6a/@3;
bl/0bLW90;Ng]`2ATI40MWIf05ADE01<C4`0?Shn03`l?00j>SX0>c/k03Xj>P0i>CT0>c/k03`l?00i
>CT00P0l?3`02`14A4@0?3`l03Xj>P1<C4`0@d=303Ph>00i>CT0?clo03Xj>P0l?3`0?clo0080?Shn
00L0@4100451@@0j>SX0>CTi03Lg=`0h>3P0>CTi0080@T9201/0?3`l03/k>`0m?Cd0?Cdm03hn?P10
@400>3Ph03`l?00i>CT0BTY:06a/K01ADE40?clo03`l?00k>c/0>CTi03/k>`0n?Sh0>CTi03`l?00j
>SX0=cLg03`l?00j>SX0>c/k03`l?00j>SX00P0k>c/01@0j>SX0>CTi03/k>`0i>CT0=cLg00<0>SXj
00<0>3Ph03Lg=`0i>CT00`0k>c/05@0i>CT0?3`l03De=@0k>c/0?Shn0451@@10@400ADE503hn?P11
@D40?Shn03Ti>@0k>c/0A4A404Q8B01`L700TY:B09RHV01ZJVX0CDe=0451@@0203Ph>00=03Xj>P0h
>3P0=cLg03@d=00b<S80=cLg03Xj>P0g=cL0?Cdm03/k>`0n?Sh0>SXj03Ph>00403Xj>P0Q03`l?00o
?cl0>SXj03dm?@0j>SX0?clo04i>CP1lO7`0c<c<0=cLg035aLD0eMGE0=cLg03Cdm<0f=SH0=cLg03T
i>@0h>3P0=oOg`35aLD0VYZJ06QXJ015ADD0@T9205MGE`1[Jf/0QXJ609NGU`2>SXh0KVi^05]KF`1=
CDd0?Shn0080@41000H0>CTi03Lg=`0h>3P0=SHf03Ti>@12@T8203Ti>@0:03Ph>00m?Cd0@T9205EE
E@1dM7@0Zj^[0<g=c@3Bd]80d=3@0<_;b`gooooo000@ooooo`070:b/[023Ph<0KVi^05YJFP1>CTh0
BDU904Q8B00204Y:BP0404E5A@16ATH0AdM704M7A`80ATI601h0ADE504A4A013@d<0@T9204Q8B016
ATH0BDU904A4A016ATH0A4A404Y:BP13@d<0ATI604A4A013@d<0Bd];04Y:BP16ATH0@T920451@@13
@d<0A4A404I6AP15ADD0A4A404E5A@17AdL0@D5104A4A011@D4204=3@`0804A4A015ADD0@d=303lo
?`12@T80@d=303lo?`12@T830451@@0?0410@014A4@0@4100492@P0o?cl0@4100492@P0l?3`0?Shn
0410@011@D40@T9203dm?@13@d<0?clo0080?Shn0P10@400A@0o?cl0@T9204=3@`0l?3`0?Shn0492
@P11@D40AdM70410@00l?3`0?clo0492@P11@D40?3`l03Ti>@0m?Cd0>SXj03`l?00j>SX0?3`l03hn
?P0l?3`0>SXj03dm?@0k>c/0>3Ph03/k>`0i>CT0=SHf03Xj>P0i>CT0?Cdm03Ph>00k>c/0>SXj03Ph
>00m?Cd0?3`l03Xj>P0o?cl0?Shn03dm?@0l?3`0?clo03hn?P0m?Cd0?clo0451@@0n?Sh0>SXj03lo
?`12@T80A4A4059BDP12@T80?Shn0410@00o?cl0>CTi03`l?011@D40@41003dm?@10@400@T9203`l
?00k>c/0?clo03dm?@0203`l?00703dm?@0n?Sh0>3Ph0410@014A4@0B4Q803lo?`0203/k>`0303Ti
>@0k>c/0?3`l0080>CTi00X0?3`l03Ph>00g=cL0>CTi03Lg=`0h>3P0>SXj03`l?00m?Cd0>c/k0P0m
?Cd02@0k>c/0@4100492@P0n?Sh0>c/k03`l?00k>c/0?Cdm03/k>`0303hn?P80>c/k00D0@41004I6
AP0m?Cd0AdM704=3@`0204E5A@0A0410@00j>SX0>3Ph03`l?00j>SX0A4A404U9B@16ATH0@41004Q8
B017AdL0?Shn03lo?`0n?Sh0ATI604U9B@18B4P00P14A4@01012@T80>3Ph03`l?00i>CT203/k>`0H
03dm?@0n?Sh0>SXj03Ph>00k>c/0>SXj04A4A01TI6@0Ogmo09ZJVP2IVIT0S8b<092@T02DU9@0VYZJ
0::RXP2[Zj/0Q8B406m_K`1kNg/0W9bL09jNWP27QhL0J6QX0P1ADE40801:BTX0AdM70451@@14A4@0
@T9204=3@`11@D40CTi>05aLG01eMGD0MgMg06YZJP1]KFd0UYJF0;Vi^@3>c/h0hn?S0>;RhP3>c/h0
QXJ60:RXZ02o_kl0`<300<[:bP37alL0/[:b0:f][@3;bl/0emOG0=oOg`3Hf=P0`l?30P2b/[805P33
`l<0f][J0=3@d02WYjL0U9BD0:RXZ02][Jd0QXJ607emO@2WYjL0dm?C0=CDe03?cll0a<C409>CT`1V
IVH0EEEE04i>CP11@D40?Shn03`l?012@T8203Ph>00303Xj>P0n?Sh0>SXj0080>CTi00l0?Cdm03Xj
>P0o?cl0@41005YJFP1QHF40@41003hn?P0g=cL0>CTi03dm?@17AdL0@D5103lo?`13@d<00P1:BTX0
2@0i>CT0@D510451@@12@T80DU9B04e=C@15ADD0@d=303dm?@0203Xj>P0803`l?00m?Cd0>CTi03Xj
>P1:BTX0IfMW06ATI00k>c/203Ti>@0603Ph>00i>CT0>c/k03hn?P0g=cL0>3Ph0P0l?3`0100j>SX0
>c/k03Ph>00o?cl303/k>`0503Ti>@0h>3P0>3Ph03Ti>@0h>3P00P0j>SX00`0i>CT0=cLg03Ti>@02
03Ti>@0I03Ph>00i>CT0=3@d03Lg=`0i>CT0A4A404E5A@10@400=cLg03Ti>@0j>SX0>3Ph03De=@0h
>3P0@41006IVIP1TI6@0MGEe06m_K`17AdL0>3Ph03/k>`0g=cL0=SHf03Ti>@0203Ph>00;03Hf=P0e
=CD0=CDe03Xj>P0l?3`0=cLg03lo?`0i>CT0>SXj03Ph>00j>SX00P0k>c/203Xj>P0:03Ti>@0e=CD0
>3Ph0410@01;Bd/0J6QX0::RXP3Bd]80h>3P0=oOg`80f][J00d0e]KF0=SHf03Fe]H0c<c<0;Zj^P2O
Wil0SXj>06ATI01?Cdl0A4A404I6AP1;Bd/0H61P0080KFe]00H0IVIV05ADE014A4@0>c/k03hn?P0j
>SX203Lg=`0B03Ti>@0h>3P0=CDe03dm?@0i>CT0=cLg03/k>`0i>CT0Cdm?08N7Q`2OWil0`L710=oO
g`3Hf=P0alO70:j^[P2>SXh0MgMg3Oooool0013ooooo00X0UYJF08b<S02=SHd0Ph>3065QH@1@D500
B4Q804];B`1<C4`0BTY:0P1=CDd04@17AdL0B4Q804M7A`16ATH0AdM704I6AP17AdL0B4Q804M7A`19
BDT0AdM704I6AP13@d<0BDU90451@@19BDT0ADE50080AdM70P13@d<01015ADD0A4A404I6AP16ATH2
04E5A@80A4A400<0ATI60451@@12@T800P11@D4204=3@`0404I6AP15ADD0@D510410@080@D5101D0
A4A40410@011@D40@D5103lo?`12@T80@d=30451@@15ADD0@T920410@011@D40?clo0410@011@D40
@d=303lo?`18B4P0AdM704=3@`10@4000P11@D400`0o?cl0@D5104E5A@020451@@80?clo01<0@D51
03dm?@0n?Sh0?3`l03/k>`0m?Cd0>c/k03Xj>P0m?Cd0>c/k03dm?@0n?Sh0?3`l03Xj>P0n?Sh0?3`l
03dm?@0l?3`0?Cdm0080>SXj00T0?Cdm03Xj>P0m?Cd0?Shn03/k>`0j>SX0?Shn0492@P0j>SX00`0l
?3`02P0h>3P0>SXj03/k>`0m?Cd0?3`l03Xj>P0g=cL0?3`l03Xj>P0k>c/203`l?00503Xj>P0n?Sh0
?Shn03`l?00m?Cd00`0n?Sh00`0o?cl0?Cdm03hn?P0203`l?0090410@00o?cl0@d=30492@P0m?Cd0
?3`l03dm?@0n?Sh0>3Ph0080>CTi00@0?Shn03Xj>P0m?Cd0>SXj0P0l?3`303Xj>P0503`l?00n?Sh0
?clo03hn?P0k>c/00P0j>SX203Ti>@0;03`l?011@D40?Cdm03`l?00j>SX0?clo03/k>`0h>3P0?Cdm
0410@014A4@00P13@d<01@0n?Sh0?3`l0410@012@T80Bd];0080@D5100<0?Cdm03`l?00n?Sh00`0m
?Cd01012@T80@41004E5A@18B4P204];B`0303lo?`10@400A4A40080?clo00@0?Shn0410@013@d<0
?Shn0`0k>c/0100l?3`0>c/k03/k>`0m?Cd303`l?00803Ph>00l?3`0?Shn03Ti>@10@400D51@055A
D@1FEUH2059BDP80E5AD0P1HF5P02@1KFe/0DU9B04Y:BP18B4P0EEEE05MGE`1>CTh0AdM70451@@02
03hn?P0804];B`1GEeL0Jf][07EeM@2TY:@0];Bd09FEU@2?Shl2096AT@0G08b<S02=SHd0VYZJ0:BT
Y02a/K40alO70<o?c`2l_;`0[:b/0:RXZ02][Jd0^KVi0;Rh^02FUYH0QHF508N7Q`29RHT0VIVI0;2`
/02f][H0[Zj^0<30`038b<P00P3?cll05@2m_Kd0`/;20;^k^`2f][H0_kno0:RXZ02EUID0X:2P0;Fe
]@29RHT0OGem06IVIP18B4P0@T9204=3@`0j>SX0?Shn03dm?@0n?Sh0>SXj03`l?00203Xj>P80?3`l
01H0?clo03`l?00j>SX0?3`l051@D01hN7P0MGEe0451@@0i>CT0?3`l03Xj>P0n?Sh0?Cdm03lo?`1M
GEd0MWIf071`L01RHV80GEeM03/k>`0n?Sh0AdM70P1:BTX01`0n?Sh0>c/k03Xj>P0i>CT0>SXj03Ti
>@0k>c/00P0j>SX0100n?Sh0F5QH04=3@`0m?Cd203Ph>080>SXj0P0o?cl01`0m?Cd0>c/k03Xj>P0k
>c/0>SXj03Ti>@0n?Sh00`0j>SX01`0k>c/0>SXj03Ti>@0o?cl0>3Ph03Ti>@0m?Cd00`0i>CT0200g
=cL0>3Ph03Ti>@0i>CT0>3Ph03Lg=`11@D40?clo0P0j>SX0100l?3`0?clo03Xj>P0f=SH203Ph>00=
03/k>`0l?3`0C4a<05=CD`17AdL0BDU90451@@0l?3`0>CTi03Lg=`0j>SX0=cLg03Xj>P0203Lg=`06
03Hf=P0g=cL0=cLg03Xj>P0k>c/0>3Ph0P0j>SX00`0k>c/0>SXj03`l?00203`l?00803Xj>P0i>CT0
>CTi03/k>`1[Jf/0PX:207AdM02c/k<20=OGe`0=0=WIf@38b<P0_;bl0;Rh^02SXj<0V9RH08n?S`1_
Kfl0GEeM05EEE@1?Cdl0@T920451@@0303/k>`0603lo?`0n?Sh0?3`l03dm?@0h>3P0?3`l0P0h>3P0
0`0f=SH0>CTi03Ti>@0203Ph>00@03Hf=P0j>SX0>CTi05IFEP1eMGD0WIfM0<?3``3Fe]H0dM7A0<71
`@2KVi/0LW9b05aLG01BDU80F5QH06=SH`gooooo000@ooooo`03059BDP1TI6@0L71`0080NWYj00H0
LG5a06m_K`1`L700HV9R04a<C019BDT204Y:BP0B04e=C@19BDT0B4Q804U9B@17AdL0BDU904I6AP17
AdL0BDU904Q8B016ATH0ADE504Q8B014A4@0AdM704E5A@18B4P0A4A40`17AdL02`1ADE40BTY:04I6
AP17AdL0ATI604E5A@16ATH0@D5104A4A016ATH0A4A40080@d=300D0AdM704e=C@14A4@0?clo0451
@@020492@P80@D5100D0B4Q804=3@`0o?cl0?Cdm0410@00204=3@`80?Shn00<0?Cdm03hn?P12@T80
0P10@4001`13@d<0@41003`l?00o?cl0?Cdm03hn?P0m?Cd00P0o?cl03P10@400?Shn0410@00m?Cd0
>c/k03hn?P0m?Cd0@D5103`l?00j>SX0?Shn03/k>`0m?Cd0?clo0P0n?Sh04011@D40?Cdm03Ti>@0j
>SX0>c/k03`l?00m?Cd0>3Ph03Xj>P0l?3`0>SXj03Ph>00l?3`0>c/k03hn?P0i>CT203`l?00703Xj
>P0k>c/0?Cdm03Ti>@0f=SH0>CTi03`l?00203Xj>P0<03dm?@0k>c/0>SXj03dm?@0g=cL0>CTi03Xj
>P0g=cL0>CTi03/k>`0o?cl0?Shn0P0j>SX01@0m?Cd0?3`l0410@00n?Sh0?Cdm0080>c/k00<0>CTi
03hn?P0n?Sh00P0l?3`0300k>c/0?Cdm03dm?@0i>CT0?clo03`l?00i>CT0?Cdm03hn?P0m?Cd0?3`l
03/k>`80@41000/0>c/k03Xj>P10@400@41003lo?`0m?Cd0>c/k03Ti>@0h>3P0=cLg03lo?`0303/k
>`80>CTi01@0?3`l03/k>`0l?3`0?Cdm03/k>`0m?Cd0?3`l03dm?@0o?cl0?Shn03lo?`0k>c/0@410
03/k>`0l?3`0?clo04E5A@0n?Sh0?Cdm04A4A080Bd];00@0?clo0410@012@T80@4100P0m?Cd02P0l
?3`0>SXj03/k>`0j>SX0>CTi03`l?00j>SX0?3`l03hn?P0l?3`503Xj>P1A03`l?00j>SX0?3`l03dm
?@0k>c/0@T9203Xj>P0m?Cd0De=C06a/K01aLG40HF5Q05YJFP14A4@0?Cdm03/k>`10@400?Cdm03hn
?P0l?3`0?clo03Xj>P13@d<0ATI605=CD`1mOGd0XJ6Q0;bl_02b/[80WYjN09^KV`2HV9P0UIFE09VI
V@2XZ:P0ZZZZ09>CT`24Q8@0O7al07IfMP1oOgl0LG5a06UYJ@1OGel0GEeM05aLG01PH600JVYZ07If
MP1bLW80Ph>3092@T02CTi<0UiNG0:FUY@2b/[80/k>c0<30`02m_Kd0^KVi0:>SX`2>SXh0MgMg06i^
KP28R8P0[Zj^0<_;b`35aLD0a/K60;Zj^P2VYZH0LG5a05YJFP13@d<0>CTi03dm?@0n?Sh0?3`l03dm
?@0l?3`0>c/k0080>SXj00/0>c/k03hn?P0m?Cd0?clo03hn?P0o?cl0EeMG08f=S@1TI6@0@41003Xj
>P0303/k>`80?clo00@0A4A404E5A@13@d<0?Shn0P0l?3`04@13@d<0De=C055AD@0n?Sh0?Cdm0410
@00j>SX0>CTi03Xj>P0g=cL0>3Ph03Ti>@0j>SX0>3Ph03`l?00i>CT0>SXj0080>c/k00D0?clo03`l
?00m?Cd0>CTi03Xj>P0203Ph>00503Xj>P0k>c/0@D5104A4A00i>CT00P0g=cL0100h>3P0>CTi03Ph
>00h>3P203De=@0503/k>`0j>SX0>SXj03/k>`0g=cL00P0f=SH0200h>3P0>SXj03/k>`0g=cL0?3`l
03Lg=`0i>CT0=SHf0P0j>SX01P0k>c/0?Cdm03Xj>P0k>c/0BDU904A4A0<0>SXj00P0=3@d03Lg=`0i
>CT0>SXj03dm?@0i>CT0>3Ph03Lg=`80=SHf0P0g=cL00`0e=CD0>3Ph03Ti>@0203De=@0G03Lg=`0h
>3P0?3`l03Xj>P0g=cL0>CTi03hn?P1QHF40Ng]k09:BTP2OWil0U9BD096AT@2][Jd0WYjN09BDU020
P800LG5a05iNGP1FEUH0ATI60410@015ADD00P0m?Cd03@0k>c/0?3`l03/k>`0i>CT0=cLg03/k>`0m
?Cd0=cLg03`l?00f=SH0>3Ph03Ti>@0g=cL00P0j>SX05@0h>3P0=cLg03/k>`0l?3`0ATI6069RHP2;
Rh/0Zj^[0<W9b@3AdM40alO709bLW01hN7P0EeMG04a<C018B4P0GemO08R8R02WYjL0_;bl0:j^[P0=
ooooo`004?ooool02@20P800VIVI0;2`/02UYJD0XZ:R09jNWP2<S8`0MgMg05aLG002051@D006055A
D@1?Cdl0Cdm?04a<C01;Bd/0AdM70`16ATH204U9B@0I04M7A`16ATH0ADE504M7A`15ADD0BDU904M7
A`15ADD0ATI604Q8B015ADD0@T9204a<C01:BTX0A4A404E5A@18B4P0ADE504Q8B012@T80ATI604M7
A`15ADD0@d=30410@00204E5A@090492@P11@D40ADE50451@@10@400@D510410@011@D40@T9200<0
?clo00`0@T920451@@0o?cl0@D5103lo?`0m?Cd0?clo0492@P0n?Sh0>c/k03Xj>P0m?Cd203lo?`03
0410@00l?3`0?clo0080@T9200X0@D510410@010@400?Cdm0410@00o?cl0?3`l03/k>`0m?Cd0?3`l
0P0j>SX203/k>`0@03Ph>00m?Cd0?Cdm03hn?P0o?cl0?Shn03/k>`0i>CT0>c/k03Ti>@0n?Sh0@D51
03dm?@10@400>c/k03dm?@<0>SXj00L0>c/k03dm?@0n?Sh0>c/k03Xj>P0h>3P0>SXj0080>c/k0P0m
?Cd04P0n?Sh0@d=303hn?P0h>3P0>c/k03`l?013@d<0?Cdm03lo?`0l?3`0?Cdm03hn?P0o?cl0>SXj
03/k>`0l?3`0?Cdm03Ph>080>SXj00@0?Shn03`l?00k>c/0?clo0P0l?3`03@0o?cl0?Cdm03lo?`0h
>3P0>c/k03`l?00o?cl0>c/k03dm?@0o?cl0@d=303/k>`0m?Cd00P0n?Sh01`0k>c/0?3`l03dm?@0l
?3`0>3Ph03Ti>@0k>c/00P0o?cl02`0k>c/0?Cdm03dm?@10@400@T9203lo?`0n?Sh0>c/k03Ti>@0j
>SX0@4100080?Cdm00X0?clo03`l?00n?Sh0@d=303lo?`0m?Cd0?3`l04=3@`0m?Cd0@D510`0o?cl0
1@0h>3P0?Shn03lo?`0o?cl0?3`l0080?Shn00@0?3`l03dm?@0l?3`0>SXj0P0i>CT05@0j>SX0>c/k
03Xj>P0i>CT0>c/k03Ti>@0j>SX0?3`l03Ph>00j>SX0?3`l04E5A@1KFe/0JFUY06=SH`1TI6@0EEEE
04U9B@16ATH0?clo03hn?P0203dm?@0I0410@00m?Cd0>c/k03dm?@12@T80D51@06ATI028R8P0QHF5
09FEU@2SXj<0WYjN08b<S01kNg/0QhN708R8R01mOGd0Kfm_06=SH`1FEUH0Bd];04E5A@0n?Sh0@d=3
0451@@020410@00903`l?010@400A4A404=3@`18B4P0CDe=05aLG01_Kfl0O7al0080Shn?03H0QHF5
06m_K`1QHF40D51@04];B`17AdL0BTY:04i>CP1GEeL0LG5a09ZJVP2l_;`0`/;20=?Cd`3EeMD0g=cL
0=OGe`32`/80Z:RX08N7Q`1IFET0Cdm?069RHP1?Cdl0?clo0410@00n?Sh0?Cdm03`l?00k>c/0@410
03lo?`0l?3`0@d=3055AD@1GEeL0E5AD05]KF`1gMgL0Rh^;05mOG`0l?3`0?Cdm0410@01BDU80H61P
06a/K01[Jf/0Fe]K04a<C00n?Sh0>CTi0410@011@D4203/k>`0303dm?@0o?cl0>c/k0080>3Ph00<0
>CTi03`l?00i>CT00P0j>SX203Ti>@80=cLg0P0f=SH03P0h>3P0>c/k03/k>`0i>CT0>SXj03Ph>00j
>SX0?Cdm04i>CP1;Bd/0>CTi03Hf=P0k>c/0>CTi1P0j>SX00`0h>3P0>CTi03Xj>P0203Ti>@0903`l
?00k>c/0>SXj03Ti>@0g=cL0?Cdm03Hf=P0g=cL0=SHf0080>CTi00h0>3Ph03Xj>P13@d<0ATI604Y:
BP0o?cl0>3Ph03Ti>@0f=SH0>c/k03`l?00m?Cd0=cLg03Ph>080=cLg00T0>CTi03Ph>00k>c/0=CDe
03Lg=`0j>SX0>CTi03Xj>P0h>3P00P0g=cL0500h>3P0=CDe03Ti>@0h>3P0AdM708^;R`31`L40/;2`
08F5Q@26QXH0PX:20820P01YJFT0FEUI05EEE@10@400?Cdm03Lg=`0n?Sh0?3`l0P0k>c/303Ti>@80
>c/k0240>3Ph03De=@0i>CT0>CTi038b<P0g=cL0>3Ph03Ti>@0f=SH0>c/k03Xj>P0n?Sh0B4Q8069R
HP2JVYX0[Zj^0;2`/02b/[80_Kfm0:VYZ@21PH40Hf=S051@D01FEUH0M7Ad09:BTP2f][H0d=3@0=?C
d`3?cll0^[Zj08V9R@1UIFD03Oooool0013ooooo01@0EUIF05ADE01WIfL0Jf][07inOP2?Shl0SHf=
07moO`1iNGT0UYJF08^;R`24Q8@0Kfm_051@D01=CDd0C4a<04i>CP1<C4`0BTY:04U9B@<0B4Q800@0
BTY:04U9B@16ATH0AdM70P1<C4`02@1:BTX0B4Q804I6AP15ADD0ATI604A4A015ADD0A4A404=3@`03
04I6AP0604M7A`1:BTX0BTY:04I6AP14A4@0ATI61013@d<02@11@D40@4100410@011@D40@41004A4
A013@d<0?Shn0451@@0203hn?P0>03`l?012@T80@d=30451@@0l?3`0@D5104A4A013@d<0?Cdm03hn
?P0o?cl0>c/k0410@011@D420410@00603lo?`0n?Sh0?Shn03hn?P0o?cl0>SXj0P0m?Cd0100i>CT0
?Shn03lo?`0k>c/203Xj>P0:03dm?@0l?3`0?3`l03`l?00j>SX0>CTi03Xj>P0l?3`0?Shn03lo?`80
>CTi00H0?3`l03dm?@13@d<0@T9203/k>`11@D4203/k>`80?3`l0P0j>SX04@0m?Cd0?Shn03/k>`0l
?3`0?Shn03Xj>P0m?Cd0?3`l03Xj>P0o?cl0?3`l03/k>`0l?3`0>SXj0410@00l?3`0>c/k0080>CTi
00P0>SXj03Ph>00g=cL0>CTi03/k>`0j>SX0>CTi03/k>`80>SXj00H0>CTi03Xj>P10@400>SXj03Ti
>@0m?Cd303`l?00A0451@@0k>c/0?Shn03dm?@10@400?Shn03/k>`0m?Cd0?Shn03Xj>P0k>c/0>CTi
03/k>`0m?Cd0>c/k03lo?`10@4000P0l?3`203hn?P80?Cdm00@0@D5104=3@`0o?cl0?Shn0P11@D40
200o?cl0?Cdm03/k>`0o?cl0?Shn0410@00l?3`0>c/k0P0h>3P01`0n?Sh0>SXj03/k>`0o?cl0@D51
0492@P0j>SX00P0k>c/303`l?00603/k>`0j>SX0=SHf03/k>`0l?3`0?Cdm0P0l?3`0;@0m?Cd0?3`l
03Xj>P0k>c/0>SXj03Ti>@15ADD0B4Q80451@@1BDU80JFUY071`L01NGUh0I6AT04Y:BP0m?Cd0?Shn
03`l?00k>c/0?Shn0410@015ADD0BTY:04a<C01=CDd0EeMG06=SH`1lO7`0S8b<0820P01`L700IfMW
06=SH`1hN7P0QhN708B4Q01cLg<0DE5A04Q8B01>CTh0H61P06a/K01EEED0A4A403lo?`0203hn?P0=
03`l?00o?cl0ADE504U9B@1FEUH0MgMg07]kN`2BTY80RXZ:06][J`1OGel0AdM70410@00203dm?@0>
0451@@18B4P0E5AD04i>CP1?Cdl0C4a<04Y:BP17AdL0CTi>05EEE@1UIFD0JFUY06e]K@1_Kfl207Ee
M@0S08>3P`2QXJ40[jn_09ZJVP2ATI40P820075aL@1PH600EUIF04a<C017AdL0@T9204Q8B01IFET0
K6a/05iNGP2BTY80`<300;no_`2i^KT0a<C40<_;b`39bLT0Vi^K07YjNP20P800YjNW0=3@d03De=@0
_;bl0:FUY@2IVIT0Lg=c04A4A013@d<00P15ADD03`12@T80>c/k03hn?P0o?cl0?Cdm03Ph>00k>c/0
>CTi03Xj>P0i>CT0>c/k03Lg=`1;Bd/0@d=303Ph>00203Ti>@0903Xj>P0k>c/0>c/k03lo?`0i>CT0
@41003dm?@0l?3`0@T920080>SXj00T0=cLg03Ph>00h>3P0?Cdm03Ti>@0g=cL0=SHf03Ti>@0l?3`0
0P0k>c/0100g=cL0>c/k03lo?`0j>SX203Ti>@0403Ph>00g=cL0>c/k03Xj>P80?3`l00H0>CTi03Xj
>P0k>c/0@d=30410@00n?Sh203Ph>00D03Ti>@0g=cL0>CTi03Lg=`0j>SX0=CDe03Xj>P0k>c/0?Cdm
03Ti>@0g=cL0>3Ph03Hf=P0g=cL0>CTi03`l?00h>3P0>c/k03dm?@0k>c/203Xj>P80>CTi01L0@410
06e]K@2_[jl0_kno09fMW@2VYZH0[Jf]08R8R01@D500@T9203Ph>00j>SX0?Cdm03Ti>@0k>c/0>CTi
03Xj>P0i>CT0=cLg03Ti>@0f=SH0>3Ph03Lg=`0203/k>`80=CDe0P0j>SX0200f=SH0>3Ph03/k>`0k
>c/0>CTi051@D026QXH0[jn_0P3Cdm<04`3AdM40][Jf096AT@1WIfL0AdM70492@P1:BTX0T92@0<K6
aP3IfMT0gMgM0>?Sh`3<c<`0^KVi09>CT`1dM7@0Fe]K04A4A00k>c/03Oooool0013ooooo00D0CTi>
04m?C`1ADE40D51@04i>CP0204a<C00C04i>CP1?Cdl0EUIF05IFEP1EEED0E5AD079bLP2EUID0U9BD
09JFUP2GUiL0LW9b059BDP1@D500C4a<04Q8B016ATH0BTY:04M7A`0204Y:BP80BDU900D0BTY:04a<
C01>CTh0BDU904Q8B00204I6AP0404M7A`1:BTX0E5AD04U9B@<0ADE500/0A4A404E5A@12@T80C4a<
04Q8B012@T80A4A404=3@`18B4P0@T9204A4A0030451@@@0?Shn00D0?clo0451@@10@400@41003/k
>`0204=3@`0?04I6AP10@400?Cdm03hn?P0o?cl0A4A403lo?`0l?3`0>c/k0410@012@T80?Shn03`l
?00m?Cd0>3Ph00<0>c/k00D0?clo03hn?P0i>CT0>3Ph03Ti>@0203/k>`80?3`l00<0?Cdm03Ti>@0j
>SX00`0k>c/00`12@T80>SXj03/k>`020451@@0503hn?P0j>SX0@41003Xj>P0k>c/00P0l?3`02P0n
?Sh0>c/k03/k>`0k>c/0>SXj03`l?00n?Sh0?Cdm03`l?00n?Sh203Xj>P070410@00l?3`0>c/k03Ti
>@0m?Cd0>SXj03/k>`0203Lg=`0;03Ti>@0e=CD0=cLg03Ti>@0l?3`0>3Ph03/k>`0j>SX0>3Ph03De
=@0h>3P00`0j>SX00`0i>CT0>SXj0492@P0203lo?`0703dm?@0j>SX0>c/k03`l?00m?Cd0?clo0410
@00203/k>`80>SXj00H0>c/k03Hf=P0j>SX0>c/k04=3@`12@T8303`l?00303Xj>P0h>3P0>c/k0080
?Cdm0P0n?Sh04P0l?3`0>SXj03/k>`13@d<0?clo0410@00o?cl0@T9203dm?@0k>c/0?Cdm0410@00o
?cl0>3Ph03dm?@0o?cl0?3`l0410@080?clo0`0j>SX01@0o?cl0?3`l03dm?@0i>CT0=cLg0080?Cdm
00P0?clo0410@012@T80@T9203hn?P19BDT0@d=30492@P80C4a<00L0@41003lo?`10@400?clo03hn
?P0k>c/0@D510080?3`l00T0?Cdm03lo?`0n?Sh0?Shn04=3@`1CDe<0D51@05=CD`1EEED00P1BDU80
3P1?Cdl0ATI604A4A01>CTh0EEEE05eMG@1VIVH0G5aL04a<C012@T80?Cdm04U9B@16ATH0Cdm?0P12
@T803@1HF5P0Cdm?04i>CP1>CTh0GEeM07=cL`29RHT0QXJ607QhN01YJFT0DE5A04A4A013@d<00P10
@4002015ADD0?Shn03dm?@0n?Sh0?clo04Y:BP1=CDd0DU9B0P1>CTh0>012@T80?Shn0410@014A4@0
CTi>05ADE01IFET0HF5Q06a/K028R8P0];Bd0<[:bP34a<@0Z:RX08B4Q02@T900UiNG09ZJVP2HV9P0
R8R80820P023Ph<0UiNG0;Zj^P3:b/X0c/k>0=oOg`3QhN40fm_K0=7Ad@33`l<0aLG50;fm_@2b/[80
U9BD0820P02MWId0UiNG09:BTP2MWId0][Jf0;Ng]`2/[:`0`L710;jn_P2_[jl0YZJV08^;R`1UIFD0
F5QH03Lg=`0l?3`0?clo03Ph>00j>SX0>CTi0P0k>c/00`1GEeL0@41003Ti>@0203Ph>080>c/k00@0
?Cdm03`l?00j>SX0>c/k0P0l?3`203Ti>@0M03Ph>00i>CT0>c/k03dm?@0k>c/0>SXj03`l?00o?cl0
@4100451@@0o?cl0>c/k03`l?00m?Cd0?3`l03Lg=`0f=SH0=cLg03Ti>@0j>SX0?clo04A4A00n?Sh0
>CTi05=CD`1TI6@0C4a<03Xj>P0o?cl00`0h>3P203Hf=P0703Xj>P0f=SH0=SHf03`l?013@d<0>3Ph
03Xj>P0203/k>`0603dm?@0j>SX0>SXj03dm?@11@D40>SXj0P0i>CT03@0f=SH0=cLg03Ti>@0j>SX0
DU9B08b<S02l_;`0^k^k0:f][@34a<@0TI6A061PH00o?cl00`0i>CT0100g=cL0?3`l03Ti>@0h>3P2
03Lg=`0903Xj>P0g=cL0>CTi03Hf=P0h>3P0=SHf03Lg=`0h>3P0=cLg0080>CTi01h0>3Ph03Ti>@0j
>SX0?3`l05QHF02BTY80c<c<0=SHf035aLD0/;2`08>3P`1MGEd0ATI603hn?P0o?cl0EEEE07QhN02P
X:00c<c<0<o?c`32`/80Zj^[07UiN@1JFUX0D51@04I6AP0m?Cd0?3`l03Ph>00k>c/=ooooo`004?oo
ool0=`1EEED0FEUI05eMG@1QHF40IVIV06m_K`2@T900X:2P0:BTY02VYZH0/k>c0<;2`P2h^;P0W9bL
08J6QP1hN7P0M7Ad0861P@26QXH0I6AT051@D01>CTh0DU9B05YJFP1PH600Fe]K05mOG`1QHF40LG5a
0:2PX02ZZZX0ZJVY0;6a/@2TY:@0XZ:R0:6QX@2OWil0XZ:R092@T028R8P0KFe]04U9B@16ATH0EEEE
05mOG`1EEED0DU9B061PH01BDU80K6a/07inOP20P800RXZ:09^KV`23Ph<00P1TI6@01P19BDT0@D51
03hn?P0o?cl0@41004A4A080?clo0P0n?Sh02013@d<0?clo0410@00o?cl0@4100451@@0l?3`0?Shn
0P0l?3`01P0n?Sh0?Cdm03/k>`0n?Sh0@D5103lo?`80?Shn00D0>c/k03lo?`0o?cl0?clo03hn?P02
03lo?`0603hn?P0m?Cd0?3`l03dm?@0l?3`0>SXj0`0i>CT203`l?080>c/k00@0?3`l03Xj>P0k>c/0
>3Ph0P0j>SX03@0k>c/0>SXj03hn?P0o?cl0?Cdm03`l?00m?Cd0@41003dm?@0l?3`0>c/k03`l?00m
?Cd00P0l?3`04`0m?Cd0?3`l03dm?@0n?Sh0@41003Ti>@0g=cL0>CTi03`l?00m?Cd0>CTi03lo?`0m
?Cd0>3Ph03Lg=`0j>SX0>3Ph03Lg=`0e=CD00P0i>CT203Ph>00603Ti>@0j>SX0>c/k03Hf=P0j>SX0
>CTi0P0k>c/0100j>SX0?Cdm03`l?00j>SX203dm?@0803Lg=`0i>CT0>c/k03Xj>P0h>3P0?clo04=3
@`0n?Sh203/k>`0903dm?@0l?3`0>c/k03`l?00o?cl0?Cdm0410@014A4@0?Cdm0080>SXj00P0>c/k
03`l?00k>c/0=SHf03Ti>@0j>SX0?Shn03`l?080AdM700<0>CTi03dm?@0n?Sh00`0n?Sh0100m?Cd0
>c/k03`l?00h>3P203Ti>@0603/k>`0h>3P0>3Ph03lo?`0i>CT0?3`l1@0k>c/00`0i>CT0>c/k03/k
>`0203hn?P80?clo0180?Cdm03`l?00n?Sh0ATI60492@P0n?Sh0A4A404E5A@1=CDd0F5QH06MWI`1_
Kfl0Jf][06a/K01JFUX0B4Q803dm?@0o?cl303hn?P0I03Xj>P0m?Cd0?Cdm03hn?P0m?Cd0>c/k03lo
?`10@400?Cdm0451@@17AdL0@T920410@00l?3`0?clo03hn?P0m?Cd0>c/k03hn?P12@T80?Cdm03`l
?00n?Sh0@D5103/k>`0204M7A`0a04E5A@0n?Sh0@41004=3@`15ADD0C4a<05IFEP1KFe/0HF5Q06m_
K`1eMGD0Ti>C0:NWY`2NWYh0UIFE0:>SX`2YZJT0WIfM09FEU@2LW9`0UIFE08R8R02<S8`0NWYj07If
MP2=SHd0WIfM0:VYZ@35aLD0eMGE0=3@d038b<P0^k^k0:n_[`2a/K40]kNg0<c<c03Jf]X0g]kN0=oO
g`3Shn<0g=cL0=7Ad@3Bd]80fMWI0<W9b@2h^;P0][Jf0<;2`P020;bl_0060<o?c`3Ph>00j>SX0=oO
g`2d];@0HV9R0P1CDe<01P1gMgL0GemO05EEE@12@T80?Cdm03lo?`<0>SXj00<0AdM703dm?@0k>c/0
0P0k>c/00`0h>3P0>CTi03Ti>@0303Ti>@0603Ph>00j>SX0>c/k03Xj>P0h>3P0>c/k0P0i>CT09`0k
>c/0>SXj03Xj>P0l?3`0?Shn03lo?`14A4@0?clo03Lg=`0i>CT0>SXj03dm?@0k>c/0?Cdm03`l?00j
>SX0>3Ph03Lg=`0m?Cd0B4Q805=CD`1@D500>3Ph03Xj>P0g=cL0>3Ph03`l?00j>SX0=cLg03Hf=P0j
>SX0=SHf03De=@0d=3@0>c/k0451@@0k>c/0?clo03dm?@0203Xj>P0F03Lg=`0c<c<0=3@d03Xj>P0f
=SH0ADE505IFEP1TI6@0CTi>07moO`2d];@0Xj>S08B4Q01aLG40MGEe05]KF`0n?Sh0?Cdm03Xj>P0i
>CT0?Cdm03/k>`80>3Ph02d0>CTi03Lg=`0g=cL0=cLg03Ph>00g=cL0>CTi03De=@0d=3@0>3Ph03@d
=00f=SH0>3Ph03Xj>P1:BTX0DU9B06m_K`21PH40YZJV0<71`@2n_[h0Ti>C06ATI014A4@0@D5103lo
?`19BDT0CDe=05eMG@20P800ZZZZ0;:b/P2d];@0UiNG06i^KP1OGel0CTi>03lo?`0k>c/0?3`l03hn
?P0m?Cd0>c/k03Ph>00l?3`03Oooool0013ooooo00X0/[:b0<?3``3=cLd0f=SH0=GEe@38b<P0[Jf]
092@T024Q8@0QXJ60P2;Rh/0;`2IVIT0Xj>S0:n_[`2QXJ40WYjN0::RXP2EUID0Shn?09jNWP2^[Zh0
][Jf0<k>cP3=cLd0`L710;Ng]`2k^k/0_kno0;2`/02KVi/0W9bL0;:b/P3Cdm<0gMgM0=cLg03Bd]80
e]KF0<G5a@2PX:00MgMg051@D01?Cdl0J6QX07AdM01YJFT0GEeM05MGE`1LG5`0H61P06ATI01XJ6P0
HV9R07IfMP23Ph<0QHF507moO`1IFET0BTY:0080?clo00T0@d=30492@P0n?Sh0?clo03hn?P10@400
>c/k0410@012@T800`10@400200n?Sh0@41003/k>`0g=cL0?Shn0410@00o?cl0?Cdm0P0l?3`01016
ATH0>SXj03Xj>P0n?Sh303dm?@0R03hn?P11@D40?clo03lo?`0n?Sh0?Cdm03`l?00o?cl0>c/k03Ti
>@0j>SX0>3Ph03Xj>P0k>c/0>SXj03Ph>00j>SX0?Shn03Ti>@0h>3P0?Cdm0451@@0o?cl0?Cdm03hn
?P0k>c/0>SXj03/k>`0o?cl0?3`l03dm?@0i>CT0>3Ph03Xj>P80>c/k00/0>SXj03/k>`0k>c/0>CTi
03Lg=`0f=SH0>CTi03Ph>00m?Cd0>c/k03Lg=`0203Ph>00A03Lg=`0j>SX0>3Ph03Ph>00g=cL0>3Ph
03dm?@0k>c/0=cLg03/k>`0m?Cd0>SXj03Ph>00i>CT0>SXj03Ti>@0g=cL00P0j>SX01P10@400?Cdm
03Ph>00h>3P0>CTi03Hf=P80>c/k0`0i>CT01P0l?3`0>c/k03Xj>P0j>SX0>CTi03Xj>P<0?3`l00<0
>CTi03Ph>00k>c/00P0l?3`0;@0h>3P0>CTi03dm?@0j>SX0=SHf03Ph>00j>SX0?Cdm03`l?00o?cl0
A4A403Xj>P0h>3P0>c/k03dm?@0k>c/0>SXj03dm?@0i>CT0>SXj03dm?@0i>CT0>3Ph03Ti>@0l?3`0
?Shn03`l?00h>3P0?Shn0451@@0k>c/0@41003`l?00j>SX0?Shn03Ph>00o?cl0@D5103dm?@0l?3`0
@D5104e=C@1DE5@0ADE50410@00203Xj>P0303lo?`13@d<0ATI60080CDe=00D0C4a<04Q8B014A4@0
?clo0451@@0203dm?@1=03hn?P0l?3`0>CTi03Xj>P0l?3`0>3Ph03`l?011@D40FEUI06][J`2BTY80
VIVI09ZJVP2PX:00VYZJ08N7Q`25QHD0P82007YjNP1TI6@0CTi>03dm?@0n?Sh0C4a<05ADE01EEED0
JFUY07UiN@2;Rh/0S8b<09RHV02RXZ80VIVI09^KV`2HV9P0U9BD09fMW@2EUID0WIfM09^KV`2IVIT0
Vi^K09FEU@1mOGd0H61P05YJFP1GEeL0DE5A05mOG`1]KFd0PH610:2PX02][Jd0YZJV09ZJVP2WYjL0
^[Zj0<g=c@3Bd]80c<c<0=7Ad@3<c<`0_kno0:b/[02NWYh0VIVI08V9R@2<S8`0TY:B09ZJVP2m_Kd0
bl_;0=7Ad@2f][H0^KVi0=3@d03Jf]X00P3=cLd03P3GemL0f][J0=;BdP2k^k/0/K6a0:>SX`2d];@0
U9BD04m?C`0l?3`0@D51059BDP29RHT0Jf][0P1;Bd/0301<C4`0?Shn03dm?@0n?Sh0@T9203lo?`0k
>c/0?3`l03Ti>@0k>c/0>SXj03Ti>@80>SXj01T0>3Ph03/k>`0j>SX0>c/k03Xj>P0h>3P0>CTi03`l
?00j>SX0>c/k03`l?00m?Cd0>SXj03Ti>@0j>SX0?Cdm03Ph>00k>c/0?3`l03/k>`0l?3`0>c/k03`l
?00k>c/0?3`l0080>SXj0`0i>CT03`0k>c/0?3`l03dm?@0i>CT0?Shn03/k>`0g=cL0>3Ph03Xj>P0i
>CT0=cLg03Xj>P0d=3@0=cLg03De=@0203Hf=P0L03/k>`0l?3`0>3Ph03Lg=`0j>SX0GemO08F5Q@2P
X:00ZJVY09NGU`1UIFD0Ti>C08b<S01QHF40B4Q804];B`12@T80>CTi03Ph>00l?3`0>SXj03Ph>00i
>CT0>c/k03Xj>P0h>3P0>c/k03Ph>080=cLg01h0=3@d03Ti>@0e=CD0=CDe03Hf=P0e=CD0B4Q805eM
G@1jNWX0WinO0<O7a`3:b/X0][Jf0::RXP2EUID0JFUY04];B`0k>c/0?Shn05YJFP2IVIT0/[:b0:^[
Z`2MWId0VYZJ08j>SP1bLW80JVYZ05]KF`1>CTh203/k>`0903Lg=`0h>3P0>c/k03/k>`0i>CT0?3`l
03/k>`0i>CT0?Cdm00gooooo000@ooooo`0J0:NWY`2d];@0clo?0=;BdP3Cdm<0cLg=0<30`02`/;00
Zj^[0:f][@2^[Zh0[Jf]0;2`/02_[jl0/k>c0:^[Z`2UYJD0]KFe0<C4a03>c/h0`/;20<g=c@3Hf=P0
dM7A0;^k^`31`L420<_;b`050=;BdP3Hf=P0g]kN0=_Kf`3IfMT00P3Hf=P03`3Lg=`0fm_K0;Zj^P22
PX80KFe]05=CD`1=CDd0C4a<04i>CP19BDT0AdM704I6AP1>CTh0EeMG05eMG@0205ADE00<04E5A@16
ATH0ADE504M7A`15ADD0@D5104E5A@0o?cl0?Shn04E5A@14A4@0DE5A0P1@D5001`1SHf<0EUIF04E5
A@0o?cl0ADE503lo?`10@4000P0o?cl02P10@400?Shn03/k>`11@D40ADE503Ti>@0l?3`0?clo03/k
>`0n?Sh203/k>`<0?3`l00T0?Shn03lo?`0n?Sh0?Cdm03`l?010@400?clo03Xj>P0m?Cd00P0i>CT0
3@0n?Sh0>c/k03Ti>@0k>c/0>CTi03dm?@0j>SX0>3Ph03/k>`0i>CT0>SXj03hn?P0k>c/00`0m?Cd0
1P0j>SX0?Cdm03/k>`0l?3`0>c/k03dm?@<0>SXj00<0=cLg03Ti>@0k>c/00P0k>c/203Ph>00F03`l
?00g=cL0?3`l03Xj>P0g=cL0>SXj03`l?00h>3P0>SXj03dm?@0j>SX0=cLg03Ti>@0j>SX0?Cdm03Xj
>P0i>CT0?3`l03Ph>00j>SX0=cLg03Xj>P80>c/k0P0h>3P00`0i>CT0>3Ph03Ti>@0403Ti>@0903Xj
>P0f=SH0>3Ph03Lg=`0h>3P0>c/k03hn?P0g=cL0>CTi00<0>3Ph00<0=cLg03Ph>00j>SX00P0k>c/0
3@0h>3P0>CTi03Ti>@0k>c/0>3Ph03Ti>@0k>c/0>SXj03/k>`0l?3`0@41003dm?@0n?Sh00P0m?Cd0
4`10@400?Cdm03`l?00l?3`0>SXj03Ph>010@400?Shn03`l?00j>SX0>3Ph03Xj>P0n?Sh0>c/k03Xj
>P0i>CT0?3`l03Ph>00i>CT00P0l?3`01`0i>CT0?clo0451@@16ATH0@D5104=3@`10@4000P11@D42
055AD@0H0492@P0n?Sh0>3Ph03/k>`0j>SX0@T9203lo?`0k>c/0>CTi03`l?00k>c/0@d=30451@@14
A4@0?Cdm04U9B@1:BTX0ADE504U9B@1OGel0IfMW05MGE`1OGel0FUYJ0P1FEUH05@1BDU80C4a<04Y:
BP14A4@0ATI604E5A@0k>c/0?3`l04I6AP1XJ6P0PH6108B4Q02SXj<0b/[:0=CDe02m_Kd0WYjN08B4
Q01[Jf/0DE5A04i>CP0204E5A@0C0492@P17AdL0DU9B06a/K01jNWX0SXj>09NGU`2KVi/0R8R809^K
V`2a/K40];Bd0:FUY@2ATI40SHf=09:BTP2HV9P0Rh^;07YjNP0207MgM`0W075aL@1]KFd0HF5Q05EE
E@18B4P0ATI60492@P14A4@0CTi>05ADE01ADE40HF5Q06MWI`1cLg<0MWIf071`L01/K6`0LW9b08R8
R02TY:@0a/K60<_;b`3@d=00][Jf09NGU`2MWId0QXJ607AdM02:RXX0IVIV0820P02[Zj/0`/;20<K6
aP3Bd]80alO70:6QX@1dM7@0@4100080?Cdm00@0?Shn03dm?@0k>c/0>c/k0P0l?3`01@0h>3P0?Cdm
03Ph>00j>SX0BTY:0080>c/k00D0>SXj03dm?@0i>CT0>c/k03Lg=`0303Ti>@0>03Xj>P0g=cL0=cLg
03Ti>@0l?3`0>CTi03Xj>P0m?Cd0>SXj03Lg=`0k>c/0?Cdm03Ph>00j>SX203`l?00;03Ph>00i>CT0
>SXj03Ti>@0k>c/0CDe=0492@P0m?Cd0>CTi03Hf=P0h>3P00P0g=cL203Ph>00F03@d=00i>CT0=cLg
03De=@0d=3@0>3Ph03/k>`0j>SX0=cLg04Y:BP1aLG40KVi^05QHF01<C4`0AdM703dm?@15ADD0?3`l
03lo?`0h>3P0?clo03Ti>@80>SXj00D0>c/k03Ph>00i>CT0=cLg03De=@0303<c<`0/038b<P0e=CD0
>3Ph03Ti>@0h>3P0>c/k03Ph>01;Bd/0LG5a0;6a/@37alL0]KFe09FEU@1fMWH0GemO04Q8B013@d<0
?clo03Ph>00n?Sh0Fe]K0:FUY@3:b/X0^[Zj08^;R`1fMWH0JFUY05aLG013@d<0>SXj03Ti>@0j>SX0
>c/k03Lg=`0i>CT0>3Ph03Lg=`0h>3P0>CTi03Ph>00m?Cd0Bd];075aL@2NWYh=ooooo`004?ooool0
6@1?Cdl0FUYJ06=SH`1XJ6P0P820092@T01nOWh0Q8B408f=S@21PH40N7Qh07alO02GUiL0YjNW0:>S
X`2NWYh0VYZJ0:2PX02NWYh0^[Zj0=OGe`3De=@0eMGE0=[JfP3IfMT00P3Lg=`01`3MgMd0fm_K0=CD
e039bLT0aLG50;bl_02i^KT00P2m_Kd08@32`/80YjNW0820P01jNWX0JFUY05UIF@1RHV80IFEU06QX
J01UIFD0EeMG04m?C`1ADE40C4a<04I6AP1=CDd0A4A40410@015ADD0@d=304E5A@14A4@0DU9B04m?
C`1:BTX0Cdm?04e=C@18B4P0ADE504I6AP1:BTX0C4a<04e=C@0204=3@`030410@00n?Sh0@T920080
ADE500P0@d=304M7A`1<C4`0D51@04E5A@0m?Cd0?Shn03lo?`80?3`l00<0>CTi03dm?@10@4000P10
@40203dm?@0?03lo?`0n?Sh0?3`l03`l?00k>c/0>3Ph03hn?P0m?Cd0?Shn03`l?00k>c/0?3`l03dm
?@0i>CT0>c/k0080?3`l00H0?clo03dm?@0m?Cd0>CTi03/k>`0o?cl203`l?00703dm?@0k>c/0?Cdm
03dm?@0o?cl0?Cdm03/k>`0203Ti>@0703Xj>P0k>c/0?Cdm03hn?P0k>c/0?Cdm04];B`0203Ti>@80
>3Ph00T0>CTi03/k>`0n?Sh0?Cdm03/k>`0l?3`0?clo03dm?@0i>CT00`0k>c/303Xj>P0403dm?@0j
>SX0?Shn03Xj>P80>CTi0P0h>3P02`0j>SX0>c/k03Xj>P0h>3P0>CTi03Xj>P0g=cL0>CTi03Lg=`0j
>SX0>CTi0080>c/k00L0?3`l03Xj>P0h>3P0>c/k03hn?P10@400>SXj0080>c/k00X0?Cdm03/k>`0g
=cL0?Shn03/k>`0i>CT0>c/k03hn?P0k>c/0>SXj0P0k>c/02P0o?cl0>c/k03`l?010@400?clo0451
@@10@400?Shn03lo?`0l?3`203dm?@0403`l?00o?cl0>SXj03/k>`80>CTi00P0>c/k03hn?P0n?Sh0
@D5104a<C016ATH0?Shn03Ti>@80?Cdm00L0@4100492@P16ATH0CDe=04E5A@1=CDd0AdM70080?Shn
00X0?Cdm0410@016ATH0?Cdm03/k>`0h>3P0?3`l03lo?`12@T80AdM70P12@T803P0l?3`0@d=30451
@@0n?Sh0?3`l03dm?@13@d<0AdM7051@D010@400?Cdm03`l?00i>CT0>c/k0`0j>SX05P13@d<0B4Q8
05EEE@1OGel0J6QX07MgM`2=SHd0Y:BT09nOW`25QHD0CDe=04m?C`11@D40?Shn03lo?`12@T80CDe=
065QH@1gMgL0[Zj^0:n_[`2l_;`20;Bd]00909^KV`2PX:00TI6A0820P01LG5`0Cdm?04Q8B014A4@0
?clo0080@D510180@4100451@@0n?Sh0@41003lo?`10@400?Cdm04E5A@0n?Sh0ADE505EEE@1hN7P0
Z:RX0;^k^`39bLT0clo?0=3@d030`<020:ZZZP040;:b/P2`/;00YJFU092@T080Ogmo02L0RHV909^K
V`2j^[X0dm?C0;bl_01bLW80DE5A05EEE@1eMGD0QHF508b<S02PX:00_[jn0<g=c@2VYZH0QHF505IF
EP18B4P0>c/k03hn?P0l?3`0?Cdm03/k>`0m?Cd0>SXj03dm?@10@400BDU905mOG`1`L700Cdm?03`l
?011@D40?3`l03/k>`0n?Sh0>CTi03`l?00k>c/00P0i>CT00`0h>3P0>CTi03/k>`0203Xj>P80?3`l
00l0>SXj0492@P15ADD0>CTi03`l?00i>CT0>SXj03Ph>00i>CT0>c/k03Xj>P15ADD0@d=304e=C@0i
>CT00P0h>3P01`0j>SX0>3Ph03Lg=`0f=SH0=cLg03De=@0d=3@00`0f=SH03P0h>3P0>c/k03`l?00k
>c/0>3Ph03Hf=P0g=cL0>3Ph03Hf=P0i>CT0?3`l03Xj>P0g=cL0?Cdm0P1BDU80201>CTh0?clo03/k
>`0l?3`0>c/k03Lg=`0e=CD0>3Ph0P0g=cL03P0f=SH0>3Ph03/k>`0i>CT0=3@d03Hf=P0b<S80?clo
05YJFP2IVIT0QhN7075aL@1KFe/0B4Q80P0l?3`05`0f=SH0?Shn03hn?P19BDT0FUYJ09fMW@3?cll0
b/[:08Z:RP1ADE40A4A40410@00i>CT0=cLg03Xj>P0g=cL0>3Ph03De=@0h>3P0>c/k03Ti>@0h>3P0
=cLg0080>SXj00D0Bd];0861P@2k^k/0hN7Q0>KViP0=ooooo`004?ooool0:`1<C4`0CDe=04i>CP1=
CDd0C4a<04];B`1=CDd0Bd];04a<C01BDU80CTi>04e=C@1>CTh0Cdm?04i>CP1?Cdl0D51@05EEE@1C
De<0EUIF06=SH`1WIfL0MGEe092@T02MWId0YZJV0:ZZZP38b<P0e]KF0=WIf@36a/H0]kNg09jNWP1k
Ng/0VIVI0;Zj^P32`/80_[jn0<g=c@3Ng]h0dm?C0<_;b`3Bd]800P3>c/h02@2m_Kd0_kno0<C4a034
a<@0]kNg096AT@1GEeL0B4Q804M7A`0204I6AP0:04E5A@12@T80ATI604I6AP10@400ADE50410@012
@T80A4A404=3@`80@41001D0?clo04A4A01dM7@0S8b<08f=S@2DU9@0Xj>S0;Ng]`2m_Kd0_;bl0<W9
b@38b<P0YjNW06][J`1=CDd0?clo0492@P11@D40?Shn03`l?00j>SX0100m?Cd01`13@d<0?3`l03hn
?P0n?Sh0?3`l03Ti>@0k>c/00P0m?Cd0100j>SX0?Shn03`l?00n?Sh203`l?00<03Xj>P0o?cl0?3`l
03hn?P0l?3`0>3Ph03Xj>P0n?Sh0>3Ph03Xj>P0k>c/0>SXj0P0k>c/203Ti>@80>SXj00D0>CTi03/k
>`0l?3`0>c/k03Xj>P0203`l?00503hn?P0i>CT0>3Ph03Xj>P0k>c/00P0j>SX01`0k>c/0?3`l03dm
?@0k>c/0>CTi03Lg=`0i>CT00P0m?Cd05@0o?cl0@41003Xj>P0m?Cd0ADE503Ti>@11@D40>SXj03Ti
>@0j>SX0?Cdm03Lg=`0i>CT0?3`l03Ph>00j>SX0?Cdm03Ti>@0k>c/0=cLg03@d=00303Ti>@0703dm
?@0k>c/0>SXj03`l?00j>SX0=3@d03hn?P0203`l?00<03Xj>P0k>c/0?3`l03Xj>P0m?Cd0>c/k03Ti
>@0h>3P0?Cdm0451@@0k>c/0?3`l0P0o?cl03@0i>CT0>c/k03hn?P0l?3`0@41004=3@`0n?Sh0=cLg
03Xj>P0h>3P0>c/k03Xj>P0k>c/00P0m?Cd0E@0k>c/0>SXj03/k>`1;Bd/0C4a<0451@@0l?3`0@D51
0410@00l?3`0@41003hn?P12@T80?clo04A4A00m?Cd0>SXj03lo?`0k>c/0?3`l03hn?P0o?cl0?3`l
03dm?@0h>3P0=cLg03Ph>00j>SX0>CTi03`l?00k>c/0?Shn0451@@0l?3`0>c/k03hn?P15ADD0?3`l
04A4A00o?cl0BTY:04E5A@0m?Cd0?clo0410@012@T80?clo04A4A01KFe/0LW9b07UiN@1aLG40GUiN
051@D015ADD0BDU904e=C@13@d<0ATI605QHF01SHf<0HF5Q061PH01ZJVX0PX:20:JVYP2d];@0^k^k
0:NWY`2l_;`0`<3008^;R`1YJFT0FEUI04U9B@12@T80@41003hn?P12@T80?Shn03`l?00n?Sh0>CTi
03`l?011@D400P14A4@0;@12@T80C4a<059BDP1VIVH0Kfm_07QhN01_Kfl0Ogmo0;6a/@3De=@0i>CT
0=gMg@39bLT0`l?30;no_`2YZJT0Ogmo07=cL`1^KVh0UYJF09bLW02UYJD0W9bL0:n_[`30`<00d];B
0<_;b`3@d=00bLW90;2`/02?Shl0Jf][05YJFP1@D500Bd];04U9B@1ADE40Lg=c09BDU02b/[80b<S8
0<?3``1cLg<0ADE503`l?0020410@00>04Q8B01IFET0O7al07AdM01fMWH0Ph>308B4Q01hN7P0F5QH
04e=C@0n?Sh0>c/k0492@P13@d<203lo?`0<0410@011@D40?3`l03/k>`0j>SX0?Cdm05ADE01LG5`0
Bd];0410@016ATH0BTY:0P0n?Sh00`0l?3`0>c/k03Ti>@0203/k>`0;03`l?01<C4`0>c/k03/k>`0i
>CT0=cLg03Ti>@0k>c/0>SXj03Ti>@0g=cL00`0f=SH02P0g=cL0>CTi03Ph>00j>SX0=cLg03Ph>00f
=SH0=CDe038b<P0i>CT203De=@0603Lg=`0l?3`0=cLg03Ti>@0l?3`0@T920P0m?Cd09P0i>CT0=cLg
03Lg=`0j>SX0=SHf03De=@0f=SH0=cLg03Ph>00g=cL0=3@d03Ph>00g=cL0=3@d03Hf=P0j>SX0@T92
05ADE01:BTX0>CTi03Xj>P0i>CT0=cLg03Hf=P0n?Sh0Fe]K08J6QP2ZZZX0/;2`09RHV027QhL0OGem
05EEE@0n?Sh0>SXj03`l?00f=SH0>SXj0`0i>CT03P0b<S80>3Ph04I6AP1<C4`0D51@05MGE`16ATH0
B4Q805MGE`29RHT0]kNg0:FUY@2>SXh0RHV93Oooool0013ooooo00<0C4a<04];B`1<C4`00P1;Bd/0
201:BTX0B4Q804];B`19BDT0AdM704Y:BP1=CDd0C4a<0P1=CDd08@18B4P0CDe=04e=C@1;Bd/0D51@
05MGE`1TI6@0DE5A059BDP1DE5@0CDe=05ADE01SHf<0M7Ad0:>SX`2GUiL0JVYZ05UIF@1CDe<0E5AD
05QHF01MGEd0JVYZ079bLP20P800Shn?096AT@2UYJD0`L710=SHf03>c/h0Z:RX0<71`@020=oOg`06
0;jn_P2GUiL0Ogmo06QXJ01DE5@0BTY:0P15ADD204I6AP0M05QHF01YJFT0EeMG04a<C018B4P0Bd];
0451@@12@T80@D51075aL@2KVi/0Y:BT0;Bd]02h^;P0`<300<K6aP2h^;P0YZJV09:BTP25QHD0NWYj
07emO@1^KVh0MgMg08R8R01]KFd0AdM704E5A@0o?cl00P10@4002P15ADD0?3`l0451@@0k>c/0>CTi
03`l?00n?Sh0?Cdm0410@00n?Sh203dm?@0503Xj>P0i>CT0>CTi03`l?00j>SX00P0l?3`01`0g=cL0
>SXj03Xj>P0j>SX0?Cdm03lo?`0m?Cd00P0g=cL00`0l?3`0>SXj03/k>`0403/k>`0803Xj>P0l?3`0
>SXj03`l?00j>SX0@41003/k>`0l?3`203dm?@0303`l?00k>c/0?Cdm0080>CTi0`0k>c/00`0l?3`0
>c/k03Ti>@0203Xj>P80>CTi00P0=cLg03`l?00j>SX0>3Ph0410@00k>c/0>CTi03Lg=`80>SXj01/0
>c/k03Ph>00i>CT0=cLg03dm?@0l?3`0>c/k03dm?@0k>c/0>CTi03Xj>P0l?3`0>c/k03Xj>P0k>c/0
?Cdm03/k>`0o?cl0>c/k03dm?@0n?Sh0?Cdm03hn?P0h>3P0=cLg03Xj>P0h>3P00P0k>c/02P0l?3`0
?Cdm03/k>`0k>c/0?clo0492@P0i>CT0>3Ph03/k>`0i>CT203`l?00503Xj>P0f=SH0=cLg03Xj>P0o
?cl00P0n?Sh02`0m?Cd0?3`l0492@P0l?3`0>SXj03lo?`0h>3P0?Shn03dm?@10@400?clo0080?Shn
00l0?Cdm03/k>`0j>SX0>CTi03Ph>00j>SX0>CTi03Xj>P0k>c/0?3`l03lo?`14A4@0@d=30451@@0k
>c/00P0i>CT03@0n?Sh0@T9203lo?`11@D40?Shn03Ti>@0k>c/0?Cdm0451@@0m?Cd0>CTi03Xj>P12
@T800P0m?Cd02@1BDU80PX:207alO023Ph<0Ogmo07EeM@20P800O7al071`L00205ADE006055AD@17
AdL0B4Q805ADE01XJ6P0LG5a0P1fMWH0;@1aLG40Kfm_08>3P`2?Shl0PH6108j>SP26QXH0Ogmo07]k
N`1aLG40K6a/05IFEP14A4@0?Cdm0451@@0o?cl0@D5104E5A@16ATH0F5QH06UYJ@25QHD0Shn?08V9
R@1/K6`0NWYj0:b/[034a<@0e]KF0=3@d03=cLd0/K6a096AT@28R8P0Shn?092@T01mOGd0H61P05UI
F@1QHF40KVi^0820P01WIfL0Ph>30:6QX@020;bl_0180;Bd]02e]KD0/K6a0:FUY@2XZ:P0_;bl0<_;
b`3GemL0f=SH0=[JfP3GemL0b/[:0<G5a@30`<00]KFe0:RXZ02PX:00[Jf]0<o?c`3Fe]H0eMGE0:ZZ
ZP1nOWh0M7Ad08N7Q`2SXj<0bLW90=_Kf`3Hf=P0eMGE0<_;b`3AdM40fMWI0;Fe]@2=SHd0YZJV09RH
V02?Shl0ZJVY0:^[Z`2?Shl0H61P04a<C013@d<0?Cdm0410@012@T80MGEe07]kN`1PH600F5QH079b
LP1`L700OGem09RHV01QHF40>SXj03dm?@0k>c/0AdM70410@00j>SX0>3Ph03`l?00g=cL0>CTi03Xj
>P0h>3P0>CTi03Ph>00g=cL0>3Ph0`0g=cL0100i>CT0>SXj03/k>`0f=SH303Lg=`0503Hf=P0g=cL0
=cLg03Ph>00d=3@00P0e=CD0300f=SH0=cLg03Ph>00f=SH0>3Ph03Lg=`0e=CD0=3@d03Lg=`0h>3P0
>CTi03Lg=`<0=SHf02d0>3Ph03Ti>@0g=cL0>3Ph03Hf=P0h>3P0=cLg03Ti>@0f=SH0>SXj03/k>`0f
=SH0>CTi05iNGP2NWYh0aLG50:NWY`25QHD0F5QH03hn?P0j>SX0=cLg03De=@0g=cL0>c/k03Xj>P0f
=SH0>c/k04];B`1UIFD0LG5a05EEE@1bLW80TY:B08R8R01NGUh0EeMG06MWI`1MGEd0D51@05=CD`17
AdL0@T9204U9B@1`L7003Oooool0013ooooo00P0C4a<04];B`1=CDd0C4a<04];B`19BDT0AdM704Y:
BP80B4Q800l0Bd];04e=C@1<C4`0C4a<051@D01:BTX0C4a<04Y:BP1;Bd/0EEEE061PH01XJ6P0CTi>
051@D01CDe<00P1@D500?@1QHF40E5AD05MGE`1JFUX0F5QH06][J`1ZJVX0M7Ad07QhN01ZJVX0FUYJ
055AD@1<C4`0HV9R06UYJ@1ZJVX0KFe]08n?S`35aLD0X:2P09fMW@2i^KT0clo?0<c<c03IfMT0clo?
0=CDe03=cLd0];Bd09JFUP21PH40QXJ60;:b/P3EeMD0]KFe07inOP1iNGT0V9RH08n?S`1gMgL0H61P
05IFEP1LG5`0FEUI069RHP1nOWh0Jf][059BDP1:BTX0AdM704U9B@1<C4`0CDe=0451@@12@T80@D51
04U9B@1MGEd0E5AD04e=C@1KFe/00P1CDe<01`1ADE40G5aL06][J`1HF5P0CTi>04A4A012@T800P0k
>c/00`0l?3`0?Cdm03/k>`0203`l?00B03Ti>@0l?3`0>SXj03`l?00h>3P0>SXj03/k>`11@D40?clo
03/k>`10@400?3`l03lo?`0l?3`0>c/k03`l?00k>c/0?3`l0P0n?Sh0200o?cl0?Shn03dm?@0j>SX0
>CTi03Xj>P0l?3`0?Shn0P0i>CT02@0k>c/0?Cdm03/k>`0k>c/0?Shn03Xj>P0i>CT0>c/k03dm?@02
03`l?00303/k>`0j>SX0?3`l0080>c/k00P0>3Ph03Ti>@0k>c/0>CTi03dm?@0k>c/0>3Ph03Ti>@<0
?3`l00<0?Cdm03Ti>@15ADD00P0m?Cd203/k>`0=0410@00n?Sh0?3`l03/k>`0m?Cd0>CTi03Lg=`0k
>c/0>SXj03Ti>@0l?3`0>SXj03Ti>@0203Xj>P0403dm?@0j>SX0>CTi03/k>`80?3`l01`0?Cdm03hn
?P0m?Cd0?Shn03`l?00n?Sh0@D5103hn?P0j>SX0?Cdm03Ti>@0k>c/0?Cdm03`l?00i>CT0?3`l03dm
?@0j>SX0?3`l03hn?P0k>c/0>CTi03/k>`11@D40?Shn03`l?00k>c/0>CTi0P0g=cL01010@400>c/k
03/k>`0n?Sh203lo?`80>SXj00/0?Cdm03`l?00k>c/0?3`l0492@P1:BTX0AdM70451@@0o?cl0@T92
0410@00203/k>`0:03`l?00m?Cd0@41003/k>`0h>3P0=cLg03/k>`0l?3`0@41003`l?080>SXj00l0
CDe=05=CD`1UIFD0OGem07AdM020P800Kfm_06ATI01LG5`0BTY:04A4A019BDT0?clo0410@00l?3`0
0P0o?cl01`12@T80@D510410@011@D40?Cdm04A4A011@D400P10@4000`15ADD0?Shn03dm?@020451
@@0Y0492@P1?Cdl0H61P05YJFP1IFET0EeMG04m?C`1IFET0IfMW08Z:RP2>SXh0O7al08^;R`2MWId0
W9bL0;Bd]03<c<`0gMgM0>?Sh`3Jf]X0b/[:09^KV`21PH40UIFE0:j^[P2GUiL0WYjN07AdM01cLg<0
IfMW065QH@1[Jf/0G5aL06e]K@1nOWh0LW9b05IFEP1<C4`0DE5A06=SH`1mOGd00P2DU9@0@02LW9`0
T92@0820P01oOgl0QXJ609jNWP2c/k<0_[jn0;bl_02m_Kd0alO70<S8b02j^[X0_;bl0=3@d03IfMT0
g]kN0<O7a`2PX:00XJ6Q0;Zj^P3Cdm<0eMGE0=[JfP3YjNT0iNGU0=kNgP3Hf=P0f][J0>3Ph03Jf]X0
eMGE0=_Kf`3MgMd0bLW90;Vi^@2RXZ80OGem05EEE@10@400?Cdm04A4A01hN7P0S8b<0;2`/03Fe]H0
hN7Q0=KFeP2RXZ80MWIf061PH01VIVH0Bd];03lo?`0j>SX0>CTi03Hf=P0k>c/0>SXj03Ph>00j>SX0
>CTi03Xj>P0i>CT203Ph>00703Ti>@0k>c/0>SXj03Lg=`0d=3@0=cLg03De=@0303Lg=`80>3Ph00D0
>c/k03Ti>@0e=CD0>3Ph03Xj>P0203Lg=`0603Ti>@0g=cL0=cLg03Hf=P0e=CD0=3@d0P0f=SH00`0i
>CT0@4100410@00203`l?00D03/k>`0j>SX0=SHf03Lg=`0h>3P0=SHf03Lg=`0j>SX0>3Ph03/k>`0g
=cL0@D5108N7Q`2o_kl0YJFU06IVIP0m?Cd0>SXj03Ti>@0h>3P203Hf=P0?03De=@0g=cL0>CTi03dm
?@12@T80@41003hn?P1;Bd/0EEEE05=CD`1[Jf/0JFUY059BDP0l?3`0A4A40080?3`l00H0>SXj04A4
A01FEUH0Ogmo0:f][@3:b/X=ooooo`004?ooool01`1;Bd/0BTY:04a<C01:BTX0B4Q804U9B@17AdL0
0P18B4P0101>CTh0Cdm?04e=C@1=CDd204a<C00404m?C`1<C4`0BTY:04Y:BP80Bd];00D0B4Q804M7
A`18B4P0Bd];05EEE@0204Y:BP0D04Q8B01:BTX0ATI604a<C01FEUH0IFEU07QhN02=SHd0T92@07If
MP1gMgL0PH6109VIV@2i^KT0_Kfm0<G5a@3;bl/0_[jn09>CT`1^KVh206UYJ@0C07AdM01kNg/0UIFE
0;Zj^P38b<P0a<C40=CDe03GemL0f=SH0=[JfP3<c<`0]kNg0:JVYP2CTi<0Kfm_05eMG@1<C4`0A4A4
04M7A`0204=3@`0904Q8B013@d<0@T9204A4A012@T80@41004i>CP1BDU80Hf=S0080G5aL00T0KVi^
07MgM`1/K6`0EEEE051@D01=CDd0@d=303lo?`14A4@00P1HF5P05P16ATH0@41003dm?@0k>c/0@410
03/k>`0m?Cd0>SXj03Ph>00k>c/0?clo03/k>`0m?Cd0?clo03Ti>@0m?Cd0>SXj03`l?00j>SX0?Cdm
0451@@0l?3`203Ti>@0=03/k>`0n?Sh0?Cdm03dm?@0j>SX0@41003dm?@0j>SX0?Cdm03lo?`0k>c/0
?3`l03/k>`0203hn?P0303lo?`0h>3P0>CTi0080?Cdm0P0n?Sh0100k>c/0>CTi03/k>`0o?cl203/k
>`0503Xj>P0i>CT0?Shn04Y:BP0k>c/00P0j>SX203/k>`0?03hn?P0m?Cd0?3`l03dm?@14A4@0?3`l
03Ti>@0m?Cd0@T9203Ph>00i>CT0?3`l03dm?@0k>c/0?Cdm0080@41000P0?3`l03/k>`0j>SX0>CTi
03/k>`0n?Sh0?clo03Ti>@80?Cdm00@0>CTi03Ph>00i>CT0?3`l0P0j>SX00`0n?Sh0@41003lo?`02
03hn?P0403`l?00k>c/0>c/k03`l?080>c/k0P0l?3`203Xj>P0403Ti>@0h>3P0?Shn03dm?@80>CTi
00H0?Shn03dm?@0n?Sh0>SXj03/k>`0j>SX203`l?00803hn?P0k>c/0ATI603Ti>@0k>c/0?3`l03Ti
>@0h>3P203/k>`0903`l?00m?Cd0?3`l03Xj>P0i>CT0?clo0451@@0l?3`0@4100080>c/k0`0m?Cd0
6@10@400?clo03dm?@0n?Sh0?clo03hn?P11@D40@41004=3@`10@400>c/k0410@018B4P0DU9B05=C
D`1EEED0C4a<04Y:BP19BDT0@T9203hn?P13@d<0?Shn03`l?00n?Sh00P0o?cl0100n?Sh0?Cdm03Xj
>P0m?Cd203lo?`0V03`l?014A4@0@T9204=3@`12@T80C4a<05EEE@1]KFd0QhN709BDU02@T900Shn?
08R8R02?Shl0UYJF08R8R01bLW80PH6108>3P`1eMGD0Ng]k09BDU02ZZZX0WYjN09ZJVP2BTY80VIVI
0::RXP2TY:@0/[:b0;jn_P3;bl/0a<C40:NWY`1iNGT0I6AT05UIF@15ADD20451@@0;03hn?P10@400
@41004A4A01;Bd/0EEEE06YZJP29RHT0Vi^K08b<S01[Jf/00P1DE5@04@1>CTh0FEUI06UYJ@29RHT0
Zj^[0;Jf]P2h^;P0^KVi0;^k^`2`/;00/K6a0<C4a03?cll0e=CD0=gMg@3De=@0`<300080/[:b00<0
[:b/0;bl_03AdM400P3IfMT01P3Lg=`0gmoO0=3@d02^[Zh0ZZZZ0<o?c`80f][J01@0fMWI0=KFeP3C
dm<0fm_K0=kNgP3QhN40cLg=0:NWY`2:RXX0/[:b0=kNgP3QhN40iNGU0<_;b`2DU9@0JVYZ05YJFP1D
E5@0BDU904E5A@80>SXj0P14A4@00`0l?3`0?Shn03/k>`0203Ti>@0303Xj>P0l?3`0>SXj00<0>CTi
0100?3`l03/k>`0k>c/0=cLg03Ti>@0h>3P0>CTi03Hf=P0g=cL0>CTi03Ph>00j>SX0GemO0451@@0i
>CT0>3Ph0P0f=SH00`0h>3P0>CTi03Ph>00203Lg=`0603Hf=P0l?3`0?Shn0451@@0l?3`0?clo0`0i
>CT0700g=cL0<c<c03Hf=P0h>3P0=cLg03Ti>@0h>3P0>SXj04];B`1iNGT0V9RH08J6QP1KFe/0?Cdm
03Ti>@0j>SX0>3Ph03Lg=`0h>3P0=SHf03Ph>00g=cL0>3Ph03Ti>@0j>SX0=cLg03@d=00e=CD203Lg
=`0>0410@00g=cL0?Cdm04Q8B01/K6`0VIVI0:NWY`1mOGd0Ng]k09nOW`2`/;00_[jn0:BTY01]KFd=
ooooo`004?ooool204a<C00504e=C@1;Bd/0Bd];04i>CP1;Bd/00P1:BTX0401@D500CTi>04Y:BP1:
BTX0BDU904];B`1?Cdl0Bd];04U9B@18B4P0C4a<04];B`15ADD0CDe=04Q8B019BDT204M7A`1704A4
A01;Bd/0ATI604Q8B01;Bd/0DU9B05EEE@1@D500ATI604Q8B017AdL0Bd];04a<C01=CDd0EeMG06=S
H`1YJFT0LW9b07MgM`25QHD0Ogmo06m_K`1LG5`0Cdm?04i>CP1@D500EUIF08N7Q`2l_;`0_Kfm0:f]
[@2NWYh0SHf=071`L01UIFD0GUiN069RHP1OGel0MgMg0861P@1eMGD0I6AT05]KF`1GEeL0GUiN061P
H01]KFd0HV9R05]KF`1GEeL0Cdm?04E5A@1=CDd0EUIF06UYJ@1lO7`0U9BD09>CT`2ATI40Ph>306EU
I@14A4@0?3`l03hn?P12@T80?Shn0451@@0o?cl0?Cdm03hn?P19BDT00P0m?Cd503`l?00303/k>`0n
?Sh0?Cdm0080>c/k01h0?Cdm03hn?P17AdL0AdM70410@014A4@0?Shn03/k>`0n?Sh0>c/k03hn?P0o
?cl0?3`l03/k>`0m?Cd0>CTi03Ph>00k>c/0?Cdm03`l?012@T80?clo03/k>`0j>SX0?clo03dm?@0n
?Sh0?3`l03/k>`0n?Sh303`l?00=03dm?@0l?3`0?3`l03/k>`1MGEd0IfMW03lo?`0l?3`0@41003dm
?@0k>c/0@41003Xj>P0203Ti>@0703Ph>00g=cL0=SHf03`l?010@400>CTi03dm?@0203Xj>P0703dm
?@0l?3`0?Shn03dm?@0l?3`0?clo03dm?@0203Ti>@0803lo?`0i>CT0?Cdm03Xj>P0k>c/0?Shn03lo
?`0n?Sh203Ti>@0703/k>`0l?3`0?clo0410@00o?cl0?Shn03Ti>@0303/k>`0I03dm?@0k>c/0?Shn
0451@@0l?3`0>CTi03Lg=`0j>SX0>CTi03lo?`10@400?Shn03lo?`0k>c/0>SXj03Lg=`0j>SX0=cLg
03Xj>P0g=cL0?Cdm03hn?P0k>c/0=CDe03Ti>@0203dm?@0403hn?P0m?Cd0>SXj03dm?@80>c/k00X0
?Cdm03hn?P0m?Cd0?3`l03/k>`0j>SX0>3Ph03`l?00m?Cd0>SXj0`0o?cl02P0m?Cd0@4100410@018
B4P0ATI603dm?@0o?cl0?3`l03Xj>P0i>CT20451@@80>SXj0P0l?3`303/k>`0303`l?00o?cl0?3`l
0080?Cdm00<0?3`l03/k>`0m?Cd00P0h>3P0?P0k>c/0?Cdm03Ph>013@d<0@T9203`l?01=CDd0MGEe
08Z:RP2;Rh/0Ph>308V9R@2ATI40WinO0;:b/P2a/K40Ph>306a/K01^KVh0IfMW075aL@2@T900YZJV
0:b/[02OWil0NGUi069RHP1NGUh0Hf=S06i^KP1RHV80GEeM061PH01[Jf/0GemO04=3@`11@D40?3`l
0492@P0o?cl0?Cdm04=3@`0n?Sh0EEEE06QXJ01bLW80HV9R06ATI01kNg/0RXZ:09NGU`2RXZ80[Zj^
0;Ng]`2l_;`0`l?30<_;b`3Fe]H0dm?C0;^k^`2WYjL0UIFE0P1oOgl04@22PX80Shn?0:JVYP2d];@0
/k>c0;jn_P37alL0^[Zj0;6a/@2_[jl0^;Rh0;jn_P3Bd]80b<S80;Ng]`2n_[h0a/K60080cLg=02d0
e]KF0=SHf03>c/h0bl_;0=SHf03EeMD0dM7A0=CDe03AdM40`/;20<S8b03?cll0d];B0=[JfP3Ti>@0
hN7Q0=[JfP3Cdm<0e]KF0<71`@2:RXX0O7al08>3P`1gMgL0K6a/07IfMP2CTi<0WYjN08:2PP1WIfL0
IFEU079bLP1XJ6P0Bd];03/k>`0j>SX0>3Ph03Lg=`0j>SX0?Cdm03Ti>@0j>SX0>3Ph03`l?00j>SX0
0P0g=cL0600h>3P0>SXj03dm?@1FEUH0GUiN03De=@0j>SX0>3Ph03Xj>P0g=cL0>CTi03Lg=`0i>CT0
=cLg03Ph>00k>c/0?clo03Xj>P0i>CT0>3Ph03Ti>@0e=CD0>SXj03/k>`80=SHf0P0g=cL02@0h>3P0
?Shn05EEE@1fMWH0/k>c092@T01IFET0>c/k03dm?@0303Hf=P0303De=@0g=cL0=CDe0080=CDe0P0g
=cL0100h>3P0>c/k03Ph>00d=3@203De=@0?03Ti>@0e=CD0@T9207QhN030`<00][Jf09VIV@1aLG40
FEUI075aL@2<S8`0Jf][051@D012@T80CDe=00gooooo000@ooooo`0:04e=C@1<C4`0BTY:04e=C@1<
C4`0Bd];04a<C01=CDd0B4Q804a<C080CTi>0P19BDT204a<C00704M7A`1:BTX0B4Q804Y:BP19BDT0
CDe=04a<C00404M7A`0Q04];B`1=CDd0Bd];04I6AP1<C4`0BTY:04];B`1<C4`0BDU904a<C01;Bd/0
BDU904=3@`16ATH0BDU904E5A@12@T80ATI604A4A01:BTX0AdM704a<C01@D500GEeM06MWI`1XJ6P0
GemO061PH01NGUh0FUYJ05=CD`1;Bd/0H61P0080Ogmo01H0P82006i^KP1CDe<0GUiN08F5Q@2RXZ80
[Jf]0;2`/02SXj<0XJ6Q0;^k^`3Cdm<0aLG50;fm_@2e]KD0^[Zj0;6a/@2^[Zh0ZZZZ09RHV01XJ6P0
A4A40P12@T804`0o?cl0ADE50410@00o?cl0@T9203`l?013@d<0@T9203`l?00n?Sh0?Cdm0410@013
@d<0@T9203hn?P10@400?clo03hn?P0o?cl00`0n?Sh03@12@T80FUYJ07MgM`2GUiL0Kfm_04];B`0l
?3`0@41003lo?`0m?Cd0?3`l03hn?P10@4000P0m?Cd03@0k>c/0@D5106IVIP1KFe/0ADE50410@00l
?3`0>3Ph03Ti>@0l?3`0?Cdm03`l?00j>SX00P0l?3`03@0h>3P0?Shn04A4A010@400?Shn03dm?@0l
?3`0@D5103Ti>@1gMgL0JFUY04];B`0m?Cd00P0k>c/203lo?`0303hn?P12@T80?Cdm0080>c/k01<0
>SXj03/k>`0g=cL0>SXj03`l?00i>CT0?Cdm03`l?00m?Cd0>SXj03/k>`0n?Sh0?Cdm03/k>`0l?3`0
?Cdm03lo?`0k>c/0?3`l0080>SXj0P0l?3`01@0m?Cd0>c/k03hn?P0k>c/0?Shn00<0@D5100H0@T92
03Ti>@0k>c/0?3`l03hn?P0j>SX203`l?00:03lo?`0k>c/0?Cdm03dm?@0o?cl0>c/k03Xj>P0m?Cd0
?3`l03/k>`80?3`l00L0=SHf03lo?`0l?3`0?Shn03Xj>P0o?cl0?Cdm0080>SXj00@0?Cdm03`l?00l
?3`0?Shn0P0o?cl0200g=cL0>c/k03/k>`0j>SX0?3`l03Ph>00i>CT0?3`l0P0j>SX01@0o?cl0>SXj
03dm?@0k>c/0?Cdm0080@41001D0@d=303lo?`0o?cl0@T920451@@0j>SX0>c/k0492@P0h>3P0ATI6
03hn?P11@D40@T920410@00n?Sh0@41003Lg=`0j>SX0>CTi03`l?00k>c/00P0m?Cd04P0l?3`0>c/k
03/k>`0j>SX0>c/k03dm?@0j>SX0?3`l03/k>`0g=cL0?clo05aLG01gMgL0FUYJ05EEE@1BDU80F5QH
05iNGP80GemO00H0Fe]K059BDP18B4P0@d=304I6AP1EEED207AdM00j06IVIP1QHF40EEEE04=3@`14
A4@0?3`l03lo?`0n?Sh0>SXj03lo?`10@400ADE503Ti>@0m?Cd0?clo03hn?P0k>c/0?clo04=3@`1:
BTX0DE5A05IFEP1EEED0J6QX08R8R02YZJT0][Jf09nOW`2IVIT0Vi^K09VIV@2?Shl0UYJF092@T01n
OWh0NWYj08b<S02KVi/0VIVI08b<S02OWil0a/K60=KFeP3Cdm<0clo?0<W9b@37alL0a<C40;jn_P2m
_Kd0cLg=0=oOg`3Shn<0j^[Z0>WYj@3Rh^80g]kN0=_Kf`80hN7Q02H0h^;R0=3@d03<c<`0c<c<0=CD
e03GemL0eMGE0=;BdP3<c<`0`L710<;2`P3:b/X0a/K60<30`02PX:00[:b/0<[:bP3>c/h0d=3@0=7A
d@31`L40]kNg09fMW@1DE5@0@D5104E5A@1GEeL0JFUY08:2PP2`/;00XZ:R0820P01ZJVX0B4Q803hn
?P0m?Cd0>CTi03Lg=`80>CTi00l0>c/k03`l?00k>c/0>3Ph03Ti>@0g=cL0>3Ph03Xj>P11@D40B4Q8
04Y:BP0l?3`0>SXj03Hf=P0h>3P00P0i>CT203/k>`0703`l?00g=cL0@D5104I6AP0i>CT0=CDe03Lg
=`0303Hf=P0E03De=@0f=SH0>CTi03dm?@12@T80Fe]K07QhN01oOgl0P82006UYJ@1RHV80@T9203Lg
=`0f=SH0>SXj03Lg=`0k>c/0@41006e]K@1aLG40?3`l0080=cLg00P0>3Ph0451@@0k>c/0=SHf03Lg
=`0h>3P0>CTi03Hf=P80>3Ph00d0@d=305eMG@1HF5P0ATI603`l?00i>CT0?Shn03/k>`0l?3`0@410
069RHP2OWil0];Bd00gooooo000@ooooo`80Bd];00@0B4Q804Y:BP1<C4`0AdM70P19BDT03018B4P0
BTY:04U9B@16ATH0C4a<04Y:BP16ATH0BTY:04E5A@19BDT0Bd];04Q8B080BTY:00@0BDU904M7A`14
A4@0ADE50P1=CDd00`1:BTX0ATI604A4A00204E5A@0A04Y:BP17AdL0@d=304E5A@14A4@0AdM704E5
A@17AdL0ADE50451@@13@d<0A4A404M7A`14A4@0@d=304Q8B01@D5000P1<C4`02@19BDT0B4Q8051@
D01SHf<0F5QH059BDP19BDT0@T9204E5A@0204i>CP80C4a<04L0AdM704Y:BP1BDU80EUIF05aLG01O
Gel0FEUI05QHF01SHf<0IFEU06e]K@22PX80]KFe0<g=c@3GemL0clo?0;Bd]02HV9P0RXZ:08^;R`25
QHD0LW9b06IVIP1FEUH0EEEE04Q8B012@T80@d=304i>CP1YJFT0LG5a06e]K@1QHF40GEeM04M7A`1A
DE40Cdm?05iNGP1ZJVX0M7Ad07emO@1lO7`0MGEe07=cL`21PH40RXZ:08F5Q@21PH40Ph>307YjNP1m
OGd0QXJ608N7Q`26QXH0P82008B4Q021PH40OWin06UYJ@1kNg/0YJFU0861P@1?Cdl0@d=303lo?`0m
?Cd0@D5103Xj>P0m?Cd0?3`l03dm?@0203hn?P80?3`l01D0@4100451@@0n?Sh0>3Ph03/k>`0l?3`0
?clo04E5A@1:BTX0>SXj03/k>`0m?Cd0>c/k03`l?00h>3P0?Cdm03Xj>P0m?Cd0>3Ph03`l?00i>CT0
0P0k>c/00`0l?3`0>c/k03Ti>@0203/k>`0503`l?00j>SX0>SXj03Xj>P0k>c/00P0n?Sh00`0k>c/0
?Cdm03/k>`0303dm?@0?0451@@18B4P0A4A403Xj>P11@D40>c/k03lo?`0m?Cd0@D510492@P10@400
@d=304M7A`10@400=cLg00<0>c/k00P0>SXj03hn?P0m?Cd0?3`l03/k>`0o?cl0?3`l03lo?`80?3`l
00/0>3Ph03Xj>P10@400?3`l03/k>`0j>SX0=CDe03`l?00n?Sh0?3`l03Lg=`0203`l?00<03dm?@0l
?3`0?Cdm03`l?00j>SX0>3Ph03/k>`0i>CT0?Shn03Ph>00n?Sh0?3`l0P0k>c/203Xj>P80?3`l01H0
>CTi0451@@11@D40@T920451@@0j>SX0?Shn0492@P0o?cl0?3`l03/k>`0j>SX0>3Ph03Ti>@0j>SX0
?3`l0451@@0m?Cd0=cLg03hn?P0j>SX0?3`l0P0m?Cd02P0l?3`0?Shn03/k>`0k>c/0?clo059BDP1;
Bd/0EEEE04E5A@0i>CT203Xj>P0403lo?`11@D40?Cdm03hn?P<0?Cdm01D0@D5103dm?@13@d<0ADE5
04i>CP1CDe<0EEEE04e=C@15ADD0A4A403dm?@0l?3`0>SXj0410@00j>SX0?Shn0451@@0k>c/0?3`l
03lo?`13@d<00P12@T80;@1:BTX0De=C05UIF@1UIFD0KFe]07inOP2MWId0W9bL0:ZZZP2[Zj/0VYZJ
09:BTP2ATI40Lg=c05MGE`1EEED0NWYj0:2PX02IVIT0[Jf]0<W9b@2n_[h0ZJVY096AT@1mOGd0KVi^
06EUI@1`L700[Zj^0=?Cd`3EeMD0`l?30:BTY02OWil0_;bl0<k>cP3@d=00emOG0>;RhP3Shn<0h^;R
0=cLg03Cdm<0aLG50;^k^`020;Fe]@0h0:j^[P2d];@0^;Rh0:JVYP2DU9@0UYJF09VIV@2VYZH0/[:b
0;Fe]@2_[jl0UiNG08:2PP2EUID0^;Rh0;Ng]`2][Jd0XJ6Q0;:b/P2c/k<0^KVi09RHV022PX80H61P
04e=C@19BDT0@d=304Q8B01KFe/0@T9204m?C`2=SHd0[jn_092@T01TI6@0?Shn03dm?@0k>c/0=cLg
03Xj>P0k>c/0?3`l05mOG`1BDU80D51@03hn?P0i>CT0?3`l03lo?`0m?Cd0>SXj03/k>`0o?cl0?3`l
03lo?`0l?3`203Ti>@0503Xj>P0k>c/0>c/k03lo?`0h>3P00P0j>SX0400k>c/0=SHf03Lg=`0h>3P0
=CDe03Ti>@0k>c/0CDe=08J6QP2PX:00Q8B405YJFP17AdL0>SXj03Ti>@0b<S8303Hf=P06038b<P0j
>SX0>c/k055AD@1`L700EeMG0P0e=CD01@13@d<0CTi>04];B`0g=cL0=SHf0080>3Ph0140=cLg03Hf
=P0e=CD0>CTi03Ph>00k>c/0=SHf03Xj>P0d=3@0=cLg03hn?P1IFET0OWin0:n_[`3De=@0c<c<08N7
Q`0=ooooo`004?ooool01P1:BTX0Bd];04a<C018B4P0BDU904Q8B080ATI601<0A4A404U9B@19BDT0
BTY:04A4A019BDT0Bd];04Q8B016ATH0AdM704];B`17AdL0BDU904M7A`19BDT0CDe=04a<C017AdL0
ATI60080B4Q800@0ATI604U9B@16ATH0A4A40P16ATH02@18B4P0ADE50492@P16ATH0@d=304A4A012
@T80A4A404M7A`0204A4A00304U9B@15ADD0AdM70080AdM701`0?clo04M7A`15ADD0De=C05YJFP1H
F5P0Fe]K059BDP16ATH0Cdm?05aLG01FEUH0Fe]K05ADE01JFUX0EEEE05MGE`1CDe<0EUIF05EEE@1@
D500Cdm?051@D01?Cdl0HF5Q051@D01FEUH0V9RH0P2c/k<08P33`l<0d=3@0=GEe@3GemL0h>3P0=7A
d@2`/;00UiNG09ZJVP2UYJD0Z:RX09VIV@2^[Zh0bl_;0=KFeP3AdM40d];B0<c<c02CTi<0];Bd0<S8
b02i^KT0/k>c0:b/[02o_kl0hn?S0=;BdP33`l<0aLG50<k>cP3Ph>00emOG0<?3``2_[jl20:b/[00M
09^KV`2:RXX0WIfM0=7Ad@3IfMT0bLW908j>SP1GEeL0A4A403lo?`0i>CT0@d=303Ti>@0n?Sh0ATI6
04A4A00k>c/0>SXj03lo?`0m?Cd0>c/k03hn?P0l?3`0>SXj03`l?00o?cl0?Shn04E5A@0m?Cd00`0l
?3`01P0n?Sh0>CTi03Ti>@0k>c/0?Shn03/k>`80>3Ph00<0?Shn03`l?00o?cl00`0i>CT00`0j>SX0
>c/k03/k>`0303/k>`0=03`l?00k>c/0>CTi03Ph>00l?3`0?clo03`l?00i>CT0>c/k03`l?00j>SX0
>c/k03Xj>P0203dm?@0<03`l?00n?Sh0>c/k03`l?00m?Cd0?Shn03dm?@0l?3`0ATI60492@P0l?3`0
>SXj0P0k>c/02@0l?3`0>3Ph03Xj>P0i>CT0>c/k03Xj>P0n?Sh0?Cdm03hn?P0203dm?@0903`l?00i
>CT0>SXj03dm?@0l?3`0>c/k03Ti>@0k>c/0>3Ph0080>SXj00X0>c/k03Ph>00k>c/0?clo03/k>`0i
>CT0@41003`l?00k>c/0>3Ph0P0k>c/04P0o?cl0?Shn03/k>`0j>SX0>CTi03`l?00k>c/0?Cdm03`l
?015ADD0@d=303hn?P0j>SX0>CTi03Xj>P0m?Cd0?clo03Ti>@<0>c/k00D0?Shn0492@P12@T80?Cdm
03`l?00203Xj>P80?Cdm00@0?3`l0410@013@d<0@D510P0n?Sh02@11@D40?3`l03hn?P0k>c/0>SXj
03hn?P0k>c/0>CTi03lo?`0204M7A`0:055AD@1DE5@0FEUI04M7A`15ADD0@T9204A4A016ATH0@D51
0410@080@D5100<0?3`l03hn?P10@4000P0k>c/203lo?`0d03/k>`0j>SX0?Shn04Q8B01IFET0Lg=c
08J6QP2JVYX0R8R806=SH`1VIVH0OGem0861P@1gMgL0Shn?096AT@2:RXX0NWYj07MgM`1jNWX0RHV9
09nOW`2KVi/0][Jf0<30`02_[jl0]KFe0<C4a02i^KT0ZJVY09VIV@2;Rh/0LW9b065QH@1ZJVX0KFe]
08J6QP2YZJT0^k^k0;Vi^@2YZJT0Y:BT0:j^[P30`<00[Jf]0;:b/P2f][H0WinO08F5Q@1eMGD0JFUY
05IFEP80BDU903P0E5AD05mOG`1oOgl0VIVI0:RXZ02^[Zh0[Jf]0:BTY02KVi/0[Jf]0<g=c@3De=@0
clo?0;Zj^P2o_kl0f][J0=kNgP3IfMT0aLG50;:b/P2_[jl0^k^k0<k>cP3AdM40_[jn0;2`/02[Zj/0
XZ:R08:2PP1nOWh0Rh^;0:j^[P3Bd]80aLG50;Zj^P2QXJ40KFe]04m?C`22PX80TI6A06][J`1NGUh0
KFe]08F5Q@2PX:00WYjN0410@00m?Cd0>c/k03Xj>P0m?Cd0@41004=3@`1^KVh0NWYj04M7A`80?Cdm
0P0i>CT01`0k>c/0>SXj03De=@0i>CT0>3Ph03Ti>@0g=cL00`0h>3P0200f=SH0BDU906e]K@1nOWh0
N7Qh055AD@0k>c/0=SHf0P0g=cL01P0h>3P0=3@d03Ti>@0h>3P0@D5103lo?`80>3Ph00P0=SHf03De
=@0g=cL0<c<c03Ti>@10@400>c/k03Ti>@80=3@d00@0=cLg03Ti>@0h>3P0=CDe0P0d=3@03@0f=SH0
=cLg03Ph>00h>3P0ADE504];B`1bLW80U9BD0<K6aP32`/80SHf=05UIF@0o?cl03Oooool0013ooooo
0P1:BTX01P1;Bd/0BTY:04U9B@17AdL0ATI604U9B@80AdM700/0B4Q804];B`17AdL0AdM704Q8B016
ATH0BDU904I6AP18B4P0ATI604A4A00204I6AP0G04U9B@18B4P0ATI604Q8B016ATH0@d=304I6AP14
A4@0B4Q804A4A015ADD0ATI604Q8B013@d<0@T920451@@10@400ATI60492@P14A4@0ADE504A4A013
@d<00`11@D401@13@d<0@D5104=3@`19BDT0B4Q80080ADE500H0@d=303lo?`12@T80Bd];0492@P13
@d<204A4A00303hn?P11@D40@d=30080@d=303H0Bd];069RHP1OGel0E5AD04Q8B00n?Sh0AdM704Y:
BP1;Bd/0EeMG05EEE@1NGUh0NGUi0861P@2:RXX0UiNG0::RXP2UYJD0[Zj^0;:b/P2BTY80LW9b055A
D@1@D500E5AD061PH02GUiL0YjNW0:f][@3AdM40f=SH0=[JfP3Lg=`0clo?0=SHf03Kfm/0h>3P0>?S
h`3QhN40fMWI0=gMg@3Ogml0emOG0=7Ad@31`L40YjNW09:BTP2DU9@0Vi^K09FEU@2VYZH0UIFE07=c
L`1EEED20451@@0603dm?@11@D40@41003lo?`11@D40@d=30P11@D402`0k>c/0?3`l03lo?`0l?3`0
?Shn03lo?`10@400@T9203dm?@13@d<0?Shn00<0>c/k00D0?clo03`l?00m?Cd0?Cdm03`l?0020451
@@0703/k>`0n?Sh0?Shn05aLG017AdL0?clo03dm?@0203/k>`0803Xj>P0k>c/0?Cdm03hn?P0k>c/0
?Cdm03hn?P0m?Cd203/k>`0903hn?P0m?Cd0@D5104=3@`14A4@0>CTi03Xj>P0l?3`0?Cdm0080@410
00H0?Shn03Xj>P0l?3`0>CTi0451@@10@40203Lg=`0>03lo?`0l?3`0>CTi03hn?P0j>SX0?clo03/k
>`15ADD0@T9203hn?P0k>c/0>3Ph03`l?00h>3P303Xj>P80?3`l01H0?Cdm03/k>`0i>CT0>SXj03hn
?P0j>SX0>3Ph03/k>`0l?3`0?Shn03Hf=P0h>3P0?clo03dm?@0k>c/0?Shn0492@P0o?cl0?Cdm03`l
?010@400?Cdm0P0l?3`02`0m?Cd0?Shn03Xj>P0l?3`0=SHf03Xj>P0h>3P0>c/k0451@@0j>SX0>3Ph
00<0=cLg00P0?Shn03`l?00m?Cd0>c/k03Lg=`0j>SX0?3`l03Xj>P80?Shn00T0?3`l03/k>`0n?Sh0
>SXj03`l?00n?Sh0>SXj03Ti>@0h>3P00P0i>CT05@0k>c/0>SXj03lo?`0n?Sh0?Cdm03lo?`14A4@0
Bd];04e=C@15ADD0@D5103`l?00o?cl0@D510410@017AdL0A4A403dm?@0o?cl0?3`l03lo?`0203hn
?P0C0492@P0o?cl0?3`l03hn?P14A4@0Bd];05QHF01fMWH0OWin09RHV02VYZH0/[:b0:>SX`24Q8@0
L71`06e]K@25QHD0PX:205MGE`02051@D00G05ADE025QHD0SXj>07QhN021PH40UYJF09BDU024Q8@0
J6QX05QHF01OGel0FUYJ04m?C`18B4P0EeMG0861P@2BTY80Vi^K09>CT`1gMgL0KFe]05UIF@1<C4`0
0P1;Bd/09`1@D500HF5Q05eMG@1JFUX0GUiN06YZJP1`L700LG5a07IfMP1gMgL0K6a/06UYJ@1SHf<0
JVYZ07moO`1iNGT0Rh^;09jNWP35aLD0emOG0=3@d03:b/X0dm?C0=CDe03GemL0fMWI0=kNgP3Kfm/0
g]kN0=oOg`3Ti>@0i^KV0>CTi03UiND0i^KV0=kNgP3Bd]80bLW90<K6aP020<o?c`0V0;jn_P30`<00
aLG50;6a/@2SXj<0YJFU0;Bd]03:b/X0bLW90;^k^`3Hf=P0h^;R0>3Ph03Ng]h0b/[:0:ZZZP2UYJD0
]kNg0:>SX`2OWil0U9BD092@T02WYjL0/[:b0:2PX01mOGd0HV9R0410@00k>c/0?Shn03Ti>@0l?3`0
>3Ph03Xj>P0i>CT0>SXj03Lg=`0f=SH203Xj>P0O03`l?00j>SX0ADE505ADE018B4P0@41003Xj>P0f
=SH0>c/k03De=@12@T80?3`l03Lg=`0f=SH0@D5104A4A015ADD0>c/k03Hf=P0e=CD0=cLg03Ph>00f
=SH0=cLg03De=@0f=SH0=3@d03Lg=`0h>3P0>c/k03@d=00203Hf=P0=038b<P0i>CT0=3@d05ADE01J
FUX0?clo03dm?@1@D500NWYj09FEU@2=SHd0IfMW04Y:BP0203`l?00303/k>ooooooooooo00_ooooo
000@ooooo`0=04];B`1<C4`0BTY:04];B`1:BTX0AdM704E5A@17AdL0ATI604U9B@17AdL0ATI604A4
A00204E5A@0G04I6AP1;Bd/0Bd];04I6AP13@d<0A4A404U9B@18B4P0BDU904A4A017AdL0ADE50451
@@13@d<0AdM70492@P14A4@0AdM704I6AP12@T80A4A40492@P0o?cl00P11@D401@15ADD0@T9204=3
@`13@d<0A4A40080AdM700/0@T9204E5A@1>CTh0@d=304E5A@1:BTX0Bd];04=3@`1;Bd/0BTY:04A4
A0020451@@0A04E5A@14A4@0@D510410@00m?Cd0@d=304E5A@11@D40ATI605EEE@1KFe/0CDe=04A4
A010@400@T9204=3@`12@T800`15ADD09P1>CTh0GEeM05MGE`1/K6`0J6QX061PH01OGel0Jf][0861
P@2<S8`0QHF506][J`1NGUh0K6a/065QH@1UIFD0V9RH0:RXZ02MWId0XJ6Q0<G5a@3Jf]X0bLW90<S8
b02ZZZX0V9RH08n?S`2=SHd0Rh^;0:2PX02l_;`0`l?30;jn_P2l_;`0[jn_09fMW@2HV9P0YZJV0P2M
WId0501iNGT0B4Q803/k>`10@400@T9204U9B@1>CTh0DE5A03`l?00m?Cd0?clo0492@P0h>3P0?3`l
0410@00o?cl0>c/k03lo?`10@400?clo0P0k>c/203lo?`040410@011@D40@T920410@0<0?Shn00d0
>SXj03dm?@0o?cl0?3`l04Y:BP1;Bd/0MWIf05QHF00n?Sh0>CTi0492@P0g=cL0>SXj0080?Shn00H0
?Cdm03`l?00m?Cd0>c/k03`l?00n?Sh203/k>`<0?3`l00D0>SXj03dm?@0o?cl0?clo0451@@0303`l
?00303Ph>00k>c/0?Cdm0080?clo00`0?Shn03dm?@0o?cl0@41003hn?P0m?Cd0>CTi03`l?00m?Cd0
?Shn03dm?@10@40203Ph>00803/k>`0h>3P0>CTi03Ph>00i>CT0?clo03/k>`0o?cl203Xj>P80>c/k
00H0?clo03Ti>@0k>c/0>c/k03Xj>P0l?3`20451@@0>03`l?00k>c/0?Cdm0492@P10@400>c/k03hn
?P12@T80>c/k0451@@0n?Sh0>SXj03lo?`0h>3P203dm?@050410@00l?3`0>c/k03lo?`0j>SX00P0k
>c/03@0j>SX0?Cdm03Ph>00g=cL0>CTi03hn?P0j>SX0>3Ph03Ti>@0j>SX0>CTi03/k>`0m?Cd00P0j
>SX203hn?P0603dm?@0j>SX0?3`l03`l?014A4@0?3`l0P0o?cl03010@400>CTi03Ti>@0k>c/0?Shn
03dm?@0n?Sh0?3`l0410@00n?Sh0>CTi03`l?080>SXj00H0>CTi03Xj>P15ADD0CTi>05=CD`1?Cdl2
04M7A`0I04e=C@1;Bd/0CDe=04m?C`16ATH0CTi>05eMG@2:RXX0YJFU08f=S@1iNGT0G5aL05EEE@1I
FET0NWYj08n?S`1hN7P0KFe]08b<S029RHT0MWIf069RHP1OGel0FEUI04I6AP020451@@0603lo?`0n
?Sh0A4A405ADE01PH600J6QX0P1ZJVX0G01/K6`0GUiN05ADE017AdL0@D5104=3@`0n?Sh0?clo04E5
A@1KFe/0KVi^07AdM01`L700M7Ad0861P@24Q8@0MgMg07EeM@2@T900][Jf0<[:bP3;bl/0^[Zj0;6a
/@2j^[X0bLW90=SHf03?cll0];Bd096AT@23Ph<0S8b<09ZJVP2TY:@0[jn_0<O7a`3GemL0f][J0>7Q
h@3Ph>00i>CT0=oOg`3Ph>00gmoO0=KFeP3=cLd0^k^k09bLW028R8P0S8b<08J6QP2EUID0XJ6Q0:VY
Z@2n_[h0`l?30<71`@2a/K40VYZJ09BDU02;Rh/0UYJF0:VYZ@33`l<0emOG0<K6aP2`/;00X:2P0:^[
Z`2d];@0c/k>0=3@d03AdM40f=SH0<W9b@3:b/X0c<c<0<K6aP2EUID0De=C03hn?P10@400?3`l03/k
>`0m?Cd0>c/k03Xj>P0o?cl0?3`l03Xj>P0i>CT0?3`l0P0j>SX02@0k>c/0?Shn03Lg=`0i>CT0@D51
05MGE`1RHV80FUYJ0451@@0203Ti>@0903Lg=`0j>SX0=cLg03De=@0h>3P0<c<c03Hf=P0g=cL0=SHf
0080=CDe01P0=3@d03Lg=`0d=3@0=SHf03De=@0c<c<0=cLg03@d=00j>SX0>CTi055AD@1_Kfl0GUiN
03dm?@17AdL0V9RH0<C4a02YZJT0E5AD03Ti>@10@400>CTi03Hf=P1>CTh=ooooo`004?ooool0201<
C4`0BTY:04U9B@18B4P0BDU904M7A`15ADD0A4A40P16ATH01P15ADD0@d=304Q8B016ATH0ADE504I6
AP80BDU900d0AdM704E5A@15ADD0B4Q804M7A`18B4P0@d=304Q8B014A4@0BDU904];B`17AdL0A4A4
0080ATI600T0ADE50492@P15ADD0@41004=3@`18B4P0@41004e=C@14A4@00`15ADD02014A4@0ATI6
0492@P12@T80A4A404=3@`17AdL0@T920P0o?cl04012@T80A4A403lo?`12@T80@D5103hn?P11@D40
?Cdm0451@@10@400?clo0492@P1<C4`0BDU904a<C016ATH204=3@`1<0492@P0n?Sh0@41004E5A@11
@D40?Cdm04A4A010@400A4A40451@@14A4@0?Shn0410@011@D40CDe=04I6AP1;Bd/0BDU904Y:BP17
AdL0ADE50451@@14A4@0ADE505=CD`1FEUH0J6QX09JFUP2l_;`0`l?30<[:bP36a/H0]KFe0;Rh^02c
/k<0TI6A07UiN@1gMgL0Ti>C07]kN`1UIFD0GUiN06YZJP1hN7P0Ogmo09JFUP2YZJT0][Jf0:6QX@20
P800TY:B09bLW021PH40E5AD04=3@`0j>SX0?Cdm0451@@17AdL0>c/k03dm?@0l?3`0@D5103dm?@0l
?3`0ADE504A4A019BDT0CDe=05MGE`1HF5P0EeMG0451@@0o?cl0?Shn03dm?@80?Shn0140?Cdm03`l
?018B4P0BTY:055AD@1=CDd0FEUI06UYJ@1UIFD0FEUI04i>CP0l?3`0>c/k03`l?00j>SX0?Cdm03hn
?P0203dm?@<0?3`l0`0k>c/0200o?cl0?3`l03dm?@0l?3`0?Cdm03Xj>P0l?3`0?clo0`0k>c/02P0o
?cl0@41004=3@`11@D40@4100492@P10@400?Cdm03hn?P10@40203dm?@0903Xj>P0n?Sh0>SXj03/k
>`0i>CT0>c/k03lo?`0l?3`0>SXj0080?Shn0280>CTi03Ph>00k>c/0>CTi03`l?010@400@T9203Xj
>P0l?3`0>SXj03hn?P0m?Cd0@41004=3@`0m?Cd0?Shn0492@P0o?cl0>c/k03Ti>@10@400A4A403Ti
>@0n?Sh0?3`l03Ph>00j>SX0=CDe03Ti>@0j>SX0?Cdm03lo?`0l?3`0?Cdm0P0j>SX00`0i>CT0>3Ph
03Lg=`0203/k>`0603Lg=`0j>SX0>SXj03`l?00k>c/0=cLg0P0j>SX02P0k>c/0>CTi03hn?P0j>SX0
>c/k03hn?P0i>CT0?3`l0410@00n?Sh303/k>`0E03Xj>P0k>c/0>c/k03Xj>P0k>c/0>SXj03`l?010
@400?Cdm03hn?P0k>c/0@T9203/k>`0o?cl0>SXj03hn?P17AdL0?Shn03Ph>00j>SX0?3`l0080?clo
00`0@T9203`l?018B4P0IFEU05mOG`1]KFd0OWin07IfMP1`L700JFUY05EEE@1>CTh205=CD`0904e=
C@1OGel0QHF509ZJVP2>SXh0Jf][04Q8B010@400?3`l0080?Cdm02<0>c/k04A4A01KFe/0K6a/069R
HP1QHF40H61P04e=C@0o?cl0?Shn0410@00o?cl0AdM704];B`1<C4`0@T920451@@0n?Sh0Cdm?05mO
G`1_Kfl0TY:B0;>c/`2n_[h0`l?30:JVYP2BTY80Vi^K08n?S`1jNWX0OWin08Z:RP28R8P0V9RH0:ZZ
ZP020;fm_@0C0:ZZZP2VYZH0/K6a0<;2`P2b/[80XJ6Q09bLW02OWil0VIVI0:VYZ@2[Zj/0ZJVY0:JV
YP2IVIT0RHV9079bLP1]KFd0Kfm_07QhN00206i^KP0C07EeM@2?Shl0]KFe0<O7a`3?cll0dm?C0=WI
f@3Kfm/0eMGE0=7Ad@3>c/h0bLW90<G5a@2j^[X0a/K60=OGe`3IfMT0cLg=0:NWY`0209fMW@0D0<71
`@3Hf=P0gMgM0=KFeP39bLT0cLg=0;Fe]@2JVYX0U9BD0:f][@2m_Kd0UYJF0861P@2GUiL0OWin05=C
D`1JFUX0Kfm_05MGE`0o?cl203hn?P0=0451@@1MGEd0MGEe04m?C`0h>3P0@T9208B4Q02/[:`0MWIf
05]KF`0n?Sh0>3Ph03Hf=P0203Ti>@0303Lg=`0h>3P0=cLg0080>SXj00D0>3Ph03Lg=`0f=SH0=3@d
03De=@0203Lg=`0E03Ti>@0k>c/0>c/k03Ph>012@T80@D5103Ti>@0n?Sh0=CDe05=CD`1gMgL0LG5a
09RHV01RHV80?Shn03Ph>00j>SX0>c/k03Ph>00i>CT0Cdm?00gooooo000@ooooo`0404Y:BP18B4P0
BDU904Q8B080BDU900P0AdM704I6AP18B4P0ATI604M7A`15ADD0ATI604E5A@80ATI61014A4@01@16
ATH0B4Q804E5A@1:BTX0AdM70080ADE500@0ATI604Y:BP14A4@0A4A40P12@T802@17AdL0ADE504Q8
B019BDT0ADE504A4A012@T80ADE504M7A`0204Q8B00:04U9B@1>CTh0ATI60451@@12@T80D51@04=3
@`0m?Cd0@D510410@080@T9200@0@D5103lo?`10@400?clo0`0n?Sh20451@@0;03lo?`14A4@0ADE5
04=3@`16ATH0AdM703lo?`0n?Sh0@41004=3@`0o?cl00P0m?Cd02P0l?3`0@T9203/k>`0o?cl0A4A4
03lo?`13@d<0BDU904Y:BP17AdL203`l?00Z03lo?`11@D40@D510410@00m?Cd0?clo0451@@19BDT0
AdM704a<C01:BTX0CDe=05EEE@1RHV80Jf][07IfMP1jNWX0OWin08n?S`2LW9`0ZJVY0<S8b030`<00
Z:RX09:BTP2TY:@0_;bl0<[:bP3Hf=P0fm_K0=WIf@3Bd]80]KFe0;Rh^02g]kL0YZJV08R8R01?Cdl0
?Cdm03Ti>@11@D40A4A40P10@400;01ADE40GEeM06][J`22PX80ZZZZ0;2`/02_[jl0XJ6Q09ZJVP2K
Vi/0QXJ604];B`12@T80@D5104e=C@1VIVH0J6QX07=cL`2<S8`0/;2`0;^k^`2g]kL0[Jf]0::RXP2o
_kl0S8b<04U9B@10@400?3`l03hn?P11@D40@T9203dm?@0l?3`0?Cdm03/k>`0l?3`0?Cdm03`l?00i
>CT0?Cdm0410@00m?Cd0?Shn0P11@D401`10@400>c/k03dm?@0n?Sh0>c/k0451@@0j>SX00P0o?cl0
2011@D40ATI604=3@`0o?cl0?Cdm03hn?P12@T80?clo0P0i>CT00`0l?3`0?clo0410@00203hn?P0;
03lo?`0m?Cd0>c/k03dm?@0k>c/0>CTi03`l?00k>c/0>CTi03dm?@0o?cl0100n?Sh01`0l?3`0ADE5
04A4A00o?cl0>CTi03/k>`0m?Cd00P0j>SX06P0k>c/0?3`l03/k>`0l?3`0>CTi03`l?00m?Cd0?Shn
03dm?@0n?Sh0?Cdm03Xj>P0m?Cd0?Shn03/k>`0o?cl0@41003hn?P0j>SX0>CTi03Lg=`0k>c/0>SXj
03Lg=`0k>c/0?3`l0P0j>SX203`l?00B03Xj>P0k>c/0>SXj03hn?P0l?3`0>c/k03Xj>P0f=SH0>c/k
0451@@0k>c/0?clo03dm?@0k>c/0@41003dm?@0l?3`0>3Ph0P0g=cL0<P0j>SX0>3Ph03`l?00l?3`0
>c/k03lo?`0m?Cd0?clo03dm?@10@400@d=303Xj>P0k>c/0@D5103`l?00i>CT0?clo04A4A01?Cdl0
MGEe06YZJP1NGUh0GEeM04m?C`14A4@0@41003/k>`0n?Sh0@T9204M7A`1HF5P0PH6107alO01TI6@0
Fe]K04i>CP0k>c/0?clo0410@00m?Cd0@41004=3@`11@D40CDe=05MGE`1ADE40?Shn03Ph>00o?cl0
@D510P0n?Sh08@1EEED0OGem08F5Q@1eMGD0H61P05mOG`1RHV80De=C07]kN`2/[:`0_;bl0<?3``2/
[:`0R8R806e]K@1UIFD0H61P07QhN02;Rh/0X:2P0;Bd]02c/k<0WIfM08V9R@1gMgL0MWIf069RHP1G
EeL0Cdm?059BDP1CDe<0Bd];04A4A00304E5A@80A4A400l0DE5A05]KF`1LG5`0H61P07YjNP2GUiL0
]KFe0<k>cP3Bd]80dM7A0=;BdP3De=@0bl_;0;Ng]`2SXj<00P2ATI403@22PX80M7Ad07moO`1gMgL0
N7Qh08:2PP2KVi/0[jn_0<g=c@3Ph>00g=cL0=SHf03Lg=`00P3IfMT0?`3Cdm<0fMWI0=KFeP3;bl/0
dM7A0<C4a033`l<0d=3@0=gMg@3Ti>@0gMgM0=GEe@3Kfm/0dM7A0;Ng]`2k^k/0aLG50:JVYP2:RXX0
Rh^;0;6a/@2k^k/0Rh^;04e=C@14A4@0D51@05]KF`1nOWh0H61P03lo?`0l?3`0=cLg03Ph>00e=CD0
<c<c0410@01gMgL0JVYZ04e=C@0i>CT0>SXj03Ph>00g=cL0>CTi03Xj>P0i>CT0=cLg03/k>`0g=cL0
>CTi03/k>`0h>3P0?Cdm04A4A01KFe/0?3`l0410@013@d<0ATI603Lg=`0h>3P0>CTi03Lg=`0203Hf
=P<0>CTi00<0=CDeooooooooool02oooool0013ooooo1019BDT03@16ATH0AdM704U9B@15ADD0A4A4
04U9B@1;Bd/0B4Q804A4A015ADD0B4Q804];B`18B4P00P19BDT02@1:BTX0ADE504E5A@16ATH0AdM7
04I6AP13@d<0BTY:04E5A@0204I6AP0404Q8B015ADD0BTY:04M7A`80@d=300P0B4Q804U9B@12@T80
@d=304E5A@13@d<0A4A404=3@`80A4A400D0ATI604E5A@12@T80@d=304M7A`0204=3@`80@D5100<0
?clo04=3@`0o?cl00P0o?cl03`10@400A4A40451@@10@400@D5103hn?P17AdL0BDU904=3@`0m?Cd0
@d=303hn?P13@d<0BTY:04Q8B00203hn?P0803lo?`0k>c/0>SXj04E5A@1CDe<0CDe=04a<C012@T82
03lo?`0C0410@00m?Cd0>SXj03lo?`10@400ADE504I6AP0m?Cd0>c/k0451@@1;Bd/0C4a<04E5A@1<
C4`0BTY:04A4A017AdL0?clo04A4A00204=3@`0d04a<C01MGEd0HV9R06MWI`1NGUh0De=C04];B`1U
IFD0[Jf]0<30`03=cLd0e=CD0=KFeP2PX:00J6QX04m?C`1=CDd0De=C05ADE01PH600GUiN05]KF`1T
I6@0IVIV06UYJ@2?Shl0][Jf09bLW02[Zj/0_Kfm0=cLg03IfMT0cLg=0:6QX@1iNGT0KFe]05YJFP1`
L700O7al09ZJVP35aLD0h>3P0=?Cd`3IfMT0g]kN0=KFeP2f][H0SHf=06IVIP1CDe<0CTi>03lo?`80
?Cdm00<0@T920410@00l?3`00`0l?3`01@10@400?Shn03Xj>P0m?Cd0@4100080@D510200@d=304A4
A013@d<0C4a<05EEE@1CDe<0AdM705QHF01WIfL0MgMg08N7Q`1^KVh0DE5A0492@P15ADD0@D5103/k
>`0l?3`0@D5104=3@`0n?Sh0?clo0492@P18B4P0ADE503`l?011@D40BDU90451@@10@400@D510410
@080>c/k00X0?clo03Xj>P0m?Cd0>3Ph03/k>`0n?Sh0@41003Xj>P0o?cl0@4100P11@D401012@T80
?clo03/k>`0k>c/203dm?@0>03Ti>@0g=cL0>CTi03Ti>@0k>c/0>SXj03`l?00m?Cd0?3`l03/k>`0m
?Cd0>c/k03hn?P10@40203`l?00303dm?@12@T80?Shn0080>CTi00T0?Shn0451@@0m?Cd0>SXj03lo
?`0l?3`0?clo03dm?@0l?3`00P0n?Sh02P0o?cl0?3`l03dm?@0k>c/0>SXj03hn?P0l?3`0?clo03`l
?00j>SX203dm?@0903`l?014A4@0@41003`l?00j>SX0>3Ph03Ti>@10@400?3`l0080>c/k00T0?Cdm
03Xj>P0j>SX0>3Ph03lo?`0m?Cd0?3`l03/k>`0j>SX00P0o?cl01@13@d<0CDe=04U9B@1:BTX0B4Q8
0080?clo0200?Cdm03`l?00i>CT0>SXj04a<C01OGel0Kfm_065QH@1LG5`0FEUI04U9B@12@T80@D51
03hn?P0m?Cd0@41003dm?@0n?Sh0?Cdm03Xj>P0m?Cd0>SXj03Hf=P0k>c/0?clo0451@@1ADE40EUIF
05QHF01RHV80De=C06][J`80MWIf00`0QHF509fMW@1kNg/0Lg=c08J6QP2>SXh0Ng]k071`L01hN7P0
O7al0861P@25QHD208B4Q00<07IfMP1/K6`0EUIF04a<C012@T80?clo03`l?00m?Cd0@D5103hn?P11
@D40@4100P14A4@0201RHV80Rh^;09nOW`2YZJT0[jn_0;>c/`38b<P0aLG50P2f][H05P2b/[80];Bd
0:>SX`2;Rh/0M7Ad06][J`1UIFD0I6AT079bLP20P800QHF509NGU`2/[:`0^[Zj0<[:bP3Cdm<0a/K6
0<;2`P2o_kl0^k^k0;Bd]033`l<20=3@d080eMGE0P3Bd]802P3MgMd0hN7Q0=_Kf`3<c<`0a/K60;Fe
]@2[Zj/0`/;20=7Ad@3IfMT30>;RhP0T0=;BdP2ZZZX0^[Zj0=KFeP3Ng]h0g=cL0=KFeP3Ng]h0c/k>
0;Jf]P2TY:@0QHF508J6QP1gMgL0NWYj07IfMP1/K6`0F5QH04=3@`0j>SX0>3Ph03Ti>@0n?Sh0Kfm_
04Y:BP0l?3`0>3Ph03Hf=P0h>3P0@d=304];B`16ATH0>c/k03dm?@0i>CT0>SXj0P0h>3P0200g=cL0
>SXj059BDP16ATH0?3`l03Lg=`0h>3P0=3@d0P0g=cL0200b<S80>3Ph03Lg=`0i>CT0=cLg03Ph>00f
=SH0>3Ph3Oooool0013ooooo00T0Cdm?04e=C@1<C4`0CDe=04Q8B01;Bd/0ATI6059BDP1KFe/00P17
AdL01@13@d<0B4Q804Y:BP1:BTX0CDe=0080ATI600/0B4Q804];B`14A4@0@T9204A4A013@d<0ADE5
04Q8B017AdL0B4Q804U9B@0204M7A`0404E5A@1:BTX0ADE504M7A`80@T9200@0A4A404I6AP12@T80
@T920P14A4@00`10@400@T9204=3@`0204=3@`0804I6AP0o?cl0AdM704E5A@13@d<0@D5104I6AP10
@4020451@@0M03lo?`13@d<0@T9204E5A@11@D40?clo0451@@14A4@0B4Q804U9B@13@d<0?3`l0451
@@0m?Cd0@d=30451@@0m?Cd0?clo0451@@13@d<0?clo04I6AP1@D500De=C04A4A016ATH0@d=30492
@P0o?cl00P0l?3`0300m?Cd0?Shn03hn?P12@T80@D5103`l?00k>c/0?Cdm03hn?P0o?cl0>c/k03lo
?`80@41000P0@T920410@00n?Sh0?Cdm0451@@10@400@T920410@0<0ATI602D0@d=304I6AP1eMGD0
PX:209NGU`2<S8`0Rh^;08N7Q`1iNGT0Ogmo06i^KP1OGel0DE5A09JFUP33`l<0[:b/0<G5a@2l_;`0
a/K60=_Kf`2k^k/0Ti>C0:BTY033`l<0e]KF0=gMg@3Kfm/0fMWI0=gMg@3=cLd0[:b/0<G5a@3Jf]X0
e=CD0>OWi`3Shn<0f=SH0080bLW90340][Jf09jNWP2=SHd0RHV906][J`12@T80?Shn0451@@0o?cl0
Cdm?04i>CP1MGEd0FEUI04=3@`0n?Sh0?clo0451@@0m?Cd0@D5103`l?010@400A4A404=3@`0n?Sh0
?Cdm04I6AP1?Cdl0GEeM07QhN02`/;00cLg=0;Vi^@2:RXX0G5aL04Q8B012@T80@d=304Q8B01@D500
LG5a08Z:RP1mOGd0MGEe06e]K@1MGEd0B4Q803Xj>P0l?3`0?Cdm0080@d=300D0@D5103hn?P0n?Sh0
?Shn03Ph>00303hn?P80>SXj00`0?3`l0410@00h>3P0>c/k0410@00l?3`0>c/k03`l?00m?Cd0@D51
03/k>`0j>SX203/k>`0903Lg=`0h>3P0>SXj03dm?@0k>c/0?3`l03/k>`0j>SX0>CTi0080>SXj00L0
?3`l03dm?@0j>SX0?Shn03`l?00o?cl0?Shn0080>SXj00h0@D5103lo?`0m?Cd0?Cdm03lo?`0f=SH0
>CTi03Ph>00e=CD0>SXj0410@00l?3`0>SXj0410@080?3`l01L0?clo03Ph>00g=cL0=cLg03Xj>P0h
>3P0>c/k03`l?011@D40?Shn03/k>`0m?Cd0>c/k03`l?00m?Cd0>c/k03`l?00m?Cd0?Shn03Xj>P0h
>3P0=cLg03Ph>00303Xj>P0403lo?`1=CDd0Bd];03dm?@80@41000<0@D5103dm?@0g=cL00P0l?3`0
2`0o?cl0?3`l04U9B@1UIFD0MWIf05iNGP1;Bd/0@D5103Xj>P0h>3P0?Cdm0080@D510P0l?3`0400o
?cl0@D5103dm?@0k>c/0=SHf03`l?00n?Sh0@T9205EEE@26QXH0YjNW08n?S`2ATI40RXZ:08^;R`2Y
ZJT209NGU`0=09>CT`23Ph<0MGEe08N7Q`2/[:`0VYZJ06][J`1/K6`0Kfm_05UIF@1GEeL0De=C04];
B`0203dm?@0303`l?00i>CT0=3@d0080@41000@0@T9203Xj>P0l?3`0@d=30P1=CDd0B01_Kfl0SHf=
0:RXZ038b<P0fMWI0=_Kf`3WinL0iNGU0>7Qh@33`l<0YZJV0861P@1SHf<0FUYJ05ADE01PH600NGUi
09:BTP2/[:`0^;Rh0<O7a`3?cll0fm_K0=WIf@39bLT0a/K60<C4a02g]kL0XZ:R09NGU`1hN7P0Hf=S
05QHF01PH600NWYj07MgM`20P800OWin07UiN@2<S8`0ZJVY0;Zj^P3AdM40d];B0=?Cd`3Lg=`0e=CD
0=7Ad@2j^[X0][Jf0<K6aP3Ogml0g]kN0<W9b@1_Kfl0Jf][09FEU@2RXZ80Xj>S0<;2`P3>c/h0e=CD
0=3@d03Jf]X0b/[:09nOW`2`/;00dM7A0<?3``2GUiL0FUYJ03hn?P80>3Ph0100?3`l03@d=00m?Cd0
=SHf03Ti>@0e=CD0B4Q805]KF`1_Kfl0CDe=03lo?`13@d<0BDU903/k>`0g=cL0>c/k0P0f=SH04@14
A4@0>c/k03<c<`0b<S80=CDe03@d=00e=CD0=3@d03Hf=P0a<C40=CDe03Hf=P0i>CT0<c<c03Hf=P0l
?3`0BDU900gooooo000@ooooo`0:04i>CP1:BTX0BDU904Y:BP14A4@0AdM704A4A01BDU80HF5Q04Q8
B080A4A40P17AdL204I6AP0704A4A016ATH0B4Q804];B`17AdL0@d=304A4A00204E5A@0A04U9B@13
@d<0AdM704];B`14A4@0ADE504A4A017AdL0A4A404];B`16ATH0?clo04=3@`1:BTX0@T920451@@12
@T800P11@D407@13@d<0AdM704=3@`12@T80@d=304M7A`10@400?Shn0451@@12@T80@d=303lo?`0l
?3`0@D5103dm?@16ATH0@T9204A4A010@400?Shn03`l?012@T80@41003lo?`0n?Sh0?3`l0492@P0m
?Cd0?clo00<0@41000P0>c/k0451@@10@400@T9203hn?P0o?cl0?Cdm03lo?`80?Cdm00L0?3`l03Xj
>P0m?Cd0@41003dm?@0j>SX0>c/k0080>CTi00D0>SXj03lo?`12@T80?Cdm03`l?00203/k>`0:03dm
?@0n?Sh0?Cdm0410@00n?Sh0?clo0451@@0k>c/0@41003lo?`80?Shn01h0@D5104=3@`1<C4`0FUYJ
06EUI@1?Cdl0D51@05mOG`1YJFT0MgMg069RHP1WIfL0K6a/07inOP2BTY80Shn?0:BTY02n_[h0`/;2
0<g=c@3;bl/0a<C40<G5a@3@d=00b/[:0=OGe`3Ph>00fm_K0<c<c030`<020;2`/00?0:f][@33`l<0
fm_K0=oOg`38b<P0YZJV09>CT`26QXH0MgMg06QXJ01BDU80ADE50492@P10@400A4A40080?clo01<0
@D510492@P12@T80?clo0410@014A4@0BTY:04a<C018B4P0@T9204Q8B01=CDd0JFUY07inOP2@T900
[Zj^0;Bd]02i^KT0`<300080dm?C01H0Y:BT07inOP1nOWh0SXj>09FEU@2BTY80ZZZZ0:VYZ@2HV9P0
TI6A06YZJP1=CDd0BTY:04A4A00n?Sh0?Cdm03lo?`0k>c/0>CTi03hn?P10@400?Shn0P0k>c/00`10
@400?3`l03lo?`0203hn?P0603`l?00k>c/0?Shn03hn?P0j>SX0@4100`0n?Sh01@0l?3`0>CTi03Xj
>P0f=SH0>SXj0080?Shn00<0?3`l03/k>`0n?Sh00P0n?Sh06@0k>c/0>CTi03Xj>P0l?3`0>CTi03Lg
=`0i>CT0>SXj03lo?`0n?Sh0?3`l03hn?P0l?3`0>3Ph03Ti>@0k>c/0@41003lo?`0n?Sh0>c/k0410
@00i>CT0>3Ph03/k>`16ATH00P0n?Sh01@11@D40?Shn03hn?P0g=cL0>c/k00<0>SXj00<0?clo03dm
?@0j>SX00P0j>SX0500l?3`0?Cdm03/k>`0l?3`0@41003/k>`0i>CT0?Shn03lo?`0m?Cd0?3`l03Ph
>00o?cl0@4100492@P19BDT0DE5A051@D015ADD0>c/k0`0n?Sh03P0j>SX0?3`l03Ph>00i>CT0>SXj
03`l?015ADD0Cdm?04a<C011@D40?3`l03dm?@11@D40>SXj0P0k>c/00`0n?Sh0>SXj03lo?`0203/k
>`0>03hn?P1;Bd/0CDe=05=CD`18B4P0IVIV09BDU02j^[X0/;2`08:2PP24Q8@0QXJ608F5Q@2<S8`2
07inOP0;06a/K01IFET0I6AT08:2PP2RXZ80RXZ:06UYJ@1ADE40AdM70410@00o?cl00P0l?3`00`0n
?Sh0>c/k03dm?@0203Xj>P80>c/k02@0>SXj04U9B@1aLG40X:2P0;fm_@30`<00_kno0<?3``2o_kl0
][Jf0;Vi^@3@d=00fm_K0>?Sh`3EeMD0_[jn0;>c/`2OWil0XZ:R0:>SX`2TY:@0_Kfm0<G5a@3:b/X0
f=SH0<G5a@2b/[80RXZ:08>3P`1mOGd0LW9b061PH01EEED0CDe=04I6AP15ADD204A4A00W04];B`1D
E5@0HV9R06i^KP1YJFT0N7Qh09JFUP2d];@0bLW90<k>cP3Fe]H0emOG0=kNgP3Ogml0g=cL0=KFeP39
bLT0];Bd0:VYZ@2`/;00`L710<_;b`2KVi/0OWin06e]K@1OGel0EEEE06IVIP1cLg<0MgMg08>3P`29
RHT0W9bL0:2PX02>SXh0XZ:R07alO01SHf<0@4100080>CTi0P0k>c/0200h>3P0>SXj03Ph>00g=cL0
>CTi065QH@1>CTh0BDU90P0i>CT03`0h>3P0>CTi03Lg=`0j>SX0?Cdm03Lg=`0j>SX0@d=303Xj>P0k
>c/0>SXj03Ti>@0h>3P0=cLg03De=@0203Ph>00703<c<`0g=cL0>3Ph03Ph>00k>c/0AdM7096AT@0=
ooooo`004?ooool01@1<C4`0CDe=04];B`19BDT0ATI60080AdM700T0A4A404I6AP17AdL0B4Q804M7
A`19BDT0ADE504=3@`12@T800`17AdL01P16ATH0ADE504E5A@16ATH0B4Q804M7A`80ADE500D0@410
04Q8B015ADD0AdM704E5A@0204I6AP0L04Q8B014A4@0ADE504Y:BP18B4P0AdM704=3@`11@D40@T92
0451@@0n?Sh0@D5104=3@`10@400?3`l03hn?P0o?cl0@d=30451@@10@400>c/k0410@012@T80@410
03/k>`0n?Sh0@T920410@0<0?clo00P0?Cdm0451@@16ATH0@d=30410@00k>c/0?3`l0492@P80?3`l
00<0?clo03hn?P11@D400P0o?cl0100l?3`0?Shn03/k>`0o?cl203`l?00503dm?@0l?3`0?Cdm0451
@@0o?cl00P0n?Sh08`0k>c/0@d=303lo?`0k>c/0?Cdm03Ti>@0l?3`0>SXj03`l?00n?Sh0?clo03dm
?@0o?cl0ADE503Xj>P0n?Sh0>c/k03`l?00o?cl0@41003lo?`14A4@0?Shn04U9B@1HF5P0EeMG04e=
C@1;Bd/0EEEE059BDP16ATH0@41004M7A`1?Cdl0EeMG0080CTi>00<0CDe=04Y:BP1:BTX00P1GEeL0
?`1EEED0GUiN05YJFP1VIVH0MgMg08V9R@2FUYH0YJFU0<?3``3=cLd0gMgM0=CDe02l_;`0][Jf0:j^
[P1TI6@0ADE504e=C@16ATH0A4A40410@00o?cl0@D510410@00o?cl0A4A404E5A@1;Bd/0DU9B055A
D@1LG5`0MGEe09RHV032`/80d];B0<o?c`37alL0/K6a0;Fe]@36a/H0c<c<0=3@d03=cLd0`/;20;Bd
]036a/H0d=3@0=_Kf`3GemL0b<S80:n_[`2EUID0Q8B408b<S02DU9@0ZJVY08B4Q01KFe/0CTi>04=3
@`0o?cl0?Shn03lo?`020410@080?clo00@0?Cdm0492@P14A4@0@D510P0n?Sh02@10@400?clo03lo
?`13@d<0BTY:061PH01/K6`0Kfm_04M7A`0203hn?P0303Xj>P0o?cl0?clo0080?Cdm00T0?Shn0410
@018B4P0P82005QHF00o?cl0>c/k0410@00n?Sh00P0l?3`203Xj>P@0>CTi00D0>SXj03hn?P10@400
>SXj03/k>`0303`l?00D03/k>`0n?Sh0?Cdm03`l?00h>3P0@T9204m?C`10@400>c/k03`l?00m?Cd0
>c/k03`l?010@400>c/k03Xj>P0m?Cd0?3`l03Xj>P0m?Cd303/k>`0?03Xj>P0m?Cd0?clo03Xj>P0i
>CT0>SXj03`l?00i>CT0>SXj0410@00o?cl0>SXj03lo?`11@D40A4A40080Bd];00X0@T9204M7A`13
@d<0@41003hn?P11@D40>SXj03/k>`0j>SX0?Cdm0P0j>SX01P0h>3P0>CTi03Xj>P0k>c/0>SXj03dm
?@80>SXj00@0?Cdm03hn?P0k>c/0>CTi0P0m?Cd01@0h>3P0?clo04A4A01NGUh0HF5Q0080BTY:01D0
EeMG06][J`2=SHd0Ogmo06i^KP1VIVH0MgMg07YjNP1/K6`0F5QH05MGE`1=CDd0@T9203/k>`0n?Sh0
DE5A051@D014A4@0@41003Xj>P0k>c/00P0l?3`203hn?P0304=3@`15ADD0B4Q80080@d=307D0@D51
04Y:BP1]KFd0YZJV0<k>cP34a<@0WinO07moO`1WIfL0J6QX08b<S02][Jd0^[Zj0;jn_P37alL0cLg=
0<[:bP3AdM40e]KF0=3@d03>c/h0cLg=0;Rh^02g]kL0YjNW09nOW`2KVi/0Lg=c055AD@11@D40@d=3
04U9B@1?Cdl0EEEE05eMG@1SHf<0MgMg07emO@1oOgl0SXj>0;6a/@2n_[h0/K6a0;:b/P2i^KT0alO7
0<o?c`3EeMD0d=3@0<S8b02k^k/0_[jn0;Vi^@2c/k<0XJ6Q0:ZZZP32`/80[Zj^0:2PX02VYZH0Zj^[
0:JVYP2LW9`0XJ6Q0<W9b@3EeMD0^KVi0:RXZ02PX:00UIFE07IfMP1BDU80AdM705=CD`1]KFd0Bd];
0492@P0k>c/0?Cdm03/k>`0m?Cd0>c/k03Xj>P0h>3P0>SXj03/k>`0o?cl0>CTi03lo?`0h>3P0@410
04E5A@0k>c/0>SXj0492@P1:BTX0F5QH055AD@0i>CT0=3@d03Hf=P0k>c/0>3Ph03Ti>@0g=cL0>c/k
03Ti>@0g=cL0>SXj03Lg=`0i>CT0>SXj03Lg=`0o?cl0KVi^0:BTY01nOWh03Oooool0013ooooo00@0
C4a<04e=C@1<C4`0Bd];0`18B4P204I6AP030451@@18B4P0ADE50080ADE501P0AdM704=3@`17AdL0
A4A404I6AP14A4@0AdM704U9B@14A4@0ATI604M7A`14A4@0@d=304Q8B014A4@0ADE504M7A`13@d<0
ATI604A4A015ADD0@d=304I6AP15ADD204Q8B00C04A4A016ATH0AdM704A4A017AdL0?clo04M7A`10
@400?clo04=3@`0o?cl0?Shn0410@00o?cl0?Shn0451@@10@400@T9203dm?@0203lo?`@0?Shn00P0
>c/k03lo?`10@400?clo0451@@0m?Cd0?3`l03hn?P80>SXj00/0?Shn03/k>`0o?cl0?Shn0451@@0k
>c/0?3`l03hn?P14A4@0?Cdm03`l?00203hn?P030410@013@d<0?Shn0080@D5100D0?3`l03hn?P10
@400?3`l03Xj>P0203dm?@0D03`l?00m?Cd0?3`l03hn?P0j>SX0?clo04=3@`0j>SX0?Cdm03Ti>@10
@400@D5103`l?00k>c/0A4A403dm?@14A4@0BTY:04I6AP13@d<203dm?@0;03lo?`12@T80@41004I6
AP10@400@d=304I6AP18B4P0@4100492@P18B4P00P13@d<0:@12@T80ATI604M7A`1=CDd0BDU904a<
C01DE5@0GemO05QHF01YJFT0Ogmo0:>SX`2YZJT0[:b/08R8R01kNg/0D51@05QHF01eMGD0Ogmo08J6
QP28R8P0T92@08f=S@2@T900UiNG0;:b/P3EeMD0emOG0=CDe03Cdm<0g]kN0>[ZjP3Vi^H0hn?S0=oO
g`3Ng]h0iNGU0>KViP3GemL0b<S80080][Jf00l0/[:b0:^[Z`2UYJD0R8R808F5Q@22PX80IfMW04e=
C@18B4P0@T920451@@13@d<0BTY:04E5A@10@4000P12@T805`0m?Cd0@D510451@@0o?cl0?Cdm03lo
?`10@400E5AD07=cL`1jNWX0JFUY06=SH`1XJ6P0L71`08j>SP2LW9`0RXZ:08N7Q`2>SXh0Kfm_04Q8
B00m?Cd0>c/k0080?Shn02D0@41003lo?`0m?Cd0?clo04E5A@17AdL0E5AD05IFEP19BDT0?Cdm03/k
>`0l?3`0?Cdm03`l?00i>CT0>SXj03dm?@0k>c/0>SXj03dm?@0k>c/0>3Ph03dm?@11@D40?3`l03dm
?@10@400@d=303hn?P0m?Cd0?3`l0451@@10@400DU9B0::RXP2@T900ADE50080>SXj01`0?3`l03/k
>`0j>SX0>3Ph03/k>`0n?Sh0?clo0410@00i>CT0?clo03`l?00m?Cd0@D510410@00h>3P0?Shn03Ti
>@0l?3`0?Cdm03hn?P0j>SX0>CTi03dm?@0o?cl0@T9205=CD`1BDU80@4100P0j>SX01@0i>CT0?Cdm
03`l?011@D40?Cdm0080>c/k00<0A4A403lo?`0n?Sh01@0m?Cd00`0l?3`0?Cdm0410@00203/k>`0O
03hn?P10@400?3`l03hn?P0o?cl0BDU905=CD`1DE5@0EEEE0820P01dM7@0AdM70451@@1VIVH0OWin
08>3P`1^KVh0IfMW05ADE01=CDd0@T920410@00l?3`0>SXj03Ti>@0j>SX0B4Q804E5A@0o?cl0>SXj
03`l?00203hn?P0>03/k>`10@400>SXj03hn?P0m?Cd0@D5104=3@`1ADE40P82009BDU029RHT0PH61
08b<S02KVi/209ZJVP0C09^KV`23Ph<0Vi^K0;Zj^P30`<00UYJF06e]K@1dM7@0RHV9092@T02=SHd0
WYjN09nOW`2?Shl0Ph>306i^KP1OGel0EEEE04M7A`0204E5A@80?Cdm00/0F5QH07QhN02?Shl0VYZJ
09VIV@2EUID0XJ6Q0;Vi^@2m_Kd0/;2`0:NWY`020:b/[00G09JFUP25QHD0PH6107inOP2?Shl0TI6A
08f=S@2EUID0RHV908b<S02OWil0]KFe0;Zj^P38b<P0fMWI0=oOg`3Ph>00iNGU0>?Sh`3Jf]X0alO7
0;Fe]@3=cLd00P3QhN402`3Ph>00hN7Q0>;RhP3Ph>00bLW909VIV@20P800QhN706i^KP1/K6`0HF5Q
0080@41000T0>c/k03dm?@0m?Cd0?3`l03dm?@11@D40DU9B05]KF`1HF5P00P1IFET0201MGEd0BDU9
03lo?`12@T80?Shn0492@P0i>CT0=cLg0P0j>SX0400i>CT0>SXj03Lg=`0k>c/0?Cdm03Xj>P0g=cL0
>SXj0451@@1YJFT0L71`04I6AP25QHD0W9bL05iNGP0n?Sh=ooooo`004?ooool0201:BTX0CDe=04];
B`1:BTX0B4Q804U9B@16ATH0AdM70P18B4P02`16ATH0B4Q804=3@`16ATH0ADE504A4A012@T80ATI6
04A4A015ADD0EEEE0080BDU90140ADE504U9B@15ADD0@D5105MGE`16ATH0ADE504A4A013@d<0ATI6
04E5A@17AdL0B4Q804M7A`15ADD0A4A404=3@`0204M7A`0304A4A011@D40@T920080@T9200L0ADE5
04Q8B011@D40@4100492@P16ATH0@T920080@D5100<0@4100451@@13@d<00P11@D401@0l?3`0?clo
03lo?`10@400?3`l0080?Cdm0`0o?cl0200n?Sh0@T9203hn?P0l?3`0>c/k03Xj>P0i>CT0>SXj0P0k
>c/00`0m?Cd0@D510410@00203hn?P80?3`l00H0?clo03dm?@0l?3`0?3`l03hn?P15ADD20410@00A
03dm?@0j>SX0>SXj03hn?P0k>c/0?clo03Xj>P0m?Cd0>c/k03hn?P0o?cl0>c/k03Xj>P0m?Cd0>c/k
03Lg=`0j>SX00P0m?Cd00`0n?Sh0?Cdm03dm?@0203/k>`0<03dm?@0k>c/0?Shn03lo?`0n?Sh0>SXj
0451@@13@d<0A4A40451@@0j>SX0?Shn0P0k>c/0100i>CT0?Shn03hn?P0m?Cd204A4A01@051@D01I
FET0EUIF04i>CP17AdL0@D5104Q8B01DE5@0G5aL06i^KP1fMWH0Lg=c07emO@2@T900Y:BT09:BTP2P
X:00YZJV09BDU02][Jd0][Jf0=7Ad@3Ph>00c<c<0<71`@3>c/h0fMWI0<S8b02n_[h0_;bl0;Fe]@3:
b/X0d];B0=SHf03GemL0clo?0<O7a`2SXj<0QhN706a/K01FEUH0BTY:04U9B@12@T80@4100492@P0n
?Sh0?clo03hn?P19BDT0@d=303hn?P12@T80A4A40451@@0m?Cd0?Shn0451@@1HF5P0JFUY06=SH`1F
EUH0Hf=S07QhN024Q8@0Zj^[0=?Cd`3De=@0`/;20:f][@1gMgL0FUYJ04Y:BP1<C4`0B4Q805EEE@1/
K6`0IfMW05]KF`1`L70209:BTP0607]kN`1OGel0C4a<04e=C@14A4@0@4100P0o?cl01@0m?Cd0ADE5
03lo?`0m?Cd0>SXj0080>c/k00P0@D5103hn?P10@400@41004A4A00o?cl0>c/k03Ph>080?3`l00<0
?Cdm0451@@12@T800P13@d<02@1LG5`0/;2`0:BTY01@D500>SXj03Lg=`0l?3`0?Cdm03`l?00203Xj
>P80>c/k00T0>CTi03dm?@11@D40@41003`l?014A4@0@41003`l?00i>CT00P0k>c/01@0i>CT0?3`l
0451@@0l?3`0>c/k0080@41000<0BTY:0451@@0j>SX00P0m?Cd02P0n?Sh0>SXj03hn?P0o?cl0@410
03dm?@0n?Sh0?3`l0410@00o?cl30410@00703`l?00n?Sh0?Cdm03Ti>@0l?3`0>SXj03Ti>@0203lo
?`0A03/k>`0n?Sh0B4Q805IFEP1`L700FEUI04i>CP1MGEd0Lg=c05UIF@0o?cl0D51@06][J`20P800
IfMW05]KF`1@D5000P0m?Cd03P0n?Sh0>c/k0492@P0h>3P0@4100451@@18B4P0?3`l03hn?P0l?3`0
?Cdm0410@012@T80@d=30P0n?Sh01@13@d<0ATI604];B`1GEeL0M7Ad0080UIFE02/0K6a/061PH01e
MGD0VIVI09^KV`2e]KD0bl_;0;no_`2XZ:P0VIVI08Z:RP2;Rh/0T92@09jNWP2OWil0SXj>07alO01d
M7@0HV9R06=SH`1RHV80Hf=S06m_K`25QHD0Hf=S055AD@1<C4`0@D5104=3@`19BDT0C4a<05ADE01L
G5`0Cdm?05YJFP1UIFD0LG5a07AdM02@T900Xj>S0:b/[030`<00`l?30080_Kfm00`0dm?C0=_Kf`3E
eMD0f=SH0=3@d037alL0d];B0<k>cP3=cLd0e=CD0=OGe`3Jf]X20=oOg`0S0>3Ph03Jf]X0emOG0=OG
e`3Fe]H0d=3@0<G5a@32`/80_;bl0<71`@36a/H0d=3@0=gMg@3Shn<0h^;R0=kNgP3Ph>00gmoO0=7A
d@2l_;`0XZ:R08j>SP2;Rh/0NWYj065QH@1DE5@0[:b/0<o?c`3Hf=P0`<300:ZZZP2;Rh/0SXj>069R
HP0o?cl00P0m?Cd0100n?Sh0>3Ph03Xj>P0i>CT303Xj>P0>0451@@0l?3`0>3Ph03dm?@15ADD0EEEE
08b<S02[Zj/0IVIV04A4A01OGel0N7Qh08J6QP2ATI4=ooooo`004?ooool00`1;Bd/0C4a<04U9B@03
04Q8B0<0ADE500@0A4A404I6AP16ATH0ADE50P16ATH204E5A@0504A4A012@T80@D5104Q8B012@T80
0P15ADD304M7A`0804A4A018B4P0A4A404=3@`12@T80@D5104A4A019BDT204Q8B0040492@P18B4P0
A4A404=3@`80@T9200H0@d=30492@P1;Bd/0@D510492@P17AdL204=3@`040451@@0m?Cd0@T920410
@080?Shn0180@41003/k>`0n?Sh0?3`l0451@@15ADD0?clo03dm?@0n?Sh0@T9203Xj>P14A4@0@T92
0451@@0n?Sh0@D5103`l?00k>c/303`l?00603lo?`0n?Sh0>c/k03lo?`0m?Cd0>SXj0P0l?3`01P0n
?Sh0@4100410@012@T80@41003/k>`80?Cdm00/0@d=30492@P0m?Cd0>SXj03`l?00i>CT0?Shn0451
@@0m?Cd0>SXj03dm?@0203/k>`0N03`l?00i>CT0>c/k03Ph>00j>SX0@41003Ph>00l?3`0?Shn03`l
?00j>SX0?Shn03`l?00m?Cd0>CTi03/k>`11@D40@41003Lg=`0j>SX0>c/k03dm?@0j>SX0?Shn03dm
?@0g=cL0>SXj03lo?`11@D40@T920P14A4@204=3@`0603lo?`10@400?clo0451@@0n?Sh0@D510P10
@400C013@d<0AdM704U9B@1CDe<0MGEe08:2PP1kNg/0SHf=08V9R@1gMgL0Lg=c075aL@1kNg/0Ph>3
06ATI01?Cdl0Fe]K06=SH`1RHV80J6QX07emO@2RXZ80/;2`0:ZZZP2g]kL0b/[:0<_;b`2QXJ40QhN7
07EeM@1MGEd0Cdm?0492@P1:BTX0H61P07IfMP1`L700KFe]06IVIP1WIfL0KVi^06][J`1OGel0GEeM
06ATI01^KVh0LG5a07QhN02:RXX0YJFU0;Ng]`2c/k<0]kNg0<o?c`3>c/h0_Kfm0:VYZ@29RHT0MWIf
07YjNP22PX80KVi^04i>CP12@T80@d=30492@P1BDU80WinO0;2`/026QXH0EeMG051@D017AdL0Bd];
04A4A011@D420410@080?Cdm0P0o?cl0200m?Cd0?3`l04=3@`15ADD0?Shn04M7A`1=CDd0@d=30`0o
?cl00`0m?Cd0>c/k0410@00203hn?P0803Ph>00l?3`0?Shn03lo?`1PH600^[Zj0:>SX`1:BTX203dm
?@0803lo?`0k>c/0>c/k04A4A011@D40=cLg03Xj>P0o?cl303`l?080?clo00H0?Shn03dm?@0m?Cd0
@T9203dm?@0k>c/203lo?`0304Q8B01KFe/0GEeM0080A4A402/0>CTi03lo?`0l?3`0A4A404=3@`10
@400?Cdm03/k>`0l?3`0@D5103lo?`0n?Sh0@d=304E5A@0o?cl0@T9204Q8B012@T80?Cdm03lo?`0n
?Sh0?Cdm03`l?00o?cl0?3`l03/k>`0m?Cd0C4a<04];B`1QHF40IfMW04U9B@14A4@0?clo04Y:BP1=
CDd0?clo0492@P1=CDd0D51@04a<C00k>c/0?Shn0080?Cdm00L0?Shn03dm?@0l?3`0?clo03`l?00j
>SX0?Cdm0080>c/k03P0>SXj03Ti>@0k>c/0>SXj03Ph>00g=cL0?Shn04e=C@1FEUH0DU9B04a<C01T
I6@0QHF508f=S@2<S8`0UiNG08b<S02:RXX0QhN707]kN`2QXJ40X:2P08j>SP1lO7`0IFEU061PH01O
Gel0E5AD061PH01bLW80Shn?09nOW`2WYjL0WinO0:2PX022PX80I6AT055AD@17AdL0A4A404E5A@17
AdL0DU9B05MGE`1YJFT0Ph>308b<S02JVYX0T92@09nOW`2^[Zh0[jn_0;Fe]@2k^k/0dm?C0=_Kf`80
h^;R00@0hN7Q0=7Ad@3;bl/0a<C40P3;bl/05@32`/80b/[:0=3@d03Kfm/0f][J0=SHf03@d=00_kno
0:>SX`22PX80L71`06UYJ@1PH600G5aL05iNGP1RHV80NWYj08n?S`2KVi/0]KFe0<W9b@020=_Kf`0J
0>7Qh@3Ti>@0hn?S0=WIf@33`l<0/k>c0;fm_@3Hf=P0i^KV0=kNgP3Shn<0eMGE0<W9b@3Ti>@0hN7Q
0=gMg@3Jf]X0[Zj^09jNWP2LW9`0N7Qh069RHP2CTi<0Zj^[06m_K`17AdL204=3@`0A0410@00i>CT0
?Cdm03`l?00i>CT0?clo03hn?P1HF5P0KFe]07=cL`1;Bd/0KFe]0:f][@3:b/X0h^;R0>KViP3Kfm/0
3Oooool0013ooooo00@0CDe=04Y:BP19BDT0B4Q80P16ATH204M7A`0304I6AP15ADD0AdM70080AdM7
00<0ADE504A4A016ATH00P15ADD01P16ATH0Bd];04M7A`11@D40ATI604U9B@80AdM700D0A4A404U9
B@17AdL0@d=304A4A00204I6AP0404E5A@12@T80@T9204=3@`80AdM70140ADE504=3@`14A4@0@T92
04E5A@12@T80@4100492@P16ATH0AdM70492@P13@d<0@D5103hn?P0o?cl0A4A40410@00203hn?P08
0451@@0n?Sh0?clo03Xj>P0m?Cd0?3`l03hn?P11@D420492@P0<0410@014A4@0A4A403dm?@0k>c/0
>SXj03`l?00j>SX0?3`l03lo?`12@T80@4100P0m?Cd04P0k>c/0>SXj03/k>`0l?3`0?Cdm03hn?P10
@400A4A403lo?`0m?Cd0@T9203hn?P0k>c/0=cLg03`l?00k>c/0?clo0451@@80?clo00h0>CTi03Xj
>P14A4@0@T9203Xj>P0m?Cd0>CTi03Xj>P0m?Cd0>3Ph03dm?@0k>c/0>3Ph03/k>`80?3`l00L0?Shn
03Xj>P0l?3`0>c/k03hn?P0l?3`0@4100080>c/k01@0>CTi03lo?`0l?3`0>SXj03lo?`0j>SX0>c/k
03`l?00n?Sh0?clo03dm?@0n?Sh0?clo0492@P0n?Sh0@4100492@P0n?Sh0>SXj03dm?@80?3`l01/0
?Shn04Y:BP1IFET0GemO06=SH`1HF5P0CDe=04m?C`1@D500Bd];0451@@0n?Sh0C4a<05=CD`18B4P0
@d=304E5A@1:BTX0D51@05eMG@26QXH0WYjN0::RXP2KVi/0R8R807alO02NWYh00P2/[:`06P2d];@0
UiNG07moO`2EUID0Z:RX0:^[Z`3>c/h0gMgM0=oOg`3?cll0_[jn0<k>cP3De=@0_;bl0:n_[`2l_;`0
dM7A0=_Kf`38b<P0Xj>S07moO`1JFUX0EEEE08>3P`2PX:00_Kfm0P32`/80=@2j^[X0aLG50;^k^`26
QXH0EUIF0492@P10@400?3`l04A4A00o?cl0A4A404M7A`15ADD0@41003/k>`12@T80@D5104=3@`0j
>SX0?3`l03hn?P11@D40@T9204E5A@1=CDd0FEUI07emO@1aLG40GEeM04Q8B012@T80?clo03`l?00m
?Cd0@D5103dm?@0l?3`0>SXj03dm?@0h>3P0@T9203dm?@14A4@0EEEE08b<S030`<00^k^k07MgM`1@
D500ADE504Q8B00o?cl0?Cdm0080?clo00@0@D5103`l?00j>SX0>SXj0P0m?Cd01@0j>SX0>c/k0410
@00o?cl0?3`l0080>SXj00`0?3`l0492@P1BDU80UiNG09bLW01/K6`0ADE503`l?00i>CT0>c/k03`l
?00k>c/20410@0040451@@10@400?Cdm0410@080@T9200T0?Cdm03lo?`11@D40?Shn0451@@13@d<0
?clo0410@00l?3`00`0m?Cd06P0k>c/0?Shn03dm?@0o?cl0@41003dm?@0n?Sh0@41003Xj>P19BDT0
ATI604E5A@17AdL0ADE503hn?P0k>c/0@41003/k>`0j>SX0>3Ph03Xj>P0k>c/0>3Ph03Ti>@0j>SX0
>CTi0P0k>c/00`0n?Sh0>3Ph03`l?00203Xj>P0503`l?00j>SX0=cLg03/k>`0m?Cd00P14A4@05@1V
IVH0O7al09RHV036a/H0VYZJ07QhN01IFET0ADE505UIF@1aLG40UiNG08N7Q`1QHF40ADE50451@@1:
BTX0IfMW075aL@1LG5`0A4A403lo?`0204I6AP0E04M7A`15ADD0C4a<04M7A`1;Bd/0@T9206ATI02@
T900ZJVY0:j^[P2i^KT0][Jf0<G5a@3IfMT0e=CD0<_;b`2e]KD0c/k>0=_Kf`3Ogml0h^;R0080i>CT
01`0gmoO0>;RhP3GemL0`L710;Zj^P30`<00b/[:0=KFeP3<c<`0bl_;0;Rh^02ZZZX0V9RH08>3P`1S
Hf<0EUIF04i>CP1:BTX0GUiN07=cL`1dM7@0PX:208b<S02WYjL0a/K60=WIf@3Ng]h0h>3P0P3Ng]h0
;`3Fe]H0cLg=0<k>cP3;bl/0b<S80<_;b`34a<@0clo?0=kNgP3QhN40g=cL0=OGe`3IfMT0dM7A0=GE
e@3IfMT0fm_K0=SHf03Ph>00alO7096AT@37alL0emOG0<?3``2>SXh0WYjN0;Zj^P2TY:@0^;Rh0<30
`02^[Zh0SXj>08B4Q022PX80QHF507YjNP2LW9`0dM7A0=;BdP2LW9`0Cdm?04A4A01cLg<0cLg=0=SH
f02ZZZX0Rh^;00gooooo000@ooooo`0704a<C019BDT0Bd];04];B`18B4P0ATI604Q8B00304I6AP0>
04A4A016ATH0ADE504E5A@18B4P0AdM704=3@`19BDT0ATI604Q8B016ATH0A4A404Q8B01:BTX204Q8
B0<0ADE500@0A4A404=3@`13@d<0@T920P17AdL08@12@T80B4Q80492@P14A4@0ADE504I6AP1:BTX0
A4A404I6AP13@d<0AdM704U9B@12@T80@41004E5A@12@T80@4100451@@0o?cl0A4A40492@P14A4@0
@d=303lo?`0n?Sh0?3`l03hn?P0o?cl0@D5103dm?@0l?3`0@d=303`l?00203/k>`0>03dm?@0k>c/0
?clo03/k>`0i>CT0>c/k03lo?`10@400@D510410@00o?cl0?Cdm04A4A015ADD203`l?080?Shn00P0
>SXj03/k>`0j>SX0>c/k0410@00j>SX0?3`l0410@080?3`l00<0@41003hn?P10@4000P0k>c/00`0n
?Sh0A4A403/k>`0203dm?@80?3`l00l0?Cdm03Xj>P0k>c/0>c/k03Ti>@0g=cL0?3`l03/k>`0h>3P0
>CTi03lo?`0k>c/0?3`l0492@P13@d<00P0k>c/03`0m?Cd0?3`l03hn?P0h>3P0>SXj03Ph>00k>c/0
>SXj03/k>`0i>CT0>3Ph03`l?00k>c/0?Shn03Ti>@0203/k>`0?03Xj>P0l?3`0>CTi03Ti>@0o?cl0
>SXj03dm?@10@400?Shn0410@011@D40@41003hn?P0j>SX0?Cdm0080?clo01D0@D5104I6AP1DE5@0
GemO06=SH`1LG5`0I6AT061PH01/K6`0Jf][06MWI`1HF5P0DE5A04I6AP1BDU80ATI604a<C01:BTX0
Cdm?069RHP22PX800P2l_;`04@2XZ:P0/[:b0;:b/P2LW9`0Ph>309FEU@2ZZZX0/k>c09bLW02FUYH0
Xj>S0;Bd]02e]KD0/;2`0:BTY028R8P0YjNW0080clo?00/0[Zj^07YjNP1OGel0I6AT07UiN@2CTi<0
O7al07inOP1`L700EeMG04A4A00204=3@`80@41002d0ATI60492@P0l?3`0@D5105aLG026QXH0S8b<
0861P@1jNWX0MgMg06UYJ@13@d<0@D5104Q8B015ADD0@D5104M7A`10@400@d=303lo?`0n?Sh0?Cdm
0451@@0k>c/0?3`l03dm?@16ATH0Bd];0492@P18B4P0Lg=c08B4Q02DU9@0Vi^K07alO01UIFD0Lg=c
07moO`1nOWh0Bd];03Xj>P10@400A4A405QHF01>CTh00P10@4005P0o?cl0>3Ph03Ti>@0l?3`0?Shn
03lo?`0k>c/0?clo03dm?@12@T80LW9b08:2PP25QHD0H61P04=3@`0k>c/0@D5103dm?@0l?3`0?clo
0410@014A4@203lo?`040410@00n?Sh0?clo03dm?@80?Shn00P0?clo03hn?P0l?3`0?Cdm03/k>`0n
?Sh0?clo03`l?080?Cdm00`0@T920451@@0o?cl0>c/k03`l?013@d<0>3Ph04e=C@1EEED0A4A404a<
C012@T8203hn?P0:03dm?@0i>CT0?Shn03Ti>@0h>3P0>SXj03De=@0k>c/0?Shn03/k>`<0?3`l00D0
>3Ph03/k>`0i>CT0>3Ph03Ti>@0203dm?@0303/k>`0l?3`0>c/k0080@d=300d0AdM706MWI`2BTY80
QXJ6075aL@1[Jf/0IFEU04Y:BP1@D500HF5Q06EUI@1OGel0EUIF0080@T9201<0@d=304U9B@1QHF40
K6a/05YJFP14A4@0>CTi03/k>`1<C4`0Kfm_08>3P`2LW9`0WYjN08F5Q@1]KFd0PX:20;Ng]`3Bd]80
e=CD0080c/k>00D0dM7A0=?Cd`3Bd]80dM7A0=OGe`020=SHf00P0=?Cd`3;bl/0b/[:0<_;b`3>c/h0
dm?C0=CDe02o_kl0XZ:R09ZJVP2DU9@0VYZJ08R8R01VIVH0GemO079bLP1eMGD0PX:208n?S`2VYZH0
ZJVY09fMW@2/[:`0c<c<0=SHf03IfMT0h^;R0=WIf@3?cll0e]KF0=gMg@3GemL30=?Cd`0@0<K6aP33
`l<0c<c<0<[:bP37alL0^[Zj0;2`/02[Zj/0^KVi0=WIf@3AdM40c<c<0=7Ad@3Hf=P0h>3P0>GUi@80
h^;R0P3Ogml06`3Kfm/0eMGE0=[JfP3Ogml0e]KF0=CDe034a<@0];Bd08j>SP1cLg<0QHF508R8R02L
W9`0[:b/0<K6aP3@d=00fm_K0=CDe037alL0YJFU09BDU01bLW80Ogmo0;jn_P2j^[X0Shn?05EEE@0=
ooooo`004?ooool0101:BTX0B4Q804];B`19BDT304I6AP0804M7A`16ATH0ATI604M7A`19BDT0ADE5
04I6AP18B4P204M7A`0A04E5A@19BDT0ATI604A4A013@d<0A4A404];B`1@D500C4a<04E5A@13@d<0
ADE504I6AP1:BTX0@d=30492@P14A4@00P12@T801016ATH0@41004A4A013@d<30410@00>04E5A@13
@d<0?clo03hn?P14A4@0@T9204A4A011@D40@T920451@@0m?Cd0@41003`l?010@40204A4A00503`l
?00o?cl0?Cdm03dm?@10@4000P0k>c/02`0n?Sh0?Cdm03Ph>00h>3P0?3`l0410@00j>SX0>c/k03hn
?P0m?Cd0@4100080?Shn00P0>SXj03dm?@0l?3`0>c/k0451@@0l?3`0>SXj03`l?080>c/k0140?Shn
03`l?00k>c/0>c/k03lo?`11@D40?Cdm03lo?`0m?Cd0>c/k03`l?010@400>SXj03Ti>@0o?cl0?Shn
03/k>`0203Xj>P0403/k>`0l?3`0>c/k03Ti>@80>SXj0P0l?3`303/k>`80?Cdm00H0>SXj03Ti>@0j
>SX0@41003/k>`0n?Sh20410@00=03Xj>P0n?Sh0?Shn03dm?@0l?3`0>c/k03Ti>@0m?Cd0>SXj03`l
?00n?Sh0?Cdm0410@00203/k>`80>SXj00<0?Shn0410@00o?cl00P0k>c/09011@D40>c/k03lo?`10
@400>c/k03Ti>@0k>c/0?Cdm03/k>`12@T80ADE504Y:BP1MGEd0KFe]061PH01FEUH0D51@04U9B@10
@400?Shn04A4A00n?Sh0A4A404Q8B015ADD0BDU9059BDP1LG5`0M7Ad08N7Q`26QXH0R8R807UiN@1S
Hf<0F5QH05mOG`80E5AD00/0G5aL069RHP1UIFD0IVIV06UYJ@1gMgL0IfMW06=SH`1aLG40SXj>0:>S
X`0209fMW@0@0:JVYP2e]KD0b/[:0<30`02KVi/0RXZ:07alO01aLG40MgMg07QhN01mOGd0TY:B07]k
N`1YJFT0OGem08b<S080SHf=00X0Ogmo07MgM`1dM7@0IfMW07UiN@1hN7P0M7Ad06a/K01QHF40ATI6
0P17AdL00`16ATH0E5AD08B4Q00209^KV`0H08J6QP29RHT0QHF506YZJP13@d<0?Cdm051@D01IFET0
CTi>03hn?P10@400@d=303lo?`0n?Sh0@d=303lo?`0m?Cd0A4A404E5A@10@400?clo0410@00n?Sh0
@D510P12@T80100j>SX0>c/k03Ti>@0l?3`303hn?P0:0492@P16ATH0CTi>04M7A`1MGEd0Ogmo05=C
D`0m?Cd0>CTi03dm?@80@T9200@0@41003hn?P0k>c/0?Shn0P0k>c/0700o?cl0@T920410@00l?3`0
@41003Ti>@11@D40?clo03hn?P0j>SX0>CTi03`l?00o?cl0B4Q803`l?013@d<0ADE503hn?P0m?Cd0
>c/k03dm?@12@T80@D5104I6AP1OGel0GEeM0451@@0k>c/203dm?@0503/k>`0j>SX0>3Ph03/k>`0i
>CT00P0k>c/303Ti>@80>c/k00@0?Cdm03`l?00i>CT0>c/k0`0h>3P00`0i>CT0>3Ph03hn?P020451
@@1904Y:BP1>CTh0>CTi03lo?`13@d<0@D51051@D021PH40OWin05QHF01:BTX0@d=303dm?@0j>SX0
>c/k03dm?@0n?Sh0>c/k0410@011@D40?3`l03Xj>P0g=cL0>c/k04Y:BP1ZJVX0MgMg06MWI`1ZJVX0
K6a/05ADE01PH600V9RH0<_;b`3Kfm/0e=CD0=7Ad@39bLT0d];B0<c<c034a<@0]kNg0<30`02l_;`0
YjNW0861P@1WIfL0GemO069RHP1`L700LW9b07moO`2?Shl0PH6107inOP27QhL0Zj^[0;^k^`34a<@0
b<S80=KFeP3Ph>00h^;R0>KViP3Rh^80e=CD0;^k^`3De=@0hn?S0>7Qh@3Shn<0hN7Q0=cLg0020=[J
fP0E0=7Ad@2n_[h0_[jn0<W9b@3GemL0fMWI0=KFeP34a<@0ZZZZ09BDU02<S8`0X:2P0;6a/@39bLT0
fMWI0=KFeP3AdM40clo?0<g=c@39bLT0`l?30080^[Zj01d0Z:RX0;Jf]P38b<P0`L710;no_`3:b/X0
e]KF0=WIf@3@d=00bLW90;Jf]P2^[Zh0^[Zj0:6QX@2VYZH0]kNg0<?3``2o_kl0dm?C0=GEe@3Cdm<0
a/K60=SHf02k^k/0UiNG0<?3``2i^KT0/;2`0;jn_P0=ooooo`004?ooool01@1;Bd/0BTY:04a<C016
ATH0AdM70080ATI600D0AdM704I6AP16ATH0BTY:04M7A`0204A4A00604M7A`18B4P0ADE504I6AP15
ADD0@T920P15ADD01P14A4@0AdM704i>CP19BDT0B4Q804Y:BP80AdM70P14A4@05`17AdL0@T9204E5
A@1:BTX0BDU904I6AP19BDT0ADE503lo?`11@D40BDU9051@D01ADE40D51@04=3@`0n?Sh0?clo04A4
A013@d<0A4A40410@013@d<0?Cdm0080?Shn0P11@D401014A4@0?Shn03dm?@0m?Cd203/k>`0903Ph
>00l?3`0?Cdm03hn?P10@400?Shn0410@00k>c/0>SXj0080?3`l00L0>c/k03dm?@0o?cl0>c/k03hn
?P0o?cl0>CTi0080?3`l00L0?Cdm03`l?00m?Cd0?Cdm03lo?`0l?3`0>c/k0080?Cdm00@0FEUI03lo
?`0m?Cd0?Cdm0P0n?Sh00`0k>c/0>CTi03Ti>@0203lo?`80?Shn00<0@4100451@@0k>c/00P0m?Cd0
100j>SX0>CTi03hn?P10@40303hn?P80@41000`0?Cdm03/k>`0m?Cd0>c/k03Ph>012@T80ATI603/k
>`0i>CT0>c/k04E5A@0m?Cd203/k>`0803dm?@0h>3P0>c/k0410@00m?Cd0>SXj0410@00i>CT203Xj
>P0603/k>`11@D40?Shn03/k>`0m?Cd0>SXj0P10@40203hn?P0D04A4A00k>c/0?Shn03`l?010@400
?Cdm0410@012@T80FUYJ06IVIP1FEUH0?clo03hn?P0m?Cd0@D5103hn?P17AdL0CDe=05QHF01BDU82
04Q8B00604a<C017AdL0B4Q804M7A`15ADD0Bd];0P19BDT20492@P060451@@0j>SX0ATI60410@015
ADD0De=C0P1LG5`0?`1_Kfl0Ng]k08B4Q02RXZ80][Jf0::RXP24Q8@0U9BD0:^[Z`2VYZH0[Zj^09NG
U`1dM7@0PH61092@T024Q8@0NWYj08>3P`1aLG40E5AD04Q8B017AdL0CTi>051@D01CDe<0Jf][08Z:
RP2?Shl0UIFE09:BTP1oOgl0OWin07AdM02:RXX0/;2`0;Fe]@2`/;00WYjN0;Ng]`3<c<`0^KVi0;Fe
]@2GUiL0L71`05QHF01:BTX0@T9203/k>`15ADD0Hf=S07MgM`1LG5`0B4Q803lo?`0n?Sh0>c/k0492
@P0n?Sh0>c/k03hn?P0h>3P0>SXj0410@00203dm?@0A03/k>`0j>SX0>c/k03Ti>@0l?3`0>SXj03/k
>`0n?Sh0?3`l0410@012@T80HF5Q05UIF@17AdL0@d=304Y:BP0m?Cd00P15ADD203`l?080?Cdm00H0
@41003dm?@0k>c/0?3`l03dm?@0n?Sh203dm?@0703/k>`0l?3`0?3`l03hn?P0m?Cd0?Shn03dm?@02
0410@00503`l?010@400@d=30492@P13@d<00P0n?Sh01`1>CTh0EeMG05=CD`1;Bd/0@D5103dm?@0k
>c/00P0l?3`02`10@400?Shn03dm?@0m?Cd0?3`l03hn?P0m?Cd0?Shn03Ph>00i>CT0?Cdm0080@D51
00<0?Cdm03`l?00m?Cd00P0i>CT203`l?00C03/k>`1;Bd/0EeMG04Y:BP10@400@D5103`l?00k>c/0
>CTi03Xj>P1>CTh0I6AT06a/K01XJ6P0Fe]K04];B`12@T80?Cdm03/k>`0203dm?@0303lo?`0j>SX0
>3Ph0080>3Ph02T0>c/k03`l?00i>CT0?Shn03dm?@19BDT0GemO05UIF@1`L700MWIf09RHV02m_Kd0
`l?30:VYZ@2@T900Shn?09JFUP2BTY80PH6107MgM`1aLG40E5AD04];B`19BDT0Bd];06UYJ@2JVYX0
[Zj^0;Vi^@3<c<`0aLG50<;2`P36a/H0`L710<c<c03Fe]H0h>3P0>OWi`3Ogml0fm_K0>;RhP020>?S
h`040>;RhP3Ph>00hN7Q0>3Ph080hN7Q02<0gMgM0=GEe@37alL0`l?30;^k^`2KVi/0K6a/05iNGP1J
FUX0PH610:BTY02n_[h0bl_;0<W9b@3:b/X0cLg=0=WIf@3Ogml0e]KF0<K6aP2_[jl0WYjN092@T02?
Shl0TI6A0::RXP2e]KD0^[Zj0<;2`P3:b/X0c<c<0<;2`P2^[Zh0X:2P09NGU`020861P@0908J6QP2X
Z:P0e]KF0=SHf03=cLd0b<S80<[:bP3Bd]80e]KF0080f=SH00<0eMGE0<k>cP3De=@00P3Bd]801@38
b<P0_;bl0:b/[02NWYh0Xj>S00gooooo000@ooooo`0604a<C01:BTX0BDU904U9B@17AdL0ATI60P15
ADD00`16ATH0ADE504Y:BP0204M7A`0604I6AP17AdL0B4Q804I6AP1<C4`0B4Q80P15ADD02`16ATH0
@d=304=3@`19BDT0BTY:04E5A@12@T80ATI604E5A@13@d<0A4A40080@T9200d0@D510492@P15ADD0
@41004E5A@14A4@0@T9203lo?`16ATH0A4A404E5A@14A4@0@T920080@D5100<0@d=30492@P0o?cl0
0P0n?Sh0200o?cl0?3`l04I6AP1;Bd/0CTi>04I6AP12@T80?Cdm0P0o?cl0100m?Cd0?clo03hn?P0m
?Cd203/k>`0903Ph>00k>c/0>c/k03`l?00k>c/0?Cdm03hn?P11@D40?Shn0080?3`l00D0?clo03Xj
>P0l?3`0>c/k03`l?00203/k>`0303`l?00m?Cd0>c/k0080>SXj00l0=cLg03dm?@0k>c/0>SXj03/k
>`0j>SX0?clo03Ph>00g=cL0?Shn03lo?`0l?3`0>SXj03/k>`0h>3P00P0l?3`01@10@400?3`l03Ph
>00m?Cd0?3`l0080?Shn00@0?Cdm03`l?00j>SX0?3`l0P0n?Sh03P0j>SX0>3Ph03dm?@0l?3`0?clo
03Lg=`0j>SX0?Cdm04=3@`0g=cL0>CTi03Xj>P10@400?Cdm0P10@4000`0m?Cd0>3Ph03Ph>00203`l
?080>c/k00@0?clo03`l?00j>SX0?Shn0P0k>c/02@0n?Sh0?3`l03hn?P0n?Sh0>c/k0451@@0l?3`0
>c/k04m?C`0205mOG`0>05MGE`1<C4`0?Shn03/k>`0m?Cd0B4Q804M7A`0m?Cd0ATI603lo?`11@D40
?Shn03`l?00k>c/203lo?`040451@@12@T80@D5104E5A@<0@T9204/0@d=304Y:BP1DE5@0HF5Q08:2
PP2@T900ZJVY0;Rh^02_[jl0]KFe0:RXZ02;Rh/0Lg=c06m_K`1ZJVX0Hf=S05iNGP1JFUX0E5AD06][
J`1fMWH0Ng]k0820P01iNGT0LW9b07inOP2GUiL0ZZZZ09>CT`2BTY80Rh^;0:NWY`31`L40`/;20<30
`02n_[h0/[:b0;Bd]03;bl/0d=3@0=gMg@3Hf=P0i^KV0>CTi03Ph>00f][J0=cLg03MgMd0d=3@0;Jf
]P2EUID0MGEe061PH017AdL0@D510410@00n?Sh0@41003hn?P11@D40>c/k03lo?`0m?Cd0@D5103`l
?00n?Sh0>CTi03dm?@0i>CT0>SXj03/k>`0o?cl0>c/k03hn?P0l?3`00`0m?Cd05`0o?cl0@D5103dm
?@1>CTh0KVi^06e]K@1XJ6P0UYJF0861P@1^KVh0K6a/07]kN`2<S8`0SHf=05iNGP0n?Sh0?clo03Xj
>P0k>c/0?Cdm0451@@0m?Cd0?3`l00<0>c/k00T0?3`l03lo?`0m?Cd0?clo04E5A@11@D40>CTi03dm
?@10@4000P0o?cl204I6AP0704A4A00o?cl0CDe=06m_K`1lO7`0F5QH03/k>`0203hn?P0>04A4A00m
?Cd0?clo03hn?P0l?3`0>SXj03/k>`10@400?Cdm03/k>`0m?Cd0>SXj03lo?`0m?Cd203/k>`0;03Ti
>@0j>SX0?Cdm03hn?P0m?Cd0=cLg03/k>`13@d<0G5aL06QXJ01=CDd00P0j>SX05@0n?Sh0=CDe03Xj
>P0k>c/0FEUI06IVIP1EEED0Bd];03dm?@0n?Sh0=CDe03`l?00j>SX0>CTi03Xj>P0h>3P0?3`l03Ph
>00n?Sh0>CTi03dm?@0303Ti>@0J03lo?`1ADE40JVYZ06a/K01IFET0MWIf0861P@2;Rh/0RHV9061P
H01GEeL0A4A403dm?@13@d<0?clo04A4A00n?Sh0AdM705MGE`1iNGT0V9RH09nOW`2i^KT0emOG0=SH
f03AdM420<S8b0050<30`039bLT0bLW90=?Cd`3MgMd00P3Kfm/01`3EeMD0g=cL0=GEe@37alL0a<C4
0;Jf]P2ZZZX00P2TY:@05@2PX:00SHf=07MgM`1RHV80F5QH055AD@17AdL0ATI605ADE02JVYX0/K6a
0<O7a`3Fe]H0dm?C0<k>cP3<c<`0bLW90=?Cd`3Jf]X0g=cL0<c<c0020<O7a`0C0<S8b03<c<`0_[jn
0:b/[02SXj<0T92@08R8R01lO7`0M7Ad06MWI`1_Kfl0K6a/07AdM01mOGd0PX:208j>SP2XZ:P0b/[:
0=cLg0020=kNgP0@0=cLg03Jf]X0fMWI0=OGe`3EeMD0e=CD0=GEe@3@d=00`/;20<G5a@3=cLd0emOG
0<o?c`2b/[80XZ:R0<;2`Pgooooo000@ooooo`0604Y:BP1;Bd/0Bd];04U9B@18B4P0ATI60P14A4@0
1@15ADD0A4A404I6AP18B4P0AdM700@0A4A400H0BTY:04A4A013@d<0@d=304A4A012@T8204=3@`0J
04E5A@14A4@0@d=304E5A@14A4@0@D5104=3@`10@400@T9204A4A017AdL0BTY:04A4A015ADD0@d=3
0492@P0k>c/0@T9203dm?@12@T80@41004E5A@14A4@0?clo0492@P17AdL203hn?P0:03dm?@0n?Sh0
?Cdm04];B`1>CTh0BDU90410@00m?Cd0?3`l03Xj>P<0?Shn0P0l?3`02`0m?Cd0>c/k03Xj>P0n?Sh0
?3`l03hn?P0k>c/0@41003lo?`0m?Cd0=cLg0080?Cdm00L0@41003dm?@0l?3`0>c/k03`l?00j>SX0
>3Ph0080>CTi0P0l?3`303Xj>P0903/k>`0n?Sh0?Cdm03/k>`0n?Sh0>SXj03dm?@0n?Sh0?3`l0080
>CTi00P0@D5103Ti>@0k>c/0?Cdm03lo?`0k>c/0?3`l03dm?@80?3`l00@0?clo03`l?00i>CT0>SXj
0P0m?Cd00`0h>3P0?Cdm03/k>`0203hn?P80?Cdm00<0?clo04M7A`0o?cl00P0l?3`05@0j>SX0>c/k
03Xj>P0h>3P0?3`l03/k>`0l?3`0>3Ph03hn?P0o?cl0?3`l03Ph>00j>SX0>c/k03Xj>P0n?Sh0?Cdm
03hn?P0m?Cd0?3`l03dm?@0203`l?080?clo0140@T9204];B`13@d<0?clo03/k>`0o?cl0>c/k03dm
?@11@D40=cLg0492@P0j>SX0?Cdm03Ti>@0j>SX0?Cdm03hn?P0203`l?00f03dm?@0o?cl0?3`l04=3
@`11@D40?Cdm04Q8B01FEUH0GUiN07IfMP23Ph<0Ogmo09:BTP2<S8`0MgMg06i^KP1KFe/0D51@04I6
AP0m?Cd0AdM704U9B@1>CTh0EUIF05mOG`1^KVh0M7Ad07=cL`1aLG40J6QX06e]K@1EEED0F5QH04i>
CP1;Bd/0CDe=04];B`1=CDd0GemO07alO02>SXh0Ph>307IfMP23Ph<0Vi^K0:b/[02KVi/0Ti>C08j>
SP2EUID0YjNW09RHV02^[Zh0alO70P3Lg=`03034a<@0X:2P0:NWY`2_[jl0Z:RX08j>SP23Ph<0SHf=
09VIV@2FUYH0I6AT04=3@`80?Cdm00<0>c/k04=3@`10@4000P0l?3`07P0n?Sh0?clo03/k>`0m?Cd0
?3`l03Ti>@0k>c/0>SXj03/k>`0l?3`0?Shn0451@@1=CDd0M7Ad0;Zj^P2^[Zh0Kfm_07=cL`2CTi<0
Vi^K0<K6aP3Cdm<0dM7A0:BTY023Ph<0LW9b06YZJP1LG5`0?clo0410@0<0?Shn01L0@41003dm?@0n
?Sh0?clo03`l?014A4@0@D5103lo?`10@400B4Q80492@P0o?cl0?Shn03dm?@0o?cl0@4100451@@0o
?cl0DE5A08^;R`2GUiL0H61P0451@@0203dm?@0703hn?P0o?cl0?clo03Xj>P0o?cl0?Shn03Xj>P02
03`l?080>3Ph00H0>SXj03`l?00n?Sh0?Cdm03Xj>P0k>c/203Ti>@0Z03`l?00i>CT0>SXj03dm?@10
@400DU9B04M7A`0n?Sh0>SXj03Ph>00m?Cd0@41003/k>`0l?3`0?Shn04E5A@10@400>c/k03Xj>P0n
?Sh0>SXj03De=@0k>c/0=cLg03hn?P1CDe<0FEUI0451@@0o?cl0?Cdm03`l?00h>3P0?Cdm04Q8B01V
IVH0MgMg05ADE012@T80@d=304e=C@1ADE40DU9B0P1:BTX0800o?cl0?Cdm03Xj>P0k>c/0?3`l03/k
>`10@400Jf][08b<S01nOWh0OGem07UiN@1fMWH0Vi^K0::RXP2OWil0[jn_0;jn_P2b/[80[Zj^0;Bd
]038b<P0_[jn0;6a/@2FUYH0Ph>307=cL`1^KVh0IVIV05mOG`1EEED0Fe]K0P1ZJVX03P1LG5`0CTi>
0492@P12@T80@d=305aLG01[Jf/0P8200:6QX@31`L40g]kN0=gMg@3Kfm/0d];B0P2n_[h02`37alL0
e]KF0=SHf03@d=00^KVi0:^[Z`2XZ:P0W9bL08j>SP25QHD0NGUi0080GemO00l0H61P06IVIP1TI6@0
L71`08:2PP2@T900WinO0:FUY@28R8P0XJ6Q0;2`/038b<P0e=CD0=_Kf`3Ng]h00`3GemL01@3Lg=`0
g]kN0=_Kf`3GemL0f][J0080hN7Q00L0gMgM0=GEe@3Bd]80eMGE0=7Ad@31`L40a<C400gooooo000@
ooooo`0;04Y:BP1@D500C4a<04e=C@15ADD0CDe=04Y:BP1;Bd/0BTY:04U9B@15ADD00P16ATH01018
B4P0ADE504M7A`13@d<204E5A@0E04A4A012@T80A4A404I6AP13@d<0@41004A4A017AdL0ADE504A4
A012@T80B4Q804E5A@14A4@0@d=304A4A015ADD0@T9204I6AP13@d<0?clo0080@T9200D0ATI60492
@P12@T80?clo04M7A`0203lo?`0703hn?P13@d<0ATI603lo?`0m?Cd0@D510410@0030451@@0303dm
?@0n?Sh0@T920080?3`l01P0?Cdm03hn?P0o?cl0?Shn03lo?`0j>SX0>CTi03`l?00m?Cd0>SXj0410
@011@D40@41003/k>`0m?Cd0?clo04A4A010@400@T9203hn?P0k>c/0?Cdm03`l?00i>CT203dm?@80
?3`l0140?clo0410@00k>c/0>SXj03hn?P0o?cl0?Shn03`l?00n?Sh0>SXj03Ph>00j>SX0>3Ph03`l
?00j>SX0>c/k03lo?`0203/k>`0303Xj>P0k>c/0?clo0080>SXj00@0?Shn03dm?@0m?Cd0>SXj0P0m
?Cd203hn?P0803dm?@0l?3`0?3`l03dm?@1CDe<0@D5103lo?`12@T8203hn?P0303dm?@0k>c/0>c/k
0080?Shn00L0@D5103dm?@0k>c/0?clo03`l?00j>SX0>c/k0080?Shn00D0>c/k03`l?00o?cl0?clo
03dm?@0203lo?`0603Ph>00m?Cd0?clo03/k>`0n?Sh0@D510P0k>c/00`0i>CT0?Cdm03`l?00203dm
?@0603Xj>P0m?Cd0@41003hn?P0m?Cd0?clo0P0l?3`00`0k>c/0>SXj03/k>`0203`l?00<03lo?`1:
BTX0CDe=05MGE`1LG5`0DU9B05=CD`1@D500DU9B04e=C@1<C4`0@4100P0n?Sh01P0o?cl0@d=304i>
CP1gMgL0Ng]k065QH@80E5AD03@0Cdm?0451@@1@D500GUiN061PH01BDU80EEEE059BDP1LG5`0KFe]
07IfMP1YJFT0FEUI059BDP1JFUX0OGem08B4Q01ZJVX0HF5Q06e]K@1RHV80EUIF05eMG@1IFET0KVi^
08f=S@1lO7`0RHV90;Zj^P30`<00c/k>0<71`@2/[:`0S8b<069RHP1GEeL0EUIF05eMG@1oOgl0R8R8
0:b/[02NWYh0M7Ad04M7A`0k>c/0@41003lo?`10@400@T920451@@0k>c/0@d=30P0o?cl00`11@D40
?Cdm0410@00203lo?`0C04A4A01IFET0QXJ60<;2`P3Ph>00g=cL0:n_[`2][Jd0`<300=?Cd`3Lg=`0
fMWI0<W9b@2NWYh0GUiN04U9B@15ADD0?Shn03dm?@0203lo?`0403`l?010@400>c/k03hn?P80?Cdm
01H0@41004A4A019BDT0GEeM071`L01nOWh0KFe]0451@@12@T80?clo03hn?P0j>SX0@T9204Y:BP1_
Kfl0WYjN08>3P`1>CTh0ADE503`l?00n?Sh0?Cdm0P0n?Sh03P0m?Cd0>CTi0451@@12@T80?3`l03Xj
>P0m?Cd0>SXj03/k>`0i>CT0?Shn03dm?@0n?Sh0?3`l0P0i>CT01@0l?3`0?clo0492@P0k>c/0@410
0080Cdm?01L0@41003/k>`0j>SX0>SXj03Ti>@0j>SX0?3`l03dm?@0h>3P0>c/k03Ti>@0h>3P0>c/k
03Lg=`0m?Cd0>CTi0492@P1VIVH0Ogmo06IVIP18B4P0?3`l03/k>`0203Ti>@0X03hn?P1IFET0M7Ad
075aL@1FEUH0CTi>06=SH`1PH600LG5a06UYJ@1>CTh0>c/k03Ph>00k>c/0>3Ph03Lg=`11@D40A4A4
07EeM@29RHT0R8R806MWI`1MGEd0Bd];0492@P1DE5@0MGEe07moO`2[Zj/0/[:b0::RXP2NWYh0X:2P
0820P01WIfL0C4a<04Q8B00n?Sh0?clo03`l?080@D5102D0@41003lo?`13@d<0@d=304U9B@1EEED0
MgMg08N7Q`2<S8`0UiNG0<71`@3@d=00fm_K0=kNgP3Shn<0inOW0>KViP3MgMd0g=cL0=_Kf`3IfMT0
a/K609fMW@1iNGT0I6AT055AD@1HF5P0Hf=S07=cL`2:RXX0SHf=08Z:RP1jNWX0Ng]k08F5Q@2[Zj/0
aLG50080d=3@01/0a/K60;Vi^@2YZJT0U9BD0:6QX@2_[jl0eMGE0=_Kf`3MgMd0fMWI0=KFeP3De=@0
eMGE0=SHf03AdM40bLW90;Bd]037alL0bl_;0<k>cP3EeMD0d];B0<o?c`3=cLd0bLW90<G5a@3>c/h0
3Oooool0013ooooo00H0RXZ:07EeM@1nOWh0T92@09:BTP26QXH207]kN`0?0820P01dM7@0Fe]K04M7
A`16ATH0@d=304A4A016ATH0B4Q804];B`1?Cdl0Bd];04I6AP12@T80@D510080@T9201`0ADE504A4
A013@d<0@T9204=3@`18B4P0@d=304A4A012@T80?Shn04A4A013@d<0@T9204A4A019BDT0ATI604M7
A`15ADD0@d=304A4A011@D40@41003dm?@11@D40@4100451@@10@400>c/k0P15ADD02@11@D40?clo
03hn?P0o?cl0A4A403/k>`11@D40@41003dm?@0203hn?P0703`l?00m?Cd0>3Ph03/k>`0l?3`0>c/k
03`l?00203Xj>P0403/k>`0i>CT0?Shn0410@080?3`l0P0o?cl20410@00403`l?00m?Cd0?Shn03lo
?`80?Shn00D0>SXj03`l?00l?3`0>SXj03`l?00203lo?`0803`l?00j>SX0>c/k03`l?00h>3P0=CDe
03/k>`0m?Cd203/k>`0803lo?`0k>c/0?Cdm03`l?00i>CT0?Cdm04E5A@11@D4203lo?`0703Xj>P0o
?cl0A4A404=3@`1;Bd/0?clo03dm?@0203Xj>P0803hn?P0m?Cd0?3`l03/k>`0i>CT0>SXj03dm?@0g
=cL203dm?@0903Ti>@0j>SX0@41003hn?P0o?cl0@D5103`l?00g=cL0>CTi0080?Shn0P0k>c/0100n
?Sh0@d=303dm?@0l?3`303/k>`0603dm?@0n?Sh0@d=30492@P0l?3`0>CTi0P0j>SX01`0g=cL0>CTi
03dm?@0h>3P0>c/k03`l?00m?Cd00P0j>SX0200m?Cd0?3`l03`l?00m?Cd0?3`l04a<C01ADE40B4Q8
0P19BDT01P17AdL0?3`l03hn?P12@T80>c/k03dm?@80?clo00/0?3`l03hn?P11@D40?Cdm04A4A00o
?cl0AdM704Y:BP15ADD0@d=303lo?`0203dm?@80?clo01H0A4A405=CD`1jNWX0Hf=S06YZJP1EEED0
DE5A04];B`16ATH0A4A404E5A@18B4P0@T9204Q8B01EEED0EUIF05=CD`1QHF40PH6107=cL`1/K6`0
PX:20P23Ph<08@1VIVH0EeMG05aLG01SHf<0O7al08R8R02DU9@0[:b/0;Fe]@2RXZ80_kno0;fm_@32
`/80a<C40:JVYP2>SXh0MWIf07QhN02HV9P0WIfM08>3P`1oOgl0N7Qh07moO`1eMGD0EEEE04A4A013
@d<0D51@075aL@2DU9@0^;Rh0<_;b`020=;BdP0E0=KFeP31`L40a<C40<c<c02o_kl0`<300;>c/`2_
[jl0X:2P08B4Q01jNWX0OWin06IVIP0o?cl0>c/k0451@@0n?Sh0?Cdm03`l?00m?Cd0@D510080?clo
0380DU9B0:6QX@2][Jd0RHV905MGE`19BDT0@d=303hn?P15ADD0?3`l03/k>`17AdL0J6QX0:b/[03@
d=00WinO04U9B@0n?Sh0>CTi03dm?@0k>c/0@41003hn?P0o?cl0>SXj03Ph>00o?cl0?3`l03Xj>P0m
?Cd0@41003dm?@0n?Sh0?Cdm03lo?`12@T80?Shn03lo?`11@D40?Shn04I6AP1:BTX0@d=303hn?P16
ATH0@d=303/k>`0i>CT0?Cdm03`l?080>c/k0200?Cdm03lo?`0o?cl0>c/k03Ti>@0f=SH0>SXj03Ti
>@0k>c/0@d=3061PH029RHT0Lg=c04M7A`0n?Sh0?Cdm03`l?00h>3P0?3`l03Xj>P11@D40DE5A04I6
AP10@400?Cdm03Xj>P12@T80Bd];055AD@13@d<0>c/k03`l?080>SXj0P0k>c/09`19BDT0JVYZ08V9
R@25QHD0MGEe05aLG01>CTh0?Shn04A4A01aLG40WIfM0::RXP2i^KT0YZJV09BDU01mOGd0H61P04=3
@`12@T80?3`l0492@P15ADD0@T9203Ti>@0j>SX0?Cdm03Ti>@1@D500KFe]08f=S@2WYjL0];Bd0<;2
`P2n_[h0_kno0<S8b03Bd]80c/k>0=7Ad@020=GEe@0A0<k>cP36a/H0cLg=0;bl_02TY:@0N7Qh05EE
E@1;Bd/0IfMW08Z:RP2XZ:P0];Bd0;Jf]P2?Shl0GEeM04a<C014A4@00P12@T80201WIfL0Rh^;0:f]
[@37alL0c/k>0<?3``2b/[80`L710P3<c<`05P33`l<0aLG50<[:bP35aLD0^k^k0:n_[`2WYjL0/[:b
0;fm_@33`l<0_[jn09fMW@2?Shl0M7Ad071`L01/K6`0JVYZ06ATI01SHf<0GemO05iNGP1ZJVX=oooo
o`004?ooool05P3Kfm/0dm?C0=OGe`3Bd]80cLg=0;Vi^@2LW9`0Rh^;08V9R@1gMgL0HV9R05=CD`1I
FET0HV9R06EUI@1cLg<0MWIf07moO`1fMWH0FUYJ04I6AP12@T8204I6AP80@T9200D0@d=304E5A@17
AdL0@D510492@P020451@@0Q0410@013@d<0AdM704I6AP11@D40@T9204];B`18B4P0AdM7069RHP1S
Hf<0BTY:04E5A@14A4@0@d=303lo?`0m?Cd0?3`l03dm?@11@D40@41004E5A@12@T80?clo04];B`15
ADD0?Cdm03hn?P11@D40?Shn03`l?00n?Sh0B4Q80080@D510P0n?Sh02@17AdL0ADE50451@@0m?Cd0
>c/k03Xj>P0g=cL0?Shn0410@00203dm?@0803lo?`0n?Sh0?3`l03dm?@0n?Sh0>SXj03dm?@0l?3`2
03Xj>P0H03Hf=P0j>SX0>c/k03`l?00m?Cd0>c/k03Xj>P11@D40?3`l03/k>`12@T80?clo03`l?00n
?Sh0?Cdm03/k>`0l?3`0?Cdm03hn?P12@T80>c/k03Ti>@0m?Cd0@T920P0n?Sh0300k>c/0AdM7055A
D@1IFET0CTi>04a<C016ATH0?Shn03Ph>00j>SX0>c/k03`l?080>c/k00`0?Cdm03Xj>P0j>SX0=cLg
03/k>`0m?Cd0?3`l0451@@1ADE40@D5104A4A012@T8203Xj>P0703`l?00k>c/0>SXj03Ti>@10@400
@D5103Xj>P0203/k>`0703Ph>00m?Cd0>c/k03/k>`0m?Cd0@D5103/k>`0203dm?@0>03`l?00i>CT0
>CTi03Ph>00g=cL0?Shn04E5A@0m?Cd0>CTi03Xj>P0n?Sh0@41003/k>`0j>SX20492@P0304a<C012
@T80?Cdm0080@D510180?Cdm03Hf=P0k>c/0?Shn0451@@0k>c/0>SXj0410@00o?cl0>SXj03lo?`0l
?3`0>SXj03`l?014A4@0?clo03hn?P0o?cl203/k>`0803Xj>P0n?Sh0?Shn04A4A01JFUX0EUIF04=3
@`0l?3`20410@080@D5101h0?clo03`l?00n?Sh0@d=305iNGP1^KVh0OGem07MgM`1aLG40JVYZ055A
D@1:BTX0Bd];04U9B@18B4P0D51@06UYJ@1^KVh0Rh^;09bLW02?Shl0QHF50861P@23Ph<0Hf=S05IF
EP1;Bd/0EEEE05IFEP19BDT204];B`0C05iNGP2NWYh0]kNg0;fm_@3?cll0fMWI0=SHf03MgMd0_Kfm
0::RXP2SXj<0_kno0=KFeP32`/80[Jf]09>CT`2?Shl0Xj>S0<30`0020;no_`0G0<k>cP33`l<0[Zj^
06m_K`1:BTX0ATI603hn?P14A4@0?clo0492@P0o?cl0B4Q805iNGP1lO7`0LG5a06UYJ@1gMgL0Hf=S
05UIF@21PH40WinO09BDU01DE5@00P15ADD01@1CDe<0KVi^08^;R`2>SXh0OWin0080LW9b02<0N7Qh
07alO01lO7`0ADE50410@00i>CT0?Cdm03Ph>00k>c/0@41003dm?@0n?Sh0>CTi03`l?010@400>CTi
03/k>`0m?Cd0>SXj0451@@0m?Cd0@41003lo?`1=CDd0FUYJ079bLP27QhL0KVi^04A4A00l?3`0>SXj
03Ti>@0n?Sh0@D5103/k>`0203hn?P0703Ti>@0k>c/0?Shn03lo?`0k>c/0>CTi03/k>`0203Ti>@08
03Xj>P12@T80DU9B06IVIP1WIfL0FEUI04E5A@10@40203Xj>P0:03Ti>@0k>c/0>3Ph03/k>`0n?Sh0
?3`l03dm?@0k>c/0>CTi0410@080?3`l0P0i>CT05@0k>c/0>3Ph03hn?P0m?Cd0AdM705YJFP1EEED0
DE5A04m?C`1ADE40AdM703`l?012@T80GEeM07AdM021PH40Ph>307emO@1WIfL0Cdm?04A4A00203`l
?00]05=CD`1QHF40J6QX07AdM01ZJVX0Cdm?06QXJ01TI6@0PH6109jNWP2`/;00]KFe0;^k^`2o_kl0
WIfM08R8R01kNg/0[Zj^0<K6aP2VYZH0VYZJ08>3P`1^KVh0Ng]k0861P@1`L700I6AT04i>CP10@400
E5AD06][J`2EUID0Xj>S09JFUP21PH40R8R808Z:RP1`L700IfMW07MgM`2ATI40X:2P0:n_[`3;bl/0
e]KF0080gmoO01D0h>3P0=[JfP3AdM40bl_;0<W9b@38b<P0]KFe0;2`/02[Zj/0WYjN096AT@20P800
LG5a07=cL`1eMGD0LG5a05mOG`1EEED0BTY:0451@@0o?cl00P0m?Cd01@0o?cl0?Shn04=3@`13@d<0
BTY:00gooooo000@ooooo`190;^k^`25QHD0JFUY05QHF01CDe<0EeMG05aLG01]KFd0Jf][05MGE`1:
BTX0B4Q804I6AP1:BTX0C4a<04e=C@1:BTX0BDU904Q8B014A4@0@D510492@P17AdL0B4Q804A4A010
@400A4A404I6AP14A4@0ADE504A4A011@D40Bd];05eMG@1CDe<0J6QX061PH01RHV80Fe]K05IFEP1?
Cdl0Fe]K08F5Q@27QhL0JFUY05=CD`19BDT0A4A404=3@`12@T80?Shn03/k>`11@D40?3`l03dm?@0l
?3`0?Shn03lo?`0n?Sh0?clo0451@@0n?Sh0?Cdm03`l?00j>SX0>c/k0492@P0n?Sh0@41003lo?`16
ATH0?Cdm03`l?00203Xj>P0903Ph>013@d<0@D5103dm?@17AdL0?Cdm03/k>`0m?Cd0@4100080?clo
00`0>c/k03dm?@0k>c/0>c/k03dm?@0h>3P0?Cdm03hn?P0h>3P0>c/k03Ph>00g=cL203`l?00403Ti
>@0k>c/0>SXj03dm?@80>CTi0P0o?cl05P0g=cL0?clo0410@00k>c/0?Shn03Xj>P10@400@D5106EU
I@1SHf<0G5aL04U9B@14A4@0>c/k03Ti>@10@400>SXj03dm?@0j>SX0?3`l03Ti>@0k>c/203dm?@0C
03Ti>@0l?3`0>SXj0451@@10@400>c/k03dm?@0n?Sh0?clo03/k>`0m?Cd0>SXj03`l?00m?Cd0>c/k
03Xj>P0l?3`0@d=30410@00203Xj>P0303dm?@0l?3`0>SXj0080>c/k00P0>CTi0410@00n?Sh0@d=3
0451@@0n?Sh0?Cdm03hn?P80>SXj00X0?Shn04A4A00j>SX0>SXj03hn?P0m?Cd0>SXj03`l?00k>c/0
@D510P0j>SX01P0k>c/0@D5103/k>`0n?Sh0>SXj03hn?P80?Cdm01<0A4A404I6AP0o?cl0?Cdm04=3
@`0m?Cd0@41003lo?`0l?3`0?clo03/k>`0m?Cd0@T9203/k>`0m?Cd0?Shn03lo?`10@400?Shn0080
@D5100T0?Cdm03Xj>P0n?Sh0?clo0492@P0m?Cd0?3`l0451@@10@4000P17AdL01@1:BTX0ADE50492
@P0o?cl0@4100080?Shn01@0A4A40451@@1;Bd/0J6QX07=cL`1`L700IfMW05MGE`1>CTh0AdM704A4
A00k>c/0?clo03hn?P0m?Cd0@41004A4A017AdL0De=C08>3P`80W9bL03`0[Zj^0;6a/@34a<@0d];B
0;fm_@2][Jd0`/;20;Jf]P2`/;00/K6a0:j^[P2g]kL0`/;20<O7a`3=cLd0fMWI0=[JfP3?cll0bLW9
0;Ng]`2<S8`0Jf][05]KF`1CDe<0DU9B05UIF@1]KFd0NGUi07]kN`1bLW80EeMG05mOG`1dM7@0OWin
06UYJ@1/K6`0UIFE0:^[Z`3>c/h0dM7A0;Jf]P2EUID0PX:208j>SP2XZ:P0e]KF0=gMg@2o_kl0R8R8
06a/K01>CTh0B4Q80451@@10@400?clo0410@00n?Sh0?clo0451@@0l?3`203hn?P0K03dm?@0l?3`0
>CTi0492@P11@D40>c/k03hn?P0j>SX0?Cdm0410@012@T80IFEU09bLW02c/k<0]KFe0:2PX01[Jf/0
C4a<03lo?`0k>c/0?3`l03Ph>00j>SX0@41003`l?011@D40?clo0080?Cdm00`0?3`l03Ti>@0i>CT0
>3Ph03dm?@0l?3`0A4A405EEE@1eMGD0MWIf04e=C@13@d<203Lg=`0D03Xj>P0o?cl0>SXj03Xj>P0i
>CT0>SXj03Ti>@0k>c/0?3`l03Xj>P0l?3`0>CTi03/k>`0h>3P0>CTi03Ph>00o?cl0AdM70451@@0l
?3`204=3@`0i04A4A013@d<0?3`l03dm?@0k>c/0?Shn04E5A@1RHV80QXJ605YJFP16ATH0A4A403dm
?@0j>SX0=cLg03dm?@1BDU80LG5a09:BTP1^KVh0Bd];0492@P0o?cl0Bd];06a/K01XJ6P0QXJ60;Rh
^03?cll0aLG509^KV`1XJ6P0D51@079bLP2KVi/0[Jf]07YjNP1ADE40CDe=061PH02@T900UYJF0861
P@1VIVH0IfMW061PH01LG5`0IFEU06QXJ01JFUX0CTi>04A4A017AdL0F5QH07alO02:RXX0Xj>S0080
d];B00l0bLW90;jn_P2i^KT0[:b/0:j^[P2RXZ80SHf=08R8R027QhL0UYJF09fMW@2@T900J6QX05EE
E@1:BTX00P12@T804@1?Cdl0EEEE04a<C01@D500B4Q804Y:BP1FEUH0IVIV071`L01iNGT0L71`06EU
I@1bLW80Ph>30:JVYP2`/;00][Jf00gooooo000@ooooo`0l05YJFP1VIVH0G5aL04e=C@17AdL0ATI6
04i>CP1;Bd/0C4a<04];B`1=CDd0BTY:059BDP1CDe<0Cdm?04U9B@14A4@0Cdm?04I6AP17AdL0@d=3
0492@P16ATH0@T9204E5A@13@d<0@D5104A4A016ATH0@T92065QH@1iNGT0TY:B0:FUY@2FUYH0NWYj
06IVIP1FEUH0Bd];04I6AP12@T80?Shn04=3@`12@T80ATI604M7A`14A4@0@T9204U9B@0m?Cd0?clo
03hn?P10@400>SXj0451@@0n?Sh0@D510410@00m?Cd0?3`l0P0m?Cd06P12@T80?Shn03/k>`0i>CT0
?Shn03lo?`1CDe<0D51@03`l?00o?cl0?Shn03`l?00h>3P0>SXj03/k>`0i>CT0?clo0410@00l?3`0
?Cdm03/k>`0o?cl0>c/k0451@@0n?Sh0?Cdm0P0i>CT0100n?Sh0>c/k03dm?@11@D4203Xj>P0Q03/k
>`0j>SX0>3Ph03/k>`0j>SX0?3`l03Xj>P0k>c/0>3Ph03lo?`0l?3`0@41003Ti>@0j>SX0>3Ph03`l
?00o?cl0?Cdm04a<C017AdL0EUIF051@D012@T80?Cdm03/k>`11@D40?3`l03lo?`0k>c/0?Cdm03/k
>`0l?3`0>SXj0080?clo00D0>CTi03dm?@10@400@41003Ti>@0203hn?P0S0410@00i>CT0>c/k04A4
A018B4P0>3Ph03hn?P17AdL0EEEE05eMG@1^KVh0DU9B04=3@`0k>c/0@41003lo?`0j>SX0?Cdm03/k
>`0m?Cd0>SXj03lo?`0m?Cd0@T9203`l?00n?Sh0>c/k03lo?`16ATH0>3Ph03/k>`0h>3P0=cLg03Xj
>P0n?Sh00`0j>SX0100k>c/0=cLg03Ph>00l?3`203Xj>P0;03`l?00j>SX0?Cdm03Xj>P10@400>SXj
0410@014A4@0?clo03`l?00k>c/00P0m?Cd01012@T80?Cdm03`l?010@40203`l?00O03Xj>P0n?Sh0
@41003`l?00n?Sh0?3`l03/k>`0h>3P0>CTi03/k>`0h>3P0?clo0451@@10@400?clo0451@@0m?Cd0
?Shn03`l?00j>SX0?Cdm03`l?00k>c/0?Cdm03hn?P1:BTX0EEEE05YJFP1LG5`0FEUI04I6AP0203lo
?`80?3`l00d0>SXj0410@018B4P0D51@05]KF`1^KVh0Lg=c07moO`2=SHd0TI6A09FEU@2KVi/0UYJF
0080PX:203T0QXJ607emO@1SHf<0G5aL06i^KP1lO7`0UIFE09:BTP2VYZH0YjNW0;6a/@3<c<`0a<C4
0;:b/P2LW9`0UYJF08N7Q`1hN7P0QHF50:b/[031`L40d];B0<O7a`35aLD0];Bd0:ZZZP2k^k/0c/k>
0<C4a02XZ:P0Xj>S09jNWP2c/k<0clo?0>3Ph03MgMd0e=CD0<?3``39bLT0c/k>0<_;b`3EeMD0f][J
0<g=c@2XZ:P0PX:205eMG@11@D40CDe=0410@00m?Cd0?3`l03/k>`10@400@T9204A4A00n?Sh00P0l
?3`203/k>`0M03dm?@0o?cl0?Cdm03/k>`0n?Sh0>c/k04E5A@1GEeL0G5aL08R8R030`<00dm?C0=KF
eP3=cLd0_kno0:FUY@25QHD0LG5a051@D00o?cl0>c/k04A4A00o?cl0@41003hn?P0o?cl0?Shn03`l
?010@4000P0j>SX04`11@D40AdM708N7Q`24Q8@0IVIV04Q8B00o?cl0>SXj03`l?00j>SX0>3Ph03De
=@0g=cL0>SXj03Ti>@0l?3`0>3Ph03lo?`0j>SX00P0h>3P05`0k>c/0?3`l03Ti>@0l?3`0?Cdm04e=
C@12@T80@d=303/k>`11@D40?clo03Xj>P0l?3`0?Cdm0451@@15ADD0BDU905UIF@1<C4`0@d=30410
@00i>CT0?clo00<0>CTi0200>c/k05IFEP1hN7P0HF5Q04A4A00j>SX0>3Ph03Ti>@0j>SX0@D5105MG
E`1nOWh0KFe]06YZJP1cLg<0FUYJ04Y:BP1WIfL0IVIV079bLP1OGel0ADE505ADE01_Kfl0UYJF0:j^
[P2YZJT0NGUi0820P01oOgl0NGUi06UYJ@80EEEE01`0G5aL05eMG@1JFUX0HV9R096AT@2i^KT0a<C4
0;Zj^P2^[Zh0SXj>07AdM01TI6@0Ogmo08R8R01mOGd0KVi^05YJFP1/K6`0UiNG0;Bd]02`/;00UIFE
06e]K@1ADE40E5AD06ATI01nOWh0WYjN0P2d];@03`2e]KD0[Jf]0;Zj^P31`L40_kno0<c<c034a<@0
`<300<G5a@3@d=00e=CD0=GEe@3Hf=P0b/[:0;no_`0=ooooo`004?ooool01P1>CTh0BTY:04Y:BP18
B4P0AdM704Q8B080ATI60140AdM704];B`1;Bd/0B4Q804a<C01>CTh0GemO07QhN01jNWX0J6QX04U9
B@1:BTX0ADE504=3@`15ADD0ATI604A4A00204E5A@80@d=300/0C4a<05mOG`1CDe<0CDe=055AD@1:
BTX0ATI60451@@16ATH0@D5104=3@`030492@P0303hn?P13@d<0ADE50080@D510P0n?Sh0400o?cl0
?3`l03dm?@0l?3`0?Shn03`l?014A4@0>SXj03dm?@0j>SX0?Cdm03hn?P0m?Cd0?3`l03Xj>P13@d<2
03hn?P0I0492@P0k>c/0?Cdm03dm?@0o?cl0?Shn0492@P0l?3`0>CTi03hn?P18B4P0?Cdm03Xj>P0k
>c/0@41003lo?`0l?3`0?Shn03lo?`0l?3`0?Cdm03`l?00o?cl0?Cdm03/k>`0203Xj>P0803/k>`0n
?Sh0>c/k03`l?010@400>SXj03Ph>00g=cL303`l?080?Cdm00L0?Shn03Lg=`0i>CT0>c/k03lo?`1@
D500E5AD0080>CTi01H0?Shn03dm?@0m?Cd0@T920410@011@D40>c/k03dm?@0l?3`0?Cdm03Ph>00l
?3`0?Cdm03/k>`0l?3`0@41003Xj>P0l?3`0=SHf03Xj>P0o?cl0?Shn0P0k>c/203`l?00904e=C@1o
Ogl0WinO09:BTP20P800Jf][04I6AP0m?Cd0>CTi0080@D5100@0>CTi03hn?P13@d<0AdM70P11@D40
2@0n?Sh0>c/k03`l?00k>c/0?3`l0451@@10@400>CTi03hn?P0203Ti>@0603/k>`0o?cl0>c/k03`l
?00j>SX0>c/k0P0g=cL03@0k>c/0>3Ph03/k>`0j>SX0>3Ph03`l?010@400?Cdm03`l?00m?Cd0>c/k
03Ph>00k>c/00P0m?Cd01`0i>CT0?Cdm03dm?@0k>c/0?Shn03Xj>P0m?Cd00P0n?Sh0100j>SX0?3`l
03`l?00l?3`203lo?`0303/k>`0o?cl0@T9200<0@T920P10@4000`0m?Cd0?Shn03Ti>@0203/k>`08
0492@P1:BTX0C4a<051@D01HF5P0AdM704E5A@11@D420492@P80?clo0380BTY:04A4A016ATH0DU9B
06ATI01ZJVX0Hf=S06][J`1HF5P0H61P06IVIP1WIfL0Kfm_07]kN`1/K6`0HV9R055AD@1EEED0GUiN
06a/K01jNWX0Ng]k07IfMP1_Kfl0K6a/07inOP1gMgL0MWIf0861P@1WIfL0EEEE06][J`2ATI40Shn?
06=SH`18B4P0Hf=S09JFUP2ATI40VIVI0:NWY`2][Jd0WinO0;Rh^03EeMD0fMWI0>7Qh@3Ogml0f][J
0<O7a`80bl_;01D0/K6a0:6QX@2BTY80PH6107MgM`1WIfL0JFUY07EeM@1/K6`0A4A40492@P10@400
@D5103`l?00n?Sh0@D5104];B`1EEED0@T9203hn?P10@4000P0m?Cd0400n?Sh0?Cdm03hn?P0l?3`0
?Shn04];B`1[Jf/0QhN709JFUP2][Jd0^KVi09nOW`2EUID0Ti>C07moO`1RHV8205EEE@0805ADE018
B4P0ATI604U9B@0o?cl0@41004I6AP0i>CT203/k>`0D03hn?P0m?Cd0>c/k03/k>`0i>CT0?clo051@
D01dM7@0RXZ:04i>CP0o?cl0>SXj03/k>`0o?cl0@T9203Xj>P0i>CT0>c/k03`l?00o?cl203Ph>005
03Xj>P0k>c/0>CTi03Xj>P0i>CT00P0m?Cd0400i>CT0@d=303dm?@0n?Sh0>3Ph03Ti>@0j>SX0>c/k
03dm?@0l?3`0>3Ph03`l?012@T80C4a<04=3@`0m?Cd203Ph>00j03/k>`0i>CT0>CTi03/k>`0i>CT0
?Cdm051@D01?Cdl0B4Q803/k>`0g=cL0>3Ph03hn?P1@D500JVYZ08^;R`1lO7`0Hf=S04A4A00e=CD0
>3Ph03/k>`0l?3`0?Shn03lo?`0k>c/0AdM705EEE@1eMGD0L71`06m_K`1hN7P0Kfm_04i>CP1<C4`0
AdM703lo?`1;Bd/0JFUY08b<S02^[Zh0^KVi09fMW@2PX:00[:b/096AT@1fMWH0EUIF055AD@1aLG40
Vi^K0:NWY`2GUiL0Kfm_05=CD`10@400@d=3059BDP80EeMG01T0C4a<04I6AP1>CTh0GEeM07IfMP2X
Z:P0c<c<0<o?c`30`<00a<C40<_;b`3Cdm<0g=cL0=WIf@3Ogml0h>3P0=;BdP30`<00bLW90;no_`2R
XZ80PH6106UYJ@1LG5`0DU9B00gooooo000@ooooo`80C4a<0P16ATH00`17AdL0B4Q804];B`0404A4
A00V04=3@`16ATH0@d=304=3@`15ADD0D51@05UIF@1=CDd0AdM704A4A01EEED0Ph>307=cL`1RHV80
EUIF04];B`15ADD0@d=304E5A@11@D40ATI605iNGP1nOWh0QhN707UiN@1aLG40Fe]K05=CD`17AdL0
A4A404E5A@14A4@0AdM704U9B@1:BTX0@d=303hn?P13@d<20492@P80?clo00P0?Shn0492@P11@D40
@d=30492@P13@d<0?Shn03lo?`<0?Shn0180@4100492@P14A4@0AdM703hn?P1FEUH0Lg=c05mOG`1X
J6P0N7Qh07MgM`1IFET0E5AD05aLG01DE5@0?Shn0410@016ATH20410@00503lo?`10@400?Shn0451
@@0l?3`00P0k>c/01@0j>SX0>c/k03/k>`0k>c/0?3`l0080?Shn01D0@41003dm?@0i>CT0?3`l03Xj
>P0l?3`0?Shn03Ph>00j>SX0?Shn03dm?@0i>CT0BDU905]KF`1WIfL0C4a<03hn?P0h>3P0>SXj03dm
?@12@T800P11@D4203`l?00@03Xj>P0l?3`0>SXj03hn?P0i>CT0>c/k03dm?@13@d<0>c/k03lo?`0l
?3`0=SHf03Xj>P0k>c/0>3Ph0451@@80?Shn01H0?clo04=3@`1;Bd/0Fe]K071`L01CDe<0@d=30451
@@0k>c/0>SXj03dm?@0l?3`0ATI605EEE@1JFUX0Fe]K04m?C`15ADD0@D510410@00k>c/0?Cdm0P0k
>c/02`0n?Sh0?3`l0410@00m?Cd0ATI604M7A`12@T80?3`l03Lg=`0k>c/0=cLg0080>CTi01T0>3Ph
03/k>`0k>c/0?Shn03`l?00k>c/0?3`l03dm?@0g=cL0>c/k03dm?@0n?Sh0>SXj03Ti>@0k>c/0?clo
03/k>`0m?Cd0>c/k03Ti>@0n?Sh0?Cdm03`l?00o?cl0?Shn0080?3`l00<0>CTi03/k>`0k>c/00P0o
?cl03011@D40?Cdm03hn?P0m?Cd0?Shn03Xj>P0k>c/0?3`l03lo?`0j>SX0?clo03hn?P80@T9200@0
>c/k03Ph>010@400>c/k0P11@D40600k>c/0@41004A4A014A4@0CDe=059BDP12@T80A4A40451@@0o
?cl0@41004=3@`15ADD0H61P07inOP2=SHd0MWIf065QH@1NGUh0EUIF059BDP1DE5@0GEeM05=CD`80
BDU900D0B4Q804M7A`1:BTX0D51@05eMG@0209>CT`0A075aL@1QHF40Hf=S06IVIP1BDU80BTY:0492
@P16ATH0B4Q8051@D01JFUX0OWin09^KV`2ZZZX0/;2`0<71`@33`l<00P31`L40@@3<c<`0g=cL0=cL
g03MgMd0d];B0;2`/02KVi/0UYJF09jNWP2LW9`0OGem08J6QP1lO7`0HV9R06e]K@1kNg/0S8b<092@
T02/[:`0Y:BT092@T01kNg/0Fe]K05UIF@1gMgL0Ti>C0:VYZ@2EUID0P82006m_K`1=CDd0D51@07al
O024Q8@0MWIf061PH01TI6@0Fe]K04Y:BP1=CDd0DE5A06YZJP1dM7@0JFUY05YJFP12@T80?Shn04A4
A017AdL0@D5103lo?`11@D40>c/k03`l?00m?Cd0?clo03dm?@0n?Sh0@41004I6AP1FEUH0MGEe055A
D@14A4@0?3`l0080>c/k00P0>SXj03lo?`0l?3`0>SXj03Ti>@0h>3P0=cLg03`l?080>c/k00H0?3`l
03Ti>@0k>c/0?3`l03/k>`0j>SX203Ti>@0803Lg=`0k>c/0>SXj03/k>`13@d<0GUiN051@D015ADD2
03/k>`0403lo?`0l?3`0=cLg03Hf=P80=cLg00@0>c/k03`l?00i>CT0>CTi0P0j>SX00`0i>CT0>SXj
03Ph>00203Ph>00703Ti>@14A4@0TY:B0;^k^`1fMWH0FEUI04I6AP0203Xj>P0?03De=@0m?Cd0>c/k
03`l?00n?Sh0GemO059BDP1<C4`0ADE503dm?@1GEeL0PH6108>3P`1GEeL0>CTi0080>SXj0100?Shn
04i>CP1cLg<0RHV90:JVYP2XZ:P0YJFU09BDU01/K6`0CDe=055AD@1QHF40K6a/079bLP1WIfL0EEEE
0P10@4007@1=CDd0D51@059BDP1MGEd0OGem09ZJVP2EUID0T92@09:BTP2CTi<0`L710=OGe`3?cll0
ZZZZ09fMW@2/[:`0][Jf0<30`039bLT0_;bl0;Vi^@2QXJ40OWin05eMG@1GEeL0Bd];0410@00m?Cd0
@D510080?Shn3Oooool0013ooooo00l0BTY:04Q8B01<C4`0CDe=04I6AP19BDT0ATI604A4A01ADE40
B4Q804U9B@1;Bd/0A4A40410@014A4@00`16ATH204=3@`0404E5A@13@d<0CTi>04Q8B0<0A4A40P11
@D405014A4@0?clo0410@00n?Sh0BDU9051@D01BDU80FEUI05mOG`1[Jf/0KFe]04U9B@11@D40AdM7
04A4A018B4P0G5aL079bLP1JFUX0?clo0P12@T820410@0030492@P18B4P0ATI60080A4A401T0@D51
03hn?P0n?Sh0?Shn0451@@0m?Cd0?clo04=3@`12@T80?Shn0410@01_Kfl0WYjN0::RXP24Q8@0NWYj
06a/K01HF5P0EUIF04M7A`0j>SX0?Cdm03Ti>@0n?Sh0>CTi0080?3`l00T0@D5103`l?00m?Cd0?clo
03Xj>P0n?Sh0>CTi0410@011@D400P0o?cl05`0k>c/0@41003dm?@0i>CT0?3`l03lo?`0m?Cd0>c/k
03lo?`0l?3`0>CTi03Xj>P0n?Sh0?3`l04e=C@1;Bd/0A4A403/k>`0n?Sh0ATI60410@00k>c/0?Cdm
0080?clo00D0@T9203dm?@0o?cl0?clo0451@@0203`l?00B03hn?P11@D40>SXj03Xj>P0o?cl0>CTi
03Lg=`0k>c/0>CTi03De=@0n?Sh0A4A403hn?P0o?cl0BTY:04E5A@14A4@0?clo0P0m?Cd09`11@D40
>SXj0410@01BDU80DE5A05IFEP1PH600DE5A04m?C`0m?Cd0@41004M7A`0o?cl0>c/k03dm?@0l?3`0
>CTi03Xj>P0k>c/0Bd];05IFEP1OGel0AdM703`l?00m?Cd0>c/k03dm?@0k>c/0?Shn03`l?00k>c/0
?Cdm03`l?00m?Cd0>c/k03Xj>P0l?3`0?clo03dm?@0203`l?00?0410@011@D40?3`l03hn?P13@d<0
?Shn03lo?`0l?3`0>CTi03hn?P0m?Cd0?Shn03dm?@0j>SX0?Shn0080>c/k0100@41003hn?P0n?Sh0
>SXj03dm?@10@400?clo03dm?@11@D40?Shn03`l?00n?Sh0@D5103Ti>@0l?3`0?Cdm0P0j>SX0:00n
?Sh0>SXj03Xj>P0n?Sh0?3`l03lo?`10@400A4A403lo?`0n?Sh0@D510410@012@T80?Cdm03lo?`11
@D40>c/k0492@P16ATH0FEUI05=CD`13@d<0?3`l03Xj>P11@D40@T9204A4A00o?cl0?Shn03/k>`0l
?3`0?Shn0492@P1JFUX0HF5Q05=CD`1<C4`0DE5A0492@P1CDe<205iNGP0B05QHF016ATH0@d=30451
@@1>CTh0FUYJ06][J`27QhL0Rh^;08b<S02CTi<0V9RH092@T01hN7P0Lg=c07inOP2EUID0^k^k0P2l
_;`0402CTi<0KVi^07emO@2;Rh/0VIVI0<30`036a/H0`L710;6a/@2c/k<0aLG50=WIf@3QhN40gmoO
0=SHf03>c/h20;jn_P090<C4a02][Jd0_;bl0;jn_P3<c<`0e]KF0<k>cP2j^[X0SHf=0080LW9b01<0
M7Ad0820P027QhL0OGem07alO027QhL0[Jf]0:BTY02MWId0UYJF08B4Q01PH600?clo03`l?00o?cl0
@D510410@00j>SX0?Shn0080?3`l01H0?Shn03lo?`0m?Cd0?Shn04I6AP1`L700EeMG07IfMP2e]KD0
TY:B05IFEP1KFe/0HF5Q04I6AP0l?3`0=cLg03lo?`0l?3`0?Cdm03Xj>P0h>3P0>SXj0P0i>CT00`0e
=CD0>SXj03Xj>P0203hn?P0<03`l?00j>SX0>3Ph03Ph>011@D40DU9B075aL@1eMGD0DU9B04A4A00h
>3P0=cLg0`0h>3P0200j>SX0>3Ph03Xj>P0k>c/0?3`l03Hf=P0l?3`0>3Ph0P0j>SX04`0f=SH0?3`l
03Xj>P0i>CT0ADE507IfMP2_[jl0S8b<04Y:BP12@T80>SXj03hn?P0o?cl0@d=305mOG`1PH600?Cdm
04m?C`1<C4`00P10@4002`1ADE40Lg=c07moO`1UIFD0@41003Ti>@0h>3P0ATI6069RHP23Ph<0OWin
0080UiNG02d0MWIf06EUI@1QHF40JFUY069RHP1TI6@0Lg=c08Z:RP2DU9@0Shn?075aL@1>CTh0G5aL
08:2PP2=SHd0YjNW0;>c/`2m_Kd0_;bl0:>SX`2<S8`0L71`07]kN`2ZZZX0bLW90:BTY02ATI40Q8B4
09ZJVP2EUID0KFe]05IFEP1HF5P0EUIF04U9B@15ADD0?Shn0410@01>CTh0FUYJ061PH01]KFd0SHf=
09RHV02FUYH03Oooool0013ooooo00@0Bd];04I6AP19BDT0BDU90P18B4P01017AdL0BDU904e=C@16
ATH204E5A@0904=3@`15ADD0A4A403lo?`15ADD0AdM704I6AP12@T80@d=30080A4A400H0ADE50451
@@13@d<0@D510410@012@T820451@@80@T9200@0@D510492@P12@T80@4100P16ATH01@13@d<0A4A4
0410@012@T80@D510080?clo01d0AdM704Q8B014A4@0AdM704I6AP13@d<0?Shn04A4A010@400A4A4
04=3@`1;Bd/0C4a<04U9B@0n?Sh0@41003dm?@12@T80?Shn0410@00n?Sh0@T9205IFEP1dM7@0NWYj
06EUI@1=CDd0@4100451@@0303`l?00403dm?@0k>c/0?clo03`l?080>SXj00<0?Shn0410@00h>3P0
0P0m?Cd03`0h>3P0>CTi03/k>`0i>CT0?Shn03lo?`0n?Sh0?clo03dm?@0k>c/0?clo03hn?P0l?3`0
>c/k03Xj>P0203`l?00603/k>`11@D40HF5Q06EUI@0m?Cd0>CTi0P0l?3`0100j>SX0@41004=3@`10
@40203dm?@0703/k>`13@d<0DE5A04];B`1FEUH0CDe=03`l?0020451@@0403/k>`0i>CT0?Cdm03`l
?080>c/k01@0?clo03Ph>00i>CT0>SXj03hn?P14A4@0ATI604A4A018B4P0@D5103/k>`0j>SX0?Shn
03/k>`0l?3`0BTY:04a<C00o?cl0@41004E5A@80?Cdm00H0?3`l03/k>`0m?Cd0?3`l03/k>`0m?Cd2
03`l?00303dm?@0o?cl0@4100080?clo0`0l?3`03011@D40?Cdm03hn?P11@D40Bd];059BDP1<C4`0
@41003/k>`0o?cl0?Cdm03/k>`80>CTi00H0=cLg03dm?@0l?3`0?Cdm03Xj>P0o?cl204M7A`0K03hn
?P0i>CT0?3`l03Xj>P0n?Sh0>CTi03`l?00i>CT0>SXj03Ph>00m?Cd0?Shn03dm?@0n?Sh0?3`l03Ph
>00g=cL0?Cdm03/k>`0n?Sh0?3`l03Xj>P0i>CT0>SXj03/k>`0j>SX0?Cdm0080>SXj00h0>CTi03dm
?@0l?3`0@41003hn?P11@D40@T9203lo?`0l?3`0?Shn03/k>`0l?3`0>c/k03`l?080>c/k00<0>SXj
03Ph>010@4000P0m?Cd0200l?3`0@d=30410@011@D40>CTi03Xj>P0n?Sh0>c/k0P0l?3`0<`12@T80
A4A40492@P15ADD0?3`l03lo?`0n?Sh0@41004a<C017AdL0?3`l04E5A@1=CDd0IfMW07moO`2?Shl0
Vi^K09ZJVP24Q8@0MWIf06][J`1jNWX0UIFE09jNWP21PH40Ng]k07emO@1/K6`0KVi^07IfMP25QHD0
T92@09RHV02[Zj/0[Zj^09fMW@2a/K40[Zj^09fMW@2JVYX0/k>c0<?3``35aLD0`/;20=7Ad@3<c<`0
`l?30<o?c`3<c<`0Xj>S06m_K`0205iNGP0H05aLG01gMgL0UYJF0;:b/P3<c<`0cLg=0=7Ad@39bLT0
^[Zj0;Jf]P2][Jd0UYJF06=SH`1CDe<0Bd];03lo?`17AdL0A4A404E5A@13@d<0?clo04A4A010@400
?Shn0P10@400600m?Cd0?Shn0492@P1>CTh0JVYZ0:>SX`2XZ:P0MgMg09VIV@38b<P0eMGE0;Rh^02R
XZ80/;2`0:ZZZP1iNGT0AdM703`l?018B4P0?Cdm03`l?00i>CT0>SXj03Ph>080>SXj01d0?Cdm03Lg
=`0h>3P0>SXj03Ph>010@400EUIF065QH@1FEUH0Shn?07QhN01[Jf/0H61P03lo?`0i>CT0>3Ph03`l
?00j>SX0>CTi03Ph>00k>c/0?3`l03Lg=`0j>SX0=SHf03Xj>P0m?Cd0>CTi03/k>`0203Xj>P0I03hn
?P1NGUh0LW9b07MgM`21PH40Ng]k055AD@0j>SX0>c/k05EEE@1kNg/0FUYJ05UIF@1jNWX0HV9R03hn
?P0k>c/0>SXj03lo?`18B4P0De=C04=3@`0l?3`0>3Ph03Xj>P020410@00F065QH@1^KVh0GemO04i>
CP1FEUH0BTY:03Ti>@16ATH0KVi^08B4Q01kNg/0P82009>CT`2@T900IfMW04U9B@0k>c/0?clo05=C
D`1lO7`0QHF508Z:RP80VYZJ00D0NWYj05mOG`1IFET0L71`08f=S@020:ZZZP0D09RHV024Q8@0Ph>3
0820P01GEeL0GUiN06m_K`1`L700Lg=c08F5Q@2DU9@0UYJF09RHV02b/[80_Kfm0<30`035aLD0d];B
0=SHf03Cdm<=ooooo`004?ooool204U9B@0504Q8B017AdL0AdM704I6AP14A4@00`17AdL02P15ADD0
ATI604M7A`14A4@0@T9203lo?`13@d<0AdM704E5A@12@T8204=3@`0304A4A012@T80@T9200<0@D51
00L0?clo0451@@11@D40@d=304M7A`1?Cdl0C4a<0080?clo00@0@T9203lo?`0n?Sh0?Shn0P0o?cl0
8P10@400?clo04A4A013@d<0?clo04A4A013@d<0@41004=3@`12@T80DE5A06=SH`1[Jf/0H61P06MW
I`1^KVh0DU9B0451@@10@400?clo059BDP1QHF40PH6108:2PP1lO7`0MGEe055AD@19BDT0@D5103Xj
>P0m?Cd0?Shn0410@00o?cl203hn?P80>SXj0P0m?Cd0400g=cL0?3`l03/k>`0m?Cd0@T9203`l?00i
>CT0>SXj03lo?`0m?Cd0>c/k03hn?P0j>SX0@D5103/k>`0m?Cd203Xj>P0?03Ti>@0m?Cd0>c/k03/k
>`0m?Cd0BDU907]kN`25QHD0EeMG03lo?`0j>SX0?Cdm03Xj>P1<C4`0BDU90080AdM700H0C4a<079b
LP1SHf<0ATI604A4A010@40203hn?P0403/k>`0l?3`0>c/k03Xj>P80?3`l0P0n?Sh07P0k>c/0?3`l
03Ti>@0k>c/0@D510410@014A4@0@T920410@00h>3P0?3`l03/k>`0i>CT0>SXj03Ti>@0m?Cd0?Shn
0410@011@D40@4100492@P11@D40?clo03`l?00j>SX0>c/k03Xj>P0m?Cd0@D5104A4A080?Cdm02L0
?3`l0410@013@d<0@T920410@00o?cl0?3`l03Xj>P0l?3`0?Cdm03lo?`19BDT0AdM704A4A00m?Cd0
@41004=3@`11@D40@41003dm?@1;Bd/0HV9R05eMG@17AdL0BTY:04m?C`1DE5@0Bd];03lo?`0n?Sh0
>c/k03Ti>@0k>c/0@D5103lo?`0m?Cd0?3`l03dm?@0n?Sh00P0l?3`0500i>CT0?Cdm03dm?@0j>SX0
>3Ph04A4A011@D40?Shn03/k>`0m?Cd0>SXj03/k>`10@400?Cdm03Ph>00j>SX0>c/k03lo?`0n?Sh0
?3`l0P0o?cl203`l?00E0410@011@D40@41003Xj>P0o?cl0>c/k03Xj>P0m?Cd0@D5103Ti>@0h>3P0
?clo03dm?@0j>SX0?Shn03/k>`0n?Sh0>c/k03Ti>@0j>SX0>CTi0080@d=300d0?Cdm0451@@0f=SH0
>CTi03/k>`0l?3`0A4A404E5A@0n?Sh0A4A404];B`1HF5P0J6QX0080JVYZ00/0IfMW05mOG`1IFET0
C4a<04];B`1<C4`0Hf=S08>3P`2@T900P82006QXJ002069RHP10061PH01QHF40MWIf08n?S`2NWYh0
][Jf0<K6aP2b/[80UYJF09>CT`2>SXh0PH61079bLP1hN7P0Ti>C0:2PX02a/K40`L710<c<c03>c/h0
b<S80<O7a`2g]kL0];Bd0;Fe]@30`<00ZJVY0::RXP2UYJD0TI6A09bLW02NWYh0TY:B07inOP27QhL0
X:2P09ZJVP1hN7P0IFEU06e]K@1cLg<0R8R807QhN01CDe<0Cdm?06a/K02HV9P0UiNG08^;R`1jNWX0
K6a/07emO@1jNWX0TY:B0:VYZ@3:b/X0gMgM0<O7a`28R8P0GemO06QXJ01iNGT0NWYj069RHP80Bd];
01l0@d=303hn?P0n?Sh0=CDe03/k>`0n?Sh0>CTi03Ph>00k>c/0>SXj03/k>`0l?3`0>c/k04=3@`1=
CDd0H61P04=3@`1;Bd/0NGUi08n?S`2HV9P0][Jf0:NWY`1ZJVX0?clo03Ph>00k>c/0?Cdm03Hf=P0e
=CD0>3Ph00<0>SXj00D0>CTi03Xj>P0g=cL0>CTi03/k>`0203Xj>P0C03Ph>00n?Sh0N7Qh09RHV01^
KVh0ATI60492@P0l?3`0>CTi03Xj>P0l?3`0FEUI04E5A@0j>SX0<c<c03Lg=`0e=CD0=cLg03dm?@02
03hn?P0303/k>`0j>SX0=SHf0080>SXj00D0?Shn04A4A015ADD0?3`l03Ti>@0203`l?00_03/k>`1@
D500Jf][06m_K`1mOGd0J6QX04U9B@1:BTX0C4a<0451@@0i>CT0@41005QHF01eMGD0WIfM09^KV`1W
IfL0Bd];0451@@10@400A4A405iNGP2BTY80][Jf0;Bd]02c/k<0QXJ607AdM01_Kfl0J6QX06ATI01g
MgL0UYJF0:RXZ02LW9`0WinO0:j^[P32`/80`L710;bl_02b/[80]KFe0<S8b039bLT0`<300<?3``2b
/[803Oooool0013ooooo0P1:BTX01@19BDT0ATI604Q8B015ADD0A4A40080BDU90P17AdL01@1;Bd/0
ADE504=3@`11@D40@T920080@d=300D0ATI604M7A`14A4@0@d=30451@@020492@P0603lo?`15ADD0
B4Q80492@P14A4@0ADE50P12@T80100o?cl0@4100492@P10@40303lo?`090410@00o?cl0?clo0451
@@15ADD0@d=304A4A010@400A4A40080?Shn0180@T920410@013@d<0B4Q804A4A016ATH0Bd];04Q8
B00o?cl0?Shn04A4A01GEeL0U9BD092@T027QhL0KVi^04i>CP11@D420492@P80@41001L0Bd];05YJ
FP18B4P0EUIF04e=C@13@d<0?Shn03Ti>@0l?3`0@4100451@@0k>c/0?Cdm03Ti>@0m?Cd0@41003Xj
>P0k>c/0@41003dm?@0j>SX0?Cdm03hn?P0203lo?`80>SXj00l0>c/k03hn?P0m?Cd0@D5103`l?013
@d<0C4a<04];B`12@T80?Shn03`l?00n?Sh0>CTi0410@00k>c/00P0m?Cd04`10@400ATI604Y:BP0m
?Cd0?Shn03`l?00m?Cd0>3Ph03`l?00m?Cd0>c/k03hn?P0m?Cd0AdM704E5A@11@D40@41003/k>`0l
?3`00P15ADD0501<C4`0AdM70492@P0m?Cd0?3`l03Ph>00k>c/0>SXj04=3@`0n?Sh0>CTi03dm?@0g
=cL0@41003/k>`0o?cl0?Cdm03hn?P0j>SX0?Shn0P11@D404010@400@D5103dm?@11@D40?clo0492
@P10@400>c/k03lo?`0n?Sh0@4100492@P11@D40?Cdm03lo?`0m?Cd203hn?P0<03`l?010@400A4A4
04i>CP1HF5P0Lg=c0820P023Ph<0QhN708R8R01WIfL0C4a<0P1;Bd/03010@400?Cdm03`l?00i>CT0
?3`l04=3@`18B4P0C4a<04Q8B010@400@T9204=3@`80?clo00`0@D5103lo?`10@400@T9203Xj>P0n
?Sh0@D5103lo?`0l?3`0>c/k03Ph>00l?3`203Xj>P0<0410@00i>CT0>CTi03Ti>@0n?Sh0?Cdm03lo
?`0n?Sh0?Cdm03Xj>P0k>c/0?clo0P10@40203hn?P0403Ti>@0f=SH0?Shn03hn?P80@4100P0l?3`2
03Xj>P0503`l?012@T80?clo03/k>`0m?Cd00P11@D40300i>CT0?Cdm03lo?`0l?3`0>CTi03Xj>P0k
>c/0?Shn0410@015ADD0AdM704=3@`80?clo00<0?Shn0451@@11@D400P0o?cl03015ADD0B4Q804m?
C`1PH600I6AT05iNGP1ADE40@D5103lo?`11@D40@d=3059BDP80Hf=S0540MGEe08V9R@2<S8`0P820
07IfMP1QHF40FUYJ04e=C@1HF5P0OGem092@T02VYZH0[Zj^0:FUY@2QXJ40X:2P09fMW@2FUYH0XZ:R
0;:b/P2c/k<0[jn_0:>SX`2ZZZX0/k>c0;2`/02HV9P0Ng]k07IfMP2JVYX0ZZZZ0:>SX`2YZJT0YZJV
0;Jf]P38b<P0eMGE0=[JfP3?cll0Z:RX0:>SX`3EeMD0f][J0>7Qh@3Ogml0clo?0<G5a@3:b/X0`L71
0=7Ad@3IfMT0iNGU0=kNgP33`l<0XJ6Q08N7Q`1/K6`0G5aL04i>CP0o?cl0?3`l0451@@0n?Sh0>c/k
0451@@0l?3`0@D510492@P11@D40?clo03hn?P16ATH0F5QH05MGE`1NGUh0TI6A0:j^[P29RHT0D51@
075aL@2NWYh00P2YZJT02@2RXZ80OGem04I6AP0m?Cd0>c/k03Ph>00l?3`0?Shn03`l?00203/k>`04
03Xj>P0i>CT0>c/k03Xj>P80>CTi00P0>c/k03dm?@0i>CT0?Shn04A4A01FEUH0Hf=S04];B`80>3Ph
00D0>SXj03dm?@0j>SX0>SXj03Ti>@0203`l?00503/k>`0i>CT0?3`l03Xj>P0m?Cd00P0i>CT0400e
=CD0?clo03/k>`11@D40?Shn03Lg=`0i>CT0>3Ph03Ti>@0h>3P0?3`l05eMG@1UIFD0MgMg05UIF@13
@d<203Xj>P0P03`l?00d=3@0>SXj04a<C01XJ6P0SHf=08R8R01RHV80CDe=0451@@0e=CD0C4a<06a/
K028R8P0QXJ607alO021PH40IVIV055AD@18B4P0A4A406UYJ@2@T900Zj^[0;6a/@2i^KT0a<C40=?C
d`3<c<`0_;bl0;6a/@2SXj<209bLW0070:6QX@2TY:@0V9RH079bLP1JFUX0BTY:04I6AP0=ooooo`00
4?ooool0201=CDd0BTY:04];B`17AdL0ATI604Q8B01>CTh0BDU90P17AdL04P19BDT0B4Q804Q8B019
BDT0ADE504I6AP14A4@0BTY:04U9B@14A4@0@d=30492@P13@d<0A4A404M7A`13@d<0@T9204A4A080
@4100P0o?cl02P11@D40?Shn03hn?P12@T80A4A40410@00m?Cd0?3`l0492@P14A4@20451@@0604E5
A@11@D40@d=30492@P10@400?clo0P0m?Cd01@0o?cl0AdM704A4A01<C4`0B4Q80080@d=300T0@D51
0410@012@T80@D5104Q8B012@T80A4A403lo?`0n?Sh00P0k>c/0200n?Sh0@D5103lo?`12@T80?Shn
0492@P15ADD0AdM70P11@D402@0k>c/0@d=305eMG@1`L700I6AT03`l?00o?cl0?3`l03dm?@0203/k
>`0:03dm?@0i>CT0?Cdm03lo?`0n?Sh0A4A40451@@0o?cl0A4A403`l?080>SXj01@0ADE505=CD`1B
DU80?Shn03/k>`0m?Cd0@D5103`l?010@400?3`l03/k>`0i>CT0@41003hn?P0k>c/0?Shn04=3@`0n
?Sh0?Cdm0451@@80?Shn01@0>CTi03/k>`0m?Cd0?Cdm03Ph>012@T80>c/k03`l?013@d<0DU9B05iN
GP1TI6@0C4a<04Q8B010@400?Cdm03`l?00n?Sh0@D5103/k>`80@T9200H0?Cdm04I6AP1ADE40BDU9
0451@@0n?Sh203`l?00803lo?`0j>SX0?Shn03`l?00m?Cd0?3`l0451@@0o?cl203/k>`0:03lo?`14
A4@0?Cdm03dm?@0g=cL0?3`l03dm?@0l?3`0@41003Xj>P80?Shn01L0?Cdm04E5A@15ADD0C4a<055A
D@1=CDd0FEUI06m_K`1/K6`0DE5A04];B`11@D40?Shn03Xj>P0m?Cd0>c/k0410@013@d<0AdM704i>
CP1DE5@0C4a<04A4A00203`l?00304A4A010@400?3`l0080@D5100D0@4100492@P14A4@0CDe=04I6
AP0203lo?`80>c/k00H0?Cdm0492@P0m?Cd0>c/k03`l?00n?Sh203Ti>@80>SXj00P0@d=303hn?P0j
>SX0?Cdm03hn?P0k>c/0?Shn0410@080>SXj00T0=cLg03`l?01CDe<0?Shn03dm?@0n?Sh0>SXj03hn
?P0j>SX00P0l?3`00`14A4@0CDe=03dm?@0403/k>`0803dm?@0o?cl0?Cdm03dm?@11@D40ADE504i>
CP16ATH203dm?@0;03lo?`0k>c/0?3`l03hn?P0k>c/0?Cdm04I6AP1=CDd0ATI603Xj>P10@4000P13
@d<02@10@400@T9203Ti>@0o?cl0@D5104U9B@1=CDd0@d=304Y:BP0205ADE01P04Y:BP11@D40?Cdm
0451@@1CDe<0PX:20:>SX`2/[:`0QhN706UYJ@1HF5P0D51@05]KF`1IFET0FUYJ051@D01TI6@0OGem
07AdM01iNGT0UIFE0:VYZ@33`l<0/;2`0;Bd]02h^;P0]kNg0<G5a@3:b/X0^[Zj0;jn_P38b<P0bLW9
0<[:bP35aLD0b/[:0<?3``2c/k<0`<300=;BdP38b<P0dM7A0=GEe@3:b/X0[Jf]09JFUP2<S8`0TY:B
09jNWP30`<00emOG0<_;b`2k^k/0[Zj^0:ZZZP2RXZ80S8b<05]KF`1?Cdl0De=C05MGE`1HF5P0HF5Q
07moO`2CTi<0YZJV0::RXP29RHT0Vi^K0<30`03Hf=P0bLW90=CDe03Hf=P0`/;20:2PX01mOGd0Q8B4
08>3P`1MGEd0BTY:0451@@0l?3`0?clo04Q8B01CDe<0NGUi08j>SP1EEED0?clo03dm?@0j>SX0?3`l
03Xj>P0k>c/0>SXj0P0l?3`01`0k>c/0>CTi04i>CP1gMgL0KFe]04U9B@15ADD00P0l?3`0100m?Cd0
>SXj03`l?00i>CT203`l?00403Ph>00g=cL0=SHf03Xj>P<0=cLg00@0>SXj03/k>`1:BTX0CDe=0P0h
>3P07@0l?3`0=SHf03Hf=P0l?3`0=SHf0451@@10@400ATI604=3@`11@D40?3`l03Lg=`0h>3P0=SHf
0492@P1DE5@0Ogmo0:VYZ@2WYjL0LG5a0492@P0i>CT0>3Ph03Ti>@1DE5@0/k>c0:b/[01cLg<0ADE5
0080?Cdm01P0>c/k03`l?01RHV80W9bL0<S8b030`<00OGem06UYJ@2DU9@0bl_;0=;BdP34a<@0ZZZZ
0;2`/02JVYX0NGUi07emO@29RHT0KFe]05QHF01OGel0LG5a0820P024Q8@=ooooo`004?ooool00`1=
CDd0BTY:04];B`0204Q8B00<04Y:BP15ADD0ATI604E5A@17AdL0A4A404Y:BP1<C4`0ATI604A4A015
ADD0@d=30P16ATH03P12@T80@D510451@@13@d<0@D5104A4A010@400@T920451@@0n?Sh0?clo0410
@00l?3`0?Cdm0`12@T807`0k>c/0@D5104=3@`0l?3`0@41003lo?`10@400?Cdm0492@P0o?cl0@D51
03hn?P12@T80>c/k04=3@`15ADD0?clo04=3@`0o?cl0A4A403dm?@10@400?Shn03`l?011@D40?3`l
03dm?@13@d<0@T9203hn?P10@4000P14A4@02012@T80@D5103hn?P0k>c/0@D5103`l?00n?Sh0>SXj
0`10@400:P0n?Sh0?Cdm0410@014A4@0Bd];04E5A@19BDT0?Shn03Ti>@0n?Sh0?3`l03/k>`0o?cl0
>CTi03Xj>P0l?3`0@41004a<C01DE5@0KFe]04I6AP0m?Cd0>c/k04I6AP1IFET0ADE503Xj>P0h>3P0
>SXj0451@@0m?Cd0?Shn0492@P11@D40?Shn0410@00l?3`0@D5103/k>`0j>SX0@41004Q8B080@T92
02X0?clo03Hf=P0i>CT0>CTi03dm?@0h>3P0>CTi03dm?@17AdL0DE5A05EEE@1BDU80@d=303/k>`10
@400?Cdm03/k>`11@D40>SXj03Ti>@12@T80Cdm?06UYJ@1ZJVX0N7Qh05iNGP18B4P0Bd];0492@P11
@D40?Shn03lo?`0n?Sh0>c/k03`l?01<C4`0D51@04E5A@18B4P0ATI604M7A`0n?Sh203/k>`0>03lo
?`0i>CT0?Shn03`l?016ATH0Cdm?04A4A00k>c/0@D5103Ph>00k>c/0B4Q804M7A`0k>c/20410@00D
04e=C@1DE5@0>3Ph03lo?`13@d<0>c/k03Xj>P0k>c/0?3`l0410@014A4@0B4Q803lo?`0h>3P0?clo
03/k>`10@400@D5104Q8B00o?cl203`l?080?Shn00H0A4A404e=C@12@T80ATI603lo?`12@T8203dm
?@80?Shn00X0?3`l03dm?@0n?Sh0?Cdm03`l?00n?Sh0>CTi03/k>`0l?3`0>SXj0P0m?Cd0400j>SX0
?3`l03`l?00n?Sh0?3`l03dm?@18B4P0DU9B04U9B@0l?3`0>3Ph03hn?P0m?Cd0@D510410@00i>CT2
03Xj>P0403dm?@15ADD0@D5103`l?080>CTi00H0>c/k03`l?00j>SX0ATI604=3@`0o?cl203hn?P04
03Ph>00i>CT0=SHf03/k>`80>3Ph0140AdM704=3@`1:BTX0ADE504A4A00g=cL0?Cdm04E5A@0n?Sh0
?3`l03Xj>P0n?Sh0B4Q804A4A00m?Cd0@41003`l?00203hn?P0P03Xj>P0k>c/0>3Ph04a<C01]KFd0
UYJF0:2PX02CTi<0QXJ6065QH@14A4@0@41004E5A@1:BTX0@D5104a<C01KFe/0KVi^08R8R026QXH0
OGem09jNWP2WYjL0X:2P09NGU`2KVi/0VYZJ09bLW02h^;P0a<C40:RXZ02d];@20<;2`P0O0;jn_P3=
cLd0e=CD0;Vi^@31`L40a/K60=CDe033`l<0aLG50=GEe@3:b/X0WIfM08Z:RP2QXJ40`l?309nOW`2?
Shl0XJ6Q0=KFeP33`l<0]kNg0<71`@37alL0][Jf09ZJVP2?Shl0/;2`0<_;b`35aLD0d];B0=gMg@02
0>CTi00L0>OWi`3GemL0h>3P0>SXj03Rh^80eMGE0=_Kf`3De=@0_kno08n?S`1mOGd0M7Ad06=SH`1F
EUH0Bd];055AD@1QHF40P82009ZJVP2QXJ40^k^k0:>SX`1YJFT0KVi^06YZJP1QHF40EUIF0410@080
?clo00`0C4a<06UYJ@1OGel0ATI608R8R02GUiL0De=C0451@@0h>3P0=cLg03`l?00j>SX203dm?@05
03Lg=`0k>c/0>CTi03/k>`0g=cL00P0m?Cd0@00k>c/0?3`l03Xj>P1:BTX0GEeM059BDP0o?cl0=SHf
03Ph>00d=3@0=cLg03Ti>@0j>SX0>3Ph03/k>`0i>CT0=SHf038b<P0h>3P0<c<c03Ti>@0e=CD0Bd];
08J6QP2ATI40R8R806i^KP1:BTX0?Shn03@d=00i>CT0=SHf03dm?@2;Rh/0X:2P05EEE@0l?3`0=SHf
03`l?00m?Cd0D51@08>3P`2k^k/0bl_;09>CT`1/K6`0ADE507=cL`2SXj<0b<S80;fm_@2[Zj/0UiNG
08^;R`2GUiL0WIfM0:JVYP2SXj<0QHF508V9R@2ZZZX0`/;20<S8b03;bl/=ooooo`004?ooool0401=
CDd0BTY:04];B`18B4P0AdM704Y:BP15ADD0ATI604A4A019BDT0AdM704E5A@16ATH0@d=304E5A@16
ATH204A4A0<0@d=300/0?Cdm04A4A013@d<0@T920410@00n?Sh0@4100451@@13@d<0@D510492@P02
03dm?@0<03hn?P0o?cl0>SXj03`l?010@400?Cdm0492@P10@400@D5103hn?P11@D40?3`l0P15ADD0
1`11@D40@T9204=3@`15ADD0@41003`l?00o?cl00P11@D40200j>SX0@4100451@@0l?3`0@41004=3
@`0m?Cd0?3`l0P0o?cl01P0n?Sh0?clo0410@010@400?clo03/k>`<0?Cdm00`0?Shn03lo?`0o?cl0
?clo03hn?P0o?cl0?3`l03hn?P0j>SX0>c/k0492@P1:BTX204Q8B00X04U9B@10@400?3`l03Xj>P1D
E5@0LG5a07EeM@1SHf<0ADE504A4A00i>CT0>c/k03dm?@0o?cl0?Shn04=3@`10@400>SXj03`l?01?
Cdl0A4A403`l?00k>c/0@D5103hn?P0i>CT0>c/k0451@@0i>CT0?Cdm0492@P10@400?Shn03Xj>P14
A4@0@41004E5A@11@D40>SXj03`l?080@41000D0@d=304A4A010@400?Cdm03hn?P0203dm?@0?04=3
@`12@T80CDe=06EUI@1SHf<0EUIF06i^KP2LW9`0UYJF07IfMP1:BTX0EUIF06e]K@1EEED0@4100080
?Cdm00T0>c/k03dm?@0o?cl0ADE504U9B@14A4@0D51@04a<C017AdL00P11@D402@0o?cl0BTY:04i>
CP1JFUX0KVi^06=SH`1@D500@D510410@00203hn?P040410@01=CDd0?clo03`l?080@D5100P0>CTi
0410@010@400?clo03/k>`0n?Sh0>c/k03dm?@<0?Shn00<0?Cdm03Xj>P0l?3`00P10@40203dm?@05
04A4A011@D40?clo03`l?015ADD00P11@D404@12@T80?clo03dm?@12@T80@d=303dm?@11@D40B4Q8
03hn?P0m?Cd0>SXj0410@013@d<0@D5103hn?P0k>c/0?3`l0080>c/k0P0m?Cd203hn?P0C03lo?`15
ADD0ADE504M7A`14A4@0@4100451@@0o?cl0>c/k03Ph>00l?3`0@T9203lo?`0i>CT0>c/k03`l?00n
?Sh0?Cdm03hn?P0203/k>`0403Xj>P0k>c/0>c/k03Xj>P80?Shn01P0?Cdm03`l?00l?3`0>3Ph03Xj
>P0n?Sh0@D5104=3@`16ATH0DE5A051@D012@T80@41003lo?`0k>c/0>CTi03/k>`0i>CT0?Cdm03`l
?010@400?Shn03`l?00k>c/20410@00<03Ph>00n?Sh0?Cdm03dm?@1>CTh0SXj>08f=S@1eMGD0H61P
04];B`18B4P0@T920`0o?cl06`1>CTh0DE5A05IFEP1TI6@0MGEe09^KV`2JVYX0P82008J6QP1kNg/0
L71`075aL@1lO7`0Q8B40:2PX02KVi/0UiNG09JFUP2KVi/0XZ:R0:j^[P2/[:`0/K6a0;2`/02TY:@0
/k>c0<O7a`020=GEe@0=0=SHf03Ng]h0emOG0<K6aP2n_[h0d=3@0>KViP3Ng]h0bLW90<71`@3Fe]H0
e=CD0=_Kf`020=oOg`0:0<?3``2b/[80];Bd0<?3``3AdM40c/k>0=;BdP3Hf=P0hN7Q0>;RhP80h>3P
00T0g]kN0<S8b02OWil0Ph>308V9R@23Ph<0Ogmo08^;R`1kNg/00P1/K6`07@27QhL0QXJ6092@T02_
[jl0]KFe0;Rh^01oOgl0J6QX06e]K@1dM7@0SHf=0::RXP2`/;00VIVI07UiN@24Q8@0XJ6Q0;jn_P37
alL0_[jn0820P023Ph<0LG5a04m?C`1;Bd/0AdM703lo?`0m?Cd0>SXj0080>c/k00l0?3`l03Xj>P0k
>c/0>c/k0492@P1BDU80CDe=04=3@`0o?cl0GEeM05aLG016ATH0?3`l03Xj>P0h>3P00P0l?3`02015
ADD0?Cdm03Ph>00g=cL0?3`l03Ph>00j>SX0>3Ph0P0e=CD0600g=cL0GEeM096AT@24Q8@0GemO04Q8
B00j>SX0=cLg03Xj>P0k>c/0BDU907UiN@1WIfL0EeMG04U9B@0h>3P0>SXj0451@@1BDU80QhN70:BT
Y02WYjL0R8R8061PH080@T920180E5AD08n?S`2g]kL0/k>c08V9R@1bLW80LG5a0:JVYP2o_kl0W9bL
08J6QP1hN7P0Lg=c096AT@2f][H0_kno0;^k^`2n_[h=ooooo`004?ooool01`1<C4`0Bd];04U9B@18
B4P0ATI604U9B@17AdL00P15ADD00`13@d<0ATI604I6AP0404=3@`030492@P11@D40@D510080A4A4
00X0@41004A4A013@d<0@d=30410@00l?3`0?Shn0410@011@D40?3`l0`10@400200n?Sh0?Cdm03lo
?`0o?cl0@D5103lo?`10@400A4A40P13@d<02P12@T80?clo0451@@14A4@0ADE504A4A012@T80ADE5
03lo?`13@d<20410@00:03hn?P10@400?3`l03lo?`11@D40@41003lo?`12@T80?Cdm0410@080A4A4
0P0o?cl203hn?P070451@@10@400?3`l03lo?`0l?3`0>c/k03Xj>P020410@00`0451@@14A4@0@T92
03`l?00n?Sh0AdM704e=C@1DE5@0FUYJ051@D017AdL0@T920451@@14A4@0CTi>04I6AP0l?3`0?Shn
04=3@`18B4P0CTi>05IFEP11@D40@T92055AD@1?Cdl0ATI60451@@1CDe<0Hf=S06IVIP1CDe<0EEEE
0451@@0k>c/0@41004M7A`1MGEd0C4a<0410@00n?Sh0@d=304M7A`1=CDd0EEEE04e=C@11@D40A4A4
0`12@T801P0l?3`0>SXj03Ti>@0n?Sh0ADE504A4A080DE5A01<0ATI604Q8B01DE5@0D51@04I6AP12
@T80B4Q804E5A@14A4@0@T9204E5A@1ADE40@T9203hn?P0i>CT0?3`l0410@00n?Sh0@T920080@410
00<0B4Q804M7A`1:BTX00P10@4001P14A4@0B4Q804i>CP1IFET0GUiN05EEE@80ADE500H0ATI603lo
?`11@D40@T9203dm?@13@d<303hn?P0903/k>`0n?Sh0>c/k03lo?`0l?3`0@d=304I6AP13@d<0@410
00<0?Shn00<0?3`l03/k>`0j>SX00P0m?Cd0200o?cl0>CTi0410@011@D40BDU904I6AP10@400?3`l
0P10@4001`0n?Sh0>c/k03`l?011@D40?Shn04=3@`15ADD00P0m?Cd02@16ATH0FEUI04I6AP0m?Cd0
?clo0410@00o?cl0>c/k0410@0020451@@0G03lo?`15ADD0EEEE05YJFP19BDT0?Shn0410@00n?Sh0
?clo03dm?@0k>c/0=cLg03dm?@10@400?3`l03Ti>@0h>3P0>SXj03`l?00j>SX0?Shn0410@012@T80
0P0l?3`07@0k>c/0>SXj03hn?P0i>CT0>3Ph03Xj>P0k>c/0>CTi03Hf=P0m?Cd0FUYJ06IVIP1>CTh0
A4A40451@@0k>c/0?Cdm03Ph>00m?Cd0>CTi03dm?@0l?3`0>c/k03lo?`0n?Sh0?Cdm03`l?00k>c/0
=SHf0080?Cdm00l0>CTi03lo?`1BDU80Ph>307IfMP1:BTX0@d=303/k>`0n?Sh0>SXj03hn?P1<C4`0
Cdm?05YJFP1XJ6P00P1VIVH0L01KFe/0BTY:05QHF017AdL0@41004I6AP1JFUX0K6a/07AdM021PH40
S8b<08V9R@1gMgL0N7Qh08>3P`29RHT0Ti>C092@T028R8P0WYjN09nOW`2[Zj/0`<300<k>cP38b<P0
_;bl0;Bd]02l_;`0c<c<0=;BdP3Hf=P0f][J0=?Cd`3IfMT0f][J0=7Ad@39bLT0a<C40<K6aP37alL0
`/;20;no_`37alL0`L710<O7a`3MgMd0g=cL0=3@d03<c<`0c/k>0<W9b@2j^[X0`l?30=7Ad@2_[jl0
R8R807QhN01iNGT0QhN70:VYZ@32`/80alO70;Jf]P2LW9`0R8R808>3P`2KVi/0/[:b0:FUY@2?Shl0
Lg=c09FEU@2h^;P0bLW90=7Ad@3Fe]H0hn?S0>KViP3Ng]h0d];B0;Zj^P2TY:@0W9bL0:ZZZP2l_;`0
_Kfm0:n_[`1mOGd0Fe]K04e=C@1<C4`0CTi>04M7A`10@400?3`l03dm?@0n?Sh0?clo06YZJP2/[:`0
S8b<05MGE`0k>c/0@d=3055AD@0o?cl0>c/k03`l?00k>c/0FUYJ061PH00k>c/203Ti>@0Z03Hf=P0i
>CT0>SXj03Hf=P0e=CD0>CTi03Hf=P0h>3P0Bd];08b<S029RHT0D51@03Hf=P0g=cL0>3Ph03dm?@1;
Bd/0OWin0861P@1[Jf/0@T9203Ti>@0j>SX0>3Ph03lo?`23Ph<0[jn_08J6QP1ZJVX0GUiN04a<C00m
?Cd0Bd];079bLP2GUiL0][Jf08j>SP1VIVH0IFEU08B4Q02XZ:P0^k^k0P31`L40202o_kl0Y:BT0:6Q
X@2QXJ40ZZZZ0:f][@2[Zj/0[jn_3Oooool0013ooooo0P1:BTX304M7A`0304U9B@1:BTX0AdM70080
@d=300L0ATI604E5A@11@D40@T920451@@13@d<0ADE50080@d=300H0@T920451@@14A4@0BDU90451
@@0o?cl30410@00=04=3@`11@D40@41003lo?`11@D40?Shn0492@P13@d<0@T9203dm?@0n?Sh0>SXj
03/k>`020492@P0>0410@012@T80@4100492@P13@d<0ADE504I6AP14A4@0ADE50492@P11@D40?clo
0492@P11@D420410@00D03lo?`0n?Sh0?clo0492@P0n?Sh0@D5104=3@`12@T80?Cdm03`l?00n?Sh0
@D5104Q8B019BDT0@d=304E5A@1ADE40A4A403hn?P11@D4204a<C00?05=CD`1>CTh0?Shn03lo?`13
@d<0@D5104M7A`1<C4`0ADE50410@011@D40?Shn0410@00l?3`0?Cdm0080>c/k00L0?Shn03`l?012
@T80?Shn03dm?@0k>c/0>CTi0080>c/k01h0>CTi04E5A@1OGel0OWin07IfMP1VIVH0KFe]04Y:BP0o
?cl0?Cdm0451@@1PH600CDe=03lo?`11@D40Bd];05iNGP1[Jf/0M7Ad07MgM`1;Bd/0?clo04=3@`1_
Kfl0KFe]06i^KP1TI6@0AdM703`l?016ATH204A4A00<04I6AP1:BTX0Q8B40;6a/@2XZ:P0SHf=06a/
K01UIFD0BDU904=3@`10@400?clo0P0n?Sh0:011@D40DU9B06m_K`1cLg<0PH6109>CT`2YZJT0QhN7
07]kN`1ZJVX0FEUI04E5A@0l?3`0@41003`l?00n?Sh0?3`l03dm?@0k>c/0?clo04];B`18B4P0?clo
0451@@15ADD0@T9203Ti>@0n?Sh0>c/k0410@013@d<0HF5Q06UYJ@1WIfL0Lg=c05]KF`1BDU80@D51
03dm?@0o?cl203dm?@0G0451@@0m?Cd0?clo0492@P0m?Cd0?clo03hn?P1EEED0GemO05MGE`0n?Sh0
>c/k03dm?@0l?3`0@D5103hn?P0l?3`0@T9204A4A011@D40@41003/k>`11@D400P0m?Cd06P0j>SX0
=cLg03/k>`0m?Cd0A4A40492@P19BDT0G5aL059BDP17AdL0ADE50410@012@T80?clo03`l?011@D40
?Cdm0410@00n?Sh0?clo0451@@13@d<0>CTi03Xj>P0h>3P0?3`l0P0h>3P02P0j>SX0?clo04I6AP1F
EUH0@T9203hn?P0l?3`0>SXj03/k>`10@40203Xj>P1303lo?`0k>c/0AdM70451@@14A4@0Cdm?04=3
@`11@D40@41003dm?@0k>c/0?Shn03`l?00m?Cd0>3Ph03Ti>@0k>c/0?Cdm0451@@0i>CT0?Shn03Ti
>@0m?Cd0>SXj03Ph>00k>c/0Bd];06QXJ01`L700EEEE0492@P0l?3`0@41004I6AP1@D500G5aL059B
DP1>CTh0AdM704U9B@18B4P0ATI604A4A015ADD0BDU904A4A01:BTX0JVYZ096AT@2PX:00RXZ:05eM
G@1CDe<0Hf=S08b<S02;Rh/0Q8B406i^KP1`L700J6QX06m_K`27QhL0TY:B09nOW`2VYZH0XJ6Q09BD
U0020861P@0a08R8R02TY:@0^;Rh0<71`@38b<P0d=3@0=SHf03Jf]X0emOG0<W9b@2n_[h0YjNW08^;
R`2<S8`0UiNG0;Fe]@3Bd]80dm?C0<G5a@3@d=00dm?C0<[:bP3@d=00bLW90<;2`P2YZJT0clo?0=OG
e`3:b/X0[Jf]09ZJVP2PX:00a<C40=OGe`3Kfm/0hn?S0=WIf@3Jf]X0dM7A0<S8b03Bd]80dm?C0;Zj
^P2QXJ40UiNG0:j^[P39bLT0bl_;0=?Cd`020=;BdP0O0<k>cP2i^KT0RHV905eMG@1VIVH0MgMg09ZJ
VP2EUID0QhN709:BTP2OWil0Zj^[0:6QX@2PX:00UiNG07EeM@1;Bd/0ATI6061PH02EUID0[Zj^0<30
`02`/;00SXj>075aL@1JFUX0?Shn03`l?00n?Sh0?3`l03Ph>00203`l?00503dm?@0i>CT0@T9203Ti
>@0h>3P00P0g=cL0<@0h>3P0>c/k03Ti>@0m?Cd0>c/k03`l?017AdL0@D5103Lg=`0j>SX0>CTi0492
@P1_Kfl0V9RH08J6QP19BDT0>c/k03Hf=P0h>3P0?3`l0451@@1^KVh0X:2P05mOG`0n?Sh0ADE50451
@@0n?Sh0C4a<069RHP1lO7`0T92@079bLP1BDU80Jf][07IfMP2FUYH0^KVi0<G5a@2e]KD0];Bd0:VY
Z@2`/;00X:2P07alO024Q8@0SXj>08b<S020P8003Oooool0013ooooo0P1:BTX00`17AdL0B4Q804E5
A@0204Q8B00504I6AP15ADD0@d=304=3@`17AdL00P15ADD01@14A4@0@D5104M7A`16ATH0A4A400@0
@T9200<0@D5103lo?`13@d<00P10@4002013@d<0?clo0451@@0l?3`0@D5103lo?`12@T80@4100P0n
?Sh03`0m?Cd0>SXj0451@@0n?Sh0@41003dm?@0o?cl0A4A40451@@12@T80ADE50451@@0o?cl0?3`l
0410@00203lo?`0K03`l?010@400?Cdm0492@P0l?3`0>c/k03lo?`0m?Cd0@D510492@P0o?cl0@410
03hn?P0l?3`0?Cdm03/k>`0n?Sh0@D5103lo?`0n?Sh0@D510410@00o?cl0BDU9059BDP11@D40?clo
0080?3`l00D0?Cdm0410@00o?cl0?3`l03dm?@0203hn?P0404A4A00o?cl0?clo0410@080?3`l01h0
?Cdm03Ti>@0k>c/0>c/k03dm?@0n?Sh0>c/k03`l?011@D40ATI604m?C`1EEED0Fe]K05IFEP18B4P0
A4A40410@00l?3`0?Cdm0492@P0i>CT0?3`l04I6AP11@D40?clo04M7A`12@T80@41003`l?013@d<2
03hn?P0403lo?`12@T80@41004m?C`80FUYJ00X0H61P06MWI`1QHF40EeMG05QHF01NGUh0P82009VI
V@2JVYX0S8b<0P22PX804`1NGUh0BDU904U9B@1:BTX0@41004];B`1iNGT0][Jf0<G5a@34a<@0^k^k
092@T01DE5@0BTY:0410@00o?cl0?Shn04A4A016ATH00P10@4001`11@D40?Shn03`l?013@d<0@410
0451@@0m?Cd00P0o?cl02@11@D40@T920451@@16ATH0KFe]08R8R01oOgl0IFEU05MGE`020492@P80
@4100P0m?Cd01P14A4@0B4Q805IFEP1UIFD0I6AT05EEE@80CTi>00d0CDe=0451@@11@D40?clo04=3
@`0m?Cd0=cLg03/k>`10@400@D510492@P10@400?clo0080?3`l00<0@D5103/k>`0k>c/00P0l?3`2
03hn?P0;0410@01:BTX0EEEE05=CD`18B4P0BTY:04E5A@11@D40@T9203/k>`13@d<00P0o?cl05012
@T80?clo0492@P1;Bd/0FUYJ059BDP16ATH0?clo03`l?00i>CT0?Cdm03`l?00n?Sh0B4Q806IVIP1o
Ogl0JVYZ04E5A@0m?Cd0?clo0P0l?3`0300i>CT0?Cdm04e=C@1RHV80GemO06YZJP1ADE40?Shn03Ph
>00j>SX0?3`l03/k>`80>CTi00P0?3`l03/k>`0k>c/0?Shn03lo?`0j>SX0>CTi03Ph>080>c/k0P0l
?3`06P12@T80D51@05]KF`1/K6`0H61P04I6AP0g=cL0BTY:05iNGP1_Kfl0LW9b06=SH`1<C4`0A4A4
03/k>`0n?Sh0>c/k03`l?00k>c/0?Shn04I6AP0l?3`0B4Q805QHF01LG5`0F5QH0P1;Bd/0=@1PH600
JFUY06QXJ01UIFD0GEeM04m?C`1=CDd0DE5A06IVIP1iNGT0OWin06m_K`1LG5`0DU9B05=CD`1ADE40
CDe=05IFEP1>CTh0Bd];06UYJ@2QXJ40][Jf0;jn_P2h^;P0Xj>S0:BTY02IVIT0V9RH0:b/[02i^KT0
_kno0<S8b033`l<0[:b/0:6QX@2JVYX0YJFU09JFUP20P800Q8B4092@T02UYJD0[Jf]0<?3``37alL0
`L710;Rh^02`/;00^KVi0=7Ad@2_[jl0W9bL0080][Jf01H0_Kfm0;Fe]@30`<00bl_;0<K6aP2`/;00
[Zj^0:f][@2GUiL0Kfm_065QH@1UIFD0I6AT05mOG`1TI6@0Kfm_07MgM`2NWYh0][Jf0<?3``31`L40
c/k>0P3Lg=`03P37alL0V9RH07QhN01^KVh0Hf=S07moO`2ATI40VYZJ0<?3``3De=@0]KFe07inOP1G
EeL0BTY:0P16ATH04@13@d<0?clo03`l?00k>c/0AdM704i>CP11@D40>SXj03Ph>00g=cL0>3Ph03Ti
>@1;Bd/0JFUY06e]K@1SHf<0A4A40080>SXj01H0=cLg03Ph>00h>3P0>SXj03hn?P1LG5`0P82008f=
S@1WIfL0@T9203Ti>@0n?Sh0DU9B07AdM020P800R8R80861P@1LG5`0?Shn03dm?@0g=cL0EEEE0P1d
M7@0301LG5`0CDe=059BDP1=CDd0IVIV0820P027QhL0WYjN0:FUY@2BTY80TI6A08j>SP80Hf=S00@0
CDe=04E5A@16ATH0ATI60P0n?Sh=ooooo`004?ooool204Q8B00704U9B@1:BTX0B4Q804U9B@17AdL0
BDU904I6AP0204A4A080ADE500<0@d=304Q8B017AdL00P15ADD01014A4@0@d=304=3@`12@T830451
@@0804Q8B012@T80@41004A4A012@T80@D5103dm?@10@4020451@@0;04=3@`12@T80@D5104A4A012
@T80?Shn03lo?`0n?Sh0?clo0492@P10@4000P0n?Sh0200o?cl0?Cdm0492@P14A4@0@D5103dm?@0n
?Sh0?Cdm0P10@4002014A4@0?clo0410@012@T80?Shn03lo?`0n?Sh0>SXj0P0o?cl03`0m?Cd0?Shn
0410@017AdL0@41003dm?@0l?3`0?Cdm03Xj>P0n?Sh0?Cdm0410@011@D40?Cdm0451@@0203hn?P04
03/k>`0n?Sh0?clo03dm?@80?3`l01D0@d=303lo?`12@T80ADE503Ti>@0l?3`0?clo03hn?P0o?cl0
@T9204Y:BP1>CTh0D51@05ADE01[Jf/0LW9b05YJFP19BDT0?Shn03/k>`0j>SX00P0l?3`0300m?Cd0
?Shn0451@@0n?Sh0ATI603dm?@0k>c/0?clo03`l?010@400?Shn03/k>`80@41004P0?Shn03lo?`1B
DU80C4a<04Y:BP1HF5P0GemO04i>CP15ADD0@41003dm?@12@T80Fe]K079bLP1jNWX0IVIV059BDP1:
BTX0A4A403lo?`14A4@0@T920410@00m?Cd0?Shn0451@@19BDT0CDe=05ADE01ZJVX0PH6107=cL`25
QHD0LW9b05iNGP1TI6@0PH6107]kN`1UIFD0Lg=c07UiN@1UIFD0G5aL0451@@13@d<0A4A404m?C`1T
I6@0N7Qh07UiN@25QHD0JFUY06MWI`1_Kfl0De=C04A4A011@D40ADE504=3@`1;Bd/0B4Q804a<C019
BDT0Bd];04Q8B01=CDd0EEEE05]KF`1=CDd0@d=303hn?P10@40203dm?@80?Shn04T0?clo03dm?@12
@T80?clo04Q8B01<C4`0A4A403lo?`11@D40>3Ph03dm?@0n?Sh0>SXj03hn?P0j>SX0?Cdm04=3@`1D
E5@0IfMW06ATI01ADE40@d=303`l?00m?Cd0?clo03/k>`0o?cl0?Cdm04Q8B01dM7@0PH6106UYJ@1D
E5@0CDe=059BDP1@D500@4100451@@0k>c/0?Cdm04E5A@1BDU80I6AT06IVIP1KFe/0D51@0451@@0l
?3`0@41003Ph>00k>c/0@41004m?C`1DE5@0KFe]08^;R`26QXH0I6AT03lo?`0l?3`0>3Ph03Xj>P0l
?3`0?clo03/k>`0o?cl0@41003hn?P0k>c/0>SXj03`l?00n?Sh0?3`l0080>c/k00L0?Shn03/k>`0n
?Sh0?clo06QXJ01nOWh0B4Q80080?clo01@0BTY:06e]K@25QHD0LG5a04e=C@11@D40?Shn0451@@0m
?Cd0?3`l0410@00i>CT0?3`l03lo?`0n?Sh0A4A403dm?@0l?3`0@T9203`l?080?clo0140IVIV05]K
F`1:BTX0Cdm?04=3@`0n?Sh0@D5104a<C01GEeL0De=C04M7A`16ATH0@D5104=3@`0o?cl0?Shn03dm
?@020410@01M0492@P1]KFd0X:2P08F5Q@1kNg/0P82006m_K`1XJ6P0MGEe08n?S`2TY:@0YZJV096A
T@1cLg<0Kfm_06YZJP1NGUh0OWin0:JVYP2j^[X0ZZZZ0:BTY02^[Zh0[Jf]096AT@2<S8`0VYZJ0;Rh
^02e]KD0Xj>S0:JVYP2][Jd0][Jf0:n_[`2][Jd0alO70;fm_@2d];@0Zj^[0;Jf]P31`L40[jn_0:f]
[@2j^[X0/k>c09nOW`2;Rh/0Vi^K0:^[Z`2l_;`0`L710=3@d03IfMT0e=CD0=kNgP3Ti>@0h>3P0=gM
g@3GemL0f][J0=_Kf`34a<@0^;Rh0<O7a`3AdM40e]KF0=kNgP3Rh^80g=cL0<;2`P2UYJD0R8R808j>
SP2DU9@0TY:B07alO01hN7P0LG5a06m_K`1VIVH0Cdm?05=CD`16ATH0?3`l03hn?P0f=SH0C4a<06IV
IP28R8P0X:2P0::RXP1fMWH0BTY:0080>3Ph00D0>SXj03dm?@1ADE40GemO05iNGP02051@D00E04a<
C014A4@0>SXj04M7A`1VIVH0T92@0;Fe]@20P800N7Qh05=CD`10@400>SXj03dm?@0g=cL0B4Q806][
J`1IFET0?Shn03Ti>@1:BTX0Ng]k0080U9BD00T0TI6A092@T027QhL0VYZJ0:VYZ@2DU9@0KFe]04=3
@`0i>CT00P0j>SX0100o?cl0@D5105=CD`1VIVH=ooooo`004?ooool00`1;Bd/0AdM704Y:BP0204Q8
B00704M7A`15ADD0AdM704=3@`16ATH0AdM704I6AP0304E5A@0504=3@`11@D40ATI604A4A010@400
0P11@D404@13@d<0@T920451@@16ATH0@D5103hn?P14A4@0@41003lo?`0m?Cd0@D510410@00m?Cd0
@41004=3@`10@400?Shn0080@41000d0@T9203dm?@0o?cl0?clo04=3@`17AdL0?clo04=3@`11@D40
ADE504=3@`12@T80?clo0080?Cdm00<0?clo0492@P10@4000`10@400100m?Cd0@4100410@00m?Cd2
0410@080?clo0P0l?3`08`0k>c/0?Cdm03/k>`0o?cl0@41003dm?@0j>SX0?3`l03hn?P0l?3`0?clo
03dm?@12@T80?Shn03dm?@10@400A4A404=3@`0k>c/0?Shn03`l?00k>c/0>SXj03Ti>@0k>c/0?Shn
04E5A@1?Cdl0IVIV06QXJ01UIFD0IfMW05UIF@1<C4`0CDe=0080?Shn02l0?clo0410@00m?Cd0>SXj
03Ti>@12@T80@41003lo?`0k>c/0?Cdm03Hf=P0k>c/0?3`l0410@00m?Cd0?clo03dm?@0n?Sh0@d=3
04E5A@11@D40ATI604E5A@16ATH0?Cdm03lo?`0m?Cd0BDU905=CD`1PH600JFUY06MWI`1EEED0ATI6
0492@P11@D40?Shn03/k>`14A4@0@D5103`l?013@d<0?3`l03/k>`0l?3`0?Shn03lo?`020410@00H
04A4A01EEED0FEUI06ATI01VIVH0Ng]k08R8R01fMWH0EeMG06YZJP1SHf<0I6AT05MGE`1iNGT0Ng]k
09VIV@2j^[X0ZJVY07MgM`1WIfL0Hf=S05eMG@1LG5`0EeMG0P13@d<0201=CDd0KFe]07]kN`1hN7P0
Kfm_05iNGP18B4P0@d=30P11@D400`0o?cl0>c/k03dm?@0203hn?P0303lo?`0m?Cd0?Shn0080?clo
00L0CDe=059BDP22PX80QhN706=SH`18B4P0@D510080?Cdm0P0l?3`0;P0n?Sh0@T920410@01FEUH0
LG5a07=cL`1IFET0Bd];03`l?00o?cl0?Shn0410@00o?cl0CDe=051@D01<C4`0BDU905QHF01fMWH0
MGEe05EEE@10@400?3`l0451@@10@400?clo04U9B@1JFUX0T92@07IfMP1/K6`0D51@0410@00i>CT0
=3@d03/k>`0m?Cd0?Shn03`l?015ADD0CTi>07EeM@1]KFd0E5AD0451@@0k>c/203`l?00=03/k>`0n
?Sh0>CTi0451@@1NGUh0MGEe07YjNP1OGel0@T9203lo?`0g=cL0?3`l03Xj>P0203/k>`0L03lo?`15
ADD0C4a<04M7A`1DE5@0B4Q80451@@10@400DE5A069RHP1WIfL0J6QX04E5A@0k>c/0?Shn03Xj>P0k
>c/0?Cdm03`l?00j>SX0?Shn03Xj>P0o?cl0=cLg03lo?`0l?3`0>CTi03Xj>P80>c/k00@0?clo03Ti
>@0l?3`0ATI60P15ADD01018B4P0Cdm?04M7A`0n?Sh204A4A00D03hn?P0j>SX0?Shn03dm?@0j>SX0
?3`l03/k>`1:BTX0De=C05UIF@1UIFD0EEEE03lo?`18B4P0J6QX08B4Q02GUiL0WIfM08N7Q`1XJ6P2
04m?C`0I06=SH`1YJFT0MGEe09>CT`2h^;P0]KFe0:b/[02LW9`0Ph>307QhN01eMGD0LG5a08N7Q`2C
Ti<0UYJF09BDU02CTi<0U9BD09FEU@2FUYH0TI6A09VIV@2XZ:P0^k^k0<71`@020;bl_0070;>c/`2R
XZ80ZJVY0:^[Z`2OWil0];Bd0<k>cP020=GEe@0A0<_;b`2o_kl0`<300<?3``38b<P0`/;20<o?c`34
a<@0][Jf0:>SX`2OWil0/[:b0;Bd]031`L40c/k>0=[JfP3Lg=`00P3Shn<0<03QhN40c/k>0<O7a`31
`L40c/k>0=7Ad@3IfMT0eMGE0<G5a@2/[:`0QXJ605eMG@1?Cdl0Fe]K05EEE@1>CTh0EeMG07AdM02M
WId0UYJF06=SH`1:BTX0@41003dm?@1;Bd/0GUiN0820P01kNg/0NWYj0:JVYP2QXJ40DU9B03lo?`0m
?Cd0?Shn04I6AP1hN7P0/;2`0;Zj^P2RXZ80I6AT04E5A@0l?3`0>c/k03Ph>01FEUH0OWin04E5A@80
>c/k00d0=CDe03/k>`15ADD0RXZ:08n?S`1PH600HF5Q08j>SP2ATI40MgMg06IVIP1?Cdl0AdM70080
>3Ph00L0?3`l03lo?`24Q8@0WinO07MgM`1`L700VIVI00gooooo000@ooooo`06051@D01:BTX0BTY:
04M7A`1:BTX0Bd];0P18B4P02`17AdL0BTY:04Q8B013@d<0@D510492@P13@d<0ADE504=3@`16ATH0
ADE50080@T9200P0@D5104=3@`16ATH0A4A404=3@`14A4@0@T9204E5A@80?clo00`0?Shn0492@P12
@T80?clo03dm?@0l?3`0?Cdm03lo?`0n?Sh0?Cdm03hn?P0o?cl20410@00<0492@P17AdL0?Shn0451
@@10@400B4Q80492@P0n?Sh0@41003dm?@0n?Sh0?Cdm0P11@D404`0o?cl0?3`l03`l?00n?Sh0@d=3
0451@@15ADD0?clo03`l?00o?cl0?Cdm03`l?00o?cl0?Cdm0492@P11@D40?Shn0410@00j>SX00P10
@4005`0m?Cd0?clo03Ti>@0l?3`0?clo0451@@0m?Cd0>c/k0451@@12@T80?3`l03lo?`0k>c/0?3`l
0410@00l?3`0@d=305eMG@1ADE40Bd];05=CD`1>CTh0@4100080?3`l00T0?Cdm03lo?`10@400?Cdm
03Xj>P0k>c/0?3`l03Xj>P0l?3`00P0m?Cd08010@400?Shn03Ti>@0o?cl0@41003hn?P0o?cl0@D51
04E5A@13@d<0AdM703lo?`10@400@D510492@P0k>c/0@D5104=3@`1ADE40J6QX06ATI01QHF40Fe]K
04e=C@13@d<0@41003hn?P0o?cl0?3`l03/k>`0l?3`0?Shn0P15ADD05P13@d<0@41003hn?P10@400
?Shn04E5A@18B4P0E5AD05eMG@1RHV80IFEU06a/K01QHF40E5AD04=3@`0m?Cd0?clo0410@00m?Cd0
>CTi04I6AP1JFUX305QHF00=04e=C@0m?Cd0ATI606i^KP1PH600G5aL05mOG`1KFe/0C4a<05MGE`1d
M7@0FUYJ04Y:BP0203lo?`0804=3@`11@D40?Shn03lo?`11@D40@4100451@@0n?Sh20410@00G04=3
@`17AdL0D51@05UIF@1oOgl0OGem07]kN`1OGel0F5QH065QH@1DE5@0@d=303lo?`19BDT0LW9b08Z:
RP23Ph<0L71`08F5Q@2>SXh0RHV906m_K`1KFe/00P1<C4`03@1CDe<0EEEE06a/K01kNg/0GUiN04U9
B@0o?cl0@41003`l?012@T80?Cdm03hn?P10@4000P0n?Sh01@12@T80GUiN06IVIP1ADE40@T920080
?3`l00<0?clo03dm?@11@D400P0l?3`04`0n?Sh0ATI605mOG`16ATH0@41003/k>`0n?Sh0>CTi04Y:
BP1SHf<0DE5A03hn?P17AdL0FUYJ08^;R`23Ph<0EeMG04E5A@0i>CT00P0n?Sh07@13@d<0B4Q8069R
HP27QhL0R8R808F5Q@1eMGD0H61P065QH@1JFUX0BDU9061PH02;Rh/0Ph>3069RHP16ATH0>c/k03Ti
>@11@D40@41003Lg=`0k>c/0?3`l03dm?@0f=SH0>SXj0410@014A4@0?Cdm00<0?Shn0P15ADD203hn
?P0g0451@@1ADE40GEeM06IVIP1@D500BTY:04E5A@0l?3`0?Cdm03/k>`0n?Sh0?3`l03dm?@0o?cl0
?3`l03hn?P0l?3`0?clo04U9B@13@d<0@T9203`l?014A4@0FEUI075aL@23Ph<0N7Qh065QH@1;Bd/0
?clo0492@P1:BTX0MWIf07moO`1aLG40KFe]07moO`1iNGT0Hf=S05aLG01@D500EeMG06m_K`29RHT0
Ti>C09ZJVP2NWYh0TY:B09RHV02SXj<0/[:b0<?3``37alL0_kno0<71`@020;Zj^P040;Rh^02_[jl0
YJFU0:b/[080YZJV00@0VIVI08f=S@25QHD0P8200P27QhL0201iNGT0Jf][06i^KP1cLg<0OGem07If
MP1oOgl0RHV90P2@T900101oOgl0UIFE0;2`/02k^k/20<S8b00o0<c<c03Jf]X0h>3P0=gMg@3Kfm/0
e]KF0<K6aP2d];@0`/;20=SHf03MgMd0f][J0<c<c02o_kl0]kNg0;Rh^03AdM40^KVi07=cL`1TI6@0
JFUY05ADE014A4@0?Shn03Xj>P0m?Cd0PH610;Rh^035aLD0WinO05UIF@1<C4`0De=C06][J`2@T900
UYJF09^KV`2_[jl0_kno0<g=c@2c/k<0PX:205IFEP0o?cl0>SXj0492@P1EEED0L71`07IfMP1RHV80
@D5103Ph>00j>SX0F5QH079bLP1jNWX0HF5Q04e=C@1/K6`0Xj>S0;>c/`1WIfL0DE5A0080?3`l00X0
>CTi03Xj>P0k>c/0Bd];08Z:RP2DU9@0LW9b061PH02;Rh/0WYjN3Oooool0013ooooo00@0CDe=04];
B`1;Bd/0BDU90P16ATH02`17AdL0A4A404I6AP18B4P0BDU904A4A015ADD0@d=30492@P14A4@0@410
0080@d=300/0ADE504M7A`14A4@0@T9204M7A`15ADD0>c/k0451@@10@400@T920410@00203hn?P0A
0451@@12@T80@d=303lo?`0m?Cd0?Shn0451@@13@d<0@D5103hn?P11@D40?clo0410@013@d<0ATI6
04E5A@14A4@00P11@D402@12@T80?Cdm03hn?P0l?3`0?Shn0410@00o?cl0@D5103dm?@0203/k>`80
?clo00L0?Cdm03lo?`0m?Cd0>CTi03dm?@0l?3`0?Cdm0080?clo0P10@4002@0k>c/0?Shn03Xj>P0m
?Cd0?Shn0451@@14A4@0?Shn04A4A00203`l?080@41000`0@T9204=3@`0k>c/0?3`l03lo?`0k>c/0
?Shn03dm?@0j>SX0>c/k03`l?00j>SX203hn?P0603Xj>P0k>c/0?Shn03hn?P0l?3`0>SXj0`0l?3`0
2`0k>c/0>CTi03dm?@0j>SX0?Shn03dm?@11@D40>c/k0492@P1=CDd0Bd];0080@D5100P0A4A404M7
A`0n?Sh0>CTi03hn?P11@D40?Shn0492@P80EUIF00D0EEEE051@D014A4@0@T920410@00203hn?P0<
0451@@10@400?Cdm03hn?P0o?cl0@41004E5A@1:BTX0A4A404Q8B00m?Cd0?Shn0P11@D402P1RHV80
KVi^075aL@1WIfL0GUiN055AD@1;Bd/0?3`l03dm?@10@40203`l?080?clo00H0?3`l03lo?`12@T80
?Cdm03`l?00j>SX20410@00?03lo?`15ADD0D51@06UYJ@24Q8@0IVIV04M7A`18B4P0NWYj09BDU01e
MGD0ATI603lo?`14A4@0?clo0080?Shn03@0@4100451@@0n?Sh0@41003lo?`1KFe/0K6a/07MgM`1_
Kfl0Hf=S05iNGP1FEUH0ATI6059BDP1[Jf/0H61P05aLG01?Cdl0D51@06EUI@1kNg/0Shn?08:2PP1K
Fe/0AdM703hn?P0j>SX0ATI603lo?`16ATH0EeMG05QHF018B4P0BTY:04];B`11@D40?Shn03Xj>P10
@400D51@04a<C01;Bd/0A4A404U9B@1QHF40KFe]07AdM01CDe<0@41003/k>`0l?3`0=cLg0P0n?Sh0
5@0l?3`0?Shn04Y:BP1>CTh0EEEE04];B`0m?Cd0AdM704i>CP1ADE40GEeM06m_K`29RHT0SXj>07Ad
M01UIFD0I6AT05YJFP1CDe<0A4A403lo?`0203dm?@0A03hn?P16ATH0DU9B07YjNP2>SXh0R8R807em
O@23Ph<0PX:2071`L01[Jf/0EUIF071`L02MWId0Rh^;069RHP16ATH00`0k>c/01`0i>CT0?3`l03/k
>`0k>c/0?Cdm03Ph>00m?Cd00P0k>c/02@0l?3`0ADE505EEE@1ADE40@d=30451@@0n?Sh0AdM705mO
G`0207IfMP0304e=C@15ADD0?Shn0080?Cdm0P0n?Sh02P0l?3`0?Cdm03Xj>P0j>SX0?3`l03Hf=P0n
?Sh0?3`l03/k>`0n?Sh30410@00;061PH01aLG40D51@04=3@`0l?3`0@41003`l?018B4P0CDe=04];
B`1:BTX00`13@d<06@0m?Cd0>c/k03lo?`17AdL0B4Q805EEE@1QHF40EUIF05EEE@1BDU80Fe]K06m_
K`1nOWh0U9BD0;2`/02d];@0Xj>S09jNWP27QhL0NGUi08N7Q`2FUYH0YJFU0:f][@2EUID00P1kNg/0
301RHV80Bd];04e=C@1HF5P0GUiN05UIF@1FEUH0DE5A061PH01/K6`0JVYZ071`L080P82003P0NGUi
08:2PP2<S8`0TY:B08N7Q`2:RXX0P82008B4Q02UYJD0];Bd0;>c/`2_[jl0/[:b0;bl_03>c/h0_Kfm
0<[:bP3Hf=P0e=CD0<o?c`3De=@0fm_K0=GEe@2PX:00_Kfm0<c<c02WYjL0SXj>07UiN@1]KFd0L71`
06m_K`1YJFT0U9BD0<o?c`3MgMd0`l?308F5Q@1RHV80GemO08Z:RP2o_kl0eMGE0=kNgP3IfMT0aLG5
0:^[Z`23Ph<0HF5Q05MGE`1BDU80@T92069RHP2?Shl0]KFe08J6QP80@41001T0AdM705aLG024Q8@0
/;2`08n?S`1jNWX0TY:B0:NWY`2YZJT0TI6A05=CD`12@T80ATI603Lg=`0j>SX0>CTi03Xj>P1ADE40
TI6A07MgM`26QXH0QHF508b<S02@T900PH6100gooooo000@ooooo`0F04Y:BP17AdL0BTY:04a<C019
BDT0ATI604Q8B019BDT0CDe=0492@P18B4P0@d=304A4A013@d<0@T920451@@12@T80@D510492@P13
@d<0ADE504Q8B080@d=300L0@T9204=3@`15ADD0@41003hn?P0o?cl0@4100080@D510`12@T801`0o
?cl0@d=30492@P0l?3`0@41003lo?`11@D400P13@d<01P14A4@0AdM704Y:BP19BDT0@T9203lo?`80
@41000`0@d=303lo?`0l?3`0?3`l03/k>`0n?Sh0>c/k03hn?P0l?3`0?clo03dm?@0l?3`203lo?`<0
?Shn0P10@40203/k>`0503dm?@14A4@0?Cdm03hn?P0m?Cd00P0n?Sh01P0m?Cd0>c/k0451@@0m?Cd0
@D5103hn?P80A4A400P0@T9203dm?@10@400@41003dm?@15ADD0A4A403`l?080?Cdm00X0?3`l03Xj
>P0k>c/0?Cdm03Ti>@0n?Sh0?3`l03/k>`0n?Sh0>3Ph0P0o?cl03@11@D40?clo03Ti>@0k>c/0?clo
04=3@`18B4P0@41004A4A01=CDd0@T920410@00n?Sh00P12@T804@11@D40?3`l04A4A01BDU80De=C
05MGE`1>CTh0?Shn0410@00j>SX0?clo03Ti>@10@400?clo04A4A00l?3`0?Cdm0080=SHf01/0?clo
03hn?P0o?cl0@41003/k>`14A4@0@T9205EEE@1`L700HF5Q059BDP12@T80@D5103lo?`0l?3`0?clo
04I6AP0j>SX0?clo03dm?@0n?Sh0@T920410@012@T80>SXj03lo?`0m?Cd00P0o?cl09P10@400?Cdm
04Y:BP1YJFT0RXZ:08^;R`1ZJVX0CDe=05=CD`1VIVH0Jf][06QXJ01IFET0B4Q80410@00l?3`0?Cdm
03/k>`0l?3`0?Shn04E5A@19BDT0IVIV05IFEP1>CTh0QHF5092@T01WIfL0GEeM06UYJ@1^KVh0RHV9
0861P@1dM7@0I6AT04A4A00l?3`0?Cdm0P0o?cl0200n?Sh0@D5103`l?00l?3`0>SXj0410@00l?3`0
>c/k0P0m?Cd00`0o?cl0@41003dm?@0203hn?P0>0451@@15ADD0CDe=04U9B@1<C4`0Bd];04=3@`1H
F5P0MgMg07IfMP1GEeL0@d=303hn?P0l?3`203dm?@0604Y:BP1HF5P0GEeM06e]K@1hN7P0OGem0P1c
Lg<09028R8P0UiNG09JFUP2DU9@0WIfM0:2PX02JVYX0Vi^K08j>SP28R8P0OGem06IVIP1BDU80@T92
03/k>`0m?Cd0>c/k0492@P1FEUH0Jf][06a/K01[Jf/0MGEe09:BTP2GUiL0Lg=c051@D013@d<0BDU9
07QhN02;Rh/0Jf][04a<C00o?cl0?Cdm03Ti>@80>SXj01@0>3Ph03Ti>@0i>CT0?3`l03/k>`0l?3`0
>3Ph04=3@`1CDe<0IFEU06e]K@1WIfL0IFEU06UYJ@1[Jf/0L71`06i^KP1aLG40GemO04E5A@80@T92
00X0?Shn03/k>`0l?3`0>SXj0410@00k>c/0>3Ph03Xj>P0l?3`0>CTi0P0l?3`03`0k>c/0>CTi0451
@@12@T80@D5105YJFP1NGUh0B4Q803/k>`0n?Sh0?Cdm03hn?P13@d<0De=C04I6AP0203dm?@0303`l
?00j>SX0?clo0080@d=300D0ADE50492@P13@d<0?3`l03@d=00203/k>`0M06ATI023Ph<0TI6A08f=
S@1jNWX0K6a/05UIF@1ADE40GEeM07EeM@2BTY80UYJF08n?S`22PX80LG5a06MWI`1GEeL0H61P07Ee
M@21PH40PX:208B4Q02CTi<0SXj>08J6QP2;Rh/0ZZZZ0:f][@2EUID00P2VYZH03P2MWId0V9RH09VI
V@2IVIT0UYJF08f=S@2:RXX0Ogmo08Z:RP2DU9@0T92@08J6QP1lO7`0OWin0P1oOgl06@27QhL0WIfM
09bLW01nOWh0Shn?0;>c/`2f][H0a<C40;6a/@2TY:@0Q8B407=cL`2][Jd0alO70;no_`2m_Kd0WIfM
0:6QX@2>SXh0S8b<0;fm_@3?cll0fMWI0<S8b033`l<00P2g]kL0:@2`/;00^;Rh0;fm_@2UYJD0RHV9
08B4Q01]KFd0QhN707inOP1hN7P0Vi^K0:FUY@2e]KD0Kfm_075aL@2ATI40QXJ609FEU@2o_kl0_;bl
0:6QX@2KVi/0[jn_09FEU@1EEED0?Shn03Lg=`0n?Sh0?3`l03/k>`0m?Cd0=cLg0410@01KFe/0EUIF
04m?C`1BDU80QhN70:ZZZP1jNWX0Jf][00gooooo000@ooooo`0404a<C019BDT0BDU904M7A`80BTY:
00L0B4Q804Y:BP19BDT0B4Q804U9B@14A4@0@d=30080@4100P11@D401`0n?Sh0A4A403dm?@12@T80
BDU904A4A012@T800P0o?cl01P10@400@T920451@@0o?cl0?3`l03hn?P80@D5100h0@T9204=3@`11
@D40?Shn03lo?`0l?3`0@4100492@P0o?cl0@D510410@017AdL0@T920451@@80@d=300`0?3`l03lo
?`11@D40@41003hn?P0o?cl0@D5103lo?`11@D40>c/k03Xj>P0n?Sh203dm?@070410@012@T80?Shn
0451@@0n?Sh0A4A40492@P0203lo?`0=03`l?00k>c/0>CTi03Ti>@0n?Sh0?3`l03/k>`0m?Cd0?Shn
03`l?00m?Cd0>CTi03Xj>P0303lo?`0603`l?010@400A4A403lo?`0m?Cd0>c/k0P0o?cl203/k>`80
?3`l00<0?Shn03lo?`0j>SX00P0j>SX0200m?Cd0>SXj03Ti>@0j>SX0?Cdm03Ph>00i>CT0?Shn0P14
A4@0100n?Sh0?Cdm03dm?@11@D4203lo?`0:04A4A010@400?Cdm0410@01;Bd/0AdM704A4A018B4P0
BDU90451@@80?clo01d0?3`l03Ph>00j>SX0?Shn04=3@`14A4@0?Shn03/k>`0o?cl0>SXj03/k>`0j
>SX0?Shn0451@@1ADE40EUIF05UIF@1PH600Fe]K05ADE018B4P0ATI60410@00o?cl0?Shn03/k>`0i
>CT0?3`l03dm?@0203lo?`80AdM705`0?Shn04A4A017AdL0ADE503lo?`11@D40A4A404a<C01LG5`0
PH610:j^[P2NWYh0I6AT06YZJP22PX80P82006YZJP1;Bd/0@D5103lo?`16ATH0@T9203/k>`0h>3P0
C4a<05=CD`1EEED0DE5A04m?C`1NGUh0CTi>04U9B@1=CDd0D51@06UYJ@1nOWh0SHf=09:BTP2EUID0
R8R8096AT@1dM7@0@d=303hn?P12@T80A4A403lo?`0n?Sh0DE5A04A4A00n?Sh0@41004A4A01>CTh0
Cdm?04M7A`1JFUX0RHV908n?S`20P800IVIV06QXJ01PH600FEUI06=SH`1dM7@0I6AT05EEE@1UIFD0
M7Ad065QH@16ATH0@41004=3@`0o?cl0?Shn03lo?`13@d<0CTi>06e]K@22PX80UIFE0:JVYP2d];@0
[:b/0:>SX`2PX:00ZJVY0:b/[02PX:00UiNG08N7Q`80NWYj00d0OWin07]kN`1IFET0@D510410@00m
?Cd0ADE504];B`1SHf<0NWYj09VIV@2PX:00U9BD0080QhN700h0Lg=c05UIF@1:BTX0GEeM07UiN@1j
NWX0JFUY05=CD`11@D40?3`l0451@@10@400>c/k03`l?0<0>SXj0100>c/k0410@00m?Cd0?3`l051@
D01XJ6P0Q8B409:BTP2HV9P0VYZJ08Z:RP1jNWX0HF5Q04];B`19BDT0Cdm?0P1@D500200o?cl0@410
03lo?`0m?Cd0?3`l03Ti>@0o?cl0?Cdm0P0l?3`20451@@0;03lo?`0n?Sh0?Cdm04=3@`15ADD0Bd];
059BDP1GEeL0BTY:0492@P0m?Cd00P0j>SX01`12@T80A4A403lo?`0l?3`0>SXj04Y:BP14A4@00P12
@T805@13@d<0?clo03Xj>P0i>CT0>SXj03Ph>00k>c/0?Shn05UIF@1WIfL0G5aL051@D018B4P0?Cdm
03hn?P13@d<0Fe]K06][J`1UIFD0G5aL04U9B@020492@P1>04M7A`1GEeL0EUIF06m_K`28R8P0PX:2
06QXJ01PH600HF5Q05QHF01LG5`0LG5a09fMW@2/[:`0WinO09RHV02ATI40VYZJ08V9R@25QHD0Ogmo
075aL@1RHV80K6a/0861P@2<S8`0T92@08j>SP24Q8@0NGUi07YjNP1bLW80Kfm_06UYJ@1RHV80FUYJ
06ATI01cLg<0OGem07=cL`20P800Ph>307]kN`1RHV80HF5Q069RHP1/K6`0HV9R06i^KP2:RXX0/[:b
09NGU`29RHT0WYjN0;>c/`2o_kl0e]KF0=kNgP3GemL0[jn_08b<S02XZ:P0`l?30<[:bP3De=@0e]KF
0;Jf]P2FUYH0Z:RX0:n_[`27QhL0VIVI0:BTY02][Jd0ZJVY09bLW02^[Zh0`<300P3;bl/01P2QXJ40
PH6106m_K`1DE5@0BTY:03dm?@80?clo00d0CTi>04Q8B00i>CT0>CTi0451@@1SHf<0?Shn04U9B@1d
M7@0YJFU08f=S@1ADE40?Shn00gooooo000@ooooo`0404I6AP18B4P0BTY:04Q8B080ATI600H0A4A4
04E5A@16ATH0CDe=061PH01CDe<304=3@`060451@@10@400?clo04A4A00o?cl0@d=30P12@T802`11
@D40@T9204I6AP1;Bd/0A4A40410@011@D40?Cdm03lo?`15ADD0@d=300<0@41000L0?Cdm04E5A@11
@D40@4100451@@0n?Sh0?clo0080@T9200P0ATI60492@P0n?Sh0@41003dm?@13@d<0@4100451@@80
?clo00D0@D5103dm?@0m?Cd0?Cdm03hn?P0203dm?@80@4100P0l?3`0200o?cl0@4100492@P0o?cl0
?Cdm03hn?P0k>c/0?clo0`0l?3`02@0n?Sh0?Cdm03hn?P0m?Cd0>c/k03hn?P0o?cl0@D5104];B`02
03`l?00503Ti>@10@400A4A403Xj>P0k>c/00P10@4001015ADD0@T920410@00o?cl203/k>`0803dm
?@0k>c/0>SXj03Hf=P0n?Sh0@D5103Ti>@0l?3`203dm?@0503lo?`11@D40>c/k03hn?P0k>c/00P0m
?Cd05P0l?3`0>CTi0451@@11@D40B4Q803hn?P0k>c/0?clo0410@00n?Sh0@D5104e=C@10@400?3`l
04A4A00m?Cd0?clo03hn?P15ADD0A4A404M7A`11@D4203dm?@0503hn?P0m?Cd0@41006ATI01NGUh0
0P1FEUH02`1HF5P0HV9R05aLG01DE5@0C4a<0451@@0o?cl0?3`l0410@011@D40?Shn0080?Cdm01H0
?Shn04E5A@15ADD0?Shn04U9B@1;Bd/0DE5A05EEE@1LG5`0F5QH06=SH`1^KVh0QXJ607moO`1iNGT0
OWin07alO01SHf<0DU9B03lo?`10@400>CTi0P0k>c/203dm?@0T0451@@14A4@0CTi>04M7A`11@D40
?3`l03hn?P0o?cl0@T9204E5A@1=CDd0EUIF07YjNP1XJ6P0E5AD04m?C`12@T80@d=304E5A@1DE5@0
@D5103hn?P1:BTX0ADE503dm?@12@T80A4A404Y:BP11@D40@4100451@@12@T80DU9B06YZJP2GUiL0
_Kfm0P3>c/h01`2m_Kd0Vi^K06IVIP1TI6@0FEUI04m?C`13@d<00P15ADD03@13@d<0?3`l03hn?P0o
?cl0@D5103hn?P12@T80KVi^096AT@2=SHd0RXZ:07alO01hN7P00P1_Kfl01P1kNg/0SXj>08N7Q`1k
Ng/0LG5a06EUI@80KVi^01h0H61P05=CD`1BDU80BDU904A4A012@T80GEeM06EUI@22PX80RXZ:07em
O@1FEUH0GUiN05mOG`1IFET0Fe]K06=SH`2EUID0YjNW07moO`1MGEd0DE5A0451@@10@400?Cdm03Ph
>010@400?clo03Xj>P0m?Cd203Xj>P80>c/k0140?Cdm03`l?00o?cl0E5AD096AT@2c/k<0Y:BT08^;
R`1XJ6P0EeMG04Q8B011@D40@T9204U9B@1=CDd0EEEE04A4A00203lo?`0D03Xj>P0i>CT0?3`l0492
@P0l?3`0@D5105mOG`1ZJVX0K6a/05MGE`1@D500@D5103hn?P16ATH0H61P06MWI`1DE5@0Bd];0410
@00n?Sh203lo?`0L04M7A`1ADE40C4a<0492@P0n?Sh0ATI604a<C01FEUH0ATI603hn?P13@d<0AdM7
03dm?@0g=cL0>SXj03Ti>@0l?3`0>SXj03/k>`0l?3`0?Shn03`l?010@400?Shn04M7A`19BDT0BTY:
04A4A080@D5102@0ADE504Y:BP1ADE40HV9R06IVIP1IFET0Bd];04=3@`12@T80>SXj03dm?@12@T80
DU9B06IVIP1kNg/0QXJ607inOP1SHf<0EeMG05QHF01]KFd0PX:208^;R`1VIVH0HV9R05ADE01>CTh0
GemO079bLP1fMWH0QXJ608>3P`1hN7P0OGem07AdM01`L70208>3P`0T07QhN01ZJVX0MWIf06i^KP1T
I6@0KFe]07UiN@1gMgL0MGEe079bLP1_Kfl0I6AT06e]K@1/K6`0JVYZ079bLP1cLg<0NWYj0861P@27
QhL0QHF508R8R02a/K40alO70<W9b@2n_[h0[Jf]0;Ng]`2j^[X0`l?30=?Cd`3IfMT0dm?C0<o?c`3A
dM40c<c<0P2o_kl05039bLT0alO70<c<c03?cll0fMWI0<[:bP2^[Zh0Ph>305iNGP10@400?clo04A4
A01FEUH0Kfm_09:BTP2KVi/0XJ6Q07alO01OGel0EeMG0P1lO7`01`1GEeL0UiNG0:RXZ01SHf<0?clo
03hn?P0g=cL03Oooool0013ooooo0P18B4P00`16ATH0AdM704A4A0020492@P0904E5A@14A4@0A4A4
04Q8B017AdL0@d=304M7A`16ATH0@d=30080@D5100l0ADE504U9B@15ADD0A4A404I6AP19BDT0FEUI
069RHP1hN7P0MgMg04i>CP14A4@0BTY:05=CD`1<C4`00P11@D402P1FEUH0D51@059BDP1IFET0EUIF
0451@@0n?Sh0?Cdm03lo?`19BDT203lo?`0903dm?@10@400@D5103hn?P13@d<0@41003hn?P10@400
?Cdm0080@d=300`0?3`l0451@@0n?Sh0@41004A4A011@D40?3`l03Ti>@0n?Sh0@D5104A4A00n?Sh2
0451@@80?3`l0180>c/k03dm?@0l?3`0?clo0410@012@T80?clo0410@00n?Sh0?clo03hn?P0m?Cd0
?Shn0451@@10@400>CTi0410@00o?cl203Xj>P0>03lo?`17AdL0C4a<0451@@0m?Cd0@41003/k>`0n
?Sh0?Cdm0410@00o?cl0>SXj03hn?P0i>CT203Xj>P0603dm?@0l?3`0>c/k03Xj>P10@400?clo0P0l
?3`02@0n?Sh0?3`l03Ti>@0o?cl0?Cdm04=3@`0l?3`0>c/k03lo?`030410@00<04I6AP0n?Sh0?clo
0410@00k>c/0?Cdm03hn?P0k>c/0@D5104A4A00n?Sh0A4A40P10@4003011@D40Bd];06ATI01<C4`0
CDe=04m?C`1:BTX0?clo03dm?@0l?3`0ADE504A4A080?3`l01h0>SXj03`l?00m?Cd0>SXj04E5A@1F
EUH0Bd];04I6AP0o?cl0@d=304Y:BP1@D500EUIF06IVIP1XJ6P0I6AT05eMG@1BDU80GUiN06QXJ01H
F5P0ADE503dm?@0l?3`0>SXj03`l?00m?Cd0AdM704m?C`14A4@30410@00503Ph>010@400?clo03dm
?@0n?Sh00P11@D40>`0m?Cd0?3`l03`l?013@d<0@41003hn?P0m?Cd0B4Q80451@@0o?cl0ATI603`l
?011@D40?Shn03dm?@0l?3`0@T9205iNGP2DU9@0XJ6Q08F5Q@1XJ6P0GemO05aLG01ADE40Bd];05=C
D`1kNg/0Ogmo06][J`1UIFD0IfMW06m_K`1KFe/0@41003dm?@10@400?Shn04U9B@0o?cl0ADE504e=
C@1:BTX0FUYJ0:NWY`3=cLd0Y:BT06YZJP19BDT0FUYJ0820P02][Jd0][Jf0;2`/021PH40De=C05eM
G@1<C4`0@T920080?clo00H0?Shn03`l?00o?cl0?3`l03hn?P0o?cl204=3@`0404i>CP1GEeL0H61P
0820P080WIfM0100VYZJ0::RXP2FUYH0QXJ606QXJ018B4P0?Cdm03`l?00i>CT0>c/k03hn?P11@D40
?Shn03dm?@0n?Sh0@4100P0l?3`02@0j>SX0>3Ph03/k>`1ADE40KFe]09FEU@2>SXh0IFEU04];B`02
03/k>`0403`l?00j>SX0@41004E5A@80>c/k0P0o?cl06`0j>SX0?clo03lo?`0m?Cd0?clo05aLG01o
Ogl0/k>c0<_;b`2k^k/0U9BD07=cL`1FEUH0FEUI06i^KP1YJFT0HV9R04U9B@0k>c/0?Shn03Xj>P0i
>CT0?Shn03Ti>@14A4@0E5AD06YZJP0208:2PP0506m_K`1DE5@0>c/k03Hf=P0k>c/00P0h>3P05P0k
>c/0>3Ph03Ti>@0i>CT0=cLg03Xj>P0o?cl0A4A403dm?@0l?3`0CTi>055AD@19BDT0?Shn04A4A012
@T80F5QH08F5Q@2?Shl0J6QX05=CD`12@T8203Xj>P0>0410@00h>3P0>CTi03Ph>00m?Cd0@D5105iN
GP1_Kfl0JVYZ05YJFP0o?cl0@T9204=3@`19BDT204a<C00M05QHF013@d<0@T9205IFEP1fMWH0OWin
07alO02:RXX0TI6A08J6QP22PX80Ng]k07IfMP1jNWX0Kfm_05iNGP1IFET0AdM704Q8B01ADE40IFEU
07=cL`1eMGD0KVi^06a/K01`L700LG5a07=cL`1/K6`00P1UIFD06@1RHV80LG5a075aL@1_Kfl0JVYZ
06MWI`1VIVH0J6QX071`L01jNWX0Q8B407inOP24Q8@0S8b<09NGU`2DU9@0Xj>S0;:b/P2m_Kd0`<30
0;fm_@3>c/h0dM7A0<K6aP2l_;`00P3:b/X06@2[Zj/0MWIf051@D01CDe<0EUIF06a/K02EUID0/;2`
0;^k^`32`/80aLG50<K6aP2OWil0P82007AdM01_Kfl0MWIf06i^KP1GEeL0GUiN07AdM01RHV80GUiN
04I6AP1FEUH03Oooool0013ooooo00H0ATI604M7A`15ADD0AdM704A4A012@T820410@0030492@P10
@400@D510080@d=300<0A4A40492@P10@4000P11@D403P14A4@0@D5103lo?`0o?cl0?Cdm03lo?`12
@T80@d=304M7A`1:BTX0@T9203lo?`14A4@0BTY:0P16ATH06`17AdL0EUIF059BDP1>CTh0Cdm?05IF
EP10@400ADE503lo?`13@d<0B4Q80410@017AdL0Bd];04I6AP18B4P0@T9203dm?@0o?cl0>SXj0410
@011@D40>c/k04A4A011@D40ADE505YJFP0206=SH`0>04M7A`10@400>CTi03`l?00o?cl0@41003lo
?`10@400@D5103lo?`0k>c/0@T9203lo?`0m?Cd203`l?00304M7A`10@400?Shn0080?clo00X0?3`l
03lo?`0l?3`0?clo03Ph>00i>CT0@41003/k>`0l?3`0?Cdm0P0n?Sh01011@D40?clo03Ti>@0n?Sh2
03Xj>P0@03/k>`0n?Sh0?3`l03Xj>P0l?3`0>SXj03dm?@0j>SX0>c/k03Ph>00o?cl0ADE504I6AP0o
?cl0>SXj03Ph>080>c/k00T0>CTi03hn?P0n?Sh0@41003Xj>P0n?Sh0ADE503lo?`0l?3`00P0m?Cd0
5@0i>CT0?3`l0492@P12@T80B4Q805=CD`0n?Sh0@D5104=3@`0m?Cd0@41004Y:BP1BDU80DE5A05YJ
FP1RHV80E5AD04e=C@13@d<0>SXj03`l?00203lo?`80?3`l00L0>c/k03lo?`0m?Cd0?Cdm03lo?`12
@T80@D510080?clo00D0@D5103lo?`15ADD0?clo04M7A`0304Y:BP0>04I6AP14A4@0?clo03hn?P0m
?Cd0B4Q803hn?P0m?Cd0?clo04M7A`1JFUX0NWYj08:2PP1NGUh20492@P<0@D5102<0ADE503hn?P0o
?cl0@D510492@P0n?Sh0A4A403hn?P0m?Cd0?Shn0410@012@T80?clo04=3@`12@T80A4A403hn?P17
AdL0@d=304Y:BP1BDU80I6AT07QhN02HV9P0X:2P08^;R`1aLG40F5QH05MGE`1EEED0C4a<04Q8B01;
Bd/0BTY:04=3@`0303dm?@0K04=3@`0m?Cd0?3`l03hn?P13@d<0ADE504i>CP1=CDd0LG5a08Z:RP22
PX80QhN709NGU`2WYjL0Shn?06ATI01?Cdl0DE5A05]KF`1VIVH0Rh^;0:j^[P2@T900EUIF03`l?00k
>c/0?Shn00<0?3`l01<0>SXj03hn?P0k>c/0?Cdm0492@P1;Bd/0I6AT08b<S02`/;00`<300;Jf]P2A
TI40NGUi06EUI@1GEeL0@T9204M7A`16ATH0?Cdm0080ATI600P0BDU904=3@`15ADD0BTY:04e=C@0o
?cl0?Shn03dm?@<0?Shn01d0EUIF08V9R@2o_kl0/k>c08Z:RP1:BTX0B4Q804I6AP1>CTh0Bd];0451
@@0n?Sh0?Cdm03/k>`0l?3`0@T9204=3@`0l?3`0@D5103hn?P1GEeL0Q8B40:^[Z`2c/k<0[jn_09BD
U01^KVh0HF5Q05MGE`0205eMG@0F08b<S02EUID0S8b<05mOG`1<C4`0@D5103lo?`0l?3`0?Shn05QH
F01ZJVX0Q8B40:>SX`2VYZH0OGem061PH01:BTX0?Cdm03`l?00g=cL0?clo03/k>`80@d=300<0?Cdm
0492@P0i>CT00P0k>c/0400o?cl0ATI606a/K028R8P0Ng]k05EEE@1MGEd0MGEe08>3P`1]KFd0JVYZ
061PH01@D500>c/k03`l?00g=cL403/k>`0403Ti>@15ADD0@D510451@@80?Cdm01H0>SXj03Ph>00k
>c/0>SXj03`l?00o?cl0>SXj03`l?00k>c/0ADE5075aL@2<S8`0PH6107]kN`1gMgL0I6AT05mOG`1T
I6@0H61P05EEE@1>CTh0@4100P0o?cl0@`18B4P0BDU905eMG@1XJ6P0HF5Q05]KF`1IFET0Hf=S06QX
J01YJFT0G5aL04m?C`18B4P0?clo0492@P1FEUH0I6AT05QHF01FEUH0Bd];04Y:BP18B4P0CDe=04Y:
BP1@D500E5AD05MGE`1WIfL0J6QX06e]K@1YJFT0LG5a079bLP21PH40Rh^;096AT@2a/K40_;bl0;jn
_P30`<00_kno0:n_[`2XZ:P0`/;20;Fe]@2k^k/0^[Zj0<C4a03=cLd0^KVi0;6a/@2][Jd0X:2P0:BT
Y02MWId0YZJV0:BTY029RHT0Q8B407QhN022PX80QhN709^KV`2TY:@0OWin05QHF01RHV803Oooool0
013ooooo00@0ATI604A4A014A4@0A4A40`11@D420492@P80?clo0180@D510492@P10@400@4100451
@@12@T80?Shn04=3@`0n?Sh0?clo03hn?P0o?cl0@41003lo?`13@d<0@T920410@012@T8303lo?`05
03dm?@10@400A4A404=3@`16ATH00P10@400=P13@d<0@T9204=3@`12@T80AdM704a<C016ATH0@d=3
04I6AP12@T80A4A404Q8B012@T80@d=303lo?`11@D40?3`l03hn?P10@400BTY:05=CD`1]KFd0NWYj
08:2PP1[Jf/0CTi>069RHP1aLG40NWYj04A4A00o?cl0@4100451@@12@T80?3`l03dm?@0l?3`0?clo
03/k>`11@D40A4A40492@P1<C4`0GemO06QXJ01LG5`0A4A403Xj>P12@T80A4A40451@@15ADD0?Cdm
03Xj>P80?Cdm00@0>c/k03`l?010@400@d=30P0o?cl02010@400>SXj03`l?00k>c/0>CTi03`l?00h
>3P0>SXj0P0m?Cd01P0k>c/0@41004=3@`12@T80?3`l03Xj>P80?3`l0P0m?Cd0100l?3`0>3Ph03hn
?P0m?Cd203hn?P0<03Ph>00m?Cd0?Cdm03dm?@0l?3`0?Shn03dm?@0l?3`0BDU904];B`0m?Cd0?Shn
0P0o?cl00`10@400ATI604I6AP0204a<C00404i>CP11@D40>c/k03`l?080?Cdm00D0>SXj03`l?00l
?3`0?clo03Xj>P0203/k>`0503Ph>00n?Sh0?3`l03/k>`11@D400`0o?cl02015ADD0?3`l0492@P11
@D40?Shn03lo?`11@D40?clo0P10@4002P0j>SX0@d=303`l?013@d<0GEeM06a/K01ZJVX0Fe]K0492
@P0k>c/204=3@`0<04I6AP15ADD0AdM704i>CP13@d<0?clo04=3@`0o?cl0@41004e=C@16ATH0?Cdm
0P10@4002@0k>c/0?Shn0410@00o?cl0@T9204Y:BP1KFe/0LW9b08B4Q00207alO00O06YZJP1EEED0
CTi>055AD@1PH600EeMG04a<C017AdL0@d=303`l?00k>c/0?clo0492@P11@D40?Shn03/k>`0n?Sh0
?Cdm0451@@10@400ADE504a<C01EEED0LG5a06m_K`1IFET0B4Q804A4A012@T80C4a<04U9B@0203hn
?P0m03dm?@0n?Sh0>c/k04A4A017AdL0?clo0410@018B4P0EUIF06ATI01fMWH0S8b<08j>SP1fMWH0
IVIV05eMG@1EEED0OWin0:RXZ02n_[h0`/;20<C4a03:b/X0[jn_09:BTP1lO7`0K6a/055AD@17AdL0
HV9R08^;R`2RXZ80UIFE08R8R01ZJVX0MGEe06MWI`1>CTh0?clo0410@017AdL0H61P0861P@1hN7P0
Ogmo08:2PP2GUiL0Z:RX08J6QP1PH600IfMW06QXJ01LG5`0GUiN06][J`1cLg<0JVYZ04Q8B011@D40
BDU904Y:BP0203lo?`0?06MWI`2HV9P0a/K60<G5a@2SXj<0QXJ607IfMP1IFET0B4Q804E5A@18B4P0
CDe=06=SH`1aLG40FEUI0080CDe=00h0C4a<04E5A@17AdL0DE5A07YjNP2`/;00YjNW08J6QP1kNg/0
Hf=S075aL@2FUYH0YJFU06][J`80Bd];00D0CTi>04A4A014A4@0@4100451@@020492@P0F04];B`1N
GUh0Ph>30;6a/@33`l<0/;2`08F5Q@1mOGd0NWYj09>CT`22PX80C4a<0451@@0h>3P0>CTi03/k>`0j
>SX0?3`l03lo?`14A4@0B4Q803`l?080>c/k00L0=cLg03dm?@0e=CD0>c/k03Ti>@0n?Sh0B4Q80080
?Cdm02D0>CTi03Xj>P0m?Cd0@410065QH@1fMWH0F5QH04U9B@0m?Cd0>c/k03hn?P0o?cl0?Shn0410
@00k>c/0?3`l03lo?`18B4P0FEUI06EUI@1LG5`0CTi>04Y:BP1ADE40HF5Q05YJFP1LG5`0EEEE055A
D@0k>c/0>CTi03Ph>012@T80C4a<04I6AP0n?Sh0>c/k0080ATI60P1CDe<03P1=CDd0BTY:04i>CP1@
D500FEUI06EUI@1OGel0EUIF04Y:BP17AdL0@41004M7A`18B4P0E5AD0P1RHV807@1OGel0H61P06i^
KP1[Jf/0MgMg096AT@24Q8@0Shn?096AT@2?Shl0RXZ:08B4Q02^[Zh0]kNg0;no_`36a/H0c<c<0<g=
c@35aLD0[Zj^0<71`@2o_kl0aLG50;bl_02][Jd0XZ:R08f=S@1_Kfl0J6QX00gooooo000@ooooo`08
04Q8B015ADD0A4A40492@P11@D40@41004A4A019BDT20492@P050451@@10@400@D5103lo?`10@400
0P13@d<20492@P80@D5100P0A4A40492@P11@D40@D5103dm?@0o?cl0@4100492@P80?Cdm00@0?Shn
03`l?00n?Sh0@4100P0n?Sh01@0m?Cd0@4100410@011@D40AdM70080BTY:0`11@D402P12@T80?clo
04A4A013@d<0ADE504I6AP0o?cl0?Shn04E5A@0m?Cd20410@00:04I6AP1=CDd0DU9B05UIF@1ADE40
C4a<05MGE`1UIFD0J6QX055AD@80@d=301H0@41004Q8B013@d<0?clo03dm?@0o?cl0ATI60492@P1H
F5P0GUiN08R8R02WYjL0/[:b09^KV`1ZJVX0FUYJ05IFEP1BDU80A4A405aLG01eMGD0EeMG0P0m?Cd0
300k>c/0?clo03lo?`13@d<0?Cdm03/k>`0o?cl0>c/k04=3@`14A4@0>CTi03/k>`80?Cdm00P0>SXj
03`l?010@400A4A404a<C00n?Sh0>CTi03`l?080>c/k00<0>SXj0410@00m?Cd00P0l?3`0300f=SH0
?clo04A4A00o?cl0?Cdm03`l?00o?cl0>SXj03/k>`0l?3`0?Cdm04=3@`80?clo00@0?3`l04A4A012
@T80@T920P13@d<07018B4P0ATI604I6AP10@400ADE504A4A010@400@D5103hn?P0m?Cd0?Shn03Xj
>P0i>CT0?3`l0410@00j>SX0?Cdm0410@00m?Cd0BDU904i>CP13@d<0ATI60492@P0l?3`0?clo03dm
?@12@T820451@@040492@P16ATH0ADE504E5A@80?clo01@0@41004U9B@1;Bd/0B4Q803dm?@10@400
ATI604e=C@1@D500AdM704Q8B01;Bd/0CDe=04A4A00o?cl0@D510410@014A4@0@D5103`l?080?Cdm
0P0o?cl04`10@400BDU906IVIP1eMGD0QHF508>3P`20P800Ng]k06QXJ01@D500BDU905ADE01JFUX0
GemO05MGE`12@T80@D5103Ti>@0o?cl00P13@d<03P1:BTX0B4Q803lo?`12@T80@d=304A4A01=CDd0
GEeM061PH01eMGD0J6QX05=CD`1>CTh0@D510P0o?cl0700n?Sh0?Cdm03lo?`0m?Cd0?3`l03hn?P0l
?3`0>SXj03/k>`0l?3`0?clo051@D01`L700TI6A09nOW`2HV9P0X:2P0<71`@2f][H0TY:B08^;R`28
R8P0U9BD09JFUP1gMgL0FEUI055AD@1FEUH206ATI00R05YJFP1LG5`0IfMW08b<S02LW9`0/k>c09nO
W`1_Kfl0HV9R06IVIP1^KVh0KFe]06=SH`25QHD0VYZJ0::RXP2d];@0/K6a09nOW`1_Kfl0CDe=04=3
@`19BDT0CTi>04U9B@1>CTh0@d=303hn?P13@d<0@D5104U9B@14A4@0ADE504];B`80CTi>02L0B4Q8
069RHP2GUiL0alO70;6a/@25QHD0G5aL04Q8B016ATH0DE5A06IVIP1CDe<0C4a<059BDP1LG5`0BTY:
0492@P14A4@0@D5104M7A`1QHF40Ti>C09jNWP2a/K40a<C40:RXZ02_[jl0^k^k0:FUY@2CTi<0S8b<
08F5Q@1fMWH0K6a/06QXJ01OGel0BTY:04A4A01JFUX00P1[Jf/05`1`L700OGem0:FUY@2o_kl0`l?3
0:^[Z`22PX80J6QX065QH@1YJFT0LW9b07AdM01EEED0?Cdm03Lg=`10@400Bd];06ATI01gMgL0QXJ6
08V9R@1cLg<0Bd];0080>c/k00`0>SXj03dm?@13@d<0FUYJ06m_K`1aLG40IFEU04e=C@0m?Cd0>c/k
03Ti>@14A4@204e=C@0>05QHF016ATH0?Cdm03/k>`0j>SX0?3`l03hn?P0m?Cd0>CTi03lo?`0n?Sh0
?3`l0451@@15ADD30492@P0D055AD@1GEeL0DU9B059BDP1;Bd/0@D5103`l?00j>SX0?clo04E5A@1?
Cdl0D51@04Q8B00o?cl0?3`l0451@@1ADE40De=C05ADE01BDU8305MGE`0Z04e=C@17AdL0@41003lo
?`0k>c/0>CTi03Xj>P0l?3`0BDU904Y:BP1=CDd0@4100451@@0n?Sh0@4100451@@15ADD0CDe=04Q8
B01<C4`0FEUI05MGE`1IFET0EEEE059BDP1DE5@0F5QH06m_K`27QhL0T92@08F5Q@2KVi/0Z:RX0;Bd
]02e]KD0^;Rh0:FUY@24Q8@0K6a/08>3P`25QHD0SHf=3Oooool0013ooooo00T0ADE504=3@`14A4@0
ATI604=3@`11@D40@d=304U9B@14A4@00P11@D402`13@d<0@D5103lo?`10@400@T9204=3@`14A4@0
@d=304A4A010@400?clo00<0@T9200<0?Shn03lo?`0n?Sh0100o?cl05`0m?Cd0Bd];04E5A@0j>SX0
?Shn0451@@14A4@0AdM704I6AP1;Bd/0@D510410@00m?Cd0?clo03hn?P0l?3`0?Shn03dm?@0o?cl0
A4A403hn?P0k>c/0?clo0080@T920P0n?Sh00`13@d<0@41004=3@`020410@00=03dm?@0l?3`0?Shn
03lo?`11@D40@T9204Y:BP1=CDd0BDU904=3@`12@T80CDe=04A4A0020492@P0J04Q8B01>CTh0Bd];
04a<C01ADE40FUYJ04U9B@0n?Sh0ATI60492@P19BDT0HF5Q0861P@1fMWH0BDU90410@00k>c/0?Shn
03Xj>P0l?3`0?clo03`l?00m?Cd0@41003dm?@0l?3`203/k>`0703lo?`0n?Sh0?3`l03/k>`13@d<0
?clo03/k>`0203Xj>P0<03lo?`0l?3`0?3`l03/k>`0o?cl0?Shn03dm?@0n?Sh0>CTi03Xj>P0k>c/0
>SXj0P0k>c/06P0i>CT0>SXj03Ph>00l?3`0@d=304A4A012@T80?clo0451@@14A4@0@41003dm?@0n
?Sh0?clo0410@016ATH0@T9203hn?P10@400A4A403hn?P17AdL0?Shn03`l?010@400>c/k0P0o?cl0
2@10@400ADE505=CD`15ADD0ATI604Q8B011@D40?3`l0410@00203Ti>@0D03`l?00n?Sh0?Cdm0451
@@15ADD0A4A40451@@0k>c/0@d=303lo?`0i>CT0?Shn0410@013@d<0@D5103`l?010@400A4A404];
B`14A4@20451@@0D04A4A018B4P0@T920410@00o?cl0@41004A4A012@T80@D510410@014A4@0?Shn
03lo?`12@T80Cdm?06UYJ@1SHf<0H61P06ATI01IFET204];B`0;04m?C`1DE5@0F5QH04i>CP13@d<0
CDe=05ADE01<C4`0@T9204=3@`16ATH00P0n?Sh04P10@400@D5104M7A`1>CTh0B4Q8059BDP1`L700
EeMG04I6AP0m?Cd0?Shn03dm?@0k>c/0?Shn03/k>`0l?3`0>CTi03hn?P80?clo00h0@41003hn?P0m
?Cd0B4Q805ADE01ZJVX0U9BD0:ZZZP2UYJD0U9BD09fMW@2HV9P0Shn?06MWI`80D51@02<0BDU904];
B`12@T80?Cdm03`l?00n?Sh0@41003hn?P11@D40?Shn0492@P1:BTX0G5aL061PH01hN7P0Ph>308b<
S021PH40EEEE0410@01KFe/0Ti>C0;Rh^02e]KD0^;Rh09bLW01JFUX0A4A403hn?P0j>SX0?Cdm03Xj
>P13@d<0DE5A03dm?@0303`l?00403dm?@14A4@0Fe]K0:>SX`80_;bl05H0/;2`0;Zj^P3Cdm<0c/k>
0:BTY01hN7P0MWIf06][J`15ADD0@41004A4A01WIfL0I6AT04Y:BP11@D40BDU9055AD@1XJ6P0RXZ:
0:RXZ02n_[h0d];B0=_Kf`3AdM40f=SH0=CDe03@d=00bLW90:^[Z`2XZ:P0/;2`08^;R`1NGUh0BTY:
059BDP14A4@0E5AD06IVIP2:RXX0ZZZZ0:VYZ@26QXH0M7Ad08R8R02=SHd0X:2P08V9R@1QHF40De=C
05IFEP1]KFd0HV9R05UIF@14A4@0?Shn04a<C01MGEd0NGUi09JFUP2`/;00Z:RX07inOP1PH600CTi>
04=3@`1FEUH0Hf=S05QHF01RHV80WinO0;Ng]`2b/[80T92@065QH@19BDT0@D5104=3@`1JFUX0JFUY
05eMG@1ADE40C4a<05eMG@1DE5@0ATI603/k>`80>SXj0200?Shn055AD@1;Bd/0?clo03Ti>@0j>SX0
>c/k04M7A`1NGUh0JFUY06a/K01CDe<0@41003/k>`0i>CT0>c/k04U9B@1>CTh0C4a<059BDP1:BTX0
@41004=3@`1<C4`0B4Q804a<C01;Bd/0B4Q804a<C01EEED0ATI603hn?P80>SXj00T0>c/k03Xj>P12
@T80@D5104E5A@0o?cl0@d=304i>CP16ATH00P0l?3`03@0m?Cd0>3Ph03/k>`0h>3P0?Cdm0410@01@
D500EUIF05EEE@1JFUX0DU9B051@D018B4P00P13@d<03`17AdL0Bd];04U9B@17AdL0ATI604U9B@1D
E5@0EUIF059BDP1?Cdl0F5QH04a<C018B4P0ATI604a<C00=ooooo`004?ooool03018B4P0ADE504E5
A@14A4@0ADE504A4A015ADD0ATI60451@@14A4@0@41004I6AP80@D5100@0@T9204A4A014A4@0A4A4
0P13@d<01P14A4@0ADE504Y:BP13@d<0@41003lo?`@0?Shn01@0@d=303lo?`14A4@0A4A40451@@0l
?3`0?Cdm03hn?P11@D40@d=30492@P16ATH0?clo03hn?P14A4@0ADE503lo?`17AdL0A4A403`l?080
?Shn00<0?Cdm03/k>`0m?Cd00P0n?Sh03@0m?Cd0@d=303Xj>P11@D40ATI60410@012@T80?Shn03dm
?@0k>c/0@41004U9B@0n?Sh00P10@40204=3@`0@03hn?P11@D40>SXj0451@@10@400@d=30410@00o
?cl0@D5104I6AP10@400>CTi03lo?`0m?Cd0ADE504e=C@80CTi>0140EUIF04a<C01BDU80GEeM04m?
C`0n?Sh0C4a<05IFEP1EEED0GemO04A4A00n?Sh0@d=304A4A01QHF40BTY:03`l?00203lo?`0A03hn
?P0k>c/0?3`l03Xj>P0i>CT0>c/k03hn?P0l?3`0>CTi03dm?@11@D40?clo03`l?00k>c/0?clo03`l
?00m?Cd00`0l?3`20410@00704A4A015ADD0@d=30451@@0o?cl0@41003lo?`0203hn?P0?03dm?@0l
?3`0?Cdm03`l?011@D40?Cdm03/k>`10@400ADE503lo?`0l?3`0ATI60492@P0n?Sh0@D510080@d=3
00L0Bd];0451@@0o?cl0>SXj03hn?P0o?cl0?Cdm0080?Shn00T0@T9203dm?@0n?Sh0?3`l03dm?@10
@400A4A403`l?00k>c/00P0l?3`05@0m?Cd0@D5103lo?`0o?cl0?Shn03lo?`12@T80@d=304I6AP12
@T80@41003Ti>@0o?cl0BDU904I6AP14A4@0ADE50410@014A4@0>c/k03hn?P0203lo?`0;03/k>`0o
?cl0@T9204E5A@1BDU80LG5a07IfMP1HF5P0ATI604Q8B01=CDd00P13@d<02P12@T80@D5104M7A`13
@d<0BTY:0492@P10@400BDU905YJFP1:BTX204A4A00>04=3@`18B4P0?clo03hn?P14A4@0ATI603Xj
>P0n?Sh0ADE50410@00m?Cd0@D5103hn?P11@D4204I6AP07065QH@1LG5`0GUiN06=SH`1QHF40I6AT
06EUI@0205QHF00706][J`26QXH0O7al069RHP1>CTh0BTY:04E5A@020451@@050410@00o?cl0@T92
03hn?P13@d<00P0m?Cd203lo?`0>04Q8B012@T80@D5104A4A01FEUH0Kfm_07YjNP1lO7`0M7Ad05UI
F@18B4P0G5aL06][J`1eMGD207moO`0608F5Q@1ZJVX0Cdm?04M7A`1:BTX0CDe=0P11@D40301BDU80
>c/k03`l?00l?3`0@D5104I6AP1CDe<0VIVI0<G5a@2b/[80Vi^K0:ZZZP80^[Zj01@0XZ:R08f=S@20
P800KVi^06UYJ@1MGEd0C4a<04E5A@11@D40BDU904i>CP1iNGT0TI6A0:n_[`33`l<0d=3@0<K6aP3E
eMD0emOG0=?Cd`80clo?0580][Jf08^;R`1kNg/0KVi^05]KF`1IFET0Cdm?04I6AP0m?Cd0@T9204U9
B@16ATH0HF5Q06m_K`23Ph<0Ogmo08j>SP1]KFd0EUIF061PH01TI6@0HV9R055AD@16ATH0BTY:04e=
C@1DE5@0ATI60492@P19BDT0Jf][08n?S`2ATI40UiNG09FEU@2JVYX0PX:206ATI01?Cdl0@T92059B
DP27QhL0XZ:R09ZJVP2<S8`0Ogmo05aLG01ADE40BDU904i>CP1NGUh0K6a/08b<S02KVi/0OWin0820
P01gMgL0Lg=c05mOG`13@d<0>c/k04a<C01MGEd0F5QH06EUI@1KFe/0ATI603/k>`11@D40GUiN06][
J`1dM7@0I6AT055AD@1:BTX0A4A404Q8B01<C4`0GUiN065QH@1OGel0Fe]K0P1CDe<0:01GEeL0Bd];
04U9B@1:BTX0AdM70451@@15ADD0CTi>05ADE019BDT0?3`l03/k>`12@T80ADE504i>CP1ADE40D51@
04i>CP17AdL0A4A404];B`1?Cdl0CTi>04e=C@17AdL0@D5103Xj>P0l?3`0@41004];B`1HF5P0FEUI
055AD@1EEED0G5aL05MGE`1?Cdl0BTY:04];B`10@4020451@@0=03`l?00o?cl0?3`l03`l?00n?Sh0
=CDe03Lg=`0i>CT0>c/k03Ti>@0k>c/0>CTi03Xj>P0=ooooo`004?ooool01@15ADD0ATI604U9B@17
AdL0A4A40080ADE500H0@d=304A4A014A4@0?Shn0451@@13@d<304A4A0070451@@13@d<0@T920451
@@13@d<0A4A404=3@`0204A4A00:0451@@10@400?clo0410@00o?cl0@41003dm?@12@T80@41003hn
?P80?clo00H0@D5103hn?P0l?3`0>c/k03hn?P11@D4203hn?P090451@@0k>c/0A4A40492@P0m?Cd0
?Shn03dm?@0l?3`0@4100080?3`l00d0@D5103`l?013@d<0A4A403`l?013@d<0@D5103lo?`11@D40
ADE503Xj>P0o?cl0AdM700<0@41000L0?clo0410@011@D40@T920410@015ADD0@D510080>c/k0100
@4100492@P10@400?Shn03/k>`0n?Sh0@D510410@012@T80?Shn03`l?013@d<0@41004=3@`0o?cl0
ATI60P14A4@0:P1ADE40IfMW05QHF01<C4`0ADE50492@P15ADD0DE5A06EUI@1[Jf/0DU9B04m?C`1=
CDd0ADE503Xj>P0n?Sh0?clo03hn?P0l?3`0>c/k03dm?@12@T80@D5103dm?@0o?cl0>c/k0451@@0o
?cl0ATI6055AD@1QHF40N7Qh09FEU@2NWYh0S8b<04Y:BP0k>c/0?Cdm03hn?P0o?cl0?3`l03lo?`80
@d=300P0@41003dm?@0m?Cd0@D5103hn?P10@400?clo03dm?@80@T9200D0Bd];0492@P11@D40?Shn
0410@00203lo?`030451@@0o?cl0?Cdm0080@4100`0l?3`01`10@400@D510451@@10@400?clo03Xj
>P0l?3`00P0j>SX04@11@D40@d=303`l?00o?cl0A4A403lo?`12@T80@41003`l?010@400BDU90410
@00o?cl0?Shn0410@014A4@0@4100080@d=301l0?Shn03lo?`11@D40?3`l03hn?P0k>c/0?Shn03lo
?`1BDU80H61P065QH@1:BTX0A4A403hn?P13@d<0A4A404I6AP0n?Sh0@T9204A4A012@T80?clo0410
@00l?3`0@T9204=3@`16ATH0DU9B05EEE@1>CTh0ATI60080?Shn00@0?clo03hn?P0o?cl0ADE50P1M
GEd09`1@D500@D510451@@10@400FEUI06EUI@1JFUX0De=C05YJFP1KFe/0IVIV05]KF`1:BTX0ATI6
04M7A`1;Bd/0D51@04M7A`1:BTX0ADE50451@@0m?Cd0>c/k03Xj>P0i>CT0>SXj03dm?@0j>SX0?clo
03`l?012@T80@d=304m?C`1>CTh0A4A404M7A`1@D500OGem09VIV@0209fMW@1>08f=S@22PX80Lg=c
05iNGP1CDe<0FEUI059BDP1:BTX0@d=303lo?`13@d<0@T92055AD@1[Jf/0T92@09NGU`1IFET0?Cdm
0492@P10@400AdM705ADE01YJFT0S8b<0:2PX02`/;00YJFU07EeM@1>CTh0K6a/0:VYZ@2_[jl0PH61
06EUI@1?Cdl0ATI604=3@`12@T80?Cdm03/k>`0n?Sh0BDU908N7Q`3Bd]80emOG0;jn_P2m_Kd0/K6a
0;Vi^@3;bl/0^;Rh0:^[Z`2MWId0NGUi051@D013@d<0@D5103lo?`10@400A4A40492@P1IFET0N7Qh
09FEU@2QXJ40U9BD09FEU@23Ph<0KVi^08V9R@2h^;P0Z:RX0:NWY`2XZ:P0WYjN08f=S@27QhL0NGUi
0P1fMWH06P1RHV80I6AT08^;R`2CTi<0];Bd0:ZZZP1_Kfl0F5QH04];B`19BDT0AdM704a<C01PH600
MWIf07=cL`1^KVh0K6a/05=CD`14A4@0?clo04Q8B01CDe<0NGUi096AT@2NWYh0QXJ60P2@T9007020
P800KVi^04Y:BP13@d<0?Cdm04=3@`1SHf<0SXj>08V9R@1iNGT0LW9b059BDP18B4P0Cdm?05ADE01]
KFd0IFEU05iNGP1ADE40EUIF05UIF@1LG5`0HF5Q05EEE@1@D500AdM704=3@`1=CDd204m?C`0B055A
D@1=CDd0?Shn04m?C`1NGUh0HV9R05iNGP1KFe/0Cdm?04U9B@1ADE40EUIF05QHF01PH600HF5Q05QH
F01JFUX0EUIF0P19BDT07P1;Bd/0F5QH06=SH`1HF5P0CDe=059BDP1HF5P0DE5A05iNGP1QHF40GemO
05QHF01@D500CTi>04a<C015ADD0DE5A04e=C@15ADD0>c/k03lo?`10@400?Shn0451@@0k>c/0>SXj
03Ti>@0h>3P0>SXj03Ti>@80=cLg00<0=CDe03Ph>00g=cL03Oooool0013ooooo00D0AdM704I6AP17
AdL0ADE504=3@`0204E5A@0<04A4A012@T80?Cdm0410@013@d<0@D510492@P11@D40?clo03hn?P10
@400@D510P0o?cl01012@T80@D510410@00m?Cd20410@00303lo?`11@D40@D510080?Shn00@0@T92
04=3@`11@D40@4100P0n?Sh20410@00504=3@`0n?Sh0>c/k03dm?@13@d<00P11@D401P10@400?clo
03hn?P0n?Sh0?Cdm03/k>`80@T920140?clo03dm?@0o?cl0?Cdm0451@@10@400@d=303lo?`13@d<0
?Cdm0410@00k>c/0@T9203/k>`0l?3`0?clo03dm?@0203hn?P0303dm?@10@400@D510080@41000@0
>SXj03hn?P10@400@D510P0o?cl01P13@d<0?clo0451@@0m?Cd0@D5103/k>`80@D510P0m?Cd20492
@P0H0451@@10@400ADE504=3@`0n?Sh0?Cdm03lo?`0m?Cd0ATI604e=C@1fMWH0Ph>3065QH@1EEED0
B4Q80451@@10@400CTi>05]KF`1QHF40GUiN05ADE015ADD0?3`l0P0k>c/00`0o?cl0Bd];05aLG002
07EeM@0;08V9R@2FUYH0Vi^K0:n_[`2`/;00WYjN07IfMP1:BTX0A4A404=3@`0l?3`00P0m?Cd01@0l
?3`0>CTi03Xj>P0j>SX0?Shn0080?Cdm00<0?3`l0451@@13@d<00P13@d<01010@400>SXj03`l?00m
?Cd203hn?P0403/k>`0o?cl0?Cdm0451@@80?clo0P0l?3`00`0m?Cd0>c/k03lo?`0203hn?P0304A4
A00o?cl0>c/k00<0?3`l0P11@D400`12@T80@41003Ti>@0203lo?`0503hn?P0k>c/0>CTi03dm?@11
@D400`0o?cl03P0k>c/0?clo03`l?00o?cl0@d=30451@@0k>c/0@4100451@@0o?cl0ADE505MGE`18
B4P0@d=30`0m?Cd0100n?Sh0@41004U9B@15ADD20451@@0>03lo?`0m?Cd0@D5103lo?`10@400@D51
04Q8B01ADE40Bd];04Q8B010@400AdM704Q8B01@D50204a<C00@051@D01GEeL0AdM704U9B@1?Cdl0
ADE504m?C`1YJFT0F5QH04E5A@13@d<0?3`l0492@P17AdL0@d=304Y:BP80ADE50`0m?Cd08@0j>SX0
>c/k03Xj>P11@D40?Cdm03`l?00k>c/0>CTi04M7A`18B4P0ATI604Y:BP1GEeL0GUiN08R8R02EUID0
LW9b06a/K022PX80V9RH08^;R`1gMgL0GUiN05EEE@1@D500ATI604U9B@1DE5@0Cdm?0492@P0m?Cd0
A4A404E5A@0204];B`2905iNGP1KFe/0GEeM05iNGP1EEED0EeMG065QH@1mOGd0VYZJ08Z:RP1gMgL0
IVIV05iNGP1>CTh0ADE5059BDP1DE5@0D51@06e]K@2<S8`0O7al08B4Q01gMgL0HF5Q06UYJ@1SHf<0
De=C051@D01TI6@0UIFE0;Vi^@2YZJT0TY:B09RHV02QXJ40^;Rh0;jn_P2GUiL0LG5a06MWI`1_Kfl0
De=C03lo?`0n?Sh0A4A405mOG`1lO7`0FEUI06=SH`2YZJT0d=3@0<W9b@2WYjL0Hf=S04m?C`1>CTh0
D51@071`L025QHD0V9RH08>3P`1WIfL0KFe]07MgM`1eMGD0Jf][04Y:BP1QHF40WinO0;Fe]@2OWil0
LW9b075aL@1MGEd0Cdm?04M7A`1CDe<0FEUI04I6AP12@T80C4a<04U9B@12@T80?clo04I6AP1HF5P0
KVi^07EeM@1kNg/0RHV908j>SP22PX80OWin07YjNP1/K6`0BTY:0451@@12@T80@D5104];B`1KFe/0
Jf][0861P@1ZJVX0HV9R04m?C`16ATH0AdM704E5A@1:BTX0@T9203`l?017AdL0GUiN05=CD`1;Bd/0
EeMG051@D019BDT0>CTi03Ph>00i>CT0AdM7055AD@1BDU80BTY:0492@P1=CDd0Fe]K069RHP1EEED0
BDU904Y:BP1=CDd0BDU904a<C01HF5P00P1LG5`05P1EEED0EUIF04];B`1ADE40De=C04a<C01BDU80
G5aL05eMG@1FEUH0FEUI065QH@1RHV80F5QH05EEE@1KFe/0EUIF05ADE01FEUH0D51@04M7A`18B4P2
04Y:BP0904I6AP11@D40?Cdm03hn?P0j>SX0?3`l03lo?`0j>SX0>c/k0080>SXj0P0g=cL01@0i>CT0
?3`l03Lg=`0i>CT0?3`l00gooooo000@ooooo`0504E5A@14A4@0B4Q804A4A017AdL00P13@d<04@12
@T80?clo04=3@`11@D40@d=30451@@0o?cl0@T9203`l?00n?Sh0?clo0410@00n?Sh0?Cdm0492@P0l
?3`0?clo0080?Cdm00<0?3`l0410@012@T800P11@D400`0o?cl0AdM704E5A@020410@0060451@@10
@400@D510410@012@T80?Shn0P0m?Cd20451@@050410@00n?Sh0>SXj03dm?@0o?cl00P0n?Sh203dm
?@0703Xj>P0o?cl0?3`l03Xj>P0o?cl0>SXj0410@0020451@@80?3`l0P0m?Cd01@0o?cl0>c/k03`l
?00l?3`0?clo0080?Shn0P0l?3`02@0k>c/0?clo03`l?00n?Sh0?clo03hn?P0l?3`0>SXj03`l?003
0410@00A0492@P0k>c/0@T9203dm?@0n?Sh0@41003dm?@0o?cl0@4100492@P0m?Cd0@D5103Xj>P0n
?Sh0?clo04M7A`1@D5000`1CDe<01`14A4@0?Shn03lo?`0o?cl0ATI604a<C01?Cdl00P1>CTh02016
ATH0?clo03Xj>P0l?3`0@T9204A4A010@400?Shn0P16ATH06P1?Cdl0C4a<04U9B@1ADE40FEUI06AT
I01RHV80EUIF04a<C013@d<0A4A40492@P11@D40?Shn03`l?00n?Sh0?clo03`l?00k>c/0?3`l0410
@01=CDd0HV9R05aLG01OGel0EEEE0P13@d<00`10@400?Cdm03hn?P0203dm?@0I03Ti>@0k>c/0?3`l
0410@00l?3`0@T920451@@0l?3`0@41004E5A@16ATH0@41004M7A`1<C4`0ADE504I6AP11@D40Cdm?
059BDP17AdL0ADE504a<C010@400?Shn03`l?00203lo?`0803`l?00n?Sh0@41003dm?@0o?cl0@d=3
03/k>`0n?Sh203dm?@0L04=3@`0n?Sh0A4A404a<C01?Cdl0De=C04Y:BP0o?cl0@D5103hn?P0m?Cd0
>3Ph03dm?@0j>SX0>c/k03lo?`15ADD0?Cdm03/k>`0m?Cd0?clo03/k>`0m?Cd0>c/k04E5A@1FEUH0
FEUI05MGE`80F5QH00L0CTi>04=3@`14A4@0@D5103lo?`0k>c/0@T920080AdM703@0?Shn04=3@`11
@D40?clo04I6AP17AdL0BDU904=3@`1;Bd/0A4A404=3@`10@400@T9203/k>`0i>CT0>SXj03/k>`0j
>SX0@41005MGE`1:BTX0?Cdm03`l?01<C4`0FUYJ05mOG`1>CTh0Cdm?05]KF`1SHf<0M7Ad071`L01R
HV80J6QX05]KF`1?Cdl0@T9204=3@`14A4@0@d=304a<C01IFET0De=C051@D00n?Sh0@D5104M7A`1L
G5`0KVi^06QXJ01UIFD0FUYJ0P1<C4`0201VIVH0M7Ad0861P@24Q8@0LW9b069RHP1EEED0BDU90P14
A4@05P1=CDd0GemO079bLP1eMGD0LW9b07UiN@1^KVh0EEEE05QHF01CDe<0DU9B06ATI01ZJVX0IFEU
05mOG`1QHF40Jf][06MWI`1UIFD0KFe]07=cL`1_Kfl207EeM@0D06UYJ@1VIVH0EeMG04m?C`12@T80
@D5104U9B@1JFUX0LW9b08^;R`1/K6`0OGem09nOW`2ZZZX0_kno0::RXP1fMWH0BTY:03dm?@0o?cl2
04=3@`0X03hn?P0o?cl0ADE504I6AP1TI6@0IVIV0410@00n?Sh0L71`07YjNP1GEeL0Fe]K071`L01d
M7@0GemO05eMG@1IFET0IfMW06EUI@1eMGD0P82009nOW`2JVYX0Ogmo08>3P`2IVIT0QhN7092@T029
RHT0UiNG08j>SP1oOgl0KFe]06MWI`1RHV80Fe]K04e=C@18B4P0CDe=06a/K080Ph>30140Jf][04Y:
BP12@T80@4100451@@0n?Sh0>CTi03dm?@0k>c/0@d=304e=C@1WIfL0EUIF0492@P0k>c/0@T9203Xj
>P0203dm?@0Y03Xj>P18B4P0De=C04a<C01>CTh0D51@05EEE@1ADE40>3Ph03hn?P0m?Cd0?Shn0492
@P1?Cdl0De=C04Y:BP1<C4`0BTY:04I6AP1<C4`0Bd];04U9B@1;Bd/0EeMG04e=C@1BDU80EUIF05EE
E@1ADE40CTi>05YJFP1KFe/0ATI604];B`1?Cdl0BDU905ADE01HF5P0CDe=04U9B@17AdL00P13@d<0
3@17AdL0?3`l03Ph>00g=cL0>CTi03Lg=`0j>SX0>CTi03Xj>P0h>3P0=cLg03De=@0h>3P00P0i>CT0
0`0h>3P0>CTi03Ti>@0=ooooo`004?ooool0401MGEd0K6a/08J6QP1lO7`0NWYj05IFEP17AdL0@T92
0410@016ATH0A4A404Q8B014A4@0?clo04=3@`0n?Sh204=3@`0>0451@@0n?Sh0?clo0492@P16ATH0
@T9203hn?P10@400>c/k03hn?P10@400@T9204=3@`11@D4203hn?P80@D5100L0A4A403lo?`12@T80
@d=30451@@13@d<0@T920080?Cdm00T0@4100492@P12@T80>c/k03hn?P10@400@T920410@00k>c/0
0P0o?cl20410@00@03/k>`0n?Sh0?Shn03Xj>P0n?Sh0?clo03dm?@0j>SX0@D5103hn?P0o?cl0?Cdm
03lo?`0l?3`0>c/k03`l?0<0?Cdm00@0?clo03`l?00k>c/0>3Ph0P0l?3`00`0k>c/0?3`l03lo?`02
03lo?`80?Cdm00d0?3`l0492@P0l?3`0?3`l03hn?P0o?cl0?Cdm03`l?00j>SX0@T920410@00k>c/0
?Cdm0080@D5101X0@T9204=3@`0k>c/0@T9203lo?`0m?Cd0?Shn03Ti>@0n?Sh0>c/k03dm?@0n?Sh0
@41003Xj>P0k>c/0?clo04=3@`0o?cl0@41003`l?00k>c/0?clo0451@@0o?cl0?Shn0492@P80@d=3
01l0@D510410@00m?Cd0@T920451@@18B4P0ATI60410@00k>c/0?Cdm0492@P10@400>c/k03Ti>@0l
?3`0?Cdm05MGE`1dM7@0L71`05eMG@1EEED0A4A40410@012@T80@41004=3@`1;Bd/0A4A40410@00l
?3`0?clo0080?Shn01/0@D5104Q8B014A4@0EEEE07alO01kNg/0J6QX05iNGP10@400?Shn03lo?`0k
>c/0@T9204I6AP13@d<0?Cdm03`l?00k>c/0>SXj03hn?P12@T80?clo03/k>`0o?cl0@D5103Ti>@11
@D400P12@T820451@@0>04Y:BP17AdL0?Shn03hn?P12@T80ADE50492@P0o?cl0@T9204U9B@15ADD0
?clo0451@@0n?Sh203lo?`0@0451@@1<C4`0?clo03hn?P1FEUH0K6a/05MGE`18B4P0EEEE06a/K01W
IfL0EEEE04U9B@11@D40?Shn0451@@80?Cdm00D0?3`l03Xj>P0i>CT0?3`l03Xj>P0203`l?00303lo
?`0m?Cd0?clo0080@T920240?Shn03`l?010@400ADE503lo?`0k>c/0?Shn03/k>`0j>SX0>c/k03dm
?@0j>SX0>3Ph03dm?@0n?Sh0?clo04M7A`1OGel0Hf=S055AD@1<C4`0BTY:04e=C@1SHf<0J6QX06AT
I01QHF40EUIF04M7A`10@400?clo0451@@12@T800P11@D403P14A4@0@D5105QHF01TI6@0N7Qh07Mg
M`1YJFT0Hf=S05]KF`1PH600EeMG05aLG01ZJVX0Kfm_0P1^KVh04@1UIFD0MWIf07inOP1/K6`0DU9B
04=3@`19BDT0C4a<05MGE`1^KVh0LW9b071`L01RHV80BTY:04A4A01:BTX0@4100080@D5100/0C4a<
05IFEP1@D500Cdm?04];B`1IFET0DE5A051@D01PH600HV9R05]KF`0204i>CP1204U9B@15ADD0B4Q8
055AD@1@D500F5QH05YJFP1MGEd0G5aL05=CD`1HF5P0JVYZ079bLP20P800Lg=c04a<C00l?3`0@410
04Y:BP14A4@0AdM704A4A01NGUh0JFUY06EUI@1ADE40E5AD05QHF01?Cdl0D51@061PH01VIVH0Lg=c
07inOP1NGUh0C4a<04E5A@12@T80BTY:05QHF01oOgl0SXj>0::RXP2FUYH0Ti>C0::RXP2/[:`0S8b<
07alO01cLg<0KFe]06QXJ01SHf<0GUiN05ADE018B4P0G5aL04m?C`1CDe<0IFEU06m_K`1YJFT0IFEU
05YJFP1;Bd/0@d=30`0o?cl0:P1ADE40De=C04U9B@19BDT0C4a<055AD@0o?cl0?Shn0451@@16ATH0
B4Q804Y:BP1<C4`0ADE504I6AP15ADD0AdM704];B`1=CDd0A4A403/k>`11@D40@41004M7A`1ADE40
Cdm?04];B`16ATH0AdM704i>CP1<C4`0BDU904m?C`1FEUH0GemO06YZJP1[Jf/0H61P065QH@1LG5`0
De=C05ADE080De=C01<0B4Q80492@P1>CTh0EUIF04i>CP1GEeL0GUiN04e=C@15ADD0@D5103hn?P12
@T80?Shn03Xj>P0m?Cd0=SHf03/k>`0h>3P0?3`l0080@d=300@0?3`l03Ti>@0i>CT0>CTi0P0g=cL2
03Hf=P0303De=Ooooooooooo00_ooooo000@ooooo`0K0:b/[02TY:@0T92@09fMW@2UYJD0Ti>C06AT
I01CDe<0NGUi0:6QX@2TY:@0RHV9079bLP1fMWH0K6a/04m?C`17AdL0ADE504i>CP19BDT0CDe=04M7
A`15ADD0@d=304A4A019BDT0Bd];0080D51@0180ATI604Q8B018B4P0ADE503`l?010@400?clo0410
@00o?cl0@d=304M7A`11@D40@41003`l?00m?Cd0@D510410@00o?cl20492@P0703hn?P12@T80?clo
03hn?P13@d<0?clo0451@@020410@00;03lo?`10@400?Cdm0451@@13@d<0?Shn0451@@0n?Sh0ADE5
03dm?@10@4000P0m?Cd02P11@D40?3`l0410@00n?Sh0@T9203dm?@0o?cl0@41003dm?@0k>c/203Xj
>P0403`l?00m?Cd0?3`l03/k>`80?clo0`0n?Sh0300k>c/0@D510410@010@400?3`l03Xj>P0l?3`0
?Shn03dm?@10@400?Cdm03`l?080>c/k00d0?clo0492@P16ATH0@T9203hn?P0m?Cd0?3`l03lo?`0n
?Sh0@4100451@@0n?Sh0?clo0080@41000<0?clo03/k>`0m?Cd00P0m?Cd01@10@400?clo04A4A01<
C4`0B4Q80080?Shn00L0@D510492@P11@D40@d=303hn?P0o?cl0@D5100<0?clo00L0@T920410@00n
?Sh0?Shn04A4A011@D40AdM700<0@41000P0?3`l0492@P18B4P0CDe=05EEE@1DE5@0EEEE04E5A@80
?clo01L0@d=30410@015ADD0CTi>05YJFP14A4@0E5AD07MgM`1nOWh0CTi>04m?C`17AdL0?Cdm03/k
>`0l?3`0@D5104i>CP18B4P0@T9203lo?`10@400A4A404E5A@020451@@0>0492@P0l?3`0@d=30410
@012@T80@41003lo?`10@400@d=30451@@19BDT0@D5103lo?`12@T8203lo?`0603hn?P0i>CT0?Shn
0451@@0o?cl0A4A40P0m?Cd02010@400?clo04A4A00o?cl0A4A404a<C01;Bd/0@4100P11@D402015
ADD0@D510492@P12@T80>c/k03Ti>@10@400?clo0P14A4@02@0n?Sh0@T9203`l?00n?Sh0?clo03hn
?P19BDT0Cdm?04U9B@0203/k>`0E03`l?00i>CT0@d=303hn?P12@T80B4Q804=3@`0l?3`0@41003lo
?`0n?Sh0>3Ph03/k>`0h>3P0>CTi03Ph>010@400AdM704=3@`0m?Cd0@4100080ADE501X0AdM70451
@@15ADD0?clo0410@00l?3`0>c/k03Ti>@0m?Cd0@D5104E5A@1ADE40F5QH06EUI@1fMWH0M7Ad06=S
H`19BDT0Bd];06IVIP1`L700IFEU05QHF01VIVH0LW9b065QH@80De=C01X0H61P07IfMP1`L700Fe]K
04=3@`1@D500De=C06EUI@1XJ6P0Fe]K04a<C018B4P0@d=303`l?014A4@0C4a<05=CD`1JFUX0GUiN
06UYJ@1EEED0B4Q804U9B@1;Bd/0CTi>04Y:BP80AdM701@0ATI604U9B@14A4@0@T9204];B`15ADD0
Cdm?05=CD`1KFe/0HF5Q06ATI01[Jf/0GemO05YJFP1DE5@0HV9R05mOG`1MGEd0FEUI05mOG`80E5AD
01/0@T9203lo?`0o?cl0ATI604e=C@1MGEd0HF5Q05UIF@1RHV80QHF508N7Q`1/K6`0OWin07MgM`1j
NWX0L71`06a/K01BDU80ADE50492@P0n?Sh0C4a<069RHP1BDU80@d=305=CD`1lO7`00P2BTY804`1[
Jf/0CDe=03dm?@0m?Cd0@T920410@011@D40EUIF05eMG@1ADE40Cdm?05=CD`1OGel0LW9b07IfMP1n
OWh0K6a/04i>CP16ATH00P0l?3`01010@400D51@04];B`0k>c/203Ti>@0?03Xj>P0n?Sh0ATI604m?
C`15ADD0?clo03`l?015ADD0A4A403hn?P0h>3P0>SXj03Ph>00g=cL0A4A40080ATI600P0BDU904e=
C@13@d<0>3Ph0410@015ADD0Cdm?04I6AP80?Cdm0140Bd];05QHF01OGel0I6AT05QHF01MGEd0FEUI
055AD@1<C4`0E5AD059BDP1KFe/0De=C05EEE@1LG5`0EEEE055AD@0204];B`80@41000<0?Shn03De
=@0m?Cd00P0o?cl01@0l?3`0<S8b03De=@0f=SH0=CDe0080?Shn0P0d=3@00`0i>CT0=SHf03Hf=P02
03Lg=`0303Hf=P0d=3Cooooo00cooooo000@ooooo`0=07YjNP1_Kfl0De=C05=CD`1OGel0Jf][065Q
H@1LG5`0S8b<0;6a/@2][Jd0RXZ:07MgM`0207=cL`07061PH01DE5@0GUiN07IfMP1ZJVX0IFEU05eM
G@0204Y:BP0R05]KF`1gMgL0SHf=09bLW02PX:00RXZ:08R8R01fMWH0EeMG0492@P0l?3`0@T9203hn
?P0l?3`0?Shn04=3@`10@400A4A40410@00n?Sh0@T9203hn?P10@400@D5103dm?@0n?Sh0@d=30451
@@14A4@0@D5103dm?@0l?3`0?Shn03/k>`80@41000L0@D510410@010@400@41003hn?P10@400@d=3
0080?clo00@0>c/k03`l?00m?Cd0>CTi0P0k>c/01P0n?Sh0>CTi03Hf=P0k>c/0>SXj0451@@80?3`l
0100?Shn03`l?00j>SX0?3`l03dm?@0l?3`0>CTi03/k>`0o?cl0?Cdm03lo?`11@D40ATI603Xj>P0o
?cl0?3`l0P0o?cl203dm?@0403Xj>P0l?3`0?clo0410@080?3`l00<0@41003lo?`0k>c/00P0j>SX0
3011@D40?Shn03dm?@0k>c/0@41003dm?@0k>c/0?Cdm03hn?P0l?3`0>SXj0410@080Bd];00P0AdM7
04=3@`11@D40>SXj03/k>`14A4@0ADE503dm?@80>CTi0`0l?3`02P0m?Cd0>c/k03hn?P0n?Sh0?clo
0451@@12@T80>SXj03/k>`10@40203dm?@2604a<C01GEeL0E5AD04Y:BP19BDT0?Cdm03`l?010@400
?clo03dm?@0l?3`0@d=304M7A`1?Cdl0CDe=04M7A`14A4@0?Shn03dm?@10@400CTi>05=CD`11@D40
AdM705EEE@1GEeL0Hf=S055AD@19BDT0Cdm?05ADE01PH600EeMG04M7A`0n?Sh0@D5104Y:BP1[Jf/0
MGEe04a<C012@T80?clo04I6AP14A4@0ADE50492@P0m?Cd0>SXj03lo?`0g=cL0@D5103Xj>P0m?Cd0
@D5103/k>`0l?3`0ADE504U9B@0o?cl0>c/k03Xj>P10@400BDU904A4A015ADD0A4A403Xj>P14A4@0
=CDe03dm?@10@400?Shn0451@@0m?Cd0>CTi0410@011@D40?Cdm0410@00m?Cd0?clo03/k>`0o?cl0
@41004U9B@1OGel0EeMG04I6AP0j>SX0?Shn0410@00i>CT0CDe=0492@P14A4@0ADE503dm?@0g=cL0
>c/k03`l?012@T80>CTi0492@P18B4P0?Cdm03lo?`1:BTX0?3`l0451@@0l?3`0@D5104E5A@18B4P0
@41004M7A`10@400?Cdm0492@P0i>CT0?3`l03hn?P0k>c/0ADE504I6AP1BDU80JVYZ06QXJ01MGEd0
G5aL04Y:BP13@d<0CDe=05QHF01FEUH204Q8B00H04a<C01ADE40FEUI055AD@1:BTX0CTi>04A4A00o
?cl0ATI6055AD@1<C4`0JFUY06ATI012@T80A4A40410@00l?3`0@d=304m?C`1_Kfl0Jf][05iNGP1L
G5`0JFUY0P1_Kfl03@1WIfL0I6AT05YJFP16ATH0@41003/k>`17AdL0ATI604e=C@1?Cdl0C4a<059B
DP1;Bd/00P1BDU803P1IFET0HV9R06ATI01LG5`0CTi>04E5A@0m?Cd0?clo03hn?P0k>c/0?Cdm04I6
AP19BDT0C4a<0P1ADE4205ADE00505aLG01OGel0FEUI06ATI01EEED00P1KFe/0701DE5@0G5aL069R
HP1QHF40MWIf07UiN@1XJ6P0FEUI04E5A@19BDT0De=C04I6AP0l?3`0CTi>07=cL`1nOWh0HV9R051@
D010@400>CTi03Ph>00m?Cd0@41004Q8B01ADE40I6AT051@D01<C4`205YJFP0<055AD@17AdL0ADE5
05aLG01JFUX0ATI60492@P0i>CT0>c/k03`l?00n?Sh0@4100`0i>CT07`14A4@0ATI603Xj>P0h>3P0
=CDe03Hf=P0d=3@0>c/k03Xj>P0h>3P0=CDe03Lg=`0f=SH0?Cdm04M7A`12@T80?3`l04a<C01>CTh0
>c/k03De=@0l?3`0=CDe03/k>`0e=CD0=cLg03/k>`16ATH0D51@055AD@1?Cdl00P0n?Sh03@10@400
?clo04A4A01DE5@0FEUI069RHP1>CTh0Cdm?05iNGP1?Cdl0AdM704Q8B013@d<00P0n?Sh01@0k>c/0
>3Ph03`l?00m?Cd0>3Ph0080=CDe00P0=SHf03<c<`0f=SH0=cLg03Hf=P0b<S80<c<c03Hf=P80=CDe
00@0=SHf03Ph>00g=cL0=3@d3Oooool0013ooooo0P1;Bd/00`13@d<0A4A404I6AP0204=3@`0=04E5
A@1CDe<0GUiN05iNGP1GEeL0De=C055AD@1<C4`0B4Q804i>CP1CDe<0H61P059BDP0204a<C00>0410
@012@T80BDU9069RHP20P800X:2P0;2`/02][Jd0]kNg0;2`/02NWYh0NWYj05EEE@1>CTh20451@@0>
0410@014A4@0ADE504=3@`1;Bd/0ATI60451@@10@400@D5104E5A@16ATH0AdM70451@@14A4@20451
@@0A04I6AP12@T80ADE504I6AP1ADE40BDU904E5A@1:BTX0Bd];051@D013@d<0?Cdm03`l?00n?Sh0
?3`l03hn?P13@d<00P0n?Sh0100l?3`0?Cdm03`l?00n?Sh203/k>`0903lo?`10@400@T9203`l?00j
>SX0?Cdm03`l?00m?Cd0?3`l0080>c/k00`0?clo0410@00m?Cd0?Shn0451@@12@T80B4Q804=3@`0k
>c/0?clo03/k>`11@D4203dm?@0803hn?P0j>SX0?Shn0410@00o?cl0>CTi03hn?P0j>SX203`l?080
?clo00T0@41003/k>`10@400?Cdm03Ph>00k>c/0@41003lo?`11@D400P1>CTh01`14A4@0?clo03dm
?@10@400?Shn03dm?@0o?cl00P0n?Sh06@0m?Cd0?3`l03Xj>P0j>SX0>c/k03dm?@0l?3`0?clo0410
@00m?Cd0?3`l03dm?@0k>c/0?clo0410@00o?cl0?3`l04M7A`1>CTh0@T9203/k>`0n?Sh0@T9204A4
A017AdL00P12@T802P10@400@T9204M7A`1;Bd/0@d=304E5A@14A4@0?clo03`l?00n?Sh204I6AP06
04=3@`0n?Sh0CDe=04I6AP1;Bd/0CDe=0P1SHf<03`1RHV80GemO04U9B@16ATH0@T9204A4A01?Cdl0
GEeM07=cL`1QHF40A4A403dm?@1@D500Bd];0492@P0203`l?080A4A401T0BTY:04I6AP0m?Cd0>SXj
03hn?P0l?3`0@d=303hn?P15ADD0CTi>04];B`10@400ATI604Y:BP1>CTh0EeMG04e=C@18B4P0AdM7
03Xj>P0n?Sh0@T9204A4A00m?Cd0?3`l0080?clo00L0@41003`l?00o?cl0>CTi03`l?00m?Cd0@T92
0080ATI600T0BTY:03lo?`12@T80>CTi03hn?P11@D40>c/k03dm?@0i>CT00P0j>SX01`0n?Sh0>3Ph
03/k>`0m?Cd0?3`l0410@018B4P00P14A4@0>`0n?Sh0@T9203/k>`0o?cl0?Shn03dm?@0k>c/0?Cdm
03hn?P10@400?Cdm03`l?00n?Sh0>CTi03`l?00o?cl0>3Ph03hn?P13@d<0CTi>05=CD`1ADE40Bd];
04a<C015ADD0@41003/k>`10@400?Shn03lo?`0n?Sh0AdM705iNGP1EEED0BTY:0410@00k>c/0?Cdm
04e=C@1GEeL0De=C059BDP1<C4`0?Shn03Ti>@0l?3`0?Shn04E5A@1;Bd/0C4a<05UIF@1>CTh0Cdm?
04Y:BP19BDT0EeMG065QH@1BDU80ATI60080?3`l0100ADE504I6AP1MGEd0Fe]K05MGE`1ADE40AdM7
04E5A@0o?cl0ADE505IFEP1DE5@0Bd];04A4A00n?Sh0>c/k0`0l?3`05@0k>c/0@4100492@P1<C4`0
B4Q805EEE@1NGUh0EEEE055AD@1FEUH0FEUI05YJFP1@D500Cdm?04i>CP14A4@0ADE50451@@17AdL0
BDU904Y:BP0205YJFP0O05IFEP1JFUX0GEeM06ATI01QHF40ATI603lo?`1<C4`0DE5A05EEE@19BDT0
?Cdm04=3@`17AdL0DE5A06ATI01WIfL0KVi^05aLG01:BTX0@D5104E5A@1<C4`0CTi>0410@00i>CT0
=cLg03/k>`0l?3`0>SXj03Ti>@0203hn?P0>03`l?00h>3P0ADE504e=C@1;Bd/0?clo0492@P10@400
?3`l03Ph>00d=3@0>CTi03Hf=P0h>3P203Lg=`0503Hf=P0j>SX0>c/k03hn?P10@4000P0k>c/01@14
A4@0@41003Ti>@0f=SH0=CDe0080=cLg00L0B4Q804a<C00j>SX0?3`l03dm?@0h>3P0=SHf0080=CDe
00@0=SHf03`l?016ATH0De=C0P1@D5003`1<C4`0Cdm?05EEE@1;Bd/0@D510492@P15ADD0A4A40410
@00m?Cd0?clo03Ph>00k>c/0?Cdm03Ti>@0403Hf=P0303De=@0f=SH0=CDe00<0=SHf00<0>3Ph03Hf
=P0f=SH00P0f=SH=ooooo`004?ooool02P1?Cdl0ATI604A4A014A4@0@D5104M7A`12@T80ATI603lo
?`11@D4204M7A`0:0451@@14A4@0@d=304A4A010@400?clo04=3@`14A4@0@T9204=3@`80@41001H0
@T9203lo?`10@400ADE504Q8B01@D500CDe=05ADE01/K6`0RXZ:08N7Q`1hN7P0GEeM0410@015ADD0
BDU907IfMP2;Rh/0Shn?06e]K@1YJFT0K6a/0P1RHV80301hN7P0QhN707]kN`1FEUH0BTY:05mOG`2L
W9`0ZJVY0:n_[`2PX:00/;2`09bLW080UIFE01/0RHV906a/K019BDT0A4A40451@@0n?Sh0?Cdm0410
@00n?Sh0@D5103`l?00m?Cd0>c/k0410@00n?Sh0?clo03Ti>@10@400@D5103hn?P0m?Cd0@D5103/k
>`0m?Cd0?clo0410@00j>SX00P0m?Cd0400h>3P0@41003hn?P0n?Sh0>SXj03hn?P10@400>CTi03Xj
>P0m?Cd0@41003`l?011@D40@T9203`l?00g=cL203dm?@0A03lo?`12@T80>SXj03hn?P0j>SX0?Shn
03Xj>P14A4@0?Shn03`l?00o?cl0?3`l0451@@13@d<0@D510492@P15ADD00P12@T803P0n?Sh0?3`l
03dm?@0m?Cd0>c/k03lo?`0l?3`0ATI603`l?00k>c/0>CTi03/k>`0o?cl0@4100P0o?cl00`0l?3`0
@41003/k>`0203`l?080?Shn00<0@d=303/k>`0n?Sh00P0o?cl02@0l?3`0@41003lo?`0m?Cd0AdM7
03lo?`0n?Sh0?clo04=3@`020492@P060451@@13@d<0B4Q804=3@`11@D40?clo0`0n?Sh05@0j>SX0
@D510410@017AdL0DU9B061PH01:BTX0?clo0451@@0m?Cd0?3`l0451@@19BDT0CTi>055AD@19BDT0
@d=30492@P0o?cl0?Cdm0410@00204];B`0R04A4A013@d<0GemO07MgM`1LG5`0ATI60492@P11@D40
?Shn0410@014A4@0GemO0820P01cLg<0Hf=S06QXJ01iNGT0SHf=0:6QX@2<S8`0P82007inOP1aLG40
E5AD04=3@`12@T80?clo03hn?P19BDT0@d=303`l?00m?Cd0?Shn03dm?@80>c/k00H0?Shn03/k>`0h
>3P0>SXj03Ph>00l?3`203/k>`0>04=3@`0l?3`0?Cdm03Ti>@0g=cL0>CTi03/k>`0j>SX0>3Ph0410
@00j>SX0?clo03Lg=`0m?Cd203Xj>P0803/k>`0m?Cd0?3`l03Xj>P0g=cL0>c/k03Hf=P0k>c/203`l
?00303/k>`0i>CT0>3Ph0080>c/k00T0>CTi03`l?019BDT0AdM704=3@`10@400>c/k03dm?@0k>c/0
0P0i>CT0100k>c/0?3`l03hn?P0n?Sh203/k>`0B03hn?P10@400ADE505IFEP1MGEd0?clo0410@00k
>c/0?Shn03dm?@0n?Sh0?clo04e=C@1?Cdl0B4Q80492@P0k>c/0?Shn0P10@4001018B4P0A4A403hn
?P0n?Sh203/k>`0>03hn?P0o?cl0CDe=04a<C01=CDd0BTY:04M7A`19BDT0ATI604A4A017AdL0@d=3
03dm?@0i>CT203Xj>P0O03lo?`0j>SX0?Cdm04=3@`1:BTX0A4A404=3@`1:BTX0EEEE04e=C@1IFET0
G5aL05iNGP1GEeL0EEEE055AD@15ADD0A4A403/k>`0l?3`0>c/k03lo?`0n?Sh0B4Q804];B`1<C4`0
CTi>0492@P11@D40ADE50451@@0303dm?@0=0492@P1=CDd0>SXj0451@@0n?Sh0>SXj03/k>`12@T80
@d=304A4A016ATH0DU9B04=3@`0203Ti>@0603`l?016ATH0@D5103Lg=`0i>CT0=SHf0P0i>CT01P0m
?Cd0@T9204U9B@19BDT0CDe=0451@@80A4A400L0>c/k03Lg=`0i>CT0?clo03`l?00g=cL0>3Ph0080
=SHf00P0>3Ph03Lg=`0i>CT0>c/k03Lg=`0k>c/0=cLg03Ph>080=cLg0P0i>CT01`0h>3P0=cLg03De
=@0i>CT0>c/k03Ph>00c<c<00P0e=CD03@0f=SH0>c/k03hn?P0n?Sh0>SXj03dm?@14A4@0AdM704U9
B@1<C4`0CTi>059BDP19BDT00P10@4001@0j>SX0?clo03Ti>@0k>c/0>CTi0080=SHf0P0g=cL03`0f
=SH0=cLg03Lg=`0b<S80@T9203`l?00d=3@0<c<c03Hf=P0d=3@0=SHf03Ti>@0h>3P0=CDe03Ph>002
03Hf=Pgooooo000@ooooo`0:04Y:BP17AdL0ATI604E5A@13@d<0@T920410@016ATH0@D5103lo?`<0
@T9200<0A4A40492@P13@d<00P11@D402012@T80A4A404=3@`13@d<0@41003lo?`10@400@D510P13
@d<01P0o?cl0@T920492@P11@D40?clo04I6AP80A4A400/0AdM704=3@`12@T80@D5104M7A`1=CDd0
D51@0492@P13@d<0B4Q80451@@020492@P0C04U9B@16ATH0@41004=3@`1?Cdl0H61P06YZJP1lO7`0
Ogmo07MgM`25QHD0Ti>C08j>SP20P800HV9R08^;R`2GUiL0SHf=06ATI002051@D00?04Q8B011@D40
?clo03dm?@10@400?Shn04M7A`13@d<0ADE503hn?P0l?3`0?clo03`l?00n?Sh0>SXj0080>c/k00T0
?clo03hn?P0m?Cd0@d=303lo?`0k>c/0?3`l0492@P0k>c/00P0n?Sh00`0l?3`0>c/k03/k>`0403dm
?@80@D5100D0@41003`l?012@T80?Cdm03Xj>P0203hn?P0H03/k>`0j>SX0?Shn03`l?00h>3P0@410
04Y:BP19BDT0@T9203`l?00j>SX0?3`l03lo?`12@T80?clo04I6AP0o?cl0A4A403lo?`0i>CT0?Cdm
03/k>`0m?Cd0?clo0`0k>c/02@0m?Cd0?Shn03dm?@0i>CT0?3`l0451@@0m?Cd0?clo03hn?P0203`l
?00<03/k>`0o?cl0?Shn03`l?00k>c/0?3`l03Ti>@0n?Sh0ADE50410@012@T80A4A40P0l?3`02P11
@D40Bd];04=3@`11@D40AdM703hn?P12@T80?Shn0492@P0m?Cd203hn?P0603Ti>@0o?cl0?3`l03dm
?@0h>3P0?3`l0P0m?Cd0;@0k>c/0?clo0410@012@T80@41004A4A012@T80@410051@D01?Cdl0Bd];
04I6AP14A4@0@D5104I6AP1<C4`0AdM7051@D017AdL0A4A403lo?`0k>c/0?clo04Q8B01?Cdl0C4a<
04I6AP17AdL0CDe=059BDP1[Jf/0PH6107QhN01eMGD0MWIf07AdM01JFUX0@d=304];B`1BDU80H61P
06UYJ@1ADE40ADE504Y:BP0205YJFP0G055AD@16ATH0@41003dm?@0j>SX0?3`l03dm?@13@d<0B4Q8
03/k>`10@400>CTi03`l?00n?Sh0>c/k03Ph>00m?Cd0>c/k04=3@`11@D40?3`l03Ti>@0h>3P00`0m
?Cd03`0k>c/0>CTi03hn?P0i>CT0>c/k03lo?`11@D40?Shn03Ph>00m?Cd0>CTi03/k>`0g=cL0ADE5
03/k>`0203`l?00803Lg=`0l?3`0>CTi03Ti>@0l?3`0@D5103`l?00h>3P203Ti>@0B03Ph>00j>SX0
>3Ph03Ph>00j>SX0?3`l04A4A01<C4`0B4Q80410@00j>SX0>CTi03Ph>00k>c/0?Cdm03hn?P10@400
AdM70P0l?3`01@0k>c/0?Cdm04=3@`10@400?clo0080?Shn0440?3`l03/k>`0k>c/0@41004U9B@12
@T80?Cdm04M7A`13@d<0@T920410@013@d<0ADE50410@00n?Sh0?3`l03Ph>00i>CT0>c/k03Xj>P0m
?Cd0?clo0410@013@d<0?Shn04A4A019BDT0Bd];05=CD`1=CDd0E5AD04I6AP18B4P0BDU904a<C018
B4P0?Shn04I6AP0n?Sh0@D5104I6AP13@d<0C4a<04M7A`19BDT0Bd];04M7A`16ATH0?Cdm04I6AP11
@D40>SXj03`l?00j>SX0@D5104E5A@0j>SX0A4A403Ph>00g=cL0>c/k03Xj>P0l?3`0>SXj03`l?002
03Ti>@0603Lg=`0j>SX0>CTi03`l?00g=cL0>CTi0`0g=cL02P0i>CT0>c/k03lo?`0o?cl0?3`l04E5
A@11@D40@41003Xj>P0g=cL203Ti>@0503Lg=`0h>3P0>SXj03Ph>00g=cL00P0f=SH0100i>CT0>c/k
03Ph>00g=cL203dm?@0>03Ti>@0h>3P0=cLg03Lg=`0e=CD0=SHf03/k>`0i>CT0>3Ph03@d=00e=CD0
=cLg03<c<`0i>CT203hn?P0E03/k>`0m?Cd0@D5103Xj>P10@400Bd];04=3@`0n?Sh0ADE504=3@`0k
>c/0?Shn03`l?00n?Sh0?clo03hn?P0m?Cd0>CTi03`l?00h>3P0=3@d00<0=cLg00D0=CDe03Hf=P0b
<S80=3@d03Hf=P0203@d=00303`l?00i>CT0>CTi00<0=CDe0P0g=cL=ooooo`004?ooool204I6AP80
ADE50P14A4@01010@400@D5104A4A012@T8204=3@`080451@@12@T80@4100492@P10@400@d=304U9
B@15ADD20410@0030451@@12@T80@d=300<0@D5100H0?Cdm0492@P12@T80@D5104=3@`11@D420410
@00803dm?@10@400@41003dm?@11@D40A4A404E5A@14A4@204=3@`0S03dm?@11@D40@T9204=3@`0n
?Sh0?clo03`l?00o?cl0?Shn03lo?`0n?Sh0?Cdm03hn?P11@D40@4100492@P14A4@0ADE505=CD`1=
CDd0F5QH05MGE`1OGel0Ti>C07alO01DE5@0D51@04=3@`0n?Sh0C4a<05]KF`16ATH0?Shn03/k>`10
@4000P0l?3`0;@0o?cl0?3`l04];B`1>CTh0?Shn03`l?013@d<0@D5104];B`1?Cdl0F5QH05aLG01G
EeL0FEUI06MWI`1<C4`0@D5104e=C@1SHf<0LW9b07alO01XJ6P0Hf=S07MgM`20P800KVi^04i>CP0o
?cl0?3`l0492@P15ADD0?Shn0451@@0n?Sh0?3`l04=3@`12@T80ADE50410@00m?Cd0?3`l0410@011
@D40?3`l0451@@020492@P0903lo?`0n?Sh0@41003dm?@0j>SX0?clo0451@@0o?cl0?3`l0080?Cdm
00T0>SXj03dm?@0l?3`0?clo03hn?P10@400@D5104A4A00o?cl00P0n?Sh00`0l?3`0?Cdm03hn?P02
0451@@80?Shn00/0?clo04A4A010@400@T9204I6AP14A4@0@T9203dm?@16ATH0@41003lo?`0203hn
?P0M0492@P0m?Cd0@T9204=3@`16ATH0>SXj04A4A00n?Sh0>c/k03dm?@0o?cl0@T9203lo?`0n?Sh0
?clo0451@@0n?Sh0@41003lo?`14A4@0@T920451@@1=CDd0ATI604a<C012@T80@D5104A4A01:BTX0
0P10@4000`13@d<0>c/k03lo?`020410@0050492@P16ATH0B4Q804I6AP13@d<00P1CDe<01018B4P0
Bd];04Q8B014A4@20451@@0;03dm?@18B4P0De=C04a<C017AdL0ATI604U9B@18B4P0ATI605EEE@1J
FUX00P18B4P03@15ADD0?3`l03Xj>P0n?Sh0ATI6051@D01NGUh0GemO04a<C016ATH0?Cdm03`l?00o
?cl00P10@4006@0k>c/0ATI604A4A00n?Sh0>CTi03/k>`0h>3P0>SXj03`l?00k>c/0>SXj03/k>`0l
?3`0=cLg03Ph>00l?3`0>c/k03`l?00k>c/0ATI605YJFP1KFe/0CTi>04=3@`11@D400P0o?cl01P0j
>SX0>c/k03/k>`0i>CT0?Cdm03/k>`80>3Ph0P0i>CT04@0k>c/0?clo0410@00m?Cd0>c/k03dm?@0l
?3`0>SXj03dm?@0h>3P0>CTi03`l?00m?Cd0?Shn0410@00k>c/0>CTi0080?clo00@0@D5103`l?00n
?Sh0@T920P0l?3`01015ADD0?clo03hn?P0j>SX203dm?@80>SXj00/0?Shn0410@00m?Cd0>SXj03/k
>`0i>CT0?3`l03Ti>@0g=cL0>CTi03/k>`0203Xj>P80?clo00P0?Cdm03`l?00l?3`0=cLg03hn?P12
@T80@d=304E5A@80>c/k0140>3Ph03Ti>@0n?Sh0@41004A4A013@d<0B4Q804A4A015ADD0AdM704E5
A@1:BTX0@41004A4A018B4P0@T9203lo?`0203hn?P0303Ph>00j>SX0?clo00<0?Shn00P0=cLg03Ph
>00f=SH0<c<c03Ph>00i>CT0=cLg03Xj>P80>c/k00<0=cLg03Hf=P0j>SX00`0g=cL01010@400@T92
0451@@0l?3`203hn?P0303`l?00k>c/0>SXj0080>c/k00D0?clo03`l?00k>c/0>SXj03Ti>@0203Hf
=P0Q03Ti>@0g=cL0=3@d03De=@0i>CT0?3`l03dm?@0j>SX0>CTi03lo?`12@T80?Cdm03hn?P0h>3P0
>c/k04E5A@11@D40>CTi03Hf=P0e=CD0>3Ph03Ti>@0k>c/0@T9204E5A@0o?cl0@T920451@@15ADD0
ATI603Ti>@0j>SX0?Cdm0080>3Ph00X0@D5104I6AP0o?cl0?Cdm03/k>`0n?Sh0>CTi03Lg=`0i>CT0
=CDe0P0g=cL203Ph>00503De=@0j>SX0=CDe03Hf=P0e=CD00`0g=cL0100k>c/0?3`l03Ti>@0i>CT2
03Ph>00303Ti>@0k>c/0@41000gooooo000@ooooo`0:04I6AP15ADD0@d=304E5A@12@T80ADE50410
@015ADD0@T9204=3@`80ATI600L0?clo0410@00o?cl0@T920410@00o?cl0@4100080@d=30P12@T80
0`13@d<0@T920451@@020451@@0I0410@011@D40@d=304A4A012@T80@41003hn?P0o?cl0@d=303hn
?P12@T80@41003dm?@11@D40>c/k03dm?@14A4@0@T9204=3@`12@T80@41004E5A@0n?Sh0@4100451
@@020410@00:04=3@`0m?Cd0>c/k03Ti>@0k>c/0@D5103`l?010@400@d=30492@P80@41000d0B4Q8
0451@@14A4@0DE5A04I6AP1;Bd/0ATI603dm?@14A4@0@d=30451@@0n?Sh0?clo00<0?Shn03/0?3`l
03lo?`1QHF40QhN706a/K01;Bd/0B4Q8059BDP1VIVH0Jf][069RHP1FEUH0M7Ad06i^KP1TI6@0DU9B
05MGE`1WIfL0UiNG0:ZZZP2g]kL0[:b/0:VYZ@2b/[80^[Zj0=?Cd`2c/k<0LG5a04i>CP10@400?3`l
05QHF01IFET0EeMG06EUI@1^KVh0Fe]K04e=C@1FEUH0IVIV05QHF01bLW80QhN706IVIP16ATH0A4A4
03lo?`0n?Sh0?clo0492@P10@400A4A403hn?P0o?cl0De=C05UIF@1FEUH0ATI60451@@020410@007
04I6AP0o?cl0?Shn0451@@12@T80>c/k03`l?00203Xj>P0903`l?00n?Sh0@D5104Y:BP15ADD0@410
03lo?`13@d<0@4100080?clo00T0@T920410@00o?cl0@D5103dm?@0i>CT0>c/k0492@P11@D400P0m
?Cd01P10@400@D510492@P0n?Sh0?clo0410@080?clo01L0?Cdm03hn?P0m?Cd0?3`l03dm?@0n?Sh0
?clo0492@P0m?Cd0>c/k0410@011@D40?Cdm0451@@0n?Sh0>c/k03lo?`0j>SX0>c/k0492@P15ADD0
?Cdm0451@@0203hn?P0<03/k>`0l?3`0>c/k04=3@`11@D40@d=303lo?`0n?Sh0?clo03hn?P11@D40
?clo0P10@40204E5A@0A03Xj>P0n?Sh0@T9204A4A01>CTh0B4Q804E5A@12@T80>c/k04A4A016ATH0
@41003dm?@17AdL0B4Q803`l?010@4000P0l?3`00`0m?Cd0?Shn03lo?`0204=3@`0:0410@00o?cl0
@41003Lg=`0i>CT0?Cdm04Y:BP0o?cl0@T9204I6AP80@D510100@d=303/k>`0k>c/0?Shn04A4A017
AdL0Cdm?05mOG`1mOGd0WIfM08n?S`1dM7@0HV9R05IFEP1HF5P0AdM70P10@400100m?Cd0>c/k03`l
?00h>3P203Ti>@0803dm?@17AdL0CDe=05MGE`1OGel0EUIF04=3@`0i>CT203Xj>P0A03`l?00k>c/0
=cLg03dm?@0l?3`0>3Ph03dm?@0j>SX0?Shn0451@@19BDT0A4A403/k>`0f=SH0>3Ph03Lg=`0i>CT0
0P0k>c/00`0j>SX0@T9203dm?@0203Xj>P0>03hn?P11@D40?3`l03`l?00f=SH0>c/k03Lg=`0j>SX0
>CTi03Hf=P0g=cL0>SXj03Ti>@0g=cL203/k>`0>03Xj>P0k>c/0=cLg03Ti>@0j>SX0>CTi03Xj>P0d
=3@0=cLg03Ti>@0j>SX0>CTi03`l?00m?Cd30492@P0D03dm?@12@T80?Cdm0410@012@T80>c/k03dm
?@10@400?Cdm03Ti>@0k>c/0=cLg03Ph>00i>CT0=cLg03Ti>@0k>c/0=cLg03Ti>@0j>SX203Lg=`0@
03Ti>@0j>SX0>CTi03Ph>00g=cL0>3Ph03Ti>@0h>3P0>c/k03Ph>00k>c/0?3`l03Ti>@0m?Cd0?3`l
03Xj>P80>c/k00X0>CTi03Xj>P0i>CT0>3Ph03/k>`0i>CT0>3Ph03Xj>P0i>CT0>SXj0P0f=SH02P0k
>c/0=cLg03De=@0e=CD0=SHf03Ti>@0h>3P0>SXj03Ti>@0g=cL203Ti>@0503hn?P0l?3`0AdM704Q8
B017AdL00`0i>CT04P11@D40?Shn03hn?P0n?Sh0?Cdm0451@@16ATH0@T9203Xj>P0i>CT0?3`l03Xj
>P0h>3P0>SXj03dm?@12@T80?Shn03/k>`80>SXj00D0=cLg03Xj>P0e=CD0=SHf03Lg=`0203Ti>@09
03Hf=P0d=3@0=cLg03Hf=P0g=cL0>SXj03Ph>00i>CT0>3Ph00<0>c/k00L0>3Ph03Ti>@0i>CT0?Shn
0492@P1BDU80Bd];00gooooo000@ooooo`0;04E5A@12@T80A4A404I6AP13@d<0A4A404Q8B017AdL0
@d=30410@014A4@00P12@T800`0o?cl0@d=30492@P020492@P0303lo?`13@d<0?clo0080@41000X0
AdM703hn?P11@D40@T920451@@12@T80AdM704=3@`12@T80@D510P0n?Sh0100o?cl0>c/k04E5A@1B
DU820410@00B03hn?P0o?cl0?Cdm04=3@`0n?Sh0@4100451@@12@T80@41003lo?`11@D40@41003dm
?@0o?cl0@D5103lo?`0k>c/0?Shn0P0o?cl04@0l?3`0?Cdm0492@P12@T80?clo04E5A@12@T80A4A4
03hn?P0m?Cd0?Shn03/k>`0n?Sh0@41003`l?00m?Cd0>SXj00<0?3`l0P0m?Cd0>`0o?cl0C4a<055A
D@1DE5@0CDe=04A4A00m?Cd0?Shn03lo?`12@T80ATI60410@014A4@0@D5104Y:BP0m?Cd0ADE504A4
A016ATH0B4Q804Y:BP1<C4`0Bd];04U9B@1MGEd0Jf][07EeM@1UIFD0IVIV04Y:BP13@d<0LW9b07Mg
M`1kNg/0SHf=0:>SX`2=SHd0N7Qh08:2PP2NWYh0U9BD0:JVYP2g]kL0^KVi08Z:RP1NGUh0HV9R071`
L021PH40JVYZ07YjNP20P800QXJ606QXJ029RHT0TI6A07alO01bLW80M7Ad0080L71`01<0LG5a07in
OP1jNWX0EEEE04U9B@1;Bd/0@T9203hn?P10@400ADE504A4A019BDT0FEUI04];B`12@T80?clo04=3
@`14A4@0@D510080?Cdm00d0@d=303dm?@12@T80?clo03`l?010@400?Shn04M7A`12@T80?clo0410
@00k>c/0@d=30080>SXj00L0?Cdm04A4A011@D40@T920410@00o?cl0@T920080?Cdm0P0n?Sh0100m
?Cd0@D510410@00o?cl203dm?@0@0492@P0o?cl0@D5103Ti>@0l?3`0BDU903dm?@0k>c/0?Shn0492
@P15ADD0@T9203lo?`10@400?Shn03/k>`80?3`l00L0@d=303`l?00o?cl0@41004=3@`12@T80@410
0080?Shn02D0@41004];B`1RHV80C4a<04=3@`0i>CT0@T9203/k>`14A4@0BTY:0451@@0n?Sh0>CTi
03dm?@0i>CT0>c/k03`l?00i>CT0?3`l03lo?`0m?Cd0?3`l03Ti>@0l?3`0>c/k03Ti>@0n?Sh0B4Q8
04m?C`1=CDd0BTY:0410@011@D40?clo03/k>`11@D40?clo0080@d=300D0?Cdm03Xj>P0m?Cd0BTY:
05ADE00206=SH`0P05QHF01UIFD0L71`06EUI@1/K6`0FUYJ05eMG@1IFET0BDU903Ph>00o?cl0>c/k
03dm?@17AdL0LW9b08n?S`2@T900Rh^;08N7Q`1kNg/0MGEe04Y:BP16ATH0E5AD04U9B@0n?Sh0>SXj
03lo?`13@d<0CDe=04m?C`1ZJVX2071`L00306MWI`1:BTX0?Shn0080?3`l00X0?clo04];B`13@d<0
?Cdm03Xj>P0m?Cd0>SXj03Ti>@0n?Sh0?Cdm0P0k>c/03`0l?3`0?Cdm03/k>`0j>SX0@D5103`l?00h
>3P0=cLg03/k>`0j>SX0>c/k03dm?@0k>c/0=cLg03@d=00203Ti>@80?3`l00<0>3Ph03Hf=P0h>3P0
0P0i>CT05`0e=CD0>c/k03dm?@0n?Sh0?clo03Ti>@0m?Cd0>c/k03`l?00n?Sh0>c/k03hn?P0d=3@0
>CTi03De=@0k>c/0?clo0492@P0l?3`0>CTi03Ph>00i>CT0=cLg00<0>3Ph00D0=CDe03Lg=`0i>CT0
>3Ph03De=@0203Ti>@80>3Ph00<0=cLg03Xj>P0g=cL00P0j>SX04@0i>CT0?3`l03`l?00h>3P0>SXj
03Ti>@0e=CD0>3Ph03De=@0g=cL0>3Ph03Xj>P0i>CT0>3Ph03/k>`0i>CT0>3Ph0080>CTi00@0=cLg
03De=@0g=cL0?3`l0P0i>CT01`0h>3P0>CTi03Ti>@0g=cL0>3Ph03Ti>@0f=SH00`0g=cL0400b<S80
=cLg03Hf=P0g=cL0>CTi03Hf=P0h>3P0>c/k03Xj>P12@T80A4A403Xj>P0o?cl0?Cdm03Xj>P11@D42
03lo?`0604Q8B014A4@0>c/k04E5A@0k>c/0>CTi0P0g=cL00`0j>SX0=cLg03/k>`0303Hf=P0A03@d
=00e=CD0>3Ph03Ti>@0j>SX0>3Ph03Hf=P0i>CT0>SXj03Lg=`0j>SX0?3`l04M7A`11@D40@T92055A
D@15ADD03Oooool0013ooooo01/0B4Q804M7A`18B4P0Bd];06m_K`1lO7`0Kfm_04m?C`18B4P0@T92
04Q8B00o?cl0@d=303hn?P13@d<0@T920451@@17AdL0ADE504A4A013@d<0A4A404U9B@1EEED0IfMW
06][J`1FEUH00P1=CDd06@12@T80?clo03hn?P0m?Cd0?3`l03lo?`10@400?clo03dm?@10@400>SXj
03lo?`13@d<0?clo0492@P1BDU80@d=30410@00o?cl0@D5103dm?@11@D40?Cdm03hn?P11@D400P0n
?Sh01P0m?Cd0@D5103`l?00o?cl0@D5103lo?`80@D510P10@400200n?Sh0>SXj04=3@`14A4@0?Cdm
03`l?00j>SX0?3`l0P11@D40200i>CT0>SXj03/k>`0k>c/0?Cdm03lo?`0m?Cd0C4a<0P10@40203hn
?P0504A4A00n?Sh0>c/k03`l?00o?cl00P0m?Cd0400o?cl0>SXj04I6AP0l?3`0@T9203lo?`0l?3`0
?Shn0492@P0l?3`0?Cdm0492@P0n?Sh0?clo0492@P0n?Sh203dm?@0503`l?014A4@0ADE504I6AP10
@4000P18B4P07P1;Bd/0ADE504=3@`1ADE40Cdm?05=CD`1PH600FUYJ04I6AP13@d<0EUIF05aLG01H
F5P0LG5a0820P01cLg<0HV9R06EUI@1cLg<0QXJ60:j^[P2k^k/0_;bl0;Ng]`2a/K40Y:BT0:NWY`2Y
ZJT0][Jf0:VYZ@80Ph>300h0Rh^;05iNGP1GEeL0GemO07=cL`1_Kfl0Jf][07QhN024Q8@0SHf=07in
OP1[Jf/0De=C04=3@`<0A4A400h0ADE504I6AP10@400@4100492@P10@400@T9204U9B@1<C4`0CDe=
05UIF@1BDU80BDU904=3@`80?Cdm00<0>c/k03lo?`0m?Cd00P0o?cl203`l?0030410@00o?cl0?3`l
0080>c/k00P0?Shn0451@@0o?cl0@T9203/k>`0l?3`0>3Ph03hn?P80@41000H0?Cdm03Xj>P0n?Sh0
?3`l03hn?P0o?cl203dm?@0K0451@@14A4@0>c/k03dm?@0n?Sh0?clo03hn?P12@T80BTY:06IVIP1Y
JFT0GEeM04=3@`0l?3`0?Shn03`l?012@T80?Shn0451@@0j>SX0?3`l03lo?`0m?Cd0?Shn03/k>`0l
?3`0>CTi0080>SXj0100>3Ph03hn?P0i>CT0>3Ph03hn?P17AdL0CTi>04];B`11@D40?3`l03/k>`0l
?3`0?Cdm03Ti>@0l?3`0>SXj0P0k>c/04@0j>SX0?clo0410@017AdL0@T92051@D018B4P0?clo04=3
@`1;Bd/0BTY:04A4A019BDT0?Shn0492@P14A4@0ATI60080ADE50P1;Bd/06@1BDU80FUYJ06a/K01k
Ng/0MWIf06EUI@1/K6`0Jf][05aLG01DE5@0BDU90410@012@T80>3Ph05EEE@1VIVH0IfMW06m_K`20
P800Ph>307UiN@1KFe/0CDe=055AD@19BDT00P12@T803@14A4@0?3`l03Ti>@0i>CT0?Cdm03hn?P0m
?Cd0>SXj03`l?00k>c/0?3`l03Lg=`0j>SX00P0k>c/0200j>SX0?3`l03/k>`0k>c/0>SXj03lo?`0k
>c/0?Cdm0P0k>c/04P0l?3`0?Cdm03Ph>00l?3`0?Shn03Xj>P0h>3P0>c/k03Ph>00l?3`0>SXj03hn
?P0m?Cd0>c/k03Xj>P0e=CD0>c/k03dm?@80>c/k00L0?Cdm03/k>`0f=SH0>SXj03Ti>@0m?Cd0@T92
0080?3`l00T0>CTi03Ph>00i>CT0=cLg03Hf=P0i>CT0=SHf03De=@0g=cL00P0h>3P0400f=SH0=3@d
03@d=00h>3P0>c/k03Ti>@0j>SX0=cLg03/k>`0j>SX0>3Ph03Xj>P0i>CT0>3Ph03Lg=`0h>3P203/k
>`0403Hf=P0i>CT0>3Ph03Xj>P80=SHf00P0>c/k03De=@0f=SH0>SXj03Ti>@0h>3P0>SXj03Hf=P80
>3Ph0P0k>c/01P0l?3`0@T9203/k>`0j>SX0=cLg03Xj>P80=cLg00L0=CDe03Xj>P0k>c/0>3Ph03Xj
>P0i>CT0>3Ph0080>c/k0100>3Ph03`l?00o?cl0>SXj03`l?00n?Sh0>c/k03hn?P14A4@0?clo04m?
C`0o?cl0?3`l04A4A010@400?Shn0P0k>c/00`0j>SX0>CTi03Xj>P0203Hf=P0703Ti>@0h>3P0?3`l
03dm?@0i>CT0>3Ph03`l?00203/k>`0304E5A@1?Cdl0HF5Q0080JVYZ00@0I6AT07QhN02=SHd0Ogmo
3Oooool0013ooooo01d0HV9R05eMG@1QHF40LG5a0;2`/02@T900GUiN04e=C@1GEeL0EUIF051@D01D
E5@0IFEU07YjNP2=SHd0OGem06m_K`29RHT0TY:B09ZJVP2PX:00U9BD09RHV02d];@0^k^k09nOW`1k
Ng/0IVIV05=CD`020492@P0:04E5A@12@T80A4A404=3@`0o?cl0?Cdm03hn?P0m?Cd0>CTi0492@P80
?Cdm0P12@T808@0n?Sh0?clo0451@@11@D40@T9203lo?`16ATH0BDU904=3@`14A4@0?clo0492@P11
@D40?Shn04I6AP14A4@0AdM7051@D01>CTh0C4a<04Q8B01:BTX0@d=303dm?@0o?cl0>SXj03`l?00k
>c/0?3`l03hn?P0o?cl0?Shn0410@00303dm?@0B03lo?`10@400BDU903Xj>P0o?cl0?Cdm03lo?`14
A4@0?Cdm03Ph>00n?Sh0?clo03Xj>P0n?Sh0@D5103`l?00n?Sh0>SXj0P0k>c/03@0m?Cd0?clo0451
@@0i>CT0?Shn04=3@`0m?Cd0?clo03hn?P14A4@0@D5103dm?@0n?Sh00P13@d<06@0n?Sh0?clo03`l
?00n?Sh0?Cdm03`l?00o?cl0@T9203hn?P10@400@T9204I6AP11@D40?Shn04A4A012@T80@41003`l
?012@T80@D5103`l?00n?Sh0>c/k0451@@17AdL00P1CDe<07`1BDU80F5QH04a<C01DE5@0MWIf08:2
PP1hN7P0MWIf08F5Q@1eMGD0IFEU05IFEP1TI6@0WinO0;^k^`2/[:`0a/K60<_;b`3Bd]80c/k>0<g=
c@30`<00XZ:R08N7Q`2HV9P0aLG50<[:bP2d];@0[jn_0::RXP2=SHd00P28R8P00`21PH40JFUY05iN
GP0206=SH`0a05aLG01EEED0CTi>05MGE`1IFET0GEeM05aLG019BDT0A4A403lo?`12@T80B4Q805AD
E01?Cdl0ATI60410@016ATH0Bd];04A4A016ATH0A4A403`l?00m?Cd0?3`l03dm?@11@D40?Shn03dm
?@0l?3`0@D5103lo?`0m?Cd0?Shn0410@00o?cl0@D510492@P0n?Sh0@41004a<C01;Bd/0B4Q805AD
E01JFUX0BDU903hn?P10@400?Cdm03Ph>00203/k>`<0>SXj100m?Cd01@16ATH0?3`l03Xj>P0l?3`0
?Shn0080@D5101@0>c/k03hn?P0o?cl0?clo03Ph>00i>CT0>SXj03dm?@0j>SX0=cLg03hn?P0k>c/0
>SXj03Ti>@0n?Sh0@D5103/k>`0n?Sh0?Cdm03`l?080>SXj00h0?3`l04=3@`13@d<0?clo03Ti>@0j
>SX0?3`l03/k>`0l?3`0@D5104Q8B01=CDd0BDU904Y:BP<0@T9200`0ATI604U9B@1=CDd0De=C04e=
C@11@D40@41004=3@`10@400@T9203hn?P0k>c/20410@00l0451@@0m?Cd0@d=30410@011@D40?Shn
03dm?@15ADD0@d=30410@00n?Sh0>CTi03hn?P0j>SX0?Shn04e=C@1EEED0?Cdm0451@@0o?cl0?Cdm
03Xj>P0e=CD0>c/k03hn?P0l?3`0>c/k0451@@18B4P0CDe=04I6AP15ADD0C4a<051@D01GEeL0EUIF
04I6AP0m?Cd0>3Ph03/k>`0i>CT0@41004a<C017AdL0?Shn03lo?`0m?Cd0@d=30410@00o?cl0?Shn
03dm?@10@400?3`l04=3@`0m?Cd0>SXj03lo?`0n?Sh0?3`l0P0o?cl02P0j>SX0?3`l03/k>`0f=SH0
>3Ph03Hf=P0e=CD0=SHf03Xj>P0i>CT303Lg=`0?03Ph>00g=cL0=CDe03Lg=`0h>3P0>CTi03Xj>P0i
>CT0>SXj03Ti>@0g=cL0>CTi03Xj>P0f=SH0>CTi00<0>3Ph00@0?3`l03Lg=`0f=SH0=cLg0P0h>3P0
6`0i>CT0=cLg03/k>`0k>c/0>SXj03dm?@0k>c/0>SXj03Hf=P0i>CT0>3Ph03lo?`0f=SH0?Cdm04I6
AP0n?Sh0?Cdm03Xj>P0k>c/0>SXj03Ti>@0n?Sh0@D510492@P0n?Sh0?Cdm03/k>`0203dm?@0303lo
?`15ADD0@d=30080BDU901H0B4Q804Y:BP1@D500AdM70451@@1;Bd/0DE5A05=CD`1HF5P0Hf=S061P
H01CDe<0EUIF055AD@16ATH0B4Q804=3@`12@T80ATI60410@00i>CT0?Cdm0`0k>c/0300i>CT0@D51
055AD@1jNWX0TI6A09fMW@2QXJ40WinO09^KV`2PX:00[:b/0:FUY@gooooo000@ooooo`1>0;6a/@2b
/[80][Jf0<?3``31`L40Vi^K08f=S@2OWil0UiNG08n?S`24Q8@0SXj>09RHV02MWId0YZJV0:n_[`2m
_Kd0eMGE0=cLg03EeMD0bLW909fMW@2CTi<0QXJ606i^KP1JFUX0De=C051@D01KFe/0E5AD05=CD`1H
F5P0CDe=04Q8B010@400?Cdm0451@@10@400ATI604M7A`1BDU80F5QH05aLG01^KVh0JVYZ05EEE@17
AdL0A4A404a<C01QHF40JFUY07MgM`23Ph<0M7Ad05eMG@1HF5P0DE5A05]KF`1lO7`0UYJF08N7Q`1j
NWX0Ogmo06][J`1MGEd0EEEE04Y:BP16ATH0ADE503hn?P0k>c/0?Cdm03/k>`0n?Sh0A4A40410@00n
?Sh0?Cdm0P10@4001`0m?Cd0@T9204=3@`0k>c/0?clo03dm?@12@T800`0n?Sh02@0k>c/0@41003dm
?@0l?3`0@D5103dm?@10@400?clo03`l?00203hn?P0>03dm?@13@d<0ADE503hn?P0j>SX0?clo03`l
?00k>c/0?3`l0492@P0o?cl0?3`l03dm?@10@40303hn?P80@4100240?Shn03dm?@0l?3`0@41003`l
?00i>CT0>c/k04=3@`11@D40>c/k03lo?`0l?3`0?clo03`l?010@400?Shn0492@P0n?Sh0@D5103dm
?@0o?cl0@d=304A4A01;Bd/0B4Q80410@011@D40?clo0410@012@T80A4A403`l?00o?cl00P0l?3`0
6@0n?Sh0AdM705QHF01TI6@0MGEe06][J`1hN7P0LG5a08B4Q02SXj<0]KFe0:NWY`2][Jd0/k>c0:ZZ
ZP2c/k<0[Jf]0;>c/`2a/K40^KVi0:b/[02NWYh0SXj>07alO02<S8`00P2WYjL0902XZ:P0ZZZZ0:j^
[P2WYjL0VIVI08B4Q01JFUX0AdM704U9B@1DE5@0O7al09BDU01RHV80@d=304Q8B01FEUH0Jf][07Yj
NP1[Jf/0EEEE04E5A@0m?Cd0?clo04I6AP1HF5P0GemO061PH01_Kfl0K6a/05iNGP1DE5@0De=C06e]
K@1QHF40I6AT065QH@80Hf=S00X0I6AT04Y:BP11@D40@d=304M7A`1:BTX0D51@04M7A`10@400?clo
0`0n?Sh02P0g=cL0>SXj03lo?`0n?Sh0>CTi03/k>`0m?Cd0?Shn0492@P13@d<204Y:BP0704I6AP0n
?Sh0?3`l03Ti>@0k>c/0=SHf03/k>`0203`l?00503Xj>P0k>c/0>3Ph03Ti>@0e=CD00P0m?Cd01011
@D40?Cdm03dm?@0k>c/203lo?`80?Shn0P0l?3`05`0i>CT0>c/k03`l?00m?Cd0@D5103dm?@14A4@0
@D5103Xj>P14A4@0@T9204Y:BP1=CDd0B4Q804=3@`19BDT0BTY:04I6AP10@400A4A403lo?`14A4@0
>c/k0080?Shn00P0?Cdm03/k>`0i>CT0?3`l03Xj>P0i>CT0?3`l03hn?P80?3`l00l0>SXj03/k>`0n
?Sh0@D5103/k>`0h>3P0?Cdm03`l?00m?Cd0@d=30451@@0o?cl0>c/k0492@P0n?Sh00P0j>SX01010
@400@T9204a<C01EEED305YJFP0G05aLG01ZJVX0Kfm_075aL@1<C4`0A4A403Xj>P0k>c/0DE5A06MW
I`1eMGD0Kfm_06=SH`1DE5@0H61P06IVIP1JFUX0A4A403dm?@0n?Sh0@d=304A4A00m?Cd00P12@T80
300n?Sh0?clo03lo?`17AdL0BTY:03dm?@0k>c/0@T9203hn?P0h>3P0>SXj03Ph>0<0>CTi00D0>3Ph
03Xj>P0h>3P0>3Ph03Ti>@0203Lg=`0503/k>`0l?3`0>SXj03/k>`0j>SX00P0n?Sh01P0m?Cd0>CTi
03Ti>@0k>c/0>CTi03Lg=`80>SXj00H0>c/k03Ph>00l?3`0>c/k03Ti>@0h>3P203Ti>@80>SXj00<0
>CTi03Xj>P0h>3P00P0j>SX03`0i>CT0?3`l03`l?00k>c/0@T9204A4A00m?Cd0ATI605MGE`1OGel0
GEeM06m_K`1gMgL0J6QX06a/K00206m_K`80KFe]0180K6a/0861P@21PH40OWin08F5Q@29RHT0QXJ6
08f=S@2?Shl0Q8B408R8R02=SHd0TI6A09RHV02FUYH0U9BD096AT@25QHD207moO`0G07inOP24Q8@0
Ng]k08:2PP25QHD0MGEe06QXJ01UIFD0F5QH04i>CP10@400?Cdm05QHF01oOgl0Shn?09ZJVP2OWil0
WYjN09JFUP2LW9`0VIVI09bLW02BTY803Oooool0013ooooo01h0LW9b096AT@25QHD0P82007YjNP1c
Lg<0K6a/07IfMP1dM7@0N7Qh08B4Q02?Shl0QHF506m_K`1eMGD0XZ:R0:^[Z`2a/K40a<C40;>c/`2@
T900M7Ad07moO`1SHf<0D51@04A4A01<C4`0KFe]08:2PP1oOgl206][J`0U055AD@14A4@0@D5104A4
A01<C4`0H61P09FEU@2m_Kd0^[Zj0;:b/P2TY:@0[Zj^0;Jf]P2?Shl0HV9R05iNGP2<S8`0/K6a0:RX
Z02HV9P0TY:B08f=S@2@T900YJFU0:JVYP2i^KT0e]KF0<71`@28R8P0GemO05=CD`1LG5`0FUYJ04i>
CP19BDT0@d=30410@00203lo?`0603`l?00m?Cd0@D5104A4A011@D40?Cdm0P1BDU802017AdL0D51@
051@D01DE5@0BTY:04E5A@0l?3`0?Shn0P0m?Cd05P0n?Sh0?3`l0451@@0l?3`0@D5103`l?00n?Sh0
?clo03/k>`0o?cl0EEEE05eMG@1]KFd0I6AT04Y:BP19BDT0Cdm?04Y:BP17AdL0A4A403hn?P10@402
03lo?`0;03hn?P10@400BTY:03dm?@14A4@0@T9203lo?`11@D40?Shn0410@00m?Cd00P0o?cl05@0k
>c/0?Cdm03hn?P0j>SX0?3`l0410@00n?Sh0@41003hn?P12@T80?clo03hn?P1>CTh0GEeM06QXJ01W
IfL0GemO04a<C012@T80?3`l03hn?P0203lo?`0903`l?014A4@0?3`l03/k>`0o?cl0?Cdm03hn?P11
@D40?clo00<0@41000H0BDU90492@P14A4@0ATI604U9B@1:BTX204];B`0504U9B@18B4P0BTY:05QH
F01FEUH00P1EEED0A@1LG5`0Lg=c0861P@2;Rh/0N7Qh06UYJ@1aLG40PH6107]kN`1lO7`0R8R809jN
WP2;Rh/0N7Qh08B4Q01/K6`0Lg=c07QhN01lO7`0PH6108N7Q`2SXj<0ZZZZ08^;R`1MGEd0EUIF04Q8
B01NGUh0KVi^08B4Q02?Shl0XZ:R0:FUY@2][Jd0YZJV092@T01cLg<0HF5Q06MWI`1cLg<0P820071`
L01^KVh0JFUY05YJFP1DE5@0FEUI05MGE`1NGUh0KVi^06ATI01HF5P0EEEE05IFEP1EEED0EUIF05AD
E01LG5`0H61P06ATI01>CTh0ADE504i>CP1GEeL0GemO05UIF@15ADD0AdM703dm?@0203lo?`0603dm
?@0o?cl0>c/k03lo?`10@400?Cdm0P0j>SX06`0o?cl0?Cdm03dm?@0n?Sh0?3`l03hn?P10@400>SXj
03`l?00n?Sh0De=C05ADE013@d<0?clo03/k>`0m?Cd0ADE504e=C@1>CTh0?Shn03lo?`10@400?3`l
03Xj>P0l?3`0CTi>055AD@0204m?C`0;04M7A`14A4@0BDU903/k>`13@d<0@T9203dm?@0n?Sh0>c/k
03Ti>@0m?Cd00P0j>SX00`0k>c/0=cLg03Hf=P0303Ti>@0403dm?@0k>c/0?3`l03/k>`80>SXj0100
>c/k03Ti>@0l?3`0?Cdm03Ti>@0j>SX0?Shn03Xj>P0k>c/0>3Ph03Ti>@0l?3`0>SXj03Ti>@0m?Cd0
>CTi0P0j>SX0200m?Cd0>c/k03dm?@0n?Sh0ATI605=CD`1KFe/0CDe=0P15ADD0=@1;Bd/0EeMG05mO
G`1[Jf/0I6AT05]KF`1HF5P0GEeM05mOG`1CDe<0CTi>04a<C01DE5@0FUYJ05ADE01CDe<0BTY:04A4
A011@D40>c/k03`l?011@D40@41003Ti>@0j>SX0?3`l03Xj>P0g=cL0>CTi03Ph>00j>SX0?Cdm03Xj
>P0h>3P0=CDe03Ti>@0j>SX0@41003Ti>@0l?3`0>CTi03/k>`0m?Cd0@D5103hn?P0h>3P0?3`l03dm
?@0l?3`0>CTi03dm?@0j>SX0?3`l0080A4A40P0m?Cd02`0l?3`0>3Ph03Ti>@0k>c/0>SXj03Ti>@0n
?Sh0?Cdm03hn?P0j>SX0>CTi0080>c/k00l0BDU904i>CP1NGUh0Kfm_07YjNP1lO7`0NGUi08F5Q@2C
Ti<0UIFE09ZJVP2LW9`0V9RH08R8R02BTY800P2IVIT0202EUID0VIVI09nOW`2SXj<0WinO0:FUY@2O
Wil0Y:BT0P2JVYX0102TY:@0XZ:R09nOW`2PX:0209nOW`0;09jNWP2LW9`0U9BD08Z:RP1oOgl0QhN7
08Z:RP29RHT0R8R809NGU`2OWil00P2JVYX03@2FUYH0Shn?08b<S01bLW80MgMg09>CT`2`/;00[Zj^
0:NWY`2/[:`0Y:BT0::RXP2QXJ400P2[Zj/00`2a/K7oooooooooo`0;ooooo`004?ooool03P19BDT0
B4Q804M7A`1:BTX0ATI604E5A@14A4@0@D5104A4A012@T80AdM704Y:BP19BDT0ATI60P1:BTX204a<
C00505QHF01IFET0CTi>04U9B@1=CDd00P14A4@0E@19BDT0CTi>05=CD`1=CDd0BTY:04E5A@18B4P0
AdM704=3@`14A4@0BDU9051@D01>CTh0Kfm_096AT@2?Shl0R8R807YjNP24Q8@0YJFU0:b/[02QXJ40
WYjN0;Fe]@3=cLd0_[jn0:NWY`2`/;00^k^k0;Vi^@3@d=00b<S80;bl_030`<00]KFe0;Jf]P2YZJT0
[Zj^0;^k^`33`l<0[jn_08b<S01dM7@0IfMW07AdM01WIfL0EeMG05UIF@1DE5@0F5QH079bLP2DU9@0
UIFE079bLP1SHf<0L71`05iNGP1;Bd/0C4a<04A4A011@D40ATI604Q8B01ADE40Fe]K06QXJ01PH600
DE5A04i>CP1<C4`0BDU904Q8B01FEUH0KVi^09FEU@2BTY80TI6A08>3P`1WIfL0FEUI05QHF01BDU80
AdM703hn?P0l?3`00P0j>SX203lo?`0703dm?@11@D40AdM704A4A011@D40?3`l03hn?P0203dm?@0F
04M7A`1<C4`0@D5103dm?@12@T80?Shn0451@@0o?cl0?Shn0451@@14A4@0DU9B061PH01?Cdl0DE5A
06MWI`1KFe/0D51@04A4A011@D40?Cdm0410@080?Shn00`0@D5103hn?P0l?3`0?3`l03hn?P0m?Cd0
?clo03hn?P13@d<0@41003dm?@0i>CT20410@00L0451@@0o?cl0@d=30410@00o?cl0@T9204=3@`12
@T80ATI603hn?P18B4P0CTi>04a<C01NGUh0H61P06i^KP1ZJVX0GemO04e=C@14A4@0BTY:04i>CP1<
C4`0ATI60451@@1:BTX0E5AD055AD@80C4a<01T0@41004a<C01DE5@0Fe]K05iNGP1LG5`0H61P05iN
GP1EEED0D51@06IVIP1aLG40OGem0820P01mOGd0R8R809JFUP2TY:@0X:2P09VIV@2;Rh/0MGEe06=S
H`1aLG40Ogmo0080Shn?02<0UYJF09BDU02:RXX0Q8B40861P@1fMWH0N7Qh08V9R@2:RXX0PX:207mo
O`22PX80RXZ:08N7Q`2;Rh/0PH6107emO@1^KVh0JVYZ06=SH`1GEeL0Cdm?04E5A@1:BTX0A4A404U9
B@1=CDd0EUIF065QH@1PH600G5aL04m?C`13@d<0A4A40451@@0203hn?P0704=3@`11@D40?Shn03`l
?00j>SX0@D5104I6AP0205QHF00J05EEE@1DE5@0CDe=04=3@`1<C4`0G5aL06=SH`1IFET0FUYJ059B
DP14A4@0Cdm?05=CD`1FEUH0CDe=04I6AP1=CDd0BDU904A4A01ADE40CTi>04A4A015ADD0@41003hn
?P0o?cl203dm?@080492@P0k>c/0>c/k03Ph>00i>CT0>c/k03Ti>@0g=cL303Ti>@0503/k>`0l?3`0
@T9203dm?@0l?3`00P0m?Cd0100k>c/0?3`l03dm?@0m?Cd203`l?080>CTi00D0>c/k03Ph>00m?Cd0
>SXj03`l?00203hn?P0?03`l?00i>CT0?Cdm03dm?@0h>3P0>CTi03hn?P0k>c/0?Cdm03hn?P0j>SX0
?Shn03`l?00k>c/0?Cdm0080AdM700d0BDU904I6AP15ADD0B4Q80451@@14A4@0?Cdm04E5A@14A4@0
?Cdm03/k>`0l?3`0?Cdm0080>CTi00D0>3Ph03Ti>@0n?Sh0>c/k03Ti>@0203Ph>00603Lg=`13@d<0
?Cdm03`l?00m?Cd0?Shn0P0l?3`02`12@T80?Cdm04M7A`11@D40?clo0451@@13@d<0?Shn04=3@`12
@T80@41000<0@d=301P0@41004M7A`1:BTX0EUIF05iNGP1LG5`0H61P05aLG01KFe/0EeMG05IFEP1K
Fe/0FEUI051@D01;Bd/0C4a<04e=C@11@D40?Cdm03Xj>P1;Bd/0OWin08Z:RP2ATI4209jNWP0F09^K
V`2DU9@0V9RH09JFUP2MWId0WYjN09VIV@2DU9@0SHf=09>CT`2NWYh0VIVI09NGU`2NWYh0X:2P09BD
U02:RXX0T92@09bLW02WYjL0XZ:R0:>SX`80YjNW0240Z:RX0:j^[P2_[jl0[Jf]0:VYZ@2ZZZX0];Bd
0;Ng]`2j^[X0^;Rh0;Bd]02a/K40^k^k0<71`@38b<P0aLG50<?3``3:b/X0clo?0=3@d02`/;00a/K6
0=;BdP3=cLd0b/[:0<S8b03:b/X0cLg=0<K6aP3?cll0d];B0<o?c`3<c<`03Oooool0013ooooo01/0
BTY:04Q8B014A4@0AdM704A4A013@d<0A4A40451@@13@d<0@T9204=3@`15ADD0@41004U9B@14A4@0
ATI60492@P0n?Sh0@41004=3@`11@D40?Shn03dm?@12@T80AdM7051@D016ATH00P12@T820451@@0:
03dm?@10@400@D510451@@14A4@0BDU904I6AP13@d<0ATI60492@P80ATI600<0BTY:04Q8B01:BTX0
0P1^KVh03P1/K6`0P82008B4Q021PH40N7Qh06i^KP1aLG40NWYj07QhN01WIfL0L71`0820P02EUID0
VYZJ0P2DU9@08P2?Shl0S8b<06UYJ@1MGEd0D51@05aLG01lO7`0QHF507moO`2DU9@0[Jf]0;:b/P3<
c<`0dm?C0<[:bP36a/H0^KVi0;6a/@2DU9@0Ng]k075aL@20P800VYZJ0;Vi^@2m_Kd0^KVi0<?3``34
a<@0^KVi0;6a/@28R8P0IFEU05=CD`1IFET305=CD`0605mOG`1FEUH0?Shn04=3@`0o?cl0@D510P0n
?Sh00`0i>CT0?Cdm03dm?@0203lo?`0P04];B`1ADE40ADE504A4A01GEeL0JVYZ07YjNP1QHF40BDU9
05QHF01DE5@0BTY:0492@P17AdL0EEEE05QHF01RHV80IFEU06MWI`1[Jf/0HF5Q051@D018B4P0?clo
04A4A010@400@D5103`l?011@D40@41003lo?`0k>c/203dm?@0R04=3@`1CDe<0IVIV06=SH`1HF5P0
ADE50451@@16ATH0A4A40451@@1;Bd/0F5QH05EEE@16ATH0?Shn04I6AP11@D40ADE504];B`15ADD0
BTY:059BDP1GEeL0L71`07inOP1`L700IFEU05ADE01:BTX0@T9204=3@`12@T80@d=304E5A@80?clo
02l0>c/k04M7A`0o?cl0A4A404I6AP0o?cl0@D510410@014A4@0?clo0410@00o?cl0@d=30492@P13
@d<0CDe=04];B`1OGel0LG5a06m_K`1YJFT0I6AT06EUI@1GEeL0FUYJ05MGE`1IFET0FUYJ06ATI01N
GUh0HV9R05IFEP1PH600FEUI06EUI@1[Jf/0JVYZ06QXJ01ZJVX0K6a/06UYJ@1VIVH0HV9R05aLG01R
HV80KVi^08:2PP0207UiN@0G06IVIP1KFe/0DE5A055AD@1>CTh0FEUI05aLG01?Cdl0BTY:059BDP1L
G5`0FEUI05]KF`1OGel0Fe]K06e]K@1`L700NGUi06i^KP1EEED0ADE504=3@`17AdL00P16ATH0401A
DE40JFUY071`L01bLW80MgMg06i^KP1RHV80DE5A05MGE`1LG5`0GUiN06=SH`1WIfL0HV9R05QHF01L
G5`2065QH@0=061PH01>CTh0ATI603hn?P17AdL0BDU904e=C@1DE5@0BDU90451@@0o?cl0@D5103dm
?@020451@@0503/k>`0n?Sh0>c/k03`l?00k>c/00P0i>CT01@0j>SX0?Cdm03`l?00i>CT0?3`l00<0
?Cdm0P0l?3`00`1?Cdl0>c/k03hn?P0203dm?@0<03hn?P0o?cl0>SXj04=3@`0o?cl0>CTi03dm?@0o
?cl0@D510410@00m?Cd0?Shn0`0m?Cd0100n?Sh0?clo03lo?`0l?3`203lo?`0E03hn?P0i>CT0?3`l
03Xj>P0m?Cd0>c/k0492@P13@d<0BDU90410@014A4@0ADE504U9B@17AdL0@T9204M7A`12@T80@D51
0492@P18B4P0@d=30080?3`l00X0>c/k03dm?@0i>CT0@D5104=3@`1:BTX0CDe=04U9B@1;Bd/0Cdm?
0P1BDU809`1HF5P0Fe]K05]KF`1LG5`0IFEU06i^KP1LG5`0HV9R06YZJP1[Jf/0I6AT065QH@1LG5`0
Hf=S065QH@1VIVH0Jf][06IVIP1`L700MgMg07moO`28R8P0QXJ608B4Q01lO7`0QXJ608R8R02<S8`0
TY:B09BDU027QhL0O7al08Z:RP24Q8@0I6AT0410@00m?Cd0Hf=S08j>SP0209NGU`07096AT@24Q8@0
QHF508F5Q@2:RXX0Rh^;08j>SP0209BDU00409FEU@2@T900UiNG09^KV`80WinO00L0W9bL09nOW`2T
Y:@0Shn?0:6QX@31`L40b<S80080dM7A00H0emOG0=[JfP3AdM40fMWI0=[JfP3Ng]h20=[JfP040=cL
g03Fe]H0dM7A0<_;b`80clo?01D0cLg=0=3@d036a/H0[jn_0;6a/@32`/80a/K60;:b/P2EUID0X:2P
0<G5a@3<c<`0d];B0<o?c`3AdM40d];B0=3@d03>c/h0c<c<0<k>cP3?cll03Oooool0013ooooo00D0
B4Q804E5A@13@d<0@d=30451@@020492@P0803lo?`11@D40@D5103lo?`17AdL0ADE504I6AP14A4@2
0492@P0@04A4A013@d<0@41004A4A011@D40ATI604M7A`14A4@0ADE503hn?P10@400@D5104A4A011
@D40@d=30451@@<0?clo00<0A4A404M7A`12@T800P13@d<0101:BTX0ADE50492@P14A4@204=3@`0B
03lo?`17AdL0B4Q804A4A011@D40ADE50451@@15ADD0AdM704Y:BP16ATH0AdM704I6AP1:BTX0ATI6
04a<C018B4P0@4100P11@D4203dm?@0L03`l?012@T80B4Q8059BDP1QHF40KFe]06i^KP1nOWh0Ti>C
09ZJVP2PX:00U9BD09VIV@24Q8@0Ogmo09^KV`2`/;00];Bd0;Ng]`2IVIT0RHV908B4Q02FUYH0TI6A
07QhN01CDe<0BDU905IFEP80BTY:00D0DU9B04Y:BP13@d<0?Cdm0410@00203hn?P0S04A4A010@400
BTY:06UYJ@20P800QhN708Z:RP2ATI40VYZJ09:BTP1aLG40FUYJ06IVIP1RHV80G5aL059BDP18B4P0
?clo0451@@10@400DU9B079bLP2<S8`0P82006ATI01GEeL0BDU904a<C012@T80De=C04e=C@1BDU80
D51@03hn?P13@d<00P10@4005`0o?cl0?Shn0410@019BDT0Cdm?06ATI01]KFd0LG5a06QXJ01ZJVX0
M7Ad07moO`1cLg<0FEUI04M7A`1:BTX0CTi>059BDP1IFET0IVIV071`L01PH600I6AT0080K6a/00/0
Jf][079bLP1`L700IVIV065QH@1?Cdl0@d=30451@@0n?Sh0@41003hn?P0203lo?`0804A4A00o?cl0
@T9204a<C01CDe<0DE5A05QHF01SHf<205ADE00S051@D01BDU80Cdm?05MGE`1IFET0I6AT06e]K@1S
Hf<0F5QH05eMG@1YJFT0E5AD04];B`15ADD0CTi>051@D01<C4`0E5AD05MGE`1HF5P0DE5A05UIF@1B
DU80EEEE059BDP1GEeL0DU9B05YJFP1=CDd0BTY:051@D018B4P0?clo04A4A00n?Sh00`0k>c/04`11
@D40BDU904=3@`1@D500Cdm?05EEE@1OGel0IFEU06ATI01ZJVX0B4Q803/k>`0l?3`0BTY:06EUI@1h
N7P0L71`06EUI@1KFe/00P1BDU80<01NGUh0L71`06UYJ@1MGEd0GUiN06MWI`1[Jf/0KVi^06e]K@1V
IVH0GemO061PH01MGEd0KFe]06UYJ@1UIFD0Fe]K04i>CP1EEED0EeMG069RHP1PH600FUYJ069RHP1Y
JFT0HV9R05iNGP1FEUH0Fe]K051@D01<C4`0D51@04i>CP1?Cdl0A4A40492@P10@400>c/k04=3@`11
@D40?Cdm03lo?`0k>c/0?Shn03`l?00o?cl0>SXj03/k>`80?Cdm00D0>c/k03dm?@12@T80@D5103lo
?`0203dm?@080410@014A4@0>c/k03lo?`0n?Sh0?3`l03/k>`11@D4204M7A`0404Q8B014A4@0Cdm?
0451@@80@d=301@0@T9204=3@`10@400@41003hn?P0o?cl0@d=30451@@0o?cl0@d=303hn?P0m?Cd0
>c/k04A4A00m?Cd0?clo03`l?013@d<0A4A404Q8B080C4a<00P0D51@04U9B@1BDU80De=C055AD@1E
EED0Bd];04I6AP80Cdm?04d0BDU903hn?P0m?Cd0@T9205EEE@1hN7P0R8R808b<S024Q8@0RHV908j>
SP2?Shl0S8b<09FEU@2GUiL0U9BD09JFUP2EUID0Ti>C08^;R`2:RXX0Q8B40820P023Ph<0QXJ608:2
PP21PH40QXJ607moO`1mOGd0PH610820P024Q8@0PX:208F5Q@1hN7P0NGUi06a/K01UIFD0JVYZ06UY
J@1fMWH0RHV909FEU@2@T900UIFE0::RXP2NWYh0RHV907alO024Q8@0W9bL09nOW`2RXZ80WIfM09NG
U`2NWYh0[Jf]0:^[Z`2XZ:P0Zj^[0;Ng]`2l_;`0^k^k0;jn_P2i^KT0^k^k0<30`02m_Kd0^k^k0;Zj
^P2l_;`0bl_;0::RXP2UYJD0c<c<0=;BdP020=SHf00<0=OGe`3Jf]X0eMGE0=gMg@3Fe]H0fMWI0=SH
f03IfMT0dM7A0<k>cP3:b/X0b<S80P3<c<`02`3:b/X0c<c<0;2`/02DU9@0/K6a0<G5a@3>c/h0_Kfm
0;2`/038b<P0fMWI0080dm?C00P0clo?0=?Cd`3Cdm<0bl_;0<O7a`3:b/X0cLg=0=7Ad@gooooo000@
ooooo`0<04I6AP14A4@0@T9204E5A@0o?cl0@41004A4A013@d<0ADE504=3@`11@D40A4A40P12@T83
0451@@0604=3@`14A4@0@T9204E5A@16ATH0@d=30P15ADD00`1>CTh0@T9204A4A00204A4A00;0492
@P17AdL0AdM70492@P0m?Cd0@d=30451@@0o?cl0@d=303`l?00o?cl00P10@4001@11@D40ADE50492
@P10@400?3`l0080A4A400d0B4Q804I6AP1=CDd0D51@04a<C016ATH0CDe=04A4A013@d<0ADE50451
@@0l?3`0?clo0080?Shn00P0?Cdm03lo?`0o?cl0ADE504Q8B016ATH0CTi>04Y:BP80De=C02/0H61P
04i>CP1>CTh0AdM70492@P17AdL0A4A40451@@1?Cdl0HF5Q06=SH`1QHF40G5aL04Y:BP0n?Sh0BDU9
061PH01RHV80D51@04Q8B01GEeL0MWIf06m_K`27QhL0Lg=c04a<C01EEED0G5aL05ADE01>CTh0IfMW
07]kN`1bLW80OGem0:f][@2n_[h0aLG50<K6aP2f][H0W9bL07MgM`1;Bd/0@41000<0?Cdm0340>SXj
0451@@13@d<0A4A404I6AP1=CDd0E5AD055AD@1DE5@0DE5A05=CD`1WIfL0JVYZ04i>CP1;Bd/0ATI6
04U9B@14A4@0ADE503hn?P12@T80ATI604=3@`1CDe<0H61P06QXJ01MGEd0HF5Q06YZJP1SHf<0GEeM
065QH@1JFUX0Fe]K04e=C@13@d<0@41004E5A@1LG5`0I6AT06MWI`1MGEd0DE5A04a<C01BDU80DE5A
04Q8B015ADD0@T920080ADE502d0?Shn0492@P11@D40ATI60492@P1>CTh0@41003hn?P18B4P0De=C
04e=C@1>CTh0De=C04a<C017AdL0Bd];05aLG01CDe<0Cdm?05EEE@1>CTh0C4a<05iNGP1RHV80K6a/
06YZJP1SHf<0C4a<04M7A`1>CTh0@d=304M7A`1;Bd/0EEEE05UIF@1;Bd/0BTY:04Q8B013@d<0C4a<
051@D01EEED0Cdm?05=CD`1BDU800P1ADE403016ATH0B4Q80410@017AdL0?clo0451@@0k>c/0?3`l
03dm?@11@D40>c/k03hn?P80?3`l00D0>c/k03dm?@11@D40@T9203`l?00203dm?@0?03`l?00k>c/0
>c/k03dm?@11@D40@41004=3@`19BDT0ADE504a<C01GEeL0HF5Q069RHP1;Bd/0CTi>0080F5QH00/0
C4a<0451@@11@D40@41003lo?`18B4P0FUYJ06ATI01QHF40EeMG05aLG00205EEE@0D055AD@1:BTX0
Cdm?05ADE01WIfL0GEeM05=CD`1BDU80BDU904E5A@11@D40CTi>04Q8B019BDT0@41003dm?@0o?cl0
?3`l03dm?@12@T8203dm?@0903hn?P0j>SX0?3`l03Xj>P0l?3`0@41003`l?018B4P0BDU90080A4A4
00@0@D5103lo?`16ATH0@4100P0o?cl00`11@D40A4A403hn?P0203dm?@0D03lo?`1DE5@0EeMG05AD
E01<C4`0CDe=0451@@17AdL0A4A404=3@`1>CTh0D51@05ADE01<C4`0ADE504M7A`18B4P0BDU905EE
E@1OGel205eMG@0T069RHP1IFET0CDe=04A4A017AdL0C4a<06QXJ01mOGd0RHV908n?S`2>SXh0QhN7
0861P@1lO7`0P820071`L01UIFD0BTY:05EEE@1?Cdl0?clo04A4A01UIFD0PH6109NGU`2MWId0WinO
09fMW@2OWil0W9bL0:NWY`2UYJD0Z:RX0:JVYP2ZZZX0Z:RX0P2/[:`00`2UYJD0ZZZZ0:FUY@0209ZJ
VP0C0:>SX`2YZJT0Z:RX09nOW`2MWId0Xj>S0:VYZ@2a/K40]kNg0;Zj^P2h^;P0_Kfm0;>c/`2XZ:P0
Zj^[0;>c/`1kNg/0Ph>30:>SX`020:FUY@0Q0:b/[02[Zj/0/K6a0;:b/P2][Jd0^[Zj0;Jf]P2c/k<0
_Kfm0;:b/P2j^[X0c<c<0<S8b02i^KT0`<300<?3``32`/80b<S80<O7a`34a<@0_kno0<C4a02n_[h0
^KVi0;^k^`2o_kl0_;bl0<c<c02][Jd0ZJVY0<G5a@3>c/h0eMGE0080emOG00/0dm?C0=CDe03<c<`0
dm?C0=KFeP3Hf=P0d];B0<o?c`3AdM40clo?0<S8b0020<c<c080cLg=00P0bl_;0<o?c`3Cdm<0d];B
0=CDe03GemL0e]KF0=cLg080eMGE00T0e]KF0=3@d03De=@0e=CD0=KFeP3?cll0c/k>0<W9b@3?cll0
3Oooool0013ooooo00T0ADE504=3@`14A4@0@d=304A4A00o?cl0@41004A4A011@D400P12@T820410
@00404I6AP14A4@0@4100451@@80@T9200`0ADE504U9B@14A4@0@D510410@00n?Sh0@T920451@@0o
?cl0@d=30410@011@D430410@00603hn?P0o?cl0?Cdm03hn?P0o?cl0?Shn0P0o?cl06`10@400?3`l
04];B`18B4P0@4100451@@1>CTh0G5aL05QHF01ADE40C4a<05EEE@18B4P0ATI604Q8B010@400?3`l
03hn?P0m?Cd0>c/k03`l?00o?cl0?Shn0492@P15ADD0ATI604a<C00204e=C@0805ADE017AdL0@T92
04A4A015ADD0?clo03hn?P10@4020451@@0;03hn?P11@D40?Cdm03/k>`10@400@T9204M7A`14A4@0
?clo04A4A018B4P00P14A4@02P11@D40?Shn04Q8B01ADE40G5aL04m?C`14A4@0CDe=061PH01ZJVX2
05YJFP1106UYJ@1DE5@0A4A404m?C`1IFET0GEeM069RHP1LG5`0Hf=S07YjNP1PH600A4A40492@P13
@d<0@D5105QHF01eMGD0NWYj05iNGP1DE5@0De=C04e=C@1DE5@0GemO05]KF`1PH600Fe]K04Q8B017
AdL0ADE504];B`1JFUX0DU9B055AD@1LG5`0HF5Q06m_K`23Ph<0TY:B08n?S`1fMWH0I6AT051@D018
B4P0A4A404];B`1<C4`0@T920410@013@d<0@41004I6AP1ADE40GUiN06=SH`1KFe/0CTi>04a<C015
ADD0AdM70492@P0n?Sh0?Cdm03`l?010@4000P13@d<03P17AdL0B4Q804U9B@14A4@0AdM704a<C01>
CTh0Cdm?04E5A@10@400@d=30492@P0m?Cd0>c/k0P0l?3`03`10@400?Cdm03lo?`12@T80BTY:05QH
F01<C4`0E5AD05=CD`1>CTh0Bd];04M7A`18B4P0A4A404U9B@0204=3@`0903lo?`10@400BTY:04e=
C@1?Cdl0CTi>04Y:BP1>CTh0@D510080A4A40P10@4001@0o?cl0A4A403dm?@0o?cl0@4100080?3`l
00H0>CTi03hn?P0k>c/0>CTi03lo?`0l?3`203/k>`0303`l?00k>c/0?3`l00<0>CTi00`0>SXj03hn
?P0j>SX0>SXj03hn?P0l?3`0?Cdm0410@00m?Cd0?3`l0410@00n?Sh20410@02203lo?`15ADD0ATI6
04=3@`0k>c/0@d=303Ti>@0o?cl0?Shn04M7A`13@d<0AdM70451@@1BDU80De=C05MGE`1;Bd/0ATI6
0492@P13@d<0CTi>0492@P0o?cl0Bd];04U9B@16ATH0B4Q804=3@`10@400?Shn03lo?`10@400?3`l
03dm?@14A4@0BDU904A4A010@400@d=303dm?@14A4@0@410055AD@1DE5@0EUIF051@D01DE5@0DU9B
05QHF01ADE40E5AD051@D018B4P0AdM704E5A@17AdL0Cdm?0492@P10@400@D51059BDP1PH600HV9R
06MWI`1_Kfl0JFUY05eMG@1NGUh0Jf][071`L02;Rh/0SHf=08R8R01mOGd0KVi^07=cL`1kNg/0S8b<
09^KV`2LW9`0Vi^K0:2PX02SXj<0V9RH08b<S022PX80Q8B408b<S02JVYX0XZ:R0:FUY@2ZZZX0YjNW
0:2PX02QXJ40Vi^K09nOW`2NWYh0TI6A07]kN`1YJFT0GUiN05QHF01JFUX0PH61096AT@2>SXh0VYZJ
09fMW@2/[:`0/K6a0:j^[P2n_[h0`/;20;no_`32`/80^k^k0;2`/02b/[80^;Rh0;Ng]`2h^;P0^k^k
0;Bd]02XZ:P0[:b/0<S8b03<c<`0^;Rh0;Bd]080^[Zj0P2i^KT02P2f][H0];Bd0;Ng]`2d];@0^k^k
0;no_`3=cLd0b<S80;:b/P3:b/X20<C4a00S0:6QX@2HV9P0Xj>S0:BTY02SXj<0X:2P07QhN02<S8`0
]KFe0<?3``3>c/h0b/[:0<71`@2h^;P0a/K60<?3``31`L40a<C40;Ng]`30`<00`/;20<C4a02j^[X0
][Jf0;jn_P31`L40a/K60<C4a02XZ:P0W9bL0<C4a039bLT0e]KF0=GEe@3De=@00P3Cdm<30=GEe@0E
0=?Cd`3?cll0c/k>0=7Ad@3=cLd0alO70<W9b@38b<P0bl_;0<c<c039bLT0cLg=0<k>cP3AdM40eMGE
0=SHf03Fe]H0eMGE0=CDe03EeMD0e=CD0080d=3@00H0c/k>0<o?c`3AdM40clo?0<c<c03;bl/=oooo
o`004?ooool01@1<C4`0A4A404I6AP14A4@0@d=30080@T9200P0AdM705]KF`1>CTh0@D5104I6AP15
ADD0A4A40492@PH0@4100P0m?Cd203hn?P030410@011@D40?Shn0080?clo0P0m?Cd0100n?Sh0@410
03hn?P0m?Cd203lo?`0H03hn?P0l?3`0>SXj03`l?011@D40?clo03hn?P0j>SX0>CTi03hn?P13@d<0
C4a<04A4A00o?cl0?Cdm03lo?`0n?Sh0>c/k04=3@`0o?cl0?3`l03/k>`0l?3`0?Shn0`0k>c/0800h
>3P0?Shn03lo?`0l?3`0?Cdm04=3@`0j>SX0@T9203hn?P0j>SX0?3`l03hn?P12@T80?Cdm03/k>`0l
?3`0@T9203lo?`0l?3`0?Shn0492@P1:BTX0E5AD0451@@16ATH0?clo03`l?00m?Cd0?3`l03/k>`0n
?Sh0?Cdm0P0n?Sh01@0k>c/0@D5103hn?P12@T80@D510080?3`l01P0@4100451@@11@D40?Cdm03`l
?00k>c/0@D5104M7A`1:BTX0ATI60492@P17AdL0@T9204E5A@1;Bd/0Hf=S075aL@1XJ6P0D51@04i>
CP1:BTX0A4A40492@P15ADD204Y:BP0I04A4A00l?3`0@T9204a<C01JFUX0IVIV071`L01VIVH0Lg=c
07]kN`1eMGD0MgMg07moO`1gMgL0KFe]07EeM@1bLW80OWin08F5Q@1nOWh0IfMW05mOG`1XJ6P0JVYZ
06UYJ@0206QXJ00<06UYJ@1RHV80HV9R05aLG01>CTh0AdM70492@P0m?Cd0?clo0492@P14A4@0@T92
0P11@D402`15ADD0C4a<04m?C`1LG5`0HF5Q05mOG`18B4P0ATI60451@@0n?Sh0ADE50080?Cdm01X0
>c/k03hn?P0l?3`0@41003lo?`13@d<0@T9204A4A01@D500AdM704Y:BP11@D40@T920410@00o?cl0
?Shn03dm?@0l?3`0?Shn04I6AP17AdL0Bd];051@D01BDU80AdM704U9B@80@d=300l0@41003lo?`0k
>c/0@41004A4A00o?cl0?Shn03dm?@0n?Sh0@T9203dm?@0l?3`0>SXj03lo?`0l?3`00P0o?cl05`0l
?3`0>CTi03`l?00o?cl0?Shn03lo?`0m?Cd0>c/k0410@00l?3`0>SXj03Ti>@0l?3`0?clo0492@P15
ADD0@41003dm?@10@400?Shn03dm?@0o?cl0ATI60080>c/k00`0?3`l03hn?P0j>SX0>c/k0451@@0l
?3`0?clo03dm?@0o?cl0ATI604A4A013@d<204E5A@0;0451@@0m?Cd0ATI604i>CP1DE5@0Bd];04I6
AP19BDT0ADE504I6AP1<C4`00`1:BTX04@18B4P0A4A404i>CP1BDU80GemO065QH@1EEED0D51@059B
DP1>CTh0FEUI06=SH`1cLg<0QhN708b<S02GUiL0UIFE0080TI6A01<0U9BD092@T02;Rh/0QhN708R8
R01mOGd0Lg=c05iNGP15ADD0?Cdm06EUI@2;Rh/0SHf=09RHV02LW9`0VIVI09FEU@2?Shl0Ti>C0080
VYZJ01D0WYjN0:2PX02NWYh0WIfM09ZJVP2QXJ40XZ:R0:FUY@2TY:@0XZ:R09RHV02TY:@0Zj^[0:ZZ
ZP2XZ:P0YZJV0;2`/02a/K40[:b/0:n_[`2c/k<00P2o_kl09@2m_Kd0/;2`0;>c/`2n_[h0_kno0<K6
aP33`l<0_Kfm0;Fe]@2SXj<0V9RH09NGU`2TY:@0/[:b0;Zj^P2f][H0[Zj^0;Jf]P2l_;`0];Bd0;:b
/P2[Zj/0[jn_0:ZZZP2][Jd0/k>c0;Rh^02i^KT0][Jf0;Zj^P2i^KT0]KFe0;Ng]`2o_kl0_Kfm0;^k
^`2f][H00P2d];@0:02c/k<0^[Zj0;>c/`2g]kL0_;bl0;Bd]02g]kL0/[:b0<30`038b<P0aLG50<_;
b`39bLT0b/[:0<S8b037alL0cLg=0<C4a02k^k/0_;bl09RHV02YZJT0cLg=0<k>cP3=cLd0aLG50;Vi
^@2g]kL0`L710<;2`P2n_[h0^KVi0;Zj^P3:b/X0a/K60<O7a`2h^;P0/k>c0<G5a@38b<P20<K6aP0:
0;2`/02a/K40bl_;0=3@d03IfMT0e]KF0=?Cd`3Bd]80d=3@0=KFeP80eMGE00X0d];B0<o?c`3>c/h0
clo?0<[:bP34a<@0b<S80<c<c038b<P0bl_;0P3>c/h01`3;bl/0c<c<0=GEe@3GemL0a/K60=;BdP3C
dm<00P3Bd]801@3EeMD0d=3@0=3@d03@d=00dM7A0080d=3@00<0c/k>ooooooooool02oooool0013o
oooo0180AdM704A4A017AdL0ATI604Q8B010@400AdM705mOG`24Q8@0NGUi05ADE01BDU80BTY:04U9
B@1ADE40Cdm?04=3@`12@T8204=3@`030410@00n?Sh0?3`l00<0?clo01L0>c/k03lo?`13@d<0ADE5
04e=C@1KFe/0AdM70451@@0l?3`0?Cdm04A4A01KFe/0H61P04a<C01DE5@0I6AT06EUI@1HF5P0GEeM
04Y:BP0o?cl0?Cdm03Ti>@0203lo?`0503dm?@0n?Sh0@d=303`l?00h>3P00P0n?Sh0200m?Cd0>c/k
03`l?00l?3`0>c/k03Ti>@0l?3`0>c/k0P11@D400`0k>c/0?clo03lo?`0303dm?@030410@00j>SX0
?clo0080>c/k00T0?3`l03Ph>00m?Cd0>SXj03`l?00n?Sh0?Cdm0410@00n?Sh00P0l?3`0100i>CT0
?Cdm03/k>`0l?3`303dm?@0J03/k>`0n?Sh0>SXj03hn?P0l?3`0>3Ph03`l?00j>SX0?clo0451@@0l
?3`0@d=30492@P0l?3`0?Cdm0451@@16ATH0@T9204I6AP17AdL0B4Q80410@012@T80B4Q804];B`10
@4020451@@0P03lo?`12@T80@T9204=3@`12@T80A4A40492@P0k>c/0@D5104];B`1=CDd0A4A40410
@01?Cdl0GEeM05iNGP1LG5`0FUYJ05MGE`1MGEd0DU9B051@D01MGEd0EeMG06=SH`1ZJVX0GemO05IF
EP1NGUh0FUYJ05ADE01>CTh204Y:BP080492@P17AdL0BDU904=3@`18B4P0DE5A04U9B@12@T820451
@@0<04A4A016ATH0@T92051@D01IFET0Fe]K061PH01aLG40I6AT04e=C@11@D40A4A40P0n?Sh02`0o
?cl0?Shn03hn?P17AdL0@d=304Q8B015ADD0Cdm?05IFEP1HF5P0A4A40080@T9200D0@41003lo?`0l
?3`0?Cdm0410@00203hn?P090492@P14A4@0B4Q8055AD@1DE5@0B4Q804U9B@17AdL0BDU90080B4Q8
0100@41003lo?`0m?Cd0?3`l0410@00j>SX0>c/k03hn?P10@400>c/k03hn?P0l?3`0?clo03hn?P10
@400@d=30P0n?Sh0100l?3`0?Shn0492@P0o?cl203/k>`1<03lo?`16ATH0?Shn03`l?00m?Cd0@D51
0492@P17AdL0B4Q803lo?`11@D40?Cdm0410@00l?3`0@D5104=3@`0l?3`0?clo03hn?P13@d<0@D51
03hn?P11@D40?Shn04A4A015ADD0?Shn04Q8B017AdL0ATI60451@@10@400>CTi03hn?P1=CDd0EeMG
065QH@1SHf<0F5QH05YJFP1HF5P0JFUY075aL@1hN7P0Q8B408V9R@24Q8@0M7Ad07QhN01oOgl0RXZ:
08V9R@28R8P0PH6107emO@1eMGD0NGUi08R8R02>SXh0UIFE09:BTP2DU9@0V9RH09>CT`2NWYh0WIfM
09bLW02MWId0Vi^K0:>SX`2PX:00WIfM0820P01KFe/0CDe=07AdM080Vi^K00H0WYjN0:2PX02RXZ80
ZJVY0::RXP2PX:020:FUY@050::RXP2VYZH0ZZZZ0:ZZZP2XZ:P00P2][Jd03P2k^k/0_Kfm0;Jf]P2_
[jl0];Bd0;Vi^@34a<@0a/K60<c<c03@d=00eMGE0=CDe03EeMD0clo?0P3Bd]80:@3@d=00bLW90<71
`@39bLT0d=3@0=GEe@3=cLd0`L710;Vi^@2YZJT0UIFE09bLW02^[Zh0][Jf0;^k^`2i^KT0];Bd0;>c
/`2j^[X0/k>c0:n_[`2ZZZX0ZJVY0;Bd]02g]kL0^;Rh0;>c/`2h^;P0]kNg0;Fe]@2b/[80_;bl0;Ng
]`2l_;`0_Kfm0;no_`2b/[80[jn_0::RXP2f][H0];Bd0080/k>c0200_[jn0;Jf]P2d];@0Zj^[0:j^
[P2f][H0a<C40<W9b@3:b/X0a/K60<;2`P2h^;P0a<C40<?3``38b<P0b/[:0<_;b`3?cll0dm?C0<_;
b`36a/H0`l?30<;2`P2`/;00_;bl0<C4a02n_[h0_Kfm0;Vi^@33`l<0bLW90<_;b`80_kno00`0c<c<
0<[:bP3;bl/0a/K60;2`/02b/[80d=3@0=;BdP3Cdm<0e=CD0=GEe@3Fe]H30=OGe`070=KFeP3De=@0
dm?C0<o?c`3;bl/0alO70<g=c@020<_;b`090<o?c`3@d=00c<c<0<_;b`3:b/X0c/k>0=GEe@3Fe]H0
c/k>0080e=CD00D0clo?0=3@d03Cdm<0c<c<0<g=c@020<o?c`030=7Ad@3Cdm<0e]KF00gooooo000@
ooooo`030492@P14A4@0@4100080@d=301H0@D510492@P14A4@0@d=304M7A`13@d<0A4A40451@@1;
Bd/0EEEE065QH@1<C4`0D51@04e=C@15ADD0@T9204=3@`11@D40A4A40451@@0n?Sh0?clo0P12@T80
2P13@d<0CTi>05]KF`1RHV80EeMG04];B`15ADD0CDe=07emO@21PH42061PH00906i^KP1LG5`0D51@
06QXJ01`L700JVYZ05EEE@0m?Cd0?3`l0080>c/k0100?3`l03/k>`0n?Sh0@41003Xj>P10@400A4A4
03dm?@16ATH0B4Q804M7A`15ADD0@D5103/k>`0o?cl0?Shn0P0k>c/02P0m?Cd0?3`l03hn?P0m?Cd0
?clo0451@@0k>c/0>SXj03/k>`0j>SX203`l?00403dm?@0n?Sh0?Cdm03/k>`80>CTi00<0?Cdm03`l
?00k>c/00P0k>c/03@0i>CT0>c/k03/k>`0l?3`0?Cdm04=3@`10@400?Cdm03hn?P0j>SX0>c/k03`l
?010@4000P11@D409@0o?cl0?Cdm03dm?@14A4@0>c/k03lo?`0k>c/0?clo0492@P10@400?Shn0451
@@14A4@0@D5103hn?P12@T80B4Q80451@@0m?Cd0>c/k03dm?@0n?Sh0>SXj0492@P10@400@d=30410
@00o?cl0?Cdm0451@@16ATH0@d=30410@012@T80Bd];04Q8B01;Bd/00P18B4P09@17AdL0Cdm?055A
D@1>CTh0BDU904E5A@1?Cdl0BDU9051@D015ADD0@T920451@@0k>c/0@T9203hn?P0o?cl0?Cdm03hn
?P0o?cl0?Shn03/k>`11@D40?clo0451@@0o?cl0ATI603lo?`14A4@0@D510410@014A4@0?clo03`l
?00o?cl0@41003hn?P0m?Cd00P0n?Sh0400o?cl0B4Q804E5A@14A4@0CDe=05ADE01?Cdl0@D5103hn
?P0o?cl0?Shn04=3@`0o?cl0AdM70492@P0m?Cd204M7A`0<03dm?@17AdL0DU9B04e=C@18B4P0@d=3
0492@P10@400?Shn04E5A@0n?Sh0@T920P0m?Cd03P11@D40?Cdm03Ph>00n?Sh0?clo04=3@`0j>SX0
@D5103hn?P0o?cl0?Shn03lo?`10@400@D510P0n?Sh0200o?cl0@4100410@00o?cl0@D510410@00n
?Sh0Bd];0P1<C4`03@1?Cdl0CTi>059BDP1BDU80F5QH055AD@1@D500FUYJ05]KF`1EEED0Cdm?059B
DP1:BTX00P1IFET06P1PH600HV9R061PH01RHV80Hf=S05iNGP1PH600FEUI05ADE01?Cdl0?clo03dm
?@1<C4`0NWYj08>3P`2ATI40VYZJ09NGU`2FUYH0V9RH09bLW02PX:00Xj>S0:6QX@2KVi/0X:2P0P2M
WId01@2NWYh0XZ:R09bLW02LW9`0XJ6Q0080VIVI00`0Vi^K0:2PX02QXJ40YjNW0;2`/02VYZH0XJ6Q
09VIV@2DU9@0RHV908J6QP2:RXX209NGU`0?0:BTY02YZJT0XZ:R0:6QX@2JVYX0YZJV0:b/[02^[Zh0
]kNg0;Vi^@2m_Kd0`<300;Jf]P2i^KT0][Jf0080]kNg0100^[Zj0;Fe]@2`/;00][Jf0;Ng]`31`L40
b/[:0=3@d035aLD0^[Zj0;jn_P38b<P0clo?0<g=c@3@d=00e=CD0P3Hf=P0403GemL0dM7A0=?Cd`3E
eMD0bLW90<G5a@36a/H0b/[:0<o?c`3>c/h0^k^k0;no_`2h^;P0XZ:R0:NWY`2`/;020;Zj^P050;bl
_02k^k/0`l?30<C4a033`l<00P2e]KD02P2g]kL0^KVi0<C4a032`/80_Kfm0;bl_02h^;P0_kno0;Ng
]`2e]KD20;Vi^@0>0<30`02l_;`0]kNg0:RXZ02[Zj/0/k>c0;Vi^@2e]KD0_;bl0:j^[P2g]kL0^[Zj
0;Rh^02b/[820;Vi^@070;Rh^02j^[X0`/;20<71`@30`<00_kno0;Jf]P020;Zj^P0M0;^k^`2h^;P0
_Kfm0<c<c035aLD0_kno0;bl_02i^KT0[:b/0;no_`3<c<`0a<C40<;2`P2i^KT0_[jn0<_;b`3?cll0
a<C40<G5a@3;bl/0c/k>0<_;b`3<c<`0_Kfm0<71`@3AdM40clo?0=CDe03Cdm<00P3Fe]H03@3IfMT0
emOG0=OGe`3EeMD0f=SH0=[JfP3Fe]H0c/k>0<O7a`3:b/X0bl_;0<[:bP3?cll00P3AdM420<W9b@0@
0<k>cP3De=@0e]KF0=?Cd`3Jf]X0f=SH0=GEe@3Bd]80dm?C0=3@d03AdM40eMGE0=3@d03EeMD0emOG
0=SHf0gooooo000@ooooo`80ADE500h0@T9204A4A012@T80@D510492@P0m?Cd0@T920410@011@D40
@T920451@@12@T80?clo03dm?@80?clo0100?Cdm03/k>`0m?Cd0?clo03Xj>P0n?Sh0?Cdm03hn?P0m
?Cd0>c/k03`l?00n?Sh0?Cdm03hn?P0o?cl0?Cdm0P11@D402@0n?Sh0@41003dm?@0l?3`0?clo03hn
?P0o?cl0?Cdm0451@@0204Q8B00D04A4A00o?cl0?Cdm03lo?`10@400?Cdm03`l?00n?Sh0@T920410
@00m?Cd0?3`l03hn?P14A4@0CDe=059BDP1;Bd/0?Shn03dm?@0k>c/20410@00A03`l?00i>CT0@D51
04i>CP18B4P0?clo03hn?P0j>SX0?Cdm0410@00i>CT0A4A40451@@13@d<0ADE503`l?00n?Sh00P0j
>SX203/k>`0603dm?@0l?3`0?3`l03Xj>P0o?cl0>c/k0P0i>CT01`0k>c/0>SXj03`l?00n?Sh0>c/k
03`l?00k>c/00P0n?Sh01`0h>3P0?3`l03dm?@0n?Sh0@T9203/k>`0i>CT00P0k>c/02@11@D40@410
03hn?P10@400@D5103hn?P0m?Cd0@D5103dm?@0203lo?`0B03hn?P0k>c/0>c/k03hn?P0o?cl0@410
03hn?P0m?Cd0?Shn03`l?010@400ADE50451@@14A4@0@d=304I6AP14A4@0B4Q80P12@T802P19BDT0
De=C04Y:BP14A4@0ATI60451@@14A4@0AdM704I6AP13@d<403lo?`0L0410@00m?Cd0?Cdm03`l?00o
?cl0?Shn03`l?00o?cl0?3`l03hn?P0l?3`0?clo03`l?010@400@D5103lo?`10@400@D5104I6AP10
@400?Cdm03lo?`0n?Sh0?clo03dm?@0n?Sh0>c/k03lo?`80?Shn0P0o?cl00`12@T80@D510492@P02
0492@P0>04A4A018B4P0AdM704Q8B01BDU80CDe=04I6AP15ADD0@d=304I6AP1<C4`0@d=30451@@0n
?Sh20451@@0?03dm?@15ADD0A4A403lo?`13@d<0ADE50492@P14A4@0?3`l0492@P14A4@0ATI603lo
?`11@D40B4Q80080@41002/0?3`l0410@012@T80B4Q804i>CP1EEED0C4a<05IFEP1RHV80Kfm_08>3
P`2;Rh/0TI6A08f=S@2>SXh0UiNG09FEU@2FUYH0TI6A08j>SP2?Shl0T92@09:BTP2;Rh/0RXZ:08f=
S@2DU9@0UiNG09bLW02IVIT0V9RH09nOW`2KVi/0VYZJ09fMW@2FUYH0TY:B06i^KP1IFET0B4Q806AT
I02FUYH0WIfM0080XZ:R03L0Xj>S0:RXZ02WYjL0/K6a0;Zj^P2f][H0^;Rh0;2`/02ZZZX0Zj^[0:j^
[P2YZJT0Zj^[0:f][@2g]kL0]KFe0:n_[`2c/k<0]KFe0;^k^`2n_[h0`/;20<?3``32`/80`<300<71
`@35aLD0^k^k0;no_`2a/K40/k>c0:VYZ@2SXj<0UIFE09:BTP2MWId0YZJV0:FUY@2ATI40Z:RX0;no
_`32`/80`L710;no_`2j^[X0];Bd0;Rh^02k^k/0_Kfm0<71`@32`/80/k>c0;Rh^02c/k<0^[Zj0080
`<3000T0]KFe0;>c/`36a/H0a/K60<k>cP3<c<`0d=3@0=CDe03Cdm<00P3EeMD01`3AdM40d];B0<_;
b`32`/80`L710<G5a@3<c<`00P3GemL20=7Ad@0F0<W9b@34a<@0`/;20;Rh^02f][H0];Bd0;Vi^@30
`<00`L710;Vi^@2e]KD0_;bl0;fm_@30`<00_[jn0<71`@30`<00_;bl0;>c/`2b/[80^k^k0<30`080
_[jn03L0^;Rh0;^k^`2m_Kd0^KVi0;>c/`2WYjL0^KVi0;jn_P30`<00`l?30;Jf]P2c/k<0^k^k0;Rh
^02i^KT0_;bl0;jn_P2j^[X0_Kfm0;no_`2m_Kd0_[jn0<C4a02h^;P0];Bd0;Vi^@2l_;`0]kNg0;fm
_@3>c/h0`/;20<71`@30`<00^KVi0;6a/@2l_;`0b/[:0<W9b@2l_;`0/K6a0;Vi^@33`l<0bl_;0<71
`@35aLD0dM7A0<_;b`3=cLd0b<S80<G5a@36a/H0cLg=0=CDe03>c/h0e]KF0080e=CD00<0e]KF0=?C
d`3Fe]H00P3IfMT0103EeMD0d];B0<[:bP36a/H20<c<c00F0<_;b`3?cll0clo?0<_;b`3@d=00dM7A
0=;BdP3EeMD0fm_K0=GEe@3GemL0eMGE0=CDe03Fe]H0e=CD0=GEe@3Cdm<0f=SH0=KFeP3Cdm<0eMGE
0=OGe`gooooo000@ooooo`80A4A401T0@T9204A4A014A4@0?clo03hn?P10@400@T9203lo?`12@T80
@41003lo?`0m?Cd0?Shn03/k>`0o?cl0?Shn03dm?@0l?3`0?Shn0451@@0m?Cd0?Shn03/k>`0n?Sh0
?Cdm0080>SXj00l0@4100451@@0n?Sh0?Cdm03`l?00m?Cd0?Shn03lo?`12@T80?Shn03dm?@10@400
@d=303`l?010@4000P0m?Cd02`0n?Sh0?clo03lo?`0m?Cd0?Shn03dm?@0j>SX0?Shn03Ti>@0j>SX0
?3`l00<0>c/k00L0>SXj03lo?`0j>SX0>SXj03`l?00n?Sh0?clo0080?3`l0180>SXj03Ti>@0n?Sh0
@4100451@@0l?3`0?clo03/k>`0n?Sh0?Cdm0451@@14A4@0ADE504m?C`0o?cl0@D5104=3@`0k>c/2
03hn?P0<03`l?00n?Sh0?clo03lo?`10@400BDU90451@@0k>c/0?Cdm03Xj>P0l?3`0>c/k0P10@400
8@11@D40?clo0451@@0l?3`0?Cdm03hn?P0m?Cd0?clo03Xj>P12@T80@41003hn?P0o?cl0>SXj03`l
?00n?Sh0?3`l0451@@12@T80?Shn0451@@0l?3`0>c/k03dm?@0n?Sh0>SXj03dm?@12@T80@4100492
@P0o?cl0>CTi03dm?@020410@00C0492@P0o?cl0@d=30451@@10@400?3`l0451@@10@400A4A404a<
C01;Bd/0?clo0410@00l?3`0?Shn0410@014A4@0@T920410@00203lo?`0803hn?P0m?Cd0@d=30410
@00m?Cd0?clo0410@00n?Sh20410@00803hn?P12@T80@D510451@@0o?cl0@4100451@@0o?cl30492
@P070451@@0n?Sh0?Shn03hn?P12@T80@41003lo?`0203`l?0090410@012@T80@4100410@011@D40
@d=304e=C@15ADD0@T920080@D5100<0@410051@D01?Cdl00`1@D5002P1:BTX0Cdm?05IFEP1@D500
A4A404Q8B01=CDd0D51@05ADE01KFe/305mOG`0:05QHF01OGel0H61P06=SH`1aLG40J6QX05eMG@1D
E5@0Cdm?055AD@80B4Q80P11@D40<01_Kfl0OWin08b<S02EUID0Shn?09:BTP2EUID0W9bL09ZJVP2Q
XJ40WYjN0::RXP2UYJD0Zj^[0:JVYP2TY:@0WYjN09ZJVP2FUYH0VIVI09nOW`2PX:00XZ:R0:NWY`2T
Y:@0[Jf]0:NWY`2VYZH0Xj>S0:j^[P2ZZZX0[Zj^0;Fe]@2c/k<0/[:b0:^[Z`2][Jd0V9RH09bLW02[
Zj/0]KFe0;bl_032`/80`<300<?3``34a<@0alO70<[:bP80`l?301<0a<C40;jn_P2o_kl0^KVi0<C4
a036a/H0`<300<W9b@33`l<0a/K60<S8b03?cll0b/[:0<C4a038b<P0alO70<k>cP35aLD0`L710080
a/K60100b<S80;no_`2n_[h0_kno0;Zj^P2`/;00[:b/0;2`/02e]KD0[:b/07]kN`2JVYX0]kNg0;no
_`32`/80_kno0P32`/804P36a/H0`/;20<71`@37alL0bLW90;no_`33`l<0/;2`0:n_[`2f][H0/;2`
0:^[Z`2g]kL0bLW90<O7a`3=cLd0bl_;0=?Cd`80eMGE0`3Hf=P02P3Fe]H0c<c<0<?3``38b<P0alO7
0<C4a03Cdm<0e]KF0=OGe`3;bl/20<o?c`080;bl_02e]KD0]KFe0:j^[P2[Zj/0^k^k0;:b/P2l_;`3
0;Vi^@0X0;Ng]`2j^[X0`/;20;no_`2h^;P0/K6a0;Vi^@2h^;P0_;bl0;^k^`2n_[h0_Kfm0<71`@2k
^k/0`<300;:b/P2ZZZX0^k^k0;fm_@32`/80`L710;Bd]02[Zj/0`<300<W9b@2k^k/0a<C40<71`@34
a<@0`/;20<[:bP2n_[h0^KVi0;Zj^P2a/K40[:b/0;Fe]@2m_Kd0_;bl0<O7a`80`<3000l0_Kfm0;jn
_P2i^KT0];Bd0;Zj^P35aLD0a/K60<71`@2o_kl0`/;20<C4a038b<P0alO70<?3``3>c/h00P3<c<`0
3P3Bd]80bl_;0<k>cP3Cdm<0dM7A0<o?c`3De=@0dm?C0=WIf@3De=@0dm?C0=;BdP3>c/h0e=CD0P3A
dM440<g=c@0A0=7Ad@3Fe]H0c/k>0=CDe03AdM40eMGE0=OGe`3De=@0eMGE0=KFeP3Jf]X0fm_K0=SH
f03Jf]X0emOG0=WIf@3GemL00P3Kfm/00`3Fe]H0emOG0=SHf00=ooooo`004?ooool04017AdL0ADE5
04E5A@15ADD0@d=30492@P0o?cl0ATI604U9B@11@D40?clo04A4A01;Bd/0EUIF05=CD`19BDT204=3
@`0804A4A00o?cl0?Shn0451@@0o?cl0@41003dm?@10@40203hn?P0603lo?`11@D40@4100410@012
@T80@D51100n?Sh03P11@D40>c/k04E5A@1<C4`0BDU903hn?P14A4@0?Shn0451@@12@T80?clo04M7
A`11@D40?Cdm0P0o?cl0300l?3`0?Shn03/k>`0m?Cd0?Shn03Ph>00k>c/0?3`l03Ph>00n?Sh0>SXj
03/k>`<0?3`l01H0?Cdm03Xj>P0l?3`0?Cdm03lo?`0l?3`0?Shn03Xj>P0n?Sh0@D5103hn?P11@D40
?Shn0492@P15ADD0D51@04Q8B00j>SX0?Cdm03Xj>P0k>c/0?3`l0P0m?Cd08@0l?3`0ADE503dm?@0k
>c/0@D5103dm?@13@d<0@T9205=CD`1RHV80EeMG04m?C`1EEED0DE5A04a<C00i>CT0?Cdm04=3@`14
A4@0@D510492@P10@400?Cdm03/k>`0m?Cd0?clo03dm?@12@T80ADE50451@@0m?Cd0?clo03hn?P02
04I6AP0903dm?@0j>SX0@41004=3@`0n?Sh0A4A40410@012@T80@D510080?Cdm0180>c/k0492@P15
ADD0ATI603hn?P16ATH0@D5103dm?@0o?cl0@T920451@@10@400>c/k03dm?@0o?cl0@T9204A4A00n
?Sh20451@@0803hn?P12@T80@D5103lo?`10@400@D5103dm?@13@d<20410@00303dm?@13@d<0@d=3
0080@T9200`0A4A404E5A@10@400A4A40451@@0n?Sh0@41004M7A`16ATH0@d=30492@P15ADD204A4
A00A04=3@`18B4P0BDU904Q8B01=CDd0BDU904Q8B014A4@0ADE504M7A`1QHF40GemO06][J`1bLW80
KVi^07IfMP1kNg/00P26QXH0:@28R8P0Ph>308J6QP29RHT0R8R808^;R`2>SXh0UYJF09VIV@2CTi<0
TY:B09BDU02>SXh0Ti>C09FEU@2HV9P0X:2P09bLW02IVIT0Vi^K08b<S022PX80NWYj079bLP1NGUh0
De=C096AT@2ZZZX0YJFU0:6QX@2SXj<0WIfM09^KV`2RXZ80YjNW0:f][@2ZZZX0Zj^[0;>c/`2b/[80
/;2`0080/K6a02l0[Zj^0:RXZ02][Jd0Zj^[0;6a/@2l_;`0`<300;fm_@33`l<0alO70<C4a02m_Kd0
a/K60<;2`P33`l<0bl_;0<g=c@34a<@0`/;20;jn_P2YZJT0WinO0;:b/P30`<00a/K60<[:bP39bLT0
a/K60;fm_@33`l<0b/[:0<K6aP35aLD0c<c<0<K6aP31`L40`<300<S8b034a<@0alO70<[:bP36a/H0
`<300<?3``34a<@0aLG50<_;b`020<[:bP0e0=?Cd`37alL0a<C40<S8b034a<@0b<S80<71`@32`/80
`l?30;^k^`2j^[X0_;bl0;jn_P30`<00_[jn0:j^[P2i^KT0`L710<?3``34a<@0_[jn0;Zj^P33`l<0
b<S80<K6aP33`l<0alO70<G5a@2o_kl0^[Zj0;6a/@2d];@0^[Zj0;Bd]02^[Zh0^[Zj0<g=c@3AdM40
c/k>0=7Ad@3GemL0fMWI0=CDe03@d=00e=CD0=GEe@3Cdm<0b/[:0<_;b`3<c<`0a<C40<G5a@3<c<`0
0P3?cll08@33`l<0c<c<0<;2`P2d];@0/k>c0;2`/02d];@0[Jf]0<30`02h^;P0`<300;bl_02n_[h0
^[Zj0;Jf]P2l_;`0b/[:0<;2`P2f][H0^;Rh0;fm_@2j^[X0_[jn0<C4a031`L40`<300;Ng]`2j^[X0
`l?30;Zj^P2d];@0`/;20<O7a`020<W9b@0U0<O7a`30`<00b/[:0=;BdP37alL0bLW90<_;b`36a/H0
c/k>0<g=c@3;bl/0aLG50<;2`P2i^KT0]KFe0;:b/P37alL0a/K60<_;b`37alL0`l?30<C4a031`L40
^[Zj0;^k^`34a<@0`<300<G5a@34a<@0a/K60<;2`P2n_[h0bLW90<[:bP35aLD0b/[:0=3@d0020=CD
e0080<o?c`3Bd]80e]KF0=OGe`3Cdm<0fMWI0=OGe`3Hf=P20=GEe@0>0=?Cd`3?cll0dm?C0=KFeP3D
e=@0c/k>0=GEe@3AdM40dm?C0=GEe@3Fe]H0emOG0=SHf03EeMD20=?Cd`070=OGe`3Ogml0g=cL0=[J
fP3Kfm/0fMWI0>3Ph0020=[JfP060=cLg03MgMd0gMgM0=cLg03Jf]X0g=cL3Oooool0013ooooo01L0
B4Q804A4A011@D40@T9203hn?P0o?cl0BDU905]KF`1]KFd0IVIV05eMG@1TI6@0P82009BDU02LW9`0
SXj>06i^KP1IFET0J6QX051@D014A4@0ATI604=3@`020410@00<04A4A01HF5P0EEEE05aLG01YJFT0
F5QH051@D01OGel0J6QX06ATI01DE5@0D51@0`1GEeL03`1TI6@0IfMW06e]K@1FEUH0De=C04e=C@18
B4P0A4A404=3@`1EEED0@d=303lo?`13@d<0?clo03/k>`0203dm?@0403lo?`14A4@0@41003`l?080
?Shn00X0@4100492@P14A4@0@T920451@@15ADD0?Cdm0492@P0o?cl0ATI60P13@d<09015ADD0@d=3
0410@012@T80?Shn04=3@`17AdL0De=C05ADE01<C4`0ATI604];B`14A4@0@D5104a<C01FEUH0D51@
05=CD`1<C4`0BTY:04I6AP18B4P0DU9B055AD@1GEeL0GemO06m_K`1jNWX0MWIf079bLP1^KVh0EeMG
04E5A@0o?cl0ATI603`l?080?Cdm0180?Shn03dm?@0h>3P0>c/k03Hf=P0o?cl0@41004A4A00o?cl0
?Cdm0410@00o?cl0?Cdm03hn?P0m?Cd0@d=303hn?P13@d<20410@00804=3@`0o?cl0@D5104=3@`12
@T80@D510410@016ATH204A4A01003hn?P19BDT0ATI604E5A@14A4@0Cdm?0492@P15ADD0?Cdm0451
@@0m?Cd0A4A404Y:BP12@T80A4A40492@P0m?Cd0?Shn0451@@0o?cl0@T9204=3@`15ADD0A4A40410
@014A4@0ATI604=3@`14A4@0ADE50451@@16ATH0BDU904Q8B01<C4`0BTY:04I6AP13@d<0DU9B05IF
EP1GEeL0GUiN06MWI`1QHF40HV9R06][J`1lO7`0LG5a071`L01ZJVX0GUiN05UIF@17AdL0@D51069R
HP2>SXh0WIfM09bLW02MWId0X:2P0:6QX@2OWil0X:2P0:BTY0<0YjNW00D0[Jf]0;6a/@2][Jd0XZ:R
0:FUY@030:>SX`030:VYZ@2NWYh0W9bL0080WIfM0P2IVIT08@2VYZH0/[:b0;:b/P2^[Zh0[Jf]0;2`
/02JVYX0XZ:R0;6a/@31`L40_Kfm0;bl_032`/80_Kfm0<71`@37alL0c/k>0<S8b035aLD0cLg=0<k>
cP3=cLd0bl_;0<K6aP32`/80a/K60;bl_035aLD0a<C40<30`035aLD0a<C40<?3``020<G5a@0@0<C4
a030`<00a<C40<G5a@37alL0bLW90<c<c02j^[X0][Jf0;Vi^@2/[:`0/;2`0<71`@3>c/h0b/[:0<_;
b`80bLW900P0a/K60<?3``34a<@0clo?0<[:bP3>c/h0clo?0<W9b@80cLg=00d0bl_;0<c<c03;bl/0
b<S80<o?c`34a<@0b<S80<c<c03Cdm<0cLg=0=3@d03Cdm<0cLg=00@0d=3@0P3?cll07036a/H0_[jn
0<;2`P2m_Kd0_[jn0<71`@34a<@0_Kfm0<G5a@39bLT0`l?30<O7a`32`/80^k^k0;Fe]@2a/K40]KFe
0;no_`34a<@0_kno0<30`02k^k/0_;bl0<?3``2m_Kd0];Bd0:^[Z`2h^;P20<k>cP060=3@d03EeMD0
e]KF0=OGe`3Cdm<0dM7A0P3GemL0;03Bd]80bl_;0=3@d037alL0a/K60<g=c@3>c/h0a/K60<?3``2n
_[h0c<c<0<O7a`2^[Zh0WIfM0:VYZ@2d];@0]kNg0<O7a`2l_;`0/k>c0;Zj^P30`<00/k>c0;jn_P3:
b/X0e=CD0<_;b`32`/80aLG50<[:bP2j^[X0aLG50<?3``39bLT0^[Zj0:VYZ@2l_;`0cLg=0<G5a@2i
^KT0alO70<k>cP3Bd]80b<S80P3;bl/05`3>c/h0cLg=0<O7a`32`/80_Kfm0;no_`36a/H0aLG50<S8
b034a<@0`L710;fm_@2b/[80]KFe0<C4a038b<P0bl_;0<O7a`35aLD0b<S80<;2`P31`L40`l?30080
aLG500P0a/K60<30`035aLD0_[jn0;bl_035aLD0bLW90;fm_@80eMGE0140emOG0=GEe@3@d=00f=SH
0=cLg03Fe]H0emOG0=cLg03Fe]H0fMWI0=CDe03Fe]H0eMGE0=;BdP3Cdm<0e]KF0=?Cd`020=GEe@04
0=?Cd`3EeMD0fm_K0=SHf080fMWI0P3Fe]H02P3Kfm/0emOG0=_Kf`3Ng]h0gMgM0=[JfP3Lg=`0hN7Q
0=[JfP3Ph>030=gMg@030=CDe038b<P0`/;200gooooo000@ooooo`0L04I6AP14A4@0@T920451@@0o
?cl0?3`l0410@014A4@0C4a<04U9B@1CDe<0D51@05eMG@1QHF40Ogmo08:2PP1eMGD0I6AT0820P01K
Fe/0A4A404I6AP13@d<0@4100492@P18B4P0M7Ad07alO080NWYj01l0I6AT071`L02<S8`0Ti>C09NG
U`2?Shl0TY:B09VIV@25QHD0J6QX06a/K01YJFT0QhN708F5Q@27QhL0PH6107EeM@1aLG40N7Qh0861
P@1`L700GEeM05]KF`1EEED0B4Q804I6AP0l?3`0C4a<05mOG`1^KVh0Lg=c0080I6AT01@0JFUY06YZ
JP1cLg<0JFUY06YZJP1^KVh0I6AT06=SH`1<C4`0FUYJ05MGE`1UIFD0GEeM065QH@1ADE40A4A40451
@@1ADE40GEeM05iNGP80Cdm?0180E5AD05mOG`1>CTh0G5aL079bLP1eMGD0L71`07emO@1/K6`0NGUi
07=cL`1mOGd0QXJ60820P01QHF40GemO06e]K@1bLW8206][J`0=05eMG@1DE5@0ADE50492@P17AdL0
@41003Xj>P0n?Sh0@41003dm?@0j>SX0>CTi03Ph>0020410@00N03dm?@13@d<0ATI604U9B@12@T80
?clo03Xj>P10@400?3`l04=3@`10@400@d=303lo?`0n?Sh0@d=30451@@1CDe<0D51@03/k>`18B4P0
BTY:04M7A`19BDT0B4Q8051@D01;Bd/0B4Q804M7A`1?Cdl0AdM70P15ADD09017AdL0@d=304U9B@1>
CTh0ADE504M7A`18B4P0ATI604A4A012@T80?Shn04U9B@1@D500ADE504];B`15ADD0D51@05EEE@1>
CTh0EUIF05aLG01GEeL0G5aL061PH01UIFD0Kfm_06a/K01WIfL0HF5Q06m_K`1mOGd0SXj>09JFUP2I
VIT0Ph>308j>SP80W9bL00`0S8b<08>3P`26QXH0N7Qh06YZJP1=CDd0BTY:06a/K02DU9@0Z:RX0::R
XP2SXj<209nOW`0Y0:JVYP2/[:`0^KVi0<S8b033`l<0bl_;0<c<c038b<P0bLW90<c<c03:b/X0d];B
0<30`03:b/X0c<c<0<O7a`3=cLd0_[jn0<g=c@35aLD0`<300<G5a@31`L40^k^k0;bl_02`/;00XJ6Q
09:BTP2WYjL0[Zj^0;^k^`39bLT0_kno0<C4a03=cLd0eMGE0<_;b`39bLT0alO70<c<c039bLT00P3<
c<`01P3>c/h0a/K60<71`@39bLT0^;Rh0<71`@80`<3001<0^[Zj0<71`@38b<P0alO70<C4a031`L40
a/K60;no_`32`/80aLG50<O7a`3@d=00b<S80<K6aP39bLT0aLG50<O7a`3>c/h0e]KF0080bl_;02L0
cLg=0<[:bP39bLT0bLW90<o?c`3;bl/0b/[:0<g=c@3@d=00dm?C0<k>cP3?cll0d=3@0<_;b`3@d=00
bl_;0=3@d03<c<`0aLG50=;BdP3>c/h0dm?C0=7Ad@3@d=00c/k>0<g=c@3De=@0c<c<0<k>cP3@d=00
d];B0<o?c`39bLT0b/[:0<_;b`31`L40`<300<71`@2o_kl00P35aLD20<30`0030;fm_@2h^;P0/;2`
0080[jn_00@0_;bl0<30`02i^KT0^KVi0P2h^;P02032`/80_[jn0;Fe]@2ZZZX0]kNg0<k>cP3AdM40
d];B0P3EeMD01P3Fe]H0e=CD0=CDe03Kfm/0dm?C0<_;b`80cLg=01P0aLG50<g=c@3AdM40d];B0;jn
_P34a<@0`l?30<K6aP37alL0/;2`09ZJVP2QXJ40Zj^[0;Ng]`36a/H0_Kfm0;no_`30`<00]KFe0;Jf
]P3<c<`0clo?0<g=c@3@d=030<O7a`070<30`034a<@0`L710<O7a`36a/H0_[jn0<?3``020<S8b004
0<G5a@38b<P0bl_;0=;BdP80cLg=0P3:b/X06P36a/H0alO70<71`@2m_Kd0][Jf0<G5a@32`/80b<S8
0<g=c@39bLT0^KVi0;Bd]02j^[X0bLW90<O7a`38b<P0b/[:0<S8b034a<@0_[jn0<S8b034a<@0`l?3
0<C4a038b<P0`/;20`35aLD04`37alL0b/[:0<o?c`3Bd]80e=CD0=KFeP3Lg=`0e=CD0=OGe`3MgMd0
eMGE0=OGe`3Hf=P0emOG0=cLg03Hf=P0emOG0=GEe@3De=@00P3Fe]H20=OGe`0C0=SHf03GemL0f][J
0=gMg@3IfMT0f=SH0=_Kf`3Hf=P0f][J0=_Kf`3Lg=`0h^;R0=_Kf`3Ogml0gMgM0=cLg03MgMd0g]kN
0=_Kf`020=[JfP040=WIf@30`<00RHV908R8R0gooooo000@ooooo`80ADE500T0A4A40492@P0n?Sh0
?Shn04A4A012@T80?clo0410@012@T800P19BDT02@1:BTX0CTi>04m?C`1@D500Bd];051@D013@d<0
@41003lo?`0303hn?P0I03/k>`1@D500D51@05=CD`1HF5P0BTY:061PH026QXH0TI6A08Z:RP2BTY80
WinO0:2PX02>SXh0Ng]k06YZJP1NGUh0NGUi08N7Q`2;Rh/0TY:B096AT@2>SXh0Rh^;09>CT`0209jN
WP0609>CT`27QhL0MgMg071`L01MGEd0K6a/0P28R8P03`2?Shl0U9BD09jNWP2DU9@0LG5a06e]K@1M
GEd0IFEU08:2PP1jNWX0LW9b06UYJ@1/K6`0L71`07UiN@0207YjNP0>06QXJ01JFUX0FUYJ06][J`1c
Lg<0JFUY06YZJP1`L700HF5Q05UIF@1EEED0M7Ad08b<S02ATI4209BDU00Y08n?S`2;Rh/0TY:B09RH
V02KVi/0QHF505aLG01=CDd0EeMG06MWI`1QHF40GUiN05EEE@12@T80?Shn03lo?`12@T80?Shn03Xj
>P11@D40?clo04A4A011@D40?Cdm03lo?`10@400?clo03/k>`10@400?clo03hn?P10@400Bd];04Q8
B01;Bd/0A4A404M7A`14A4@0ATI60410@014A4@00P1=CDd0901DE5@0D51@04U9B@1CDe<0EEEE05]K
F`1TI6@0Hf=S06i^KP1cLg<0IVIV065QH@1WIfL0GUiN05=CD`1DE5@0D51@059BDP1RHV80KFe]06QX
J01LG5`0HF5Q04i>CP1;Bd/0ATI604E5A@1VIVH0MGEe07MgM`1iNGT0MgMg07emO@23Ph<0RHV9096A
T@80U9BD01h0UYJF09BDU02DU9@0V9RH09>CT`2DU9@0Shn?09NGU`2MWId0Xj>S0:ZZZP2][Jd0Y:BT
0:JVYP2/[:`0XJ6Q09ZJVP2GUiL0Xj>S09fMW@2KVi/0T92@08^;R`2EUID0Y:BT0;Bd]02k^k/0^[Zj
0;jn_P30`<020<O7a`040<_;b`3Bd]80e]KF0=KFeP80dM7A0180clo?0<c<c036a/H0cLg=0<W9b@3@
d=00d];B0=3@d03Bd]80cLg=0<k>cP3?cll0c<c<0<o?c`3@d=00bLW90<G5a@2b/[830:j^[P0509JF
UP2ATI40_Kfm0;Zj^P32`/800P3>c/h04@39bLT0a/K60<71`@30`<00`L710<O7a`35aLD0bl_;0<K6
aP37alL0`l?30;Vi^@31`L40`/;20<G5a@2m_Kd0`L7100<0`l?300T0`L710<K6aP38b<P0a<C40<W9
b@3=cLd0dM7A0=GEe@3=cLd00`3>c/h01P3AdM40clo?0<O7a`3=cLd0c/k>0<S8b080bLW901<0emOG
0<o?c`3Cdm<0dm?C0=3@d03AdM40bl_;0<c<c03AdM40cLg=0<o?c`3Bd]80dM7A0<g=c@3<c<`0clo?
0<k>cP3Bd]80clo?0080d];B00D0clo?0=3@d03<c<`0dM7A0<c<c0020<o?c`0N0<c<c03?cll0b<S8
0;Jf]P2i^KT0a<C40<c<c03=cLd0alO70<C4a031`L40][Jf0;Bd]02f][H0/k>c0:j^[P2d];@0aLG5
0;no_`2h^;P0^KVi0;Bd]030`<00`L710;Ng]`2[Zj/0]kNg0=7Ad@3Cdm<0dM7A0P3Cdm<07@3Fe]H0
f=SH0=GEe@3IfMT0d];B0<k>cP3?cll0dM7A0<c<c03?cll0eMGE0<W9b@2j^[X0bLW90<g=c@32`/80
b/[:0<71`@2b/[80[jn_0;>c/`2e]KD0b/[:0<O7a`35aLD0a<C40;fm_@2h^;P0c/k>0080dM7A00/0
d];B0<c<c03=cLd0b/[:0;Fe]@2l_;`0`/;20<c<c03;bl/0b<S80<_;b`020<c<c00K0<[:bP39bLT0
clo?0=CDe03?cll0dM7A0<[:bP3<c<`0aLG50<_;b`34a<@0`l?30;no_`35aLD0a<C40<[:bP3=cLd0
c/k>0<O7a`38b<P0a/K60<_;b`3<c<`0aLG50<S8b037alL0a/K60080aLG500@0a<C40<G5a@35aLD0
b/[:0P35aLD02@3:b/X0c<c<0<k>cP3Cdm<0dM7A0=;BdP3De=@0fm_K0=WIf@020=?Cd`0E0=SHf03>
c/h0e=CD0=KFeP3GemL0fm_K0=OGe`3Fe]H0e=CD0=GEe@3Fe]H0d=3@0=?Cd`3Bd]80e=CD0=OGe`3J
f]X0g=cL0=[JfP3GemL0f][J0080fm_K00@0f][J0=oOg`3Shn<0gMgM0P3Lg=`02P3MgMd0hN7Q0=cL
g03IfMT0f][J0=SHf03Fe]H0^KVi06a/K01dM7@=ooooo`004?ooool01017AdL0ATI604A4A014A4@2
04=3@`0:04Q8B015ADD0BDU905=CD`1:BTX0B4Q804A4A012@T80A4A40410@080?clo00d0?Shn0492
@P10@400?Cdm03lo?`11@D40?Cdm03hn?P10@400@D510492@P1?Cdl0HV9R0080JVYZ00d0MWIf065Q
H@1UIFD0IFEU06MWI`1LG5`0EUIF05EEE@1LG5`0HV9R075aL@1_Kfl0KFe]0080LW9b00/0KFe]07Mg
M`22PX80R8R807moO`1_Kfl0IFEU06=SH`1LG5`0EeMG069RHP0206=SH`0Q06i^KP1iNGT0KFe]04i>
CP14A4@0@d=304Y:BP1FEUH0E5AD05QHF01WIfL0IVIV06m_K`1aLG40OWin07alO01dM7@0KVi^079b
LP1hN7P0OGem07alO01iNGT0NWYj07AdM01TI6@0KFe]07alO021PH40Rh^;09:BTP21PH40Lg=c0080
KVi^00X0L71`07]kN`1aLG40EUIF04E5A@16ATH0Cdm?04a<C016ATH0B4Q80`0o?cl01012@T80ATI6
04a<C01EEED205MGE`0304m?C`1:BTX0ATI60080@d=300@0A4A404U9B@1:BTX0CDe=0P1JFUX01@1G
EeL0FEUI05mOG`1EEED0CDe=0080A4A400T0E5AD06=SH`1SHf<0IfMW06e]K@1mOGd0RXZ:09NGU`2I
VIT00P2LW9`00`2TY:@0Xj>S0::RXP0208b<S00408Z:RP2>SXh0UiNG09JFUP80TY:B02`0QXJ608R8
R022PX80SHf=08J6QP20P800IVIV05mOG`2@T900WinO0:>SX`2TY:@0ZZZZ0:BTY02PX:00YjNW0:ZZ
ZP2^[Zh0/;2`0;>c/`2`/;00[jn_0:RXZ02d];@0_kno0;^k^`2l_;`0a<C40<K6aP39bLT0d=3@0<g=
c@3;bl/0dM7A0<o?c`3=cLd0c/k>0<_;b`3<c<`0`/;20;Zj^P2ZZZX0/k>c0<;2`P80c/k>00L0b<S8
0<k>cP3>c/h0clo?0<S8b03>c/h0e=CD0080dM7A00d0d];B0=?Cd`3AdM40clo?0<k>cP3;bl/0clo?
0=;BdP3EeMD0dm?C0<o?c`3AdM40d=3@0080clo?01P0c/k>0=3@d03?cll0e=CD0=?Cd`3AdM40c<c<
0<O7a`2`/;00ZZZZ0<W9b@38b<P0b/[:0<K6aP37alL0`l?30<30`033`l<0`<300;fm_@2o_kl0a/K6
0<W9b@37alL20<W9b@050;no_`34a<@0alO70<S8b036a/H00P33`l<06035aLD0alO70<S8b033`l<0
a<C40<W9b@3<c<`0cLg=0<o?c`3De=@0c<c<0<_;b`37alL0cLg=0=;BdP3AdM40b<S80<k>cP3@d=00
cLg=0<o?c`39bLT0c/k>0<S8b080cLg=00H0b/[:0<o?c`3AdM40clo?0=3@d03AdM420=;BdP0<0=3@
d03?cll0c/k>0<_;b`3Bd]80cLg=0<c<c03Bd]80d=3@0<k>cP3@d=00b<S80`3<c<`20<o?c`040=3@
d03<c<`0aLG50;fm_@80a<C401/0clo?0=;BdP3:b/X0bLW90;no_`33`l<0^KVi0;:b/P2_[jl0]kNg
0<;2`P2i^KT0/k>c0;Vi^@2k^k/0_kno0;jn_P30`<00][Jf0;Vi^@3>c/h0dM7A0=?Cd`3GemL0eMGE
0=OGe`3IfMT00P3Jf]X04P3De=@0d];B0<k>cP3De=@0eMGE0=3@d03AdM40b/[:0<c<c03AdM40a/K6
0;^k^`35aLD0cLg=0<W9b@2j^[X0`L710;Ng]`80aLG500l0a/K60<S8b035aLD0`/;20<[:bP3AdM40
dm?C0<k>cP3:b/X0bl_;0<W9b@2l_;`0`<300<_;b`3Bd]800P3:b/X04`3>c/h0eMGE0=?Cd`3Bd]80
b/[:0=;BdP3AdM40bl_;0<o?c`39bLT0clo?0<c<c03;bl/0alO70<C4a037alL0c/k>0<c<c036a/H0
0P3Bd]803@3@d=00bl_;0<o?c`3:b/X0dM7A0<O7a`3=cLd0bl_;0<c<c039bLT0c<c<0=7Ad@3EeMD0
0P3Cdm<02@3>c/h0clo?0<k>cP3Bd]80eMGE0=cLg03IfMT0eMGE0=7Ad@020=KFeP040=GEe@3IfMT0
e]KF0=3@d080eMGE00h0emOG0=SHf03IfMT0f][J0=OGe`3EeMD0e]KF0=GEe@3Cdm<0eMGE0=OGe`3K
fm/0f][J0=cLg080gMgM00`0fm_K0=OGe`3Kfm/0fMWI0=_Kf`3Jf]X0f=SH0=oOg`3Lg=`0f][J0=_K
f`3IfMT20=[JfP050=KFeP3GemL0];Bd07QhN01cLg<03Oooool0013ooooo0140BDU904I6AP17AdL0
B4Q803hn?P0o?cl0@d=304A4A010@400@d=304I6AP12@T80ADE504Q8B013@d<0?clo03hn?P0203/k
>`0403lo?`14A4@0?3`l03lo?`80?Shn0P10@4001P13@d<0A4A404Q8B01<C4`0BDU904E5A@80@d=3
01/0@4100492@P1UIFD0HF5Q03/k>`10@400Cdm?059BDP1=CDd0BDU90451@@1CDe<0GemO06=SH`1R
HV80Jf][065QH@1PH600CTi>04I6AP1:BTX0DE5A04=3@`12@T80?Shn0410@00l?3`00P10@4000`0o
?cl0@41004=3@`0303dm?@060410@018B4P0@d=30492@P13@d<0B4Q80`17AdL0>01<C4`0EeMG059B
DP1BDU80DE5A04a<C019BDT0AdM704a<C01ADE40De=C05EEE@1QHF40IVIV05ADE01QHF40GUiN061P
H01LG5`0E5AD04];B`15ADD0@d=304E5A@14A4@0?clo0451@@0n?Sh0@D5104];B`1TI6@0LG5a07]k
N`1oOgl0PH610820P01iNGT0O7al07EeM@1jNWX0O7al0861P@25QHD0RHV9096AT@2>SXh0QHF508Z:
RP2;Rh/0QHF507EeM@1NGUh0Cdm?07IfMP2IVIT0ZZZZ0P2][Jd0702WYjL0[Zj^0:j^[P2b/[80/K6a
0:n_[`2a/K40];Bd0;>c/`2^[Zh0U9BD08N7Q`2?Shl0X:2P09nOW`2_[jl0_kno0<[:bP36a/H0`l?3
0;6a/@2OWil0X:2P0:ZZZP2QXJ40ZJVY0;jn_P33`l<20<O7a`0@0<30`02h^;P0];Bd0;Fe]@2h^;P0
_;bl0<;2`P35aLD0][Jf0<30`02l_;`0bLW90=?Cd`3@d=00dM7A0=3@d0<0c<c<00d0c/k>0<g=c@3@
d=00clo?0<g=c@3?cll0aLG50;jn_P2e]KD0_[jn0;fm_@32`/80alO70080b/[:01H0alO70<W9b@3=
cLd0bLW90<g=c@3Bd]80c<c<0<g=c@3>c/h0d];B0=?Cd`3?cll0c/k>0<g=c@3<c<`0a<C40<k>cP3D
e=@0d=3@0<c<c03Cdm<0cLg=0P3Bd]801`3@d=00d];B0=WIf@3Cdm<0e]KF0=WIf@3De=@00P3Cdm<0
6P34a<@0`/;20<[:bP3<c<`0aLG50;fm_@2o_kl0^[Zj0<30`02k^k/0/k>c0;Fe]@32`/80a<C40<K6
aP34a<@0`L710<G5a@37alL0aLG50<O7a`34a<@0alO70<30`034a<@0alO70P38b<P03P39bLT0bl_;
0=7Ad@3>c/h0d];B0<S8b037alL0b<S80<;2`P3;bl/0c/k>0=3@d03<c<`0c/k>0P3<c<`01@3;bl/0
b/[:0<k>cP3AdM40clo?0080bl_;00<0cLg=0=;BdP3>c/h00P3?cll01@3>c/h0d];B0=;BdP3>c/h0
c<c<0080clo?0`3>c/h01P3=cLd0dM7A0<[:bP37alL0b/[:0<c<c080clo?0P3:b/X01@3?cll0a/K6
0<W9b@3;bl/0aLG50080b/[:00h0cLg=0<o?c`3=cLd0bLW90<G5a@2o_kl0_;bl0;Zj^P36a/H0`l?3
0<71`@33`l<0a<C40<O7a`80aLG500T0`L710;jn_P3De=@0f=SH0=WIf@3Jf]X0f=SH0=[JfP3Kfm/0
0P3Jf]X00`3Hf=P0e=CD0=3@d0020=?Cd`80dM7A00h0dm?C0=;BdP3:b/X0`/;20;jn_P3;bl/0dM7A
0<o?c`3:b/X0bLW90;^k^`37alL0clo?0<c<c080b<S801h0b/[:0<g=c@3AdM40b/[:0<g=c@3>c/h0
d=3@0<g=c@30`<00bLW90<o?c`3Cdm<0d=3@0<g=c@3AdM40fMWI0=SHf03Cdm<0bl_;0=?Cd`3De=@0
dM7A0=GEe@3Bd]80dm?C0=GEe@3De=@0eMGE0=7Ad@3Cdm<20=CDe0050<o?c`3Hf=P0`/;20<[:bP3G
emL00P3De=@01`3GemL0f=SH0=KFeP3Cdm<0emOG0=_Kf`3Hf=P00P3IfMT00`3GemL0e]KF0=SHf002
0=[JfP0F0=WIf@3MgMd0f][J0=WIf@3AdM40e]KF0=CDe03Bd]80e=CD0=gMg@3GemL0dm?C0=KFeP3G
emL0f=SH0=OGe`3IfMT0fm_K0=WIf@3Kfm/0f=SH0=KFeP80fMWI0P3GemL0103EeMD0emOG0=OGe`3J
f]X20=SHf00<0=[JfP3EeMD0e]KF0=WIf@3Jf]X0gmoO0=gMg@3Lg=`0f][J0=gMg@3Kfm/0fMWI0P3H
f=P00`2b/[80IFEU04U9B@0=ooooo`004?ooool03017AdL0B4Q804Q8B017AdL0ADE504A4A011@D40
@4100451@@0o?cl0@d=303hn?P80ADE500l0@D510492@P12@T80@41003hn?P0o?cl0@D510492@P18
B4P0?clo0410@013@d<0BDU904=3@`0o?cl00P10@4000`0o?cl0?Cdm03/k>`0203hn?P0303/k>`13
@d<0BDU90080@41000d0@T920410@00n?Sh0@T9204A4A01FEUH0FEUI05IFEP1<C4`0EEEE04Q8B01B
DU80BTY:0080B4Q801H0A4A40451@@0l?3`0?Shn0492@P0k>c/0@D5103dm?@0k>c/0?Cdm0451@@0m
?Cd0@41003lo?`0n?Sh0@T9203hn?P12@T80?3`l0410@012@T80ADE50P19BDT04P1NGUh0EeMG05eM
G@1YJFT0KFe]079bLP1aLG40Kfm_06YZJP1cLg<0K6a/07IfMP1iNGT0L71`061PH01KFe/0GEeM05UI
F@80GUiN02<0De=C0492@P1ADE40GemO04i>CP1IFET0LW9b0861P@2HV9P0Y:BT0;2`/02k^k/0^;Rh
0;>c/`2WYjL0[:b/0:ZZZP2][Jd0[:b/0;:b/P2_[jl0/;2`0;>c/`2m_Kd0^[Zj0;^k^`2f][H0]kNg
0;^k^`2ZZZX0Ng]k079bLP2XZ:P0a/K60<[:bP020<;2`P110;jn_P35aLD0bLW90<O7a`39bLT0alO7
0<g=c@3<c<`0alO70<S8b03:b/X0`L710<K6aP3?cll0b/[:0=7Ad@3De=@0eMGE0<c<c03AdM40bl_;
0<c<c038b<P0^;Rh0:^[Z`2RXZ80WIfM0;^k^`3@d=00d];B0<;2`P2a/K40[Jf]0:ZZZP2YZJT0/;2`
0;Zj^P35aLD0`<300<S8b03Bd]80cLg=0=KFeP3@d=00dM7A0<g=c@3>c/h0cLg=0<[:bP3=cLd0bLW9
0<S8b03<c<`0a/K60<o?c`3:b/X0`<300;jn_P33`l<0bLW90<S8b03;bl/0bLW90<G5a@38b<P00P3=
cLd01`36a/H0c<c<0<c<c03AdM40clo?0=?Cd`3@d=000P3EeMD0103@d=00c/k>0=;BdP3?cll40<g=
c@0N0=3@d03?cll0e]KF0=?Cd`3Bd]80e]KF0=OGe`3Bd]80eMGE0=3@d02n_[h0bLW90=3@d03;bl/0
aLG50<?3``30`<00^;Rh0;Bd]02f][H0_;bl0;Zj^P2d];@0]KFe0;Rh^02c/k<0^KVi0;fm_@38b<P0
b/[:0P3;bl/04P36a/H0alO70<;2`P3:b/X0bLW90<G5a@37alL0c<c<0<K6aP34a<@0b<S80<[:bP3@
d=00c<c<0<_;b`36a/H0`l?30<G5a@<0cLg=0P3;bl/01P3:b/X0c<c<0<_;b`3=cLd0dM7A0=?Cd`80
c<c<00H0cLg=0<S8b03AdM40c<c<0<o?c`3AdM420=?Cd`0A0=;BdP3=cLd0bl_;0<k>cP3<c<`0c/k>
0<_;b`38b<P0c<c<0<g=c@3<c<`0b<S80<W9b@3;bl/0cLg=0<k>cP3=cLd00P3?cll01P3;bl/0b/[:
0<c<c03@d=00clo?0<O7a`80cLg=00X0clo?0=3@d03@d=00alO70=3@d03?cll0e=CD0<_;b`3:b/X0
`L710P38b<P01@2n_[h0^[Zj0<?3``31`L40d];B0080eMGE00/0e=CD0=?Cd`3Hf=P0f][J0=SHf03F
e]H0eMGE0=?Cd`3AdM40d=3@0=KFeP020=7Ad@060<o?c`37alL0][Jf0;Fe]@2j^[X0c<c<0P3?cll0
4@38b<P0c<c<0;bl_036a/H0dM7A0=3@d039bLT0`l?30:JVYP2QXJ40WIfM0:2PX02f][H0c/k>0=?C
d`3GemL0dM7A0080eMGE0P3GemL0103EeMD0fMWI0=[JfP3IfMT20=OGe`0;0=WIf@3Hf=P0dm?C0=GE
e@3Jf]X0fMWI0=[JfP3IfMT0emOG0=?Cd`3Bd]800P3GemL20=GEe@070=;BdP3EeMD0fm_K0=OGe`3L
g=`0fMWI0=[JfP020=WIf@050=[JfP3Lg=`0g=cL0=WIf@3Hf=P00P3GemL03P3IfMT0f=SH0=[JfP3E
eMD0f][J0=kNgP3Hf=P0e]KF0=SHf03GemL0e=CD0=[JfP3Rh^80e]KF0P3EeMD03@3IfMT0fm_K0=WI
f@3Jf]X0gMgM0=[JfP3MgMd0f=SH0=KFeP3MgMd0fMWI0=gMg@3Hf=P00P3IfMT02`3EeMD0f=SH0=_K
f`3Ng]h0fMWI0=cLg03Jf]X0g=cL0=kNgP3Kfm/0f][J0080h>3P00P0g=cL0=_Kf`3IfMT0f=SH0=?C
d`2NWYh0De=C055AD@gooooo000@ooooo`0404E5A@16ATH0@d=304E5A@80Bd];00X0@T920451@@12
@T80A4A404M7A`12@T80@d=304Y:BP19BDT0ATI60P12@T800`10@400?clo0410@00204=3@`0603hn
?P14A4@0B4Q804];B`13@d<0?Cdm0`0o?cl06P11@D40?Shn03`l?010@400A4A40410@014A4@0@D51
0410@019BDT0DE5A05=CD`1=CDd0C4a<05]KF`1_Kfl0EUIF055AD@1CDe<0CTi>05IFEP1@D500CDe=
04E5A@12@T80@4100P11@D401P10@400@D5103`l?015ADD0AdM70410@080B4Q800l0BTY:04e=C@1>
CTh0BDU904e=C@17AdL0@41005IFEP1UIFD0KFe]07IfMP22PX80U9BD09FEU@2LW9`00P2KVi/06P2O
Wil0WIfM09jNWP2MWId0WinO0:>SX`2a/K40[Jf]0:j^[P2ZZZX0WinO08j>SP21PH40QHF508>3P`1Z
JVX0De=C07moO`2YZJT0Vi^K0;2`/02j^[X0^k^k0<30`035aLD0c/k>0P3<c<`20<_;b`0:0<g=c@34
a<@0_kno0;no_`2j^[X0][Jf0;6a/@2h^;P0`/;20;no_`80`l?300L0`<300<G5a@36a/H0]KFe0:VY
Z@2m_Kd0b<S80080c/k>0P3GemL03`3IfMT0emOG0=KFeP3Hf=P0e]KF0<o?c`3Cdm<0e=CD0=7Ad@3?
cll0cLg=0=3@d03=cLd0c/k>0<o?c`020=7Ad@80c/k>02H0bl_;0=3@d03De=@0e]KF0=WIf@39bLT0
X:2P0;>c/`3<c<`0dM7A0<k>cP2g]kL0YZJV0:j^[P2b/[80^[Zj0<;2`P34a<@0bl_;0<W9b@3?cll0
c/k>0=?Cd`39bLT0d];B0=3@d03>c/h0c<c<0<[:bP3;bl/0a/K60<G5a@34a<@0aLG50<S8b03;bl/0
bLW90<k>cP80clo?00`0c/k>0<[:bP39bLT0bl_;0<[:bP3=cLd0c<c<0<_;b`3>c/h0dM7A0=;BdP3C
dm<20=KFeP0>0=?Cd`3?cll0c/k>0<_;b`3<c<`0d=3@0=7Ad@3@d=00dM7A0=?Cd`3AdM40d];B0=KF
eP3Cdm<20=CDe00A0=7Ad@39bLT0bl_;0=?Cd`32`/80alO70<[:bP38b<P0c/k>0<G5a@33`l<0/k>c
0;6a/@2b/[80]kNg0;Vi^@2j^[X00P2m_Kd08P2d];@0_Kfm0;no_`37alL0b<S80<C4a039bLT0alO7
0<S8b034a<@0cLg=0<S8b037alL0bLW90<g=c@36a/H0aLG50<K6aP37alL0bl_;0<O7a`39bLT0aLG5
0<O7a`39bLT0b/[:0<K6aP3AdM40a/K60<W9b@3@d=00cLg=0<W9b@3@d=030<k>cP0:0<g=c@39bLT0
bl_;0<o?c`3<c<`0c/k>0<g=c@3?cll0c/k>0<g=c@80c<c<00T0cLg=0<O7a`3:b/X0alO70<W9b@3;
bl/0c<c<0<g=c@38b<P00`3;bl/0303<c<`0d];B0=CDe03?cll0b<S80<O7a`38b<P0a/K60<C4a036
a/H0clo?0<[:bP80c/k>0180d=3@0<k>cP3De=@0clo?0=KFeP3Bd]80c/k>0<S8b03:b/X0bl_;0<C4
a035aLD0cLg=0<[:bP3Fe]H0f][J0=OGe`3IfMT20=OGe`0?0=SHf03Jf]X0fMWI0=KFeP3EeMD0dm?C
0<_;b`3Cdm<0dM7A0=;BdP3AdM40c/k>0<?3``37alL0d=3@0080d];B0180fMWI0=OGe`3Kfm/0dM7A
0=;BdP3Fe]H0f=SH0=WIf@32`/80M7Ad05YJFP1SHf<0KFe]09jNWP3EeMD0fMWI0>3Ph03Hf=P20=WI
f@030=cLg03Kfm/0fMWI0080f][J00@0fm_K0=cLg03MgMd0gMgM0`3Ng]h02`3Ogml0fMWI0=_Kf`3I
fMT0emOG0=GEe@3GemL0f][J0=SHf03IfMT0eMGE0080f=SH00@0h>3P0=[JfP3MgMd0fMWI0`3Kfm/0
403Jf]X0fMWI0=_Kf`3Hf=P0emOG0=WIf@3Lg=`0f=SH0=CDe03EeMD0e]KF0=WIf@3Lg=`0e]KF0=OG
e`3Jf]X20=gMg@050>;RhP3Xj>P0emOG0=_Kf`3Jf]X00P3Lg=`0503GemL0fMWI0=gMg@3Jf]X0fm_K
0=[JfP3Ng]h0gMgM0=WIf@3Ogml0e]KF0=WIf@3Fe]H0f=SH0=[JfP3Hf=P0fMWI0=_Kf`3Lg=`0f=SH
0P3Jf]X0103MgMd0f][J0=oOg`3Ogml20=_Kf`060=WIf@3GemL0dM7A08n?S`16ATH0FEUI3Oooool0
013ooooo0P18B4P01@17AdL0ATI604M7A`15ADD0@d=30080ADE500P0@D510410@013@d<0@D5104=3
@`0o?cl0@T920451@@<0@41000<0?Shn0410@013@d<00P10@4002@11@D40@T920451@@10@400@d=3
04I6AP14A4@0@D5103lo?`020492@P0_04A4A019BDT0D51@04I6AP13@d<0B4Q804I6AP18B4P0Cdm?
05=CD`1XJ6P0HF5Q04Q8B017AdL0Cdm?04E5A@1=CDd0De=C065QH@1SHf<0E5AD04Y:BP16ATH0DE5A
05mOG`1[Jf/0M7Ad06m_K`1bLW80MWIf0820P023Ph<0Q8B40861P@24Q8@0OWin06i^KP1<C4`0D51@
09>CT`2/[:`0[Jf]0;6a/@2`/;00/[:b0;Ng]`2h^;P00P2e]KD04`2i^KT0^[Zj0;bl_031`L40a<C4
0<K6aP38b<P0`l?30<K6aP3?cll0e]KF0=7Ad@3<c<`0^[Zj09fMW@2NWYh0][Jf0<C4a03IfMT00P3K
fm/01@3IfMT0fm_K0=SHf03Ng]h0h>3P0080h^;R02H0hN7Q0>CTi03Ng]h0eMGE0<g=c@3?cll0`/;2
0<K6aP31`L40`l?30<W9b@38b<P0c<c<0<k>cP38b<P0alO70<S8b02k^k/0^KVi0<O7a`3<c<`0d=3@
0=7Ad@3De=@0cLg=0<k>cP38b<P0bl_;0<c<c036a/H0]kNg0<O7a`33`l<0a/K60;^k^`34a<@0bl_;
0<;2`P80_kno01L0`/;20<30`030`<00a<C40<O7a`3;bl/0cLg=0=OGe`3IfMT0fm_K0=;BdP3>c/h0
dm?C0<o?c`3@d=00_Kfm0;6a/@2b/[80]kNg0;Zj^P2i^KT0a/K60<_;b`020=7Ad@050<k>cP3=cLd0
c<c<0<[:bP39bLT00P3>c/h0203<c<`0`l?30;jn_P31`L40_Kfm0<71`@32`/80alO70P3<c<`20<[:
bP030<_;b`33`l<0a<C40080alO700@0aLG50<O7a`3<c<`0clo?0`3Bd]80103AdM40dm?C0<_;b`3<
c<`20=7Ad@80c<c<0180c/k>0=3@d03De=@0dM7A0=3@d03Bd]80clo?0<[:bP36a/H0c<c<0=3@d038
b<P0b/[:0=3@d037alL0b/[:0<c<c03;bl/20<k>cP080<O7a`33`l<0_kno0;Rh^02g]kL0^k^k0;jn
_P2o_kl20;jn_P060<71`@30`<00a/K60<[:bP33`l<0b/[:0P3;bl/0203:b/X0c<c<0<S8b03;bl/0
c<c<0<[:bP39bLT0b/[:0`37alL01P36a/H0alO70<S8b037alL0b/[:0<k>cP80clo?00L0cLg=0<k>
cP3AdM40emOG0<c<c03Cdm<0clo?0080c/k>00<0c<c<0<_;b`3>c/h00`3=cLd03`3<c<`0clo?0<k>
cP3@d=00dM7A0=3@d03AdM40c<c<0<_;b`39bLT0dM7A0<[:bP3>c/h0d=3@0<_;b`020<[:bP090=7A
d@3@d=00dm?C0=GEe@3Bd]80clo?0<c<c03?cll0bLW90080b/[:00T0clo?0<W9b@3>c/h0c<c<0=3@
d03AdM40emOG0=CDe03Fe]H00P3@d=000`3Cdm<0dM7A0=KFeP020=?Cd`0B0=3@d03:b/X0d];B0=OG
e`3@d=00e=CD0=SHf03IfMT0g=cL0=oOg`3Kfm/0f][J0=WIf@3Jf]X0emOG0=GEe@3Jf]X0gMgM0P3R
h^80803Kfm/0g]kN0=oOg`3Ng]h0g=cL0>3Ph03Lg=`0gMgM0=_Kf`3Ng]h0fMWI0=KFeP3Kfm/0`L71
07AdM01KFe/0EeMG05iNGP2TY:@0g=cL0>3Ph03Ogml0gMgM0=cLg03IfMT0f][J0=WIf@3Hf=P0fMWI
0=_Kf`3Lg=`0fm_K0P3IfMT0103Lg=`0fm_K0=CDe03Kfm/30=SHf00@0=KFeP3De=@0e]KF0=[JfP3E
eMD0dm?C0=GEe@3GemL0f=SH0=_Kf`3Fe]H0fMWI0=GEe@3Hf=P0f][J0=SHf080emOG01L0fm_K0=SH
f03Fe]H0eMGE0=OGe`3Fe]H0eMGE0=SHf03Fe]H0eMGE0=SHf03Jf]X0eMGE0=SHf03Lg=`0gmoO0=kN
gP3Ti>@0f=SH0=OGe`3EeMD0e]KF0=[JfP020=cLg0060=_Kf`3Hf=P0f][J0=_Kf`3Ng]h0fm_K0P3H
f=P20=WIf@80e]KF00<0f][J0=SHf03Bd]800P3GemL0103Fe]H0fm_K0=_Kf`3Ng]h30=cLg0080=WI
f@3Jf]X0f=SH0=GEe@3AdM40SXj>06][J`1nOWh=ooooo`004?ooool0401=CDd0FUYJ05ADE016ATH0
ADE50451@@15ADD0Bd];04a<C016ATH0C4a<04I6AP14A4@0ATI60451@@15ADD20492@P80@41000@0
@D5104A4A017AdL0B4Q80P13@d<01`16ATH0AdM704M7A`1>CTh0CDe=055AD@1;Bd/00P1>CTh205IF
EP0I05=CD`1>CTh0DU9B055AD@1NGUh0LG5a07=cL`1aLG40M7Ad07moO`1MGEd0B4Q806e]K@2?Shl0
Q8B408j>SP2BTY80X:2P0:j^[P2QXJ40UiNG09BDU02QXJ40ZZZZ0;>c/`020;Vi^@030;Ng]`2h^;P0
_[jn0080_[jn00L0_;bl0<;2`P30`<00/;2`08J6QP23Ph<0a/K60080c<c<0140c/k>0<o?c`3?cll0
eMGE0=CDe03GemL0clo?0<[:bP3Cdm<0e=CD0=3@d03EeMD0f=SH0=OGe`3MgMd0f][J0=gMg@020>;R
hP090>?Sh`3Ogml0e=CD0<;2`P3:b/X0c/k>0=oOg`3Xj>P0i>CT00<0hn?S01L0h^;R0>KViP3Vi^H0
h^;R0>OWi`3QhN40g]kN0=GEe@3GemL0cLg=0<?3``36a/H0_;bl0;:b/P2i^KT0_kno0<G5a@3>c/h0
cLg=0<c<c036a/H0^;Rh0<S8b0020<W9b@0>0<[:bP30`<00a<C40;no_`2j^[X0^KVi0;fm_@2k^k/0
_[jn0;^k^`33`l<0b/[:0<W9b@35aLD20<_;b`050<C4a037alL0bLW90<O7a`35aLD00P37alL01P36
a/H0bl_;0=3@d03IfMT0clo?0=OGe`<0e]KF0100clo?0=3@d036a/H0_[jn0;^k^`2j^[X0`L710;Zj
^P34a<@0cLg=0=GEe@3Bd]80e]KF0=7Ad@3<c<`0c/k>0P3<c<`03@3?cll0c/k>0<S8b031`L40`<30
0<G5a@33`l<0`/;20<K6aP3;bl/0cLg=0=7Ad@3>c/h00P38b<P04`32`/80`l?30<g=c@34a<@0b/[:
0<k>cP3?cll0c<c<0=;BdP3Fe]H0eMGE0=?Cd`3AdM40d=3@0<g=c@3?cll0c/k>0<[:bP3?cll00P3<
c<`04`3;bl/0d];B0=7Ad@38b<P0bLW90<_;b`3Bd]80e=CD0<k>cP3;bl/0c<c<0<O7a`3<c<`0c/k>
0<c<c038b<P0bLW90<c<c03>c/h00P36a/H02`32`/80aLG50<O7a`32`/80^k^k0;fm_@31`L40b/[:
0<S8b03>c/h0b/[:0080clo?01T0c<c<0<g=c@3=cLd0clo?0<c<c035aLD0a<C40<W9b@34a<@0`L71
0<?3``3:b/X0bLW90<c<c03=cLd0b/[:0<o?c`3AdM40d=3@0=?Cd`3>c/h0d];B0=OGe`3EeMD0bl_;
0080b/[:00<0a/K60<;2`P38b<P00P3?cll02@3=cLd0d=3@0=3@d03Bd]80clo?0=3@d03?cll0cLg=
0<c<c0020<k>cP050<_;b`3<c<`0dm?C0<_;b`3>c/h00P3<c<`01P3=cLd0dM7A0=;BdP3Cdm<0e]KF
0=7Ad@80d=3@00P0c/k>0=3@d03?cll0dM7A0<o?c`3@d=00dM7A0=CDe080cLg=00@0dM7A0=?Cd`3F
e]H0f=SH0P3Bd]802`3AdM40f=SH0=SHf03Bd]80cLg=0<c<c03:b/X0cLg=0=7Ad@3Bd]80e=CD0080
f=SH0200e]KF0=_Kf`3IfMT0f=SH0=_Kf`3IfMT0f=SH0=GEe@3Lg=`0h>3P0>7Qh@3Ogml0g]kN0>7Q
h@3Ti>@0gmoO0=cLg03Rh^80hN7Q0=cLg03IfMT0gMgM0=[JfP3GemL0f=SH0<;2`P1]KFd0BTY:055A
D@1XJ6P0[Zj^0=oOg`80h>3P0140gmoO0=cLg03GemL0gMgM0=_Kf`3IfMT0f=SH0=_Kf`3Jf]X0g]kN
0=WIf@3Jf]X0fm_K0=oOg`3Jf]X0f=SH0=[JfP020=SHf00C0=KFeP3Cdm<0dM7A0=KFeP3Bd]80c/k>
0=;BdP3@d=00dM7A0=;BdP3Cdm<0eMGE0=SHf03GemL0fMWI0=SHf03Fe]H0f=SH0=KFeP030=OGe`80
e=CD00<0f=SH0=[JfP3Jf]X00P3GemL0103Fe]H0eMGE0=OGe`3Fe]H20=GEe@0:0=kNgP3MgMd0gmoO
0=gMg@3IfMT0f][J0=cLg03MgMd0g]kN0=_Kf`80f][J00<0g=cL0=WIf@3IfMT00P3Cdm<20=KFeP0@
0=GEe@3GemL0eMGE0=GEe@3Fe]H0dm?C0=OGe`3Ogml0g]kN0=[JfP3Ng]h0f=SH0=_Kf`3EeMD0f][J
0=GEe@80dM7A00<0a/K60<W9b@3=cLd03Oooool0013ooooo00H0EEEE069RHP1PH600E5AD04];B`1F
EUH205YJFP0705mOG`1GEeL0EEEE05]KF`1=CDd0EEEE051@D00204m?C`0404U9B@1<C4`0ATI6055A
D@80G5aL01`0BDU904e=C@1RHV80GemO06EUI@1cLg<0QHF509FEU@2CTi<0U9BD09VIV@2SXj<0YZJV
09nOW`2TY:@0XJ6Q09nOW`2FUYH0UIFE09bLW02TY:@0[jn_0;6a/@2XZ:P0Kfm_06a/K02`/;00c/k>
0P3=cLd02@3<c<`0clo?0=GEe@3@d=00clo?0<g=c@35aLD0bl_;0=CDe0020=KFeP80eMGE00/0f=SH
0=GEe@3EeMD0e=CD0=OGe`3Jf]X0e=CD0<30`02[Zj/0bLW90>7Qh@020=kNgP80gMgM00d0gmoO0=kN
gP3Ng]h0e=CD0<o?c`3<c<`0d];B0<g=c@3GemL0gMgM0=cLg03Ph>00g]kN0080hn?S00X0iNGU0>OW
i`3Ph>00i>CT0>3Ph03De=@0`l?30=_Kf`3Ti>@0i^KV0P3Shn<0103UiND0i>CT0>?Sh`3Ti>@20>GU
i@0B0>;RhP3MgMd0dm?C0=3@d03>c/h0`L710<C4a02m_Kd0[jn_0:VYZ@2^[Zh0^;Rh0<S8b03:b/X0
dm?C0=CDe03>c/h0bLW90P2l_;`03`2m_Kd0/k>c0;^k^`31`L40]kNg0;Jf]P2m_Kd0`/;20<_;b`3B
d]80d=3@0<o?c`3De=@0dM7A0=3@d0020=;BdP0B0<o?c`3Bd]80d];B0<c<c039bLT0dM7A0=CDe03@
d=00e=CD0=OGe`3Jf]X0eMGE0=SHf03EeMD0d=3@0=7Ad@3<c<`0`/;20P2b/[802P2g]kL0][Jf0;Rh
^035aLD0cLg=0=CDe03Fe]H0dm?C0<o?c`3;bl/20<[:bP0<0=WIf@3AdM40bl_;0<S8b033`l<0aLG5
0<S8b034a<@0a/K60<C4a039bLT0bl_;0P35aLD03P33`l<0bLW90<G5a@3=cLd0bl_;0<O7a`3?cll0
dM7A0=;BdP3Cdm<0d];B0=SHf03Fe]H0emOG0P3AdM400`3?cll0dM7A0=3@d0030<_;b`060<k>cP3<
c<`0c/k>0<K6aP31`L40alO70P3AdM40803Cdm<0dM7A0=7Ad@3=cLd0bLW90<C4a03<c<`0b<S80=CD
e03>c/h0dm?C0=7Ad@3>c/h0dm?C0<o?c`3Bd]80c/k>0<O7a`31`L40_[jn0<C4a039bLT0cLg=0<?3
``3=cLd0c/k>0=;BdP3=cLd0d];B0=KFeP3De=@0cLg=0P36a/H03@38b<P0`/;20<O7a`39bLT0bl_;
0<c<c03AdM40clo?0<_;b`3@d=00dm?C0<k>cP3@d=000P3Bd]804P3Cdm<0emOG0=3@d02l_;`0W9bL
08f=S@2:RXX0YJFU0<g=c@3Cdm<0e=CD0=;BdP3EeMD0dM7A0=3@d03Cdm<0dM7A0<k>cP80clo?00X0
d=3@0<o?c`3=cLd0d=3@0<g=c@3Bd]80dM7A0=;BdP3Fe]H0f][J0`3Fe]H00`3=cLd0d=3@0=3@d002
0<g=c@80c/k>00<0d];B0=OGe`3EeMD00P3@d=000`3>c/h0e=CD0=GEe@020=SHf0<0e=CD0`3IfMT0
2@3Ogml0fm_K0=SHf03Bd]80eMGE0=3@d03Fe]H0e=CD0=7Ad@020=3@d00C0=GEe@3Hf=P0g=cL0=WI
f@3GemL0fMWI0=SHf03MgMd0g]kN0=cLg03MgMd0g]kN0=oOg`3Ng]h0gmoO0>;RhP3Ph>00fMWI0=OG
e`020=[JfP0H0=kNgP3Hf=P0^k^k05iNGP1DE5@0GemO06IVIP2d];@0h>3P0=gMg@3Ng]h0fMWI0=_K
f`3EeMD0fm_K0=KFeP3EeMD0emOG0=GEe@3Hf=P0fMWI0=KFeP3GemL0f=SH0P3Fe]H01@3Hf=P0g=cL
0=GEe@3Hf=P0eMGE0080emOG01<0eMGE0=7Ad@3AdM40dM7A0=?Cd`3>c/h0d=3@0=;BdP3Cdm<0f=SH
0=KFeP3Hf=P0eMGE0=WIf@3Kfm/0eMGE0=[JfP3Fe]H0gMgM0080e=CD00D0f=SH0=[JfP3Hf=P0fm_K
0=CDe0020=;BdP040=?Cd`3?cll0cLg=0=3@d080f=SH00@0g=cL0=[JfP3Hf=P0fMWI0P3Jf]X01@3M
gMd0fm_K0=_Kf`3Jf]X0g=cL00<0emOG00<0cLg=0=;BdP3EeMD00P3Fe]H01@3Hf=P0e=CD0=?Cd`3@
d=00dm?C0080eMGE00L0e]KF0=OGe`3GemL0f][J0=CDe03=cLd0`l?30080bl_;00<0clo?0=;BdP3C
dm<03Oooool0013ooooo00P0CDe=04i>CP1SHf<0I6AT06MWI`1ZJVX0J6QX06a/K080LW9b01`0LG5a
07EeM@1bLW80Ogmo07]kN`1lO7`0RXZ:08f=S@28R8P0M7Ad0861P@23Ph<0Lg=c05QHF02<S8`0[:b/
0;:b/P2`/;00[Zj^0;fm_@35aLD0^;Rh0;no_`30`<00a/K60<W9b@3;bl/0c<c<0P3Cdm<20=7Ad@0?
0<K6aP2d];@0/k>c0<O7a`39bLT0^[Zj0;^k^`3EeMD0f][J0=SHf03Fe]H0fMWI0=gMg@3Hf=P0eMGE
0080fm_K00@0d];B0=[JfP3MgMd0gmoO0P3MgMd03@3Lg=`0gMgM0=[JfP3Lg=`0fm_K0=GEe@3Fe]H0
emOG0<k>cP3?cll0e]KF0=gMg@3Kfm/00P3IfMT04`3Kfm/0f][J0=OGe`3EeMD0c<c<0<S8b033`l<0
bl_;0=CDe03Lg=`0gmoO0>3Ph03Ti>@0gmoO0>?Sh`3Ti>@0hn?S0>;RhP3Shn<00P3UiND00`3Shn<0
hN7Q0>KViP020>;RhP0:0>7Qh@3Rh^80i>CT0>7Qh@3Rh^80hN7Q0>;RhP3Shn<0h>3P0=OGe`80c/k>
01`0b<S80;jn_P2l_;`0^;Rh0;6a/@2OWil0YZJV0:RXZ02g]kL0`L710<k>cP3;bl/0_kno0;Zj^P2a
/K40/k>c0;fm_@2g]kL0`/;20=?Cd`3;bl/0aLG50<O7a`3>c/h0dM7A0=3@d03De=@0emOG0P3>c/h2
0<g=c@050=3@d03?cll0d];B0<o?c`3AdM400P3Bd]80<03@d=00eMGE0=KFeP3GemL0fm_K0=OGe`3E
eMD0emOG0=;BdP38b<P0`L710:n_[`2TY:@0ZJVY0;:b/P2e]KD0^[Zj0<O7a`3AdM40e=CD0=GEe@3B
d]80dM7A0<o?c`3AdM40e=CD0=oOg`3De=@0dM7A0<?3``35aLD0c/k>0<o?c`3;bl/0c/k>0<c<c03=
cLd0b/[:0<30`032`/80`<300<O7a`3?cll0dm?C0=7Ad@3Cdm<0e=CD0=?Cd`<0e]KF00D0fMWI0=OG
e`3Hf=P0d];B0=7Ad@020=KFeP050=GEe@3Bd]80cLg=0<o?c`3<c<`00P3>c/h01@39bLT0a/K60<g=
c@3Bd]80dm?C0080dM7A01L0clo?0<g=c@3=cLd0b<S80<30`038b<P0d];B0=CDe03IfMT0e]KF0=?C
d`3Hf=P0fMWI0=KFeP3=cLd0alO70<C4a037alL0c/k>0<c<c038b<P0a/K60<G5a@020=?Cd`0?0=7A
d@3Hf=P0eMGE0=;BdP3GemL0clo?0<g=c@3Cdm<0dM7A0=CDe03>c/h0bLW90<o?c`3Bd]80d=3@0080
d];B00d0dm?C0<[:bP3Bd]80dm?C0=GEe@3Fe]H0dm?C0<k>cP2][Jd0Lg=c06ATI01_Kfl0VYZJ0080
d];B00P0e=CD0=3@d03EeMD0clo?0=7Ad@3Cdm<0e]KF0=7Ad@@0dm?C00<0c/k>0=CDe03AdM400P3E
eMD04`3Fe]H0dM7A0<W9b@3<c<`0d];B0=?Cd`3AdM40bl_;0<c<c03=cLd0dm?C0=GEe@3Fe]H0eMGE
0=?Cd`3IfMT0f=SH0=?Cd`3Bd]800P3Cdm<00`3Fe]H0f][J0=OGe`040=SHf0040=CDe03Lg=`0fm_K
0=gMg@80d=3@00L0clo?0=7Ad@3>c/h0clo?0=7Ad@3@d=00eMGE00<0gMgM00H0fMWI0=SHf03IfMT0
fm_K0=gMg@3Ogml30>;RhP070>3Ph03QhN40gmoO0>3Ph03Jf]X0fm_K0=gMg@020=_Kf`0:0=WIf@2X
Z:P0CTi>05UIF@1LG5`0H61P0<?3``3QhN40g]kN0=_Kf`80gMgM01<0f][J0=gMg@3EeMD0eMGE0=CD
e03EeMD0fMWI0=OGe`3@d=00bl_;0=?Cd`3AdM40emOG0=SHf03GemL0e]KF0=SHf03De=@0dm?C0080
eMGE00P0e]KF0=GEe@3Cdm<0f=SH0=GEe@3IfMT0clo?0=?Cd`80fMWI00<0e]KF0=SHf03Jf]X00P3J
f]X00`3IfMT0f=SH0=?Cd`020=KFeP070=OGe`3Kfm/0e=CD0=GEe@3@d=00bLW90<g=c@020<o?c`03
0=7Ad@3@d=00f=SH0080fMWI00T0emOG0=KFeP3Fe]H0emOG0=WIf@3Jf]X0fm_K0=WIf@3Hf=P00`3G
emL02`3Bd]80b/[:0=7Ad@3?cll0d];B0<[:bP3?cll0b/[:0<o?c`3AdM40d];B0080eMGE00`0e]KF
0=CDe03Cdm<0f=SH0=7Ad@3=cLd0bLW90<c<c03;bl/0d=3@0<S8b036a/H=ooooo`004?ooool0801A
DE40Lg=c09FEU@2OWil0VIVI0::RXP2YZJT0[jn_0;>c/`2/[:`0/K6a0;Rh^02m_Kd0_kno0;bl_02m
_Kd0alO70<o?c`38b<P0bLW90<S8b032`/80Z:RX09:BTP32`/80d=3@0=CDe03Cdm<0c/k>0=WIf@3G
emL0e]KF0P3Hf=P04@3MgMd0g=cL0=kNgP3Lg=`0gMgM0=WIf@3MgMd0g=cL0=[JfP3Ng]h0eMGE0<[:
bP3Bd]80dm?C0<c<c03Ogml0hN7Q0080gMgM00/0g=cL0=kNgP3Ng]h0g=cL0=_Kf`3MgMd0f=SH0=gM
g@3Ng]h0gmoO0=kNgP020=cLg0080=gMg@3Lg=`0g]kN0=KFeP3Hf=P0emOG0=SHf03Lg=`20=CDe008
0=KFeP3Hf=P0f=SH0=OGe`3EeMD0emOG0=CDe03=cLd20<K6aP050<o?c`3>c/h0i>CT0>;RhP3Shn<0
0P3Ti>@0103Rh^80hn?S0>;RhP3QhN420>?Sh`0<0>WYj@3Xj>P0hN7Q0>;RhP3UiND0h^;R0>CTi03R
h^80hn?S0>CTi03Ogml0h^;R0P3Ph>004P3Rh^80h>3P0=KFeP3@d=00c/k>0<_;b`37alL0_;bl0;:b
/P2[Zj/0Xj>S0:FUY@2][Jd0_;bl0<?3``35aLD0`/;20;jn_P80_;bl00T0_[jn0<W9b@38b<P0b/[:
0<g=c@3?cll0alO70<c<c03AdM400P3?cll04@3Bd]80clo?0=3@d03AdM40clo?0=3@d03>c/h0dM7A
0=OGe`3AdM40emOG0=CDe03Bd]80dm?C0=GEe@3Fe]H0dm?C0080emOG00D0f=SH0=;BdP3=cLd0a/K6
0;Bd]0020:NWY`0>0:ZZZP2g]kL0a/K60<S8b03<c<`0e]KF0=CDe03Hf=P0emOG0=WIf@3Jf]X0gMgM
0=_Kf`3Lg=`20=SHf0030=GEe@3De=@0dM7A0080e=CD0`3AdM402@3De=@0e]KF0<[:bP3<c<`0d=3@
0<g=c@3GemL0f][J0=SHf0020=OGe`060=7Ad@3:b/X0fMWI0=[JfP3IfMT0f=SH0P3GemL02`3Jf]X0
eMGE0=SHf03EeMD0clo?0=3@d03<c<`0clo?0<_;b`37alL0bl_;0080e]KF00H0f=SH0=CDe03De=@0
e=CD0<o?c`3:b/X20<S8b0050<g=c@3Bd]80e=CD0=WIf@3Jf]X00P3Hf=P02@3GemL0e=CD0=?Cd`3B
d]80c<c<0=7Ad@3?cll0c/k>0<[:bP020<c<c0080=CDe03Hf=P0fMWI0=[JfP3Bd]80eMGE0=[JfP3D
e=@20=OGe`070=3@d03Bd]80dm?C0=3@d03>c/h0dM7A0=GEe@020=KFeP040=GEe@3?cll0eMGE0=CD
e080d];B00T0d=3@0=?Cd`2^[Zh0IfMW04i>CP1MGEd0VIVI0=7Ad@3Bd]800P3Cdm<20=CDe0040=SH
f03De=@0f=SH0=GEe@80e]KF00D0emOG0=KFeP3Bd]80g=cL0=OGe`020=KFeP050=GEe@3AdM40c<c<
0=CDe03Cdm<00P3Bd]802P3>c/h0clo?0=7Ad@3GemL0eMGE0=7Ad@3Bd]80emOG0=_Kf`3MgMd20=CD
e0040=SHf03Fe]H0e=CD0=[JfP80e]KF00P0dm?C0=KFeP3IfMT0f][J0=_Kf`3Fe]H0e=CD0=7Ad@80
bLW900L0bl_;0=3@d03De=@0dM7A0=CDe03Jf]X0gmoO0080gMgM00@0fm_K0>3Ph03Ng]h0gmoO0P3T
i>@00`3Shn<0hN7Q0>3Ph0020>?Sh`040>3Ph03Ng]h0g=cL0=cLg080h>3P01X0fm_K0=SHf02^[Zh0
LW9b07moO`27QhL0VIVI0=OGe`3Ph>00gmoO0=cLg03Ph>00g=cL0=_Kf`3Ng]h0eMGE0=KFeP3Cdm<0
eMGE0=;BdP3Cdm<0b<S80<[:bP3@d=00bLW90<_;b`80c<c<00`0dM7A0=;BdP3@d=00d=3@0=CDe03@
d=00dM7A0<_;b`3>c/h0c<c<0=;BdP3Fe]H20=3@d0050=KFeP3EeMD0eMGE0=_Kf`3GemL00P3De=@0
0`3Hf=P0eMGE0=GEe@020=KFeP030=OGe`3De=@0dM7A0080a<C40P39bLT02P3=cLd0bLW90<k>cP3=
cLd0eMGE0=SHf03Fe]H0e=CD0=3@d03AdM430=?Cd`0@0=KFeP3@d=00dM7A0=3@d03=cLd0clo?0=3@
d03?cll0bl_;0<W9b@38b<P0_kno0<30`036a/H0alO70<W9b@80aLG500H0b<S80<_;b`39bLT0_kno
0<;2`P36a/H20<G5a@050<30`02m_Kd0^k^k0:f][@2[Zj/03Oooool0013ooooo00L0O7al0;Ng]`3A
dM40e]KF0=;BdP3Fe]H0eMGE0080emOG00L0f=SH0=CDe03Fe]H0fm_K0=[JfP3Kfm/0g]kN0080g=cL
01@0fm_K0=cLg03Ng]h0gMgM0=SHf037alL0emOG0=cLg03MgMd0g=cL0=kNgP3Ph>00hn?S0=oOg`3P
h>00gmoO0>;RhP3Shn<0gMgM0=kNgP80h>3P0140h^;R0=WIf@3Ph>00gMgM0>?Sh`3Ogml0fMWI0=CD
e03?cll0fm_K0=oOg`3Ph>00gmoO0=gMg@3IfMT0gMgM0>3Ph0020=SHf00C0=_Kf`3Lg=`0hN7Q0=gM
g@3Lg=`0g]kN0=SHf03IfMT0g]kN0=oOg`3De=@0emOG0=WIf@3Ogml0gMgM0=GEe@3@d=00emOG0=GE
e@020=OGe`080=?Cd`3@d=00b/[:0<W9b@3:b/X0dM7A0=KFeP3De=@20>7Qh@030>;RhP3WinL0iNGU
0080h^;R0P3UiND01P3QhN40h>3P0>3Ph03Ogml0g]kN0>?Sh`80h^;R00@0h>3P0>7Qh@3Ti>@0i>CT
0P3Ogml0303Rh^80hN7Q0=oOg`3Ph>00fm_K0=KFeP3De=@0bl_;0<c<c032`/80];Bd0:ZZZP80WinO
00H0[jn_0;jn_P34a<@0aLG50<O7a`39bLT20<?3``070<S8b03;bl/0c<c<0<_;b`3<c<`0eMGE0<o?
c`020=3@d0040=;BdP3AdM40d];B0=CDe080d];B00<0d=3@0=;BdP3=cLd00P3AdM40103Bd]80f=SH
0=SHf03GemL20=[JfP080=GEe@3IfMT0fm_K0=[JfP3GemL0dm?C0<W9b@2o_kl20;Bd]00@0;:b/P2m
_Kd0a/K60<c<c03De=@0eMGE0=KFeP3De=@0f][J0=OGe`3Kfm/0g=cL0=kNgP3QhN40g=cL0=OGe`80
fm_K00L0f][J0=SHf03De=@0dm?C0=CDe03Cdm<0e=CD0080eMGE00`0emOG0=CDe03De=@0e=CD0=GE
e@3MgMd0eMGE0;bl_02][Jd0YZJV0:f][@3De=@20=KFeP080=OGe`3Lg=`0f][J0=SHf03Cdm<0e]KF
0=;BdP3>c/h20=3@d00B0=CDe03AdM40cLg=0<k>cP3Cdm<0e]KF0=[JfP3Fe]H0fm_K0=kNgP3GemL0
dm?C0<_;b`3>c/h0dm?C0=GEe@3Ng]h0fm_K0P3MgMd03`3Lg=`0fMWI0=WIf@3Fe]H0fm_K0=GEe@3H
f=P0eMGE0=KFeP3De=@0fMWI0=GEe@3IfMT0gMgM0=kNgP020=WIf@0@0=GEe@3Jf]X0g=cL0=[JfP3I
fMT0f][J0=SHf03Bd]80d=3@0=;BdP3Hf=P0clo?0=KFeP3EeMD0e]KF0=GEe@@0f=SH01`0eMGE0=?C
d`2b/[80GEeM04a<C01?Cdl0UIFE0=OGe`3IfMT0e]KF0=SHf03EeMD0fMWI0=[JfP3GemL0fMWI0=SH
f03Fe]H0f=SH0=OGe`3Fe]H0dm?C0=kNgP3Jf]X0fMWI0=GEe@3AdM40c/k>0P3De=@0403?cll0cLg=
0<c<c03@d=00e=CD0=KFeP3Kfm/0emOG0=SHf03Kfm/0fMWI0=OGe`3Fe]H0dm?C0=KFeP3Hf=P20=[J
fP0@0=cLg03Hf=P0e=CD0=3@d03De=@0f=SH0=KFeP3?cll0bLW90<S8b03@d=00b<S80<[:bP3=cLd0
b<S80=3@d080e=CD02@0emOG0=oOg`3Lg=`0g=cL0=kNgP3Rh^80gmoO0>3Ph03Rh^80hN7Q0>3Ph03N
g]h0h>3P0>;RhP3Ogml0h>3P0=gMg@3Ng]h0f][J0=gMg@3Ogml0gMgM0=WIf@3De=@0dm?C0=;BdP3E
eMD0fm_K0>7Qh@3Ph>00gmoO0>7Qh@3MgMd0fMWI0=SHf03Jf]X20=;BdP040=CDe03?cll0d=3@0=?C
d`80c<c<00@0b/[:0<S8b032`/80bLW90P3;bl/00`3<c<`0b/[:0<W9b@020<[:bP0>0<g=c@37alL0
`/;20<71`@3<c<`0dM7A0<k>cP3:b/X0dM7A0<g=c@3Hf=P0e]KF0=GEe@3<c<`20=?Cd`80e]KF00H0
e=CD0=3@d03@d=00bLW90<G5a@2m_Kd20<30`080alO700P0_kno0<?3``32`/80bl_;0<o?c`3;bl/0
b/[:0<S8b080b/[:00h0alO70<G5a@38b<P0`l?30;fm_@33`l<0aLG50;Rh^02c/k<0]kNg0;:b/P2^
[Zh0YZJV0:>SX`80W9bL00T0XJ6Q09RHV02FUYH0UiNG09>CT`2FUYH0TI6A08R8R026QXH00P20P800
1P1mOGd0LW9b071`L01YJFT0I6AT05mOG`gooooo000@ooooo`0<0:BTY03Bd]80gMgM0>?Sh`3QhN40
e=CD0=_Kf`3Ng]h0fMWI0=gMg@3Ng]h0h>3P0P3MgMd0303Ng]h0h>3P0=gMg@3MgMd0h>3P0>;RhP3Q
hN40h>3P0=_Kf`3Jf]X0gmoO0>;RhP80gmoO00P0h>3P0=oOg`3QhN40g]kN0=oOg`3QhN40h>3P0>;R
hP80h>3P00D0g]kN0>7Qh@3Ogml0g=cL0=[JfP020=oOg`090=gMg@3Ogml0gMgM0=kNgP3QhN40h>3P
0>7Qh@3Ogml0g]kN0080f][J0`3Kfm/06`3Ng]h0f=SH0=_Kf`3Lg=`0g]kN0=oOg`3GemL0g=cL0=GE
e@3IfMT0clo?0=7Ad@3Cdm<0f][J0=GEe@3Fe]H0clo?0=3@d03>c/h0cLg=0=CDe03@d=00c<c<0<o?
c`3Bd]80e=CD0=WIf@020=_Kf`030>7Qh@3Ti>@0h^;R0080i>CT0P3Shn<00`3Ti>@0iNGU0>CTi002
0>?Sh`80h^;R00@0hn?S0>;RhP3QhN40h>3P0P3Ng]h0503Ph>00h^;R0=cLg03Ph>00gmoO0>3Ph03O
gml0fMWI0=SHf03GemL0d];B0<c<c03:b/X0_kno0;Vi^@2^[Zh0YjNW0;Ng]`35aLD0bLW90P3;bl/0
1034a<@0`l?30<71`@35aLD30<g=c@070=7Ad@3Hf=P0emOG0=GEe@3De=@0eMGE0=KFeP020=SHf004
0=KFeP3EeMD0eMGE0=?Cd`80eMGE0140emOG0=SHf03Kfm/0gMgM0=cLg03Ogml0h>3P0=kNgP3Jf]X0
fm_K0=cLg03MgMd0f=SH0=3@d034a<@0`<300;Rh^0020<S8b0030<G5a@3AdM40eMGE0080f][J00<0
fMWI0=?Cd`3Hf=P00P3Ng]h01P3Lg=`0g]kN0>7Qh@3Lg=`0gMgM0=WIf@80e]KF00@0eMGE0=CDe03A
dM40dM7A0P3Bd]800`3Fe]H0d];B0=?Cd`020=KFeP80f=SH00H0cLg=0:>SX`2;Rh/0Q8B409FEU@3;
bl/20=;BdP030=GEe@3Kfm/0e]KF0080eMGE00/0dm?C0=;BdP3=cLd0dm?C0=[JfP3Hf=P0emOG0=?C
d`3De=@0dm?C0=OGe`020=[JfP80g]kN00D0g=cL0=_Kf`3GemL0eMGE0=OGe`020=_Kf`80g=cL00P0
gMgM0=oOg`3Jf]X0fMWI0=OGe`3Kfm/0f=SH0=OGe`80f=SH00@0fm_K0=gMg@3IfMT0f=SH0P3MgMd0
7@3IfMT0fm_K0=[JfP3Jf]X0f=SH0=[JfP3Kfm/0emOG0=?Cd`3AdM40b/[:0=?Cd`3?cll0d=3@0=CD
e03AdM40e=CD0=GEe@3Jf]X0emOG0=;BdP3AdM40d=3@0<c<c02PX:00J6QX06][J`1HF5P0WYjN00<0
emOG00L0e]KF0=?Cd`3Fe]H0emOG0=WIf@3EeMD0e=CD0080eMGE00X0dM7A0=GEe@3@d=00f][J0=KF
eP3Bd]80clo?0=;BdP3AdM40d];B0`3>c/h01@3<c<`0bl_;0=3@d03@d=00eMGE0080e]KF00@0f=SH
0=WIf@3Hf=P0fMWI0P3Cdm<00`3Kfm/0fMWI0=_Kf`020=_Kf`0H0=[JfP3De=@0e]KF0=SHf03?cll0
c<c<0<_;b`3<c<`0d=3@0<_;b`38b<P0bl_;0<g=c@3;bl/0c<c<0=;BdP3Fe]H0g]kN0=cLg03IfMT0
gMgM0>3Ph03Ng]h0h>3P0P3QhN401@3Ogml0h>3P0=kNgP3Ng]h0gMgM0080gmoO00P0hN7Q0=gMg@3N
g]h0h>3P0=gMg@3IfMT0fm_K0=gMg@80gmoO00X0i>CT0>7Qh@3Ti>@0fMWI0=gMg@3Jf]X0g]kN0=cL
g03Jf]X0clo?0P3>c/h05P3AdM40d];B0<c<c038b<P0b/[:0<K6aP3?cll0b<S80<_;b`3<c<`0cLg=
0<S8b035aLD0`<300<G5a@36a/H0`l?30<;2`P2h^;P0_;bl0<O7a`3?cll20<c<c00<0<g=c@39bLT0
dm?C0<c<c03?cll0a/K60<C4a035aLD0bl_;0<O7a`34a<@0_[jn0P2c/k<0402d];@0[Zj^0:^[Z`2_
[jl0][Jf0:JVYP2MWId0Xj>S09bLW02MWId0VIVI092@T02EUID0T92@08j>SP29RHT207emO@0907Qh
N01cLg<0N7Qh071`L01dM7@0Kfm_06IVIP1NGUh0FUYJ0080EEEE00D0Bd];04i>CP1<C4`0Bd];04U9
B@0204Y:BP0304E5A@12@T80B4Q80080@T9200P0?Shn03dm?@0o?cl0?Cdm0410@00l?3`0@41003lo
?`gooooo000@ooooo`060;:b/P2o_kl0fm_K0=kNgP3QhN40h>3P0P3Lg=`01@3Ph>00g=cL0=oOg`3Q
hN40fm_K0080g]kN00P0gmoO0=kNgP3MgMd0g]kN0>3Ph03Ogml0g]kN0=oOg`80h>3P00L0hn?S0=kN
gP3MgMd0g]kN0>3Ph03Shn<0h>3P0080hn?S0P3QhN404@3Ph>00hN7Q0=oOg`3Shn<0g]kN0=oOg`3L
g=`0h>3P0=cLg03Ogml0hN7Q0>3Ph03Ng]h0gmoO0>3Ph03Ogml0g=cL0080gMgM0140f][J0=OGe`3H
f=P0fm_K0=gMg@3Jf]X0g]kN0=gMg@3Kfm/0f][J0=GEe@3Fe]H0d=3@0=;BdP3Cdm<0e=CD0=OGe`02
0=[JfP090=GEe@39bLT0dm?C0=7Ad@3EeMD0dM7A0<_;b`3GemL0fMWI0080g=cL00L0h>3P0>CTi03T
i>@0i>CT0>GUi@3Ti>@0h^;R0080hN7Q0P3UiND00`3Shn<0i>CT0>7Qh@030>;RhP80i>CT02L0hN7Q
0>;RhP3Shn<0h>3P0=oOg`3Ph>00hn?S0>7Qh@3Lg=`0gMgM0>7Qh@3Kfm/0fMWI0=CDe03Bd]80clo?
0<c<c038b<P0a<C40;jn_P2f][H0_kno0<[:bP3;bl/0c/k>0<o?c`3=cLd0clo?0<_;b`3<c<`0e=CD
0=OGe`3EeMD0clo?0<k>cP3;bl/0dm?C0=gMg@3Hf=P00P3IfMT01P3GemL0e]KF0=_Kf`3Kfm/0eMGE
0=gMg@80f][J00d0fm_K0=gMg@3Ph>00g]kN0=oOg`3QhN40gMgM0=oOg`3MgMd0f][J0=oOg`3Jf]X0
e=CD0080clo?00l0b<S80=3@d03EeMD0clo?0=WIf@3EeMD0emOG0=CDe03EeMD0f=SH0=[JfP3QhN40
h^;R0=_Kf`3Jf]X00P3Ng]h20=[JfP070=CDe03Cdm<0eMGE0=?Cd`3AdM40d=3@0=7Ad@020=CDe080
c<c<00`0e]KF0=[JfP3Fe]H0e]KF0=7Ad@2NWYh0MWIf08F5Q@2MWId0dM7A0=CDe03EeMD20=SHf00O
0=CDe03Jf]X0gMgM0=OGe`3Hf=P0emOG0=SHf03Lg=`0fm_K0=cLg03Jf]X0g=cL0=kNgP3Jf]X0hN7Q
0=OGe`3MgMd0f][J0=cLg03MgMd0g=cL0=KFeP3Kfm/0f][J0=_Kf`3Jf]X0fm_K0=[JfP3GemL0gMgM
0=KFeP020=SHf0040=OGe`3Jf]X0fMWI0=[JfP80g]kN00d0f][J0=cLg03MgMd0f=SH0=OGe`3Hf=P0
gMgM0=kNgP3Jf]X0e=CD0=WIf@3Fe]H0dm?C0080d];B00<0d=3@0=7Ad@3Bd]800P3Bd]802@3GemL0
fm_K0=kNgP3Jf]X0d];B0=3@d03AdM40bl_;09>CT`0207AdM00807=cL`2h^;P0emOG0=KFeP3EeMD0
e=CD0=GEe@3GemL20=SHf00C0=;BdP3Cdm<0dm?C0=CDe03Cdm<0dM7A0<g=c@3De=@0dM7A0<g=c@3>
c/h0clo?0=?Cd`3>c/h0clo?0<[:bP38b<P0a/K60<C4a0020<S8b00@0=;BdP3GemL0emOG0=?Cd`3E
eMD0d];B0=WIf@3GemL0e=CD0=SHf03IfMT0fm_K0=cLg03Fe]H0f=SH0=GEe@80e=CD0280d];B0=CD
e03=cLd0b<S80<W9b@37alL0bLW90<K6aP3>c/h0bl_;0<o?c`3@d=00emOG0=SHf03EeMD0emOG0=[J
fP3IfMT0f][J0=gMg@3Ng]h0gMgM0=[JfP3Kfm/0f=SH0=_Kf`3Lg=`0g]kN0=SHf03Kfm/0f=SH0=KF
eP3Lg=`0f][J0P3IfMT01P3Kfm/0emOG0=kNgP3Ogml0g=cL0=_Kf`80fMWI00X0f][J0=KFeP3Bd]80
dm?C0<c<c03=cLd0bLW90<?3``34a<@0aLG50P33`l<01`2l_;`0`L710;Ng]`2j^[X0`<300;>c/`2_
[jl00P2/[:`0802`/;00/[:b0:j^[P2^[Zh0[:b/0;2`/02a/K40[Zj^0:6QX@2ZZZX0ZJVY0:^[Z`2Z
ZZX0U9BD0:>SX`2ATI40R8R808J6QP24Q8@0PH6107MgM`1dM7@0LW9b06UYJ@1XJ6P0IFEU05iNGP1S
Hf<0GUiN05YJFP1DE5@0C4a<0P1;Bd/01@18B4P0AdM704I6AP17AdL0A4A40080@d=300H0@41003dm
?@0l?3`0@41003lo?`0m?Cd303hn?P0303Xj>P0o?cl0CDe=0080?Cdm00H0>SXj03`l?00j>SX0?3`l
03dm?@0l?3`203hn?P0803lo?`0j>SX0?3`l03Ti>@0k>c/0>SXj03Ti>@0j>SX203/k>`gooooo000@
ooooo`0?0=SHf03De=@0gMgM0=kNgP3Ogml0gMgM0=oOg`3Ng]h0gMgM0=[JfP3Ng]h0h^;R0=oOg`3S
hn<0hN7Q00<0gmoO00<0gMgM0=kNgP3Ogml00P3Ph>00103MgMd0fm_K0>7Qh@3Ogml20=gMg@030=cL
g03Ph>00g]kN00<0g=cL00D0gmoO0=kNgP3Ogml0gmoO0>CTi0020=gMg@030=oOg`3Ph>00gMgM0080
g=cL00T0gmoO0=kNgP3MgMd0hN7Q0=kNgP3Lg=`0g]kN0>3Ph03Ng]h00P3Lg=`00`3Ng]h0f][J0=_K
f`020=cLg080gMgM00@0fMWI0=OGe`3IfMT0emOG0P3IfMT0103Jf]X0f=SH0=gMg@3Hf=P20=OGe`0@
0<g=c@3<c<`0e=CD0=;BdP3Jf]X0gMgM0>7Qh@3Ogml0hn?S0>GUi@3Ti>@0i^KV0>GUi@3Shn<0h^;R
0>?Sh`80h^;R00L0i>CT0>3Ph03Ph>00i>CT0>GUi@3Vi^H0inOW00@0i>CT01D0h>3P0>7Qh@3Rh^80
h^;R0>3Ph03QhN40h>3P0>?Sh`3Rh^80g=cL0=[JfP3Fe]H0emOG0=GEe@3De=@0eMGE0=7Ad@3?cll0
cLg=0=7Ad@3EeMD00P3GemL03`3MgMd0g=cL0=OGe`3GemL0e]KF0=[JfP3Ng]h0f=SH0;2`/02:RXX0
SHf=0<C4a03Ng]h0gMgM0=oOg`020=gMg@050=cLg03Ng]h0gMgM0=[JfP3Lg=`00P3Kfm/30=oOg`0:
0=cLg03Kfm/0gmoO0>3Ph03Ng]h0fm_K0=kNgP3Ph>00gMgM0=SHf080fm_K00/0e=CD0<_;b`3AdM40
f=SH0=_Kf`3MgMd0f][J0=cLg03GemL0f=SH0=WIf@020>7Qh@030=gMg@3Lg=`0g]kN0080f][J01`0
fMWI0=kNgP3Hf=P0dM7A0=;BdP3Fe]H0eMGE0=OGe`3Jf]X0emOG0<o?c`3EeMD0fm_K0=WIf@3Fe]H0
emOG0=3@d02PX:00MGEe08F5Q@2WYjL0emOG0=[JfP3IfMT0g=cL0=WIf@3Jf]X0eMGE0`3Fe]H07P3E
eMD0dm?C0=GEe@3Lg=`0f][J0=cLg03Ng]h0g=cL0=KFeP3Ng]h0fMWI0>3Ph03Kfm/0g=cL0=[JfP3M
gMd0f=SH0=gMg@3IfMT0f][J0=_Kf`3IfMT0eMGE0=OGe`3Kfm/0fMWI0=SHf03GemL0eMGE0=_Kf`80
f=SH00D0eMGE0=7Ad@3GemL0f][J0=KFeP020=OGe`070=KFeP3IfMT0fm_K0=_Kf`3EeMD0emOG0=GE
e@020=CDe0040=3@d03Hf=P0clo?0<[:bP80cLg=00`0eMGE0=WIf@3Lg=`0e]KF0<g=c@3@d=00d];B
0=7Ad@31`L40_[jn0<30`03;bl/20=WIf@0:0=GEe@3Bd]80dm?C0=?Cd`3Bd]80dm?C0=;BdP3>c/h0
d=3@0=CDe080clo?00h0d=3@0<o?c`3<c<`0c<c<0<W9b@37alL0cLg=0<O7a`3?cll0c<c<0<G5a@38
b<P0b/[:0<_;b`80a/K601`0bl_;0=OGe`3Fe]H0e=CD0=7Ad@3Bd]80emOG0=WIf@3Hf=P0e=CD0=KF
eP3Hf=P0g=cL0=?Cd`3Hf=P0e]KF0=CDe03Bd]80dm?C0<o?c`39bLT0b<S80<O7a`36a/H0alO70<;2
`P37alL0b<S80P3=cLd0403EeMD0e]KF0=;BdP3Cdm<0emOG0=GEe@3Kfm/0f][J0=_Kf`3Fe]H0d];B
0=?Cd`3Fe]H0emOG0=SHf03GemL20=;BdP0S0=3@d03>c/h0dM7A0<k>cP3:b/X0`l?30;no_`32`/80
`l?30;Zj^P2e]KD0/[:b0;Bd]02][Jd0^[Zj0;2`/02/[:`0Z:RX09NGU`2KVi/0UYJF08Z:RP29RHT0
QhN707emO@1oOgl0P82007inOP1iNGT0M7Ad07EeM@1VIVH0Hf=S05eMG@1QHF400`1NGUh05P1QHF40
GemO065QH@1PH600Cdm?05MGE`1EEED0F5QH06=SH`1EEED0CDe=05MGE`1EEED0@41004=3@`0o?cl0
@T920451@@10@400?Cdm04=3@`0n?Sh20410@00603lo?`0j>SX0?Shn03lo?`0m?Cd0>CTi0P0l?3`0
9P0n?Sh0?Cdm03lo?`0m?Cd0?3`l03hn?P0l?3`0?Shn03lo?`0k>c/0>SXj03Ph>010@400?Shn03`l
?00o?cl0?3`l03lo?`0j>SX0?Cdm03`l?00o?cl0@d=304A4A011@D40@T9203hn?P1=CDd0@d=303`l
?010@400?Cdm0410@012@T80?Cdm03`l?010@400@D513Oooool0013ooooo00X0gmoO0=_Kf`3Lg=`0
g=cL0>3Ph03Ogml0gMgM0=WIf@3Jf]X0gmoO0P3Shn<01P3QhN40iNGU0>;RhP3QhN40gMgM0=oOg`80
h>3P00@0g]kN0>3Ph03Ogml0gmoO0P3Rh^803P3Ogml0gMgM0=oOg`3MgMd0hn?S0>7Qh@3Ogml0gMgM
0=cLg03Ph>00gmoO0=kNgP3Ogml0h>3P0P3MgMd01P3Lg=`0gmoO0=cLg03Lg=`0fMWI0=gMg@80g]kN
00D0h>3P0>7Qh@3QhN40gmoO0=kNgP020=gMg@060=cLg03MgMd0fm_K0=cLg03Kfm/0gMgM0P3Ng]h0
0`3Lg=`0gMgM0=gMg@030=_Kf`80gMgM00P0g]kN0=cLg03Lg=`0g=cL0=gMg@3Fe]H0gMgM0=cLg080
h>3P00<0gmoO0>3Ph03Shn<00P3Rh^802P3Shn<0i>CT0>;RhP3QhN40i>CT0>GUi@3QhN40iNGU0>;R
hP3QhN420>?Sh`030>GUi@3Vi^H0hN7Q0080hn?S00H0i>CT0>;RhP3Ph>00g]kN0>3Ph03Ogml20>7Q
h@040>;RhP3QhN40f][J0=WIf@80fm_K00/0f=SH0=CDe03EeMD0eMGE0=CDe03Hf=P0f][J0=kNgP3O
gml0g=cL0=kNgP020>3Ph00@0=kNgP3IfMT0g=cL0=_Kf`3Cdm<0Rh^;061PH01bLW80aLG50=oOg`3L
g=`0gmoO0=gMg@3Ng]h0h>3P0=cLg080fm_K00X0gMgM0=_Kf`3Lg=`0hN7Q0>?Sh`3Kfm/0g=cL0=gM
g@3QhN40fm_K0P3Ogml06@3MgMd0gmoO0=WIf@3Jf]X0fm_K0=3@d03>c/h0fMWI0=SHf03Ng]h0fm_K
0=WIf@3EeMD0fMWI0=_Kf`3MgMd0hN7Q0=gMg@3Lg=`0g]kN0=_Kf`3Ogml0f=SH0=kNgP3Lg=`00P3K
fm/0903IfMT0f][J0=SHf03Jf]X0eMGE0=SHf03Rh^80g=cL0=SHf03De=@0emOG0=;BdP3Cdm<0`l?3
09BDU02@T900PH610:VYZ@3Lg=`0gMgM0=SHf03Kfm/0g=cL0=_Kf`3IfMT0e]KF0=CDe03Bd]80fMWI
0=[JfP3Hf=P0emOG0=CDe03Kfm/0h>3P0=cLg0<0f][J00D0gMgM0=_Kf`3MgMd0eMGE0=_Kf`020=OG
e`0@0=GEe@3IfMT0f=SH0=SHf03Kfm/0f][J0=OGe`3Jf]X0e]KF0=WIf@3De=@0emOG0=KFeP3GemL0
d];B0<o?c`80f=SH00D0dm?C0=GEe@3Fe]H0f][J0=;BdP020=KFeP0;0=OGe`3Fe]H0d];B0=?Cd`3B
d]80eMGE0=7Ad@3Bd]80bl_;0<g=c@3>c/h00P3EeMD01`3Hf=P0eMGE0=;BdP3Cdm<0c/k>0<_;b`3@
d=000P3Fe]H20=WIf@0:0=KFeP3Bd]80clo?0<g=c@3<c<`0dM7A0<o?c`3>c/h0c<c<0<g=c@80bl_;
00H0c<c<0<[:bP3>c/h0b/[:0<K6aP33`l<20<C4a00@0<G5a@34a<@0a<C40<71`@32`/80_[jn0<K6
aP34a<@0bLW90<c<c03GemL0e=CD0=KFeP3Bd]80eMGE0=CDe080e]KF00H0e=CD0=7Ad@3Bd]80e]KF
0=CDe03EeMD30<o?c`070=3@d036a/H0^KVi0;6a/@2e]KD0^;Rh0;Vi^@020;Fe]@0<0;Ng]`2c/k<0
];Bd0;Rh^02l_;`0^KVi0;>c/`2a/K40Zj^[0;2`/02][Jd0YZJV0P2SXj<04@2WYjL0Vi^K09RHV02C
Ti<0T92@08Z:RP23Ph<0Ng]k07QhN01fMWH0M7Ad06e]K@1RHV80Hf=S06MWI`1TI6@0GEeM0080EUIF
0140EeMG05ADE01BDU80Cdm?04e=C@1<C4`0@d=304A4A015ADD0?clo0410@00n?Sh0?clo04A4A012
@T80?Cdm0410@00203hn?P0503dm?@10@400@4100451@@10@4000P0o?cl01P0k>c/0?Cdm03Ti>@0j
>SX0?Cdm03hn?P80?clo00<0@41003lo?`0k>c/00P17AdL00`0l?3`0>SXj03`l?00203`l?00303dm
?@0l?3`0?Shn0080?3`l00P0@4100451@@0k>c/0?Cdm03/k>`0l?3`0>SXj03/k>`80?3`l00l0>SXj
03`l?00m?Cd0@D5103lo?`0m?Cd0?3`l0410@013@d<0CDe=04a<C01>CTh0De=C05UIF@1MGEd00`1?
Cdl04`1>CTh0AdM704i>CP1@D500GEeM059BDP1=CDd0D51@05EEE@18B4P0AdM704A4A00n?Sh0@410
04A4A016ATH0@d=304Y:BP1<C4`03Oooool0013ooooo00h0g]kN0=[JfP3Lg=`0gMgM0=cLg03Kfm/0
fMWI0=[JfP3Kfm/0fMWI0>7Qh@3Xj>P0inOW0>3Ph080gmoO00<0g=cL0>?Sh`3Ph>000P3Kfm/01P3M
gMd0g=cL0>3Ph03Ogml0g=cL0=kNgP80gmoO00/0hN7Q0>;RhP3QhN40g]kN0=_Kf`3IfMT0gmoO0>;R
hP3Ogml0h>3P0=oOg`020=gMg@@0g=cL0P3Cdm<0103MgMd0g]kN0=kNgP3Ph>020>7Qh@090=kNgP3P
h>00h>3P0=gMg@3QhN40fMWI0=gMg@3Ogml0hN7Q0080gmoO00<0e]KF0=[JfP3Ogml00P3MgMd01`3N
g]h0gmoO0>3Ph03Ng]h0gMgM0>3Ph03QhN400P3Lg=`02P3@d=00bl_;0=7Ad@3Ogml0hN7Q0>3Ph03Q
hN40h^;R0>CTi03Rh^830>7Qh@80iNGU00X0hn?S0>7Qh@3Ph>00iNGU0>?Sh`3QhN40i>CT0>KViP3R
h^80hn?S0P3Ph>002@3QhN40h>3P0=kNgP3QhN40h^;R0>KViP3QhN40i^KV0>CTi0020=cLg0030=gM
g@3IfMT0f][J0080emOG0P3Jf]X04P3Ogml0fm_K0=gMg@3MgMd0hN7Q0>CTi03Ph>00hn?S0>;RhP3Q
hN40h>3P0=kNgP3@d=00OWin04a<C01^KVh0a/K60=oOg`80h>3P00D0g]kN0=oOg`3Ng]h0hN7Q0=cL
g0020=kNgP80g=cL00H0gmoO0>?Sh`3Jf]X0g=cL0=kNgP3Ph>020=gMg@0J0=kNgP3Lg=`0fm_K0=SH
f03Lg=`0f=SH0=[JfP3IfMT0g=cL0=_Kf`3IfMT0e]KF0=OGe`3Kfm/0fMWI0>3Ph03Lg=`0g]kN0=oO
g`3Kfm/0hN7Q0=WIf@3Lg=`0fm_K0=cLg03IfMT20=SHf0070=OGe`3Fe]H0eMGE0=cLg03EeMD0e=CD
0=KFeP020=WIf@0@0=KFeP3EeMD0d];B0=GEe@36a/H0Xj>S0:JVYP2UYJD0aLG50=OGe`3Bd]80e]KF
0=SHf03GemL0f=SH0=CDe080eMGE00T0f=SH0=GEe@3EeMD0d=3@0=WIf@3Hf=P0fm_K0=kNgP3IfMT0
0P3Fe]H00`3Cdm<0f=SH0=7Ad@030=;BdP0E0=CDe03EeMD0eMGE0=KFeP3GemL0fMWI0=_Kf`3EeMD0
d];B0=KFeP3Cdm<0eMGE0<g=c@3@d=00e=CD0=?Cd`3?cll0dM7A0=GEe@3Hf=P0c<c<0080dm?C00@0
e]KF0=;BdP3Fe]H0f=SH0P3GemL02@3Cdm<0dM7A0<k>cP3AdM40d=3@0=WIf@3GemL0c/k>0=;BdP02
0=KFeP0<0=SHf03EeMD0clo?0=?Cd`3AdM40dm?C0<o?c`3De=@0dm?C0=KFeP3AdM40cLg=0P3AdM40
3`3=cLd0b/[:0<o?c`3>c/h0c<c<0<K6aP35aLD0b<S80<_;b`39bLT0a<C40<71`@32`/80^k^k0;Rh
^0020;Jf]P050;Bd]02h^;P0^;Rh0;Fe]@2b/[800P2a/K401@2][Jd0[jn_0;Vi^@33`l<0^k^k0080
^;Rh00<0];Bd0;Fe]@2d];@00P2^[Zh01P2YZJT0Z:RX0:FUY@2UYJD0XZ:R09fMW@<0UYJF00X0PH61
079bLP1aLG40L71`06i^KP1]KFd0J6QX06=SH`1TI6@0H61P0P1MGEd03@1JFUX0EEEE05EEE@1CDe<0
CTi>05MGE`1BDU80D51@055AD@1:BTX0C4a<04I6AP17AdL00P13@d<01@14A4@0@D510410@00o?cl0
@4100080@D5100P0@4100451@@0o?cl0@D5103dm?@11@D40?Cdm04=3@`80?Cdm00<0?Shn03dm?@0n
?Sh00P0m?Cd0200n?Sh0?3`l03/k>`0l?3`0>SXj03/k>`0m?Cd0>CTi0P0n?Sh01@0l?3`0?Shn0492
@P12@T80@D510080?Shn01X0?clo03`l?00j>SX0>SXj03lo?`12@T80?Shn04E5A@12@T80ATI604E5
A@13@d<0A4A403lo?`15ADD0@d=304a<C016ATH0@41004I6AP1ADE40D51@04U9B@15ADD0@4100451
@@80@d=302<0?clo0492@P0o?cl0?clo04M7A`10@400AdM704E5A@16ATH0@d=304E5A@11@D40@d=3
04Y:BP1<C4`0Bd];04Y:BP1;Bd/0AdM704Q8B01>CTh0D51@05EEE@1>CTh0BDU904Y:BP1DE5@0Cdm?
05QHF01JFUX0GEeM05]KF`1QHF40GemO06UYJ@0206MWI`0606a/K01_Kfl0MGEe08>3P`2?Shl0UiNG
3Oooool0013ooooo00d0f][J0=WIf@3Lg=`0gMgM0=SHf03Jf]X0fm_K0=gMg@3Jf]X0g=cL0>3Ph03O
gml0iNGU0080hN7Q00<0hn?S0>OWi`3Ph>000P3MgMd02P3Ng]h0gmoO0=_Kf`3Ogml0h^;R0>3Ph03M
gMd0gmoO0=gMg@3UiND20=oOg`080=kNgP3Ogml0fm_K0=kNgP3Ogml0g]kN0>7Qh@3Shn<20>7Qh@07
0=oOg`3Ng]h0gmoO0>7Qh@3Ph>00g]kN0>7Qh@020=kNgP0:0=oOg`3QhN40h^;R0>7Qh@3Ng]h0h>3P
0>CTi03Ng]h0g=cL0>3Ph080i>CT00<0gmoO0=kNgP3Kfm/00P3Ph>001`3Shn<0g]kN0=gMg@3Jf]X0
gMgM0>3Ph03Ng]h00P3Ogml07@3Lg=`0e=CD0:NWY`27QhL0[Jf]0=SHf03QhN40h>3P0>7Qh@3Ogml0
h^;R0>7Qh@3Ng]h0gMgM0=oOg`3Rh^80i>CT0>3Ph03Vi^H0iNGU0>CTi03Rh^80h>3P0>;RhP3Ti>@0
hn?S0>7Qh@3Shn<0hN7Q0080h^;R0140gmoO0>3Ph03QhN40i^KV0>CTi03QhN40hn?S0=oOg`3Kfm/0
f=SH0=[JfP3Kfm/0e]KF0=SHf03Ng]h0h>3P0>?Sh`030=kNgP0?0=[JfP3Ph>00gmoO0=gMg@3Ng]h0
g=cL0=gMg@3Jf]X0a<C4071`L01<C4`0N7Qh0<g=c@3Lg=`0f=SH0080g=cL00H0h>3P0=_Kf`3Kfm/0
gMgM0=cLg03GemL20=_Kf`070=cLg03Ng]h0g=cL0=cLg03MgMd0gmoO0>7Qh@020=gMg@080=cLg03K
fm/0emOG0=[JfP3EeMD0dm?C0=OGe`3Lg=`30=KFeP060=GEe@3Hf=P0f=SH0=WIf@3De=@0f=SH0P3K
fm/0503Ng]h0fm_K0=_Kf`3Hf=P0eMGE0=?Cd`3Hf=P0emOG0=?Cd`3Fe]H0d];B0=GEe@3Bd]80f=SH
0=WIf@3Jf]X0e]KF0=?Cd`3AdM40eMGE0P3Bd]80103Cdm<0eMGE0=GEe@3Kfm/20=[JfP0C0=_Kf`3E
eMD0dm?C0=;BdP3@d=00dm?C0<k>cP3AdM40d];B0<o?c`3@d=00d];B0=?Cd`3AdM40d];B0=CDe03A
dM40c<c<0=;BdP020=3@d0030<k>cP3De=@0eMGE0080e=CD00D0d];B0=GEe@3Fe]H0f=SH0=OGe`02
0=;BdP0:0=GEe@3>c/h0c/k>0<[:bP3<c<`0d];B0<k>cP37alL0clo?0=KFeP80cLg=0140dm?C0<o?
c`3EeMD0dm?C0=CDe03Cdm<0d];B0=?Cd`3;bl/0b/[:0<o?c`3AdM40d];B0=GEe@3Cdm<0cLg=0<k>
cP020<[:bP0F0=;BdP3AdM40bLW90<S8b036a/H0a<C40;fm_@35aLD0_;bl0;jn_P30`<00]kNg0;Zj
^P2e]KD0/[:b0;2`/02^[Zh0ZZZZ0:BTY02MWId0W9bL0:6QX@80VYZJ00l0TI6A08R8R027QhL0Ph>3
07inOP1eMGD0Kfm_07MgM`1]KFd0LG5a06e]K@1XJ6P0IVIV05mOG`1UIFD00P1QHF401@1TI6@0GEeM
05UIF@1KFe/0F5QH0080EeMG00P0DE5A05QHF01@D500D51@04m?C`1<C4`0B4Q804a<C080AdM70180
A4A403lo?`12@T80@d=303lo?`11@D40@4100451@@0m?Cd0?clo04=3@`0n?Sh0@D510410@00o?cl0
@D5104=3@`0n?Sh203lo?`0503dm?@15ADD0?Shn03dm?@0o?cl00P0m?Cd203hn?P0403dm?@0n?Sh0
?Shn03Xj>P80>c/k00@0@41004=3@`0o?cl0?Shn0`0m?Cd01@0o?cl0ATI603`l?00l?3`0?Shn0080
@D5102H0?Shn03lo?`13@d<0@d=304A4A00o?cl0?Cdm04E5A@12@T80@D5104=3@`15ADD0B4Q804E5
A@0o?cl0?Shn03dm?@0o?cl0@T9204A4A012@T80@4100492@P13@d<0B4Q805MGE`1?Cdl0A4A404];
B`14A4@0AdM70492@P18B4P0BDU904i>CP17AdL0CDe=04Y:BP80E5AD00X0CDe=04M7A`1<C4`0CDe=
05ADE01EEED0EUIF05=CD`1QHF40Hf=S0P1VIVH01`1ZJVX0Kfm_06i^KP1aLG40MgMg07QhN020P800
0P27QhL03`2:RXX0V9RH09nOW`2LW9`0WIfM0:>SX`2][Jd0]KFe0;>c/`2b/[80^[Zj0;no_`33`l<0
a/K60<_;b`020<k>cP040=?Cd`3AdM40d];B0=GEe@80d=3@00D0e=CD0=?Cd`3Kfm/0h>3P0=oOg`0=
ooooo`004?ooool02@3Lg=`0gMgM0=oOg`3MgMd0g=cL0=kNgP3Ogml0g]kN0=oOg`020=kNgP80f][J
00D0h^;R0=kNgP3Rh^80kNg]0>OWi`020>;RhP070=kNgP3Ph>00g=cL0=kNgP3Ogml0hN7Q0=gMg@02
0>3Ph0050>;RhP3QhN40h^;R0=oOg`3QhN400P3Ph>000`3QhN40h^;R0>7Qh@020>3Ph0050>7Qh@3R
h^80h^;R0>7Qh@3Rh^800P3QhN402@3Rh^80h>3P0>3Ph03Ph>00hN7Q0>;RhP3Ph>00fMWI0=oOg`02
0>GUi@090>3Ph03QhN40i>CT0>?Sh`3Ogml0h>3P0>CTi03Shn<0hN7Q0080gmoO0`3Ph>020=oOg`80
gMgM00X0g=cL0<k>cP20P800JVYZ0:FUY@3Lg=`0gmoO0=gMg@3Ogml0gMgM0P3QhN401@3Ph>00g=cL
0=oOg`3Ph>00h^;R0080hn?S01`0h^;R0>GUi@3Ph>00gmoO0>;RhP3QhN40hn?S0>;RhP3Ti>@0hn?S
0>;RhP3Ti>@0hN7Q0=kNgP3QhN40hn?S0>KViP3Ph>00hN7Q0>3Ph03MgMd0f][J0=WIf@3Kfm/0g=cL
0=WIf@3Fe]H0f][J0P3Kfm/0103Lg=`0g]kN0=cLg03Lg=`20=_Kf`0>0=gMg@3GemL0fMWI0=;BdP2a
/K40I6AT05UIF@2BTY80eMGE0=[JfP3GemL0f][J0=_Kf`3MgMd30=[JfP070=SHf03MgMd0f=SH0=SH
f03IfMT0g=cL0=gMg@040=cLg00>0=[JfP3Kfm/0fm_K0=cLg03GemL0e]KF0=OGe`3Hf=P0fMWI0=SH
f03Fe]H0emOG0=cLg03Jf]X20=SHf00>0=[JfP3EeMD0eMGE0=WIf@3GemL0e=CD0=?Cd`3EeMD0d];B
0=3@d03AdM40dm?C0=3@d039bLT20<k>cP070=3@d03Cdm<0clo?0=7Ad@3@d=00dM7A0=3@d0020<_;
b`090<c<c03@d=00e=CD0<k>cP3Cdm<0e=CD0=GEe@3GemL0eMGE0080e=CD01P0e]KF0=CDe03?cll0
clo?0<[:bP3<c<`0cLg=0=;BdP3Cdm<0e=CD0=3@d03Bd]80d=3@0<k>cP3?cll0c<c<0<W9b@3@d=00
dM7A0=?Cd`3Fe]H0d=3@0=7Ad@3<c<`30=3@d00<0<c<c031`L40`/;20<o?c`38b<P0a/K60<G5a@31
`L40`l?30<30`02g]kL0aLG50P2l_;`0302j^[X0_;bl0;Rh^02i^KT0^k^k0;Rh^02g]kL0/[:b0:ZZ
ZP2TY:@0WinO0:>SX`80YjNW00`0Y:BT09^KV`2FUYH0Ti>C09BDU02ATI40S8b<08N7Q`21PH40Ph>3
07alO01fMWH2075aL@0=06][J`1WIfL0HF5Q05YJFP1MGEd0GemO05]KF`1HF5P0DU9B04e=C@1>CTh0
DE5A04Y:BP0204U9B@0=04I6AP15ADD0A4A403hn?P0o?cl0?Cdm0410@00n?Sh0?clo0492@P11@D40
@4100451@@020492@P0304=3@`10@400@4100080@41000D0?Shn0410@011@D40?Shn03lo?`020410
@0070492@P10@400?clo0451@@13@d<0ADE50451@@030492@P80@D5101L0ADE504A4A018B4P0ADE5
04=3@`16ATH0@D5103lo?`15ADD0BTY:04=3@`14A4@0BTY:04A4A011@D40A4A404E5A@18B4P0BTY:
04E5A@1<C4`0@d=30492@P0204E5A@0B04I6AP13@d<0ATI60410@015ADD0BTY:04e=C@1<C4`0@D51
04E5A@1:BTX0Bd];04U9B@15ADD0BTY:04I6AP18B4P0ATI60P17AdL02@1@D500AdM704E5A@15ADD0
BTY:04I6AP15ADD0BDU904Q8B00204Y:BP0U04I6AP1ADE40D51@04a<C01BDU80E5AD05EEE@1KFe/0
HV9R06MWI`1XJ6P0JFUY06a/K01hN7P0OGem07alO01jNWX0Ph>30820P029RHT0S8b<08^;R`2ATI40
VYZJ0:6QX@2OWil0YjNW0:^[Z`2/[:`0[jn_0;Vi^@2g]kL0`l?30<K6aP37alL0aLG50<30`0020<o?
c`0U0<c<c03?cll0dM7A0=GEe@3Bd]80e]KF0=OGe`3Jf]X0g=cL0=_Kf`3Lg=`0fm_K0=cLg03MgMd0
g]kN0=cLg03MgMd0h>3P0=cLg03Kfm/0g=cL0>CTi03Shn<0hN7Q0=kNgP3QhN40h^;R0=oOg`3Ph>00
g]kN0>GUi@3Ogml0h^;R0>3Ph03Ng]h0d];B0=gMg@020>;RhPgooooo000@ooooo`050=kNgP3Ph>00
h^;R0=gMg@3Ng]h00P3Ph>00403MgMd0g]kN0>3Ph03QhN40gMgM0=oOg`3UiND0h>3P0>;RhP3QhN40
h^;R0>3Ph03QhN40gMgM0=oOg`3Ng]h20=cLg0060>3Ph03MgMd0fm_K0<71`@2d];@0clo?0P3MgMd0
203QhN40h^;R0>?Sh`3QhN40h^;R0>7Qh@3Ng]h0hN7Q0P3Ng]h00`3Ph>00hn?S0>;RhP020>7Qh@0?
0=oOg`3QhN40h^;R0=oOg`3Shn<0h>3P0=oOg`3Jf]X0h>3P0>KViP3QhN40hn?S0>GUi@3Shn<0i>CT
0080hn?S00P0g]kN0=oOg`3Ng]h0g=cL0>3Ph03Ogml0g=cL0=gMg@80g=cL0P3MgMd02`3Ng]h0`L71
07=cL`1XJ6P0^;Rh0>;RhP3Shn<0g]kN0=oOg`3Ng]h0hn?S0080h^;R00<0g]kN0>;RhP3QhN400P3R
h^80103Ph>00gmoO0>;RhP3Ogml20>7Qh@0:0=oOg`3Shn<0i>CT0>;RhP3QhN40gmoO0>7Qh@3Ogml0
g]kN0=cLg080g]kN00L0h>3P0=KFeP3IfMT0g=cL0=_Kf`3IfMT0f=SH0080g=cL00<0f=SH0=_Kf`3M
gMd00P3Lg=`01P3Jf]X0g]kN0=cLg03Kfm/0f=SH0=OGe`80eMGE00P0dm?C0<K6aP2][Jd0/[:b0<[:
bP3Jf]X0g=cL0=[JfP80fm_K00X0f=SH0=WIf@3Fe]H0fMWI0=OGe`3Hf=P0emOG0=_Kf`3Fe]H0fMWI
0P3Kfm/20=[JfP0K0=KFeP3GemL0fMWI0=SHf03Fe]H0emOG0=;BdP3Fe]H0f=SH0=7Ad@3=cLd0c/k>
0<o?c`3Cdm<0g=cL0=OGe`3Cdm<0c/k>0<o?c`3Fe]H0emOG0=[JfP3EeMD0dm?C0=3@d03=cLd0d=3@
0080dM7A00/0c/k>0<[:bP3:b/X0c/k>0<c<c03=cLd0a/K60=CDe03@d=00b<S80<O7a`020<W9b@0E
0<S8b03<c<`0dM7A0;^k^`36a/H0b/[:0<_;b`34a<@0alO70<G5a@33`l<0`<300;^k^`2l_;`0`l?3
0;fm_@2k^k/0_;bl0;jn_P2k^k/0_;bl0080^[Zj02@0]kNg0;>c/`2b/[80[Jf]0:n_[`2WYjL0Z:RX
0:JVYP2WYjL0XZ:R0:NWY`2MWId0Vi^K09BDU02BTY80SXj>08N7Q`23Ph<0QHF50861P@20P800Ng]k
07=cL`1^KVh0Lg=c06YZJP1]KFd0HV9R06QXJ01QHF40GEeM05YJFP1QHF40GEeM05EEE@1JFUX2059B
DP0G04m?C`1>CTh0D51@04i>CP1BDU80E5AD04];B`1>CTh0ATI604M7A`16ATH0BTY:04=3@`10@400
@T920451@@13@d<0?clo03dm?@11@D40@T9204=3@`11@D400P10@4003P13@d<0A4A404=3@`12@T80
@D5104=3@`0o?cl0?Shn0410@00o?cl0@T9204=3@`0j>SX0?Shn0P0l?3`01`0o?cl0@4100492@P18
B4P0A4A404=3@`19BDT00P11@D401`16ATH0@d=303hn?P13@d<0@T9204Q8B015ADD00P14A4@07`17
AdL0ATI604m?C`19BDT0@d=304I6AP19BDT0Cdm?04e=C@1?Cdl0EeMG04i>CP1@D500EEEE05aLG01M
GEd0IFEU06ATI01RHV80HF5Q05ADE01EEED0EeMG05YJFP1EEED0C4a<05YJFP1GEeL0Cdm?051@D01E
EED00P1KFe/0201ADE40EEEE04i>CP1@D500De=C05eMG@1PH600G5aL0P1GEeL00`1KFe/0JFUY06QX
J00206=SH`0506][J`1cLg<0L71`07EeM@1iNGT00P1jNWX208:2PP0608N7Q`2;Rh/0SHf=08n?S`2:
RXX0UIFE0P2GUiL01P2MWId0Y:BT0:BTY02][Jd0[Zj^0:JVYP80/;2`00L0^[Zj0;Rh^02k^k/0_;bl
0<?3``39bLT0b/[:0080cLg=00d0c/k>0<_;b`3AdM40dm?C0=;BdP3De=@0eMGE0=CDe03EeMD0dM7A
0=3@d03Cdm<0e]KF0080emOG00/0f=SH0=OGe`3EeMD0f=SH0=cLg03MgMd0g=cL0=_Kf`3Cdm<0d=3@
0=gMg@020=kNgP0C0=[JfP3Lg=`0g]kN0=gMg@3Ng]h0gmoO0=SHf03Lg=`0gMgM0=cLg03Hf=P0g=cL
0>3Ph03Lg=`0fm_K0=oOg`3Ng]h0fm_K0=cLg0020=gMg@070=cLg03Ph>00h^;R0>;RhP3Ng]h0gMgM
0>;RhP030=kNgP050=gMg@3IfMT0f][J0<k>cP3Ng]h00P3Ph>0=ooooo`004?ooool0603Rh^80i>CT
0>GUi@3QhN40g]kN0=oOg`3Ph>00hN7Q0>;RhP3Jf]X0gmoO0=cLg03Ph>00hn?S0>7Qh@3Rh^80hn?S
0>;RhP3Ph>00hn?S0=kNgP3Ph>00gMgM0=oOg`80g]kN00X0gmoO0=CDe02BTY80QHF50<W9b@3Rh^80
g]kN0=gMg@3Ph>00h^;R0P3Ogml0103Ph>00g=cL0=kNgP3Ogml20=kNgP050>3Ph03QhN40hN7Q0>3P
h03Ng]h00P3Rh^802P3Ogml0gMgM0=cLg03QhN40gmoO0>3Ph03Ng]h0gmoO0>;RhP3Ti>@20>;RhP05
0>3Ph03Ng]h0g=cL0=oOg`3MgMd00`3Ph>00103QhN40h>3P0=gMg@3MgMd20=kNgP080=oOg`2h^;P0
L71`07alO03<c<`0h>3P0=cLg03Ng]h20=oOg`050>3Ph03QhN40h>3P0=oOg`3Ng]h00P3QhN403@3R
h^80gmoO0=cLg03Ph>00g=cL0=gMg@3Ogml0h>3P0=oOg`3Ng]h0g=cL0=gMg@3Ph>000P3MgMd0503P
h>00g=cL0=kNgP3Ph>00g]kN0=WIf@3Ng]h0gMgM0=[JfP3Kfm/0fMWI0=SHf03GemL0f=SH0=[JfP3K
fm/0emOG0=KFeP3Jf]X0g=cL0P3IfMT04@3Fe]H0e=CD0=?Cd`3AdM40e]KF0=WIf@3GemL0fMWI0=kN
gP3Kfm/0e]KF0=SHf03De=@0dm?C0=KFeP3EeMD0dM7A0080e=CD00T0d=3@0=CDe03Fe]H0emOG0=WI
f@3GemL0e]KF0=;BdP3>c/h00P3IfMT03`3EeMD0e]KF0=CDe03EeMD0c/k>0=;BdP3AdM40c<c<0<k>
cP3AdM40d=3@0=_Kf`3Rh^80c/k>0<[:bP020<W9b@0G0=7Ad@3=cLd0cLg=0<_;b`37alL0`l?30<C4
a035aLD0a/K60<G5a@2m_Kd0^KVi0;Ng]`2k^k/0]KFe0;fm_@2f][H0^[Zj0:n_[`2XZ:P0Xj>S09nO
W`2JVYX00P2OWil02@2KVi/0Ti>C09BDU02ATI40S8b<08V9R@1oOgl0MgMg08B4Q00207IfMP0307Qh
N01]KFd0Kfm_0080JFUY00X0IFEU06IVIP1PH600H61P05]KF`1EEED0De=C05MGE`1DE5@0Cdm?0P1C
De<01P1ADE40CTi>04];B`1ADE40CDe=04U9B@80BTY:00h0@T9204I6AP16ATH0AdM704=3@`14A4@0
@d=304A4A00n?Sh0@T920410@017AdL0A4A404=3@`<0@D5100d0?Shn0410@012@T80?clo0410@013
@d<0?clo0492@P11@D40?clo04M7A`15ADD0@D510080@41000<0?Shn0451@@0n?Sh00P0o?cl203hn
?P0;0492@P0o?cl0?Shn04=3@`16ATH0@T9203lo?`0n?Sh0@T9204I6AP14A4@00`12@T801011@D40
@41003lo?`12@T8204I6AP0<04Y:BP15ADD0ATI604m?C`1:BTX0AdM704=3@`18B4P0C4a<04Y:BP15
ADD0AdM70P19BDT03@1>CTh0D51@04m?C`19BDT0Cdm?05EEE@1ADE40DU9B051@D01HF5P0EUIF055A
D@1@D5000P1IFET02P1FEUH0Fe]K05EEE@1SHf<0IfMW06EUI@1`L700JFUY06a/K01`L70307QhN00:
07AdM01gMgL0O7al07inOP22PX80RHV908j>SP2EUID0TY:B09JFUP80VIVI01/0WIfM0:6QX@2RXZ80
[Jf]0:NWY`2VYZH0[Jf]0;Jf]P2l_;`0_Kfm0;Zj^P2f][H0_kno0<71`@32`/80_kno0<O7a`36a/H0
b<S80<W9b@3?cll0dm?C0=;BdP3De=@0d];B0<g=c@3Cdm<00P3?cll04@3Bd]80dM7A0=;BdP3IfMT0
e=CD0=KFeP3IfMT0eMGE0=[JfP3Fe]H0b/[:0=WIf@3Cdm<0emOG0=WIf@3GemL0e]KF0080fm_K00d0
emOG0=SHf03Jf]X0f=SH0=WIf@3Kfm/0emOG0=WIf@3Fe]H0fMWI0=GEe@3De=@0eMGE0080e=CD00T0
eMGE0=SHf03GemL0f][J0=SHf03Cdm<0f=SH0=WIf@3Lg=`00P3De=@03`3Fe]H0e=CD0=cLg03Lg=`0
fMWI0=_Kf`3MgMd0hN7Q0=[JfP3MgMd0fm_K0=SHf03Ph>00g=cL0=[JfP020=cLg0060=kNgP3MgMd0
hN7Q0>3Ph03Rh^80fMWI0P3MgMd01@3Hf=P0g]kN0=kNgP3Ph>00h^;R0080gmoO00D0h>3P0=cLg03N
g]h0g]kN0>3Ph0020=oOg`040=7Ad@3MgMd0gmoO0=oOg`gooooo000@ooooo`030>CTi03Shn<0h^;R
0080hN7Q00D0hn?S0>7Qh@3Ph>00g]kN0=_Kf`020=gMg@040=oOg`3Ph>00gmoO0=oOg`@0h>3P01X0
gmoO0=cLg03Lg=`0gMgM0=SHf03Jf]X0e=CD0<c<c027QhL0QHF50=CDe03QhN40h>3P0>?Sh`3Rh^80
hN7Q0=kNgP3Ogml0h>3P0=cLg03MgMd0g=cL0=kNgP3Ph>00gmoO0=kNgP80fm_K00D0fMWI0=kNgP3O
gml0g=cL0>3Ph0020>7Qh@040=oOg`3QhN40hN7Q0=cLg080h>3P00/0gmoO0>?Sh`3Ph>00g]kN0=oO
g`3Ph>00gmoO0>7Qh@3Ogml0hN7Q0>3Ph0020=oOg`0J0>7Qh@3Ogml0g]kN0=gMg@39bLT0];Bd0;fm
_@3GemL0gmoO0>3Ph03Ogml0f=SH0=cLg03QhN40h>3P0>7Qh@3Rh^80fm_K0=oOg`3QhN40h>3P0=oO
g`3Kfm/0g]kN0>;RhP3MgMd20=kNgP040=oOg`3Ng]h0gMgM0=cLg0<0fm_K00l0f][J0>3Ph03MgMd0
h>3P0=cLg03EeMD0fm_K0=[JfP3IfMT0f][J0=KFeP3IfMT0f=SH0=?Cd`3GemL00`3EeMD06P3IfMT0
emOG0=OGe`3EeMD0dm?C0=;BdP3@d=00cLg=0<o?c`38b<P0d=3@0<o?c`3Bd]80dM7A0<_;b`3De=@0
e]KF0=GEe@3?cll0cLg=0=7Ad@3Bd]80cLg=0<71`@35aLD0bLW90`36a/H08@32`/80^[Zj0<;2`P2n
_[h0[jn_0;6a/@2c/k<0^;Rh0;>c/`2/[:`0Zj^[0:RXZ02TY:@0Z:RX0:BTY02SXj<0WYjN0:2PX02J
VYX0Vi^K09:BTP2=SHd0SXj>08R8R02:RXX0Rh^;07moO`21PH40P82007QhN01aLG40L71`06YZJP02
06MWI`06061PH01IFET0H61P061PH01OGel0F5QH0P1DE5@01`1=CDd0DU9B04e=C@19BDT0BTY:04Q8
B015ADD00P17AdL204E5A@0404I6AP15ADD0A4A40492@P80A4A400D0@D5103hn?P12@T80@41004E5
A@0304=3@`0A04A4A011@D40A4A404=3@`10@400@d=303hn?P13@d<0A4A404=3@`12@T80A4A404=3
@`16ATH0AdM70451@@13@d<00P16ATH01@15ADD0CDe=04E5A@13@d<0@4100080?clo00X0@T9204Y:
BP1<C4`0B4Q804A4A012@T80AdM704Q8B015ADD0@d=30P15ADD05P12@T80BDU904Y:BP1?Cdl0CTi>
04M7A`11@D40ADE504Q8B014A4@0ADE504M7A`1:BTX0@T9204A4A015ADD0B4Q804A4A015ADD0CTi>
05=CD`1ADE4204a<C00=059BDP1FEUH0E5AD04m?C`1CDe<0F5QH05MGE`1MGEd0H61P05aLG01NGUh0
IVIV075aL@0206][J`0A06i^KP1fMWH0KVi^06UYJ@1^KVh0Lg=c07QhN01iNGT0NWYj08>3P`20P800
Ogmo08F5Q@2:RXX0Shn?09JFUP2CTi<00P2GUiL02@2JVYX0WYjN0:BTY02IVIT0Vi^K0:^[Z`2_[jl0
[Jf]0;Bd]0020;Ng]`0=0;^k^`2m_Kd0_;bl0;Vi^@30`<00`l?30<K6aP32`/80alO70<;2`P38b<P0
b/[:0<O7a`020=?Cd`040=GEe@3De=@0f=SH0=WIf@80e=CD01d0f=SH0=KFeP3De=@0g=cL0<k>cP3E
eMD0f=SH0=[JfP3Kfm/0g=cL0=SHf03Jf]X0emOG0=cLg03Hf=P0eMGE0=_Kf`3GemL0eMGE0=CDe03I
fMT0emOG0=GEe@3Kfm/0fMWI0=?Cd`3EeMD0e=CD0=3@d0020=?Cd`090=GEe@3Jf]X0emOG0=?Cd`3H
f=P0e]KF0=SHf03@d=00aLG50080eMGE00X0e]KF0=WIf@3Jf]X0eMGE0=WIf@3Lg=`0f][J0=_Kf`3I
fMT0e]KF0P3Hf=P01@3Bd]80e]KF0=CDe03Hf=P0dm?C0080e=CD00<0d=3@0=KFeP3Fe]H00P3Fe]H0
1`3GemL0fMWI0=CDe03IfMT0e]KF0=SHf03IfMT00P3Hf=P01@3Cdm<0f=SH0=WIf@3GemL0fm_K0080
gMgM00@0fm_K0=gMg@3Hf=P0e]KF0P3Lg=`01@3Jf]X0fMWI0=OGe`3Kfm/0f][J0080fm_K01H0gMgM
0=cLg03Jf]X0g=cL0=[JfP3MgMd0g=cL0=[JfP3Ph>00g]kN0=oOg`3MgMd0fMWI0=_Kf`3Ng]h0h>3P
0=cLg03Jf]X0dm?C0=_Kf`3MgMd0gmoO3Oooool0013ooooo0P3UiND20>;RhP0;0=kNgP3Lg=`0h>3P
0=kNgP3Ph>00hN7Q0=_Kf`3Hf=P0g=cL0>?Sh`3QhN400P3MgMd0103Ng]h0gmoO0=gMg@3Ph>020=cL
g00:0=KFeP38b<P0f=SH0=OGe`2k^k/0QHF509FEU@3De=@0fm_K0=cLg080g]kN00@0hN7Q0=oOg`3N
g]h0g]kN0P3Jf]X0203MgMd0g]kN0=kNgP3Ng]h0h>3P0=gMg@3Kfm/0gMgM0P3Ogml00`3GemL0gMgM
0>7Qh@020=kNgP0:0>7Qh@3MgMd0fm_K0>7Qh@3Rh^80gmoO0>;RhP3Ogml0h>3P0=_Kf`80gmoO00<0
h>3P0=kNgP3Ogml00P3MgMd02P3Ogml0g]kN0=cLg03Lg=`0fm_K0=SHf03Ogml0h>3P0=[JfP3IfMT2
0=kNgP080=_Kf`3Jf]X0h>3P0>3Ph03Ogml0h>3P0=_Kf`3Hf=P20=_Kf`050=WIf@3Kfm/0fm_K0=gM
g@3IfMT00`3Lg=`04@3Kfm/0g=cL0=WIf@3EeMD0fMWI0=GEe@3De=@0fMWI0=GEe@3De=@0dM7A0=CD
e03Fe]H0emOG0=KFeP3;bl/0b<S80080c<c<01h0bLW90<K6aP36a/H0c<c<0<[:bP38b<P0aLG50<C4
a035aLD0`l?30;Vi^@2_[jl0[Jf]0:j^[P2QXJ40YJFU0::RXP2PX:00WinO0:>SX`2VYZH0YjNW0:FU
Y@2FUYH0TY:B08^;R`2BTY80Rh^;08J6QP1oOgl207alO00807EeM@1hN7P0L71`07EeM@1cLg<0Kfm_
05iNGP1QHF4205eMG@0C05YJFP1GEeL0EEEE04i>CP1@D500DU9B051@D01CDe<0Bd];04U9B@1>CTh0
DU9B04Y:BP19BDT0BTY:04Q8B017AdL0Bd];04M7A`0304I6AP0304M7A`19BDT0BDU90080AdM700<0
@d=304A4A014A4@00P17AdL00`13@d<0A4A404M7A`0204=3@`0504M7A`18B4P0A4A404A4A015ADD0
0P16ATH01011@D40ADE504Q8B015ADD204=3@`0U0492@P15ADD0ADE504U9B@17AdL0A4A404M7A`14
A4@0@D5104E5A@19BDT0B4Q8051@D01<C4`0F5QH05eMG@1FEUH0EeMG05]KF`1=CDd0BDU904i>CP1G
EeL0E5AD05mOG`1LG5`0De=C05]KF`1ADE40AdM705=CD`1?Cdl0CTi>04];B`1CDe<0CDe=05UIF@02
065QH@80GemO00H0G5aL05YJFP1OGel0HF5Q06=SH`1MGEd2061PH00>069RHP1VIVH0KVi^06i^KP1W
IfL0Lg=c06a/K01fMWH0OWin08J6QP25QHD0QXJ608Z:RP2;Rh/208j>SP09092@T02GUiL0TY:B09FE
U@2NWYh0YZJV0:^[Z`2TY:@0YjNW0080[jn_0180Zj^[0;Bd]02c/k<0YZJV0;6a/@2][Jd0/[:b0;Jf
]P2g]kL0_[jn0;Vi^@2d];@0^;Rh0;bl_02j^[X0_Kfm0;jn_P36a/H20<S8b00;0<?3``30`<00b<S8
0<S8b036a/H0bLW90<[:bP3?cll0c<c<0<[:bP3@d=000P3?cll03`2o_kl0`<300<o?c`3@d=00dM7A
0=?Cd`3AdM40e=CD0=WIf@3GemL0eMGE0=?Cd`3Fe]H0emOG0=cLg0020=SHf0<0f][J00d0fMWI0=SH
f03Jf]X0gmoO0=cLg03Fe]H0g=cL0=[JfP3Kfm/0e]KF0=;BdP3EeMD0fMWI0080d=3@00H0g=cL0=_K
f`3Jf]X0f=SH0=KFeP3IfMT20=OGe`080=_Kf`3EeMD0f=SH0=KFeP3Jf]X0f=SH0=_Kf`3GemL20=SH
f0070=[JfP3Cdm<0dM7A0=7Ad@3>c/h0dm?C0<k>cP020=SHf00K0=[JfP3GemL0fMWI0=KFeP3GemL0
d];B0<g=c@3IfMT0e]KF0=GEe@3GemL0f][J0=SHf03IfMT0fm_K0=[JfP3Lg=`0fMWI0=CDe03EeMD0
emOG0=;BdP3EeMD0d=3@0=?Cd`3?cll0d];B0080dM7A00@0f=SH0=OGe`3EeMD0f=SH0P3GemL02P3D
e=@0f][J0=GEe@3IfMT0emOG0=SHf03GemL0c/k>0=OGe`3Lg=`20=_Kf`070=[JfP3Kfm/0f][J0=_K
f`3Lg=`0fMWI0=KFeP020=[JfP040=WIf@3GemL0f][J0=[JfP80g=cL0P3Kfm/20=kNgP070=WIf@3N
g]h0gMgM0=cLg03Ogml0g]kN0=cLg0020=gMg@80g]kN00L0hN7Q0=oOg`3Lg=`0dm?C0=_Kf`3Ph>00
hN7Q00gooooo000@ooooo`090>;RhP3Ph>00gmoO0=cLg03@d=00]KFe0=cLg03Ogml0gMgM0080gmoO
0P3Jf]X08`3Ph>00g=cL0=[JfP3GemL0f][J0=_Kf`3Lg=`0fm_K0=[JfP3IfMT0emOG0=?Cd`3Jf]X0
e]KF0<;2`P2_[jl0_Kfm0=[JfP3Lg=`0eMGE0=OGe`3IfMT0f][J0=_Kf`3IfMT0f][J0=_Kf`3Hf=P0
gMgM0=oOg`3Jf]X0g=cL0=[JfP3Kfm/0fMWI0080g=cL0P3Kfm/01`3GemL0f=SH0=_Kf`3Ng]h0h^;R
0=gMg@3Ng]h00P3Ogml20>3Ph0080=_Kf`3Ogml0f=SH0=cLg03Ng]h0gmoO0=[JfP3Ogml30=WIf@03
0=KFeP3EeMD0f][J0080emOG0P3IfMT0103EeMD0e]KF0=[JfP3GemL20=WIf@80f][J00<0emOG0=WI
f@3Fe]H00P3Bd]801`3AdM40c<c<0<g=c@3?cll0cLg=0<c<c03>c/h00P3:b/X00`37alL0b<S80<G5
a@020<30`080]kNg01/0];Bd0;2`/02/[:`0XZ:R0:BTY02SXj<0XJ6Q09bLW02KVi/0TY:B08f=S@2?
Shl0PX:207moO`1iNGT0Ogmo07EeM@1_Kfl0KVi^071`L01VIVH0IFEU069RHP1KFe/0E5AD05IFEP1E
EED00P1ADE40101;Bd/0ATI604Y:BP1;Bd/204Q8B00504U9B@1:BTX0BTY:04];B`18B4P00`16ATH0
0`13@d<0B4Q804A4A00204=3@`0304Y:BP15ADD0ADE50080ATI600P0ADE504A4A015ADD0ADE504A4
A01;Bd/0A4A404U9B@80ATI600<0Bd];04Y:BP1<C4`00P19BDT00`1:BTX0BDU904M7A`0204I6AP0:
04E5A@17AdL0BTY:04Q8B019BDT0B4Q804I6AP1<C4`0ATI604Q8B080Bd];00<0@T9204=3@`16ATH0
0P1;Bd/01P1?Cdl0D51@04m?C`19BDT0@d=304a<C080AdM700P0BTY:04m?C`1@D500EUIF05ADE01H
F5P0FUYJ06EUI@<0HF5Q00@0Fe]K069RHP1IFET0G5aL0P1MGEd0>@1RHV80Kfm_06i^KP1bLW80MGEe
07IfMP1dM7@0NGUi07AdM024Q8@0NWYj07emO@28R8P0SHf=092@T02HV9P0Ti>C09FEU@2BTY80TI6A
08n?S`2DU9@0V9RH0:6QX@2PX:00Xj>S0:VYZ@2UYJD0YZJV0:RXZ02^[Zh0Zj^[0:VYZ@2WYjL0[:b/
0;:b/P2/[:`0/K6a0:f][@2/[:`0^k^k0;bl_036a/H0`L710;no_`34a<@0bLW90<[:bP3;bl/0bLW9
0<[:bP3<c<`0b<S80<W9b@3;bl/0alO70<k>cP020=3@d00A0=?Cd`3@d=00clo?0<o?c`3=cLd0dM7A
0=3@d03Fe]H0d=3@0;Vi^@3;bl/0b<S80<[:bP39bLT0b<S80=GEe@3;bl/00P3:b/X03P3@d=00b<S8
0<K6aP33`l<0alO70=KFeP3EeMD0dM7A0<o?c`3Cdm<0d=3@0<_;b`3<c<`0c/k>0P3=cLd02P3?cll0
dM7A0<o?c`3<c<`0a<C40<[:bP3EeMD0e=CD0=GEe@3Fe]H20=WIf@0:0=[JfP3GemL0f=SH0=SHf03K
fm/0emOG0=WIf@3Jf]X0f=SH0=[JfP80fm_K01D0f=SH0=GEe@3IfMT0emOG0=[JfP3GemL0f][J0=_K
f`3IfMT0emOG0=KFeP3De=@0fMWI0=7Ad@3Bd]80g=cL0=_Kf`3MgMd0emOG0=WIf@3Jf]X00P3GemL2
0=[JfP80fMWI0P3Hf=P00`3GemL0fm_K0=SHf0020=SHf0040=[JfP3Hf=P0e]KF0=;BdP80dm?C0180
fMWI0=KFeP3Hf=P0emOG0=SHf03De=@0f][J0=SHf03AdM40g=cL0=GEe@3Fe]H0f=SH0=[JfP3IfMT0
f][J0=KFeP3GemL20=[JfP070=KFeP3De=@0emOG0=?Cd`3GemL0e]KF0=OGe`020=GEe@0<0=CDe03C
dm<0emOG0=KFeP3Jf]X0g=cL0=_Kf`3Lg=`0f=SH0=_Kf`3GemL0fMWI0P3Lg=`01P3Kfm/0d=3@0=cL
g03Ng]h0gMgM0=_Kf`80f][J00<0g=cL0=WIf@3Jf]X00P3IfMT02`3MgMd0f=SH0=cLg03IfMT0g=cL
0=_Kf`3Lg=`0f][J0=WIf@3MgMd0g=cL0080gMgM00`0g=cL0=kNgP3Ng]h0g=cL0=oOg`3MgMd0gmoO
0>3Ph03QhN40h>3P0=kNgP3IfMT20=KFeP030=_Kf`3Ogml0h>3P00gooooo000@ooooo`0<0>3Ph03M
gMd0hN7Q0=oOg`39bLT0XZ:R0=KFeP3Vi^H0h>3P0>7Qh@3Ph>00g=cL0P3Ph>005P3Lg=`0g]kN0=[J
fP3Ng]h0f][J0=cLg03Hf=P0f][J0=WIf@3De=@0eMGE0=KFeP3Cdm<0d];B0=KFeP3Ng]h0gmoO0=_K
f`3EeMD0dm?C0=GEe@3Fe]H30=GEe@0d0=;BdP3IfMT0f][J0=SHf03GemL0eMGE0=SHf03MgMd0gmoO
0=WIf@3Hf=P0fm_K0=cLg03AdM40emOG0=WIf@3Lg=`0fMWI0=gMg@3Jf]X0hN7Q0>CTi03Lg=`0fm_K
0=cLg03Ng]h0c/k>0=OGe`3Jf]X0emOG0=SHf03Lg=`0clo?0<g=c@3AdM40c/k>0<G5a@3;bl/0clo?
0=3@d038b<P0`L710;Zj^P2n_[h0`/;20<K6aP35aLD0`L710;fm_@2j^[X0^;Rh0;Vi^@80^;Rh00T0
[jn_0:NWY`2SXj<0WYjN09NGU`2BTY80TI6A08f=S@27QhL00P29RHT02`26QXH0NGUi07EeM@1iNGT0
KFe]05eMG@1QHF40Hf=S05YJFP1@D500FEUI0080E5AD00D0D51@04m?C`1;Bd/0Bd];04i>CP0204I6
AP0:0451@@16ATH0@d=304A4A015ADD0Bd];04=3@`14A4@0@d=304E5A@<0@T9200<0ATI604];B`12
@T800P10@400<`16ATH0@d=303lo?`13@d<0BTY:04Q8B012@T80?Shn0410@018B4P0ADE503lo?`12
@T80@d=304];B`1:BTX0AdM70451@@15ADD0ATI604A4A013@d<0ADE504Y:BP1DE5@0Cdm?04i>CP1<
C4`0E5AD051@D018B4P0De=C051@D01?Cdl0CTi>05=CD`1@D500DU9B05QHF01PH600FEUI05MGE`1D
E5@0EEEE055AD@1EEED0DE5A04U9B@1?Cdl0CTi>05ADE00205QHF00705=CD`1GEeL0GEeM06ATI01U
IFD0I6AT06QXJ00206YZJP0;06UYJ@1[Jf/0IFEU06i^KP1]KFd0KVi^07emO@23Ph<0OGem0820P025
QHD00P2CTi<08`2EUID0Vi^K09fMW@2MWId0SXj>0:>SX`2VYZH0Xj>S0:BTY02/[:`0[jn_0;Ng]`2b
/[80]KFe0;jn_P32`/80`l?30<o?c`33`l<0_[jn0<O7a`3;bl/0b/[:0=7Ad@39bLT0b/[:0<g=c@3>
c/h0a/K60<G5a@3<c<`0bl_;0<G5a@39bLT0c<c<0080bl_;0140clo?0<c<c037alL0`L710<?3``30
`<00_Kfm0<?3``34a<@0_[jn0;^k^`38b<P0a/K60<o?c`3>c/h0alO70<c<c0020=3@d0060<_;b`3>
c/h0bl_;0<k>cP39bLT0aLG50P3;bl/00`3<c<`0c/k>0=;BdP020<o?c`080=3@d03=cLd0cLg=0=7A
d@3EeMD0d];B0<c<c02n_[h20<k>cP040<_;b`38b<P0b<S80=OGe`80cLg=0P3<c<`01P3;bl/0alO7
0<K6aP3:b/X0d=3@0=7Ad@80d];B00L0dM7A0=3@d03<c<`0c<c<0<g=c@39bLT0c<c<00<0c/k>00/0
bl_;0<G5a@39bLT0d];B0=GEe@3Bd]80clo?0=7Ad@3EeMD0fm_K0=KFeP020=?Cd`080>7Qh@3EeMD0
emOG0=CDe03EeMD0emOG0=_Kf`3Hf=P20=CDe0060=cLg03IfMT0emOG0=OGe`3Hf=P0fm_K0P3Jf]X0
703IfMT0e]KF0=OGe`3@d=00d];B0=SHf03MgMd0f][J0=KFeP3IfMT0eMGE0=KFeP3IfMT0g=cL0=[J
fP3EeMD0f=SH0=KFeP3Hf=P0e]KF0=_Kf`3IfMT0f][J0=GEe@3Kfm/0eMGE0=KFeP3EeMD20=7Ad@0;
0=?Cd`3De=@0e]KF0=KFeP3EeMD0dm?C0=gMg@3Jf]X0clo?0=gMg@3Fe]H00P3Jf]X20=kNgP0;0=oO
g`3Jf]X0eMGE0=SHf03MgMd0gmoO0=3@d03De=@0e]KF0=[JfP3IfMT00P3GemL03@3Hf=P0e=CD0=7A
d@3Hf=P0f][J0=_Kf`3Lg=`0gMgM0=kNgP3GemL0g]kN0=cLg03Ng]h00P3Jf]X02@3IfMT0d=3@0=OG
e`3Jf]X0gMgM0=kNgP3Lg=`0fMWI0=gMg@020=[JfP030=_Kf`3MgMd0h>3P0080g=cL00H0f][J0>3P
h03Ng]h0h>3P0=cLg03Jf]X40=gMg@060=WIf@3MgMd0h>3P0>?Sh`3Ph>00gmoO0P3Ph>002@3Shn<0
h>3P0=oOg`3Lg=`0fMWI0=KFeP3Lg=`0g]kN0>7Qh@0=ooooo`004?ooool00`3Ogml0g]kN0=kNgP02
0=WIf@030=KFeP3Ogml0gMgM0080fm_K0P3Jf]X01`3Hf=P0f][J0=_Kf`3Fe]H0e=CD0=WIf@3GemL0
0P3IfMT05@3Lg=`0g]kN0=_Kf`3EeMD0e=CD0=GEe@3Cdm<0fMWI0=gMg@3Kfm/0emOG0=WIf@3De=@0
dM7A0=OGe`3De=@0eMGE0=;BdP3?cll0dm?C0=KFeP020=CDe0050=GEe@3Fe]H0d];B0=WIf@3De=@0
0P3GemL02`3Hf=P0e=CD0=?Cd`3>c/h0eMGE0=7Ad@3=cLd0`l?30<_;b`3<c<`0c/k>0080b/[:00d0
`L710;^k^`2l_;`0_Kfm0;:b/P2[Zj/0/K6a0:f][@2UYJD0Y:BT09bLW02<S8`0SXj>0080Shn?0140
QHF507]kN`1kNg/0PH6107]kN`1jNWX0L71`06i^KP1]KFd0IVIV06QXJ01VIVH0HV9R06EUI@1MGEd0
GemO055AD@0204a<C00F04i>CP1=CDd0BDU904Q8B01>CTh0BTY:04Q8B019BDT0ATI604Q8B016ATH0
ADE504U9B@16ATH0@d=30410@019BDT0@D5104A4A010@400ADE504I6AP80A4A40280@41004=3@`15
ADD0@d=304E5A@13@d<0ADE504=3@`12@T80ADE50410@013@d<0ADE50492@P15ADD0A4A404M7A`14
A4@0@d=30492@P19BDT0@T9203lo?`12@T80BDU904I6AP13@d<0ADE504];B`16ATH0BDU904M7A`1;
Bd/0EUIF0P1PH6001@1KFe/0FEUI04];B`1GEeL0DU9B0080CDe=00P0CTi>05EEE@1LG5`0F5QH05eM
G@1UIFD0Hf=S05mOG`80I6AT02X0H61P06MWI`1[Jf/0K6a/07=cL`1hN7P0RHV908:2PP1nOWh0PX:2
08>3P`21PH40RXZ:08R8R02:RXX0S8b<092@T02ATI40Ti>C09JFUP2HV9P0YJFU0:RXZ02VYZH0Y:BT
0:j^[P2c/k<0][Jf0;>c/`2d];@0]KFe0;6a/@2j^[X0^k^k0;Rh^02l_;`0`L710<30`033`l<0alO7
0<[:bP3;bl/30<[:bP030=?Cd`3>c/h0c<c<0080clo?01`0dM7A0=;BdP3@d=00eMGE0=7Ad@3Cdm<0
eMGE0=?Cd`3Fe]H0emOG0=7Ad@3=cLd0e=CD0=KFeP3EeMD0fm_K0=WIf@3De=@0b/[:0<c<c03:b/X0
bLW90<g=c@3<c<`0bl_;0<W9b@37alL0c<c<0P3?cll0303>c/h0bl_;0<G5a@37alL0^[Zj0;^k^`34
a<@0aLG50;Zj^P2l_;`0cLg=0<O7a`80cLg=02X0c<c<0<O7a`37alL0bl_;0<g=c@3;bl/0c<c<0=3@
d03=cLd0bl_;0<S8b037alL0bl_;0=7Ad@3@d=00c/k>0=?Cd`3?cll0b/[:0<g=c@3>c/h0bLW90<[:
bP3@d=00`l?30<[:bP3>c/h0b<S80<W9b@3;bl/0clo?0<c<c039bLT0bl_;0<g=c@3<c<`0b/[:0<k>
cP3AdM40d=3@0<o?c`3@d=020=;BdP030<o?c`3=cLd0b/[:0080c<c<00<0dm?C0<o?c`3@d=000P3?
cll20<W9b@0@0=3@d03GemL0dm?C0=CDe03GemL0e]KF0=GEe@3GemL0fm_K0=CDe03Ogml0e]KF0=SH
f03De=@0fMWI0=SHf080fMWI0100f][J0=SHf03Jf]X0f=SH0=gMg@3IfMT0fm_K0=WIf@3Lg=`0f][J
0=WIf@3GemL0fm_K0=7Ad@3EeMD0fm_K0P3Jf]X02`3Hf=P0f][J0=SHf03Kfm/0g=cL0=SHf03Kfm/0
emOG0=_Kf`3Jf]X0g=cL0080fMWI00X0f=SH0=_Kf`3Hf=P0g]kN0=WIf@3GemL0f=SH0=KFeP3EeMD0
emOG0P3Hf=P0303EeMD0e=CD0=OGe`3Lg=`0f][J0=3@d03Ng]h0f=SH0=_Kf`3Hf=P0fMWI0>3Ph080
g]kN00@0gMgM0=_Kf`3Jf]X0fm_K0P3IfMT0203Hf=P0e]KF0=[JfP3IfMT0f=SH0=OGe`3Kfm/0emOG
0P3Hf=P0403Lg=`0gMgM0=kNgP3Ng]h0gMgM0>;RhP3Ogml0g=cL0=oOg`3Jf]X0e=CD0<k>cP3IfMT0
g=cL0=SHf03MgMd30=cLg0030=WIf@3Kfm/0gMgM0080g=cL0P3Kfm/0403MgMd0g]kN0=kNgP3MgMd0
fm_K0=[JfP3Kfm/0gmoO0=gMg@3Lg=`0f][J0=cLg03Ogml0hN7Q0=kNgP3MgMd20=oOg`090>3Ph03M
gMd0g]kN0=gMg@3Jf]X0fMWI0=kNgP3Ogml0h>3P00gooooo000@ooooo`030=_Kf`3MgMd0gMgM0080
f][J00d0fm_K0=[JfP3MgMd0fm_K0=OGe`3De=@0d];B0=CDe03GemL0f=SH0=CDe03AdM40eMGE0080
e=CD00<0dM7A0=?Cd`3De=@00P3AdM402`3;bl/0b/[:0<S8b038b<P0`l?30<W9b@38b<P0`<300<71
`@2j^[X0^KVi0080^[Zj01D0^;Rh0;Jf]P2[Zj/0/K6a0:n_[`2^[Zh0[Jf]0:NWY`2TY:@0XJ6Q09nO
W`2PX:00WIfM09ZJVP2EUID0SXj>08b<S02ATI40R8R807UiN@1dM7@00P1cLg<01@1SHf<0HV9R06IV
IP1OGel0FEUI0080Fe]K01D0DE5A051@D01DE5@0C4a<04Y:BP1<C4`0BDU904e=C@1<C4`0B4Q804Y:
BP16ATH0AdM704Q8B01@D500AdM704Q8B013@d<0A4A404=3@`15ADD00P12@T802P0o?cl0A4A403lo
?`12@T80A4A404=3@`0n?Sh0@4100451@@0o?cl20451@@0504A4A016ATH0ATI60492@P10@4000P11
@D401@15ADD0@D5103lo?`13@d<0ADE50080ATI600@0@d=304U9B@16ATH0ADE50P16ATH01P18B4P0
BDU905=CD`1:BTX0AdM704m?C`80CDe=0P1CDe<2059BDP0N05YJFP1HF5P0EEEE05eMG@1IFET0GEeM
05aLG01QHF40Fe]K05mOG`1UIFD0J6QX06][J`1/K6`0MWIf07]kN`1dM7@0O7al0820P01nOWh0PX:2
096AT@2HV9P0VIVI08^;R`28R8P0UYJF09BDU02MWId0Y:BT0P2WYjL0502c/k<0/K6a0;2`/02e]KD0
]kNg0;>c/`2f][H0_Kfm0;^k^`2o_kl0_[jn0<C4a038b<P0bLW90<[:bP3=cLd0`L710<O7a`3:b/X0
b<S80P3Bd]802@3Fe]H0d];B0=GEe@3Bd]80d=3@0=;BdP3GemL0fMWI0=KFeP030=;BdP040<_;b`3D
e=@0c/k>0=3@d080d];B00<0eMGE0=3@d039bLT00`3Bd]801@3EeMD0d];B0=?Cd`3?cll0dM7A0080
clo?00/0emOG0=;BdP3EeMD0f=SH0=CDe03>c/h0e=CD0=OGe`3Cdm<0eMGE0=KFeP020=;BdP0<0=GE
e@3GemL0dM7A0<c<c03Bd]80eMGE0=OGe`3EeMD0cLg=0<o?c`3:b/X0bLW90P3;bl/01@3?cll0c/k>
0<_;b`3<c<`0b<S80080c<c<00D0clo?0<_;b`35aLD0b<S80<O7a`020<?3``80aLG501H0_;bl0<30
`03>c/h0cLg=0=7Ad@3?cll0cLg=0<k>cP3:b/X0c/k>0=;BdP3:b/X0c<c<0<g=c@3<c<`0c/k>0<[:
bP3?cll0dM7A0<o?c`3De=@0dm?C0P3AdM400`3<c<`0d=3@0<g=c@020<[:bP060=;BdP35aLD0a/K6
0=3@d03<c<`0clo?0`3AdM401`3:b/X0bLW90<_;b`3<c<`0b/[:0<S8b03;bl/00P3EeMD0103Cdm<0
fMWI0<o?c`3>c/h20<g=c@030<k>cP3GemL0e]KF0080eMGE00d0c/k>0<o?c`34a<@0cLg=0=GEe@3H
f=P0eMGE0=CDe03GemL0eMGE0=WIf@3Jf]X0fm_K0080f=SH00P0fMWI0=GEe@3GemL0f][J0=GEe@3G
emL0fm_K0=kNgP80fm_K00d0fMWI0=oOg`3IfMT0f=SH0=KFeP3Kfm/0fMWI0=GEe@3Fe]H0g]kN0=[J
fP3Cdm<0g=cL0080fMWI00H0f=SH0=[JfP3Kfm/0gMgM0=cLg03Hf=P20=[JfP040=cLg03MgMd0gMgM
0=gMg@80fMWI01<0fm_K0=SHf03Lg=`0emOG0=WIf@3Hf=P0emOG0=[JfP3Ng]h0fm_K0=OGe`3Fe]H0
f][J0=cLg03Jf]X0fMWI0=?Cd`3Ng]h0fm_K0080f][J00D0fm_K0=kNgP3Kfm/0gMgM0=cLg0020=SH
f080f][J00<0fMWI0=_Kf`3Hf=P00`3Jf]X0103IfMT0f=SH0=[JfP3IfMT20=_Kf`030=cLg03Ng]h0
g]kN0080h>3P01`0g]kN0=gMg@3Kfm/0fMWI0=SHf03@d=00f=SH0=[JfP3GemL0fm_K0=[JfP3Lg=`0
f][J0=cLg03Kfm/0fMWI0=_Kf`3IfMT0g=cL0=SHf03IfMT0g=cL0=oOg`3Lg=`0fm_K0=cLg03Hf=P0
g=cL0P3MgMd01P3Ng]h0gMgM0=kNgP3QhN40gmoO0=gMg@<0h>3P00P0hN7Q0=kNgP3Lg=`0g=cL0=WI
f@3Lg=`0h>3P0>?Sh`gooooo000@ooooo`030=GEe@3<c<`0b/[:0080d=3@00l0c<c<0<W9b@37alL0
`l?30;Ng]`2`/;00/K6a0:j^[P2b/[80[Zj^0;:b/P2[Zj/0XZ:R09ZJVP2NWYh00P2KVi/03`2BTY80
R8R808V9R@1lO7`0P82007moO`1eMGD0JFUY06YZJP1/K6`0Jf][06UYJ@1WIfL0JVYZ05iNGP0205eM
G@0?05aLG01FEUH0FEUI05]KF`1DE5@0DE5A05MGE`1ADE40Cdm?04e=C@1<C4`0CDe=04];B`17AdL0
ADE50080B4Q800@0ADE504I6AP12@T80ADE50`16ATH304A4A00N04Q8B013@d<0@T920492@P17AdL0
@D510492@P17AdL0@T9204E5A@12@T80@d=304I6AP13@d<0ADE504=3@`16ATH0@d=30492@P17AdL0
A4A404I6AP14A4@0ATI604U9B@16ATH0BDU904Q8B016ATH0C4a<0P19BDT02018B4P0Bd];055AD@1B
DU80Cdm?051@D01IFET0G5aL0P1HF5P02P1MGEd0GUiN061PH01QHF40IVIV071`L01gMgL0Jf][07If
MP1iNGT208>3P`0N08:2PP24Q8@0Shn?09NGU`2JVYX0UiNG09fMW@2PX:00Zj^[0:j^[P2[Zj/0[jn_
0;6a/@2d];@0/K6a0;Vi^@2e]KD0YJFU0:f][@2e]KD0_Kfm0;Zj^P2m_Kd0^k^k0;no_`35aLD0a/K6
0<?3``35aLD0cLg=0P3:b/X03`39bLT0d=3@0<[:bP3:b/X0dM7A0<S8b039bLT0bl_;0<G5a@3<c<`0
bLW90<k>cP3Cdm<0d];B0=3@d0020<W9b@030=;BdP3EeMD0dm?C0080c/k>00@0d=3@0=OGe`3De=@0
clo?0P3Fe]H0203De=@0e]KF0=GEe@35aLD0a/K60<o?c`3<c<`0dm?C0P3GemL00`3Hf=P0e]KF0=;B
dP020=;BdP0H0=?Cd`3Bd]80d=3@0=;BdP3?cll0d];B0<o?c`3AdM40cLg=0=7Ad@3@d=00dM7A0=;B
dP3>c/h0cLg=0=?Cd`3EeMD0f][J0=OGe`3Fe]H0e=CD0=?Cd`3Bd]80dM7A0P3Hf=P02P3EeMD0e=CD
0=GEe@3EeMD0dm?C0=7Ad@3>c/h0e=CD0=KFeP3IfMT20=OGe`0F0=GEe@3IfMT0c/k>0<c<c03@d=00
d];B0=KFeP3@d=00cLg=0<k>cP39bLT0b/[:0<c<c03;bl/0c<c<0<g=c@3>c/h0c<c<0<_;b`3:b/X0
bl_;0<o?c`80alO70180bLW90<O7a`3:b/X0clo?0<?3``35aLD0`L710;fm_@3=cLd0dM7A0=;BdP3:
b/X0d=3@0=?Cd`3?cll0d=3@0=CDe03;bl/20<o?c`030<_;b`3=cLd0b/[:00<0cLg=01T0d=3@0=;B
dP3Cdm<0e=CD0<o?c`3<c<`0bl_;0<W9b@3?cll0eMGE0;jn_P35aLD0cLg=0<_;b`3?cll0e]KF0=?C
d`3EeMD0bLW90<g=c@3>c/h0clo?0<c<c03:b/X0c/k>0080e=CD00@0f][J0=WIf@3GemL0d];B0P3H
f=P04P3>c/h0e]KF0=SHf03IfMT0f=SH0=7Ad@3=cLd0aLG50<S8b03Hf=P0e=CD0=GEe@3Fe]H0f][J
0=_Kf`3Ng]h0gMgM0=_Kf`<0emOG00X0f][J0=SHf03Kfm/0e]KF0=SHf03Lg=`0g]kN0=[JfP3Lg=`0
f][J0`3GemL04P3IfMT0g]kN0=[JfP3Fe]H0f=SH0=[JfP3GemL0e=CD0=WIf@3Hf=P0fMWI0=OGe`3I
fMT0fm_K0=kNgP3MgMd0f=SH0=cLg0<0gMgM01H0fm_K0>7Qh@3Lg=`0g=cL0=_Kf`3Jf]X0g=cL0=OG
e`3IfMT0e]KF0=OGe`3Lg=`0g]kN0=oOg`3Kfm/0fMWI0=_Kf`3Jf]X0g]kN0=_Kf`3Fe]H0gmoO0P3P
h>003@3QhN40gmoO0=_Kf`3Ogml0g]kN0=SHf03Fe]H0f][J0=cLg03Kfm/0dM7A0=SHf03Jf]X00P3I
fMT02`3Jf]X0gMgM0=_Kf`3Ogml0fm_K0=kNgP3Lg=`0g]kN0>7Qh@3Shn<0h>3P0080h^;R00L0gmoO
0>;RhP3IfMT0fMWI0<g=c@3Fe]H0fMWI0080gMgM01<0g]kN0=gMg@3Hf=P0gMgM0=cLg03Kfm/0h>3P
0=[JfP3MgMd0gmoO0=WIf@3Kfm/0f][J0=_Kf`3MgMd0h>3P0=cLg03Ph>00gmoO0080g]kN0P3QhN40
103Ph>00gMgM0=oOg`3Shn<20>;RhP080=oOg`3Ph>00hN7Q0>3Ph03Lg=`0h^;R0>KViP3Rh^8=oooo
o`004?ooool04`1mOGd0MWIf07AdM01lO7`0NGUi071`L01aLG40MGEe06UYJ@1KFe/0G5aL05MGE`1L
G5`0F5QH059BDP1ADE40De=C04m?C`1=CDd00P1:BTX0401;Bd/0Cdm?04];B`1<C4`0BTY:04M7A`19
BDT0B4Q804U9B@17AdL0Bd];04U9B@18B4P0BTY:04U9B@16ATH204M7A`0704E5A@1;Bd/0BTY:04M7
A`16ATH0Bd];04Q8B00204U9B@0904e=C@17AdL0BTY:04M7A`15ADD0BDU904e=C@1:BTX0C4a<0080
BDU900P0AdM704];B`1<C4`0D51@04i>CP1@D500DU9B05EEE@80DU9B0P1EEED09P1KFe/0GEeM05iN
GP1MGEd0H61P06EUI@1^KVh0LG5a06e]K@1_Kfl0MGEe07]kN`1nOWh0P82008N7Q`1nOWh0Ph>308b<
S02FUYH0S8b<09NGU`2FUYH0UiNG09JFUP2OWil0YJFU0:ZZZP2QXJ40[:b/0:f][@2_[jl0[:b/0;6a
/@2f][H0^KVi0;Jf]P2n_[h0][Jf0`33`l<07P34a<@0a/K60<K6aP36a/H0c/k>0<O7a`3AdM40c/k>
0<o?c`3AdM40fMWI0<k>cP3?cll0cLg=0=;BdP3=cLd0d];B0=SHf03EeMD0e]KF0=7Ad@3De=@0d];B
0=KFeP3De=@0`/;20<[:bP3;bl/0clo?0<k>cP80d];B00`0dM7A0<o?c`3=cLd0d];B0<k>cP3@d=00
d];B0=KFeP3Hf=P0fMWI0=3@d03De=@30=GEe@0;0=3@d035aLD0cLg=0<g=c@3@d=00c<c<0<g=c@34
a<@0bl_;0<c<c03:b/X00P3Bd]801P3<c<`0dM7A0=3@d03EeMD0clo?0<c<c080f=SH00d0dM7A0<c<
c03De=@0aLG50<_;b`3<c<`0b<S80<g=c@3Fe]H0d];B0=3@d03EeMD0e=CD0080d];B00/0d=3@0<k>
cP3=cLd0clo?0<k>cP3<c<`0d];B0=7Ad@3?cll0c/k>0=;BdP020=KFeP090<g=c@3@d=00dM7A0=KF
eP3EeMD0fMWI0=SHf03De=@0e]KF0080d];B0P3GemL04@3De=@0d];B0=SHf03De=@0d];B0=?Cd`3B
d]80emOG0=SHf03Jf]X0fMWI0=_Kf`3EeMD0e=CD0<o?c`3AdM40d];B00<0d=3@00@0b/[:0=7Ad@3A
dM40cLg=0P39bLT05`3<c<`0dM7A0<k>cP3>c/h0`l?30<[:bP35aLD0c<c<0<S8b03<c<`0b/[:0<S8
b03:b/X0cLg=0<[:bP38b<P0`/;20;no_`3:b/X0dm?C0=GEe@3>c/h0d=3@0080dm?C00H0dM7A0<c<
c03?cll0d];B0<o?c`3Cdm<20<g=c@<0c/k>00l0dm?C0=GEe@3AdM40dM7A0=3@d03;bl/0dm?C0=3@
d03EeMD0dM7A0<G5a@3?cll0dm?C0=;BdP3Cdm<00`3GemL06@3Fe]H0dm?C0=?Cd`3>c/h0dm?C0=;B
dP3Cdm<0f=SH0=WIf@3Lg=`0fMWI0=[JfP3Hf=P0fm_K0=gMg@3Lg=`0hN7Q0=cLg03IfMT0g=cL0=OG
e`3Bd]80alO70<_;b`3IfMT00P3GemL0103Hf=P0g=cL0=cLg03GemL20=_Kf`0H0=KFeP3EeMD0gMgM
0=gMg@3IfMT0f=SH0=gMg@3Lg=`0fMWI0>;RhP3Kfm/0g=cL0=SHf03IfMT0emOG0=[JfP3Kfm/0f][J
0=_Kf`3Lg=`0g]kN0=gMg@3Hf=P0dM7A0P3Jf]X01P3Kfm/0f][J0=gMg@3Jf]X0g]kN0=oOg`80gMgM
00<0hN7Q0=gMg@3Lg=`00P3Lg=`00`3Ogml0fm_K0=gMg@020=oOg`030=gMg@3Kfm/0fMWI00<0fm_K
0P3Ng]h00`3Kfm/0g]kN0=cLg0020=kNgP080=OGe`3Ph>00hN7Q0>3Ph03QhN40h>3P0=cLg03Ng]h2
0>3Ph00:0=gMg@3IfMT0fMWI0=gMg@3IfMT0f][J0>3Ph03Jf]X0fMWI0=SHf0<0fm_K00P0gmoO0>3P
h03MgMd0gmoO0>7Qh@3Rh^80hn?S0>3Ph080hn?S00D0gMgM0=KFeP3Bd]80c<c<0=[JfP030=cLg004
0=SHf03Kfm/0h>3P0=kNgP80g=cL00P0g]kN0=oOg`3Ng]h0fm_K0=SHf03Jf]X0emOG0=gMg@80g=cL
00<0gmoO0>3Ph03Ogml00P3MgMd01P3QhN40h>3P0=kNgP3Jf]X0g]kN0>;RhP80i>CT00P0h^;R0>3P
h03Ph>00g]kN0>7Qh@3Shn<0h^;R0>7Qh@gooooo000@ooooo`04051@D01?Cdl0C4a<04];B`80CDe=
00`0BTY:04a<C019BDT0BDU904Y:BP19BDT0CDe=04Y:BP19BDT0AdM704];B`1=CDd204Q8B080Bd];
0P18B4P0401?Cdl0CTi>04Y:BP1<C4`0CDe=059BDP1ADE40EeMG05UIF@1NGUh0GEeM05]KF`1MGEd0
EeMG05iNGP1LG5`206=SH`0U06YZJP1[Jf/0Lg=c079bLP1eMGD0NGUi08:2PP27QhL0QHF508B4Q02:
RXX0Shn?09FEU@29RHT0UiNG09jNWP2OWil0XJ6Q0:JVYP2YZJT0]kNg0;>c/`2_[jl0]kNg0;Fe]@2f
][H0^;Rh0;^k^`2n_[h0`L710<C4a030`<00];Bd0;Rh^034a<@0b<S80<_;b`020<S8b00P0<g=c@3<
c<`0cLg=0<g=c@39bLT0b<S80<[:bP3>c/h0clo?0<O7a`39bLT0cLg=0<o?c`3=cLd0clo?0<k>cP3@
d=00c/k>0=?Cd`3=cLd0bl_;0<o?c`3=cLd0dm?C0=CDe03Bd]80dm?C0=3@d03?cll0dM7A0<_;b`3@
d=020=7Ad@0>0<_;b`3?cll0cLg=0=CDe03AdM40c/k>0=3@d03AdM40a/K60<C4a03=cLd0aLG50<c<
c03?cll20=GEe@@0dM7A00T0clo?0<_;b`32`/80c/k>0=CDe03?cll0dm?C0=CDe03EeMD00P3Bd]80
103:b/X0c/k>0<o?c`3?cll20=GEe@030=CDe03EeMD0dM7A0080dm?C00X0eMGE0=?Cd`3AdM40b/[:
0<c<c03@d=00dM7A0<o?c`3AdM40eMGE0P3AdM403P3Cdm<0eMGE0=3@d03Bd]80e=CD0=KFeP3Hf=P0
eMGE0=?Cd`3Fe]H0eMGE0<o?c`3Cdm<0emOG0P3;bl/02`3@d=00bl_;0=3@d03GemL0e=CD0=?Cd`3F
e]H0emOG0=;BdP3AdM40dm?C0080e=CD00H0d=3@0<o?c`3Bd]80d];B0=KFeP3AdM440=;BdP070<g=
c@3:b/X0dm?C0=;BdP3AdM40fMWI0=KFeP020=;BdP0>0=CDe03EeMD0eMGE0=WIf@3GemL0e=CD0=3@
d03GemL0e=CD0=GEe@3?cll0emOG0=SHf03GemL20=KFeP0<0=WIf@3GemL0cLg=0=7Ad@3GemL0d];B
0=7Ad@3EeMD0dM7A0<g=c@3?cll0bl_;0P38b<P01039bLT0c<c<0=;BdP36a/H20<_;b`060<g=c@3>
c/h0c<c<0<W9b@3=cLd0clo?0P3;bl/02P37alL0c<c<0<C4a036a/H0d=3@0=7Ad@3EeMD0dM7A0=CD
e036a/H20=3@d00=0=;BdP3AdM40eMGE0=7Ad@3Cdm<0f=SH0=KFeP3Cdm<0e]KF0=?Cd`3@d=00dM7A
0=?Cd`020=CDe00B0=3@d03GemL0dm?C0=GEe@3AdM40bLW90=CDe03Fe]H0e=CD0=3@d03IfMT0f][J
0=WIf@3GemL0f=SH0=WIf@3Bd]80dM7A0P3Hf=P02P3Jf]X0f=SH0=gMg@3Kfm/0emOG0=WIf@3Lg=`0
f][J0=gMg@3Ogml20=cLg00;0=WIf@3Fe]H0eMGE0<[:bP3?cll0fm_K0=WIf@3GemL0f=SH0=cLg03M
gMd00P3Lg=`03P3Jf]X0fm_K0=SHf03IfMT0fm_K0=cLg03MgMd0gmoO0=kNgP3Ph>00gmoO0=_Kf`3Q
hN40fm_K0P3Jf]X04@3Ng]h0h>3P0>3Ph03Lg=`0fm_K0=[JfP3Lg=`0eMGE0=?Cd`3Lg=`0h>3P0=_K
f`3Jf]X0gmoO0=_Kf`3Ogml0h>3P0080g]kN0P3Ph>002@3Ng]h0gMgM0=oOg`3Ng]h0f][J0=kNgP3L
g=`0g]kN0=gMg@020=cLg0090=gMg@3Lg=`0g=cL0=_Kf`3Ng]h0h>3P0=oOg`3Ng]h0fm_K0080fMWI
01D0g]kN0>;RhP3Ti>@0gmoO0>7Qh@3Ph>00h^;R0>CTi03Shn<0gMgM0=_Kf`3Ph>00gMgM0=[JfP3K
fm/0g]kN0=cLg03Ng]h0f][J0=oOg`3Rh^800P3Ogml01@3Ng]h0h^;R0>7Qh@3QhN40h^;R00<0hn?S
00H0h>3P0>?Sh`3IfMT0d=3@0<c<c03GemL40=_Kf`80h>3P00H0g=cL0=gMg@3Ogml0g]kN0>7Qh@3P
h>020=gMg@030=kNgP3Jf]X0gmoO0080g=cL00X0g]kN0=oOg`3Lg=`0fm_K0=kNgP3Rh^80g]kN0>3P
h03MgMd0hN7Q0P3Shn<20>;RhP070>3Ph03QhN40hN7Q0>;RhP3QhN40hn?S0>CTi00=ooooo`004?oo
ool205mOG`06069RHP1SHf<0IFEU06e]K@1`L700MWIf0P1hN7P0101dM7@0NWYj07MgM`1gMgL207]k
N`0L07emO@22PX80Ph>308n?S`2:RXX0SXj>096AT@2CTi<0VIVI0:6QX@2VYZH0ZZZZ0:RXZ02[Zj/0
[jn_0;Jf]P2e]KD0/k>c0;Jf]P2m_Kd0_kno0;:b/P2i^KT0^k^k0;no_`31`L40alO70<G5a@80b/[:
0180cLg=0<_;b`3<c<`0c/k>0=;BdP3@d=00clo?0=_Kf`3Fe]H0c<c<0=;BdP3De=@0eMGE0=[JfP3L
g=`0f][J0=WIf@3Kfm/30=OGe`040=[JfP3IfMT0e]KF0=WIf@80e]KF00h0e=CD0<_;b`3=cLd0e=CD
0=7Ad@3Hf=P0e]KF0=7Ad@3?cll0dm?C0=CDe03?cll0cLg=0=;BdP80e=CD00H0dM7A0<_;b`39bLT0
cLg=0=7Ad@3>c/h50<g=c@040=7Ad@3=cLd0c/k>0<g=c@80d];B00/0dM7A0<g=c@3Bd]80d=3@0<K6
aP3;bl/0c/k>0=;BdP3<c<`0a/K60<k>cP020=3@d00=0<_;b`39bLT0clo?0<g=c@3?cll0alO70<g=
c@35aLD0c<c<0<o?c`3Bd]80dm?C0<o?c`020=;BdP80dM7A00@0cLg=0<S8b03AdM40eMGE0P3Cdm<0
7@3AdM40d];B0<o?c`3Bd]80d=3@0=CDe03=cLd0d];B0=7Ad@3De=@0e]KF0=OGe`3De=@0dM7A0=3@
d03Cdm<0d=3@0<o?c`36a/H0clo?0=7Ad@3Cdm<0e=CD0=3@d03De=@0dm?C0=;BdP3GemL0e]KF0080
dM7A00<0d=3@0=KFeP3Hf=P00P3Jf]X0203MgMd0f=SH0=;BdP3Bd]80dm?C0<g=c@3:b/X0d];B0P3G
emL00`3Hf=P0fm_K0=_Kf`020=KFeP030=;BdP3De=@0emOG0080e]KF0P3EeMD02`3Cdm<0dM7A0=CD
e03Cdm<0e]KF0=WIf@3Fe]H0f=SH0=;BdP3=cLd0dm?C0080e=CD0`3Fe]H20=?Cd`0K0=CDe03Fe]H0
e=CD0=?Cd`3EeMD0e]KF0=GEe@3De=@0emOG0=;BdP3Cdm<0emOG0=SHf03Lg=`0f][J0=_Kf`3Cdm<0
c<c<0=?Cd`3Bd]80d=3@0=;BdP3Fe]H0dm?C0<k>cP3?cll0bl_;0080bLW900h0c/k>0=3@d03Cdm<0
clo?0=7Ad@3>c/h0clo?0=?Cd`3:b/X0bLW90<S8b03;bl/0b/[:0<k>cP80b/[:00h0c/k>0<_;b`3C
dm<0d];B0=KFeP3Bd]80dm?C0<k>cP3Bd]80dm?C0=KFeP3?cll0d];B0=GEe@@0e=CD0P3EeMD30=?C
d`0=0=CDe03Hf=P0eMGE0=CDe03Fe]H0f=SH0=GEe@38b<P0dm?C0=GEe@3De=@0dM7A0=_Kf`020=cL
g0080=[JfP3Hf=P0f][J0=OGe`3Fe]H0fMWI0=GEe@3Hf=P20=cLg0030=_Kf`3Hf=P0g=cL0080g=cL
00X0f][J0=kNgP3Ogml0gMgM0=OGe`3IfMT0d];B0<[:bP3Bd]80f][J0`3IfMT0303Lg=`0gMgM0=cL
g03Jf]X0f=SH0=_Kf`3IfMT0fm_K0=cLg03Ng]h0h>3P0>;RhP80h>3P00@0hN7Q0=oOg`3Ogml0h>3P
0P3Ng]h00`3Ogml0g]kN0>3Ph0020=kNgP090=_Kf`3MgMd0fMWI0=WIf@3Shn<0g]kN0=cLg03Ogml0
h^;R0080gMgM00<0h>3P0>GUi@3QhN400P3Ph>000`3QhN40h^;R0=oOg`020=gMg@0>0=oOg`3QhN40
hn?S0>3Ph03MgMd0g=cL0=gMg@3Ng]h0gmoO0=cLg03Ogml0hN7Q0=oOg`3MgMd20=_Kf`0C0=cLg03O
gml0i>CT0>CTi03Ogml0hn?S0>CTi03UiND0h^;R0>7Qh@3Ogml0h>3P0>?Sh`3MgMd0h>3P0=oOg`3L
g=`0gmoO0=cLg0020>7Qh@0<0>3Ph03MgMd0gmoO0=oOg`3MgMd0hN7Q0>?Sh`3Rh^80h>3P0>CTi03S
hn<0hN7Q0P3MgMd01`3IfMT0eMGE0=kNgP3Rh^80gmoO0=cLg03Kfm/00P3Ogml01`3MgMd0gmoO0=oO
g`3Ng]h0h>3P0>?Sh`3QhN400P3Ogml00`3MgMd0h>3P0=kNgP020=kNgP040>7Qh@3Rh^80hN7Q0=oO
g`80h^;R00h0iNGU0=oOg`3Ph>00hn?S0>GUi@3Ti>@0hn?S0>3Ph03Shn<0iNGU0>3Ph03Ng]h0h^;R
0>CTi0gooooo000@ooooo`060;jn_P2j^[X0^KVi0;Jf]P2j^[X0alO70P3;bl/01`3AdM40c<c<0<G5
a@3=cLd0c<c<0<o?c`3>c/h00P3=cLd02P3?cll0_[jn0<W9b@38b<P0c<c<0=7Ad@3@d=00dm?C0=WI
f@3Jf]X20=OGe`0@0=WIf@3GemL0emOG0=KFeP3Cdm<0eMGE0=OGe`3Bd]80c/k>0=?Cd`3Hf=P0clo?
0=3@d03Cdm<0eMGE0=WIf@80e]KF0P3Bd]803P3AdM40e=CD0=CDe03GemL0fm_K0=SHf03Bd]80dm?C
0=OGe`3Hf=P0fm_K0=[JfP3Hf=P0fMWI0P3Hf=P01`3Cdm<0e]KF0=WIf@3IfMT0f=SH0=WIf@3De=@0
0P3EeMD00`3<c<`0alO70=?Cd`020=;BdP0A0=OGe`3De=@0d=3@0=?Cd`3@d=00clo?0=3@d03De=@0
eMGE0<k>cP3@d=00bl_;0<c<c03:b/X0d=3@0<K6aP3:b/X00P3Bd]801@3>c/h0dM7A0<o?c`3@d=00
dM7A0080cLg=0140clo?0<k>cP3AdM40eMGE0=CDe03>c/h0bl_;0<o?c`3AdM40clo?0<W9b@3>c/h0
b/[:0<o?c`3>c/h0c<c<0=;BdP020=3@d0<0c/k>0P3AdM40303?cll0eMGE0=OGe`3?cll0dm?C0<g=
c@3AdM40c<c<0<O7a`3@d=00clo?0=?Cd`80clo?0`3EeMD01@3Cdm<0eMGE0=3@d03AdM40d];B00<0
dm?C0P3Fe]H0603De=@0f=SH0=GEe@3;bl/0b<S80<k>cP3EeMD0dm?C0=CDe03Bd]80e]KF0=WIf@3F
e]H0fMWI0=CDe03Cdm<0c<c<0=?Cd`3GemL0g=cL0=[JfP3IfMT0gMgM0=GEe@80e=CD00L0emOG0<S8
b03Cdm<0emOG0=kNgP3IfMT0f][J0080fm_K00<0e]KF0=CDe03AdM400P3De=@02P3IfMT0emOG0=OG
e`3EeMD0d];B0=?Cd`3Bd]80f=SH0=GEe@3Jf]X20=GEe@080<o?c`32`/80dm?C0=GEe@3Cdm<0e=CD
0=SHf03De=@20=GEe@<0e]KF00@0gMgM0=KFeP3Hf=P0dm?C0P3Hf=P0303GemL0cLg=0=KFeP3GemL0
gMgM0=[JfP3Hf=P0dm?C0<c<c03AdM40eMGE0=CDe0<0e]KF00L0dm?C0<_;b`3Cdm<0d=3@0=?Cd`3D
e=@0dM7A0080dm?C00D0dM7A0<o?c`3Cdm<0e=CD0=;BdP020<k>cP80dM7A00H0clo?0<g=c@3<c<`0
dM7A0<g=c@3Bd]820=KFeP030=7Ad@3Bd]80dm?C0080e]KF00X0fMWI0=?Cd`3Hf=P0fMWI0=[JfP3E
eMD0f=SH0=_Kf`3GemL0eMGE0P3De=@02P3EeMD0emOG0=SHf03Jf]X0emOG0=WIf@3Fe]H0d];B0<S8
b03GemL20=[JfP030=SHf03Lg=`0g=cL0080gmoO0`3IfMT01`3Jf]X0fm_K0=SHf03Jf]X0g=cL0=[J
fP3IfMT00P3MgMd01`3Ogml0fm_K0=kNgP3MgMd0fm_K0=kNgP3Kfm/00P3Hf=P0203:b/X0dM7A0=WI
f@3Hf=P0gMgM0=_Kf`3Lg=`0g]kN0`3Lg=`02@3Ng]h0f=SH0=_Kf`3Ogml0hN7Q0>3Ph03Shn<0h^;R
0=oOg`020>3Ph00C0=kNgP3MgMd0g]kN0=oOg`3QhN40h>3P0>7Qh@3Ogml0g=cL0=kNgP3Ph>00gmoO
0=WIf@3Ogml0h>3P0=cLg03Ogml0h>3P0>7Qh@020>3Ph0040>?Sh`3Ti>@0h^;R0=kNgP<0h^;R00L0
gmoO0>3Ph03Ph>00hN7Q0>3Ph03Ng]h0hN7Q0080fMWI00H0hN7Q0>;RhP3Ph>00g]kN0=oOg`3Ph>03
0=kNgP0=0=WIf@3QhN40i>CT0>;RhP3Ogml0h>3P0>;RhP3QhN40gMgM0=kNgP3Rh^80h>3P0=cLg002
0>7Qh@080=oOg`3Ng]h0gmoO0=kNgP3QhN40hn?S0>3Ph03Ogml20>;RhP0?0>3Ph03Shn<0iNGU0>CT
i03Shn<0iNGU0>7Qh@3Ph>00gmoO0>3Ph03Hf=P0dM7A0=oOg`3UiND0h^;R0080gmoO0P3Rh^800`3P
h>00hN7Q0>;RhP020>;RhP030>?Sh`3Ogml0gmoO0080hn?S00/0hN7Q0>3Ph03QhN40gmoO0>7Qh@3R
h^80i>CT0>;RhP3Shn<0i>CT0>OWi`020>7Qh@0;0>?Sh`3UiND0iNGU0>?Sh`3Ph>00i>CT0>SXj03Q
hN40h>3P0>GUi@3Ti>@03Oooool0013ooooo00T0gMgM0=OGe`3Hf=P0d];B0=KFeP3Hf=P0emOG0=cL
g03Hf=P00`3De=@02`3Bd]80emOG0=CDe03Bd]80dm?C0=KFeP3=cLd0dM7A0<c<c03@d=00eMGE0080
e=CD00@0fMWI0=[JfP3Jf]X0f=SH0P3Fe]H02`3Jf]X0fMWI0=KFeP3GemL0e=CD0=7Ad@3?cll0dm?C
0=7Ad@3>c/h0dM7A0080e]KF00`0emOG0=?Cd`3Hf=P0e]KF0=?Cd`3AdM40emOG0=SHf03Ph>00f][J
0=7Ad@3Bd]820=SHf00:0=[JfP3MgMd0fMWI0=WIf@3:b/X0f=SH0=[JfP3EeMD0fMWI0=KFeP80emOG
00`0f=SH0=WIf@3De=@0eMGE0<g=c@3<c<`0cLg=0=CDe03GemL0e]KF0=OGe`3AdM430=OGe`030=WI
f@3Fe]H0d=3@0080dM7A01h0d=3@0<S8b03>c/h0d=3@0<O7a`39bLT0dM7A0<o?c`3>c/h0d];B0=?C
d`3EeMD0d];B0=CDe03Bd]80e=CD0=7Ad@3De=@0f=SH0=WIf@3Fe]H0d];B0=7Ad@3Cdm<0d=3@0<_;
b`3Bd]80clo?0=3@d03=cLd20=?Cd`0P0=CDe03Bd]80dM7A0<c<c03@d=00e=CD0=SHf03De=@0dm?C
0=GEe@3Fe]H0eMGE0=7Ad@3De=@0c/k>0<S8b03@d=00bl_;0=CDe03Bd]80e]KF0=3@d03Fe]H0f=SH
0=WIf@3EeMD0e=CD0=3@d03GemL0fMWI0=SHf03EeMD20=KFeP060=WIf@3GemL0eMGE0=7Ad@3=cLd0
dM7A0`3Hf=P00`3AdM40c<c<0=GEe@020=[JfP030=OGe`3Cdm<0f=SH0080emOG00@0g=cL0=WIf@3F
e]H0dm?C103Fe]H02P3=cLd0d];B0=WIf@3Kfm/0g]kN0=cLg03Jf]X0f=SH0=;BdP3De=@20=;BdP06
0=KFeP3GemL0e]KF0=SHf03GemL0dM7A0P3Hf=P02@3Kfm/0f=SH0=[JfP3Hf=P0g=cL0<o?c`3<c<`0
fMWI0=[JfP020=OGe`0<0=KFeP3MgMd0e]KF0=KFeP3Jf]X0e=CD0=GEe@3GemL0e]KF0=WIf@3Fe]H0
f=SH0P3GemL0103EeMD0gMgM0=_Kf`3Jf]X20=SHf0050=;BdP32`/80clo?0=OGe`3Hf=P00P3De=@0
103Cdm<0e=CD0=KFeP3GemL20=GEe@060=CDe03AdM40dM7A0=CDe03AdM40dm?C0P3IfMT02`3@d=00
dM7A0=7Ad@3Fe]H0dM7A0<g=c@3@d=00dM7A0<_;b`3>c/h0emOG00<0e]KF00<0eMGE0=OGe`3Bd]80
0P3Hf=P01@3Fe]H0f=SH0=WIf@3Lg=`0fMWI0080g=cL0100g]kN0=[JfP3Hf=P0fMWI0=[JfP3Hf=P0
fm_K0=[JfP3Kfm/0emOG0=gMg@3Kfm/0dM7A0=?Cd`3IfMT0emOG0P3Jf]X0203MgMd0g=cL0=gMg@3K
fm/0gMgM0=7Ad@3Fe]H0eMGE0P3IfMT01P3MgMd0f=SH0=kNgP3Jf]X0h>3P0>;RhP<0h>3P02@0gmoO
0>;RhP3Jf]X0h>3P0=WIf@3>c/h0d];B0>3Ph03Ng]h0g=cL0=kNgP3MgMd0fm_K0>3Ph03Shn<0h^;R
0=gMg@3Ng]h0h>3P0>KViP3UiND0h^;R0>?Sh`3QhN40hn?S0>;RhP3Ti>@0h^;R0=kNgP3QhN40h^;R
0>?Sh`3Ogml0hn?S0>;RhP3Vi^H30>7Qh@0<0=oOg`3Ti>@0g]kN0>3Ph03Vi^H0hN7Q0>;RhP3UiND0
i^KV0>?Sh`3Ph>00hn?S0`3Rh^830>?Sh`80h>3P00@0h^;R0>7Qh@3Ph>00gMgM0P3Rh^820>GUi@03
0=oOg`3UiND0hN7Q00<0hN7Q00@0gmoO0>;RhP3Shn<0gmoO0P3QhN400`3Vi^H0hN7Q0>7Qh@020>7Q
h@090>3Ph03UiND0h>3P0>CTi03QhN40h>3P0>CTi03Ph>00i>CT0080hN7Q00T0hn?S0>GUi@3UiND0
hn?S0>GUi@3Vi^H0j>SX0>CTi03WinL00P3Ti>@01P3Ogml0hN7Q0=gMg@3IfMT0h^;R0>KViP<0hn?S
00`0h^;R0>?Sh`3Rh^80hN7Q0>3Ph03Ng]h0gmoO0>3Ph03Ng]h0gMgM0>3Ph03Rh^820=oOg`0;0>3P
h03Ng]h0hn?S0>;RhP3UiND0hN7Q0=kNgP3Rh^80hN7Q0>CTi03Ogml00P3Rh^801@3UiND0i>CT0>CT
i03UiND0inOW0080hn?S00<0i^KV0>OWioooool03?ooool0013ooooo00D0gmoO0=WIf@3Jf]X0d=3@
0=CDe0020=[JfP070=KFeP3>c/h0dm?C0=CDe03GemL0e]KF0=SHf0020=?Cd`060=GEe@3De=@0bl_;
0=7Ad@3@d=00d];B0P3IfMT20=[JfP050=WIf@3Jf]X0f=SH0=[JfP3IfMT00P3Hf=P01P3De=@0emOG
0=WIf@3Fe]H0d=3@0=?Cd`80d];B01X0e=CD0=KFeP3EeMD0e]KF0=SHf03IfMT0e]KF0=;BdP3De=@0
e]KF0=SHf03Rh^80e]KF0=SHf03AdM40fMWI0=_Kf`3IfMT0g=cL0=GEe@3IfMT0bLW90=WIf@3Jf]X0
f=SH0=cLg080emOG0P3Hf=P0303GemL0dM7A0=GEe@3AdM40d=3@0=KFeP3Kfm/0g=cL0=WIf@3Jf]X0
fMWI0=_Kf`<0f][J00<0e]KF0=GEe@3GemL00P3EeMD03`3Cdm<0emOG0=KFeP3?cll0c/k>0=OGe`3H
f=P0e]KF0=GEe@3Fe]H0eMGE0=;BdP3Fe]H0d];B0=SHf0020=KFeP0>0=OGe`3Hf=P0fMWI0=GEe@3J
f]X0eMGE0=CDe03=cLd0d];B0=7Ad@3De=@0dm?C0=;BdP3@d=020=7Ad@050<o?c`3@d=00emOG0=OG
e`3Hf=P00P3Fe]H0103IfMT0emOG0=KFeP3Fe]H20=7Ad@0;0<o?c`3AdM40d];B0=7Ad@3Bd]80dm?C
0=7Ad@3IfMT0fm_K0=OGe`3Jf]X00P3GemL00`3EeMD0fMWI0=WIf@020=KFeP090=SHf03Lg=`0emOG
0=3@d03?cll0d=3@0=WIf@3Hf=P0eMGE0080fMWI00P0e=CD0=WIf@3IfMT0g=cL0=[JfP3GemL0fMWI
0=SHf080f][J00D0fMWI0=OGe`3GemL0fm_K0=[JfP020=SHf00<0<o?c`3GemL0f=SH0=;BdP3Kfm/0
gMgM0=[JfP3IfMT0emOG0=WIf@3GemL0f=SH0P3Lg=`20=SHf0060=_Kf`3IfMT0f][J0=WIf@3Ogml0
fm_K0`3Jf]X02P3?cll0c/k>0=KFeP3Kfm/0f][J0=_Kf`3Jf]X0fm_K0=SHf03EeMD20=KFeP040=GE
e@3Jf]X0f=SH0=SHf080fMWI00H0fm_K0=KFeP3Kfm/0f][J0=_Kf`3Ph>020=cLg0090=GEe@34a<@0
d=3@0=WIf@3Hf=P0e]KF0=WIf@3Kfm/0f=SH0080dm?C00H0e=CD0=KFeP3IfMT0eMGE0=;BdP3GemL3
0=GEe@060=WIf@3De=@0e=CD0=GEe@3Cdm<0dM7A0P3Fe]H02P3AdM40bl_;0=?Cd`3Ng]h0f][J0=SH
f03IfMT0e]KF0=_Kf`3IfMT20=gMg@040=[JfP3Lg=`0g=cL0=oOg`80gMgM00D0g=cL0=kNgP3MgMd0
g]kN0=oOg`020>7Qh@0>0>3Ph03MgMd0gmoO0=[JfP3Lg=`0f][J0=3@d03Hf=P0g]kN0=_Kf`3MgMd0
h>3P0>7Qh@3Lg=`30=[JfP030=oOg`3Kfm/0g=cL00<0g=cL00<0fm_K0>3Ph03Ph>000P3Ng]h01@3Q
hN40h^;R0>;RhP3Ti>@0h^;R0080fm_K00<0g=cL0=3@d03AdM400P3Lg=`02@3MgMd0gmoO0=kNgP3P
h>00hn?S0>CTi03QhN40g]kN0>3Ph0030>?Sh`030>7Qh@3Shn<0iNGU0080i>CT00@0iNGU0>CTi03S
hn<0i>CT0`3Rh^801@3Vi^H0iNGU0>CTi03Ph>00hn?S0080gmoO00D0i>CT0>?Sh`3Ti>@0inOW0>?S
h`020>GUi@060>OWi`3UiND0inOW0>CTi03Vi^H0h^;R0`3Ti>@40>?Sh`060>7Qh@3Ogml0gMgM0>3P
h03Ogml0i>CT0P3Shn<07P3Rh^80iNGU0>KViP3Shn<0h^;R0>3Ph03UiND0h>3P0>;RhP3Ph>00i>CT
0>;RhP3QhN40h^;R0>?Sh`3Ti>@0h^;R0>7Qh@3Rh^80iNGU0>CTi03QhN40i>CT0>3Ph03QhN40gmoO
0>7Qh@3Vi^H0i>CT0>KViP80i>CT00H0i^KV0>GUi@3YjNT0j>SX0>GUi@3Rh^820>GUi@060=_Kf`3H
f=P0h^;R0>CTi03Shn<0iNGU0P3Shn<02`3Rh^80hn?S0>;RhP3Rh^80hn?S0>;RhP3QhN40g]kN0=oO
g`3Shn<0iNGU00<0hn?S00D0i>CT0>KViP3UiND0iNGU0>?Sh`020>KViP030>GUi@3WinL0inOW0080
hN7Q00L0h^;R0>KViP3WinL0inOW0>SXj03Shn<0h^;R0080i^KV3Oooool0013ooooo00/0gmoO0=[J
fP3MgMd0e=CD0=KFeP3EeMD0fMWI0=_Kf`3IfMT0dm?C0=[JfP020=SHf0050=_Kf`3GemL0eMGE0=KF
eP3Cdm<00P3AdM40503<c<`0e=CD0=SHf03Hf=P0f][J0=WIf@3GemL0f=SH0=GEe@3GemL0fMWI0=[J
fP3Hf=P0eMGE0=?Cd`3Jf]X0e]KF0<k>cP3EeMD0e]KF0P3EeMD30=SHf00@0=WIf@3Hf=P0e]KF0=;B
dP3EeMD0e=CD0=OGe`3Ph>00eMGE0=;BdP3AdM40f=SH0=cLg03Kfm/0g]kN0=cLg080gMgM00L0g=cL
0=SHf03EeMD0fm_K0=WIf@3GemL0f=SH0080emOG00D0eMGE0=KFeP3Cdm<0dM7A0=WIf@020=gMg@03
0=[JfP3Hf=P0fm_K0080g=cL00<0gMgM0=cLg03Hf=P00P3Jf]X01`3Kfm/0emOG0=GEe@3GemL0f=SH
0=OGe`3Hf=P00P3Kfm/00`3Jf]X0f=SH0=WIf@020=[JfP080=KFeP3Hf=P0f=SH0=SHf03Jf]X0fMWI
0=KFeP3GemL20=SHf0050=cLg03Hf=P0clo?0=gMg@3Jf]X00P3GemL20=KFeP050=OGe`3Fe]H0dm?C
0=7Ad@3Fe]H00P3Hf=P02@3Fe]H0f][J0=WIf@3EeMD0e=CD0=KFeP3De=@0d];B0<k>cP020=SHf00:
0=KFeP3De=@0emOG0=OGe`3Jf]X0fm_K0=[JfP3IfMT0fm_K0=SHf080fMWI00H0gmoO0=gMg@3IfMT0
f][J0=cLg03GemL20=7Ad@040<o?c`3IfMT0fm_K0=_Kf`80g=cL00H0fm_K0=GEe@3IfMT0e]KF0=GE
e@3Jf]X20=KFeP0?0=_Kf`3Jf]X0fm_K0=[JfP3IfMT0g=cL0=gMg@3Hf=P0emOG0=;BdP3GemL0fm_K
0=OGe`3Jf]X0gMgM00<0fm_K00D0g=cL0=SHf03GemL0f=SH0=cLg0020=_Kf`0<0=oOg`3Kfm/0f][J
0=[JfP3Ng]h0gMgM0=cLg03MgMd0f][J0=7Ad@3EeMD0f][J0`3Lg=`20=kNgP0=0=_Kf`3Hf=P0f=SH
0=OGe`3Hf=P0fMWI0=OGe`3Hf=P0fm_K0=OGe`3Jf]X0f=SH0=WIf@020=_Kf`080>3Ph03Shn<0gmoO
0=WIf@3=cLd0emOG0=gMg@3Kfm/20=SHf0040=_Kf`3Lg=`0fMWI0=SHf080eMGE0100gMgM0=OGe`3D
e=@0fMWI0=OGe`3Fe]H0fMWI0=[JfP3Hf=P0g=cL0=gMg@3IfMT0dm?C0=;BdP3Fe]H0f][J0P3Bd]80
103Lg=`0g]kN0=kNgP3Ogml20=kNgP040=[JfP3MgMd0gmoO0=_Kf`80gmoO00@0g=cL0=[JfP3Ph>00
gmoO0P3Ng]h01P3QhN40gmoO0>3Ph03Ogml0g=cL0=[JfP<0g]kN00@0h>3P0=?Cd`3Hf=P0fm_K0P3L
g=`0203Ng]h0hN7Q0=cLg03Ng]h0e]KF0=WIf@3Jf]X0g]kN0P3MgMd00`3Ng]h0gmoO0>7Qh@020=kN
gP040=gMg@3Ph>00hN7Q0>;RhP80h>3P00H0g]kN0=oOg`3Ogml0g=cL0<_;b`3AdM420>3Ph0090=oO
g`3QhN40h>3P0>;RhP3QhN40i>CT0>7Qh@3Ti>@0hN7Q0080h^;R0P3UiND0103Shn<0jNWY0>GUi@3U
iND20>KViP070>SXj03Vi^H0h>3P0>?Sh`3Ti>@0hn?S0>CTi0030>?Sh`80h>3P00L0h^;R0>GUi@3V
i^H0inOW0>KViP3WinL0iNGU0080inOW00D0i^KV0>OWi`3Ti>@0i^KV0>SXj0030>KViP<0inOW00H0
i>CT0>?Sh`3Ph>00hn?S0>7Qh@3Vi^H30>GUi@80i^KV00/0i>CT0>GUi@3Ph>00iNGU0>?Sh`3WinL0
iNGU0>OWi`3Shn<0h^;R0>CTi0020>?Sh`0>0>KViP3WinL0j>SX0>GUi@3Ti>@0iNGU0>KViP3Ti>@0
hn?S0>;RhP3Shn<0i>CT0>?Sh`3YjNT20>CTi080jNWY00T0j^[Z0>OWi`3UiND0hn?S0>GUi@3Ti>@0
g]kN0=gMg@3Rh^800P3Ti>@20>KViP050>OWi`3UiND0iNGU0>GUi@3Vi^H00`3UiND0203Rh^80h>3P
0>;RhP3UiND0i^KV0>CTi03Rh^80i^KV0P3WinL0303UiND0hn?S0>GUi@3Vi^H0jNWY0>OWi`3Xj>P0
iNGU0>KViP3UiND0i>CT0>KViP80inOW0P3UiND00`3WinL0hn?Sooooo`0<ooooo`004?ooool0103S
hn<0gMgM0=cLg03GemL20=SHf0030=cLg03Jf]X0g]kN0080fm_K01d0f=SH0=[JfP3MgMd0fMWI0=GE
e@3Fe]H0eMGE0=7Ad@3@d=00dM7A0=CDe03Jf]X0fm_K0=kNgP3Kfm/0f][J0=cLg03IfMT0f][J0=_K
f`3MgMd0fMWI0=cLg03Hf=P0f][J0=GEe@3?cll0d=3@0=GEe@020=CDe0060=_Kf`3Lg=`0f][J0=[J
fP3IfMT0f][J0P3IfMT0703Hf=P0fm_K0>;RhP3De=@0emOG0=?Cd`3Jf]X0g=cL0=kNgP3MgMd0g]kN
0>3Ph03MgMd0fm_K0=KFeP3EeMD0fMWI0=KFeP3GemL0g=cL0=[JfP3IfMT0f=SH0=KFeP3EeMD0d];B
0=cLg03Ng]h20=gMg@030=SHf03Lg=`0gMgM0080g=cL0180gMgM0=WIf@3Jf]X0emOG0=gMg@3IfMT0
f][J0=WIf@3EeMD0e=CD0=OGe`3EeMD0g=cL0=oOg`3Lg=`0f=SH0=WIf@3Fe]H20=SHf00E0=WIf@3J
f]X0f][J0=WIf@3Hf=P0fm_K0=[JfP3MgMd0f][J0=GEe@3?cll0e=CD0=GEe@3Fe]H0f=SH0=OGe`3L
g=`0f][J0=WIf@3Jf]X0eMGE0080fMWI0100fm_K0=[JfP3Jf]X0g=cL0=OGe`3EeMD0e=CD0=?Cd`3E
eMD0bl_;0=WIf@3Jf]X0g]kN0=SHf03Kfm/0f=SH0P3IfMT0203Hf=P0gMgM0=OGe`3Jf]X0e]KF0=OG
e`3Jf]X0fm_K0P3Lg=`01P3Kfm/0emOG0=SHf03Bd]80d=3@0=GEe@80fm_K00/0g=cL0=kNgP3IfMT0
e=CD0=GEe@3GemL0f=SH0=gMg@3Jf]X0emOG0=_Kf`020=[JfP80gMgM00P0h>3P0>7Qh@3Kfm/0fMWI
0=;BdP3IfMT0g]kN0=SHf080g=cL00X0f][J0=kNgP3Ng]h0gmoO0>3Ph03Ogml0g=cL0=kNgP3QhN40
g=cL0P3Jf]X0103MgMd0gmoO0=kNgP3MgMd20=kNgP0<0=cLg03Cdm<0dm?C0=[JfP3Kfm/0gmoO0=cL
g03Ng]h0g=cL0=gMg@3Ogml0gMgM0P3IfMT01@3GemL0fMWI0=SHf03Lg=`0gMgM0080g=cL00<0fm_K
0>3Ph03QhN400P3Rh^805@3Ng]h0g=cL0<o?c`3EeMD0gMgM0>3Ph03Ng]h0fm_K0=cLg03Ng]h0gMgM
0>7Qh@3MgMd0emOG0>3Ph03Kfm/0g=cL0=[JfP3Hf=P0g]kN0=SHf0020=_Kf`090=cLg03MgMd0fm_K
0=SHf03Fe]H0fMWI0=gMg@3EeMD0e=CD0080g]kN00T0h>3P0>?Sh`3Ng]h0h>3P0=gMg@3Kfm/0gMgM
0=WIf@3Ph>000`3Ogml05P3QhN40gmoO0=oOg`3Ph>00hN7Q0=oOg`3Ph>00hN7Q0>3Ph03Ogml0h^;R
0>7Qh@3MgMd0gmoO0=;BdP3IfMT0g]kN0>3Ph03Hf=P0g=cL0>?Sh`3MgMd20=_Kf`060=oOg`3Ng]h0
g=cL0=cLg03Ng]h0g=cL0P3Ng]h0203MgMd0g=cL0=oOg`3Ng]h0gmoO0>7Qh@3Ti>@0hN7Q0P3Ogml0
1@3Ng]h0fMWI0<[:bP3De=@0h^;R00<0hN7Q00d0h^;R0>?Sh`3Ogml0h^;R0=kNgP3Shn<0h>3P0>GU
i@3Rh^80i>CT0>KViP3QhN40i^KV00<0iNGU00@0i^KV0>SXj03UiND0hN7Q0P3Ti>@0303Rh^80hn?S
0>7Qh@3Shn<0h^;R0>?Sh`3Ogml0hN7Q0>?Sh`3UiND0i^KV0>OWi`80i^KV00X0j>SX0>KViP3Vi^H0
hn?S0>CTi03UiND0i>CT0>?Sh`3Ti>@0i^KV0P3UiND02`3WinL0iNGU0>CTi03QhN40i>CT0>?Sh`3V
i^H0i>CT0>3Ph03WinL0i>CT0080iNGU00X0i>CT0=oOg`3Shn<0i^KV0>;RhP3UiND0hn?S0>CTi03P
h>00iNGU0P3Ti>@01`3UiND0inOW0>?Sh`3Ti>@0gmoO0>3Ph03UiND00`3Ti>@02P3Vi^H0iNGU0>?S
h`3Ti>@0i^KV0>CTi03Xj>P0i^KV0>SXj03Ti>@20>KViP090>;RhP3Ng]h0g]kN0=_Kf`3MgMd0h^;R
0>3Ph03QhN40i>CT0080iNGU00D0h^;R0>3Ph03Ph>00h>3P0=gMg@020=kNgP030=SHf03Fe]H0emOG
00<0fMWI00@0gMgM0=[JfP3Hf=P0e]KF0P3Ng]h03`3Jf]X0h^;R0=oOg`3Rh^80gmoO0=kNgP3Shn<0
h>3P0>?Sh`3Ti>@0hn?S0=cLg03Jf]X0g]kN0>3Ph00=ooooo`00ooooooocooooo`00ooooooocoooo
o`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00\
\>"],
  ImageRangeCache->{{{4.9375, 497.625}, {246.875, 0}} -> {-32.6856, -13.0213, \
2.45086, 2.45086}}],

Cell[TextData[{
  "Fig. 7.5 Nonlinear water waves, created in a wave tank at the Ship \
Division of the National Physical Laboratory, England. (Photograph by J. E. \
Frier, in ",
  ButtonBox["T. B. Benjamin (1967)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". )"
}], "Caption",
  CellTags->"Fig. 7.5"],

Cell[TextData[{
  " \tOne can see from this photo that real nonlinear waves are even more \
sharply peaked than cnoidal waves. This has to do with the approximate form \
of dispersion used in the KdV equation. Equation ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  "  is a poor approximation to the exact linear dispersion relation ",
  ButtonBox["(7.2.1)",
    ButtonData:>{"Chapter7.nb", "(7.2.1)"},
    ButtonStyle->"Hyperlink"],
  "  at large wavenumbers, which contribute to the sharp peak. More accurate \
equations that keep the exact linear dispersion can be constructed, and show \
the desired slope discontinuity at the wave peak. [See, for instance,  ",
  ButtonBox["Whitham (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  "\tThe wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " is not all that depends on the wave amplitude. The speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " of the cnoidal wave also depends on ",
  Cell[BoxData[
      \(TraditionalForm\`a, b\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". This can be easily seen by substituting  Eq. ",
  ButtonBox["(7.2.6)",
    ButtonData:>{"Chapter7.nb", "(7.2.6)"},
    ButtonStyle->"Hyperlink"],
  "  into ",
  ButtonBox["(7.2.9)",
    ButtonData:>{"Chapter7.nb", "(7.2.9)"},
    ButtonStyle->"Hyperlink"],
  " . The coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`f\^2\)]],
  " on the right-hand side of Eq. ",
  ButtonBox["(7.2.9)",
    ButtonData:>{"Chapter7.nb", "(7.2.9)"},
    ButtonStyle->"Hyperlink"],
  "  is ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/6\) \((a + b + c)\)\)]],
  ", but the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`f\^2\)]],
  " on the ",
  "left-hand",
  " side is ",
  Cell[BoxData[
      \(TraditionalForm\`v/2\)]],
  ". Therefore, we find that the wave speed is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v = \(1\/3\) \((a + b + c)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.16)"],

Cell[TextData[{
  "In the limit of a linear wave oscillating about ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ \(a \[Rule] 0\)\)]],
  " and we have ",
  Cell[BoxData[
      \(TraditionalForm\`v \[Rule] \(1\/3\) c\)]],
  ". This is the correct result for the linear wave speed as seen in a frame \
moving at velocity ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  ". In this frame, the linear wave speed is given by ",
  Cell[BoxData[
      \(TraditionalForm\`v = \[Omega]/k - c\_o\)]],
  ". Using Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " yields ",
  Cell[BoxData[
      \(TraditionalForm\`v\  = \ \(-c\_\(\(o\)\(\ \)\)\) \(k\^\(\(2\)\(\ \)\)\
\) h\^\(\(2\)\(\ \)\)/6\)]],
  ".  This does not look like ",
  Cell[BoxData[
      \(TraditionalForm\`v = c/3\)]],
  ". However, remember that the wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 2  \[Pi]/k\)]],
  " for these waves is given by Eq. ",
  ButtonBox["(7.2.15)",
    ButtonData:>{"Chapter7.nb", "(7.2.15)"},
    ButtonStyle->"Hyperlink"],
  "  with ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  ":  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\  = \(\(\@\(\(12\ \[Alpha]\)\/\(-c\)\)\)\(\
\ \ \)\(\[Pi]\)\(\ \)\)\)]],
  ".  Squaring this equation and substituting  ",
  Cell[BoxData[
      \(TraditionalForm\`c = 3\ v\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`v = \(-\[Alpha]\)\ k\^2\)]],
  ", which may be seen to agree with the  linear dispersion relation if we \
recall that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = c\_o\ h\^2/6\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAnother important case is the limit ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] \ 1\)]],
  " (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ c\)]],
  " ). In this limit, the period ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`sn\)]],
  " approaches infinity [see Eq. ",
  ButtonBox["(7.2.13)",
    ButtonData:>{"Chapter7.nb", "(7.2.13)"},
    ButtonStyle->"Hyperlink"],
  "  and Cell ",
  ButtonBox["7.35",
    ButtonData:>"Cell 7.35",
    ButtonStyle->"Hyperlink"],
  "], and as a result so does the period of the cnoidal waves.  The reason \
for this divergence in the period can be understood by examining motion in \
the potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  ". The limit ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] c\)]],
  " corresponds to an energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " for which there is a turning point just at the top of the potential curve \
(Fig. ",
  ButtonBox["7.6",
    ButtonData:>"Fig. 7.6",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.247899 0.112045 0.369262 0.0664776 [
[.02381 .29028 -6 -9 ]
[.02381 .29028 6 0 ]
[.47199 .29028 -3 -9 ]
[.47199 .29028 3 0 ]
[.69608 .29028 -3 -9 ]
[.69608 .29028 3 0 ]
[.92017 .29028 -3 -9 ]
[.92017 .29028 3 0 ]
[1.025 .30278 0 -6 ]
[1.025 .30278 10 6 ]
[.2354 .10335 -12 -4.5 ]
[.2354 .10335 0 4.5 ]
[.2354 .23631 -12 -4.5 ]
[.2354 .23631 0 4.5 ]
[.2354 .36926 -6 -4.5 ]
[.2354 .36926 0 4.5 ]
[.2354 .50222 -6 -4.5 ]
[.2354 .50222 0 4.5 ]
[.2479 .64303 -14 0 ]
[.2479 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30278 m
.02381 .30903 L
s
[(-2)] .02381 .29028 0 1 Mshowa
.47199 .30278 m
.47199 .30903 L
s
[(2)] .47199 .29028 0 1 Mshowa
.69608 .30278 m
.69608 .30903 L
s
[(4)] .69608 .29028 0 1 Mshowa
.92017 .30278 m
.92017 .30903 L
s
[(6)] .92017 .29028 0 1 Mshowa
.125 Mabswid
.07983 .30278 m
.07983 .30653 L
s
.13585 .30278 m
.13585 .30653 L
s
.19188 .30278 m
.19188 .30653 L
s
.30392 .30278 m
.30392 .30653 L
s
.35994 .30278 m
.35994 .30653 L
s
.41597 .30278 m
.41597 .30653 L
s
.52801 .30278 m
.52801 .30653 L
s
.58403 .30278 m
.58403 .30653 L
s
.64006 .30278 m
.64006 .30653 L
s
.7521 .30278 m
.7521 .30653 L
s
.80812 .30278 m
.80812 .30653 L
s
.86415 .30278 m
.86415 .30653 L
s
.97619 .30278 m
.97619 .30653 L
s
.25 Mabswid
0 .30278 m
1 .30278 L
s
gsave
1.025 .30278 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2479 .10335 m
.25415 .10335 L
s
[(-4)] .2354 .10335 1 0 Mshowa
.2479 .23631 m
.25415 .23631 L
s
[(-2)] .2354 .23631 1 0 Mshowa
.2479 .36926 m
.25415 .36926 L
s
[(0)] .2354 .36926 1 0 Mshowa
.2479 .50222 m
.25415 .50222 L
s
[(2)] .2354 .50222 1 0 Mshowa
.125 Mabswid
.2479 .13659 m
.25165 .13659 L
s
.2479 .16983 m
.25165 .16983 L
s
.2479 .20307 m
.25165 .20307 L
s
.2479 .26955 m
.25165 .26955 L
s
.2479 .33602 m
.25165 .33602 L
s
.2479 .4025 m
.25165 .4025 L
s
.2479 .43574 m
.25165 .43574 L
s
.2479 .46898 m
.25165 .46898 L
s
.2479 .07011 m
.25165 .07011 L
s
.2479 .03687 m
.25165 .03687 L
s
.2479 .00364 m
.25165 .00364 L
s
.2479 .53546 m
.25165 .53546 L
s
.2479 .5687 m
.25165 .5687 L
s
.2479 .60193 m
.25165 .60193 L
s
.25 Mabswid
.2479 0 m
.2479 .61803 L
s
gsave
.2479 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .03 ] 0 setdash
.02381 .36926 m
.06244 .36926 L
.10458 .36926 L
.14415 .36926 L
.18221 .36926 L
.22272 .36926 L
.26171 .36926 L
.30316 .36926 L
.34309 .36926 L
.3815 .36926 L
.42237 .36926 L
.46172 .36926 L
.49955 .36926 L
.53984 .36926 L
.57861 .36926 L
.61984 .36926 L
.65954 .36926 L
.69774 .36926 L
.73838 .36926 L
.77751 .36926 L
.81909 .36926 L
.85916 .36926 L
.89771 .36926 L
.93871 .36926 L
.97619 .36926 L
s
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.06244 .1369 L
.08255 .18889 L
.10458 .23731 L
.14415 .30347 L
.16372 .32704 L
.18466 .34609 L
.19488 .3532 L
.20597 .35937 L
.21644 .36378 L
.22611 .36667 L
.23076 .36767 L
.23333 .36811 L
.23577 .36847 L
.23804 .36874 L
.2405 .36897 L
.24159 .36905 L
.24275 .36912 L
.24376 .36917 L
.24483 .36921 L
.2455 .36923 L
.24623 .36925 L
.24751 .36926 L
.24823 .36926 L
.249 .36926 L
.24974 .36924 L
.2504 .36923 L
.25169 .36919 L
.25242 .36915 L
.2531 .36912 L
.25565 .36895 L
.25791 .36874 L
.2604 .36845 L
.26546 .36767 L
.27037 .36668 L
.27555 .36538 L
.2848 .36245 L
.30566 .35311 L
.3254 .34112 L
.34377 .32753 L
.38281 .29222 L
.42431 .24771 L
.46429 .20112 L
.50276 .1557 L
.54368 .10982 L
.58308 .07096 L
.62097 .04125 L
.64042 .02976 L
.65126 .02464 L
.66131 .02079 L
Mistroke
.67144 .01781 L
.67679 .01663 L
.67953 .01613 L
.68248 .01567 L
.68532 .01532 L
.68792 .01506 L
.69041 .01488 L
.69166 .01482 L
.69237 .01479 L
.69303 .01476 L
.69428 .01473 L
.69542 .01472 L
.69665 .01472 L
.69734 .01472 L
.69798 .01473 L
.69904 .01476 L
.70021 .01481 L
.70144 .01487 L
.70259 .01494 L
.70503 .01514 L
.7073 .01539 L
.71244 .01617 L
.71746 .01721 L
.72281 .01865 L
.73252 .02213 L
.74132 .02629 L
.76055 .03883 L
.78136 .05811 L
.80127 .08248 L
.82233 .11497 L
.86027 .19234 L
.90066 .30379 L
.93954 .44225 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oF?ooool0
0ol0003oooooooooo`3oooooo`kooooo001Hooooo`;o0000ooooool?ooooo`00F?ooool00ol0003o
ooooooooo`3oooooo`kooooo001Hooooo`03o`000?oooooooooo0?oooooo3_ooool005Sooooo00?o
0000ooooooooool0ooooool>ooooo`004?ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooo
oooo08Kooooo3_l00?miooooo`004?ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo
08Cooooo0_l00?l>ooooo`Co003oMOooool0013ooooo00?o003oooooooooool0AOooool00ol0003o
ooooooooo`20ooooo`Co003o5?ooool2o`00og?ooooo000Aooooo`03o`00oooooooooooo04Cooooo
00?o0000ooooooooool0OOooool3o`00oa[ooooo00?o003oooooooooool0L?ooool0017ooooo00?o
003oooooooooool0A?ooool00ol0003oooooooooo`1looooo`03o`00oooooooooooo01cooooo0_l0
0?m`ooooo`004Oooool00ol00?ooooooooooo`14ooooo`03o`000?oooooooooo07[ooooo0_l00?lQ
ooooo`03o`00oooooooooooo06gooooo000Booooo`03o`00oooooooooooo04?ooooo00?o0000oooo
ooooool0N?ooool2o`00obCooooo0_l00?m]ooooo`004_ooool00ol00?ooooooooooo`13ooooo`;o
0000Moooool2o`00obSooooo00?o003oooooooooool0J_ooool001;ooooo00?o003oooooooooool0
@oooool00ol0003oooooooooo`1dooooo`;o003o:oooool2o`00of[ooooo000Cooooo`03o`00oooo
oooooooo04;ooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0]ooooo`03o`00oooo
oooooooo06Oooooo000Cooooo`03o`00oooooooooooo04;ooooo00?o0000ooooooooool0L_ooool0
0ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo06Kooooo000Cooooo`03o`00oooooooooooo
04;ooooo00?o0000ooooooooool0L?ooool2o`00oc?ooooo00?o003oooooooooool0IOooool001Co
oooo00?o003oooooooooool0@Oooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo03Co
oooo00?o003oooooooooool0I?ooool001Cooooo00?o003oooooooooool0@Oooool00ol0003ooooo
ooooo`1^ooooo`03o`00oooooooooooo03Kooooo00?o003oooooooooool0Hoooool001Cooooo00?o
003oooooooooool0@Oooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo03Sooooo00?o
003oooooooooool0H_ooool001Cooooo00?o003oooooooooool0@Oooool00ol0003oooooooooo`1[
ooooo`;o003o>oooool00ol00?ooooooooooo`1Rooooo`005Oooool00ol00?ooooooooooo`10oooo
o`03o`000?oooooooooo06[ooooo00?o003oooooooooool0??ooool00ol00?ooooooooooo`1Qoooo
o`005Oooool00ol00?ooooooooooo`10ooooo`03o`000?oooooooooo06Wooooo00?o003ooooooooo
ool0?_ooool00ol00?ooooooooooo`1Pooooo`005Oooool00ol00?ooooooooooo`10ooooo`;o0000
JOooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo05oooooo000Fooooo`03o`00oooo
oooooooo03oooooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`11ooooo`03o`00oooo
oooooooo05oooooo000Fooooo`03o`00oooooooooooo03oooooo00?o0000ooooooooool0I_ooool0
0ol00?ooooooooooo`13ooooo`03o`00oooooooooooo05kooooo000Fooooo`03o`00oooooooooooo
03oooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo
05gooooo000Gooooo`03o`00oooooooooooo03kooooo00?o0000ooooooooool0I?ooool00ol00?oo
ooooooooo`17ooooo`03o`00oooooooooooo05cooooo000Gooooo`03o`00oooooooooooo03kooooo
00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo05cooooo
000Gooooo`03o`00oooooooooooo03kooooo00?o0000ooooooooool0H_ooool00ol00?oooooooooo
o`1:ooooo`03o`00oooooooooooo05_ooooo000Hooooo`03o`00oooooooooooo03gooooo00?o0000
ooooooooool0HOooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo05[ooooo000Hoooo
o`03o`00oooooooooooo03Cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
063ooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`1Jooooo`006?ooool00ol00?oo
ooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00ol00?oo
ooooooooo`1?ooooo`03o`00oooooooooooo05Wooooo000Hooooo`03o`00oooooooooooo02[ooooo
1_l00002ooooo`Go00001_ooool3o`0005kooooo00?o003oooooooooool0DOooool00ol00?oooooo
ooooo`1Hooooo`006Oooool00ol00?ooooooooooo`0aooooo`04odA4A?oMgMgoooooo`0000Oooooo
00?o0000ooooooooool0GOooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo05Oooooo
000Iooooo`03o`00oooooooooooo037ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`1Looooo`03o`00oooooooooooo05Cooooo00?o003oooooooooool0Eoooool001Wooooo00?o
003oooooooooool0<_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo05cooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`006_ooool00ol00?ooooooooooo`0a
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`1G
ooooo`03o`00oooooooooooo05Gooooo000Jooooo`03o`00oooooooooooo03;ooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo05Sooooo00?o003ooooo
ooooool0EOooool001[ooooo00?o003oooooooooool0>oooool00ol0003oooooooooo`1Iooooo`03
o`00oooooooooooo05[ooooo00?o003oooooooooool0E?ooool001_ooooo00?o003oooooooooool0
>_ooool00ol0003oooooooooo`1Hooooo`03o`00oooooooooooo05_ooooo00?o003oooooooooool0
E?ooool001_ooooo00?o003oooooooooool0>_ooool00ol0003oooooooooo`1Gooooo`03o`00oooo
oooooooo05gooooo00?o003oooooooooool0Doooool001_ooooo00?o003oooooooooool0>_ooool0
0ol0003oooooooooo`1Fooooo`03o`00oooooooooooo05kooooo00?o003oooooooooool0Doooool0
01cooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`1Eooooo`03o`00oooooooooooo
063ooooo00?o003oooooooooool0D_ooool001cooooo00?o003oooooooooool0>Oooool2o`0005Ko
oooo00?o003oooooooooool0H?ooool00ol00?ooooooooooo`1Booooo`007?ooool00ol00?oooooo
ooooo`0iooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool0H_ooool00ol00?oooooo
ooooo`1Aooooo`007Oooool00ol00?ooooooooooo`0hooooo`03o`000?oooooooooo05?ooooo00?o
003oooooooooool0Hoooool00ol00?ooooooooooo`1Aooooo`007Oooool00ol00?ooooooooooo`0h
ooooo`03o`000?oooooooooo05;ooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1@
ooooo`007Oooool00ol00?ooooooooooo`0hooooo`03o`000?oooooooooo057ooooo00?o003ooooo
ooooool0I_ooool00ol00?ooooooooooo`1@ooooo`007_ooool00ol00?ooooooooooo`0gooooo`03
o`000?oooooooooo053ooooo00?o003oooooooooool0J?ooool00ol00?ooooooooooo`1?ooooo`00
7_ooool00ol00?ooooooooooo`0gooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool0
JOooool00ol00?ooooooooooo`1?ooooo`007oooool00ol00?ooooooooooo`0fooooo`03o`000?oo
oooooooo04oooooo00?o003oooooooooool0JOooool00ol00?ooooooooooo`1?ooooo`007oooool0
0ol00?ooooooooooo`0fooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool0Joooool0
0ol00?ooooooooooo`1>ooooo`008?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo
04gooooo00?o003oooooooooool0K?ooool00ol00?ooooooooooo`1>ooooo`008?ooool00ol00?oo
ooooooooo`0eooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0K_ooool00ol00?oo
ooooooooo`1=ooooo`008?ooool00ol00?ooooooooooo`0eooooo`;o0000C?ooool00ol00?oooooo
ooooo`1_ooooo`03o`00oooooooooooo04gooooo000Qooooo`03o`00oooooooooooo03Cooooo00?o
0000ooooooooool0B_ooool00ol00?ooooooooooo`1aooooo`03o`00oooooooooooo04cooooo000Q
ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`1b
ooooo`03o`00oooooooooooo04cooooo000Rooooo`03o`00oooooooooooo03?ooooo00?o0000oooo
ooooool0B?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo04_ooooo000Rooooo`03
o`00oooooooooooo03?ooooo00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`1dooooo`03
o`00oooooooooooo04_ooooo000Rooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0
Aoooool00ol00?ooooooooooo`1fooooo`03o`00oooooooooooo04[ooooo000Sooooo`03o`00oooo
oooooooo03;ooooo00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`1gooooo`03o`00oooo
oooooooo04[ooooo000Sooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0AOooool0
0ol00?ooooooooooo`1iooooo`03o`00oooooooooooo04Wooooo000Tooooo`03o`00oooooooooooo
037ooooo00?o0000ooooooooool0A?ooool00ol00?ooooooooooo`1jooooo`03o`00oooooooooooo
04Wooooo000Tooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool0@oooool00ol00?oo
ooooooooo`1looooo`03o`00oooooooooooo04Sooooo000Uooooo`03o`00oooooooooooo033ooooo
0_l00013ooooo`03o`00oooooooooooo07gooooo00?o003oooooooooool0B?ooool002Gooooo00?o
003oooooooooool0<?ooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo07gooooo00?o
003oooooooooool0B?ooool002Kooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`11
ooooo`03o`00oooooooooooo07oooooo00?o003oooooooooool0Aoooool002Kooooo00?o003ooooo
ooooool0;oooool00ol0003oooooooooo`10ooooo`03o`00oooooooooooo083ooooo00?o003ooooo
ooooool0Aoooool002Oooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0oooooo`03
o`00oooooooooooo087ooooo00?o003oooooooooool0Aoooool002Oooooo00?o003oooooooooool0
;_ooool00ol0003oooooooooo`0nooooo`03o`00oooooooooooo08?ooooo00?o003oooooooooool0
A_ooool002Oooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0mooooo`03o`00oooo
oooooooo08Cooooo00?o003oooooooooool0A_ooool002Sooooo00?o003oooooooooool0;Oooool0
0ol0003oooooooooo`0looooo`03o`00oooooooooooo08Gooooo00?o003oooooooooool0A_ooool0
02Sooooo00?o003oooooooooool08_ooool5o`0000Kooooo00?o0000ooooooooool0>oooool00ol0
0?ooooooooooo`27ooooo`03o`00oooooooooooo04Gooooo000Yooooo`03o`00oooooooooooo027o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03_ooooo00?o003ooooo
ooooool0Qoooool00ol00?ooooooooooo`15ooooo`00:Oooool00ol00?ooooooooooo`0Iooooo`Ko
00000oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo03[ooooo00?o003ooooooooo
ool0ROooool00ol00?ooooooooooo`14ooooo`00:_ooool00ol00?ooooooooooo`0Rooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0ol0000iooooo`03o`00oooooooooooo08[ooooo00?o003oooooooooool0
A?ooool002[ooooo00?o003oooooooooool08oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oo
oooooooo03Sooooo00?o003oooooooooool0Roooool00ol00?ooooooooooo`14ooooo`00:oooool0
0ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool0
0ol00?ooooooooooo`2=ooooo`03o`00oooooooooooo04?ooooo000[ooooo`03o`00oooooooooooo
01oooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03Kooooo00?o003o
ooooooooool0S_ooool00ol00?ooooooooooo`13ooooo`00;?ooool00ol00?ooooooooooo`0Noooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0eooooo`03o`00oooooooo
oooo08oooooo00?o003oooooooooool0@oooool002gooooo00?o003oooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`03o`00oooooooooooo093ooooo00?o003oooooooooool0@_ooool002go
oooo00?o003oooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo097o
oooo00?o003oooooooooool0@_ooool002kooooo00?o003oooooooooool09oooool00ol0003ooooo
ooooo`0cooooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0@_ooool0017ooooo1Ol0
000Hooooo`03o`00oooooooooooo02Oooooo00?o0000ooooooooool0<_ooool00ol00?oooooooooo
o`0=ooooo`Go0000AOooool2o`000003oa0@4?oooooooooo03Sooooo00?o003oooooooooool01_oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<03Kooooo000Aooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
6Oooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
3_ooool01OnHV9So8B4Qonk^k_ooooooA4A404Kooooo00?o0000ooooooooool0>Oooool00ol00?oo
ooooooooo`06ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40=_ooool000Wooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^01_ooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0`ooooo`03
o`00oooooooooooo013ooooo00?oV9RHob4Q8Oo^k^h0A?ooool5o`0003[ooooo00?o003ooooooooo
ool01_ooool01Ol0003ooooooooooooooooo000003Kooooo000Cooooo`03oiRHV?lQ8B7ok^k^01[o
oooo00?o003oooooooooool09Oooool2o`00033ooooo00?o003oooooooooool04_ooool00onHV9So
8B4Qonk^kP13ooooo`04odA4A?oMgMgoooooo`0003cooooo00?o003oooooooooool01Oooool01Ol0
003oV9RHoooooonHV9So8B4Q03Kooooo000Dooooo`03ogMgMomVIVKooooo01[ooooo00?o003ooooo
ooooool09?ooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo01Cooooo00?oMgMgofIV
I_ooool0@_ooool01?oMgMgoEEEEooooool0000looooo`03o`00oooooooooooo00Gooooo00Go0000
oeEEEOl0003o410@olc<c00fooooo`005Oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooo
oooo02Cooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooo
oooo04;ooooo00?oMgMgolc<c?l00000?Oooool00ol00?ooooooooooo`04ooooo`03oeEEEOn7QhOo
oooo03Sooooo000Aooooo`05o`000?nj^[[ooooooiRHV?l@41007?ooool00ol00?ooooooooooo`0S
ooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool04oooool01Ol0003o^[ZjoooooonH
V9So410@04Cooooo00?ok^k^odA4A?l00000?Oooool00ol00?ooooooooooo`04ooooo`03omgMgOl@
413oV9RH03Sooooo000Aooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`07Oooool00ol00?oooooooooo
o`0Rooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool05?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<04Gooooo00?oMgMgo`000?ooool0??ooool00ol00?ooooooooooo`05ooooo`04olc<
c?m4A4Co0000oa0@43Kooooo000cooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool0
:_ooool00ol00?ooooooooooo`2Oooooo`03o`00oooooooooooo03kooooo000dooooo`03o`00oooo
oooooooo027ooooo00?o0000ooooooooool0:Oooool00ol00?ooooooooooo`2Pooooo`03o`00oooo
oooooooo03kooooo000dooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool09oooool2
o`00oj?ooooo00?o003oooooooooool0?_ooool003Gooooo00?o003oooooooooool08?ooool00ol0
003oooooooooo`0Vooooo`03o`00oooooooooooo0:Cooooo00?o003oooooooooool0:_ooool00ol@
413o0000o`000002o`000003oa0@4?oooooooooo00_ooooo000fooooo`03o`00oooooooooooo01oo
oooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`2Uooooo`03o`00oooooooooooo02co
oooo00?o0000ooooooooool03_ooool000Sooooo;_l000000ol00?oo0000o`000016o`000003o`00
ool0003o00000:Ko000000?o003oo`000?l000007ol0000=ooooo`03o`000?oooooooooo00kooooo
000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool00?l>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooo003o00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`00o`kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000o`00ooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`00>?ooool00ol00?oooooooooo
o`0Mooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0Z_ooool00ol00?oooooooooo
o`0Yooooo`03oa0@4?l0003o000000?o00003Oooool003Wooooo00?o003oooooooooool07?ooool0
0ol0003oooooooooo`0Pooooo`03o`00oooooooooooo0:cooooo00?o003oooooooooool0:_ooool0
0ol0003oooooooooo`0>ooooo`00>_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo
01oooooo00?o003oooooooooool0[Oooool00ol00?ooooooooooo`0Zooooo`03oa0@4?nj^[[ooooo
00kooooo000kooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool07_ooool00ol00?oo
ooooooooo`2^ooooo`03o`00oooooooooooo02[ooooo00Co^[Zjoa0@4?l0003o410@3Oooool003co
oooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo0;3o
oooo00?o003oooooooooool0>_ooool003gooooo0_l00?lIooooo`03o`000?oooooooooo01_ooooo
0_l00?ncooooo`03o`00oooooooooooo03[ooooo000oooooo`03o`00oooooooooooo01Kooooo00?o
0000ooooooooool06_ooool00ol00?ooooooooooo`2cooooo`03o`00oooooooooooo03[ooooo0010
ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`2e
ooooo`03o`00oooooooooooo03Wooooo0011ooooo`03o`00oooooooooooo01Cooooo0_l0000Ioooo
o`03o`00oooooooooooo0;Kooooo00?o003oooooooooool0>Oooool004;ooooo00?o003ooooooooo
ool04oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo0;Oooooo00?o003ooooooooo
ool0>Oooool004?ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Eooooo`;o003o
^_ooool00ol00?ooooooooooo`0iooooo`00A?ooool2o`00oa;ooooo00?o0000ooooooooool04_oo
ool3o`00okgooooo00?o003oooooooooool0>?ooool004Kooooo00?o003oooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`;o003o`?ooool00ol00?ooooooooooo`0hooooo`00Aoooool2o`00
o`oooooo00?o0000ooooooooool03_ooool2o`00ol;ooooo00?o003oooooooooool0>?ooool004Wo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o003oaOooool00ol00?oo
ooooooooo`0gooooo`00B_ooool2o`00o`cooooo00?o0000ooooooooool02_ooool2o`00olOooooo
00?o003oooooooooool0=oooool004cooooo0_l00?l01?lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo00Sooooo0_l00?o9ooooo`03o`00oooooooooooo03Oooooo001=ooooo`05ogMgMol0
0?oo003oo`00oomgMgL01_ooool00ol0003oooooooooo`05ooooo`?o003oboooool00ol00?oooooo
ooooo`0gooooo`00COooool01?l@413oooooooooooooool5o`00o`;ooooo00?o0000ooooooooool0
1Ol00?o?ooooo`03o`00oooooooooooo03Kooooo000@oooooa7oo`002OoooolAool000Sooooo4Ooo
00000ooooooo003oo`00o`04o`00o`;ooooo4Ooo0009oooooa7oo`002?oooolAool000Wooooo4Ooo
0009oooooa7oo`002?oooolAool000Wooooo4Ooo0009oooooa7oo`002?ooool5ool00003o`00oooo
003oo`0000Woo`00;Oooool004gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0=Cooooo00?o003oooooooooool0=_ooool004gooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo0=Gooooo00?o003oooooooooool0=Oooool004gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0=Gooooo00?o003oooooooooool0=Ooo
ool004gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0=Gooooo00?o
003oooooooooool0=Oooool005Sooooo00?o0000ooooooooool0e_ooool00ol00?ooooooooooo`0d
ooooo`00F?ooool00ol0003oooooooooo`3Fooooo`03o`00oooooooooooo03Cooooo001Hooooo`03
o`000?oooooooooo0=Kooooo00?o003oooooooooool0=?ooool005Sooooo00?o0000ooooooooool0
e_ooool00ol00?ooooooooooo`0dooooo`00F?ooool00ol0003oooooooooo`3Gooooo`03o`00oooo
oooooooo03?ooooo001Hooooo`;o0000f?ooool00ol00?ooooooooooo`0cooooo`00F?ooool00ol0
003oooooooooo`3Gooooo`03o`00oooooooooooo03?ooooo001Hooooo`03o`000?oooooooooo0=So
oooo00?o003oooooooooool0<_ooool005Sooooo00?o0000ooooooooool0f?ooool00ol00?oooooo
ooooo`0booooo`00F?ooool00ol0003oooooooooo`3Hooooo`03o`00oooooooooooo03;ooooo001H
ooooo`03o`000?oooooooooo0=Sooooo00?o003oooooooooool0<_ooool005Sooooo00?o0000oooo
ooooool0fOooool00ol00?ooooooooooo`0aooooo`00F?ooool00ol0003oooooooooo`3Iooooo`03
o`00oooooooooooo037ooooo001Hooooo`03o`000?oooooooooo0=Wooooo00?o003oooooooooool0
<Oooool005Sooooo00?o0000ooooooooool0f_ooool00ol00?ooooooooooo`0`ooooo`00F?ooool0
0ol0003oooooooooo`3Jooooo`03o`00oooooooooooo033ooooo001Hooooo`;o0000foooool00ol0
0?ooooooooooo`0`ooooo`00F?ooool00ol0003oooooooooo`3Kooooo`03o`00oooooooooooo02oo
oooo001Hooooo`03o`000?oooooooooo0=_ooooo00?o003oooooooooool0;oooool005Sooooo00?o
0000ooooooooool0foooool00ol00?ooooooooooo`0_ooooo`00F?ooool00ol0003oooooooooo`3K
ooooo`03o`00oooooooooooo02oooooo001Hooooo`03o`000?oooooooooo0=cooooo00?o003ooooo
ooooool0;_ooool005Sooooo00?o0000ooooooooool0g?ooool00ol00?ooooooooooo`0^ooooo`00
F?ooool00ol0003oooooooooo`3Looooo`03o`00oooooooooooo02kooooo001Hooooo`03o`000?oo
oooooooo0=cooooo00?o003oooooooooool0;_ooool005Sooooo00?o0000ooooooooool0gOooool0
0ol00?ooooooooooo`0]ooooo`00F?ooool00ol0003oooooooooo`3Mooooo`03o`00oooooooooooo
02gooooo001Hooooo`;o0000g_ooool00ol00?ooooooooooo`0]ooooo`00F?ooool00ol0003ooooo
ooooo`3Mooooo`03o`00oooooooooooo02gooooo001Hooooo`03o`000?oooooooooo0=gooooo00?o
003oooooooooool0;Oooool005Sooooo00?o0000ooooooooool0g_ooool00ol00?ooooooooooo`0/
ooooo`00F?ooool00ol0003oooooooooo`3Nooooo`03o`00oooooooooooo02cooooo001Hooooo`03
o`000?oooooooooo0=kooooo00?o003oooooooooool0;?ooool005Sooooo00?o0000ooooooooool0
g_ooool00ol00?ooooooooooo`0/ooooo`00F?ooool00ol0003oooooooooo`3Oooooo`03o`00oooo
oooooooo02_ooooo001=ooooo`Go00001_ooool00ol0003oooooooooo`3Oooooo`03o`00oooooooo
oooo02_ooooo001=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3O
ooooo`03o`00oooooooooooo02_ooooo001>ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003Ooooo
o`03o`00oooooooooooo02_ooooo001?ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0h?ooool00ol00?ooooooooooo`0Zooooo`00D?ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo0>3ooooo00?o003oooooooooool0:_ooool0057ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3Pooooo`03o`00oooooooooooo02[ooooo001=ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3Pooooo`03o`00oooooooooooo02[ooooo001=
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Pooooo`03o`00oooo
oooooooo02[ooooo001Hooooo`03o`000?oooooooooo0>7ooooo00?o003oooooooooool0:Oooool0
05Sooooo00?o0000ooooooooool0hOooool00ol00?ooooooooooo`0Yooooo`00F?ooool00ol0003o
ooooooooo`3Qooooo`03o`00oooooooooooo02Wooooo001Hooooo`03o`000?oooooooooo0>7ooooo
00?o003oooooooooool0:Oooool005Sooooo00?o0000ooooooooool0h_ooool00ol00?oooooooooo
o`0Xooooo`00F?ooool2o`000>?ooooo00?o003oooooooooool0:?ooool005Sooooo00?o0000oooo
ooooool0h_ooool00ol00?ooooooooooo`0Xooooo`00F?ooool00ol0003oooooooooo`3Rooooo`03
o`00oooooooooooo02Sooooo001Hooooo`03o`000?oooooooooo0>?ooooo00?o003oooooooooool0
9oooool005Sooooo00?o0000ooooooooool0hoooool00ol00?ooooooooooo`0Wooooo`00F?ooool0
0ol0003oooooooooo`3Sooooo`03o`00oooooooooooo02Oooooo001Hooooo`03o`000?oooooooooo
0>?ooooo00?o003oooooooooool09oooool005Sooooo00?o0000ooooooooool0hoooool00ol00?oo
ooooooooo`0Wooooo`00F?ooool00ol0003oooooooooo`3Tooooo`03o`00oooooooooooo02Kooooo
001Hooooo`03o`000?oooooooooo0>Cooooo00?o003oooooooooool09_ooool005Sooooo00?o0000
ooooooooool0i?ooool00ol00?ooooooooooo`0Vooooo`00F?ooool2o`000>Gooooo00?o003ooooo
ooooool09_ooool005Sooooo00?o0000ooooooooool0iOooool00ol00?ooooooooooo`0Uooooo`00
F?ooool00ol0003oooooooooo`3Uooooo`03o`00oooooooooooo02Gooooo001Hooooo`03o`000?oo
oooooooo0>Gooooo00?o003oooooooooool09Oooool005Sooooo00?o0000ooooooooool0iOooool0
0ol00?ooooooooooo`0Uooooo`00F?ooool00ol0003oooooooooo`3Vooooo`03o`00oooooooooooo
02Cooooo001Hooooo`03o`000?oooooooooo0>Kooooo00?o003oooooooooool09?ooool005Sooooo
00?o0000ooooooooool0i_ooool00ol00?ooooooooooo`0Tooooo`00F?ooool00ol0003ooooooooo
o`3Vooooo`03o`00oooooooooooo02Cooooo001Hooooo`03o`000?oooooooooo0>Kooooo00?o003o
ooooooooool09?ooool005Sooooo0_l0003Xooooo`03o`00oooooooooooo02?ooooo001Hooooo`03
o`000?oooooooooo0>Oooooo00?o003oooooooooool08oooool005Sooooo00?o0000ooooooooool0
ooooool>ooooo`00F?ooool00ol0003oooooooooo`3oooooo`kooooo001Hooooo`03o`000?oooooo
oooo0?oooooo3_ooool005Sooooo00?o0000ooooooooool0ooooool>ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00EOooool00omgMgOo
IVIVooooo`08ooooo`03ofIVI_mgMgOooooo0?oooooo1_ooool005Cooooo00?ogMgMoa0@4?o^k^h0
2Oooool00oo^k^ko410@omgMg@3oooooo`Kooooo001<ooooo`;o<S8b1_ooool00omEEEGoV9RHoooo
o`02ooooo`03oa0@4?l0003o000000;o000000Go410@ooooooooooooQhN7ofIVIP3oooooo`Kooooo
001;ooooo`04omgMgOl@413o410@olc<c0Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03onk^k_l0003ooooo0?oooooo1Oooool004_ooooo0_mVIVH00omgMgOoIVIVoooo
o`04ooooo`03oc8b<_oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooo`Cooooo001;ooooo`04o`000?oMgMgogMgMo`0000Gooooo00?o<S8booooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo1?ooool004[ooooo00KoV9RH
oc8b<_oooooooooooc8b<_nHV9P4ooooo`03o`000?o^k^kooooo00Cooooo00?o0000ooooooooool0
0oooool00oo^k^ko0000ooooo`3oooooo`Gooooo001:ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A41?ooool00omEEEGoMgMgooooo`02ooooo`03oa0@4?l0003o000000?o00000_ooool00omgMgOo
EEEEooooo`3oooooo`Gooooo0019ooooo`03omgMgOl0003ooooo00?ooooo00?o0000omgMgOooool0
0_ooool00ooMgMgo410@onk^kP04ooooo`03o`000?oooooooooo00;ooooo00?ok^k^oa0@4?oMgMd0
ooooool6ooooo`00BOooool3o`0000;ooooo0ol00004ooooo`03ogMgMomVIVKooooo00?ooooo00?o
410@okZj^_ooool00_ooool00omVIVKoMgMgooooo`3oooooo`Kooooo001Kooooo`04okZj^_l@413o
0000oa0@4?oooooo2_ooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2.45636, -5.55473, \
0.0347613, 0.0585886}}],

Cell[TextData[{
  "Fig. 7.6 Potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`v = 2, \ \ A = 0\)]],
  " (solid), and energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  "(dashed) for which a soliton solution exists."
}], "Caption",
  CellTags->"Fig. 7.6"],

Cell["\<\
Particles that start with zero velocity at the top of the hill take \
an infinitely long time to fall down the slope, which is why the period of \
the oscillatory motion goes to infinity for this energy. \
\>", "Text"],

Cell[TextData[{
  "\tSince the period of the motion is infinite, the wave peaks becomes \
infinitely separated, resulting in a single isolated peak. This peak is \
called a ",
  StyleBox["soliton, ",
    FontSlant->"Italic"],
  "or",
  StyleBox[" solitary wave.",
    FontSlant->"Italic"],
  " in Cell ",
  ButtonBox["7.38",
    ButtonData:>"Cell 7.38",
    ButtonStyle->"Hyperlink"],
  ", we plot the case of a soliton of unit amplitude (",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ") for which ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] 0\)]],
  " at large ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`c \[Rule] \ \(b \[Rule] \ 0\)\)]],
  "). "
}], "Text",
  CellTags->"i:30"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f[s, 1, 0, 0], {s, \(-20\), 20}, 
        PlotLabel \[Rule] "\<m =\>" <> ToString[1] <> "\<(soliton)\>", 
        AxesLabel \[Rule] \ {\*"\"\<s/\!\(\@\[Alpha]\)\>\"", "\<\>"}, 
        PlotRange \[Rule] {\(- .2\), 1}\ ];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.38"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.103006 0.515028 [
[.02381 .09051 -9 -9 ]
[.02381 .09051 9 0 ]
[.2619 .09051 -9 -9 ]
[.2619 .09051 9 0 ]
[.7381 .09051 -6 -9 ]
[.7381 .09051 6 0 ]
[.97619 .09051 -6 -9 ]
[.97619 .09051 6 0 ]
[1.025 .10301 0 -6.71875 ]
[1.025 .10301 32.5625 6.71875 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -41.0625 0 ]
[.5 .63053 41.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .10301 m
.02381 .10926 L
s
[(-20)] .02381 .09051 0 1 Mshowa
.2619 .10301 m
.2619 .10926 L
s
[(-10)] .2619 .09051 0 1 Mshowa
.7381 .10301 m
.7381 .10926 L
s
[(10)] .7381 .09051 0 1 Mshowa
.97619 .10301 m
.97619 .10926 L
s
[(20)] .97619 .09051 0 1 Mshowa
.125 Mabswid
.07143 .10301 m
.07143 .10676 L
s
.11905 .10301 m
.11905 .10676 L
s
.16667 .10301 m
.16667 .10676 L
s
.21429 .10301 m
.21429 .10676 L
s
.30952 .10301 m
.30952 .10676 L
s
.35714 .10301 m
.35714 .10676 L
s
.40476 .10301 m
.40476 .10676 L
s
.45238 .10301 m
.45238 .10676 L
s
.54762 .10301 m
.54762 .10676 L
s
.59524 .10301 m
.59524 .10676 L
s
.64286 .10301 m
.64286 .10676 L
s
.69048 .10301 m
.69048 .10676 L
s
.78571 .10301 m
.78571 .10676 L
s
.83333 .10301 m
.83333 .10676 L
s
.88095 .10301 m
.88095 .10676 L
s
.92857 .10301 m
.92857 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-0.2)] .4875 0 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.4)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.6)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.8)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.125 13.000 moveto
(H) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(soliton) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.125 13.000 moveto
(L) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10303 m
.03279 .10303 L
.04262 .10304 L
.05288 .10305 L
.06244 .10306 L
.0731 .10307 L
.0828 .10309 L
.094 .10311 L
.10458 .10315 L
.11428 .10318 L
.12455 .10323 L
.13333 .10329 L
.14299 .10336 L
.15313 .10346 L
.1624 .10358 L
.17311 .10375 L
.18328 .10396 L
.19287 .10421 L
.20309 .10454 L
.22147 .1054 L
.23176 .10608 L
.24289 .10703 L
.25339 .10819 L
.26306 .10955 L
.28188 .1133 L
.29257 .1163 L
.30254 .11988 L
.313 .12465 L
.3229 .13036 L
.34145 .14526 L
.35111 .15581 L
.36136 .16973 L
.37978 .20347 L
.38915 .22586 L
.39925 .25455 L
.41753 .31935 L
.43718 .40573 L
.45867 .50765 L
.4686 .55004 L
.47405 .57024 L
.4792 .58662 L
.484 .59913 L
.48653 .60454 L
.48921 .60931 L
.49146 .61255 L
.49265 .61397 L
.49394 .61526 L
.49511 .61623 L
.49619 .61694 L
.49727 .61747 L
Mistroke
.4983 .61781 L
.49955 .61802 L
.50025 .61803 L
.5009 .61797 L
.50209 .6177 L
.50334 .61719 L
.50447 .61653 L
.50552 .61573 L
.50791 .61333 L
.5105 .60978 L
.51285 .60573 L
.51814 .5939 L
.5276 .56442 L
.53654 .52883 L
.57492 .35077 L
.59435 .27533 L
.60466 .24285 L
.61576 .21364 L
.62635 .19083 L
.63605 .17374 L
.64591 .15955 L
.65508 .1488 L
.67404 .13241 L
.68406 .12621 L
.69475 .121 L
.70502 .11709 L
.71614 .1138 L
.72664 .11139 L
.7363 .10965 L
.74537 .10835 L
.7551 .10723 L
.76578 .10627 L
.77576 .10557 L
.78592 .10501 L
.79697 .10454 L
.80742 .1042 L
.81709 .10395 L
.82605 .10376 L
.83573 .10361 L
.84635 .10347 L
.85632 .10337 L
.86588 .10329 L
.87634 .10323 L
.88726 .10318 L
.89743 .10314 L
.90793 .10311 L
.91786 .10309 L
.93644 .10306 L
.94615 .10305 L
.95643 .10304 L
Mistroke
.97488 .10303 L
.97619 .10303 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{315.562, 195.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006:0000lb000`400?l00000o`00003ooooooon;
ooooo`00oooooon;ooooo`00oooooon;ooooo`00oooooon;ooooo`00oooooon;ooooo`00oooooon;
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000hoooool0
09;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A40>?ooooo002:ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h0i?ooool009;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003Jooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`3Jooooo`00T_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Jooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0=[ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0f_ooool00:gooooo00?o0000ooooooooool0
f_ooool00:gooooo00?o0000ooooooooool0f_ooool00:gooooo00?o0000ooooooooool0f_ooool0
0:gooooo00?o0000ooooooooool0f_ooool00:gooooo0_l0003Kooooo`00[Oooool00ol0003ooooo
ooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3J
ooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00
[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool2
o`000=_ooooo002]ooooo`03o`000?oooooooooo0=[ooooo002]ooooo`03o`000?oooooooooo0=[o
oooo002]ooooo`03o`000?oooooooooo0=[ooooo002]ooooo`03o`000?oooooooooo0=[ooooo0008
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^Aoooool00ol0003oooooooooo`18ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kTGooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0=?ooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0Aoooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Aoooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`15ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Co
oooo0006o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03co
oooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4017oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@04Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo000:
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000017ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000017ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000004Oooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000003Cooooo000;ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`000017ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000017ooooo`;o0000Boooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000B?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
=?ooool000cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo04Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04Oooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100BOooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0<_ooool000Sooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Aoooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Aoooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`15ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Cooooo0008ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Oooooo00?o0000ooooooooool0B?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0AOooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`03oiRHV?oooooooooo013ooooo002]oooo
o`03o`000?oooooooooo0;cooooo00?o8B4QomgMgOooool01oooool00oo^k^ko0000olc<c00Aoooo
o`00[Oooool00ol0003oooooooooo`2dooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool0
0onHV9SoEEEEooooo`07ooooo`03ogMgMol0003oIVIV00Cooooo00OoV9RHo`000?l0003oEEEEonk^
k_mVIVKo000000Kooooo002]ooooo`03o`000?oooooooooo0;Cooooo00Ko0000ojVYZOoooooooooo
okZj^_l00003ooooo`03o`000?oMgMgooooo00Gooooo00Cok^k^o`000?nHV9So8B4Q1?ooool01_l0
003oZJVYoooooon7QhOo<S8bofIVIPOooooo002]ooooo`03o`000?oooooooooo0;Gooooo00Go^[Zj
ohN7QomVIVKoIVIVoa0@4003ooooo`;oMgMg1_ooool01OmgMgOoEEEEooooool0003ogMgM00?ooooo
00Ko0000ooooooooooooooooohN7Qom4A4@7ooooo`00[Oooool00ol0003oooooooooo`2dooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0oooool00oo^k^ko410@onk^kP05ooooo`05o`000?o<c<co
oooooeEEEOn7QhL00oooool01_lQ8B7oc<c<ooooooooooooV9RHoc8b<POooooo0003oooooooo0000
Eol0000;ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00001?ooool00omEEEGoV9RHooooo`02oooo
o`03oc8b<_mEEEGo<S8b00;ooooo00?oZJVYob4Q8Oooool00_ooool01onYZJWo8B4QomgMgOo^k^ko
<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02OoooolAo`0000Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02oooooa7o00002oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0A
ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001?ooool00ooMgMgo410@ooooo`02ooooo`03okZj
^_lb<S;o^[Zj00?ooooo00?o0000omgMgOooool00_ooool01_nHV9So0000o`000?nHV9So^[Zjoc8b
<PKooooo000;ooooo`03o`000?oooooooooo04[ooooo1ol0001>ooooo`03o`000?oooooooooo04co
oooo1ol0001=ooooo`03o`000?oooooooooo01cooooo00?oEEEEoiRHV?ooool01oooool00omEEEGo
QhN7ooooo`0>ooooo`00Goooool3o`0004_ooooo00?o0000ooooooooool0BOooool3o`0007?ooooo
00?o^[ZjodA4A?ooool01oooool00onYZJWo<S8booooo`0>ooooo`00H_ooool4o`0004Oooooo00?o
0000ooooooooool0AOooool4o`00083ooooo00?ok^k^o`000?o^k^h03_ooool006Kooooo0ol00014
ooooo`03o`000?oooooooooo04;ooooo0ol00025ooooo`03odA4A?nHV9Sooooo00gooooo001Yoooo
o`Co0000@?ooool00ol0003oooooooooo`0oooooo`?o0000R?ooool00onHV9SoA4A4ooooo`0=oooo
o`00KOooool2o`0003kooooo00?o0000ooooooooool0?Oooool2o`0008_ooooo00?ok^k^o`000?l0
00002Ol00004ooooo`00Koooool2o`0003cooooo00?o0000ooooooooool0>oooool2o`0009gooooo
001aooooo`;o0000>_ooool2o`0003_ooooo00?o0000ooooooooool0WOooool007?ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0hooooo`;o0000X?ooool007Cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:3ooooo001eooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Qooooo`00
M_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
X_ooool007Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo0:?ooooo001gooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2Tooooo`00N?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0YOooool007Wooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo0:Kooooo001jooooo`03o`000?oooooooooo033ooooo
0_l0000aooooo`03o`000?oooooooooo0:Oooooo001jooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Xooooo`00Noooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Z?ooool007cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0:Wooooo001mooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Zooooo`00
O_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
Z_ooool007kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0:_ooooo001oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`2[ooooo`00Ooooool00ol0003oooooooooo`0[ooooo`;o0000;?ooool00ol0
003oooooooooo`2/ooooo`00P?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0[Oooool0083ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2^ooooo`00P_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0[oooool008;ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:oooooo0023ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2`ooooo`00
Poooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0/?ooool008Cooooo
00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0;3ooooo0024ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Vooooo`03o`000?oooooooooo0;7ooooo0025ooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2aooooo`00QOooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/Oooool008Gooooo00?o0000oooooooo
ool02_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03o`000?oooooooooo00Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03o`000?oooooooooo
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;?ooooo0026ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2cooooo`00Qoooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0/oooool008Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;Co
oooo0028ooooo`03o`000?oooooooooo02;ooooo0_l0000Tooooo`03o`000?oooooooooo0;Cooooo
0028ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2eooooo`00R?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0]Oooool008Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo0;Gooooo0029ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2fooooo`00R_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0]_ooool008[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;Oooooo002:ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2gooooo`00Roooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0]oooool008_o
oooo00?o0000ooooooooool07oooool2o`00023ooooo00?o0000ooooooooool0^?ooool008_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;Sooooo
002<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`2hooooo`00S?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0^Oooool008cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo0;Wooooo002=ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`2iooooo`00SOooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0^_ooool008gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;[ooooo002=ooooo`03o`000?oooooo
oooo01gooooo0_l0000Nooooo`03o`000?oooooooooo0;[ooooo002>ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2kooooo`00S_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0^oooool008kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;_ooooo
002>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`2kooooo`00Soooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0_?ooool008oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo0;cooooo002?ooooo`08o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`2looooo`00T?ooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0;cooooo002@ooooo`03o`000?oooooo410@00?ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo0ol0000Kooooo`03o`000?oooooooooo0;cooooo002@ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0_Oooool0093ooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`2mooooo`00TOooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo0;gooooo002Aooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0_Oooool0097ooooo00Ko0000
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2nooooo`00TOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0__ooool009;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;kooooo002Booooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2nooooo`00T_ooool00ol0003o
ooooooooo`0Hooooo`;o00006Oooool00ol0003oooooooooo`2oooooo`00T_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0_oooool009?ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0;oooooo002C
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2o
ooooo`00Toooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0_oooool009?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0<3ooooo002Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`30ooooo`00U?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0`?ooool009Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<3ooooo002Dooooo`03o`000?oooooooooo
01Kooooo0_l0000Gooooo`03o`000?oooooooooo0<7ooooo002Eooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`31ooooo`00UOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0`Oooool009Gooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<7ooooo002E
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`31
ooooo`00UOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0`_ooool009Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0<;ooooo002Fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`32ooooo`00U_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0`_ooool009Kooooo00?o0000ooooooooool05?ooool2
o`0001Kooooo00?o0000ooooooooool0`_ooool009Oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0<?ooooo002Gooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`33ooooo`00Uoooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0`oooool009Oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0<?ooooo002H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`34
ooooo`00T_ooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000000oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
a?ooool009;ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000?ooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
0<Cooooo002Booooo`07oa0@4?ooooooooooooooool@413oooooo`000009ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0001?ooooo00?o0000ooooooooool0a?ooool009;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0a?ooool009;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0aOooool009;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Kooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<Gooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`06ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`35ooooo`00T_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool01oooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0aOooool009[ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<Kooooo002Jooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`36ooooo`00V_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0a_oo
ool009[ooooo00?o0000ooooooooool04?ooool2o`0001;ooooo00?o0000ooooooooool0a_ooool0
09[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
0<Kooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`37ooooo`00Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0aoooool009_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo0<Oooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`37ooooo`00Voooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0aoooool009cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0<Sooooo002Looooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`38ooooo`00W?oo
ool00ol0003oooooooooo`0>ooooo`;o00004?ooool00ol0003oooooooooo`38ooooo`00W?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0b?ooool0
09cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0<Wooooo002Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`39ooooo`00WOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0bOooool009gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo0<Wooooo002Mooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`39ooooo`00WOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0b_ooool009kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<[ooooo002Nooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`03o`000?oooooooooo0<[ooooo002Nooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3:ooooo`00W_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0boooool0
09kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0<_ooooo002Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`3;ooooo`00Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0boooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
00Woooooo`000?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo0<_ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@09ooooool0003ooooooooooolQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`3<ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0c?ooool009;ooooo00Go0000ooooooooooooooooo`000009oooo
o`07o`000?oooooo<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00002oooool00ol0003ooooooooo
o`3<ooooo`00T_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooo<c<`00ol0
00000oo<c<coooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0c?oo
ool009;ooooo00Go410@oooooooooooooooooa0@4009ooooo`07o`000?oooooo410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0c?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`07o`000?oooooo0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0cOooool009;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`07o`000?ooooooZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0cOooool00:7ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<gooooo002Qooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3=ooooo`00XOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0c_ooool00:7o
oooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool0c_ooool00:7ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0<kooooo
002Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3>ooooo`00X_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0coooool00:;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0<oooooo002Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3?ooooo`00Xoooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0coooool00:?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=3ooooo002Sooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3@ooooo`00Y?ooool00ol0
003oooooooooo`06ooooo`;o00002?ooool00ol0003oooooooooo`3@ooooo`00Y?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0dOooool00:Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=7ooooo
002Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3Aooooo`00YOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0d_ooool00:Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0=;ooooo002Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3Cooooo`00Y_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0doooool00:Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=?ooooo002Wooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo0=Cooooo002Wooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`00Z?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0e?ooool00:Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=Gooooo
002Yooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3Eooooo`00ZOoo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0eOooool00:?ooooo1?l0
00000ol@413oooooo`000003ooooo`05o`000?ooooooooooooooool00000f?ooool00:Gooooo00?o
0000ooooooooool00_ooool2o`000005ooooool0003oooooooooool00000fOooool00:Gooooo00?o
0000ooooooooool00oooool5o`000=[ooooo002Uooooo`03o`000?oooooooooo00Gooooo0ol0003J
ooooo`00YOooool00ol0003oooooooooo`3Rooooo`00YOooool00ol0003oooooooooo`3Rooooo`00
YOooool00ol0003oooooooooo`3Rooooo`00Xoooool00omEEEGoIVIVo`00003Tooooo`00oooooon;
ooooo`00oooooon;ooooo`00Woooool00omgMgOoIVIVooooo`0eooooo`03ofIVI_mgMgOooooo0;3o
oooo002Nooooo`03omgMgOl@413ok^k^03Kooooo00?ok^k^oa0@4?oMgMd0/?ooool007cooooo0_l0
0002ooooo`05o`000?ooooooooooo`000?l@41004?ooool4o`000003oa0@4?oooooooooo00;ooooo
00?oEEEEoiRHV?ooool00_ooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEE
EOl0003o0000oeEEEOo^k^h2ooooo`Go00001?ooool5o`0000?ooooo00GoV9RHo`000?l0003oA4A4
okZj^P02ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01?l@413o0000o`000?ooool2
o`000003o`H61_oooooooooo0:kooooo001mooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEE
E@Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Co0000oooooooooooo
oooo0_l0002`ooooo`00OOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01?ooool00olb<S;oooooooooo`03ooooo`05okZj^_n7QhOoIVIVofIV
I_l@41000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0002`ooooo`00OOooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo1_l00005ooooo`03o`000?oooooo
oooo00Cooooo00?o<S8booooooooool00_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`;o0000/?ooool007gooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q01?ooooo00?o0000ooooooooool01?ooool00ol0003ok^k^ooooo`02oooo
o`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`04o`000?n7QhOoooooojVYZ@;o0000/?oo
ool007cooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZA?ooooo00?o0000oooooooo
ool01?ooool00omEEEGoMgMgooooo`02ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool0
1_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool01?ooool00ol@413o0000
o`000003ooooo`03oa0@4?l0003o000000?o00000oooool01_o^k^koEEEEo`000?l0003oEEEEonk^
kP;ooooo00?o410@o`000?mgMgL00_l000000om6ATKoEEEEooooo`2_ooooo`00Uoooool00ol0003o
ooooooooo`04ooooo`03omgMgOl@413ok^k^01Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0@ooooo`03onk^k_l@413ogMgM0;3ooooo002Eooooo`03oeEEEOmVIVKo000000Oooooo
00?oMgMgofIVI_ooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04?ooool00omVIVKoMgMgooooo`2`ooooo`00/oooool00ol@413o0000o`00
0008ooooo`03oa0@4?oooooooooo0<Wooooo003ooooooh_ooooo003ooooooh_ooooo003ooooooh_o
oooo003ooooooh_ooooo003ooooooh_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 393.438}, {242.812, 0}} -> {-21.3855, -0.252315, \
0.153925, 0.00711589}}]
}, Open  ]],

Cell["This soliton has a simple analytic form:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[f[s/\@\[Alpha], a, 0, 0]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.39"],

Cell[BoxData[
    \(a\ Sech[\(\@a\ s\)\/\(2\ \@3\ \@\[Alpha]\)]\^2\)], "Output"]
}, Open  ]],

Cell["Written as an equation, the soliton solution is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(s)\  = \ 
        a/\(\(cosh\^2\)(\(\@\(a/12\ \[Alpha]\)\) s)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.17)"],

Cell[TextData[{
  "From this expression, one can see that the length of the soliton increases \
as the amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " decreases. Cell ",
  ButtonBox["7.38",
    ButtonData:>"Cell 7.38",
    ButtonStyle->"Hyperlink"],
  " shows that the length (from end to end) is roughly"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L = \ 20\ \@\(\[Alpha]/a\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "  Also, according to Eq. ",
  ButtonBox["(7.2.16)",
    ButtonData:>{"Chapter7.nb", "(7.2.16)"},
    ButtonStyle->"Hyperlink"],
  " , the speed of the soliton increases as the amplitude increases:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v\  = \ a/3\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "(This is the speed as viewed from a frame already moving at speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  "). These expressions for the length and velocity are in scaled units. If \
we go back to real units the soliton height is ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o\  = \ 2\ h\ a/\((3\ c\_o)\)\)]],
  ", and the soliton speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\_lab\)]],
  " as seen in the lab frame depends on height  ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v\_lab = \ c\_o\ \((1 + \ z\_o/2\ h\ )\)\)]],
  ","
}], "NE2",
  CellTags->"(7.2.18)"],

Cell["and the length is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L = \ 20\/3\ \@\(h\^3/z\_o\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.19)"],

Cell["\<\
The earliest recorded observation of a soliton in the wild is found \
in a famous paper by Scott Russell (1844).  There, he describes a a soliton \
that he had witnessed ten years earlier:\
\>", "Text",
  CellTags->"i:31"],

Cell[TextData[{
  StyleBox["I was observing the motion of a boat which was rapidly drawn \
along a narrow channel by a pair of horses, when the boat suddenly stopped -- \
not so the mass of water in the channel which it had put in motion; it \
accumulated around the prow of the vessel in a state of violent agitation, \
then suddenly leaving it behind, rolled forward with great velocity, assuming \
the form of a large solitary elevation, a rounded, smooth and well-defined \
heap of water, which continued its course along the channel apparently \
without change of form or diminution of speed. I followed it on horseback",
    FontSize->10],
  ",",
  StyleBox[" and overtook it still rolling at a rate of some eight to nine \
miles an hour, preserving its original figure some thirty feet long and a \
foot to a foot and a half in height. Its height gradually diminished, and \
after a long chase of one or two miles I lost it in the windings of the \
channel. Such, in the month of August, 1834, was my first chance encounter \
with that singular and beautiful phenomenon.",
    FontSize->10]
}], "IndentedText"],

Cell[TextData[{
  "This exciting narrative shows that solitons are not mere artifacts of some \
mathematical idealization. In fact, it turns out that solitons are ubiquitous \
in nonlinear systems with dispersion. Some examples of other systems \
exhibiting solitons may be found in the exercises. They may even have useful \
practical applications: it has been proposed that soliton pulses could be \
used to transmit information in fiber optics networks. Even the best optical \
fibers are slightly dispersive, so that pulse trains eventually spread and \
lose coherence. However, pulse trains consisting of optical solitons (pulses \
with sufficiently large amplitude so that nonlinear effects in the index of \
refraction become important) are not affected by dispersive spreading. As of \
the year 2000, 10-Gbit/s bit rates have been demonstrated in fibers over \
distances of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`10\^5\)]],
  " km (see nearly any issue of ",
  StyleBox["Optics Letters",
    FontSlant->"Italic"],
  " from around this time). This is still an area of ongoing research, and \
the interested reader is referred to ",
  ButtonBox["Hasegawa and Kodama (1995)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:73"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2.3 Time-Dependent Solutions: The Galerkin Method", "Subsubtitle",
  CellTags->"c:18"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:19"],

Cell["\<\
\tWe have seen that steady soliton and cnoidal wave solutions to \
the KdV equation  occur because of a balance between nonlinear steepening and \
dispersive spreading. But how do we know that such a balance is stable? If a \
steady solution is slightly perturbed, does the result remain close to the \
steady solution, or diverge from it?  If the latter is true, then these \
steady solutions are not of much more than academic interest. Although Scott \
Russell's description indicates that solitons are in fact stable, it would be \
nice to see this fact arise from the mathematics. \
\>", "Text"],

Cell["\<\
\tThere has been considerable analytical work on the stability of \
steady solutions to the KdV equation. This work is of a highly technical \
nature and will not be discussed here. Rather, we will use numerical \
techniques already at our disposal to test the stability of the solutions.  \
We will also study the interaction between solitons, and wavebreaking. \
\>", \
"Text"],

Cell[TextData[{
  "\tWe will use the Galerkin method, solving the ",
  "KdV",
  " equation with periodic boundary conditions on an interval running from  \
",
  Cell[BoxData[
      \(TraditionalForm\`\(-L\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ".  A set of basis functions for these boundary conditions are"
}], "Text",
  CellTags->"i:74"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(
          x)\  = \ \[ExponentialE]\^\(\(\ \)\(i\ k\ x\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ n\ \[Pi]/L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\) \[LessEqual] \ n \[LessEqual] \ M\)]],
  "."
}], "NE2",
  CellTags->"(7.2.20)"],

Cell[TextData[{
  "The solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " is then written in terms of these functions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 
          t)\  = \ \[Sum]\+n\(\( c\_n\)(
              t)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \ x\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.21)"],

Cell[TextData[{
  "The basis functions are orthogonal with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-L\)\%L\( f\^*\) g \[DifferentialD]x\)]],
  ", so this is the inner product we will use. Substituting this series into \
the ",
  "KdV",
  " equation, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\[Sum]\+n\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
                  t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\), "+", 
            RowBox[{
              UnderscriptBox[
                StyleBox["\[Sum]",
                  FontSize->9], \(\(n\&_\)\&_\)], 
              RowBox[{
                UnderscriptBox[
                  StyleBox["\[Sum]",
                    FontSize->9], \(n\&_\)], \(\(\(c\_\(n\&_\)\&_\)(
                    t)\) \(\(c\_n\&_\)(
                    t)\) \[ImaginaryI]\ \(k\&_\) \[ExponentialE]\^\(\
\[ImaginaryI]\ \((\(k\&_\)\&_ + k\&_)\)\ x\)\)}]}], 
            "-", \(\[Alpha] \(\[Sum]\+n \[ImaginaryI]\ \(k\^3\) \(\(c\_n\)(
                    t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)\)}], "=", 
          "0"}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(7.2.22)"],

Cell[TextData[{
  "We now take an inner product with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  ", and note that,",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\),
                "TraditionalForm"], 
              ",", \(\[ExponentialE]\^\(\[ImaginaryI]\ \((\(k\&_\)\&_ + 
                        k\&_)\)\ x\)\)}], ")"}], 
          "=", \(L\ \[Delta]\_\(k, \ \(k\&_\)\&_ + k\&_\)\)}], 
        TraditionalForm]]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\&_\)\&_ = k - k\&_\)]],
  ", and Eq. ",
  ButtonBox["(7.2.22)",
    ButtonData:>{"Chapter7.nb", "(7.2.22)"},
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
              t)\) + \[Sum]\+\(n\&_\)\(\(c\_\(n - n\&_\)\)(t)\) \(\(c\_n\&_\)(
                t)\) \[ImaginaryI]\ k\&_ - \[Alpha]\ \[ImaginaryI]\ \(k\^3\) \
\(\(c\_n\)(t)\) = 0\)]],
  "."
}], "NE2",
  CellTags->"(7.2.23)"],

Cell[TextData[{
  "We will solve these coupled nonlinear ODEs for ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(t)\)]],
  " using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Before we do, however, we note that ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " is a real function, so this implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(-n\)\)(t)\  = \ \(\(\(c\_n\)(t)\)\^*\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.24)"],

Cell[TextData[{
  "Therefore, we do not need to solve for the coefficients with ",
  Cell[BoxData[
      \(TraditionalForm\`n < 0\)]],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(\(c[n_]\)[t_]\  := \ 
        Conjugate[\(c[\(-n\)]\)[t]]\  /; \ n < 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.40"],

Cell[TextData[{
  "\tAlso, note that the nonlinear term in Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  "  couples modes with different wavenumbers. Even though the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`n\&_\)]],
  " runs only from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ",  coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(n - n\&_\)\)(t)\)]],
  " may fall outside this range . In fact, this is sure to happen \
eventually",
  ",",
  " even if ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " is initially zero for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(n\)\(|\)\(\(>\)\(M\)\)\)\)]],
  ". For example, say that initially only ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(-1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  " are the only nonzero coefficients (i.e., the solution is a sinusoidal \
wave with wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/L\)]],
  "). Then according to Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  " , there is an initial rate of change for ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\[PlusMinus]2\)\)]],
  "given by\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) 
            c\_2 + \ \[ImaginaryI]\ \[Pi]\/L\ \((c\_1)\)\^2 = 
        0, \[IndentingNewLine]\(\[PartialD]\/\[PartialD]t\) 
            c\_\(-2\) - \ \[ImaginaryI]\ \[Pi]\/L\ \((c\_\(-1\))\)\^2 = 
        0. \)]]
}], "Text"],

Cell[TextData[{
  "When ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\[PlusMinus]2\)\)]],
  "has grown to large amplitude, these coefficients couple in turn to modes \
with ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(\[PlusMinus]3\), \ \(\[PlusMinus]4\), \)]],
  " and so on, until a broad range of wavenumbers are excited. This is called \
a ",
  StyleBox["cascade",
    FontSlant->"Italic"],
  ".  If it is unchecked, eventually waves with arbitrarily high wavenumbers \
are excited. This is what leads to wavebreaking in the case of Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " : as the wave attains infinite slope, this corresponds to Fourier modes \
with infinite wavenumber. "
}], "Text",
  CellTags->"i:53"],

Cell[TextData[{
  "\tWe can hope that the cascade is suppressed by the dispersive term in the \
KdV equation. However, one can see in Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  "  that this term, proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", causes only a rapid oscillation in the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  " for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", and does not affect its amplitude. On the other hand, we might imagine \
that this rapid oscillation does cause phase mixing, which has an equivalent \
effect to the suppression of the amplitude, so we will simply neglect all \
modes with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(n\)\(|\)\(\(>\)\(M\)\)\)\)]],
  ", explicitly setting them equal to zero: "
}], "Text"],

Cell[BoxData[
    \(\(\(c[n_]\)[t_]\  := \ 0\  /; \ Abs[n] > M;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.41"],

Cell["The hope is that these modes will not be needed.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: Cnoidal Wave", "Section",
  CellTags->{"i:44", "c:20"}],

Cell["\<\
For our first test, we will try a cnoidal wave  as the initial \
condition:\
\>", "Text"],

Cell[BoxData[{
    \(\(\(f[s_, a_, b_, 
          c_] = \ \ a\  - \ \((a - b)\)\ JacobiSN[Sqrt[\((a - c)\)/12] s, 
                  m]^2 /. m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(f0[x_]\  = \ f[x, 1,  .1, 0];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.42"],

Cell[TextData[{
  "In order to fit this cnoidal wave into our periodic boundary conditions, \
we choose ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " to be a multiple of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, b, c)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Lambda][a_, b_, c_]\  = \ 
        2\ EllipticK[m]\ Sqrt[12/\((a - c)\)]\  /. 
          m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(L\  = \ 2\ \[Lambda][1,  .1, 0]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.43"],

Cell[BoxData[
    \(35.72309221529325`\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "As usual, the initial conditions on the Fourier modes are determined by  \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_o\)(x)\)\(\ \)\)\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(
          0)\  = \((\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \ \(f\_o\)(
                x))\)/2  L\)]],
  ".",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "NE2",
  CellTags->"(7.2.25)"],

Cell["We will keep 15 modes in our solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(M = 15;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(k[n_]\  := \ n\ Pi/L;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ics\  = \ 
        Table[\(c[n]\)[0]\  \[Equal] \ 
            NIntegrate[
                Exp[\(-I\)\ k[n]\ x]\ f0[x], {x, \(-L\), L}]/\((2  L)\), {n, 
            0, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.44"],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \!\(35.72309221520074`\)."\)], \
"Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \
\!\(-35.72309221520074`\)."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \!\(35.72309221520074`\)."\)], \
"Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(NIntegrate :: \"ncvb\"\) will be suppressed \
during this calculation."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
The errors in the  integration can be ignored: they arise from the \
fact that several of the modes have zero initial amplitude. These errors can \
be avoided by setting these mode amplitudes equal to zero directly without \
evaluating the integrals.\
\>", "Text"],

Cell[TextData[{
  "\t We now integrate the ODEs forward in time using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and plot the result over a time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < t\_max\)]],
  " in steps of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", with plot range from ",
  Cell[BoxData[
      \(TraditionalForm\`f\_min\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`f\_max\)]],
  " We do so using a module, since we will be studying several examples. The \
ODEs that we will solve are given by Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  " , taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(kdVmod[tmax_, \[CapitalDelta]t_, fmin_, fmax_]\  := \ 
      Module[{k, \ ODEs}, \[IndentingNewLine]\[IndentingNewLine]k[n_]\  = \ 
          n\ Pi/L; \[IndentingNewLine]\[IndentingNewLine]ODEs\  = \ 
          Table[D[\(c[n]\)[t], t]\  - I\ k[n]^3\ \(c[n]\)[t]\  + 
                Sum[\ I\ k[nb]\ \ \(c[nb]\)[t]\ \(c[n - nb]\)[
                      t], {nb, \(-M\), M}] == 0, {n, 0, 
              M}]; \[IndentingNewLine]\[IndentingNewLine]vars\  = \ 
          Table[\(c[n]\)[t], {n, 0, 
              M}]; \[IndentingNewLine]\[IndentingNewLine]sol\  = \ 
          NDSolve[Join[ODEs, \ ics], vars, {t, 0, tmax}, 
            MaxSteps \[Rule] 6000]; \[IndentingNewLine]\[IndentingNewLine]f[
            x_, t_]\  = \ 
          Sum[\(c[n]\)[t]\ Exp[I\ k[n]\ x], {n, \(-M\), 
              M}]; \[IndentingNewLine]f[x_, t_]\  = \ 
          f[x, t] /. 
            sol[\([1]\)]; \[IndentingNewLine]\[IndentingNewLine]Table[
          Plot[f[x, t], {x, \(-L\), L}, 
            PlotRange \[Rule] {{\(-L\), L}, {fmin, fmax}}, 
            PlotLabel \[Rule] "\< M = \>" <> \ ToString[M]\  <> "\<, t = \>" <> 
                ToString[t]], {t, 0, tmax, \[CapitalDelta]t}];]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.45"],

Cell[TextData[{
  "We now evaluate the solution over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 200\)]],
  ", as shown in Cell ",
  ButtonBox["7.46",
    ButtonData:>"Cell 7.46",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(kdVmod[200, 5, 0, 2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.46"],

Cell[TextData[{
  "The solution appears to be well behaved and stable over the time scale of \
interest. It moves to the right with a speed given by Eq. ",
  ButtonBox["(7.2.16)",
    ButtonData:>{"Chapter7.nb", "(7.2.16)"},
    ButtonStyle->"Hyperlink"],
  " . Other cnoidal waves and solitons can be handled by simply varying the \
parameters.  One can also add small perturbations to these solutions. One \
finds by this sort of empirical approach that steady solutions to the KdV \
equation are stable to small perturbations. This is born out by the \
previously mentioned analytic work on this problem. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: Interacting Solitons", "Section",
  CellTags->"c:21"],

Cell["\<\
In this example, for initial conditions we take two soliton \
solutions with different amplitudes:\
\>", "Text"],

Cell[BoxData[{
    \(\(L = \ 60;\)\), "\n", 
    \(\(f0[
          x_]\  = \ \(1/3\)/Cosh[Sqrt[1/36]\ \((x + 30)\)]^2\  + \ \(1/4\)\ /
            Cosh[Sqrt[1/48]\ \((x - 30\ )\)]^2\ ;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.47"],

Cell["We will again evaluate the solution keeping 15 modes:", "Text"],

Cell[BoxData[{
    \(\(\(M = 15;\)\(\n\)
    \)\), "\n", 
    \(\(\(k[n_]\  := \ n\ Pi/L;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ics\  = \ 
        Table[\(c[n]\)[0]\  \[Equal] \ 
            NIntegrate[
                Exp[\(-I\)\ k[n]\ x]\ f0[x], {x, \(-L\), L}]/\((2  L)\), {n, 
            0, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.48"],

Cell[TextData[{
  "In order to follow the dynamics we must integrate over a longer time, ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 6000\)]],
  ", because our initial conditions are solitons of rather small amplitude. \
This implies their velocities are small. The solution is displayed in Cell ",
  ButtonBox["7.49",
    ButtonData:>"Cell 7.49",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(kdVmod[6000, 100, 0,  .6]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.49"],

Cell["\<\
The soliton in back, being of larger amplitude, moves with higher \
speed and catches up to the soliton in the front. It then feeds some of its \
amplitude to the soliton in the front, until they exchange amplitudes, and \
the soliton in the front then moves away from the one in the back. \
Effectively, the two solitons have exchanged places: they have passed through \
one another without change. Thanks to the periodic boundary conditions, this \
interaction then repeats itself ad infinitum. \
\>", "Text"],

Cell["\<\
\tThe fact that solitons effectively retain their shape during \
binary interactions implies that a description of nonlinear processes can \
often be greatly simplified - one can think of the nonlinear system as a gas \
of discrete solitons, which act almost like discrete particles, interacting \
with one another but retaining their identity. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3: Suppression of Wavebreaking", "Section",
  CellTags->{"i:45", "c:22"}],

Cell[TextData[{
  "In this example, we investigate whether wavebreaking occurs in the KdV \
equation. Recall that wavebreaking was observed in the solutions to Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " , where dispersion is neglected. Although we cannot hope to observe \
similar double-valued solutions using the Galerkin method, which expands in a \
set of single-valued modes, we might expect to see some initial conditions \
steepen, and the spectrum of waves should display a cascade to high \
wavenumbers. "
}], "Text"],

Cell[TextData[{
  "For our initial condition, we  take a single finite amplitude sine wave. \
We now keep ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(20\)\(\ \)\)\)]],
  "modes in order to be certain of capturing the high-wavenumber dynamics \
properly, as shown in Cell ",
  ButtonBox["7.50",
    ButtonData:>"Cell 7.50",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[{
    \(L = \ 40; \ M = 20;\), "\n", 
    \(\(ics\  = \ Table[\(c[n]\)[0]\  \[Equal] \ 0, {n, 0, M}];\)\), "\n", 
    \(\(\(ics[\([2]\)] = \(c[1]\)[0] \[Equal] 1/8;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(kdVmod[800, 10, \(-1\), 1]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.50"],

Cell[TextData[{
  "\tInitially the wave steepens, just as when dispersion is neglected. \
However, instead of breaking, the wave dissociates into several solitons that \
proceed to interact with one another in a complex manner.   The spectrum of \
the solution is peaked at low wavenumbers, as can be seen in the  plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\(c\_n\)(t)\)\(|\)\)\)]],
  " shown in Cell ",
  ButtonBox["7.51",
    ButtonData:>"Cell 7.51",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(spectrum = \ Abs[vars /. sol[\([1]\)]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ParametricPlot3D[{k[n], t, spectrum[\([n + 1]\)]}, {t, 0, 800}, 
          DisplayFunction \[Rule] Identity], {n, 0, M}];\)\), "\n", 
    \(\(Show[%, DisplayFunction \[Rule] $DisplayFunction, 
        BoxRatios \[Rule] {1, 1, 1}, 
        AxesLabel \[Rule] {"\<k\>", "\<t\>", "\<|\!\(c\_n\)(t)|  \>"}, 
        PlotLabel -> "\<wave spectrum\n \>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.51"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.5 1.098 -41.125 0 ]
[.5 1.098 41.125 24.5 ]
[.09072 .22988 -5.91576 -9 ]
[.09072 .22988 .08424 0 ]
[.25533 .16034 -16.7461 -9 ]
[.25533 .16034 1.25388 0 ]
[.43173 .08588 -5.24832 -9 ]
[.43173 .08588 .75168 0 ]
[.62122 .00596 -14.7438 -9 ]
[.62122 .00596 3.25621 0 ]
[.30907 .06148 -8.98592 -12 ]
[.30907 .06148 1.01408 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.12079 .90442 -10.0666 0 ]
[.12079 .90442 7.93341 9 ]
[.22056 .97437 -9.78807 0 ]
[.22056 .97437 8.21193 9 ]
[.31055 1.03745 -9.54626 0 ]
[.31055 1.03745 8.45374 9 ]
[.39213 1.09464 -9.33435 0 ]
[.39213 1.09464 8.66565 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.05358 .38541 -24 -2.72708 ]
[.05358 .38541 0 6.27292 ]
[.03208 .51999 -24 -2.84769 ]
[.03208 .51999 0 6.15231 ]
[.00848 .66771 -24 -2.98134 ]
[.00848 .66771 0 6.01866 ]
[-0.03373 .52941 -57.25 -3.77786 ]
[-0.03373 .52941 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -102.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(spectrum) show
69.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.26484 .17139 m
.2696 .17691 L
s
[(0.5)] .25533 .16034 .86068 1 Mshowa
.44047 .09754 m
.44484 .10337 L
s
[(1)] .43173 .08588 .74944 1 Mshowa
.62906 .01825 m
.63298 .02439 L
s
[(1.5)] .62122 .00596 .6382 1 Mshowa
.125 Mabswid
.13279 .22691 m
.1358 .23008 L
s
.16514 .21331 m
.16811 .21652 L
s
.19792 .19953 m
.20086 .20277 L
s
.23115 .18555 m
.23405 .18883 L
s
.299 .15703 m
.30181 .16038 L
s
.33363 .14247 m
.33639 .14585 L
s
.36874 .1277 m
.37146 .13113 L
s
.40435 .11273 m
.40703 .11619 L
s
.47711 .08214 m
.47968 .08567 L
s
.51427 .06651 m
.51679 .07008 L
s
.55198 .05066 m
.55444 .05427 L
s
.59024 .03457 m
.59265 .03822 L
s
.66846 .00168 m
.67075 .0054 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(200)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(400)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(600)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(800)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.04063 .83233 m
.04126 .82801 L
s
.06868 .85207 m
.06927 .84774 L
s
.09596 .87127 m
.09651 .86693 L
s
.14833 .90812 m
.14881 .90378 L
s
.17348 .92582 m
.17392 .92147 L
s
.19797 .94306 m
.19838 .9387 L
s
.24508 .97621 m
.24543 .97185 L
s
.26775 .99217 m
.26808 .9878 L
s
.28986 1.00772 m
.29016 1.00336 L
s
.33248 1.03771 m
.33271 1.03335 L
s
.35302 1.05217 m
.35323 1.0478 L
s
.37308 1.06628 m
.37326 1.06192 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.06714 .38007 m
.07392 .37739 L
s
[(0.02)] .05358 .38541 1 -0.39398 Mshowa
.04576 .51497 m
.0526 .51246 L
s
[(0.04)] .03208 .51999 1 -0.36718 Mshowa
.02229 .66305 m
.0292 .66072 L
s
[(0.06)] .00848 .66771 1 -0.33748 Mshowa
.125 Mabswid
.08197 .28651 m
.08601 .28484 L
s
.07713 .31702 m
.08118 .31537 L
s
.07219 .34819 m
.07625 .34657 L
s
.06198 .41265 m
.06605 .41107 L
s
.05669 .44598 m
.06078 .44443 L
s
.05129 .48008 m
.05539 .47855 L
s
.0401 .55068 m
.04422 .5492 L
s
.03431 .58725 m
.03843 .58579 L
s
.02837 .62469 m
.03251 .62326 L
s
.01607 .70236 m
.02022 .70099 L
s
.00968 .74265 m
.01384 .74131 L
s
.00313 .78396 m
.00731 .78266 L
s
gsave
-0.03373 .52941 -118.25 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
75.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.250 13.000 moveto
(H) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
(\\310) show
116.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4186 .578 m
.42216 .58164 L
s
.41502 .57434 m
.4186 .578 L
s
.41143 .57067 m
.41502 .57434 L
s
.40782 .56698 m
.41143 .57067 L
s
.40419 .56327 m
.40782 .56698 L
s
.40055 .55955 m
.40419 .56327 L
s
.39689 .55581 m
.40055 .55955 L
s
.39322 .55206 m
.39689 .55581 L
s
.38953 .54829 m
.39322 .55206 L
s
.38583 .5445 m
.38953 .54829 L
s
.3821 .54069 m
.38583 .5445 L
s
.37836 .53687 m
.3821 .54069 L
s
.37461 .53303 m
.37836 .53687 L
s
.37084 .52917 m
.37461 .53303 L
s
.36705 .5253 m
.37084 .52917 L
s
.36324 .52141 m
.36705 .5253 L
s
.35941 .5175 m
.36324 .52141 L
s
.35557 .51357 m
.35941 .5175 L
s
.35171 .50962 m
.35557 .51357 L
s
.34784 .50566 m
.35171 .50962 L
s
.34394 .50168 m
.34784 .50566 L
s
.42317 .54966 m
.4247 .6207 L
s
.41891 .56099 m
.42317 .54966 L
s
.34003 .49768 m
.34394 .50168 L
s
.5805 .57328 m
.58395 .58182 L
s
.57752 .59388 m
.5805 .57328 L
s
.3361 .49366 m
.34003 .49768 L
s
.60442 .55335 m
.60857 .58906 L
s
.60101 .54598 m
.60442 .55335 L
s
.59803 .55766 m
.60101 .54598 L
s
.33215 .48963 m
.3361 .49366 L
s
.41257 .62852 m
.41891 .56099 L
s
.46678 .51773 m
.46995 .54716 L
s
.46282 .52881 m
.46678 .51773 L
s
.5573 .6634 m
.56024 .61677 L
s
.67721 .51067 m
.6801 .50932 L
s
.32819 .48557 m
.33215 .48963 L
s
.65358 .54322 m
.65627 .53455 L
s
.62192 .52912 m
.62567 .54748 L
s
.61863 .52592 m
.62192 .52912 L
s
.3242 .4815 m
.32819 .48557 L
s
.70147 .49206 m
.70475 .49884 L
s
.67452 .51679 m
.67721 .51067 L
s
.49404 .52473 m
.49749 .54331 L
s
.4903 .53163 m
.49404 .52473 L
s
.59485 .56199 m
.59803 .55766 L
s
.46995 .54716 m
.47328 .56947 L
s
.3202 .4774 m
.3242 .4815 L
s
.69868 .49392 m
.70147 .49206 L
s
.62567 .54748 m
.6296 .57033 L
s
.61535 .52321 m
.61863 .52592 L
s
.57456 .61954 m
.57752 .59388 L
s
.45816 .56854 m
.46282 .52881 L
s
.51105 .48506 m
.51454 .50753 L
s
.50733 .50398 m
.51105 .48506 L
s
.45279 .59615 m
.45617 .61424 L
s
.44889 .59999 m
.45279 .59615 L
s
.49749 .54331 m
.50098 .56057 L
s
.31617 .47329 m
.3202 .4774 L
s
.65048 .54296 m
.65358 .54322 L
s
.61191 .51572 m
.61535 .52321 L
s
.50454 .56795 m
.50807 .58057 L
s
.50098 .56057 m
.50454 .56795 L
s
.47328 .56947 m
.47672 .58646 L
s
.50807 .58057 m
.51147 .62238 L
s
.63959 .50301 m
.64321 .51633 L
s
.63616 .49494 m
.63959 .50301 L
s
.72646 .48352 m
.72982 .49188 L
s
.45617 .61424 m
.4593 .64446 L
s
.6296 .57033 m
.63315 .58187 L
s
.60843 .50679 m
.61191 .51572 L
s
.69583 .49518 m
.69868 .49392 L
s
.64321 .51633 m
.64694 .53208 L
s
.67149 .51656 m
.67452 .51679 L
s
.72331 .47838 m
.72646 .48352 L
s
.63275 .48767 m
.63616 .49494 L
s
.31213 .46916 m
.31617 .47329 L
s
.59149 .55972 m
.59485 .56199 L
s
.60493 .49764 m
.60843 .50679 L
s
.52163 .52913 m
.52517 .55261 L
s
.51808 .5193 m
.52163 .52913 L
s
.51454 .50753 m
.51808 .5193 L
s
.47672 .58646 m
.48018 .60364 L
s
.60146 .48933 m
.60493 .49764 L
s
.48407 .73474 m
.48795 .72004 L
s
.48655 .53653 m
.4903 .53163 L
s
.49799 .65378 m
.50115 .71444 L
s
.49434 .65294 m
.49799 .65378 L
s
.4247 .6207 m
.42657 .68547 L
s
.64694 .53208 m
.65048 .54296 L
s
.62929 .47916 m
.63275 .48767 L
s
.44473 .61225 m
.44889 .59999 L
s
.59801 .48237 m
.60146 .48933 L
s
.72046 .47799 m
.72331 .47838 L
s
.62585 .47152 m
.62929 .47916 L
s
.75175 .47575 m
.75476 .47959 L
s
.30807 .46501 m
.31213 .46916 L
s
.48018 .60364 m
.48358 .62571 L
s
.58806 .55459 m
.59149 .55972 L
s
.59457 .47636 m
.59801 .48237 L
s
.62245 .46532 m
.62585 .47152 L
s
.6681 .50897 m
.67149 .51656 L
s
.69272 .49212 m
.69583 .49518 L
s
.6609 .4849 m
.66451 .49703 L
s
.65742 .47563 m
.6609 .4849 L
s
.52517 .55261 m
.52875 .59032 L
s
.49058 .65994 m
.49434 .65294 L
s
.66451 .49703 m
.6681 .50897 L
s
.48305 .52037 m
.48655 .53653 L
s
.4792 .52808 m
.48305 .52037 L
s
.304 .46084 m
.30807 .46501 L
s
.65406 .46901 m
.65742 .47563 L
s
.74856 .46954 m
.75175 .47575 L
s
.59111 .46988 m
.59457 .47636 L
s
.61912 .4615 m
.62245 .46532 L
s
.58453 .5452 m
.58806 .55459 L
s
.4593 .64446 m
.46255 .67143 L
s
.71744 .47549 m
.72046 .47799 L
s
.58097 .53413 m
.58453 .5452 L
s
.57741 .52361 m
.58097 .53413 L
s
.77703 .46483 m
.77988 .46748 L
s
.57387 .51351 m
.57741 .52361 L
s
.53882 .50159 m
.54241 .51816 L
s
.53527 .49572 m
.53882 .50159 L
s
.57032 .50383 m
.57387 .51351 L
s
.65072 .46343 m
.65406 .46901 L
s
.48358 .62571 m
.487 .64869 L
s
.74548 .46501 m
.74856 .46954 L
s
.58765 .46379 m
.59111 .46988 L
s
.68938 .48524 m
.69272 .49212 L
s
.56676 .49318 m
.57032 .50383 L
s
.50355 .52116 m
.50733 .50398 L
s
.5632 .48257 m
.56676 .49318 L
s
.5597 .47761 m
.5632 .48257 L
s
.2999 .45665 m
.304 .46084 L
s
.61578 .45787 m
.61912 .4615 L
s
.53172 .49613 m
.53527 .49572 L
s
.54241 .51816 m
.546 .53315 L
s
.5543 .71876 m
.5573 .6634 L
s
.68594 .47642 m
.68938 .48524 L
s
.57133 .63254 m
.57456 .61954 L
s
.64741 .45848 m
.65072 .46343 L
s
.58422 .46006 m
.58765 .46379 L
s
.71427 .47074 m
.71744 .47549 L
s
.77407 .46111 m
.77703 .46483 L
s
.74249 .46197 m
.74548 .46501 L
s
.68249 .4677 m
.68594 .47642 L
s
.51147 .62238 m
.51482 .69565 L
s
.546 .53315 m
.54963 .55126 L
s
.55617 .47078 m
.5597 .47761 L
s
.48029 .73824 m
.48407 .73474 L
s
.4407 .61786 m
.44473 .61225 L
s
.29578 .45244 m
.2999 .45665 L
s
.67911 .46029 m
.68249 .4677 L
s
.6124 .45355 m
.61578 .45787 L
s
.80251 .45404 m
.80541 .45789 L
s
.487 .64869 m
.49058 .65994 L
s
.64409 .45384 m
.64741 .45848 L
s
.46255 .67143 m
.46601 .68898 L
s
.55262 .46243 m
.55617 .47078 L
s
.71101 .4646 m
.71427 .47074 L
s
.58077 .45618 m
.58422 .46006 L
s
.6758 .45446 m
.67911 .46029 L
s
.52813 .48305 m
.53172 .49613 L
s
.52454 .48961 m
.52813 .48305 L
s
.47465 .57489 m
.4792 .52808 L
s
.77098 .45591 m
.77407 .46111 L
s
.54963 .55126 m
.55331 .57288 L
s
.7394 .45769 m
.74249 .46197 L
s
.54921 .47425 m
.55262 .46243 L
s
.29165 .44822 m
.29578 .45244 L
s
.4696 .69995 m
.47317 .71187 L
s
.46601 .68898 m
.4696 .69995 L
s
.7077 .45794 m
.71101 .4646 L
s
.60902 .44987 m
.6124 .45355 L
s
.47317 .71187 m
.47669 .72731 L
s
.64075 .44913 m
.64409 .45384 L
s
.79968 .45107 m
.80251 .45404 L
s
.67252 .44949 m
.6758 .45446 L
s
.52875 .59032 m
.5324 .63552 L
s
.45353 .60184 m
.45816 .56854 L
s
.57731 .45229 m
.58077 .45618 L
s
.7679 .451 m
.77098 .45591 L
s
.47669 .72731 m
.48029 .73824 L
s
.73625 .45262 m
.7394 .45769 L
s
.70439 .45153 m
.7077 .45794 L
s
.45886 .79607 m
.46292 .78431 L
s
.28749 .44397 m
.29165 .44822 L
s
.40617 .69223 m
.41257 .62852 L
s
.43692 .61315 m
.4407 .61786 L
s
.6374 .44434 m
.64075 .44913 L
s
.55331 .57288 m
.55699 .59353 L
s
.66923 .44463 m
.67252 .44949 L
s
.82833 .44448 m
.83128 .44936 L
s
.60561 .44562 m
.60902 .44987 L
s
.76485 .44653 m
.7679 .451 L
s
.79674 .44696 m
.79968 .45107 L
s
.70111 .44567 m
.70439 .45153 L
s
.57396 .457 m
.57731 .45229 L
s
.5679 .63394 m
.57133 .63254 L
s
.73305 .4472 m
.73625 .45262 L
s
.49977 .53052 m
.50355 .52116 L
s
.28331 .4397 m
.28749 .44397 L
s
.43318 .60646 m
.43692 .61315 L
s
.50115 .71444 m
.50409 .82619 L
s
.63405 .44013 m
.6374 .44434 L
s
.52087 .51932 m
.52454 .48961 L
s
.66592 .43973 m
.66923 .44463 L
s
.82552 .44102 m
.82833 .44448 L
s
.60221 .44219 m
.60561 .44562 L
s
.69785 .44038 m
.70111 .44567 L
s
.76177 .44182 m
.76485 .44653 L
s
.55699 .59353 m
.56068 .61175 L
s
.79369 .44191 m
.79674 .44696 L
s
.72985 .44178 m
.73305 .4472 L
s
.42899 .61397 m
.43318 .60646 L
s
.42657 .68547 m
.42893 .73873 L
s
.27912 .43541 m
.28331 .4397 L
s
.66263 .43537 m
.66592 .43973 L
s
.6307 .43634 m
.63405 .44013 L
s
.54575 .48704 m
.54921 .47425 L
s
.69461 .43552 m
.69785 .44038 L
s
.8545 .43587 m
.85737 .44048 L
s
.82267 .43732 m
.82552 .44102 L
s
.56433 .62611 m
.5679 .63394 L
s
.72665 .43658 m
.72985 .44178 L
s
.75865 .4369 m
.76177 .44182 L
s
.59888 .44268 m
.60221 .44219 L
s
.79063 .4368 m
.79369 .44191 L
s
.56068 .61175 m
.56433 .62611 L
s
.45485 .80281 m
.45886 .79607 L
s
.5706 .46263 m
.57396 .457 L
s
.2749 .4311 m
.27912 .43541 L
s
.65934 .43137 m
.66263 .43537 L
s
.69137 .43109 m
.69461 .43552 L
s
.85164 .43151 m
.8545 .43587 L
s
.62733 .43224 m
.6307 .43634 L
s
.72345 .43159 m
.72665 .43658 L
s
.78759 .43201 m
.79063 .4368 L
s
.75553 .43201 m
.75865 .4369 L
s
.81972 .43281 m
.82267 .43732 L
s
.49584 .55032 m
.49977 .53052 L
s
.27067 .42677 m
.2749 .4311 L
s
.68813 .42678 m
.69137 .43109 L
s
.5324 .63552 m
.53613 .68104 L
s
.59558 .44535 m
.59888 .44268 L
s
.65603 .42712 m
.65934 .43137 L
s
.8809 .42711 m
.88367 .43132 L
s
.72026 .42689 m
.72345 .43159 L
s
.84884 .42771 m
.85164 .43151 L
s
.75241 .42724 m
.75553 .43201 L
s
.4241 .6417 m
.42899 .61397 L
s
.62403 .43089 m
.62733 .43224 L
s
.78454 .4273 m
.78759 .43201 L
s
.81672 .42781 m
.81972 .43281 L
s
.26641 .42242 m
.27067 .42677 L
s
.68487 .42239 m
.68813 .42678 L
s
.71707 .42242 m
.72026 .42689 L
s
.6527 .42294 m
.65603 .42712 L
s
.74928 .42259 m
.75241 .42724 L
s
.45088 .80632 m
.45485 .80281 L
s
.87808 .42258 m
.8809 .42711 L
s
.78148 .42261 m
.78454 .4273 L
s
.84597 .42344 m
.84884 .42771 L
s
.81371 .42286 m
.81672 .42781 L
s
.56716 .4662 m
.5706 .46263 L
s
.54219 .49115 m
.54575 .48704 L
s
.44915 .62056 m
.45353 .60184 L
s
.62077 .43136 m
.62403 .43089 L
s
.4347 .44295 m
.43584 .53877 L
s
.42743 .54382 m
.4347 .44295 L
s
.26214 .41805 m
.26641 .42242 L
s
.51482 .69565 m
.51828 .78335 L
s
.55102 .75518 m
.5543 .71876 L
s
.6816 .41808 m
.68487 .42239 L
s
.59225 .44828 m
.59558 .44535 L
s
.71386 .41792 m
.71707 .42242 L
s
.90754 .41808 m
.91025 .42232 L
s
.74614 .41804 m
.74928 .42259 L
s
.77842 .41803 m
.78148 .42261 L
s
.87529 .41835 m
.87808 .42258 L
s
.64942 .42025 m
.6527 .42294 L
s
.81071 .41815 m
.81371 .42286 L
s
.84305 .41875 m
.84597 .42344 L
s
.47001 .61865 m
.47465 .57489 L
s
.51713 .53698 m
.52087 .51932 L
s
.25784 .41366 m
.26214 .41805 L
s
.44687 .80948 m
.45088 .80632 L
s
.71064 .41344 m
.71386 .41792 L
s
.67831 .41377 m
.6816 .41808 L
s
.743 .41354 m
.74614 .41804 L
s
.77535 .41353 m
.77842 .41803 L
s
.8077 .41354 m
.81071 .41815 L
s
.90479 .41374 m
.90754 .41808 L
s
.42893 .73873 m
.4318 .77736 L
s
.87248 .41409 m
.87529 .41835 L
s
.8401 .41393 m
.84305 .41875 L
s
.6175 .43249 m
.62077 .43136 L
s
.64618 .4192 m
.64942 .42025 L
s
.56373 .47255 m
.56716 .4662 L
s
.53859 .49352 m
.54219 .49115 L
s
.49164 .58716 m
.49584 .55032 L
s
.25352 .40924 m
.25784 .41366 L
s
.70742 .40917 m
.71064 .41344 L
s
.73984 .40902 m
.743 .41354 L
s
.77227 .40905 m
.77535 .41353 L
s
.8047 .409 m
.8077 .41354 L
s
.67506 .41042 m
.67831 .41377 L
s
.58892 .45261 m
.59225 .44828 L
s
.90203 .40927 m
.90479 .41374 L
s
.83715 .4092 m
.8401 .41393 L
s
.86962 .40956 m
.87248 .41409 L
s
.53613 .68104 m
.53992 .72086 L
s
.64294 .41848 m
.64618 .4192 L
s
.44285 .81219 m
.44687 .80948 L
s
.24919 .40481 m
.25352 .40924 L
s
.73668 .40459 m
.73984 .40902 L
s
.80168 .40452 m
.8047 .409 L
s
.76918 .40457 m
.77227 .40905 L
s
.70418 .40471 m
.70742 .40917 L
s
.8342 .4046 m
.83715 .4092 L
s
.61421 .43388 m
.6175 .43249 L
s
.89926 .40487 m
.90203 .40927 L
s
.86675 .4049 m
.86962 .40956 L
s
.67184 .40813 m
.67506 .41042 L
s
.41878 .67912 m
.4241 .6417 L
s
.53497 .50199 m
.53859 .49352 L
s
.44475 .63727 m
.44915 .62056 L
s
.56027 .48065 m
.56373 .47255 L
s
.24483 .40035 m
.24919 .40481 L
s
.4 .74515 m
.40617 .69223 L
s
.7335 .40016 m
.73668 .40459 L
s
.79866 .40005 m
.80168 .40452 L
s
.76608 .40007 m
.76918 .40457 L
s
.70096 .40091 m
.70418 .40471 L
s
.83125 .40007 m
.8342 .4046 L
s
.86385 .40023 m
.86675 .4049 L
s
.89646 .40037 m
.89926 .40487 L
s
.58556 .45723 m
.58892 .45261 L
s
.63966 .41746 m
.64294 .41848 L
s
.66862 .40604 m
.67184 .40813 L
s
.4318 .77736 m
.43516 .80073 L
s
.43889 .81093 m
.44285 .81219 L
s
.51339 .5359 m
.51713 .53698 L
s
.61087 .43437 m
.61421 .43388 L
s
.24045 .39588 m
.24483 .40035 L
s
.76296 .3956 m
.76608 .40007 L
s
.79562 .39557 m
.79866 .40005 L
s
.7303 .39568 m
.7335 .40016 L
s
.82829 .39556 m
.83125 .40007 L
s
.86096 .39562 m
.86385 .40023 L
s
.89365 .39577 m
.89646 .40037 L
s
.69776 .39778 m
.70096 .40091 L
s
.63633 .41578 m
.63966 .41746 L
s
.66536 .40374 m
.66862 .40604 L
s
.43516 .80073 m
.43889 .81093 L
s
.46966 .49931 m
.47277 .54413 L
s
.46552 .50981 m
.46966 .49931 L
s
.23604 .39138 m
.24045 .39588 L
s
.75983 .39111 m
.76296 .3956 L
s
.79257 .39106 m
.79562 .39557 L
s
.72712 .39155 m
.7303 .39568 L
s
.82531 .39105 m
.82829 .39556 L
s
.85806 .39106 m
.86096 .39562 L
s
.89082 .39116 m
.89365 .39577 L
s
.54745 .76479 m
.55102 .75518 L
s
.53992 .72086 m
.54372 .75069 L
s
.50966 .53039 m
.51339 .5359 L
s
.5313 .50905 m
.53497 .50199 L
s
.69456 .39482 m
.69776 .39778 L
s
.58212 .45936 m
.58556 .45723 L
s
.55676 .48805 m
.56027 .48065 L
s
.60741 .43199 m
.61087 .43437 L
s
.53806 .41242 m
.54188 .44676 L
s
.53443 .43011 m
.53806 .41242 L
s
.23162 .38685 m
.23604 .39138 L
s
.50589 .52862 m
.50966 .53039 L
s
.7895 .38655 m
.79257 .39106 L
s
.75668 .3866 m
.75983 .39111 L
s
.82232 .38652 m
.82531 .39105 L
s
.85515 .38652 m
.85806 .39106 L
s
.88798 .38655 m
.89082 .39116 L
s
.72395 .38789 m
.72712 .39155 L
s
.66209 .40165 m
.66536 .40374 L
s
.63295 .41305 m
.63633 .41578 L
s
.50532 .41607 m
.50882 .46286 L
s
.5014 .42943 m
.50532 .41607 L
s
.43975 .67325 m
.44475 .63727 L
s
.69134 .39193 m
.69456 .39482 L
s
.50409 .82619 m
.50716 .95377 L
s
.60383 .42546 m
.60741 .43199 L
s
.46541 .65289 m
.47001 .61865 L
s
.22718 .38231 m
.23162 .38685 L
s
.78642 .38201 m
.7895 .38655 L
s
.75353 .38227 m
.75668 .3866 L
s
.81932 .38197 m
.82232 .38652 L
s
.85222 .38196 m
.85515 .38652 L
s
.88513 .38196 m
.88798 .38655 L
s
.72077 .38436 m
.72395 .38789 L
s
.50212 .52292 m
.50589 .52862 L
s
.57095 .42404 m
.57479 .4432 L
s
.56729 .41686 m
.57095 .42404 L
s
.48734 .62157 m
.49164 .58716 L
s
.57854 .45566 m
.58212 .45936 L
s
.62952 .40975 m
.63295 .41305 L
s
.6588 .3995 m
.66209 .40165 L
s
.54372 .75069 m
.54745 .76479 L
s
.60021 .41775 m
.60383 .42546 L
s
.68813 .38947 m
.69134 .39193 L
s
.52758 .51737 m
.5313 .50905 L
s
.43201 .4048 m
.43347 .48947 L
s
.42652 .44537 m
.43201 .4048 L
s
.46045 .56084 m
.46552 .50981 L
s
.22271 .37774 m
.22718 .38231 L
s
.56386 .42789 m
.56729 .41686 L
s
.78332 .37744 m
.78642 .38201 L
s
.8163 .37741 m
.81932 .38197 L
s
.84929 .37739 m
.85222 .38196 L
s
.88227 .37738 m
.88513 .38196 L
s
.7504 .37824 m
.75353 .38227 L
s
.59671 .41556 m
.60021 .41775 L
s
.49826 .52603 m
.50212 .52292 L
s
.55318 .49297 m
.55676 .48805 L
s
.46857 .41895 m
.47149 .47454 L
s
.46442 .42732 m
.46857 .41895 L
s
.71759 .38104 m
.72077 .38436 L
s
.57479 .4432 m
.57854 .45566 L
s
.62611 .40744 m
.62952 .40975 L
s
.51828 .78335 m
.52192 .86346 L
s
.41346 .71273 m
.41878 .67912 L
s
.65547 .39695 m
.6588 .3995 L
s
.54188 .44676 m
.54573 .47591 L
s
.21822 .37316 m
.22271 .37774 L
s
.78022 .37298 m
.78332 .37744 L
s
.81327 .37282 m
.8163 .37741 L
s
.84633 .37279 m
.84929 .37739 L
s
.8794 .37278 m
.88227 .37738 L
s
.68488 .38677 m
.68813 .38947 L
s
.74726 .37434 m
.7504 .37824 L
s
.47277 .54413 m
.47601 .58657 L
s
.59325 .4159 m
.59671 .41556 L
s
.71441 .3779 m
.71759 .38104 L
s
.49726 .45771 m
.5014 .42943 L
s
.53074 .44847 m
.53443 .43011 L
s
.62265 .40446 m
.62611 .40744 L
s
.21371 .36855 m
.21822 .37316 L
s
.81022 .36821 m
.81327 .37282 L
s
.84337 .36818 m
.84633 .37279 L
s
.87651 .36816 m
.8794 .37278 L
s
.77712 .3687 m
.78022 .37298 L
s
.65207 .39325 m
.65547 .39695 L
s
.49422 .54264 m
.49826 .52603 L
s
.53338 .9131 m
.53698 .8543 L
s
.74411 .37058 m
.74726 .37434 L
s
.43584 .53877 m
.43671 .65226 L
s
.68157 .38312 m
.68488 .38677 L
s
.54951 .49059 m
.55318 .49297 L
s
.52382 .52681 m
.52758 .51737 L
s
.71118 .37438 m
.71441 .3779 L
s
.20918 .36391 m
.21371 .36855 L
s
.45952 .46687 m
.46442 .42732 L
s
.80717 .36365 m
.81022 .36821 L
s
.84039 .36355 m
.84337 .36818 L
s
.87362 .36353 m
.87651 .36816 L
s
.50882 .46286 m
.51246 .49864 L
s
.77401 .36452 m
.77712 .3687 L
s
.58964 .411 m
.59325 .4159 L
s
.56027 .43073 m
.56386 .42789 L
s
.61903 .39686 m
.62265 .40446 L
s
.39434 .78108 m
.4 .74515 L
s
.64852 .38632 m
.65207 .39325 L
s
.54573 .47591 m
.54951 .49059 L
s
.74095 .36686 m
.74411 .37058 L
s
.67813 .3775 m
.68157 .38312 L
s
.39107 .51395 m
.39002 .63701 L
s
.38682 .51276 m
.39107 .51395 L
s
.61526 .38475 m
.61903 .39686 L
s
.61151 .37332 m
.61526 .38475 L
s
.60813 .37511 m
.61151 .37332 L
s
.58207 .38519 m
.58589 .39974 L
s
.57835 .3753 m
.58207 .38519 L
s
.54511 .37363 m
.54893 .3929 L
s
.54143 .37643 m
.54511 .37363 L
s
.70787 .36984 m
.71118 .37438 L
s
.64481 .37574 m
.64852 .38632 L
s
.20463 .35926 m
.20918 .36391 L
s
.57485 .37922 m
.57835 .3753 L
s
.5119 .37569 m
.51561 .40145 L
s
.50794 .39612 m
.5119 .37569 L
s
.83739 .35889 m
.84039 .36355 L
s
.8707 .35887 m
.87362 .36353 L
s
.80411 .35919 m
.80717 .36365 L
s
.58589 .39974 m
.58964 .411 L
s
.64123 .36872 m
.64481 .37574 L
s
.7709 .36042 m
.77401 .36452 L
s
.32373 .41296 m
.32746 .42525 L
s
.31606 .45645 m
.32373 .41296 L
s
.67457 .36978 m
.67813 .3775 L
s
.32746 .42525 m
.3302 .45245 L
s
.43413 .72661 m
.43975 .67325 L
s
.73775 .36281 m
.74095 .36686 L
s
.63795 .3696 m
.64123 .36872 L
s
.54893 .3929 m
.55271 .40569 L
s
.6711 .36401 m
.67457 .36978 L
s
.46066 .68925 m
.46541 .65289 L
s
.70448 .36418 m
.70787 .36984 L
s
.55271 .40569 m
.55651 .41999 L
s
.20005 .35458 m
.20463 .35926 L
s
.37867 .59321 m
.38682 .51276 L
s
.83439 .35425 m
.83739 .35889 L
s
.86778 .35419 m
.8707 .35887 L
s
.80105 .35481 m
.80411 .35919 L
s
.429 1.00478 m
.43398 .97299 L
s
.55651 .41999 m
.56027 .43073 L
s
.76777 .35632 m
.7709 .36042 L
s
.52001 .52939 m
.52382 .52681 L
s
.48325 .63321 m
.48734 .62157 L
s
.47601 .58657 m
.47949 .61828 L
s
.73449 .3582 m
.73775 .36281 L
s
.60467 .37512 m
.60813 .37511 L
s
.37278 .68262 m
.37611 .70407 L
s
.36869 .67714 m
.37278 .68262 L
s
.48604 .41142 m
.48971 .43154 L
s
.48185 .42696 m
.48604 .41142 L
s
.6678 .36188 m
.6711 .36401 L
s
.70111 .35907 m
.70448 .36418 L
s
.53771 .38008 m
.54143 .37643 L
s
.49016 .55463 m
.49422 .54264 L
s
.52696 .44563 m
.53074 .44847 L
s
.19545 .34987 m
.20005 .35458 L
s
.51561 .40145 m
.51939 .41672 L
s
.42087 .61441 m
.42743 .54382 L
s
.86483 .34948 m
.86778 .35419 L
s
.83138 .34967 m
.83439 .35425 L
s
.79797 .35046 m
.80105 .35481 L
s
.57123 .37832 m
.57485 .37922 L
s
.47149 .47454 m
.47474 .51759 L
s
.76462 .35208 m
.76777 .35632 L
s
.51246 .49864 m
.51621 .51994 L
s
.3302 .45245 m
.3328 .48269 L
s
.36396 .68406 m
.36869 .67714 L
s
.51939 .41672 m
.52317 .42925 L
s
.40849 .73359 m
.41346 .71273 L
s
.63447 .36585 m
.63795 .3696 L
s
.52317 .42925 m
.52696 .44563 L
s
.73122 .35351 m
.73449 .3582 L
s
.69778 .355 m
.70111 .35907 L
s
.48971 .43154 m
.49334 .45764 L
s
.37611 .70407 m
.37898 .73604 L
s
.19082 .34515 m
.19545 .34987 L
s
.86188 .34478 m
.86483 .34948 L
s
.82836 .34513 m
.83138 .34967 L
s
.66434 .35693 m
.6678 .36188 L
s
.42089 .48601 m
.42652 .44537 L
s
.79489 .34615 m
.79797 .35046 L
s
.49334 .45764 m
.49726 .45771 L
s
.60101 .36816 m
.60467 .37512 L
s
.51621 .51994 m
.52001 .52939 L
s
.76143 .34763 m
.76462 .35208 L
s
.56363 .35353 m
.56745 .36722 L
s
.55996 .35303 m
.56363 .35353 L
s
.72793 .34895 m
.73122 .35351 L
s
.32334 .65071 m
.32711 .66298 L
s
.31908 .64594 m
.32334 .65071 L
s
.63079 .35712 m
.63447 .36585 L
s
.32711 .66298 m
.33025 .68552 L
s
.56745 .36722 m
.57123 .37832 L
s
.69436 .34945 m
.69778 .355 L
s
.53394 .37866 m
.53771 .38008 L
s
.59725 .35796 m
.60101 .36816 L
s
.18618 .3404 m
.19082 .34515 L
s
.47949 .61828 m
.48325 .63321 L
s
.66072 .34889 m
.66434 .35693 L
s
.85892 .3401 m
.86188 .34478 L
s
.62714 .34946 m
.63079 .35712 L
s
.82532 .34062 m
.82836 .34513 L
s
.59351 .34859 m
.59725 .35796 L
s
.79178 .34178 m
.79489 .34615 L
s
.45565 .59294 m
.46045 .56084 L
s
.75822 .34303 m
.76143 .34763 L
s
.31452 .64537 m
.31908 .64594 L
s
.5039 .4149 m
.50794 .39612 L
s
.58987 .34408 m
.59351 .34859 L
s
.65718 .3427 m
.66072 .34889 L
s
.72456 .34336 m
.72793 .34895 L
s
.62349 .34238 m
.62714 .34946 L
s
.69082 .3423 m
.69436 .34945 L
s
.35898 .69453 m
.36396 .68406 L
s
.3328 .48269 m
.33337 .54596 L
s
.52192 .86346 m
.52572 .91787 L
s
.18151 .33562 m
.18618 .3404 L
s
.33025 .68552 m
.33274 .71954 L
s
.48613 .55973 m
.49016 .55463 L
s
.38941 .79623 m
.39434 .78108 L
s
.85594 .33545 m
.85892 .3401 L
s
.82228 .33615 m
.82532 .34062 L
s
.5563 .35527 m
.55996 .35303 L
s
.78865 .33724 m
.79178 .34178 L
s
.61996 .33898 m
.62349 .34238 L
s
.68742 .33766 m
.69082 .3423 L
s
.37898 .73604 m
.38191 .76821 L
s
.65373 .33907 m
.65718 .3427 L
s
.53015 .38098 m
.53394 .37866 L
s
.75494 .33782 m
.75822 .34303 L
s
.47773 .43351 m
.48185 .42696 L
s
.72111 .33676 m
.72456 .34336 L
s
.58637 .34733 m
.58987 .34408 L
s
.43347 .48947 m
.43559 .55906 L
s
.30983 .64607 m
.31452 .64537 L
s
.17682 .33083 m
.18151 .33562 L
s
.45483 .49175 m
.45952 .46687 L
s
.47033 .39543 m
.47395 .41835 L
s
.46631 .3928 m
.47033 .39543 L
s
.85296 .33081 m
.85594 .33545 L
s
.42379 1.04143 m
.429 1.00478 L
s
.81923 .33162 m
.82228 .33615 L
s
.71781 .33249 m
.72111 .33676 L
s
.78546 .33234 m
.78865 .33724 L
s
.68407 .3342 m
.68742 .33766 L
s
.75159 .33181 m
.75494 .33782 L
s
.47474 .51759 m
.4783 .54665 L
s
.61637 .33443 m
.61996 .33898 L
s
.40392 .7416 m
.40849 .73359 L
s
.65026 .33515 m
.65373 .33907 L
s
.52958 .93587 m
.53338 .9131 L
s
.1721 .32601 m
.17682 .33083 L
s
.45555 .73606 m
.46066 .68925 L
s
.84997 .32619 m
.85296 .33081 L
s
.5526 .35783 m
.5563 .35527 L
s
.81613 .3269 m
.81923 .33162 L
s
.74832 .32703 m
.75159 .33181 L
s
.48212 .55997 m
.48613 .55973 L
s
.78222 .32693 m
.78546 .33234 L
s
.71451 .32856 m
.71781 .33249 L
s
.46203 .40148 m
.46631 .3928 L
s
.52632 .38193 m
.53015 .38098 L
s
.30518 .64585 m
.30983 .64607 L
s
.47395 .41835 m
.47773 .43351 L
s
.68062 .32924 m
.68407 .3342 L
s
.61275 .32931 m
.61637 .33443 L
s
.35413 .7016 m
.35898 .69453 L
s
.64664 .32843 m
.65026 .33515 L
s
.58278 .34748 m
.58637 .34733 L
s
.33274 .71954 m
.33463 .76467 L
s
.30729 .5127 m
.31606 .45645 L
s
.38191 .76821 m
.3853 .79066 L
s
.41061 .54139 m
.41295 .59444 L
s
.40592 .5512 m
.41061 .54139 L
s
.16736 .32116 m
.1721 .32601 L
s
.84695 .32151 m
.84997 .32619 L
s
.34209 .4352 m
.34503 .46194 L
s
.33251 .5129 m
.34209 .4352 L
s
.779 .32182 m
.78222 .32693 L
s
.813 .32187 m
.81613 .3269 L
s
.74508 .32281 m
.74832 .32703 L
s
.3853 .79066 m
.38941 .79623 L
s
.643 .3212 m
.64664 .32843 L
s
.71108 .32297 m
.71451 .32856 L
s
.51007 1.05246 m
.50716 .95377 L
s
.60923 .32842 m
.61275 .32931 L
s
.67706 .32266 m
.68062 .32924 L
s
.4283 .7815 m
.43413 .72661 L
s
.4783 .54665 m
.48212 .55997 L
s
.37197 .4267 m
.37568 .44131 L
s
.36689 .43757 m
.37197 .4267 L
s
.49989 .421 m
.5039 .4149 L
s
.51478 .34363 m
.51862 .35643 L
s
.51088 .34179 m
.51478 .34363 L
s
.51862 .35643 m
.52246 .37397 L
s
.1626 .31629 m
.16736 .32116 L
s
.39943 .74602 m
.40392 .7416 L
s
.37568 .44131 m
.37658 .51299 L
s
.30065 .64336 m
.30518 .64585 L
s
.63955 .31917 m
.643 .3212 L
s
.54885 .35777 m
.5526 .35783 L
s
.52246 .37397 m
.52632 .38193 L
s
.84391 .31668 m
.84695 .32151 L
s
.7758 .31722 m
.779 .32182 L
s
.80984 .3168 m
.813 .32187 L
s
.6735 .31629 m
.67706 .32266 L
s
.74172 .31727 m
.74508 .32281 L
s
.70762 .317 m
.71108 .32297 L
s
.57908 .34396 m
.58278 .34748 L
s
.4807 .35148 m
.48446 .3698 L
s
.47682 .34062 m
.4807 .35148 L
s
.52572 .91787 m
.52958 .93587 L
s
.45148 .59387 m
.45565 .59294 L
s
.34948 .70408 m
.35413 .7016 L
s
.15781 .31139 m
.1626 .31629 L
s
.47286 .33391 m
.47682 .34062 L
s
.60562 .32518 m
.60923 .32842 L
s
.67005 .31227 m
.6735 .31629 L
s
.4241 .38937 m
.42775 .40749 L
s
.42003 .38326 m
.4241 .38937 L
s
.45787 .40205 m
.46203 .40148 L
s
.34503 .46194 m
.34472 .54428 L
s
.41595 .50346 m
.42089 .48601 L
s
.39774 .41378 m
.40002 .4629 L
s
.39253 .4315 m
.39774 .41378 L
s
.84084 .31172 m
.84391 .31668 L
s
.8067 .31192 m
.80984 .3168 L
s
.7042 .31186 m
.70762 .317 L
s
.29628 .63831 m
.30065 .64336 L
s
.77253 .31189 m
.7758 .31722 L
s
.73835 .31174 m
.74172 .31727 L
s
.50698 .33536 m
.51088 .34179 L
s
.6361 .31772 m
.63955 .31917 L
s
.57532 .33762 m
.57908 .34396 L
s
.48446 .3698 m
.48822 .38972 L
s
.39851 .62628 m
.40592 .5512 L
s
.54504 .35405 m
.54885 .35777 L
s
.4687 .33656 m
.47286 .33391 L
s
.45031 .37086 m
.45407 .38721 L
s
.44615 .36914 m
.45031 .37086 L
s
.45033 .50491 m
.45483 .49175 L
s
.41542 .39049 m
.42003 .38326 L
s
.42775 .40749 m
.4307 .44815 L
s
.15299 .30647 m
.15781 .31139 L
s
.3946 .75793 m
.39943 .74602 L
s
.50308 .32696 m
.50698 .33536 L
s
.29201 .6317 m
.29628 .63831 L
s
.73503 .30711 m
.73835 .31174 L
s
.70078 .30702 m
.7042 .31186 L
s
.49593 .41767 m
.49989 .421 L
s
.83776 .30678 m
.84084 .31172 L
s
.76924 .30662 m
.77253 .31189 L
s
.8035 .3067 m
.8067 .31192 L
s
.6666 .30856 m
.67005 .31227 L
s
.60194 .32038 m
.60562 .32518 L
s
.43671 .65226 m
.43846 .74301 L
s
.5715 .32906 m
.57532 .33762 L
s
.45407 .38721 m
.45787 .40205 L
s
.49915 .32115 m
.50308 .32696 L
s
.42087 1.06352 m
.42379 1.04143 L
s
.44758 .58304 m
.45148 .59387 L
s
.33337 .54596 m
.33164 .64926 L
s
.36036 .47328 m
.36689 .43757 L
s
.34483 .70566 m
.34948 .70408 L
s
.33463 .76467 m
.33608 .81942 L
s
.44332 .58531 m
.44758 .58304 L
s
.28771 .62522 m
.29201 .6317 L
s
.53341 .31657 m
.53729 .32983 L
s
.52954 .30848 m
.53341 .31657 L
s
.48822 .38972 m
.49204 .40665 L
s
.56765 .31833 m
.5715 .32906 L
s
.53729 .32983 m
.54118 .3445 L
s
.54118 .3445 m
.54504 .35405 L
s
.63257 .3148 m
.6361 .31772 L
s
.14816 .30153 m
.15299 .30647 L
s
.56383 .31038 m
.56765 .31833 L
s
.766 .302 m
.76924 .30662 L
s
.80029 .3015 m
.8035 .3067 L
s
.83464 .30164 m
.83776 .30678 L
s
.69731 .30167 m
.70078 .30702 L
s
.73168 .3022 m
.73503 .30711 L
s
.59827 .31647 m
.60194 .32038 L
s
.44212 .36225 m
.44615 .36914 L
s
.52566 .30484 m
.52954 .30848 L
s
.49204 .40665 m
.49593 .41767 L
s
.66312 .3047 m
.6666 .30856 L
s
.4952 .31589 m
.49915 .32115 L
s
.28328 .6202 m
.28771 .62522 L
s
.56002 .30451 m
.56383 .31038 L
s
.41598 .63115 m
.42087 .61441 L
s
.46425 .35033 m
.4687 .33656 L
s
.1433 .29656 m
.14816 .30153 L
s
.43814 .35313 m
.44212 .36225 L
s
.37115 .65545 m
.37867 .59321 L
s
.79712 .29681 m
.80029 .3015 L
s
.69388 .29724 m
.69731 .30167 L
s
.8315 .29638 m
.83464 .30164 L
s
.76271 .297 m
.766 .302 L
s
.30475 .36344 m
.30269 .45469 L
s
.29825 .38454 m
.30475 .36344 L
s
.72827 .29669 m
.73168 .3022 L
s
.41295 .59444 m
.41598 .63115 L
s
.62893 .30958 m
.63257 .3148 L
s
.43559 .55906 m
.43899 .58869 L
s
.49115 .31659 m
.4952 .31589 L
s
.27868 .61703 m
.28328 .6202 L
s
.33992 .71122 m
.34483 .70566 L
s
.43377 .35595 m
.43814 .35313 L
s
.59454 .31106 m
.59827 .31647 L
s
.55619 .29822 m
.56002 .30451 L
s
.52175 .30483 m
.52566 .30484 L
s
.65961 .30053 m
.66312 .3047 L
s
.40965 .42589 m
.41542 .39049 L
s
.43899 .58869 m
.44332 .58531 L
s
.38923 .78139 m
.3946 .75793 L
s
.39002 .63701 m
.38872 .77326 L
s
.13841 .29156 m
.1433 .29656 L
s
.41107 .5173 m
.41595 .50346 L
s
.8284 .29159 m
.8315 .29638 L
s
.72486 .29148 m
.72827 .29669 L
s
.7939 .29171 m
.79712 .29681 L
s
.38671 .46029 m
.39253 .4315 L
s
.75938 .29156 m
.76271 .297 L
s
.45027 .78395 m
.45555 .73606 L
s
.69048 .29364 m
.69388 .29724 L
s
.62521 .30259 m
.62893 .30958 L
s
.44608 .50573 m
.45033 .50491 L
s
.55236 .29377 m
.55619 .29822 L
s
.59072 .30259 m
.59454 .31106 L
s
.27394 .6152 m
.27868 .61703 L
s
.65603 .29532 m
.65961 .30053 L
s
.4307 .44815 m
.43375 .48812 L
s
.58689 .29355 m
.59072 .30259 L
s
.62146 .29488 m
.62521 .30259 L
s
.1335 .28654 m
.13841 .29156 L
s
.7215 .28711 m
.72486 .29148 L
s
.40002 .4629 m
.40235 .51372 L
s
.75603 .28627 m
.75938 .29156 L
s
.82525 .2865 m
.8284 .29159 L
s
.79064 .2864 m
.7939 .29171 L
s
.487 .32168 m
.49115 .31659 L
s
.51779 .30704 m
.52175 .30483 L
s
.58309 .28677 m
.58689 .29355 L
s
.54852 .29051 m
.55236 .29377 L
s
.68703 .28952 m
.69048 .29364 L
s
.42921 .36295 m
.43377 .35595 L
s
.61772 .28793 m
.62146 .29488 L
s
.33458 .72314 m
.33992 .71122 L
s
.65242 .28983 m
.65603 .29532 L
s
.26914 .61374 m
.27394 .6152 L
s
.44186 .50461 m
.44608 .50573 L
s
.12856 .28149 m
.1335 .28654 L
s
.75271 .28134 m
.75603 .28627 L
s
.78739 .28132 m
.79064 .2864 L
s
.57933 .28288 m
.58309 .28677 L
s
.82207 .28124 m
.82525 .2865 L
s
.71813 .28288 m
.7215 .28711 L
s
.614 .28198 m
.61772 .28793 L
s
.45983 .35996 m
.46425 .35033 L
s
.68353 .28476 m
.68703 .28952 L
s
.6488 .28466 m
.65242 .28983 L
s
.54467 .28851 m
.54852 .29051 L
s
.42249 .83 m
.4283 .7815 L
s
.29834 .56846 m
.30729 .5127 L
s
.33608 .81942 m
.33722 .88168 L
s
.37658 .51299 m
.37611 .61692 L
s
.1236 .27642 m
.12856 .28149 L
s
.74937 .27638 m
.75271 .28134 L
s
.81891 .27625 m
.82207 .28124 L
s
.78413 .27621 m
.78739 .28132 L
s
.26436 .61165 m
.26914 .61374 L
s
.61027 .27625 m
.614 .28198 L
s
.51381 .30776 m
.51779 .30704 L
s
.57555 .27936 m
.57933 .28288 L
s
.71471 .27812 m
.71813 .28288 L
s
.43755 .50514 m
.44186 .50461 L
s
.36784 .38212 m
.37152 .39914 L
s
.36128 .41674 m
.36784 .38212 L
s
.40619 .52912 m
.41107 .5173 L
s
.48277 .32919 m
.487 .32168 L
s
.64513 .27855 m
.6488 .28466 L
s
.67997 .27913 m
.68353 .28476 L
s
.28391 .50185 m
.29825 .38454 L
s
.11861 .27132 m
.1236 .27642 L
s
.37152 .39914 m
.37465 .42706 L
s
.35208 .5372 m
.36036 .47328 L
s
.5408 .28963 m
.54467 .28851 L
s
.60656 .27206 m
.61027 .27625 L
s
.78083 .27095 m
.78413 .27621 L
s
.42429 .37867 m
.42921 .36295 L
s
.81571 .27111 m
.81891 .27625 L
s
.38341 .8128 m
.38923 .78139 L
s
.74604 .27185 m
.74937 .27638 L
s
.71123 .27279 m
.71471 .27812 L
s
.43375 .48812 m
.43755 .50514 L
s
.64143 .27202 m
.64513 .27855 L
s
.25965 .60836 m
.26436 .61165 L
s
.67634 .27269 m
.67997 .27913 L
s
.57177 .27678 m
.57555 .27936 L
s
.32889 .73974 m
.33458 .72314 L
s
.38242 .33026 m
.38478 .37488 L
s
.37816 .32403 m
.38242 .33026 L
s
.32455 .36805 m
.32499 .43175 L
s
.31668 .41054 m
.32455 .36805 L
s
.44414 .30682 m
.44764 .33532 L
s
.44001 .30026 m
.44414 .30682 L
s
.11359 .2662 m
.11861 .27132 L
s
.50981 .30382 m
.51381 .30776 L
s
.77756 .26612 m
.78083 .27095 L
s
.81249 .26584 m
.81571 .27111 L
s
.40526 .29682 m
.40818 .33377 L
s
.40032 .30663 m
.40526 .29682 L
s
.74268 .26713 m
.74604 .27185 L
s
.60283 .26744 m
.60656 .27206 L
s
.63775 .26633 m
.64143 .27202 L
s
.34472 .54428 m
.3451 .61829 L
s
.67271 .26649 m
.67634 .27269 L
s
.70772 .26727 m
.71123 .27279 L
s
.45553 .36169 m
.45983 .35996 L
s
.37036 .38326 m
.37816 .32403 L
s
.25502 .60381 m
.25965 .60836 L
s
.38208 .46188 m
.38671 .46029 L
s
.43543 .30748 m
.44001 .30026 L
s
.56795 .27369 m
.57177 .27678 L
s
.53689 .2901 m
.5408 .28963 L
s
.40376 .46051 m
.40965 .42589 L
s
.32258 .59181 m
.33251 .5129 L
s
.10855 .26104 m
.11359 .2662 L
s
.37465 .42706 m
.37827 .44618 L
s
.40235 .51372 m
.40619 .52912 L
s
.80927 .26069 m
.81249 .26584 L
s
.77428 .26134 m
.77756 .26612 L
s
.63408 .26136 m
.63775 .26633 L
s
.50583 .29461 m
.50981 .30382 L
s
.66911 .261 m
.67271 .26649 L
s
.47852 .33387 m
.48277 .32919 L
s
.73928 .26205 m
.74268 .26713 L
s
.70421 .26189 m
.70772 .26727 L
s
.5991 .26394 m
.60283 .26744 L
s
.25045 .59835 m
.25502 .60381 L
s
.50183 .28683 m
.50583 .29461 L
s
.43846 .74301 m
.44132 .79861 L
s
.37827 .44618 m
.38208 .46188 L
s
.44764 .33532 m
.45142 .35474 L
s
.80604 .25561 m
.80927 .26069 L
s
.6655 .25569 m
.66911 .261 L
s
.56409 .26939 m
.56795 .27369 L
s
.6304 .25661 m
.63408 .26136 L
s
.77097 .25639 m
.77428 .26134 L
s
.49773 .28678 m
.50183 .28683 L
s
.70067 .25634 m
.70421 .26189 L
s
.45142 .35474 m
.45553 .36169 L
s
.73585 .25676 m
.73928 .26205 L
s
.44534 .81096 m
.45027 .78395 L
s
.24589 .59247 m
.25045 .59835 L
s
.59538 .26172 m
.5991 .26394 L
s
.53294 .28715 m
.53689 .2901 L
s
.46272 .27815 m
.46657 .29677 L
s
.45865 .26979 m
.46272 .27815 L
s
.39057 .70813 m
.39851 .62628 L
s
.41913 .39829 m
.42429 .37867 L
s
.32307 .75693 m
.32889 .73974 L
s
.66188 .25067 m
.6655 .25569 L
s
.8028 .2506 m
.80604 .25561 L
s
.24128 .58694 m
.24589 .59247 L
s
.69711 .25064 m
.70067 .25634 L
s
.3959 .30361 m
.40032 .30663 L
s
.76761 .2511 m
.77097 .25639 L
s
.62671 .25236 m
.6304 .25661 L
s
.56022 .26536 m
.56409 .26939 L
s
.73237 .25108 m
.73585 .25676 L
s
.36458 .69439 m
.37115 .65545 L
s
.45401 .28296 m
.45865 .26979 L
s
.43127 .30044 m
.43543 .30748 L
s
.40818 .33377 m
.41091 .37764 L
s
.33722 .88168 m
.33822 .94917 L
s
.47439 .32945 m
.47852 .33387 L
s
.46657 .29677 m
.47044 .31496 L
s
.59161 .25865 m
.59538 .26172 L
s
.49366 .28186 m
.49773 .28678 L
s
.52896 .28006 m
.53294 .28715 L
s
.23652 .58274 m
.24128 .58694 L
s
.38478 .37488 m
.3878 .4077 L
s
.33164 .64926 m
.32854 .77994 L
s
.42694 .29767 m
.43127 .30044 L
s
.65824 .2456 m
.66188 .25067 L
s
.69354 .24522 m
.69711 .25064 L
s
.79954 .24551 m
.8028 .2506 L
s
.72887 .24528 m
.73237 .25108 L
s
.76422 .24561 m
.76761 .2511 L
s
.37736 .84698 m
.38341 .8128 L
s
.62301 .24819 m
.62671 .25236 L
s
.47044 .31496 m
.47439 .32945 L
s
.55633 .26223 m
.56022 .26536 L
s
.39136 .30266 m
.3959 .30361 L
s
.52097 .25422 m
.52496 .26824 L
s
.51695 .24989 m
.52097 .25422 L
s
.35419 .4577 m
.36128 .41674 L
s
.4857 .25433 m
.48968 .26811 L
s
.48156 .25121 m
.4857 .25433 L
s
.30269 .45469 m
.30222 .5278 L
s
.52496 .26824 m
.52896 .28006 L
s
.41666 .87419 m
.42249 .83 L
s
.48968 .26811 m
.49366 .28186 L
s
.23154 .58056 m
.23652 .58274 L
s
.68998 .23997 m
.69354 .24522 L
s
.72538 .23986 m
.72887 .24528 L
s
.65462 .24116 m
.65824 .2456 L
s
.79625 .24027 m
.79954 .24551 L
s
.76082 .24017 m
.76422 .24561 L
s
.58778 .25362 m
.59161 .25865 L
s
.42226 .30344 m
.42694 .29767 L
s
.61929 .24413 m
.62301 .24819 L
s
.55238 .25648 m
.55633 .26223 L
s
.51291 .24523 m
.51695 .24989 L
s
.4773 .25249 m
.48156 .25121 L
s
.15892 .24012 m
.15345 .32493 L
s
.38534 .33077 m
.39136 .30266 L
s
.72188 .23454 m
.72538 .23986 L
s
.6864 .23486 m
.68998 .23997 L
s
.75741 .23474 m
.76082 .24017 L
s
.79293 .23493 m
.79625 .24027 L
s
.58387 .24597 m
.58778 .25362 L
s
.65099 .23708 m
.65462 .24116 L
s
.22633 .58044 m
.23154 .58056 L
s
.28905 .62582 m
.29834 .56846 L
s
.31728 .77233 m
.32307 .75693 L
s
.30092 .35631 m
.30491 .36915 L
s
.28805 .45417 m
.30092 .35631 L
s
.32499 .43175 m
.32133 .55938 L
s
.30491 .36915 m
.30605 .42001 L
s
.5484 .24761 m
.55238 .25648 L
s
.61555 .24001 m
.61929 .24413 L
s
.3878 .4077 m
.39111 .43568 L
s
.44948 .28909 m
.45401 .28296 L
s
.50883 .24199 m
.51291 .24523 L
s
.44132 .79861 m
.44534 .81096 L
s
.57994 .23815 m
.58387 .24597 L
s
.39878 .47028 m
.40376 .46051 L
s
.30991 .43548 m
.31668 .41054 L
s
.41452 .40116 m
.41913 .39829 L
s
.71837 .22926 m
.72188 .23454 L
s
.75397 .22924 m
.75741 .23474 L
s
.5444 .23805 m
.5484 .24761 L
s
.68281 .22992 m
.6864 .23486 L
s
.78959 .22945 m
.79293 .23493 L
s
.41033 .26203 m
.41401 .28305 L
s
.40494 .28095 m
.41033 .26203 L
s
.64732 .23248 m
.65099 .23708 L
s
.5404 .23124 m
.5444 .23805 L
s
.57606 .23334 m
.57994 .23815 L
s
.41091 .37764 m
.41452 .40116 L
s
.47295 .25673 m
.4773 .25249 L
s
.61176 .235 m
.61555 .24001 L
s
.22093 .58179 m
.22633 .58044 L
s
.41788 .30002 m
.42226 .30344 L
s
.3451 .61829 m
.34648 .67803 L
s
.1845 .22949 m
.18792 .24706 L
s
.50471 .24095 m
.50883 .24199 L
s
.71485 .224 m
.71837 .22926 L
s
.75053 .22382 m
.75397 .22924 L
s
.78623 .22388 m
.78959 .22945 L
s
.67922 .22518 m
.68281 .22992 L
s
.53641 .23025 m
.5404 .23124 L
s
.41401 .28305 m
.41788 .30002 L
s
.64358 .22687 m
.64732 .23248 L
s
.57212 .22663 m
.57606 .23334 L
s
.39111 .43568 m
.39471 .4581 L
s
.18792 .24706 m
.1888 .28597 L
s
.34257 .61797 m
.35208 .5372 L
s
.6079 .22834 m
.61176 .235 L
s
.74707 .21846 m
.75053 .22382 L
s
.78285 .21841 m
.78623 .22388 L
s
.71132 .21896 m
.71485 .224 L
s
.37611 .61692 m
.37625 .71347 L
s
.67561 .22054 m
.67922 .22518 L
s
.44512 .28749 m
.44948 .28909 L
s
.21498 .2264 m
.21826 .24584 L
s
.21036 .21875 m
.21498 .2264 L
s
.35857 .71962 m
.36458 .69439 L
s
.56816 .21937 m
.57212 .22663 L
s
.63981 .22096 m
.64358 .22687 L
s
.37108 .88321 m
.37736 .84698 L
s
.21542 .58367 m
.22093 .58179 L
s
.33899 1.00406 m
.33822 .94917 L
s
.31132 .78909 m
.31728 .77233 L
s
.5006 .23442 m
.50471 .24095 L
s
.60398 .22044 m
.6079 .22834 L
s
.38872 .77326 m
.38861 .88887 L
s
.39471 .4581 m
.39878 .47028 L
s
.53238 .22805 m
.53641 .23025 L
s
.36313 .42789 m
.37036 .38326 L
s
.46862 .25773 m
.47295 .25673 L
s
.77947 .213 m
.78285 .21841 L
s
.7436 .21313 m
.74707 .21846 L
s
.70778 .21402 m
.71132 .21896 L
s
.56422 .21477 m
.56816 .21937 L
s
.21826 .24584 m
.21984 .28117 L
s
.60008 .21359 m
.60398 .22044 L
s
.67197 .2156 m
.67561 .22054 L
s
.63605 .21562 m
.63981 .22096 L
s
.43302 .24712 m
.437 .26204 L
s
.42866 .24304 m
.43302 .24712 L
s
.32218 .34873 m
.32561 .37046 L
s
.31804 .33716 m
.32218 .34873 L
s
.49649 .22663 m
.5006 .23442 L
s
.31259 .34321 m
.31804 .33716 L
s
.437 .26204 m
.44097 .27777 L
s
.44097 .27777 m
.44512 .28749 L
s
.24548 .22514 m
.24834 .24973 L
s
.24128 .21379 m
.24548 .22514 L
s
.23649 .20789 m
.24128 .21379 L
s
.77608 .20758 m
.77947 .213 L
s
.74012 .20785 m
.7436 .21313 L
s
.59622 .2086 m
.60008 .21359 L
s
.41065 .91949 m
.41666 .87419 L
s
.49226 .22728 m
.49649 .22663 L
s
.7042 .20884 m
.70778 .21402 L
s
.20991 .58519 m
.21542 .58367 L
s
.56028 .21252 m
.56422 .21477 L
s
.52832 .22401 m
.53238 .22805 L
s
.63224 .20959 m
.63605 .21562 L
s
.66826 .20993 m
.67197 .2156 L
s
.34861 .47038 m
.35419 .4577 L
s
.37935 .35566 m
.38534 .33077 L
s
.30605 .42001 m
.30991 .43548 L
s
.39924 .3045 m
.40494 .28095 L
s
.42367 .255 m
.42866 .24304 L
s
.32561 .37046 m
.32787 .40976 L
s
.46441 .25111 m
.46862 .25773 L
s
.77267 .20216 m
.77608 .20758 L
s
.73663 .2027 m
.74012 .20785 L
s
.59234 .20392 m
.59622 .2086 L
s
.1888 .28597 m
.18828 .33744 L
s
.30222 .5278 m
.30325 .58283 L
s
.70059 .20341 m
.7042 .20884 L
s
.3145 .63868 m
.32258 .59181 L
s
.6284 .20305 m
.63224 .20959 L
s
.27221 .21051 m
.27585 .22807 L
s
.26769 .20251 m
.27221 .21051 L
s
.6645 .2034 m
.66826 .20993 L
s
.24834 .24973 m
.24979 .28915 L
s
.52424 .21671 m
.52832 .22401 L
s
.55631 .20938 m
.56028 .21252 L
s
.46029 .2401 m
.46441 .25111 L
s
.48802 .22608 m
.49226 .22728 L
s
.4561 .23144 m
.46029 .2401 L
s
.30461 .81588 m
.31132 .78909 L
s
.20443 .58588 m
.20991 .58519 L
s
.26291 .19692 m
.26769 .20251 L
s
.27585 .22807 m
.2781 .26138 L
s
.30373 .39287 m
.31259 .34321 L
s
.76924 .19679 m
.77267 .20216 L
s
.73312 .19754 m
.73663 .2027 L
s
.62456 .19707 m
.6284 .20305 L
s
.66075 .19733 m
.6645 .2034 L
s
.69697 .19799 m
.70059 .20341 L
s
.52015 .2067 m
.52424 .21671 L
s
.58844 .19947 m
.59234 .20392 L
s
.21984 .28117 m
.22039 .32678 L
s
.34648 .67803 m
.34909 .71769 L
s
.45189 .22318 m
.4561 .23144 L
s
.51602 .20422 m
.52015 .2067 L
s
.35321 .73062 m
.35857 .71962 L
s
.33603 .3104 m
.33985 .32738 L
s
.33119 .30843 m
.33603 .3104 L
s
.34079 .43878 m
.34471 .45439 L
s
.33556 .44362 m
.34079 .43878 L
s
.38351 .76342 m
.39057 .70813 L
s
.55228 .20434 m
.55631 .20938 L
s
.76581 .19145 m
.76924 .19679 L
s
.62075 .19252 m
.62456 .19707 L
s
.44745 .22226 m
.45189 .22318 L
s
.657 .19167 m
.66075 .19733 L
s
.29897 .19801 m
.30306 .21093 L
s
.29435 .1914 m
.29897 .19801 L
s
.30306 .21093 m
.30605 .23756 L
s
.72958 .19214 m
.73312 .19754 L
s
.34471 .45439 m
.34861 .47038 L
s
.69331 .19232 m
.69697 .19799 L
s
.33985 .32738 m
.3439 .34089 L
s
.5845 .19402 m
.58844 .19947 L
s
.3439 .34089 m
.34758 .36052 L
s
.48381 .2204 m
.48802 .22608 L
s
.19895 .58611 m
.20443 .58588 L
s
.27882 .6925 m
.28905 .62582 L
s
.36432 .92681 m
.37108 .88321 L
s
.41872 .26411 m
.42367 .255 L
s
.28961 .18582 m
.29435 .1914 L
s
.32787 .40976 m
.33078 .44071 L
s
.51184 .20403 m
.51602 .20422 L
s
.54822 .1971 m
.55228 .20434 L
s
.76235 .18603 m
.76581 .19145 L
s
.65321 .18576 m
.657 .19167 L
s
.72599 .18632 m
.72958 .19214 L
s
.68961 .1862 m
.69331 .19232 L
s
.32462 .33035 m
.33119 .30843 L
s
.61692 .18798 m
.62075 .19252 L
s
.26764 .63742 m
.28391 .50185 L
s
.34758 .36052 m
.35016 .39864 L
s
.58056 .18948 m
.5845 .19402 L
s
.47961 .21282 m
.48381 .2204 L
s
.33026 .19611 m
.33391 .21559 L
s
.32593 .18627 m
.33026 .19611 L
s
.15345 .32493 m
.14867 .4066 L
s
.44279 .22711 m
.44745 .22226 L
s
.2781 .26138 m
.279 .31101 L
s
.54414 .18922 m
.54822 .1971 L
s
.35894 .28803 m
.36272 .30675 L
s
.3547 .27716 m
.35894 .28803 L
s
.30605 .23756 m
.30788 .27972 L
s
.24979 .28915 m
.25039 .33847 L
s
.64944 .18052 m
.65321 .18576 L
s
.33078 .44071 m
.33556 .44362 L
s
.32129 .18023 m
.32593 .18627 L
s
.75886 .18055 m
.76235 .18603 L
s
.68588 .18002 m
.68961 .1862 L
s
.19333 .58727 m
.19895 .58611 L
s
.72238 .18047 m
.72599 .18632 L
s
.34986 .27566 m
.3547 .27716 L
s
.47541 .20385 m
.47961 .21282 L
s
.37428 .36073 m
.37935 .35566 L
s
.61304 .18275 m
.61692 .18798 L
s
.39425 .31033 m
.39924 .3045 L
s
.34909 .71769 m
.35321 .73062 L
s
.54006 .18509 m
.54414 .18922 L
s
.33391 .21559 m
.33698 .2438 L
s
.57658 .18458 m
.58056 .18948 L
s
.36272 .30675 m
.36635 .32835 L
s
.47112 .19905 m
.47541 .20385 L
s
.50766 .19969 m
.51184 .20403 L
s
.3166 .17461 m
.32129 .18023 L
s
.68218 .17454 m
.68588 .18002 L
s
.64568 .1758 m
.64944 .18052 L
s
.71877 .17477 m
.72238 .18047 L
s
.75535 .17496 m
.75886 .18055 L
s
.18828 .33744 m
.18788 .38926 L
s
.30325 .58283 m
.30542 .62367 L
s
.35731 .44457 m
.36313 .42789 L
s
.35759 .18265 m
.3617 .196 L
s
.35314 .17478 m
.35759 .18265 L
s
.29652 .86108 m
.30461 .81588 L
s
.3617 .196 m
.36557 .21334 L
s
.60911 .17622 m
.61304 .18275 L
s
.40445 .96566 m
.41065 .91949 L
s
.37821 .24796 m
.3823 .26186 L
s
.3739 .23829 m
.37821 .24796 L
s
.3823 .26186 m
.38619 .27955 L
s
.22039 .32678 m
.22105 .37261 L
s
.57256 .17839 m
.57658 .18458 L
s
.34478 .27729 m
.34986 .27566 L
s
.32854 .77994 m
.32532 .91863 L
s
.53596 .18306 m
.54006 .18509 L
s
.36635 .32835 m
.37012 .34799 L
s
.23815 .61304 m
.2416 .63355 L
s
.23326 .60806 m
.23815 .61304 L
s
.18736 .59112 m
.19333 .58727 L
s
.46671 .19868 m
.47112 .19905 L
s
.3696 .22827 m
.3739 .23829 L
s
.4142 .2606 m
.41872 .26411 L
s
.50347 .19219 m
.50766 .19969 L
s
.36557 .21334 m
.3696 .22827 L
s
.2173 .54998 m
.22093 .56805 L
s
.21301 .53848 m
.2173 .54998 L
s
.34853 .16895 m
.35314 .17478 L
s
.67847 .1691 m
.68218 .17454 L
s
.71512 .1689 m
.71877 .17477 L
s
.43831 .22495 m
.44279 .22711 L
s
.75181 .16911 m
.75535 .17496 L
s
.20812 .53276 m
.21301 .53848 L
s
.38619 .27955 m
.39003 .29869 L
s
.64187 .1707 m
.64568 .1758 L
s
.60518 .17067 m
.60911 .17622 L
s
.35016 .39864 m
.35305 .43306 L
s
.40194 .21733 m
.40603 .23152 L
s
.39778 .20478 m
.40194 .21733 L
s
.56852 .17209 m
.57256 .17839 L
s
.39362 .19201 m
.39778 .20478 L
s
.33698 .2438 m
.34038 .26801 L
s
.38945 .17967 m
.39362 .19201 L
s
.22093 .56805 m
.22441 .58785 L
s
.37012 .34799 m
.37428 .36073 L
s
.49928 .18403 m
.50347 .19219 L
s
.38512 .17007 m
.38945 .17967 L
s
.2416 .63355 m
.24228 .68561 L
s
.40603 .23152 m
.41006 .24738 L
s
.22845 .60209 m
.23326 .60806 L
s
.39003 .29869 m
.39425 .31033 L
s
.37625 .71347 m
.37853 .76803 L
s
.34388 .16327 m
.34853 .16895 L
s
.20297 .52922 m
.20812 .53276 L
s
.71147 .16311 m
.71512 .1689 L
s
.67474 .16374 m
.67847 .1691 L
s
.41006 .24738 m
.4142 .2606 L
s
.74824 .16315 m
.75181 .16911 L
s
.38063 .16333 m
.38512 .17007 L
s
.53183 .17847 m
.53596 .18306 L
s
.60126 .16602 m
.60518 .17067 L
s
.63802 .16494 m
.64187 .1707 L
s
.30892 .64644 m
.3145 .63868 L
s
.49504 .1784 m
.49928 .18403 L
s
.22441 .58785 m
.22845 .60209 L
s
.56447 .1668 m
.56852 .17209 L
s
.46235 .19417 m
.46671 .19868 L
s
.43407 .21434 m
.43831 .22495 L
s
.34038 .26801 m
.34478 .27729 L
s
.31773 .35504 m
.32462 .33035 L
s
.42577 .18765 m
.42993 .20066 L
s
.42157 .1759 m
.42577 .18765 L
s
.42993 .20066 m
.43407 .21434 L
s
.18087 .59921 m
.18736 .59112 L
s
.30788 .27972 m
.30942 .32708 L
s
.33278 .6984 m
.34257 .61797 L
s
.41728 .16582 m
.42157 .1759 L
s
.37606 .15755 m
.38063 .16333 L
s
.70781 .15762 m
.71147 .16311 L
s
.74467 .1574 m
.74824 .16315 L
s
.67098 .1583 m
.67474 .16374 L
s
.19775 .52595 m
.20297 .52922 L
s
.63411 .15841 m
.63802 .16494 L
s
.49076 .17435 m
.49504 .1784 L
s
.52766 .17151 m
.53183 .17847 L
s
.4129 .15803 m
.41728 .16582 L
s
.59729 .16049 m
.60126 .16602 L
s
.56042 .16305 m
.56447 .1668 L
s
.27284 .57597 m
.28805 .45417 L
s
.279 .31101 m
.27886 .37431 L
s
.30542 .62367 m
.30892 .64644 L
s
.45811 .18423 m
.46235 .19417 L
s
.32133 .55938 m
.31874 .67647 L
s
.25039 .33847 m
.25053 .39408 L
s
.35922 .96448 m
.36432 .92681 L
s
.37146 .15181 m
.37606 .15755 L
s
.35305 .43306 m
.35731 .44457 L
s
.74107 .15161 m
.74467 .1574 L
s
.29326 .46024 m
.30373 .39287 L
s
.40842 .15182 m
.4129 .15803 L
s
.70415 .15217 m
.70781 .15762 L
s
.45389 .17258 m
.45811 .18423 L
s
.39002 .95939 m
.38861 .88887 L
s
.52348 .16424 m
.52766 .17151 L
s
.66721 .15281 m
.67098 .1583 L
s
.63023 .15289 m
.63411 .15841 L
s
.44965 .16193 m
.45389 .17258 L
s
.19239 .52371 m
.19775 .52595 L
s
.59329 .15437 m
.59729 .16049 L
s
.48648 .16762 m
.49076 .17435 L
s
.44534 .15316 m
.44965 .16193 L
s
.37853 .76803 m
.38351 .76342 L
s
.22105 .37261 m
.22242 .41275 L
s
.55633 .158 m
.56042 .16305 L
s
.51928 .15803 m
.52348 .16424 L
s
.4039 .14602 m
.40842 .15182 L
s
.73748 .14594 m
.74107 .15161 L
s
.70044 .14645 m
.70415 .15217 L
s
.66339 .14691 m
.66721 .15281 L
s
.44095 .14622 m
.44534 .15316 L
s
.62635 .14804 m
.63023 .15289 L
s
.18788 .38926 m
.18886 .4304 L
s
.17368 .61272 m
.18087 .59921 L
s
.48223 .15821 m
.48648 .16762 L
s
.58927 .14855 m
.59329 .15437 L
s
.18669 .52408 m
.19239 .52371 L
s
.51506 .15194 m
.51928 .15803 L
s
.5522 .15137 m
.55633 .158 L
s
.47797 .14883 m
.48223 .15821 L
s
.39935 .14023 m
.4039 .14602 L
s
.43652 .14021 m
.44095 .14622 L
s
.73387 .14037 m
.73748 .14594 L
s
.6967 .14054 m
.70044 .14645 L
s
.65954 .14072 m
.66339 .14691 L
s
.24228 .68561 m
.24008 .77229 L
s
.62242 .14241 m
.62635 .14804 L
s
.58525 .14386 m
.58927 .14855 L
s
.47366 .14096 m
.47797 .14883 L
s
.4037 .97 m
.40445 .96566 L
s
.28684 .92681 m
.29652 .86108 L
s
.54804 .14441 m
.5522 .15137 L
s
.51082 .14428 m
.51506 .15194 L
s
.2672 .77352 m
.27882 .6925 L
s
.43205 .13437 m
.43652 .14021 L
s
.73023 .13467 m
.73387 .14037 L
s
.69296 .13487 m
.6967 .14054 L
s
.46931 .13445 m
.47366 .14096 L
s
.6557 .13526 m
.65954 .14072 L
s
.1805 .52837 m
.18669 .52408 L
s
.30942 .32708 m
.31237 .35722 L
s
.61845 .13615 m
.62242 .14241 L
s
.14867 .4066 m
.14558 .47721 L
s
.5812 .13824 m
.58525 .14386 L
s
.31237 .35722 m
.31773 .35504 L
s
.50657 .13613 m
.51082 .14428 L
s
.54387 .13783 m
.54804 .14441 L
s
.42755 .12851 m
.43205 .13437 L
s
.46492 .12849 m
.46931 .13445 L
s
.72656 .12871 m
.73023 .13467 L
s
.68919 .12899 m
.69296 .13487 L
s
.22242 .41275 m
.22428 .4492 L
s
.65185 .12994 m
.6557 .13526 L
s
.50229 .12891 m
.50657 .13613 L
s
.61447 .13034 m
.61845 .13615 L
s
.16567 .63263 m
.17368 .61272 L
s
.53967 .13091 m
.54387 .13783 L
s
.57709 .13158 m
.5812 .13824 L
s
.18886 .4304 m
.19164 .45645 L
s
.46051 .12259 m
.46492 .12849 L
s
.49798 .12261 m
.50229 .12891 L
s
.72286 .12268 m
.72656 .12871 L
s
.25053 .39408 m
.25003 .45821 L
s
.68539 .12301 m
.68919 .12899 L
s
.64796 .12404 m
.65185 .12994 L
s
.61048 .12495 m
.61447 .13034 L
s
.17368 .53749 m
.1805 .52837 L
s
.53546 .12364 m
.53967 .13091 L
s
.57297 .12479 m
.57709 .13158 L
s
.20477 .49258 m
.2089 .50687 L
s
.20031 .48134 m
.20477 .49258 L
s
.2089 .50687 m
.21262 .52521 L
s
.27886 .37431 m
.27845 .44317 L
s
.45607 .11666 m
.46051 .12259 L
s
.49365 .11664 m
.49798 .12261 L
s
.19574 .47105 m
.20031 .48134 L
s
.71916 .11693 m
.72286 .12268 L
s
.6816 .11733 m
.68539 .12301 L
s
.53123 .11686 m
.53546 .12364 L
s
.64402 .11783 m
.64796 .12404 L
s
.19164 .45645 m
.19574 .47105 L
s
.56883 .11805 m
.57297 .12479 L
s
.60645 .11881 m
.61048 .12495 L
s
.21262 .52521 m
.21574 .54967 L
s
.22428 .4492 m
.22599 .48796 L
s
.48929 .11068 m
.49365 .11664 L
s
.52697 .11068 m
.53123 .11686 L
s
.71544 .11102 m
.71916 .11693 L
s
.67778 .11163 m
.6816 .11733 L
s
.64009 .11197 m
.64402 .11783 L
s
.56467 .11126 m
.56883 .11805 L
s
.60239 .11216 m
.60645 .11881 L
s
.21574 .54967 m
.21817 .58146 L
s
.16631 .55065 m
.17368 .53749 L
s
.48491 .10468 m
.48929 .11068 L
s
.52269 .10466 m
.52697 .11068 L
s
.71169 .10499 m
.71544 .11102 L
s
.56049 .10477 m
.56467 .11126 L
s
.15667 .6599 m
.16567 .63263 L
s
.67392 .10556 m
.67778 .11163 L
s
.63613 .10603 m
.64009 .11197 L
s
.5983 .10551 m
.60239 .11216 L
s
.51839 .09863 m
.52269 .10466 L
s
.55629 .09862 m
.56049 .10477 L
s
.70793 .0991 m
.71169 .10499 L
s
.5942 .09894 m
.5983 .10551 L
s
.67003 .0994 m
.67392 .10556 L
s
.63213 .09962 m
.63613 .10603 L
s
.32448 .75003 m
.33278 .6984 L
s
.28445 .50327 m
.29326 .46024 L
s
.21817 .58146 m
.21992 .62086 L
s
.22599 .48796 m
.22697 .53514 L
s
.51407 .09257 m
.51839 .09863 L
s
.55207 .09254 m
.55629 .09862 L
s
.59008 .09259 m
.5942 .09894 L
s
.70414 .09314 m
.70793 .0991 L
s
.66613 .09333 m
.67003 .0994 L
s
.6281 .09306 m
.63213 .09962 L
s
.325 .93854 m
.32532 .91863 L
s
.24008 .77229 m
.23597 .88416 L
s
.14558 .47721 m
.14498 .52978 L
s
.54783 .08645 m
.55207 .09254 L
s
.2854 .93745 m
.28684 .92681 L
s
.58594 .08643 m
.59008 .09259 L
s
.15884 .56378 m
.16631 .55065 L
s
.62406 .0866 m
.6281 .09306 L
s
.70032 .08696 m
.70414 .09314 L
s
.6622 .08706 m
.66613 .09333 L
s
.25003 .45821 m
.2486 .53469 L
s
.31874 .67647 m
.31953 .74545 L
s
.25061 .77587 m
.26764 .63742 L
s
.54356 .08032 m
.54783 .08645 L
s
.58178 .08029 m
.58594 .08643 L
s
.62 .0803 m
.62406 .0866 L
s
.69648 .08074 m
.70032 .08696 L
s
.65824 .0806 m
.6622 .08706 L
s
.27845 .44317 m
.27959 .49554 L
s
.14658 .69523 m
.15667 .6599 L
s
.21992 .62086 m
.22043 .67419 L
s
.5776 .07412 m
.58178 .08029 L
s
.61593 .0741 m
.62 .0803 L
s
.65426 .07419 m
.65824 .0806 L
s
.69262 .07447 m
.69648 .08074 L
s
.25415 .86841 m
.2672 .77352 L
s
.22697 .53514 m
.22673 .59621 L
s
.57339 .06792 m
.5776 .07412 L
s
.61183 .0679 m
.61593 .0741 L
s
.65027 .06789 m
.65426 .07419 L
s
.68872 .06807 m
.69262 .07447 L
s
.15213 .56973 m
.15884 .56378 L
s
.14498 .52978 m
.14724 .56032 L
s
.60771 .06166 m
.61183 .0679 L
s
.64626 .06163 m
.65027 .06789 L
s
.68481 .06168 m
.68872 .06807 L
s
.259 .67555 m
.27284 .57597 L
s
.60357 .05539 m
.60771 .06166 L
s
.64223 .05536 m
.64626 .06163 L
s
.68089 .05534 m
.68481 .06168 L
s
.14724 .56032 m
.15213 .56973 L
s
.27959 .49554 m
.28445 .50327 L
s
.31953 .74545 m
.32448 .75003 L
s
.63817 .04905 m
.64223 .05536 L
s
.67694 .04902 m
.68089 .05534 L
s
.22043 .67419 m
.21862 .75375 L
s
.63409 .0427 m
.63817 .04905 L
s
.67297 .04268 m
.67694 .04902 L
s
.13531 .73874 m
.14658 .69523 L
s
.2486 .53469 m
.24665 .61968 L
s
.66898 .0363 m
.67297 .04268 L
s
.22673 .59621 m
.22491 .67601 L
s
.66497 .02988 m
.66898 .0363 L
s
.23535 .90033 m
.23597 .88416 L
s
.1229 .78993 m
.13531 .73874 L
s
.21464 .85488 m
.21862 .75375 L
s
.25211 .88329 m
.25415 .86841 L
s
.24665 .61968 m
.24605 .6921 L
s
.22491 .67601 m
.2216 .77444 L
s
.24966 .71787 m
.259 .67555 L
s
.24137 .84415 m
.25061 .77587 L
s
.11148 .83888 m
.1229 .78993 L
s
.24605 .6921 m
.24966 .71787 L
s
.2199 .82751 m
.2216 .77444 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.26484 .17139 m
.2696 .17691 L
s
[(0.5)] .25533 .16034 .86068 1 Mshowa
.44047 .09754 m
.44484 .10337 L
s
[(1)] .43173 .08588 .74944 1 Mshowa
.62906 .01825 m
.63298 .02439 L
s
[(1.5)] .62122 .00596 .6382 1 Mshowa
.125 Mabswid
.13279 .22691 m
.1358 .23008 L
s
.16514 .21331 m
.16811 .21652 L
s
.19792 .19953 m
.20086 .20277 L
s
.23115 .18555 m
.23405 .18883 L
s
.299 .15703 m
.30181 .16038 L
s
.33363 .14247 m
.33639 .14585 L
s
.36874 .1277 m
.37146 .13113 L
s
.40435 .11273 m
.40703 .11619 L
s
.47711 .08214 m
.47968 .08567 L
s
.51427 .06651 m
.51679 .07008 L
s
.55198 .05066 m
.55444 .05427 L
s
.59024 .03457 m
.59265 .03822 L
s
.66846 .00168 m
.67075 .0054 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(200)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(400)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(600)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(800)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.04063 .83233 m
.04126 .82801 L
s
.06868 .85207 m
.06927 .84774 L
s
.09596 .87127 m
.09651 .86693 L
s
.14833 .90812 m
.14881 .90378 L
s
.17348 .92582 m
.17392 .92147 L
s
.19797 .94306 m
.19838 .9387 L
s
.24508 .97621 m
.24543 .97185 L
s
.26775 .99217 m
.26808 .9878 L
s
.28986 1.00772 m
.29016 1.00336 L
s
.33248 1.03771 m
.33271 1.03335 L
s
.35302 1.05217 m
.35323 1.0478 L
s
.37308 1.06628 m
.37326 1.06192 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00f_ooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G?ooool00=cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Foooool00=cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Jooooo`00g?ooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo05_ooooo003Looooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c01Looooo`00g?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05ko
oooo003Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0G_ooool00=[ooooo00?o
EEEEofIVI_l000003Oooool4o`0000Wooooo0_l0001Booooo`00m?ooool3o`000003ooooool0003o
oooo057ooooo003booooo`;o00001?ooool2o`00057ooooo003`ooooo`;o00001_ooool00ol0003o
ooooo`00001@ooooo`00kOooool3o`0000Sooooo00?o0000ooooool00000D?ooool009Gooooo0_l0
0002ooooo`03oa0@4?l0003o000004oooooo0ol0000:ooooo`04o`000?ooooooooooo`0004oooooo
002Fooooo`05o`000?ooooook^k^oc8b<_o<c<`0C_ooool2o`0000?ooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool0001?ooooo`00U_ooool01?l0003oV9RHoc8b<_o<c<a<ooooo`?o
00003oooool01Ol0003ooooooooooooooooo000004kooooo002Fooooo`03o`000?l@413oV9RH04_o
oooo0_l0000@ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0Boooool009Kooooo
00Co0000onk^k_mEEEGoQhN7B?ooool2o`0001?ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`1;ooooo`00U_ooool01Ol0003oooooodA4A?l0003o410@04Cooooo0ol00002ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`1:ooooo`00
U_ooool00ol0003oooooooooo`14ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`;o0000
1?ooool00ol0003oooooooooo`1:ooooo`00U_ooool00ol0003oooooooooo`12ooooo`;o00004_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0BOoo
ool009Gooooo0_l0000Pooooo`Co000000?o410@ooooooooool06_ooool3o`0001Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Sooooo002ioooo
o`03o`000?oooooooooo01[ooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`18oooo
o`00^Oooool00ol0003oooooooooo`0Gooooo`?o00004_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo04Oooooo002iooooo`03o`00
0?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo04Kooooo002iooooo`03o`000?oo
oooooooo01?ooooo0_l0000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
A_ooool00;Wooooo00?o0000ooooooooool04?ooool3o`0000;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo04Gooooo002iooooo`03o`000?oo
oooooooo00kooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`15ooooo`00]oooool00omEEEGoIVIVo`00000>ooooo`;o00003_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`14ooooo`00aOooool3o`00013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00<?ooooo0_l00003oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0@oooool00<7ooooo0_l0000=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04;ooooo002nooooo`?o00003oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12ooooo`00_?ooool3o`00
01;ooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`11ooooo`00^_ooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo002gooooo`?o00003oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo043ooooo002eooooo`;o00004oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?oooool00;?ooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`00/?ooool3
o`0000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool0
07[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01kooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03gooooo001jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool06_ooool3o`0000gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool007[ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oooooo0_l00002ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0??ooool007[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo
001jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Co
oooo0ol0000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0koooo
o`00N_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool2o`00
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo001joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Booooo`;o00000_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0jooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>Oooool009[ooooo0ol0000@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0hooooo`00VOooool3o`0001;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo002Fooooo`?o00003Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2
o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Oooooo002Dooooo`;o00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo002Booooo`;o00004oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool2o`0000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Ko
oooo002?ooooo`?o000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o0000
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=Oooool008gooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Ooo
ool008[ooooo0ol0000Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`00R?ooool3o`00
00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool008Ko
oooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`00Goooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01oooooo0ol0000;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03;ooooo001Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool2o`0000oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0booooo`00Goooool01Ol@413ooooooooooooooooo410@01_ooooo0_l000000ooo
oooo0000ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`00Goooool01Ol0003ooooooooooooooooo
000001Sooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0`ooooo`00Goooool01Ol0003ooooooooooooooooo000001Gooooo0ol0000?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo001Oooooo`05oa0@4?oooooo
ooooooooool@41005?ooool3o`00017ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0_ooooo`00Goooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo0ol0000<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`00Gooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000_l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool0077ooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00002?ooool3o`0000Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool006kooooo0ol000000ooooooo0000oooo
o`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0]ooooo`00K?ooool2o`00013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool006Wooooo0ol0000;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool006Oooooo0ol0000=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool2o`0000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool006Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool006Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo00?o0000ooooooooool00_l00008oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo001Uooooo`?o00003oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`00I_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool005_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`07o`000?ooooooooooooooool0003oooooo`00000;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool0
05_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`00Foooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo
001Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Kooooo001Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09Oooool005_ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool01_l0003ooooooooo
ool0003oooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o
00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo001Kooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oo
oooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool005_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`00
000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`000003ooooool0
003ooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02?ooooo001Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0S
ooooo`00I?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo0000ooooool000002?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0R
ooooo`00I?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo1Ol00003
ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo001Tooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`Co00001oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool08Oooool006Cooooo00?o0000ooooooooool03_ooool3o`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool006?ooooo0_l0
000Aooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool006?ooooo
00?o0000ooooooooool04?ooool3o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool2o`0000Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`00
Hoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000;o00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool006?ooooo00?o0000
ooooooooool04?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01_l0003o
ooooooooool0003oooooo`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Wooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01kooooo001Sooooo`03o`000?oooooooooo013ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03o`00
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo001Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01gooooo001Rooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool00oooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`0000Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool006;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`?o00001oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool0
0oooool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Sooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool006;ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool2o`000003ooooool0
003ooooo00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01_ooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo0ol00006ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000oooo
o`05ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool2o`000003ooooool0
003ooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00?ooooo1?l0
0005ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01[ooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooool0003o0000ooooool00006oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03
ooooo`;o00000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0I
ooooo`00HOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo001Qooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool02Ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool3
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6?ooool0067ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo0_l000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo001Qooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o00001_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo1?l00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000004ooooo`;o00001_ooool2o`0000Kooooo0ol00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001P
ooooo`?o00004_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00006
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o0000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo001Qooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`?o00001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000ooo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Eooooo`00?_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`0000Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000003ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool003kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000000_l00006
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000n
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01Oooool02?l0003oooooooooool0003oooooo`000?oooooo00001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo0ol00004ooooo`04o`000?oooooo
ooooooooo`?o00000oooool00ol0003oooooooooo`03ooooo`Co00001_ooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00?_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000003ooooo`?o00001?ooool01?l0003oooooooooooooool3
o`0000?ooooo00?o0000ooooooooool00oooool4o`0000Oooooo0_l000000ooooooo0000ooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`00?_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000_ooool01?l0003oooooo`000?l00004ooooo`04o`000?ooooooooooooooo`?o
00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`00
0003ooooool0003ooooo00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l0
0007ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`00?_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000Kooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00;ooooo00Co0000ooooool0003o00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00002?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool2o`00
00Gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`00?_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool2o`0001Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`06o`000?ooooooooooooooool0003o
oooo0_l00002ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00009
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04Oooool003kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool3o`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo00Co0000oooo
ool0003o00001?ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooooooool2o`0000Wooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`06ooooo`;o00002?ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooooooo`?o00004_ooool005oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
0003ooooool0003ooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000004ooooool0
003oooooooooo`;o00001Oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00?o0000oooo
ool000000oooool01?l0003oooooooooooooool2o`0000Sooooo0_l00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`07ooooo`?o00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0ol00002ooooo`03o`000?oooooooooo013ooooo001Oooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooool0003oooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo
0_l000001?oooooo0000ooooooooool2o`0000Gooooo00Ko0000ooooool0003o0000ooooool00004
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`000004ooooool0003o
ooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003ooooooooo
o`02o`0000Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooooooo`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0@ooooo`00
Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00003
ooooo`Co000000?oooooo`000?ooool00ol00005ooooo`06o`000?oooooo0000o`000?oooooo0000
1?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0ol000001?oooooo0000
ooooool00002ooooo`;o00001?ooool01?l0003oooooo`000?l00005ooooo`;o000000?oooooo`00
0?ooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo1?l00008
ooooo`03o`000?oooooooooo013ooooo001Oooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0000?ooooo0ol000001?oooooo0000ooooooooool3o`0000Gooooo
0_l000001?oooooo0000ooooool00004ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o
00001oooool2o`000005ooooool0003o0000ooooool000000_ooool2o`0000Cooooo00Go0000oooo
ool0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000000ol0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03o`000?oooooooooo013ooooo001O
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0
0002ooooo`?o000000Coooooo`000?oooooooooo0ol00002ooooo`03o`000?oooooooooo00?o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo
0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l00004ooooo`05o`000?oooooo0000oooo
ool000002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`Co00003oooool00ol0003oooooooooo`0?ooooo`00G_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`03o`0000Cooooo1?l000001?oooooo
0000ooooooooool4o`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`?o00001oooool2o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`05o`000?oo
oooo0000ooooool000002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool3o`0001;ooooo
00?o0000ooooooooool03oooool005kooooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?l00004ooooo`?o000000?oooooo`000?l000000oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?oooooo00000oooool3o`0000Oooooo
0_l00004ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`000003ooooool0003ooooo
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`000?l0000E
ooooo`03o`000?oooooooooo00oooooo001Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003o000000;o00000oooool01?l0003oooooo`000?l00002
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?l000001?ooool3o`0000Oooooo0_l00005ooooo`;o00000_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?ooool01oooool01?l0003oooooooooooooool2o`000003
ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0ol0000Hooooo`03o`000?oooooooooo00oooooo001Nooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004o`0000?ooooo
00Co0000ooooool0003o00000_ooool2o`000005ooooool0003oooooooooool000000_ooool00ol0
003oooooooooo`02o`000003ooooool0003o000000Cooooo0ol00006ooooo`04o`000?oooooooooo
o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2
o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03o`0000;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0?ooooo`00G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`02ooooo`04o`000?oooooo0000
o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Ko0000ooooool0003ooooo
o`000?ooool2o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool3o`00
01kooooo00?o0000ooooooooool03oooool005kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool03?l0003o
ooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0ol000000ooooooo
0000ooooo`02o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo
ool3o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool03oooool005kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go00000_ooool0
3?l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0_l00002
ooooo`04o`000?oooooo0000o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo0ol0000Uoooo
o`03o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`02
o`000003ooooool0003ooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0
0005ooooo`?o00001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1Ol0000Vooooo`03
o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`000?l0003oooooo`000?ooool2
o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00001?oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool01_ooool2o`000004ooooool0003oooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo1?l0000[ooooo`03o`000?oooooooooo00kooooo001Moooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000oooo
ool000000_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Kooooo0_l000001?oooooo0000
ooooool00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`Co0000;Oooool00ol0003oooooooooo`0>ooooo`00G?ooool2o`0001Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`000005ooooool0003o0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool01_ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Cooooo1Ol00004ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03_ooool005go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o00000_ooool00ol0003o
ooooooooo`02o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo1?l0000coooo
o`03o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`05o`000003ooooool0003ooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o000000Coooooo`000?oooooo00001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`00
00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`00G?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000ooooool0003o0000ooooool00003ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooo
ooooooooo`000009ooooo`0<o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`Co00001Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00kooooo001Looooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool4o`000005ooooool0003ooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000000_l00004ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooo
ool0003ooooo00;o00000oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`?o000000Coooooo`00
0?l0003o0000>_ooool00ol0003oooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo0_l00003ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo0ol00003ooooo`04o`000?oooooooooooooo
o`;o00002?ooool2o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool4o`0000Kooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo0_l00003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00000
1Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000;o
oooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04o`0000Wooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03
o`000?oooooo000000;ooooo00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003ooooo
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo1_l00003
ooooo`?o00002?ooool2o`000003ooooool0003ooooo00;ooooo0_l00006ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00gooooo001Looooo`;o00005_ooool00ol0
003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05
ooooo`;o00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000ooooool0003o00001?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool3o`0000Kooooo0ol00008ooooo`Co00000_ooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo00Co
oooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00gooooo001Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?ooool00oooool0
0ol0003oooooo`000002o`000005ooooool0003oooooooooool000000oooool3o`0000Kooooo0ol0
0007ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool03Oooool003Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03o`000?oooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002o`0000?ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooooooo0ol00006ooooo`?o0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o000000Goooooo`000?oooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00go
oooo0006ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00omgMgOo
IVIVooooo`08ooooo`03ofIVI_mgMgOooooo00Oooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool3
o`0000Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooo
oooooooooooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00001oooool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413o
gMgM00Oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4003ooooo`Go00001Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00000oooool01?l0
003oooooooooool00002ooooo`0=o`000?oooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`;o00001?ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
0000ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool00ol0003ooooooooo
o`06ooooo`Co00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`03
ooooo`06ofIVI_l0003o0000odA4A?o<c<co00000_ooool00ol0003oooooooooo`05ooooo`03oeEE
EOnHV9Sooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03ohN7QomVIVKooooo00Ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000oooo
oooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
0oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo0_l000001_oooooo
0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006
ooooo`04o`000?oooooo0000ooooo`So000000?oooooo`000?l000001Oooool00ol0003ooooooooo
o`03ooooo`Co00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`02
ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0ol00008ooooo`03o`000?oooooooooo00;ooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003
ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo0_l00003ooooo`04o`000?oooooo0000o`0000;ooooo
00?o0000ooooool000000oooool3o`000004ooooool0003oooooo`0000Sooooo00?o0000ooooool0
00001_ooool:o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo00?o00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool00olb<S;oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l000001_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o00000oooool0
1?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000Cooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooool000001Oooool7o`000004ooooool0003o0000o`0000?ooooo
0_l00005ooooo`?o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
0_l0000;ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03?ooool000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oc8b<_oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^ko
A4A4o`000005ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`04ooooo`;o
00001?ooool2o`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000005oooo
o`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooool000000_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04o`00
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo00002oooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?ok^k^o`000?ooool01_ooool00ol0003oooooooooo`04
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?oMgMgo`000?ooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o00000_ooool00ol0003o
ooooo`000005ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooool000000_l00003ooooo`;o00001Oooool3o`0000Co
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0000;ooooo`04oeEEEOmgMgOo
oooooa0@40Go00001?ooool00omgMgOoEEEEooooo`06ooooo`03o`000?oooooooooo02Gooooo0_l0
000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co
0000ooooool0003o00000_ooool00ol0003oooooo`000005ooooo`?o000000Coooooo`000?oooooo
oooo0_l00003ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooo`000002o`0000;o
oooo00?o0000ooooool000000_ooool3o`000003ooooool0003ooooo00Cooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00_ooooo0006ooooo`03o`000?oooooooooo01?o
oooo00?ogMgMoa0@4?o^k^h00_ooool00ol0003oooooooooo`04ooooo`03onk^k_l@413ogMgM00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Co
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool2o`00
00Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`000003ooooool0003o
oooo00Cooooo00?o0000ooooool000000ol000000ooooooo0000ooooo`03o`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool000001?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02ooo
ool000Kooooo00?o0000ooooooooool05?ooool01OmgMgOoIVIVoooooooooooo000000Kooooo00?o
IVIVogMgMoooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`000004ooooool0003oooooooooo`;o
00001_ooool2o`0000;ooooo00?o0000ooooool000000_l00002ooooo`?o000000?oooooo`000?oo
ool01?ooool00ol0003oooooo`000008o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool005[ooooo00?o0000ooooooooool0
5oooool01?l0003oooooooooool0000>ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o
00001Oooool2o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`0000Kooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool005Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooo`00000>ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003o
ooooo`000003ooooo`;o000000Coooooo`000?oooooooooo0_l00006ooooo`;o00000_ooool00ol0
003oooooo`000002o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00004oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03Oooool3o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooool0
00000oooool2o`000004ooooool0003oooooooooo`;o00001_ooool2o`0000;ooooo00Oo0000oooo
oooooooo0000ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`04o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02[ooooo0ol0
0005ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooo000000?ooooo0_l0
00001?oooooo0000ooooooooool2o`0000Kooooo0_l00002ooooo`04o`000?oooooo0000ooooo`Go
00000_ooool3o`0000;ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`;o
000000Coooooo`000?oooooooooo0_l00006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool02?l00003ooooo`;o00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02Wooooo1ol00000
0ooooooo0000ooooo`05ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Co00000_ooool2o`000004ooooool0003oooooo`0000?ooooo0_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00[ooooo001Hooooo`;o00009Oooool6o`000004
ooooool0003oooooo`0000?ooooo0_l00006ooooo`;o00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?oooooooooo1?l000000ooooooo
0000ooooo`02ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05?ooool3o`0003cooooo00?o0000ooooooooool02_ooool005Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo0_l00005ooooo`;o
00001?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o000000Co
ooooo`000?oooooooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo0ol00002ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool02_ooool005Sooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`000005ooooool0003o
ooooooooool000000oooool2o`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5_ooool3o`0000Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`00F?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o0000
0oooool2o`0000Cooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?l00002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooo`000?l0
0002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04oooool3o`0000[ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`00F?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Kooooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000003ooooo`;o0000
1?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Co00000_ooool0
0ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00oooooo1?l0000>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
2_ooool005Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`;o000000Go
ooooo`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00;o00001?ooool01?l0003ooooo
ooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?l000001_oooooo0000o`000?oooooo0000ooooo`;o0000
0_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000003_ooool3o`0001?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0:ooooo`00F?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo1?l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`Co000000Koooooo`000?l0003oooooo`000?ooool2o`0000;ooooo
00Ko0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000_ooooo0ol0000Fooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09
ooooo`;o00000_ooool00ol0003oooooo`000004ooooo`?o00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko0000oooooooooooo
0000ooooool00004ooooo`Co000000?oooooo`000?ooool00_l000001Ooooooo0000oooooooooooo
000000;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`Co00006_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02Oooool2o`0000;ooooo00?o0000ooooool000001?ooool00ol0003oooooo`000004
o`0000?ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`Go000000Ooooooo`000?l0003oooooo`000?oooooo
000000;ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo0ol0000Oooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02Oooool005Oooooo0_l0000Qooooo`03o`000?oooooo
oooo00[ooooo0_l00002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000000_ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00007ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool5o`000007ooooool0003oooooooooool0003oooooo`00
0002ooooo`03o`000?oooooooooo00?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo0_l00002ooooo`03o`000?oooooo000000;o00008oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool02_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo0_l00002ooooo`03
o`000?oooooo000000?ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`03o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`;o000000Coooooo`000?l0003o00009oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo00Co0000oooo
ool0003o00000oooool01?l0003oooooo`000?l00006ooooo`;o00000_ooool00ol0003oooooo`00
0003ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool5o`0002Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00
Eoooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`04o`000?oooooo0000o`0000?ooooo00Co0000ooooool0
003o00001_ooool2o`0000;ooooo00?o0000ooooool000000oooool2o`000007ooooool0003ooooo
ooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool00_l0
000Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool005Oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0;ooooo`;o00000oooool2o`0000Cooooo0_l00004
ooooo`03o`000?oooooo000000;ooooo0ol00003ooooo`04o`000?oooooo0000o`0000Kooooo0_l0
0002ooooo`03o`000?oooooo000000?ooooo0_l000001ooooooo0000oooooooooooo0000ooooool0
00000oooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool02Oooool005Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0<ooooo`;o0000
0oooool2o`0000?ooooo00?o0000ooooool000000oooool01_l0003ooooooooooooooooo0000oooo
o`?o00000oooool2o`000003ooooool0003ooooo00Gooooo0_l00002ooooo`03o`000?oooooo0000
00?ooooo0_l000001ooooooo0000oooooooooooo0000ooooool000000oooool2o`0000Gooooo00?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo001Fooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool03?ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool0
0ol0003oooooo`000003ooooo`;o000000Ooooooo`000?ooooooooooo`000?oooooo000000?ooooo
0_l00005ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00
E_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`;o0000
0oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o
oooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool2o`0000Gooooo1?l00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool005Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0=ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
00Gooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooo000000?ooooo0_l00003
ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo001Foooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool2o`0000?ooooo0_l00003oooo
o`;o00001?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?ooool01Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo1Ol00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`08ooooo`00EOooool3o`0001oooooo00?o0000ooooooooool03Oooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000
ooooo`;o000000?oooooo`000?ooool01Oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1?l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`00<oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`;o0000
0oooool2o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`04o`00
0?oooooo0000ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooo`000002ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool003?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool03_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003ooooo00Cooooo00?o
0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`07ooooo`00<oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00kooooo0_l00003ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00Kooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`04oooo
o`03o`000?oooooo000000;ooooo0_l00003ooooo`Go00000_ooool2o`0000Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool01oooool003?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool01?oo
ool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000oooo
ooooool2o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool01oooool003?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oEEEEo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`00
00;ooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooooooo00;ooooo1?l00002ooooo`?o000000?oooooo`000?ooool00_l000001?oo
oooo0000ooooooooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`00<oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo00Oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000001Ol00002ooooo`06o`000?oooooo0000o`000?oooooo
00000_ooool2o`0000Cooooo0_l00008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`00<oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0@ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo
1Ol00002ooooo`;o00000_ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00?o0000oooo
ooooool00oooool2o`0000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00Oooooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Cooooo00Coc<c<odA4A?l0003o410@1?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo013ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;o00000_ooool4o`000005ooooool0003ooooooooo
ool000000_ooool01_l0003ooooooooooooooooo0000ooooo`;o000000Goooooo`000?oooooooooo
o`000005ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`00000kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool005Co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`000004
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05o`00
00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`07ooooo`00E?ooool2o`0001kooooo00?o0000ooooooooool0
4?ooool2o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oo
oooo1Ol00003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000003gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`00E?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo017ooooo0_l00003ooooo`06o`000?oooooo0000o`000?oooooo
00000oooool00ol0003oooooooooo`05ooooo`?o00000oooool00ol0003oooooooooo`02o`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo001Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo0ol00002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo001Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000?o00001_ooool02_l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool00004oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000005
ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0003oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`00
Doooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooool00000
0oooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0000:ooooo`03o`000?oooooo000000;o
00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ool000000oooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00010ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01_ooool005?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo
0ol000000ooooooo0000ooooo`0:ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooool0
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Kooooo001Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
4Oooool2o`0000Cooooo1Ol00003ooooo`03o`000?oooooooooo00Wooooo00Co0000ooooool0003o
00001?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
ool0003o00000oooool3o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00012ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool005?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?l000000_l00003ooooo`05o`00
0?ooooooooooooooool000002oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00003ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`00Doooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo
0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`09ooooo`04
o`000?oooooo0000o`0000[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l0
0003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Gooooo001Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
3oooool5o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`04
o`000?oooooo0000o`0000[ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooo`000?l0
0003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000004Cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`00D_ooool2o`0001gooooo00?o0000ooooooooool03?oo
ool3o`0000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
2_ooool4o`0000[ooooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0003ooooo00;o
oooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo000004Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05oooo
o`00D_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo1?l00006ooooo`;o
00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo1?l0000:oooo
o`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00000oooool3o`0000Cooooo00?o
0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
A_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo001Booooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01_ooool3o`0000[ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool02oooool3o`0000[ooooo00Co0000ooooool0003o
00000_ooool01?l0003oooooooooool00003ooooo`?o00001?ooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000016ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool005;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`03ooooo`?o00003Oooool2o`0000Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0;ooooo`?o00002_ooool4o`000003ooooool0003o000000;ooooo00Co0000
oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo000004Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`05ooooo`00D_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo000000?o00004?oo
ool2o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`04o`00
0?oooooo0000o`0000[ooooo1_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000003
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo000004Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`00D_ooool0
0ol0003oooooooooo`0Jooooo`?o00005?ooool2o`0000Cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`0000[ooooo1_l00003ooooo`04o`00
0?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01?ooool005;ooooo00?o0000ooooooooool05oooool4o`0001Kooooo0_l00004ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool02oooool01?l0003oooooo`000?l0000:oooo
o`;o000000Coooooo`000?l0003o00000oooool01?l0003oooooooooooooool3o`0000?ooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo001Aooooo`03o`000?oo
oooooooo01Gooooo0ol00003ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02o`0000[ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool00000E?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Cooooo001Aooooo`03o`000?oooooooooo017ooooo1?l00006ooooo`03
o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02o`0000_ooooo00Go0000ooooool0003oooooo`000002oooo
o`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000oooooooooooo000000cooooo00Co0000
oooooooooooo0000E?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001A
ooooo`03o`000?oooooooooo00kooooo0ol0000:ooooo`03o`000?oooooooooo01Cooooo0_l00004
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
o`0000_ooooo00Co0000ooooool0003o00000oooool00ol0003oooooooooo`02ooooo`;o000000Co
ooooo`000?oooooo00003Oooool01?l0003oooooooooool0001Eooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool0057ooooo00?o0000ooooooooool02oooool3o`0000gooooo
00?o0000ooooooooool05?ooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;o00003?ooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool2o`000004ooooool0003oooooo`0000gooooo00Co0000oooooooooooo0000E_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo001@ooooo`;o00002Oooool4o`0000oo
oooo00?o0000ooooooooool05Oooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooooooo`;o00003?ooool3o`0000?ooooo00?o0000oooo
ooooool00_ooool2o`000004ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0001Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?oo
ool0057ooooo00?o0000ooooooooool01?ooool3o`0001?ooooo00?o0000ooooooooool05Oooool2
o`0000Cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo
ooooooooo`;o00003?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0
003oooooo`0000?ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0001Hooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool0053ooooo00?o0000ooooooooool0
0_ooool3o`0001Kooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l00003ooooo`03o`00
0?oooooooooo00[ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo0000F?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo001@ooooo`03o`000?oooooo000000;o00006Oooool00ol0003ooooooooo
o`0Eooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool02_ooool01ol0003ooooooooo
oooooooo0000ooooool000003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool2o`000005ooooool0003oooooooooool000002_ooool01?l0003oooooooooool0
001Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool0053ooooo0_l0000K
ooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000002ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0005[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`00D_oo
ool2o`0001Wooooo00?o0000ooooooooool05Oooool00ol0003oooooo`000004ooooo`;o00000ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002ooo
ool2o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo0000ooooool0
00003?ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool005?ooooo0_l0000Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool0
00001?ooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000_ooooo0_l00004ooooo`05o`000?ooooooooooooooool000000oooool3o`00
00gooooo00Co0000oooooooooooo0000G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00?ooooo001Booooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooo`000004ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000G?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooo`000004ooooo`;o00000oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go
0000ooooooooooooooooo`00000Cooooo`04o`000?ooooooooooo`0005gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`02ooooo`00Eoooool2o`0001?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooo`000004ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Co0000oooooooooooo
00005?ooool01?l0003oooooooooool0001Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00_ooool005Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooo000000Cooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooo
oooo00005?ooool01Ol0003ooooooooooooooooo000005kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02ooooo`00F_ooool2o`00013ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool0
000Dooooo`05o`000?ooooooooooooooool00000Goooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00;ooooo001Jooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000002_ooool00ol0003oooooo`000004ooooo`04o`000?oo
ooooooooo`0001Cooooo00Go0000ooooooooooooooooo`00001Oooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00_ooool005gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Cooooo
00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo0000063ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`00C_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`04o`000?oooooooooo
o`0000Cooooo00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo0000067ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00C_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00gooooo0_l0000Sooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Cooooo00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo
000006;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00C_ooool01Ol@
413ooooooooooooooooo410@00kooooo0_l0000Rooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0001Cooooo
00Go0000ooooooooooooooooo`00001Sooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00Oooool004kooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo0000027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007ooooo001>
ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0Tooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Wo
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`00000Eooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00Oooool004kooooo00Go410@oooooooooooooooooa0@400Booooo`;o00009?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000005Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo007ooooo001>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool2o`00
02;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
5Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo001>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h05Oooool2o`00027ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001Zooooo`03o`000?oo
oooooooo01kooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001[ooooo`03o`000?oooooooooo
01gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
5Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0:ooooo`7o00000Oooool1ooooo`00K?ooool3o`0001cooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooool000005Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool1ooooo`00K_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`00000Eooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`?o0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Fooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`7ooooo001aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o00005oooool01ol0003ooooooooooooooooo0000ooooool00000J?ooool00ol0003o
ooooooooo`07ooooo`7o00000Oooool1ooooo`00L_ooool2o`0001Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`;o00005oooool01ol0003ooooooooooooooooo0000
ooooool00000JOooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00M?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000001Oooooo00Oo0000ooooooooooooooooo`000?oooooo000006[ooooo00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool007Gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool01ol0
003ooooooooooooooooo0000ooooool000005oooool01ol0003ooooooooooooooooo0000ooooool0
0000Joooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00MOooool3o`00023ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l0000Hooooo`07o`000?ooooooooooooooool0003oooooo`00
001/ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`;o00006?ooool01ol0003ooooooooooooooooo0000oooo
ool00000K?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Wooooo0_l0000Looooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00006?ooool01ol0003ooooooooooooooooo0000ooooool00000
KOooool00ol0003oooooooooo`03ooooo`7o00000Oooool0067ooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool2o`0001Sooooo00Oo0000ooooooooooooooooo`00
0?oooooo000006kooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Qooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o00006_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0001Sooooo00Oo
0000ooooooooooooooooo`000?oooooo000006oooooo00Go0000ooooooooooooooooo`000001oooo
o`00H_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Oooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
6?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06oooooo00Co0000oooooooooooo
00000Oooool006?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Kooo
ool01?l0003oooooooooool00001ooooo`00I?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000[ooooo0_l0000Eooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool00Ol0000006Gooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`09ooooo`;o00008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l0000Hooooo`03o`000?oooooooooo07Kooooo0Ol00001ooooo`7o0000001Qooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`1g
ooooo`;o0000001Qooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o00007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03
o`000?oooooooooo07Kooooo0ol0000008Kooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000oooooooo
ool0LOooool5o`0000?ooooo0027ooooo`;o00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo06go
oooo1?l00008ooooo`00Qoooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Wooooo
1?l0000<ooooo`00R_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Cooooo1Ol0
000@ooooo`00Roooool2o`0001Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo063ooooo1?l0000Eooooo`00SOooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05_ooooo1Ol0000Iooooo`00SOooool3o`0001Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Eoooool4o`0001kooooo002@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
D_ooool5o`0002;ooooo002Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_oo
ool4o`0002Oooooo001mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000@ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
04[ooooo1?l0000[ooooo`00O_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0000?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04Gooooo1Ol0000_ooooo`00Noooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Ooo
ool4o`0003Cooooo001kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001oooool2o`0000_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0??ooool5o`0003Sooooo001kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0>?ooool4o`0003gooooo001looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooo`00
000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0dooooo`Co0000@Oooool007cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo
1Ol00015ooooo`00OOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0ol0000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0[ooooo`Co0000B_ooool009kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool09_ooool5o`0004kooooo002Oooooo`;o00004oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool4o`0005?ooooo002Q
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01kooooo1?l0001Gooooo`00X_ooool2o`00013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo1Ol0001Koooo
o`00Xoooool2o`0000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Gooooo1?l0001Pooooo`00YOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`Go0000
I?ooool00:Kooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0<ooooo`Co0000JOooool00:Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool5
o`0006gooooo002Booooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo1?l0001booooo`00
T_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Eooooo`Co0000M_ooool009;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool5o`0007[ooooo
0023ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool2
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`Co0000Ooooool0
08?ooooo00Go410@okZj^_o^k^koMgMgoa0@400:ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool5o`0008?ooooo0023ooooo`03o`00
0?oooooooooo00cooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4009ooooo`05o`000?oooooo0000ooooool000002_ooool4
o`0008Sooooo0023ooooo`03o`000?oooooooooo00cooooo00?ogMgMoa0@4?nHV9P01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000?o
ooooo`000?ooool01Oooool4o`0008cooooo0023ooooo`03o`000?oooooooooo00gooooo00Coc<c<
odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`?o000000?oooooo`000?l000000ol0002@ooooo`00POooool00ol@413o0000
o`000003o`0002gooooo0_l0002Eooooo`00Poooool00ol0003oooooooooo`35ooooo`00Poooool0
0ol0003oooooooooo`35ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00Y_oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo002V
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@402@ooooo`00Y_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000T?ooool0
0:Kooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@402@oooo
o`00Y_ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093o
oooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodco
oooo003oooooodcooooo003oooooodcooooo003;ooooo`04oa0@4?l0003o0000o`0007cooooo003<
ooooo`03o`000?oooooooooo07cooooo003<ooooo`03o`000?oooooooooo07cooooo002Nooooo`05
o`000?o<c<cogMgMo`000?o^k^h00_ooool01_nHV9So0000o`000?mgMgOo410@o`0000Cooooo00?o
8B4Qoc8b<_ooool00oooool01_o^k^koEEEEo`000?l0003oA4A4okZj^PSooooo00Ko410@oc8b<_l0
003o0000oa0@4?nYZJT3ooooo`09o`000?mgMgOo0000o`000?mEEEGok^k^ooooooo^k^koEEEE00;o
000000?oA4A4okZj^_ooool00_ooool01OmVIVKo0000o`000?m4A4Coc<c<00?ooooo00OoV9RHo`00
0?l0003oA4A4okZj^_oooooo410@00Go00001?ooool01_nHV9So0000o`000?mgMgOo0000oa0@40;o
00000_ooool01Ol0003oooooooooool0003o410@04Sooooo002Mooooo`06ojVYZOl0003oQhN7oiRH
V?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00CoV9RHoc8b<_l@413o^[Zj
0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Sooooo00Ko0000ojVYZOoooooooooookZj^_l0
0003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMgooooooo^k^koMgMgoa0@
4002ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000ooooooooool01Oooool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`17ooooo`00WOooool01_mEEEGoQhN7odA4A?mE
EEGoMgMgoeEEE@;ooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`04oa0@4?nj^[[oV9RHoc8b
<P?ooooo00?o0000ooooooooool03?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo04Oooooo002Mooooo`06o`000?oM
gMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002o`0000?ooooo00KoV9RHoc8b<_oo
oooooooooa0@4?nj^[X2ooooo`Ko00002?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP?ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`0000;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Aoooool009co
oooo00SoZJVYob4Q8OooooooQhN7oeEEEOoooooo<S8bojVYZ@Cooooo00Ooc<c<o`000?oooooooooo
onk^k_l0003ogMgM00;ooooo00[oV9RHoc8b<_oooooooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b
2?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00go0000oeEEEOo^k^koooooogMgMomV
IVKooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
0003ooooo`03o`000?oooooooooo00Gooooo00?o0000oc8b<_oMgMd01Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q04Wooooo002Looooo`?o
00000_ooool3o`0000;ooooo00Co<S8bo`000?l0003oV9RH0_ooool00ol@413o0000o`000002oooo
o`?o000000?oooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`07ooooo`06ojVYZOlQ8B7o0000
o`000?lb<S;o00000_ooool00ol@413o0000ogMgM`02o`000005ofIVI_o^k^koooooonk^k_mEEED0
0_l000001_m4A4Cok^k^ooooooooooook^k^ofIVIP;o000000CoA4A4o`000?oooooo410@1Ol00003
ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o0000ooooooooool2o`000009oooo
ool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY04Wooooo003Tooooo`03o`000?oooooooooo
06Cooooo003Tooooo`03o`000?oooooooooo06Cooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.225172, -0.107519, \
0.00427749, 0.00427749}}]
}, Open  ]],

Cell[TextData[{
  "Evidently the cascade to large wavenumbers has been suppressed by the \
dispersive term in the ",
  "KdV",
  " equation. Modes in the upper half of the spectral range have negligible \
amplitude. This implies that our cutoff of the spectrum at ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(\[PlusMinus]M\)\)]],
  " does not affect the result. This can be verified by taking larger (or \
somewhat smaller) values of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ": the answer does not change. "
}], "Text"],

Cell[TextData[{
  "\tThus, when dispersion is added in the KdV equation, wavebreaking no \
longer occurs.  Is this due to the relatively small amplitude of the  wave \
chosen in the above example? The answer is no - even for large amplitudes, \
the wavebreaking is suppressed. However, it is harder to see this \
numerically, because more  modes must be kept, making the problem somewhat \
harder to integrate.  In Fig. ",
  ButtonBox["7.7",
    ButtonData:>"Fig. 7.7",
    ButtonStyle->"Hyperlink"],
  ", we show an example of a sinusoidal initial condition with eight times \
the previous amplitude. The solution still breaks up into solitons, and the \
spectrum (Fig. ",
  ButtonBox["7.8",
    ButtonData:>"Fig. 7.8",
    ButtonStyle->"Hyperlink"],
  ") still remains peaked in the lower half of the spectral range."
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .10301 m
.00123 .10301 L
.00236 .10302 L
.00365 .10303 L
.00488 .10305 L
.00706 .10311 L
.00942 .10319 L
.01203 .1033 L
.01479 .10345 L
.01975 .1038 L
.02486 .10426 L
.02966 .10479 L
.04057 .10633 L
.0517 .10839 L
.06188 .11069 L
.08481 .11729 L
.1265 .13387 L
.16661 .15447 L
.20928 .17995 L
.25037 .20625 L
.29403 .23415 L
.3361 .25906 L
.37658 .27957 L
.3971 .28823 L
.41963 .29616 L
.44107 .30204 L
.45066 .30411 L
.46109 .30595 L
.46679 .30678 L
.47207 .30743 L
.47701 .30794 L
.48246 .30839 L
.48481 .30855 L
.48734 .30869 L
.48952 .30879 L
.49191 .30888 L
.49446 .30895 L
.49585 .30898 L
.49715 .309 L
.49836 .30901 L
.49947 .30902 L
.50074 .30902 L
.50195 .30901 L
.50316 .309 L
.50446 .30898 L
.50569 .30895 L
.50681 .30892 L
.50955 .30883 L
.51216 .30872 L
.51733 .30841 L
Mistroke
.52296 .30795 L
.53302 .30681 L
.54234 .30539 L
.56393 .30082 L
.58348 .29517 L
.6256 .27857 L
.66614 .25781 L
.70924 .2321 L
.75076 .20552 L
.79069 .17996 L
.83319 .15459 L
.8741 .13359 L
.89494 .12465 L
.91758 .11651 L
.93935 .11039 L
.94974 .1081 L
.95947 .10633 L
.96875 .10498 L
.97875 .10392 L
.98416 .10352 L
.98687 .10336 L
.98984 .10322 L
.99239 .10312 L
.99381 .10308 L
.99511 .10305 L
.99632 .10303 L
.99763 .10302 L
.99886 .10301 L
1 .10301 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
01Kooooo3?l0002:ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002Aooooo`co00004oooool002;o
oooo1ol00024ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Roooool6o`0001oo
oooo000Yooooo`?o0000P_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo
1?l0000Uooooo`00;?ooool4o`0007[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo08Cooooo0ol0000Yooooo`00<?ooool3o`0007Oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo083ooooo1?l0000/ooooo`00<oooool3o`0007oooooo00?o
0000ooooooooool0OOooool3o`00033ooooo000fooooo`?o0000O?ooool00ol0003oooooooooo`1j
ooooo`?o0000<oooool003Wooooo0_l0001jooooo`03o`000?oooooooooo07Oooooo0ol0000foooo
o`00>oooool3o`0007Oooooo0_l0001fooooo`;o0000>Oooool003kooooo0_l0001eooooo`03o`00
0?oooooooooo07?ooooo0_l0000kooooo`00@?ooool2o`0007?ooooo00?o0000ooooooooool0LOoo
ool2o`0003gooooo0012ooooo`;o0000LOooool00ol0003oooooooooo`1_ooooo`;o0000?oooool0
04Cooooo0_l0001_ooooo`03o`000?oooooooooo06gooooo0_l00011ooooo`00A_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0@Oooool004Oooooo
0_l0001/ooooo`03o`000?oooooooooo06[ooooo0_l00014ooooo`00BOooool2o`0006[ooooo00?o
0000ooooooooool0J?ooool2o`0004Kooooo001;ooooo`;o0000J?ooool2o`0006Oooooo0_l00018
ooooo`00COooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo0_l0001:oooo
o`00C_ooool2o`0006Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1:ooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`00013ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?
ooooo`;o00002_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooo
ooooo`0=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o
00003?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0N
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6
o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo0_l00005ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`0000Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41002oooool2o`0001;ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003o
oooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000kooooo0_l0000=ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001co
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool04Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj
^[X00oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`;o00004oooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000006oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooo
oooo410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@017ooooo
0_l0000<ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`;o00008_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool2o`0001Kooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooo
oooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01?ooooo00?o0000ooooooooool01Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Cooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Cooooo0_l00005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`;o00005_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00GOooool2o`0005Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Ioooo
o`00Goooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05;ooooo0_l0001Looooo`00
H?ooool2o`0005?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Looooo`00H_oo
ool2o`00057ooooo00?o0000ooooooooool0Coooool2o`0005oooooo001Tooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Oooooo`005_ooooooo`00
043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o
000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00J_ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool006_ooooo0_l0
0018ooooo`03o`000?oooooooooo04Kooooo0_l0001Xooooo`00KOooool2o`0004Kooooo00?o0000
ooooooooool0A?ooool2o`0006[ooooo001_ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`1Zooooo`00L?ooool2o`0004?ooooo00?o0000oooooooo
ool0@Oooool2o`0006gooooo001booooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`1]ooooo`00Loooool2o`00043ooooo0_l0000oooooo`;o0000L?oo
ool007Gooooo0_l0000nooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0L?ooool0
07Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`;o0000Loooool007So
oooo0_l0000kooooo`03o`000?oooooooooo03Wooooo0_l0001eooooo`00N_ooool2o`0003Wooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1eooooo`00O?ooool2o`0003Oooooo00?o
0000ooooooooool0=_ooool2o`0007Sooooo001nooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0=?ooool2o`0007[ooooo001oooooo`;o0000=?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo07[ooooo0021ooooo`;o0000<_ooool2o`0003;ooooo0_l0001mooooo`00
Poooool2o`00033ooooo00?o0000ooooooooool0;oooool2o`0007oooooo0025ooooo`;o0000;_oo
ool00ol0003oooooooooo`0]ooooo`;o0000POooool008Oooooo0_l0000/ooooo`03o`000?oooooo
oooo02[ooooo0ol00023ooooo`00ROooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Sooooo0_l00026ooooo`00R_ooool2o`0002Wooooo00?o0000ooooooooool09_ooool2o`0008So
oooo002<ooooo`;o00009oooool00ol0003oooooooooo`0Tooooo`;o0000R_ooool008kooooo0_l0
000Uooooo`03o`000?oooooooooo027ooooo0ol0002<ooooo`00T?ooool2o`0002?ooooo0_l0000P
ooooo`;o0000Soooool009;ooooo0_l0000Qooooo`03o`000?oooooooooo01gooooo0_l0002Aoooo
o`00U?ooool3o`0001kooooo00?o0000ooooooooool06_ooool3o`0009?ooooo002Gooooo`?o0000
6oooool00ol0003oooooooooo`0Hooooo`;o0000U_ooool009[ooooo1?l0000Gooooo`03o`000?oo
oooooooo01Kooooo0_l0002Hooooo`00W_ooool3o`0001Cooooo00?o0000ooooooooool04oooool3
o`0009[ooooo002Qooooo`Co00001Oooool5o`0000Kooooo00?o0000ooooooooool03_ooool5o`00
09gooooo002Uooooo`Oo000000?ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`06ooooo`So
0000X_ooool00:_ooooo00?oV9RHo`000?l000004?l0002Zooooo`00[?ooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`oooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go0000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000
/?ooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0/?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000
/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooo
oonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00]oooool00ol0003o^[Zjooooo`2^
ooooo`00]oooool2oc8b<Zoooooo0028ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410H
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP20ooooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o
c<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0P?ooool008Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003o
ooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@4100P?ooool008Wooooo00Ko0000oooooom4
A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooo
oooooooo0000083ooooo0029ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo01[ooooo00Go0000ooooooooooooooooo`000020ooooo`00ROooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@4100P?ooool008Wo
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`20ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0P?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .10766 m
.04057 .11701 L
.08481 .13144 L
.12636 .14794 L
.16632 .1657 L
.20885 .1859 L
.2498 .20596 L
.29331 .22728 L
.33524 .24715 L
.37557 .26501 L
.41848 .28189 L
.4598 .29523 L
.48055 .30052 L
.49953 .30438 L
.50927 .30596 L
.51991 .30734 L
.52574 .30793 L
.53115 .30837 L
.53632 .3087 L
.53921 .30884 L
.54183 .30893 L
.54427 .309 L
.54566 .30903 L
.54695 .30905 L
.54831 .30906 L
.54956 .30906 L
.55025 .30906 L
.551 .30906 L
.55236 .30905 L
.55352 .30904 L
.5548 .30902 L
.55613 .30898 L
.55739 .30895 L
.55963 .30887 L
.56204 .30876 L
.5676 .30841 L
.57344 .30788 L
.57844 .30731 L
.5839 .30655 L
.59469 .30461 L
.60449 .30233 L
.62649 .29526 L
.64663 .2863 L
.66847 .27378 L
.71144 .24113 L
.75281 .2031 L
.79259 .16705 L
.81472 .14956 L
.83495 .13592 L
.8561 .12428 L
Mistroke
.87571 .11591 L
.89569 .10968 L
.90623 .10727 L
.91208 .10618 L
.91746 .10533 L
.92263 .10465 L
.92829 .10404 L
.93398 .10359 L
.93709 .1034 L
.93999 .10326 L
.94131 .10321 L
.94274 .10316 L
.944 .10312 L
.94534 .1031 L
.94655 .10308 L
.94788 .10306 L
.94909 .10305 L
.95022 .10305 L
.95156 .10306 L
.95224 .10306 L
.95298 .10307 L
.95428 .10309 L
.9555 .10311 L
.95825 .10319 L
.96118 .1033 L
.96617 .10357 L
.97077 .1039 L
.98116 .10491 L
.99032 .10611 L
1 .10766 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00087ooooo6?l0000Gooooo`005_ooool3o`0009Co
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1mooooo`Co00006?ooool4o`0001?o
oooo000Iooooo`Go0000T?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo
1?l0000cooooo`007_ooool4o`0008Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo07Kooooo0ol0000gooooo`008_ooool3o`0008Gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo07?ooooo0ol0000jooooo`009Oooool3o`0008gooooo00?o
0000ooooooooool0L?ooool3o`0003gooooo000Xooooo`?o0000R_ooool00ol0003oooooooooo`1]
ooooo`?o0000@?ooool002_ooooo0ol00027ooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool0@Oooool002kooooo0ol00024ooooo`;o0000Joooool2o`0004Cooooo000aooooo`;o0000
P_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04Cooooo000cooooo`?o0000Oooo
ool00ol0003oooooooooo`1Wooooo`;o0000Aoooool003Kooooo0ol0001looooo`03o`000?oooooo
oooo06Gooooo0_l00019ooooo`00>Oooool2o`0007[ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`19ooooo`00>oooool3o`0007Oooooo00?o0000ooooooooool0H_ooool2o`0004co
oooo000nooooo`;o0000MOooool00ol0003oooooooooo`1Pooooo`;o0000C_ooool0043ooooo0_l0
001cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0C_ooool004;ooooo0_l0001a
ooooo`;o0000Goooool00ol0003oooooooooo`1?ooooo`00A?ooool3o`0006kooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`1@ooooo`00Aoooool2o`0006cooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`1Aooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool2o`0001Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oo
oooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00oooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l0000Eooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00004_ooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo0_l0000;ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Moooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`;o00004oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`?o00004Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo01Kooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
01_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000D
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00004?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007_ooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01kooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool000006_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Co
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool2o`0000[ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00006?ooool01Ol@413o
V9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`06
onk^k_lb<S;o0000oc8b<_o^k^ko00006_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`00F_ooool2o`0005Wooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1Looooo`00G?ooool2o`0005Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1Mooooo`00G_ooool3o`0005Cooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1N
ooooo`00HOooool2o`0005;ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Ooooo
o`00Hoooool2o`00053ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Pooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`00
0?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00Jooo
ool2o`0004Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`00KOooool2
o`0004Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Uooooo`00Koooool2o`00
04Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Vooooo`00LOooool2o`0004;o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00Loooool2o`00043ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Xooooo`00MOooool2o`0003kooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`1Yooooo`00Moooool2o`0003cooooo0_l00014
ooooo`03o`000?oooooooooo06[ooooo001iooooo`?o0000>Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo06_ooooo001looooo`;o0000=oooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo06cooooo001nooooo`;o0000=Oooool00ol0003oooooooooo`0oooooo`;o0000
Koooool0083ooooo0_l0000cooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Kooo
ool008;ooooo0_l0000aooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0L?ooool0
08Cooooo0_l0000_ooooo`03o`000?oooooooooo03_ooooo0_l0001cooooo`00Q_ooool3o`0002co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1cooooo`00ROooool2o`0002[ooooo
0_l0000jooooo`03o`000?oooooooooo07Cooooo002;ooooo`;o0000:?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo07Gooooo002=ooooo`;o00009_ooool00ol0003oooooooooo`0f
ooooo`;o0000N?ooool008oooooo0ol0000Sooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0N?ooool009;ooooo0ol0000Pooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0NOooool009Gooooo0ol0000Mooooo`03o`000?oooooooooo03;ooooo0_l0001looooo`00V?oo
ool3o`0001[ooooo00?o0000ooooooooool0<?ooool2o`0007kooooo002Kooooo`;o00006?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07kooooo002Mooooo`?o00005Oooool2o`00
02kooooo0_l00021ooooo`00X?ooool3o`0001;ooooo00?o0000ooooooooool0:oooool2o`0008?o
oooo002Sooooo`;o00004?ooool00ol0003oooooooooo`0Xooooo`?o0000QOooool00:Gooooo0ol0
000=ooooo`03o`000?oooooooooo02Kooooo0_l00028ooooo`00Z?ooool5o`0000Sooooo00?o0000
ooooooooool08oooool3o`0008[ooooo002]ooooo`Go00000oooool00ol0003oooooooooo`0Poooo
o`?o0000SOooool00:[ooooo1Ol00003ooooo`Co00007oooool3o`00093ooooo002Zooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool6o`0001Cooooo1_l0002Cooooo`00Zoooool00onHV9So8B4Q
onk^kP07ooooo`?o00000ooooolDo`0009Wooooo002/ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool0/?ooool00:gooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2`
ooooo`00[_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:[ooooo1Ol00006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_oo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Co
c<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_oo
ool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100
^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`00
0?l@413oZJVY0;Wooooo003oooooofWooooo002gooooo`03o`000?nj^[[ooooo0:kooooo002goooo
o`;o<S8b[oooool008Sooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`00083ooooo0029ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooo
ooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A020ooooo`00ROoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h0
POooool008Wooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00002oooool00onHV9So8B4Qonk^kP20ooooo`00ROooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo07oooooo0029ooooo`06o`000?n7
QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool0O_ooool008Wo
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RH
oa0@4020ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`0P?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .11772 m
.04057 .12901 L
.08481 .14333 L
.12636 .15812 L
.16632 .17317 L
.20885 .18976 L
.2498 .20599 L
.29331 .22324 L
.33524 .23957 L
.37557 .25475 L
.41848 .26997 L
.4598 .2833 L
.49953 .29439 L
.52162 .29957 L
.54183 .30354 L
.55181 .30518 L
.5627 .30669 L
.57299 .30783 L
.57796 .30827 L
.58254 .3086 L
.58787 .3089 L
.59068 .30902 L
.5921 .30907 L
.59364 .30912 L
.59499 .30915 L
.59621 .30917 L
.59745 .30919 L
.59862 .3092 L
.59998 .30921 L
.60124 .3092 L
.60262 .3092 L
.60332 .30919 L
.60409 .30918 L
.60532 .30916 L
.60662 .30912 L
.60894 .30905 L
.61144 .30895 L
.61417 .3088 L
.61907 .30844 L
.62363 .30799 L
.62893 .30734 L
.63468 .30643 L
.64511 .30425 L
.65526 .30135 L
.66463 .29789 L
.68433 .28754 L
.69552 .27931 L
.706 .26949 L
.7273 .24164 L
.74676 .20909 L
Mistroke
.76843 .1739 L
.78851 .14822 L
.80796 .13047 L
.81883 .12311 L
.82867 .11777 L
.83852 .11348 L
.84892 .10994 L
.85436 .10845 L
.86032 .10706 L
.87079 .1052 L
.87631 .10449 L
.88154 .10397 L
.88623 .10362 L
.88887 .10347 L
.89132 .10336 L
.89258 .10332 L
.89394 .10328 L
.89511 .10325 L
.89639 .10323 L
.89713 .10321 L
.89781 .10321 L
.89854 .1032 L
.89931 .10319 L
.90003 .10319 L
.90071 .10319 L
.90198 .1032 L
.90336 .10321 L
.90405 .10322 L
.90481 .10323 L
.90741 .10329 L
.90888 .10334 L
.91045 .10339 L
.91329 .10352 L
.91883 .10384 L
.92396 .10423 L
.93557 .10541 L
.94581 .10676 L
.95669 .10848 L
.99629 .1168 L
1 .11772 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007;ooooo6Ol0000Uooooo`00[Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo06gooooo1Ol0000Iooooo`Ko00007oooool00:kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1[ooooo`;o00009?ooool5o`0001[ooooo
002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Xooooo`?o0000
:oooool4o`0001Kooooo000Fooooo`?o0000TOooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0IOooool3o`0003;ooooo0ol0000Cooooo`006Oooool3o`0009Wooooo00?o
0000ooooooooool0Hoooool2o`0004_ooooo000Looooo`?o0000U_ooool00ol0003oooooooooo`1Q
ooooo`;o0000COooool001oooooo0ol0002Cooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0COooool002;ooooo1?l0002?ooooo`;o0000H?ooool00ol0003oooooooooo`1>ooooo`00
9_ooool3o`0008cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1?ooooo`00:Ooo
ool4o`0008Sooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1@ooooo`00;Oooool3
o`0008Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Aooooo`00<?ooool3o`00
08;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Booooo`00<oooool3o`0007oo
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Cooooo`00=_ooool3o`0007cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Dooooo`00>Oooool2o`0007[ooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`1Dooooo`00>oooool3o`0007Oooooo0_l0001I
ooooo`03o`000?oooooooooo05Gooooo000nooooo`;o0000MOooool00ol0003oooooooooo`1Goooo
o`03o`000?oooooooooo05Kooooo0010ooooo`?o0000L_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo05Oooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^o`000?l0003o0000
onk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0Oooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool00ol0003oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00CoMgMgoiRHV?ooooooV9RH
0_l0000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03
o`000?oooooooooo01Kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l0
0006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooo`000002o`0000oooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko
00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400K
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Oo410@oooooooooooooooooa0@4?oooooo000001gooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000000Cooooo0_l0000Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01cooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooooooool2o`0001gooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00005Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`03ogMgMomVIVKooooo00;ooooo00Co0000oooooooooooooooo0_l0000Loooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002Oooool3o`0001?ooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@01kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Nooooo`05o`000?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Looooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`;o00003Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9Soooooo`000?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`?o0000
2_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooo
oooo01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h06oooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00F?ooool2o`0005_ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`1Nooooo`00F_ooool3o`0005Sooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`1Oooooo`00GOooool3o`0005Gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1Oooooo`00H?ooool2o`0005?ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`1Pooooo`00H_ooool3o`00053ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1Pooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000002o`0000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool006cooooo0_l00017ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
Hoooool006kooooo0ol00014ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Hooo
ool0077ooooo0_l00012ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0I?ooool0
07?ooooo0_l00010ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0I?ooool007Go
oooo0ol0000mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool007Sooooo
0ol0000jooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0I_ooool007_ooooo0_l0
000hooooo`;o0000B?ooool00ol0003oooooooooo`1Vooooo`00OOooool3o`0003Gooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00P?ooool2o`0003?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1Wooooo`00P_ooool3o`00033ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`1Xooooo`00QOooool3o`0002gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`1Xooooo`00R?ooool2o`0002_ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`1Yooooo`00R_ooool3o`0002Sooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`1Zooooo`00SOooool2o`0002Kooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`1[ooooo`00Soooool3o`0002?ooooo0_l00012ooooo`03o`000?oooooooooo06co
oooo002Booooo`?o00008?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo06cooooo
002Eooooo`?o00007Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo06gooooo002H
ooooo`?o00006_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06kooooo002Koooo
o`?o00005oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06oooooo002Nooooo`?o
00005?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo073ooooo002Qooooo`?o0000
4Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo077ooooo002Tooooo`?o00003_oo
ool00ol0003oooooooooo`0jooooo`;o0000M?ooool00:Oooooo1?l0000:ooooo`;o0000>_ooool0
0ol0003oooooooooo`1dooooo`00Zoooool5o`0000Gooooo00?o0000ooooooooool0=oooool2o`00
07Oooooo002`ooooo`Co000000?oooooo`000?ooool0=_ooool2o`0007Wooooo002dooooo`Co0000
=?ooool00ol0003oooooooooo`1iooooo`00]Oooool00ol0003oooooooooo`03o`0002oooooo0_l0
001looooo`00]Oooool00ol0003oooooooooo`03ooooo`Go0000:?ooool2o`0007kooooo002Zoooo
o`Go00001_ooool00ol0003oooooooooo`08ooooo`Go00008?ooool3o`00083ooooo002Zooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0=ooooo`Oo00004oooool6o`00
08?ooooo002[ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Doooooa?o0000ROooool00:cooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`2`ooooo`00[Oooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo
00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo
00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wo
oooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;Oooooo00?o
0000okZj^_ooool0[_ooool00;Oooooo0_lb<S:_ooooo`00R?ooool2o`000006oa0@4?oooooooooo
oa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Joooo
o`;o000000?o410@ooooooooool0O_ooool008Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`1oooooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`00
0?oooooooooo01[ooooo1Ol00020ooooo`00ROooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`00087ooooo0029oooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00CogMgMoeEEEOoo
oooo0000POooool008Wooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00006_oo
ool00omgMgOoc<c<o`000021ooooo`00ROooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooooooo
ool06oooool00oo^k^koA4A4o`000021ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7
Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003o
ooooooooo`0Looooo`03ogMgMol0003ooooo083ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1282 m
.04057 .13934 L
.08481 .15247 L
.12636 .16547 L
.16632 .17837 L
.20885 .19238 L
.2498 .206 L
.29331 .22048 L
.33524 .23429 L
.37557 .24731 L
.41848 .2607 L
.4598 .27296 L
.49953 .28391 L
.54183 .29428 L
.58254 .30234 L
.59315 .30421 L
.59876 .30525 L
.60473 .3063 L
.60769 .30674 L
.61047 .30709 L
.61297 .30733 L
.61438 .30744 L
.61567 .30751 L
.61689 .30757 L
.61803 .30761 L
.61927 .30764 L
.62061 .30765 L
.62128 .30765 L
.62201 .30765 L
.62334 .30765 L
.62463 .30763 L
.62583 .30762 L
.62706 .30761 L
.62836 .3076 L
.62948 .30761 L
.63069 .30762 L
.632 .30766 L
.63274 .30769 L
.63341 .30772 L
.63471 .3078 L
.63594 .30791 L
.6383 .30819 L
.64049 .30854 L
.64542 .30963 L
.65085 .31103 L
.65351 .31163 L
.65467 .31183 L
.65593 .31201 L
.65724 .31214 L
.65849 .31219 L
Mistroke
.65918 .31218 L
.65991 .31215 L
.66123 .31203 L
.66199 .31191 L
.66281 .31175 L
.66429 .31136 L
.66573 .31086 L
.66706 .31029 L
.67662 .30408 L
.67914 .30229 L
.68188 .30061 L
.68314 .29999 L
.68447 .29946 L
.68561 .29912 L
.68686 .2989 L
.68763 .29884 L
.68832 .29884 L
.68909 .29891 L
.6899 .29905 L
.69126 .29946 L
.69203 .29978 L
.69274 .30015 L
.69533 .30195 L
.6981 .30459 L
.70319 .31056 L
.70597 .31369 L
.70733 .31498 L
.70857 .31594 L
.70986 .31668 L
.71125 .31712 L
.71197 .31718 L
.71276 .3171 L
.7135 .31688 L
.71419 .31655 L
.71538 .31566 L
.71669 .3142 L
.71807 .31212 L
.71936 .30964 L
.72228 .30215 L
.72497 .2932 L
.73103 .26756 L
.74199 .21583 L
.74734 .19374 L
.7522 .17673 L
.76179 .15154 L
.76706 .14159 L
.77205 .1341 L
.78247 .12283 L
.78835 .11834 L
.79377 .11503 L
Mistroke
.79867 .11259 L
.80393 .11044 L
.81345 .10752 L
.81925 .10623 L
.82476 .10528 L
.82971 .10462 L
.83511 .10408 L
.8378 .10388 L
.8407 .10371 L
.84344 .10359 L
.84474 .10354 L
.84596 .10351 L
.84715 .10348 L
.84824 .10346 L
.84944 .10345 L
.85074 .10344 L
.85198 .10343 L
.85333 .10344 L
.8546 .10345 L
.85578 .10346 L
.85705 .10349 L
.8584 .10352 L
.86086 .10359 L
.86379 .10371 L
.86647 .10384 L
.87199 .10418 L
.87781 .10464 L
.88784 .10565 L
.89855 .10698 L
.91785 .10995 L
.96144 .11873 L
1 .1282 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006Cooooo5ol0000eooooo`00[Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo063ooooo1?l0000Gooooo`Go0000<?ooool00:kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Mooooo`?o00008?ooool5o`0002_ooooo
002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Jooooo`?o0000
:?ooool5o`0002Kooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo02kooooo1Ol0000Qooooo`00]Oooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo03Cooooo1?l0000Mooooo`00]Oooool00ol0003oooooooooo`1F
ooooo`;o0000>oooool4o`0001Wooooo002eooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool0?oooool4o`0001Gooooo000Fooooo`?o0000W?ooool2o`0005Gooooo00?o0000oooooooo
ool0A?ooool2o`0001?ooooo000Iooooo`Go0000Uoooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo05[ooooo000Nooooo`Co0000Toooool00ol0003oooooooooo`1Cooooo`03o`000?oo
oooooooo05[ooooo000Rooooo`Co0000Soooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo05_ooooo000Vooooo`?o0000S?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
05_ooooo000Yooooo`Co0000R?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05_o
oooo000]ooooo`?o0000QOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05cooooo
000`ooooo`Co0000POooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05gooooo000d
ooooo`?o0000O_ooool2o`00057ooooo00?o0000ooooooooool0GOooool003Oooooo0ol0001koooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0G_ooool003[ooooo0ol0001hooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool0G_ooool001Gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`03oiRHV?l@413o000000?o00000_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooo
oooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool01_l@413o^[ZjoooooomgMgOo<S8booooo`?o000000CoV9RHoooooonHV9SoMgMg
6oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Noooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL06oooool01Ol@413o
^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooo
oa0@4003o`000003oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
o`000?oooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Mooooo`03ojVYZOl@413ooooo
00;ooooo00Co0000oooooooooooooooo0_l0000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001cooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;ooooo00?o0000oooooooo
ool07?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool01?m4
A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj^[X0
0oooool01_l0003ooooooooooooooooo0000ooooo`?o00006_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Koooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001?ooool3o`0001Sooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Nooooo`05o`000?ooooooooooooooool000000oooool00ol@413ooooooooo
o`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`?o00004Oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05o`000?nHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0:ooooo`?o00003_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Noooo
o`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;o
k^k^6oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0M
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00E?ooool3
o`0005kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00Eoooool4o`00
05[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00Foooool3o`0005Oo
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00G_ooool3o`0005Cooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00HOooool3o`00057ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1Rooooo`005_ooooooo`00043o00004oooool0
01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000002o`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`Co00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo001]ooooo`?o0000AOooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo06?ooooo001`ooooo`?o0000@_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo06?ooooo001cooooo`?o0000?oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo06?ooooo001fooooo`?o0000??ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
06Cooooo001iooooo`?o0000>Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Co
oooo001looooo`?o0000=_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Cooooo
001oooooo`Co0000<_ooool2o`0004[ooooo00?o0000ooooooooool0I?ooool008?ooooo0ol0000_
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008Kooooo0ol0000/oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008Wooooo0ol0000Yooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008cooooo0ol0000Vooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008oooooo0ol0000Sooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0IOooool009;ooooo0ol0000Pooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0I_ooool009Gooooo0ol0000Mooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0I_ooool009Sooooo0ol0000Jooooo`;o0000B?ooool00ol0003o
ooooooooo`1Vooooo`00Voooool3o`0001Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`1Vooooo`00W_ooool3o`0001Cooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`1Wooooo`00XOooool3o`00017ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1W
ooooo`00Y?ooool3o`0000kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Woooo
o`00Yoooool4o`0000[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00
Zoooool5o`0000Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00/?oo
ool4o`000003ooooool0003ooooo04Oooooo00?o0000ooooooooool0Ioooool00;Cooooo1?l00015
ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooooooo00Go0000@?ooool00ol0
003oooooooooo`1Xooooo`00]Oooool00ol0003oooooooooo`05ooooo`Co0000??ooool00ol0003o
ooooooooo`1Xooooo`00]Oooool00ol0003oooooooooo`09ooooo`Co0000>?ooool00ol0003ooooo
ooooo`1Xooooo`00]Oooool00ol0003oooooooooo`0=ooooo`Go0000<oooool00ol0003ooooooooo
o`1Xooooo`00]Oooool00ol0003oooooooooo`0Booooo`Co00008Oooool4o`0000Wooooo00?o0000
ooooooooool0JOooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo01Kooooo1?l0000Loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Yoooo
o`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool06_ooool6o`00
01Cooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0JOooool00:_o
oooo00?oV9RHob4Q8Oo^k^h01oooool3o`00023ooooo3Ol00006ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Zooooo`00[?ooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo02gooooo1_l0000;ooooo`05o`000?ooooooooooooooool0
0000KOooool00:gooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0nooooo`;o0000
00?oooooo`000?l00000KOooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`10ooooo`;o0000K_ooool00:[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`
ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoo
oooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00
Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[o
oooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o0000
0;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;Oooooo
00?o0000okZj^_ooool0[_ooool00;Oooooo0_lb<S:_ooooo`00R?ooool2o`000006oa0@4?oooooo
oooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0P?ooool008Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009oooo
o`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q083ooooo0029ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo013ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000083ooooo0029
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@20ooooo`00ROooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0Jooooo`05o`000?mEEEGo0000oa0@4?o<c<`0P?ooool008Wooooo
00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00006Oooool00omEEEGoQhN7ooooo`22
ooooo`00ROooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@
oiRHV022ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`04olc<
c?m4A4Co0000oa0@483ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13732 m
.04057 .14768 L
.08481 .1595 L
.12636 .17094 L
.16632 .18217 L
.20885 .19426 L
.2498 .20599 L
.29331 .21847 L
.33524 .23042 L
.37557 .24175 L
.41848 .25353 L
.4598 .26465 L
.49953 .2757 L
.50494 .27692 L
.50801 .27743 L
.51085 .27781 L
.51606 .27831 L
.51873 .27851 L
.52014 .27861 L
.52162 .27874 L
.52298 .27888 L
.52446 .27908 L
.52708 .27955 L
.52836 .27986 L
.52974 .28025 L
.53222 .28111 L
.53725 .28341 L
.54183 .28593 L
.54669 .28866 L
.54935 .29001 L
.55184 .29105 L
.55314 .29148 L
.55453 .29183 L
.55529 .29197 L
.55608 .29208 L
.55676 .29214 L
.5575 .29217 L
.55881 .29212 L
.55955 .29205 L
.56021 .29195 L
.56151 .29167 L
.56274 .29132 L
.56728 .28948 L
.57217 .28723 L
.5736 .28666 L
.57497 .2862 L
.57619 .28588 L
.57753 .28565 L
.57879 .28555 L
.58013 .28561 L
Mistroke
.5814 .28584 L
.58254 .28619 L
.58386 .28679 L
.58507 .28752 L
.5878 .28985 L
.59021 .29261 L
.59275 .2961 L
.59834 .30462 L
.60107 .3084 L
.60226 .30981 L
.60356 .31114 L
.60475 .31214 L
.60585 .31285 L
.6069 .31331 L
.60802 .31355 L
.60919 .31352 L
.61029 .31322 L
.6115 .31258 L
.6128 .31153 L
.61403 .31018 L
.61538 .30836 L
.61809 .30369 L
.62293 .29334 L
.6256 .28757 L
.6285 .28218 L
.62983 .2802 L
.63123 .27853 L
.63243 .27751 L
.63375 .27684 L
.63503 .27669 L
.6362 .27701 L
.63754 .27794 L
.63882 .27941 L
.64 .28127 L
.64109 .28344 L
.64356 .28989 L
.64902 .31049 L
.65189 .32313 L
.65491 .33579 L
.65757 .3448 L
.65829 .34675 L
.65907 .34853 L
.65974 .34981 L
.66047 .3509 L
.66185 .35206 L
.66314 .35205 L
.66441 .35096 L
.66557 .34902 L
.6667 .34631 L
.66791 .34253 L
Mistroke
.6701 .33361 L
.67508 .30611 L
.67989 .27655 L
.68244 .26251 L
.68515 .25016 L
.68672 .24456 L
.68815 .24064 L
.68884 .23916 L
.68959 .23788 L
.69094 .23641 L
.6916 .23611 L
.69233 .23611 L
.6931 .23649 L
.69381 .23719 L
.69508 .23932 L
.69644 .24288 L
.69777 .24766 L
.69922 .25438 L
.70185 .27068 L
.70677 .31399 L
.71153 .3636 L
.71402 .38713 L
.71538 .39781 L
.71665 .40587 L
.71738 .4096 L
.71805 .41232 L
.71879 .41457 L
.71958 .41602 L
.72097 .41613 L
.72227 .41338 L
.72359 .40783 L
.72481 .40039 L
.72755 .37651 L
.73305 .31103 L
.73895 .2406 L
.74181 .21257 L
.74452 .19039 L
.74699 .1737 L
.74961 .15912 L
.75218 .14756 L
.75451 .1391 L
.75905 .12706 L
.7616 .1223 L
.76435 .1183 L
.76933 .11304 L
.77195 .11098 L
.77483 .1092 L
.77783 .10782 L
.78063 .10689 L
.78325 .10622 L
Mistroke
.78564 .10572 L
.78819 .10523 L
.79101 .10476 L
.79227 .10458 L
.79362 .10441 L
.7948 .10429 L
.79608 .10418 L
.79682 .10413 L
.79752 .10409 L
.79888 .10403 L
.80013 .104 L
.80145 .10399 L
.8027 .10398 L
.80406 .10397 L
.80534 .10397 L
.80651 .10396 L
.80873 .10394 L
.80995 .10393 L
.8111 .10392 L
.81247 .10393 L
.81372 .10394 L
.81489 .10397 L
.81616 .10401 L
.81756 .10408 L
.81904 .10417 L
.82171 .10437 L
.82756 .10479 L
.83012 .10495 L
.83292 .10514 L
.83771 .1056 L
.84275 .1062 L
.85336 .10741 L
.87255 .1102 L
.91512 .11793 L
.95611 .12679 L
.99967 .13723 L
1 .13732 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005Sooooo4_l00016ooooo`00[Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo05Gooooo0ol0000Booooo`Oo0000?oooool00:kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`;o00007?ooool7o`0003Sooooo
002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Booooo`;o0000
9?ooool7o`00037ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo02_ooooo1Ol0000/ooooo`00]Oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo033ooooo1Ol0000Wooooo`00]Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo03Kooooo1?l0000Sooooo`00]Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo03_ooooo1?l0000Oooooo`00]Oooool2o`00053ooooo00?o0000oooooooo
ool0?oooool5o`0001[ooooo002eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
A?ooool5o`0001Gooooo000Fooooo`?o0000W?ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo04[ooooo0_l0000Cooooo`006Oooool3o`0009Wooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`1Oooooo`007?ooool3o`0009Kooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1Oooooo`007oooool3o`0009?ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1Pooooo`008_ooool4o`0008oooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1Pooooo`009_ooool3o`0008cooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1Pooooo`00:Oooool4o`0008Sooooo0_l0001=ooooo`03o`000?oooooooooo067ooooo000]oooo
o`?o0000QOooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo067ooooo000`ooooo`Co
0000POooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo067ooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05?ooool5o`000006oooooonHV9So
410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool5o`0000;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hKooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool4o`000003ogMgMolb<S;ooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00Ko0000ogMgMonH
V9SooooooiRHV?mgMgLKooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko
00001Oooool4o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool04Oooool6o`0000?o
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo00?o
V9RHob4Q8Oo^k^h00oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo01gooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003o
oooooooooooooooo000001gooooo00CoZJVYoa0@4?oooooooooo0ol00002ooooo`03o`000?oooooo
oooo01_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00onHV9So
8B4Qonk^kP02ooooo`;o00000oooool00ol0003oooooooooo`0Looooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`03o`000?oooooo000000;o0000
7_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`04ogMgMomVIVKo
ooooooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ol0000L
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`;o00008_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003oooooooooool0003o410@
00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool4o`0001Co
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`0=o`00
0?nj^[[ooooooiRHV?l@413oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0ol0000Aooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool03OnHV9So410@o`000?lQ8B7oc<c<ooooool0
003oooooonk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`00DOooool3o`00067ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`1Rooooo`00E?ooool3o`0005kooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1Rooooo`00Eoooool4o`0005[ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`1Rooooo`00Foooool5o`0005Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1R
ooooo`00H?ooool4o`00057ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Soooo
o`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool4o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00Koooool3
o`0004?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00L_ooool4o`00
03oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00M_ooool3o`0003co
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00NOooool3o`0003Wooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00O?ooool3o`0003Kooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`00Ooooool4o`0003;ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`00Poooool3o`0002oooooo0_l0001:oooo
o`03o`000?oooooooooo06Cooooo0026ooooo`?o0000;?ooool00ol0003oooooooooo`0iooooo`?o
00003Oooool00ol0003oooooooooo`1Tooooo`00ROooool3o`0002Wooooo00?o0000ooooooooool0
>Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo06Cooooo002<ooooo`Co00009Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0I?oo
ool0093ooooo1Ol0000Pooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00003Ooo
ool00ol0003oooooooooo`1Tooooo`00UOooool5o`0001_ooooo00?o0000ooooooooool0>?ooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0I?ooool009[ooooo1?l0000G
ooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo06Cooooo002Nooooo`?o00005?ooool00ol0003oooooooooo`0hooooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`1Tooooo`00XOooool3o`00017ooooo0_l0000h
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1T
ooooo`00Y?ooool3o`0000kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0IOooool00:Oooooo1?l0000:ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo06Gooooo002[ooooo`?o00001oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Uooooo`00[_oo
ool3o`0000Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0IOooool00;7ooooo0ol000000ooooooo0000ooooo`0g
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1U
ooooo`00]?ooool9o`0002;ooooo0ol0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Uooooo`00]Oooool00ol0003oooooooooo`04ooooo`Go
00007Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Uooooo`00]Oooool2o`0000[ooooo00?o0000oooooooo
ool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06Gooooo002eooooo`03o`000?oooooooooo00[o
oooo0_l00007ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Go
oooo002eooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`;o00001_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOooool00;Gooooo00?o
0000ooooooooool03_ooool3o`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo06Gooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Kooooo002eoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06Kooooo002Zooooo`Go00001_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Vooooo`00
Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00:_ooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0001gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06Kooooo002/ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool07_ooool4o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00:gooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0Oooooo`;o00002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1V
ooooo`00[_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0I_ooool00:[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0I_ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00;Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Vooooo`00]Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06Oooooo002eooooo`;o0000;oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`00]Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Oooooo002eooooo`03o`000?oooooooooo
02kooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Ioooool00;Gooooo00?o0000ooooooooool0;oooool01?l0003oooooooooool0000=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool00;Gooooo00?o0000oooo
ooooool0;oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Ioooool00;Gooooo00?o0000ooooooooool0<?ooool3o`0000gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Wooooo`00]Oooool00ol0003oooooooooo`0`ooooo`;o
00003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Oooooo002eooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Wooooo`00]Ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Iooo
ool00;Gooooo0_l00011ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool0
0;Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Sooooo002eooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Xooooo`00]Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0J?ooool00;Gooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooooooo047ooooo00Go0000
ooooooooooooooooo`00001Zooooo`00]Oooool00ol0003oooooooooo`11ooooo`05o`000?oooooo
ooooooooool00000J_ooool00;Gooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooo
oooo000006[ooooo002eooooo`;o0000@_ooool01Ol0003ooooooooooooooooo000006[ooooo002e
ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo0000Joooool00;Gooooo00?o0000
ooooooooool0@Oooool01?l0003oooooooooool0001[ooooo`00]Oooool00ol0003oooooooooo`11
ooooo`04o`000?ooooooooooo`0006_ooooo002eooooo`03o`000?oooooooooo047ooooo00Co0000
oooooooooooo0000Joooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooool00000Joooool00:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooo000006_ooooo002Zooooo`Go00001_ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooo000006_ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol00012ooooo`03o`000?oooooo000006_ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00Zoooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0/?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo
00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wo
oooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@2iooooo`00oooooomYooooo`00]oooool00ol0003o^[Zjooooo`2^ooooo`00]oooool2
oc8b<Zoooooo0028ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c020
ooooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@4100
3?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B40P?ooool008Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04
o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Joooo
o`05o`000?ooooooooooooooool00000P?ooool008Wooooo00Ko0000oooooom4A4CoA4A4ooooool0
0009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Olb<S;oV9RHoooooonHV9So<S8b083o
oooo0029ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go
c<c<o`000?l0003o0000olc<c020ooooo`00ROooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wo
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@4100P?ooool008Wooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_oooooo^[Zjo`000020ooooo`00
R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0P?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14477 m
.04057 .15425 L
.08481 .16497 L
.12636 .17518 L
.16632 .18511 L
.20885 .19577 L
.2498 .20607 L
.29331 .21687 L
.33524 .22718 L
.37557 .23811 L
.38062 .23915 L
.38541 .23991 L
.38805 .24021 L
.39094 .2405 L
.39359 .2408 L
.39599 .24115 L
.39891 .24173 L
.40201 .24251 L
.40761 .24428 L
.41848 .24915 L
.42345 .2516 L
.42617 .2527 L
.4287 .25349 L
.43003 .25381 L
.43145 .25408 L
.43226 .2542 L
.43303 .25429 L
.43371 .25436 L
.43446 .25441 L
.4358 .25447 L
.43647 .25447 L
.43721 .25446 L
.43853 .25439 L
.43976 .25428 L
.4409 .25414 L
.44214 .25394 L
.44439 .25346 L
.44698 .25281 L
.44933 .25221 L
.4507 .25191 L
.45145 .25176 L
.45215 .25165 L
.45339 .2515 L
.45476 .25143 L
.45603 .25147 L
.45719 .2516 L
.45853 .25186 L
.4598 .25222 L
.46104 .25268 L
.46237 .25329 L
Mistroke
.46474 .25469 L
.47013 .25916 L
.47573 .26527 L
.47847 .26838 L
.48099 .27098 L
.48338 .27299 L
.48458 .27377 L
.4859 .27443 L
.48722 .27487 L
.48796 .27501 L
.48864 .27508 L
.48995 .27503 L
.49119 .27476 L
.49231 .27435 L
.49349 .27375 L
.49562 .27224 L
.4979 .2701 L
.50042 .26723 L
.5056 .26053 L
.50843 .2571 L
.5098 .25568 L
.51105 .25459 L
.51221 .25377 L
.5133 .25321 L
.51445 .25285 L
.5157 .25276 L
.51698 .25299 L
.51834 .25362 L
.5195 .25448 L
.52078 .25575 L
.52225 .25764 L
.52364 .25984 L
.52624 .26498 L
.53211 .28027 L
.53714 .29451 L
.53851 .29795 L
.54 .3012 L
.54129 .30353 L
.54197 .30456 L
.54269 .30548 L
.54402 .30669 L
.54526 .3072 L
.54599 .30722 L
.54668 .30704 L
.54797 .3062 L
.54918 .30482 L
.55029 .30305 L
.55281 .29749 L
.5553 .29022 L
.55804 .2808 L
Mistroke
.56357 .26042 L
.56604 .25221 L
.56838 .24571 L
.56967 .24284 L
.57036 .24155 L
.57108 .24038 L
.57237 .23883 L
.57356 .238 L
.57477 .23781 L
.57608 .23836 L
.57732 .23962 L
.57846 .24143 L
.57949 .24361 L
.58062 .24658 L
.5829 .25441 L
.58554 .26636 L
.58841 .28238 L
.59363 .31583 L
.59609 .33094 L
.59744 .33825 L
.59871 .3442 L
.59987 .34873 L
.60094 .35197 L
.60213 .35444 L
.60341 .35567 L
.60469 .35537 L
.60605 .35333 L
.60735 .34982 L
.60852 .34539 L
.61139 .33017 L
.61411 .31162 L
.61947 .27059 L
.62232 .25012 L
.62537 .23134 L
.62679 .22412 L
.62813 .21827 L
.62944 .21358 L
.63065 .21016 L
.6318 .2078 L
.63301 .20624 L
.63437 .20567 L
.63559 .20625 L
.63627 .20702 L
.63699 .20819 L
.63827 .21122 L
.63965 .21583 L
.64116 .22251 L
.64387 .23888 L
.6464 .25919 L
.65569 .36124 L
Mistroke
.65824 .38691 L
.65963 .39819 L
.66094 .4064 L
.66205 .41131 L
.66324 .41429 L
.66457 .41466 L
.66578 .41226 L
.66646 .40981 L
.66718 .40633 L
.66848 .39799 L
.67003 .38496 L
.67143 .37073 L
.67679 .30515 L
.6818 .24631 L
.68443 .22097 L
.68721 .19934 L
.6897 .18455 L
.69112 .17809 L
.69244 .17333 L
.69365 .17003 L
.69476 .16794 L
.69604 .16659 L
.69725 .16639 L
.69839 .16715 L
.6996 .16897 L
.70064 .17136 L
.70178 .17492 L
.703 .17982 L
.70432 .18643 L
.70671 .20217 L
.70923 .22458 L
.71191 .25576 L
.71675 .32908 L
.72203 .4155 L
.72347 .43512 L
.725 .45198 L
.72631 .46247 L
.72705 .46663 L
.72774 .46926 L
.72851 .47073 L
.72925 .47067 L
.73062 .46676 L
.73139 .46247 L
.7321 .45721 L
.73371 .4411 L
.73644 .40315 L
.73935 .35417 L
.74448 .26823 L
.74989 .20019 L
.75258 .17641 L
Mistroke
.75553 .15638 L
.75822 .1425 L
.76072 .13257 L
.76223 .12776 L
.76367 .12397 L
.76636 .11859 L
.76787 .11637 L
.76926 .11471 L
.77241 .1119 L
.77493 .11024 L
.7773 .10895 L
.77989 .10783 L
.78135 .10736 L
.78269 .10705 L
.78401 .10684 L
.78523 .10673 L
.78657 .10669 L
.78732 .1067 L
.78801 .10673 L
.78939 .1068 L
.79088 .10689 L
.79161 .10694 L
.7923 .10697 L
.7936 .10702 L
.79479 .10704 L
.79608 .10705 L
.79746 .10704 L
.79875 .10704 L
.79985 .10705 L
.80108 .10709 L
.80235 .10716 L
.80356 .10727 L
.80489 .10744 L
.8063 .10765 L
.80882 .10809 L
.8145 .10889 L
.8366 .11192 L
.87657 .11876 L
.91911 .12704 L
.96006 .13577 L
1 .14477 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0EOoooolAo`0004[ooooo002^ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0?ooooo`Go0000AOooool00:[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
5Oooool5o`00043ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo01_ooooo1?l0000looooo`00]Oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo01oooooo1Ol0000gooooo`00]Oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo02Gooooo1ol0000`ooooo`00]Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo02gooooo1Ol0000[ooooo`00]Oooool2o`00057ooooo00?o0000oooooooo
ool0<_ooool5o`0002Kooooo002eooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
=oooool4o`0002;ooooo002eooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0>ooo
ool4o`0001kooooo002eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0@?ooool5
o`0001Wooooo002eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0AOooool4o`00
01Gooooo000Fooooo`?o0000W?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04Wo
oooo0_l0000Cooooo`006Oooool5o`0009Oooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1Nooooo`007_ooool4o`0009?ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1Oooooo`008_ooool4o`0008oooooo0_l0001?ooooo`03o`000?oooooooooo05oooooo000Voooo
o`Go0000R_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05oooooo000[ooooo`Go
0000QOooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05oooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h04?ooool4o`0000Kooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQkooooo00?o0000ooooooooool07oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^01_ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`?o00000oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0000Sooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool8o`0000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`?o00002?ooool00onHV9So8B4Qonk^kP04ooooo`05o`000?oooooo
ooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
6Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000006_ooool3o`000003ojVYZOl@413ooooo
00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000oooooo00Co0000oooooooooooo00002Oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01cooooo00?o410@o`000?l000000_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
01cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool01?l0003ooooo
ooooool0000:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Moooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41007Oooool01?nj^[[o8B4Qooooooooool5o`000003
oa0@4?oooooooooo01gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo0_l0000R
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?ooooo`05o`000?oo
ooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o410@oooooooo
ool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`04ogMgMonHV9SooooooiRHV0Co00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003oV9RHoooooonHV9SoMgMg01_o
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool4o`0001Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Oooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go0000oc8b<_l0
003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
001>ooooo`Go0000H_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Qooooo`00Doooool4o`0005kooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0HOooool005Oooooo1?l0001Jooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo001Kooooo`Go
0000EOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Qooooo`00H?ooool4o`00057ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
HOooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00ol00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo1?l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo001_ooooo`?o0000@oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067o
oooo001booooo`Co0000?oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067o
oooo001fooooo`Go0000>_ooool00ol0003oooooooooo`0Vooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0HOooool007_ooooo1?l0000fooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Qooooo`00Ooooool4o`0003;ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo0023ooooo`?o0000;oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0HOooool0
08Kooooo0ol0000/ooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
067ooooo0029ooooo`?o0000:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Rooooo`00S?ooool8o`00027ooooo
00?o0000ooooooooool05?ooool2o`0000oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Rooooo`00U?ooool3o`0001kooooo00?o0000ooooooooool04oooool01?l0003ooooooooo
ool0000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool009Oooooo0ol0
000Kooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool009[ooooo0ol0000Hooooo`03o`000?oo
oooooooo01?ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0H_ooool009gooooo0_l00004ooooo`Oo00002oooool01?l0003ooooooooo
ooooool3o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool009oooooo1?l00007ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06;ooooo002[ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool00:cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0H_ooool00:gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Rooooo`00[_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Rooooo`00[ooo
ool01?l0003oooooooooooooool3o`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Rooooo`00/?ooool4o`000003ooooool0003ooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Rooooo`00]Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0H_ooool00;Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo002eooooo`;o00002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06;ooooo002eooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Rooooo`00]Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H_ooool00;Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo002eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Soooo
o`00]Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Hoooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Hoooool00:[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00[o
oooo1?l0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Sooooo`00Zoooool00onHV9So8B4Qonk^kP07ooooo`?o00002oooool2o`0000kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo
002/ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Hoooool00:gooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Sooooo`00[_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06?ooooo002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Sooooo`00Z_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Hoooool00;Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Hoooool00;Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Hoooool00;Gooooo0_l0000Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Sooooo`00]Oooool00ol0003oooooooooo`0Looooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00]Oooool00ol0003oooooooooo`0L
ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool00;Gooooo00?o0000
ooooooooool07?ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Cooooo002e
ooooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00003_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Tooooo`00]Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0I?ooool00;Gooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00000>oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06Cooooo002eooooo`03o`000?oooooooooo01gooooo0_l0000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06Cooooo002eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
I?ooool00;Gooooo0_l0000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002eooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0I?ooool00;Gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Tooooo`00]Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Co
oooo002eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00;Gooooo00?o
0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Tooooo`00]Oooool00ol0003oooooooooo`0_ooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo
002eooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0IOooool00;Gooooo0_l0000`ooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo
002eooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0IOooool00;Gooooo00?o0000ooooooooool0;ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Uooooo`00]Oooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`00013ooooo
00Go0000ooooooooooooooooo`00001Wooooo`00]Oooool00ol0003oooooooooo`0`ooooo`04o`00
0?ooooooooooo`00013ooooo00Go0000ooooooooooooooooo`00001Wooooo`00[?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`00000Aooooo`05
o`000?ooooooooooooooool00000Ioooool00:gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooo0000017ooooo00Go0000ooooooooooooooooo`00001Woooo
o`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`00000Aooooo`05
o`000?ooooooooooooooool00000Ioooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`00
033ooooo00?o0000ooooool000004Oooool01Ol0003ooooooooooooooooo000006Oooooo002Zoooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@
ooooo`05o`000?ooooooooooooooool00000Ioooool00:_ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool00000Ioooool00:_ooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool00000Iooo
ool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`14ooooo`04o`000?oooooo
ooooo`0006Sooooo002eooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo0000J?oo
ool00;Gooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0001Xooooo`00]Oooool0
0ol0003oooooooooo`14ooooo`04o`000?ooooooooooo`0006Sooooo002eooooo`;o0000AOooool0
1?l0003oooooooooool0001Xooooo`00]Oooool00ol0003oooooooooo`14ooooo`04o`000?oooooo
ooooo`0006Sooooo002eooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo0000J?oo
ool00;Gooooo00?o0000ooooooooool0AOooool00ol0003oooooo`00001Xooooo`00]Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooo000006Sooooo002eooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooool00000J?ooool00;Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
o`00001Xooooo`00]Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo000006Sooooo002e
ooooo`;o0000A_ooool00ol0003oooooo`00001Xooooo`00]Oooool00ol0003oooooooooo`15oooo
o`;o0000JOooool00;Gooooo00?o0000ooooooooool0AOooool2o`0006Wooooo002eooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0Ioooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool0
0:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o
410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00
/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05
odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003oooooodA4A?m4A4Cooooo
o`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00001looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wo
oooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003o
<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@
400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool0
6oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15107 m
.04057 .15973 L
.08481 .16935 L
.12636 .17844 L
.16632 .18738 L
.20885 .19691 L
.2498 .20536 L
.29331 .21655 L
.29595 .21682 L
.29742 .21693 L
.29878 .21702 L
.30003 .21707 L
.3014 .21711 L
.30269 .21714 L
.30389 .21715 L
.30523 .21717 L
.30648 .21719 L
.30717 .21721 L
.30792 .21724 L
.30923 .21731 L
.30994 .21736 L
.31072 .21742 L
.3123 .2176 L
.31375 .21782 L
.31511 .21808 L
.31772 .2187 L
.32019 .21944 L
.32483 .22121 L
.32981 .22372 L
.33524 .227 L
.34048 .23005 L
.34305 .23127 L
.3454 .23215 L
.34658 .2325 L
.34787 .2328 L
.34916 .23303 L
.35053 .23319 L
.35127 .23324 L
.35195 .23325 L
.35273 .23325 L
.35346 .23321 L
.35477 .23308 L
.35551 .23297 L
.35619 .23284 L
.35851 .23223 L
.36067 .23144 L
.36561 .22916 L
.36811 .22798 L
.37078 .22691 L
.37208 .22649 L
Mistroke
.3733 .22619 L
.37439 .22599 L
.37557 .22586 L
.3769 .22584 L
.37757 .22587 L
.3783 .22595 L
.37959 .2262 L
.3808 .22655 L
.38224 .22714 L
.38355 .22784 L
.3865 .22999 L
.38906 .23252 L
.39183 .23589 L
.39688 .24305 L
.40178 .24992 L
.40447 .25303 L
.40579 .25428 L
.40699 .25524 L
.40802 .25591 L
.40913 .25647 L
.41026 .25683 L
.41144 .25701 L
.41267 .25694 L
.41398 .2566 L
.41522 .256 L
.41634 .25524 L
.41877 .25289 L
.42145 .24935 L
.42685 .24031 L
.43191 .23182 L
.43412 .22876 L
.43652 .22615 L
.43723 .22556 L
.43798 .22503 L
.43932 .22432 L
.44058 .22399 L
.4413 .22394 L
.44197 .224 L
.44269 .22418 L
.44344 .22449 L
.44479 .22539 L
.44554 .22608 L
.44623 .22685 L
.44782 .22905 L
.45049 .23416 L
.45292 .24022 L
.45838 .25746 L
.46346 .27466 L
.46624 .28277 L
.4676 .28606 L
Mistroke
.46884 .28858 L
.46997 .29041 L
.47105 .2917 L
.47219 .29254 L
.47343 .29282 L
.47471 .29241 L
.47606 .29118 L
.47734 .28927 L
.47849 .28695 L
.48131 .2792 L
.4839 .26997 L
.48974 .24576 L
.49485 .22616 L
.49771 .21761 L
.49907 .2144 L
.50032 .21197 L
.50154 .21015 L
.50284 .20883 L
.50414 .20818 L
.50488 .20813 L
.50558 .2083 L
.50683 .20915 L
.50797 .21054 L
.50923 .21278 L
.51056 .21593 L
.51292 .22359 L
.51512 .233 L
.5201 .26134 L
.5255 .29788 L
.52816 .31476 L
.5306 .3277 L
.53197 .33331 L
.53267 .33564 L
.53342 .33769 L
.53417 .33926 L
.53487 .34026 L
.53571 .34087 L
.53647 .34085 L
.53778 .33952 L
.53852 .33805 L
.53921 .33625 L
.54047 .33186 L
.54181 .32578 L
.55264 .24901 L
.55834 .21231 L
.56121 .19881 L
.56283 .19292 L
.56435 .18866 L
.56503 .18712 L
.56578 .18575 L
Mistroke
.56714 .18406 L
.56846 .18343 L
.56968 .18375 L
.571 .1851 L
.57175 .18633 L
.57246 .1878 L
.57387 .1917 L
.5754 .19729 L
.57811 .21097 L
.58069 .22844 L
.58554 .27233 L
.59072 .32856 L
.59326 .35452 L
.5956 .37412 L
.59692 .38246 L
.5983 .38875 L
.59902 .39089 L
.5997 .39217 L
.60043 .39275 L
.60123 .3924 L
.6026 .38944 L
.60389 .38399 L
.60506 .37705 L
.60633 .36754 L
.61628 .2602 L
.62116 .21383 L
.6233 .19788 L
.62563 .18364 L
.62794 .17285 L
.6292 .16834 L
.63038 .16501 L
.63167 .1623 L
.63285 .16072 L
.63421 .15994 L
.6355 .16022 L
.63682 .16154 L
.63748 .16261 L
.63821 .16409 L
.63951 .16753 L
.64072 .17171 L
.64345 .18477 L
.64498 .19449 L
.64639 .20503 L
.65193 .26322 L
.65783 .3474 L
.6607 .38744 L
.6621 .4044 L
.6634 .4176 L
.66458 .42723 L
.66582 .43454 L
Mistroke
.66707 .43866 L
.66844 .43929 L
.66978 .43594 L
.67105 .42926 L
.67219 .42055 L
.67343 .40849 L
.67877 .33595 L
.68335 .26849 L
.68841 .20974 L
.69124 .1861 L
.69389 .16918 L
.6967 .15588 L
.69828 .15024 L
.69972 .14618 L
.70098 .14351 L
.70215 .14177 L
.70344 .1407 L
.70482 .14054 L
.70551 .14085 L
.70626 .14148 L
.70763 .14341 L
.70895 .14624 L
.71018 .14969 L
.71275 .15961 L
.7151 .17208 L
.71781 .19134 L
.72038 .21557 L
.72494 .2756 L
.72991 .36121 L
.73272 .41016 L
.73536 .44854 L
.73669 .46304 L
.73737 .46897 L
.73812 .47416 L
.73889 .47801 L
.73971 .48033 L
.74046 .48087 L
.74116 .47997 L
.74252 .47446 L
.7438 .46491 L
.74495 .45306 L
.7462 .43716 L
.75159 .347 L
.75637 .26635 L
.759 .23017 L
.76151 .20241 L
.76445 .17719 L
.76715 .15974 L
.76967 .14713 L
.77243 .13663 L
Mistroke
.77392 .13216 L
.77533 .12865 L
.77797 .12371 L
.77945 .12171 L
.78081 .12026 L
.7824 .11893 L
.78388 .11795 L
.78634 .11668 L
.78905 .11556 L
.79168 .11469 L
.79316 .11433 L
.79451 .11409 L
.79575 .11396 L
.79691 .11391 L
.79818 .11394 L
.79956 .11405 L
.80092 .11421 L
.80236 .11442 L
.80492 .11478 L
.80607 .11491 L
.80731 .11502 L
.80847 .11511 L
.80952 .11517 L
.81197 .1153 L
.8132 .11538 L
.81455 .1155 L
.816 .11568 L
.81735 .1159 L
.81994 .11641 L
.82298 .11708 L
.82577 .1176 L
.82839 .11797 L
.83087 .11824 L
.83635 .11898 L
.87652 .12621 L
.91926 .13451 L
.96041 .14284 L
1 .15107 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
F_ooool8o`0004kooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Gooooo`?o00001oooool7o`0004Sooooo002eooooo`03o`000?oooooooooo05Kooooo0_l0
000@ooooo`Co0000A?ooool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0D
ooooo`Oo0000?Oooool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Koooo
o`Go0000>?ooool00;Gooooo0_l0001Fooooo`03o`000?oooooooooo023ooooo1Ol0000cooooo`00
]Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02Kooooo1?l0000_ooooo`00]Ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02[ooooo1Ol0000Zooooo`00]Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool7
o`0002?ooooo002eooooo`03o`000?oooooooooo03gooooo0ol0000Dooooo`03o`000?oooooooooo
03Kooooo1Ol0000Nooooo`00]Oooool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`00
01?ooooo00?o0000ooooooooool0??ooool5o`0001Wooooo002eooooo`03o`000?oooooooooo03co
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo047ooooo1?l0000Eoooo
o`005_ooool3o`0009cooooo00?o0000ooooooooool0??ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool0AOooool2o`0001?ooooo000Iooooo`Go0000Uoooool2o`0003go
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo05[ooooo000Nooooo`Co
0000Toooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Kooooo`008_ooool4o`0008oooooo00?o0000ooooooooool0
9oooool2o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo05_ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h01_ooool5o`0000oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool07oooool4
o`000005oa0@4?ooooooooooo`000?lb<S800_l000000oo^k^koooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00006_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo1Ol0000:oooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Go0000oiRHV?oooooo0000ogMgM`0@ooooo`03o`000?oooooo
oooo00?ooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_mgMgOo
V9RHoooooonHV9SoMgMgo`0001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@013o
oooo2?l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aoooo
o`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo000001oooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Cooooo1Ol0
0004ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000006Oooool5o`000005okZj^_oooooo
ooooooooool000000oooool00ol0003oooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41007Oooool5o`000005oa0@4?ooooooooooooooool@41007oooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41007_ooool2o`0002;ooooo00Ko0000oooooooooooooooo
o`000?l@4103ooooo`03oa0@4?l0003ooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Loooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co
000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
1ol0000Iooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool04_ooool2o`0000gooooo00_o0000ooooooooooooooooo`000?mgMgOoV9RHoooooonH
V9SoMgMgo`00000>ooooo`03o`000?oooooooooo00Cooooo00Wo0000ooooooooooooooooo`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So000001_ooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00_ooool5o`0001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Booooo`?o00002_ooool00omEEEGoIVIVo`00
0003ooooo`07o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`00000>ooooo`03o`000?oooooooooo00Go
oooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8b
o`00000Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo001>oooo
o`Go0000H_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Looooo`00Doooool4o`0005kooooo00?o0000oooo
ooooool04Oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0GOooool005Oooooo1?l0001Jooooo`03o`000?oooooooooo017ooooo00Co0000oooo
oooooooo00003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05gooooo001Koooo
o`Go0000EOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05gooooo001Pooooo`Co
0000DOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05gooooo000Foooooooo0000
@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o00000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`;o00001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000006ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo1?l00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool2o`0000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool006oooooo0ol00013oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0GOooool007;ooooo2_l0000hoooo
o`;o00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo001looooo`?o
0000=Oooool2o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`00
Ooooool00ol0003oooooooooo`0Oooooo`?o00003oooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0G_ooool0083ooooo0_l00009ooooo`Ko00004?oo
ool01?l0003oooooo`000?l0000>ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Nooooo`00P_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oo
oooooooo00cooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`00Q?ooool5o`0000Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co
0000ooooool0003o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo
002Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Nooooo`00Toooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0G_ooool009Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05kooooo002Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Nooooo`00U_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G_ooool009Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002G
ooooo`Co00003Oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002Hooooo`;o00003_ooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05oooooo002Xooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Gooo
ool00:Sooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`00ZOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05oooooo002Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Goooool00:Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`00
ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002Zooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Goooool00:[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05oooooo002[ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002[ooooo`04o`000?oooooo0000
o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05oooooo002/ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Goooool00;Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05oooooo002eooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Oooooo`00Z_ooool5o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05oooooo002Z
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Goooool00:_ooooo00?oV9RHob4Q8Oo^k^h01oooool3
o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00[?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Pooooo`00[Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00[_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00
Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo063ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`07ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0H?ooool00;Gooooo00?o0000ooooooooool01oooool01?l0
003oooooooooool0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Pooooo`00]Oooool2o`0000Sooooo00Co0000oooooooooooo00003oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H?ooool0
0;Gooooo00?o0000ooooooooool01oooool3o`00013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo00So
oooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Pooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Pooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003oooooooooo`0Koooo
o`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0
003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1P
ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000003oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Pooooo`00]Oooool2o`0001cooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo01_ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo
01_ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo002eoooo
o`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo067ooooo002eooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00004Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Qooooo`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`00017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0HOooool00;Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooo`00000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo002eooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool000004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00]Oooool2o`0001gooooo
00?o0000ooooool000004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00]Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00;Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo067ooooo002eooooo`03o`000?oooooo
oooo033ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00;Gooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00[?ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00[Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00
000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00:[ooooo1Ol00006
ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0HOooool00:[ooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`00033ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0HOooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`0aooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Qooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo037ooooo
00Co0000oooooooooooo00004_ooool01Ol0003ooooooooooooooooo000006Cooooo002[ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool0000Boooo
o`05o`000?ooooooooooooooool00000I?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`0aooooo`04o`000?ooooooooooo`0001;ooooo00Go0000ooooooooooooooooo`00
001Tooooo`00]Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000001?ooooo00Go0000
ooooooooooooooooo`00001Tooooo`00]Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
000001Cooooo00Co0000oooooooooooo0000I?ooool00;Gooooo00?o0000ooooooooool0<_ooool2
o`0001Cooooo00Co0000oooooooooooo0000I?ooool00;Gooooo0_l0000cooooo`;o00005?ooool0
1?l0003oooooooooool0001Tooooo`00]Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01;ooooo00Co0000oooooooooooo0000I?ooool00;Gooooo00?o0000ooooooooool0B?ooool0
1?l0003oooooooooool0001Tooooo`00]Oooool00ol0003oooooooooo`18ooooo`04o`000?oooooo
ooooo`0006Cooooo002eooooo`03o`000?oooooooooo04Sooooo00Co0000oooooooooooo0000I?oo
ool00;Gooooo00?o0000ooooooooool0B?ooool01?l0003oooooooooool0001Tooooo`00]Oooool0
0ol0003oooooooooo`18ooooo`04o`000?ooooooooooo`0006Cooooo002eooooo`03o`000?oooooo
oooo04Sooooo00Co0000oooooooooooo0000I?ooool00;Gooooo0_l00019ooooo`03o`000?oooooo
000006Gooooo002eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooool00000IOooool00;Go
oooo00?o0000ooooooooool0B?ooool00ol0003oooooo`00001Uooooo`00]Oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooo000006Gooooo002eooooo`03o`000?oooooooooo04Wooooo0_l0
001Uooooo`00]Oooool00ol0003oooooooooo`19ooooo`;o0000IOooool00;Gooooo00?o0000oooo
ooooool0BOooool2o`0006Gooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?o
oooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool01Ol0001looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A01l
ooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool00oooool00onHV9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo
00?oV9RHob4Q8Oo^k^h0O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo07_ooooo0025oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wo
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool0
08Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15624 m
.04057 .16417 L
.08481 .17258 L
.12636 .18126 L
.16632 .18896 L
.17777 .1925 L
.18339 .19386 L
.18859 .19502 L
.19102 .19549 L
.19331 .19585 L
.19445 .19598 L
.19569 .1961 L
.19705 .19619 L
.19831 .19624 L
.19965 .19626 L
.20089 .19627 L
.20226 .19627 L
.20302 .19627 L
.20371 .19627 L
.20498 .19628 L
.20636 .1963 L
.20766 .19633 L
.20885 .19637 L
.21122 .19648 L
.21376 .19663 L
.21596 .19678 L
.21834 .197 L
.2198 .19717 L
.22114 .19738 L
.22379 .19794 L
.2262 .19866 L
.22876 .19964 L
.23888 .20475 L
.2442 .20769 L
.2471 .20927 L
.2498 .2106 L
.25226 .21161 L
.25364 .21205 L
.25489 .21236 L
.25626 .21261 L
.25704 .2127 L
.25776 .21275 L
.25907 .21278 L
.25973 .21276 L
.26046 .21272 L
.26173 .21258 L
.2629 .21239 L
.26424 .21212 L
.26551 .2118 L
.27024 .21019 L
Mistroke
.27543 .20785 L
.27797 .20665 L
.28031 .20567 L
.28245 .20495 L
.28352 .20469 L
.2847 .20449 L
.28588 .20438 L
.28715 .20438 L
.28834 .20449 L
.28943 .20469 L
.29073 .20504 L
.29192 .20548 L
.29462 .20688 L
.297 .20857 L
.29953 .21083 L
.30464 .21681 L
.31027 .2247 L
.31507 .23091 L
.31777 .2336 L
.31905 .2346 L
.32024 .23536 L
.3213 .23588 L
.32242 .23627 L
.32367 .23651 L
.3248 .23653 L
.32598 .23636 L
.32727 .23594 L
.32848 .23533 L
.32959 .23458 L
.33217 .23217 L
.33451 .22924 L
.3398 .22095 L
.34475 .21284 L
.34693 .2097 L
.34933 .20677 L
.35057 .20551 L
.35192 .20439 L
.35265 .20387 L
.35333 .20347 L
.35466 .2029 L
.35601 .20262 L
.35678 .20261 L
.35749 .20269 L
.35824 .20289 L
.35893 .20317 L
.35972 .20361 L
.36046 .20415 L
.36174 .20535 L
.3631 .20701 L
.36553 .21099 L
Mistroke
.36814 .21662 L
.37102 .22419 L
.37602 .23953 L
.38148 .25633 L
.38397 .26278 L
.38534 .26573 L
.38663 .26803 L
.38784 .2697 L
.38914 .27095 L
.39032 .27153 L
.39141 .27159 L
.39279 .27099 L
.39407 .26976 L
.39481 .26877 L
.39548 .26769 L
.39698 .26468 L
.40001 .25655 L
.40287 .24694 L
.40785 .22831 L
.41334 .20892 L
.41586 .20156 L
.41718 .19825 L
.41858 .19525 L
.4198 .19306 L
.42114 .19118 L
.42236 .18996 L
.42349 .18927 L
.42416 .18907 L
.42489 .18903 L
.42622 .18945 L
.42751 .19046 L
.4287 .19192 L
.42999 .1941 L
.4314 .19718 L
.43426 .20565 L
.43678 .21553 L
.43908 .22644 L
.44426 .25607 L
.44917 .2858 L
.4513 .29709 L
.45361 .3069 L
.45496 .31116 L
.4562 .31398 L
.45738 .3156 L
.45864 .31614 L
.45996 .31539 L
.46119 .31347 L
.46254 .31007 L
.46398 .30504 L
.46657 .2929 L
Mistroke
.46902 .27861 L
.4736 .24823 L
.47867 .21575 L
.48144 .20073 L
.48404 .18914 L
.48684 .1796 L
.48833 .17584 L
.4891 .17426 L
.48993 .17281 L
.49069 .17175 L
.49139 .17099 L
.49278 .17009 L
.49404 .17 L
.49538 .17068 L
.49668 .17214 L
.49742 .17332 L
.49811 .17466 L
.4995 .17808 L
.501 .18285 L
.5037 .19449 L
.50617 .20854 L
.51217 .25529 L
.51785 .30837 L
.5204 .33027 L
.5218 .34062 L
.52312 .34886 L
.52433 .35494 L
.52543 .35909 L
.52666 .36197 L
.52799 .36292 L
.52932 .36158 L
.53056 .3583 L
.53192 .35255 L
.53337 .34411 L
.53633 .32098 L
.53903 .29557 L
.54408 .24628 L
.54881 .20714 L
.55138 .19019 L
.55374 .17748 L
.55635 .16644 L
.55779 .16173 L
.55916 .15819 L
.56053 .15557 L
.56129 .15451 L
.56198 .15379 L
.56333 .15308 L
.56459 .15323 L
.56532 .15368 L
.56608 .15443 L
Mistroke
.56744 .15648 L
.5682 .15802 L
.56891 .15971 L
.57052 .16448 L
.57317 .17525 L
.57558 .18851 L
.57836 .20846 L
.581 .23229 L
.59115 .35288 L
.59362 .37806 L
.59501 .38917 L
.59628 .39694 L
.59696 .40005 L
.5977 .40259 L
.59848 .40423 L
.5992 .40482 L
.60052 .40354 L
.60126 .40151 L
.60193 .39886 L
.60314 .39227 L
.60442 .38294 L
.60671 .36112 L
.61189 .2982 L
.61671 .24031 L
.62128 .19774 L
.62377 .18053 L
.62647 .16599 L
.62893 .15599 L
.63121 .14915 L
.63248 .14631 L
.63366 .14426 L
.63497 .14271 L
.6357 .14218 L
.63638 .1419 L
.63765 .14194 L
.63838 .14231 L
.63905 .14287 L
.64041 .14468 L
.64117 .14607 L
.64187 .14759 L
.64433 .15489 L
.64661 .16435 L
.64911 .17802 L
.65176 .19688 L
.65621 .2408 L
.66111 .30722 L
.66372 .34678 L
.66657 .38779 L
.66787 .40418 L
.66926 .41911 L
Mistroke
.67057 .43025 L
.67175 .4375 L
.67301 .44195 L
.67416 .44301 L
.67543 .44078 L
.67677 .43468 L
.67793 .42646 L
.67902 .41657 L
.68149 .38763 L
.68689 .309 L
.68973 .26849 L
.69275 .23116 L
.69539 .20457 L
.69829 .18155 L
.70094 .16568 L
.70342 .15441 L
.70603 .14569 L
.70735 .14235 L
.70878 .13942 L
.71002 .13748 L
.71133 .13596 L
.71258 .13505 L
.7137 .13465 L
.7144 .13461 L
.71513 .13474 L
.71644 .13543 L
.71717 .13606 L
.71785 .13682 L
.71941 .13918 L
.72076 .14198 L
.722 .14516 L
.72479 .15473 L
.72727 .16644 L
.72958 .18054 L
.7321 .20039 L
.73479 .22757 L
.73977 .29604 L
.74428 .37216 L
.74694 .41556 L
.74942 .44888 L
.75066 .46157 L
.752 .47137 L
.75276 .47503 L
.75348 .47715 L
.75484 .47749 L
.75601 .47396 L
.75725 .46646 L
.75831 .4572 L
.75948 .44426 L
.76453 .36667 L
Mistroke
.76997 .27697 L
.77297 .23688 L
.77583 .20682 L
.77847 .18523 L
.78135 .16709 L
.78397 .15444 L
.78641 .14539 L
.78776 .14137 L
.78918 .13782 L
.79173 .13304 L
.79315 .13111 L
.79448 .12968 L
.79749 .12735 L
.80013 .1259 L
.80253 .1248 L
.80386 .12428 L
.80531 .12378 L
.80667 .12341 L
.80794 .12316 L
.80906 .12303 L
.81026 .12298 L
.8114 .12301 L
.81244 .12309 L
.81359 .12324 L
.81486 .12343 L
.81741 .12384 L
.8187 .12402 L
.81993 .12414 L
.8206 .1242 L
.82134 .12425 L
.82262 .1243 L
.82392 .12435 L
.82515 .12439 L
.82626 .12445 L
.82747 .12454 L
.82875 .12469 L
.82994 .12487 L
.8326 .12542 L
.8374 .12655 L
.83883 .12682 L
.84017 .12703 L
.84269 .1273 L
.84543 .12755 L
.84692 .12772 L
.84832 .12792 L
.85096 .12842 L
.85385 .12911 L
.85646 .12973 L
.85894 .13021 L
.86183 .13062 L
Mistroke
.86448 .1309 L
.86732 .13127 L
.86893 .13154 L
.87041 .13183 L
.91167 .1394 L
.95134 .14681 L
.99358 .155 L
1 .15624 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo05gooooo2_l00019
ooooo`00]Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Oooooo1ol00013oooo
o`00]Oooool2o`0005_ooooo0_l0000Aooooo`Go0000?_ooool00;Gooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`0Eooooo`Go0000>Oooool00;Gooooo00?o0000ooooooooool0@?oo
ool3o`0001Oooooo00?o0000ooooooooool06_ooool7o`0003;ooooo002eooooo`03o`000?oooooo
oooo03oooooo0_l00002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08_ooool6
o`0002cooooo002eooooo`03o`000?oooooooooo02Sooooo0_l0000Eooooo`05o`000?oooooooooo
ooooool000005?ooool00ol0003oooooooooo`0Yooooo`Oo00009Oooool00;Gooooo00?o0000oooo
ooooool09oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0`ooooo`Go00008?ooool00;Gooooo00?o0000oooo
ooooool09oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0eooooo`Go00006oooool00;Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo1?l0000G
ooooo`005_ooool3o`0009cooooo0_l0000Aooooo`?o00004oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03oooooo1?l0000Cooooo`006Oooool5o`0009Oooooo00?o0000oooooooo
ool04?ooool01?l0003oooooo`000?l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0E_ooool001kooooo1?l0002Cooooo`03o`000?oooooooooo00oooooo00Go0000oooooooo
ooooooooo`00000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0E_ooool001Go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00005?oo
ool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
00002oooool4o`00000:oa0@4?oooooo0000onk^k_lb<S;o0000oc8b<_o^k^koooooo`00013ooooo
00?o0000ooooooooool01Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03
o`000?oooooooooo01Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`Go
00003oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000oooooooo
ool03oooool01Ol0003ooooooooooooooooo000000gooooo00co0000ooooooooooooooooo`000?mg
MgOoV9RHoooooonHV9SoMgMgooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Go0000ob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003ooooooooo
o`0Dooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00000_ooool6o`00
00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool2o`000003oooo
ool0003ooooo013ooooo00Go0000ooooooooooooooooo`00000=ooooo`06o`000?oooooooooooooo
ool0003o410@0oooool00ol@413oooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool000004?ooool5o`0000Sooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001[o
oooo0_l000000ooooooo0000o`00000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooool000004?ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool05oooool00onYZJWo410@ooooo`02ooooo`05o`000?oo
ooooooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000001Gooooo1ol000000ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo0000
013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool05_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMg
olc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01cooooo1Ol000000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo01gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01[o
oooo00Co0000oooooooooooooooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool01_l0003oooooooooool0003ooooooa0@40?ooooo00?o410@ooooool000003ooo
ool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooo
oooooa0@4004ooooo`03o`000?oooooooooo01Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oa0@4?nHV9SooooookZj^_l000000_ooool5o`000003ogMgMooooooooooo01Wooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003ooooooooooooooooo
0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`0<o`000?oooooo
ooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgMooooooo00003oooool00ol0003oooooooooo`06
ooooo`;o000000?ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o
0000ooooooooool05?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Cok^k^oc8b<_l0003o<S8b1?l0000Hooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00omE
EEGoIVIVo`000002ooooo`09o`000?ooooook^k^oc8b<_l0003o<S8bonk^k_oooooo000000oooooo
00?o0000ooooooooool01_ooool01OnHV9So0000o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP04ooooo`03o`000?oooooooooo01Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool004[ooooo1?l0001>ooooo`?o00004Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Eoooool004kooooo1?l00019
ooooo`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`02ooooo`;o00003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Gooooo`00D_ooool:o`0003oooooo00Go0000ooooooooooooooooo`00000@
ooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Oooooo001Loooo
o`Go0000>_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool00oooool2
o`0000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0F?ooool0067ooooo00?o0000ooooooooool08oooool2o`00
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00?ooooo0_l0000=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo05Sooooo000Foooooooo0000@?l0000Cooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`?o00001oooool2o`0000Cooooo0ol00007ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo2Ol00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool2o`0000Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool2o`0000Kooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo001fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0F?ooool007Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1H
ooooo`00Moooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo001hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool007Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Iooooo`00N_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Wooooo001kooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`;o000000?oooooo`000?ooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Ioooo
o`00O?ooool3o`0000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Wooooo002=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Iooooo`00SOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool008kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool008ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0FOooool008kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0FOooool008oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool008oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Jooooo`00
T?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Joooo
o`00T?ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1J
ooooo`00TOooool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_oo
ool0097ooooo0ol0000@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool0
0:Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`00Y?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05[ooooo002Uooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0F_ooool00:Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[ooooo002U
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool00:Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Jooooo`00YOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05[ooooo002Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
F_ooool00:Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`00Y_ooool0
0ol0003oooooooooo`06o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05_ooooo002Vooooo`09o`000?ooooooooooo`000?nHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05_ooooo002Vooooo`08o`000?ooooooooooo`000?ooooooV9RHob4Q8Oo^k^h7oooo
o`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05_ooooo002Wooooo`03
o`000?oooooo000000;ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00:Oooooo0ol00003ooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05_ooooo002^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Zooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Foooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`00]Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Foooool0
0;Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05_ooooo002eooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_o
oooo002eooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Aooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`00
]Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Foooool00;Gooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002eooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Looooo`00]Oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05cooooo002eooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0G?ooool00;Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`00000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Looooo`00]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000001;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo002e
ooooo`;o00001_ooool2o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05cooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo002eooooo`03
o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
05cooooo002eooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05cooooo002eooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo00004oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Looooo`00]Oooool00ol0003oooooooooo`0Kooooo`04
o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G?ooool00;Gooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo002eooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Loooo
o`00]Oooool2o`0001cooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Moooo
o`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0GOooool00;Gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000Coooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05gooooo002eooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
00004oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Mooooo`00]Oooool00ol0003oooooooooo`0Looooo`;o0000
5?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Mooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool07?ooool2o`0001Cooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00:gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00:[ooooo1Ol0
0006ooooo`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00:[ooooo00CoA4A4omgMgOoooooo0000
1oooool3o`0003?ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05gooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0GOooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0cooooo`04
o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Moooo
o`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooo
oooo00005?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo002/ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00;Gooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000Dooooo`05o`000?ooooooooooooooool00000H?ooool0
0;Gooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0000Dooooo`05o`000?oooooo
ooooooooool00000H?ooool00;Gooooo00?o0000ooooooooool0<oooool00ol0003oooooo`00000F
ooooo`04o`000?ooooooooooo`00063ooooo002eooooo`;o0000=Oooool2o`0001Kooooo00Co0000
oooooooooooo0000H?ooool00;Gooooo00?o0000ooooooooool0=?ooool2o`0001Kooooo00Co0000
oooooooooooo0000H?ooool00;Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0E
ooooo`04o`000?ooooooooooo`00063ooooo002eooooo`03o`000?oooooooooo04cooooo00Co0000
oooooooooooo0000H?ooool00;Gooooo00?o0000ooooooooool0C?ooool01?l0003oooooooooool0
001Pooooo`00]Oooool00ol0003oooooooooo`1<ooooo`04o`000?ooooooooooo`00063ooooo002e
ooooo`03o`000?oooooooooo04cooooo00Co0000oooooooooooo0000H?ooool00;Gooooo00?o0000
ooooooooool0COooool00ol0003oooooo`00001Pooooo`00]Oooool2o`0004kooooo00?o0000oooo
ool00000H?ooool00;Gooooo00?o0000ooooooooool0COooool00ol0003oooooo`00001Pooooo`00
]Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo0000063ooooo002eooooo`03o`000?oo
oooooooo04gooooo0_l0001Qooooo`00]Oooool00ol0003oooooooooo`1=ooooo`;o0000HOooool0
0;Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Oooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05
oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002ioooo
o`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`00
0?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4
o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Noooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00;ooooo1Ol0001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`00
00Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00CoA4A4
omgMgOoooooo0000OOooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0007gooooo0025oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
0oooool00omgMgOoc<c<o`00001mooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wo
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000007gooooo0024ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001_ooool00omg
MgOo0000ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16072 m
.04057 .16722 L
.06168 .17185 L
.07286 .17456 L
.079 .17583 L
.08202 .17633 L
.08481 .17672 L
.09021 .17726 L
.09306 .17746 L
.09607 .17763 L
.10136 .17786 L
.10395 .17797 L
.10632 .17809 L
.10867 .17825 L
.11091 .17846 L
.11328 .17876 L
.11586 .17918 L
.1213 .18045 L
.12636 .18207 L
.16745 .19143 L
.17764 .18829 L
.18012 .18766 L
.18149 .18738 L
.18278 .18717 L
.18351 .18707 L
.18431 .187 L
.18503 .18695 L
.1857 .18692 L
.18702 .18694 L
.18768 .18698 L
.18842 .18705 L
.18916 .18716 L
.18995 .1873 L
.19135 .18765 L
.19286 .18816 L
.19451 .18888 L
.19748 .19058 L
.20024 .19262 L
.21111 .20353 L
.21659 .20923 L
.21928 .21153 L
.22046 .21238 L
.22176 .21318 L
.22285 .21373 L
.22402 .21419 L
.22526 .21453 L
.22641 .2147 L
.22776 .21472 L
.22904 .21455 L
.23019 .21426 L
Mistroke
.23145 .21378 L
.23292 .21301 L
.23431 .21209 L
.23691 .20991 L
.24272 .20338 L
.24771 .19711 L
.25035 .19402 L
.25318 .19118 L
.25461 .18998 L
.25596 .18902 L
.25728 .18827 L
.2585 .18775 L
.25965 .18742 L
.26087 .18725 L
.2621 .18728 L
.26346 .18755 L
.26414 .18779 L
.26486 .18812 L
.26615 .18889 L
.26754 .19001 L
.26905 .19157 L
.27177 .19526 L
.2743 .19965 L
.28362 .22142 L
.28852 .23338 L
.29121 .2389 L
.29371 .24292 L
.29504 .24449 L
.29572 .24513 L
.29646 .24569 L
.29727 .24613 L
.29804 .24639 L
.29878 .24647 L
.29948 .24641 L
.3007 .24597 L
.30205 .24498 L
.30273 .2443 L
.30346 .24342 L
.30479 .24148 L
.30744 .23636 L
.31023 .22953 L
.31523 .21517 L
.31974 .20189 L
.32456 .18952 L
.32732 .18398 L
.32984 .18026 L
.33105 .17895 L
.33237 .17793 L
.33361 .17734 L
.33476 .17715 L
Mistroke
.33607 .17733 L
.33732 .17792 L
.33844 .1788 L
.33966 .18014 L
.34098 .18206 L
.34239 .18463 L
.34492 .19067 L
.34749 .19861 L
.34992 .20769 L
.35444 .22801 L
.3595 .25298 L
.36227 .26564 L
.36485 .27559 L
.36631 .28008 L
.36764 .28332 L
.3684 .28476 L
.36912 .28583 L
.36988 .28665 L
.37071 .28717 L
.37207 .28716 L
.37275 .28674 L
.37351 .28596 L
.37485 .28378 L
.3761 .28082 L
.38549 .23901 L
.39065 .21141 L
.39552 .18909 L
.39828 .17897 L
.39974 .17449 L
.40128 .17042 L
.40258 .16756 L
.40401 .16502 L
.4053 .16328 L
.40652 .16217 L
.40784 .16152 L
.40909 .16147 L
.41022 .1619 L
.41145 .16289 L
.41278 .16459 L
.4142 .16711 L
.41674 .17355 L
.41948 .18327 L
.42244 .19712 L
.4278 .23079 L
.43257 .26723 L
.4378 .30515 L
.43921 .31331 L
.44071 .32052 L
.44144 .32337 L
.44213 .32564 L
Mistroke
.44342 .32874 L
.44414 .32977 L
.4449 .33032 L
.44627 .32989 L
.44703 .32886 L
.44774 .3274 L
.44851 .32525 L
.44935 .32233 L
.45071 .31634 L
.45219 .30822 L
.45489 .29005 L
.45996 .24997 L
.46554 .20807 L
.46827 .19108 L
.47079 .17801 L
.47304 .16843 L
.47551 .1601 L
.47799 .15396 L
.47934 .15153 L
.48061 .14985 L
.48198 .1487 L
.48275 .14835 L
.48346 .14823 L
.48477 .1485 L
.48543 .14889 L
.48617 .14952 L
.48742 .15109 L
.48878 .1535 L
.49006 .15647 L
.49123 .15979 L
.49388 .16949 L
.49678 .18383 L
.49981 .20327 L
.50263 .22561 L
.50792 .27686 L
.51071 .30575 L
.51367 .33394 L
.51625 .35361 L
.51696 .35785 L
.51772 .36175 L
.51909 .36699 L
.52043 .36969 L
.52171 .36996 L
.52285 .36829 L
.5241 .36446 L
.52542 .35823 L
.52667 .35052 L
.529 .33211 L
.53422 .2801 L
.53908 .23163 L
Mistroke
.54361 .19494 L
.54618 .17879 L
.54851 .16689 L
.55111 .15653 L
.55255 .15196 L
.55388 .14845 L
.55515 .14572 L
.55655 .14337 L
.55723 .14248 L
.55796 .14169 L
.55873 .14106 L
.55945 .14066 L
.56079 .14039 L
.56147 .14049 L
.5622 .14078 L
.56351 .14177 L
.56473 .14325 L
.56594 .14528 L
.56726 .14813 L
.56965 .1551 L
.57197 .16431 L
.57411 .17513 L
.57898 .20941 L
.58144 .23232 L
.58413 .26169 L
.58962 .32928 L
.59232 .3608 L
.59351 .37296 L
.59482 .38463 L
.59591 .39262 L
.59709 .39929 L
.59833 .40392 L
.59949 .40588 L
.60079 .40526 L
.60215 .40147 L
.60331 .3958 L
.60458 .38722 L
.60746 .36031 L
.61007 .3298 L
.61595 .25795 L
.61856 .2301 L
.62139 .20454 L
.62386 .18624 L
.62653 .17043 L
.6292 .15815 L
.63165 .14967 L
.63283 .14645 L
.63411 .14351 L
.63531 .14128 L
.63645 .13961 L
Mistroke
.63714 .1388 L
.63788 .13809 L
.63919 .13723 L
.63993 .13697 L
.64071 .13685 L
.64138 .13689 L
.64211 .13707 L
.64342 .13778 L
.64416 .13839 L
.64483 .13908 L
.64613 .14082 L
.64736 .14296 L
.65003 .14941 L
.65138 .15373 L
.65286 .15942 L
.65548 .17213 L
.65794 .18763 L
.66083 .2109 L
.66348 .23754 L
.66945 .31472 L
.67443 .38433 L
.67586 .40159 L
.67721 .41556 L
.67843 .42573 L
.67975 .4338 L
.6809 .43809 L
.68217 .43965 L
.68349 .43765 L
.68473 .43251 L
.68589 .42499 L
.68694 .41604 L
.68932 .38986 L
.69479 .3136 L
.69779 .27263 L
.7006 .23915 L
.70324 .21314 L
.70609 .19051 L
.70866 .17429 L
.71106 .16225 L
.71348 .1528 L
.71487 .1485 L
.71613 .14525 L
.71737 .14264 L
.71871 .14038 L
.72013 .13859 L
.72147 .13736 L
.72262 .13663 L
.72389 .1361 L
.72521 .13583 L
.72645 .13582 L
Mistroke
.7276 .13601 L
.72866 .13638 L
.72988 .13706 L
.73104 .13801 L
.73241 .13955 L
.73365 .14141 L
.73509 .14417 L
.73644 .14745 L
.73884 .15508 L
.74145 .16613 L
.74433 .18217 L
.74737 .2044 L
.74997 .22873 L
.75282 .26212 L
.75785 .33682 L
.7605 .37989 L
.76332 .42203 L
.76451 .43702 L
.76578 .45066 L
.76651 .45708 L
.76718 .462 L
.7685 .46876 L
.76961 .47132 L
.77083 .47071 L
.7721 .4663 L
.77328 .45889 L
.774 .45296 L
.77478 .44541 L
.77619 .42906 L
.77883 .39163 L
.78476 .2985 L
.78741 .26201 L
.79021 .22977 L
.79262 .20746 L
.79524 .18811 L
.79789 .17292 L
.80041 .16177 L
.80286 .15344 L
.80513 .14756 L
.80653 .14471 L
.80784 .14247 L
.81028 .13925 L
.81166 .13789 L
.81292 .13684 L
.81577 .13505 L
.81808 .13399 L
.82023 .13325 L
.82147 .13292 L
.82259 .13268 L
.82389 .13247 L
Mistroke
.82512 .13234 L
.82631 .13227 L
.82758 .13226 L
.82866 .13228 L
.82985 .13235 L
.83113 .13244 L
.8325 .13256 L
.83499 .13281 L
.85606 .13569 L
.87822 .13929 L
.91826 .14616 L
.96088 .15344 L
1 .16072 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
H_ooool:o`0004Cooooo002eooooo`03o`000?oooooooooo02Wooooo0_l0000Hooooo`Co00006_oo
ool00ol0003oooooooooo`08ooooo`Oo0000?Oooool00;Gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`02
o`0001Sooooo00?o0000ooooooooool04?ooool6o`0003Oooooo002eooooo`03o`000?oooooooooo
00oooooo0ol0000Fooooo`03o`000?oooooooooo00;o00005Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool7o`00033ooooo002eooooo`03
o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07oooool5o`0002_ooooo002_ooooo`;o00001?ooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02Cooooo1Ol0000Vooooo`00[_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0:Oooool5o`00027ooooo002^ooooo`04o`000?oooooooooo
o`0000?ooooo0_l0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo1Ol0000Looooo`00[_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0d
ooooo`Ko00005_ooool001Kooooo1?l0001mooooo`;o00005?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>_ooool3o`0001?ooooo000Eoooo
o`;o000000?o410@ooooooooool01ol0000Iooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7?ooool4o`000007oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<P02o`000003ooooool0003ooooo
01;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool4o`000008oa0@4?ooooooooooo`000?lb<S;o0000
oc8b<_o^k^h3ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool6o`0000;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00gooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;o
oooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool6o`0001?ooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHo`000003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
2_l0003ooooooooooooooooo0000ogMgMonHV9SooooooiRHV?mgMgL3ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool01_nHV9So8B4Qonk^k_ooooooA4A4o`0000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Oooooo1Ol00006ooooo`Ko00001_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooo0000oa0@4003ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool01_l0003ooooooooooooooooo0000oa0@40?ooooo00Go410@ooooooooooooooooo`00
000@ooooo`03o`000?oooooooooo00Cooooo00GoV9RHob4Q8Oo^k^koooooo`000002ooooo`05oa0@
4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000<ooooo`?o00003_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
7Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000004?ooool00ol0003oooooooooo`05ooooo`04oiRHV?lQ8B7ok^k^o`0000;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo017ooooo00?oZJVYoa0@4?ooool0
0_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000?ooooo`[o00000oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00004Oooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool01_ooool0
1_mgMgOoIVIVooooool0003oooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0@ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41006?ooool6o`000005ob4Q8Ooooooo
ooooooooool@41000oooool00ol@413oooooooooo`0Mooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0>ooooo`04o`000?oooooo0000o`0000[ooooo00?o0000oooooooo
ool00_ooool01Ol@413oooooo`000?oooooo410@00Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`05ooooo`?o00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00Ko0000oooooooooooo0000ooooool@4103ooooo`05oa0@4?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool@41000oooool00ol@413o
ooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`04oa0@4?nHV9SooooookZj^P?o000000KoooooogMgMonHV9SooooooiRHV?mgMgLKooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo00Go0000
ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RH
ogMgM`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool2o`0000kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`0:o`000?ooooooooooo`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`0=o`000?nj^[[ooooooiRHV?l@413oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMg
M`09ooooo`03o`000?oooooooooo00oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`Go000000?ok^k^ooooooooool01_ooool5
o`0000kooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool3o`000004oc8b<_l0003o<S8bonk^kPoo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01_ooool2o`0000kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03oeEEEOmVIVKo000000;ooooo00Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`0=oiRHV?l@413o0000ob4Q8Oo<c<co
ooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00oooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo
0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool004Kooooo1?l00003ooooo`;o
00001?ooool3o`00017ooooo0_l000000ooooooo0000o`00000Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool2o`0000gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D_ooool004[ooooo
0ol00008ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool2o`0000gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0D_ooool005Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool005Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0D_ooool005Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Doooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo00001oooool2o`0000Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`;o00001_oo
ool00ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo001L
ooooo`Go00003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo001_oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Cooooo`00L?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0E?ooool0073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo001aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`;o00002_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Dooooo`00LOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool0
07;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo001booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Dooooo`00L_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool007?ooooo00?o
0000ooooooooool00_l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Cooooo001dooooo`?o00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o00002_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Dooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o00002_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Eooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Eooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0EOooool008Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool3o`0000Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0EOooool008Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Gooooo0029ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Eooooo`00ROooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool008[ooooo00Go0000oooooooooooo
ooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Gooooo002:ooooo`05o`000?ooooooooooooooool0
00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Eooooo`00R_ooool01?l0003oooooooooool0000Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05Gooooo002:ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0EOooool008_ooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo0ol00008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002;ooooo`?o00004_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Eooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`00X?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Eooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`00XOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Eooooo`00XOooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
ooooo`Go00001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002Q
ooooo`03o`000?oooooooooo00;ooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002Qooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP07ooooo`Co
00001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Eooooo`00X_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?oV9RHob4Q8Oo^k^h01_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Gooooo002Rooooo`04o`000?ooooooooooo`0000Oooooo00?oMgMgofIVI_ooool01Oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002Rooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Gooooo002Rooooo`04o`000?ooooooooooo`0000Cooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`00
X_ooool00ol0003oooooo`000005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00:?ooooo0_l0000@ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00Xoooool2o`00013o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo002eooooo`;o
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo002eooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00]Oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00;Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05Kooooo002eooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Fooooo`00]Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Ko
oooo002eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00;Gooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00]Oooool2o`0000Cooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Fooooo`00]Oooool00ol0003oooooooooo`03ooooo`;o00005_ooool01Ol0003ooooooooooooo
oooo000001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000005?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Gooooo`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Eoooool00;Gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0
000Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05Oooooo002eooooo`03o`000?oooooooooo01_ooooo00Co0000
oooooooooooo00005Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`00]Oooool00ol0003oooooooooo`0K
ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00;Gooooo0_l0000L
ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00;Gooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Oooooo002e
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00005Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Gooooo`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001Kooooo00Go
0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Eoooool00;Gooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00000Fooooo`05o`000?oo
ooooooooooooool000005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Oooooo
002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Looooo`;o00005ooo
ool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Gooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05Oooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Eoooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo03Gooooo00Co
0000oooooooooooo00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Oooooo
002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000eooooo`04o`000?ooooooooooo`0001So
oooo00Go0000ooooooooooooooooo`00001Jooooo`00Z_ooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooo
oooo000005[ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=Oooool0
1?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool00000F_ooool00:_ooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000001Sooooo00Go
0000ooooooooooooooooo`00001Jooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooool000006?ooool01Ol0003ooooooooooooooooo000005[ooooo
002eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool000006?ooool01Ol0003ooooooooo
oooooooo000005[ooooo002eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool000006?oo
ool01Ol0003ooooooooooooooooo000005[ooooo002eooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooool000006?ooool01Ol0003ooooooooooooooooo000005[ooooo002eooooo`;o0000=ooo
ool2o`0001Wooooo00Go0000ooooooooooooooooo`00001Jooooo`00]Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000Foooool00;Gooooo00?o
0000ooooooooool0DOooool01?l0003oooooooooool0001Kooooo`00]Oooool00ol0003ooooooooo
o`1Aooooo`04o`000?ooooooooooo`0005_ooooo002eooooo`03o`000?oooooooooo057ooooo00Co
0000oooooooooooo0000Foooool00;Gooooo00?o0000ooooooooool0DOooool01?l0003ooooooooo
ool0001Kooooo`00]Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo000005_ooooo002e
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooool00000Foooool00;Gooooo0_l0001Coooo
o`03o`000?oooooo000005_ooooo002eooooo`03o`000?oooooooooo05;ooooo00?o0000ooooool0
0000Foooool00;Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooo`00001Kooooo`00]Ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05[ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000
ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`oooo
o`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oo
oooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0
/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@
6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o410@olc<c7cooooo0025ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000cooooo00?o0000ooooooooool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q07cooooo
0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02
ooooo`05o`000?nHV9SooooooiRHV?lQ8B40O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o0000
7?ooool00ol0003oooooooooo`02ooooo`03oeEEEOn7QhOooooo07kooooo0025ooooo`06o`000?lb
<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@
4?nHV9P0O_ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omE
EEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16266 m
.01975 .16769 L
.02981 .17108 L
.0327 .17192 L
.03544 .17258 L
.04057 .1735 L
.04329 .17385 L
.04459 .17398 L
.04581 .17408 L
.04712 .17415 L
.04782 .17418 L
.04857 .17419 L
.04935 .17419 L
.0501 .17418 L
.05077 .17416 L
.0515 .17413 L
.05284 .17403 L
.05405 .17391 L
.05678 .17356 L
.06168 .17281 L
.06446 .17243 L
.0674 .17211 L
.06894 .17197 L
.07063 .17185 L
.07137 .17181 L
.07216 .17177 L
.07291 .17175 L
.07359 .17173 L
.07429 .17173 L
.07502 .17173 L
.07635 .17178 L
.07709 .17183 L
.07778 .17189 L
.07853 .17198 L
.07935 .17209 L
.08074 .17235 L
.0822 .17271 L
.08481 .17355 L
.08751 .1747 L
.09006 .176 L
.09483 .17888 L
.10554 .18667 L
.11003 .1897 L
.11249 .19102 L
.11479 .19196 L
.11599 .19234 L
.11728 .19265 L
.11801 .19279 L
.11871 .19288 L
.12001 .19299 L
Mistroke
.12121 .193 L
.12231 .19293 L
.12353 .19277 L
.12482 .1925 L
.13505 .18703 L
.14063 .18263 L
.14584 .17889 L
.14856 .17732 L
.14996 .17665 L
.15148 .17605 L
.15235 .17577 L
.15314 .17556 L
.15391 .1754 L
.15472 .17528 L
.15544 .17522 L
.15612 .1752 L
.15687 .17523 L
.15767 .17531 L
.15899 .17558 L
.15974 .17581 L
.16043 .17608 L
.16184 .17676 L
.16334 .17771 L
.16607 .18002 L
.16854 .18271 L
.17895 .19878 L
.18443 .20841 L
.18742 .21309 L
.19022 .21664 L
.19148 .21789 L
.19267 .21886 L
.19404 .21969 L
.19529 .22017 L
.19668 .22038 L
.19796 .22028 L
.19863 .22012 L
.19937 .21984 L
.20014 .21945 L
.20086 .219 L
.20332 .2168 L
.20558 .21397 L
.21066 .20528 L
.22025 .18553 L
.22302 .18051 L
.22562 .17643 L
.228 .17341 L
.23051 .17103 L
.23184 .17013 L
.2326 .16975 L
.23332 .16947 L
Mistroke
.23456 .16919 L
.2359 .1692 L
.23665 .16934 L
.23747 .16962 L
.23825 .17001 L
.23896 .17047 L
.24032 .17161 L
.24176 .17324 L
.24459 .17764 L
.24725 .18322 L
.25223 .19701 L
.2625 .23329 L
.26499 .24151 L
.26766 .24888 L
.2692 .25219 L
.2706 .25452 L
.27127 .25539 L
.272 .25614 L
.27333 .25696 L
.27453 .25709 L
.27566 .25668 L
.27689 .25565 L
.27822 .25388 L
.27954 .25148 L
.28093 .24831 L
.28341 .24121 L
.29273 .20538 L
.2979 .18577 L
.30277 .17106 L
.30546 .16498 L
.30688 .16241 L
.30838 .16018 L
.30964 .1587 L
.31031 .15806 L
.31103 .1575 L
.3123 .15681 L
.31348 .15653 L
.31476 .15662 L
.31595 .1571 L
.31726 .15806 L
.31799 .15881 L
.31865 .15961 L
.31987 .16142 L
.32118 .16386 L
.32356 .16958 L
.3259 .17684 L
.32836 .18624 L
.33277 .20727 L
.34276 .26573 L
.34563 .28035 L
Mistroke
.34705 .28624 L
.34835 .2907 L
.34954 .29386 L
.35079 .29618 L
.35206 .29739 L
.35277 .29758 L
.35345 .29741 L
.35463 .29632 L
.35593 .294 L
.35715 .29078 L
.35829 .28695 L
.36273 .26582 L
.37271 .20486 L
.37804 .17778 L
.38104 .16604 L
.3838 .15759 L
.38623 .15199 L
.3876 .14954 L
.38888 .14773 L
.39024 .1463 L
.39148 .14543 L
.39216 .14513 L
.3929 .14496 L
.39425 .14504 L
.39546 .14556 L
.39659 .14644 L
.39783 .14786 L
.39917 .14994 L
.4005 .15258 L
.4019 .156 L
.4044 .16382 L
.40888 .18363 L
.41379 .21414 L
.41887 .25391 L
.42437 .29863 L
.4269 .31565 L
.42828 .32314 L
.42957 .32871 L
.43067 .33222 L
.43186 .33466 L
.43317 .33565 L
.43437 .33497 L
.43508 .33386 L
.43584 .33211 L
.4372 .32754 L
.43881 .31995 L
.44028 .31129 L
.44589 .26823 L
.45089 .22703 L
.45636 .18902 L
Mistroke
.4615 .16354 L
.4643 .15369 L
.46691 .14686 L
.46817 .14431 L
.46936 .14233 L
.47044 .14088 L
.47159 .13969 L
.47284 .13881 L
.47399 .13836 L
.47524 .13829 L
.4766 .13869 L
.47799 .13963 L
.47868 .14031 L
.47944 .14122 L
.48079 .14326 L
.48204 .14567 L
.48487 .15308 L
.48789 .16424 L
.49075 .17826 L
.49344 .19491 L
.49848 .23539 L
.50376 .28794 L
.5087 .33572 L
.51119 .35413 L
.51259 .36173 L
.51386 .36664 L
.51458 .3685 L
.51525 .3696 L
.51598 .37012 L
.51677 .36986 L
.51807 .36756 L
.51882 .36524 L
.51952 .36242 L
.52065 .35663 L
.52189 .34868 L
.52438 .32847 L
.52885 .2844 L
.53367 .23672 L
.53891 .19487 L
.54179 .17734 L
.54444 .16438 L
.54698 .15462 L
.54967 .1468 L
.55083 .14417 L
.55208 .14179 L
.55316 .14009 L
.55433 .1386 L
.55571 .13732 L
.55701 .13653 L
.55828 .13615 L
Mistroke
.55946 .13613 L
.56084 .13651 L
.56162 .13692 L
.56234 .13743 L
.56366 .13869 L
.56505 .1405 L
.56746 .14496 L
.56883 .1483 L
.57011 .152 L
.57297 .16258 L
.57558 .17532 L
.5786 .19422 L
.58145 .21673 L
.59159 .32782 L
.59405 .35551 L
.59671 .38034 L
.59823 .39098 L
.5989 .39463 L
.59962 .39788 L
.60096 .40166 L
.60168 .40249 L
.60236 .40249 L
.60357 .40058 L
.60488 .39583 L
.60612 .38894 L
.60726 .38072 L
.61171 .33601 L
.61693 .27438 L
.6217 .22532 L
.62661 .18784 L
.62932 .17249 L
.63189 .16095 L
.63425 .15267 L
.63644 .14682 L
.63885 .14218 L
.64019 .14029 L
.64141 .13896 L
.64277 .13785 L
.64346 .13743 L
.64421 .13706 L
.64554 .13664 L
.64678 .13651 L
.64753 .13655 L
.64825 .13667 L
.64958 .13714 L
.65033 .13755 L
.65102 .13803 L
.65258 .1395 L
.65383 .14112 L
.655 .14302 L
Mistroke
.65768 .14892 L
.66028 .15702 L
.66308 .16862 L
.66574 .1828 L
.66858 .20198 L
.67368 .24952 L
.67964 .32536 L
.68256 .36485 L
.68526 .39701 L
.68659 .41008 L
.68784 .42001 L
.68914 .42765 L
.68983 .43048 L
.69057 .43253 L
.6913 .43355 L
.69211 .43346 L
.69287 .43224 L
.69357 .43014 L
.6949 .42372 L
.69557 .41932 L
.69631 .41362 L
.6988 .38902 L
.70149 .35579 L
.70634 .29084 L
.7112 .23505 L
.71386 .21117 L
.71638 .19295 L
.71936 .17606 L
.72207 .16426 L
.72461 .1557 L
.72604 .15183 L
.72737 .14875 L
.73003 .14406 L
.73144 .14227 L
.73296 .14082 L
.73372 .14027 L
.73455 .13978 L
.73533 .13941 L
.73606 .13915 L
.73743 .13885 L
.73819 .13878 L
.73889 .13878 L
.74026 .13891 L
.74152 .1392 L
.7429 .13971 L
.7436 .14005 L
.74436 .1405 L
.74565 .14145 L
.74703 .14277 L
.74952 .14614 L
Mistroke
.7508 .14846 L
.75221 .15155 L
.75507 .15969 L
.75772 .1698 L
.76021 .18193 L
.76313 .20016 L
.76581 .22157 L
.77184 .28987 L
.77718 .36844 L
.77978 .40576 L
.78214 .43426 L
.78343 .44643 L
.78464 .45519 L
.78593 .46126 L
.78665 .46314 L
.78731 .46388 L
.78862 .46248 L
.78937 .46004 L
.79006 .45671 L
.7908 .45214 L
.79147 .44706 L
.79297 .4328 L
.80348 .2865 L
.80651 .25012 L
.80935 .22253 L
.81193 .20262 L
.81466 .1861 L
.81706 .17462 L
.8197 .1648 L
.82209 .158 L
.82432 .15323 L
.82568 .15096 L
.82696 .14918 L
.82936 .14662 L
.83195 .14466 L
.83475 .1431 L
.83724 .14204 L
.83958 .14128 L
.84091 .14096 L
.84214 .14075 L
.84281 .14067 L
.84355 .1406 L
.84489 .14055 L
.84562 .14056 L
.84631 .14058 L
.84759 .14066 L
.84897 .14079 L
.85047 .14096 L
.85565 .14145 L
.85817 .14161 L
Mistroke
.86053 .14179 L
.86172 .14191 L
.86299 .14207 L
.86569 .1425 L
.87494 .14417 L
.91836 .15046 L
.94009 .15435 L
.94965 .15639 L
.96019 .15818 L
.97949 .16052 L
1 .16266 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool03oooool2o`0001[ooooo0ol00022ooooo`00[?ooool3
o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02o`0001Oooooo0_l00000
0ooooooo0000ooooo`0Hooooo`Go00007oooool00ol0003oooooooooo`12ooooo`00Zoooool00ol0
003oooooooooo`02o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Foooo
o`04o`000?ooooooooooooooo`;o00006_ooool=o`0003cooooo002Booooo`?o00005_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool2o`0000cooooo1Ol0000g
ooooo`00TOooool00ol0003oooooooooo`02o`0001Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool7o`00
033ooooo002Aooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hoooo
o`Oo0000:Oooool0097ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool08?ooool5o`0002Cooooo001hooooo`Co00005?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool09_ooool8o`0001cooooo001gooooo`;o00000_oo
ool2o`0001?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo
1_l0000Fooooo`005Oooool5o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;o000001;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`Co000000Co410@ooooooooooook^k^0_l000000olb<S;ok^k^ooooo`05oooo
o`03o`000?oooooooooo013ooooo1_l00003ooooo`05onk^k_l0003o0000oc8b<_o^k^h04Oooool0
0ol0003oooooooooo`07ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01gooooo0_l000002Ol@413o0000o`000?l0003ok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`005_ooool01?l0003oooooooooooooool5o`000003ogMgMooooooooooo01Sooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000002ooooo`05ogMgMonHV9Sooooo
oiRHV?l000004_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool01OmgMgOo0000oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?ooool01_l0003oV9RH
ob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Aooooo`03o`000?oooooo
oooo00Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo
1_l00002ooooo`Go00000oooool01?l@413oooooooooooooool2o`0000_ooooo0ol00003ooooo`Ko
00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool9o`00
0003oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool6o`0000Gooooo00?o0000ooooool000000_ooool0
1_l@413ooooooooooooooooo410@o`00017ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
013ooooo00Go0000oooooonHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo0000ooooool@41004?oo
ool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool<o`0000;ooooo1?l0000:
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oiRHV?lQ8B7ok^k^0oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`00013ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0?ooooo`07o`000?oo
oooooooooooooonHV9So8B4Qonk^kP03ooooo`05o`000?oooooo0000ooooool000004?ooool00ol0
003oooooooooo`0;ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000K
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000004_ooool2o`0000So
oooo00?o410@o`000?nj^[X00oooool00ol0003oooooooooo`06o`0001?ooooo00?o0000oooooooo
ool00oooool00ol0003oMgMgofIVIP03ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00004?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo0000ooooool000004?ooool00ol0003o
ooooooooo`0:ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Koooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41005?ooool2o`0000Oooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413o0000o`000?oooooo410@00Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool2o`0000?o
oooo00Oo410@oooooooooooooooooa0@4?oooooo000000oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4007ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00;ooooo
00?o0000oa0@4?ooool03oooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL05_ooool02Ol0003ooooooooooooooooo410@oiRHV?oooooo^[Zjo`000003ooooo`05o`00
0?nHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00Go0000okZj^_l0003oV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`07ogMgMonHV9So
oooooiRHV?mgMgOoooooo`00000?ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
00003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00[o0000oooooooo
ooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg1oooool00ol0003oooooooooo`0>ooooo`07o`00
0?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mgMgL03oooool0
0ol0003oooooooooo`09ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o
000000OoooooojVYZOl@413o0000oa0@4?nYZJWooooo00;o000000Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool00omEEEGoIVIVo`000004ooooo`07onk^k_lb<S;o0000oc8b
<_o^k^koooooo`00000>ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?oEEEEofIVI_l000000ooo
ool01_l0003ok^k^oc8b<_l0003o<S8bonk^kPOooooo00?o0000ooooooooool03Oooool02?l0003o
oooooooooonHV9So410@o`000?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`000?l0003ok^k^00oooooo
00?o0000ooooooooool02Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00>Oooool00ol0003oooooooooo`02ooooo`;o00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1<oooo
o`00>_ooool4o`0000oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo000000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0C?ooool004kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
COooool004oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooo000000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0COooool004oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0COooool0
01Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`;o
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`00DOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1>ooooo`00D_ooool2
o`0000;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool2o`0000[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C_ooool0
05?ooooo0ol0000Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1>ooooo`00J?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool2o`0000[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0C_ooool006Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00cooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo
001Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0<ooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1>ooooo`00JOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool3o`0000Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0C_ooool006Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo001Zooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`;o
00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1?ooooo`00J_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03?ooool2o`0000[ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Coooool006[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00cooooo0_l0000:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04oooooo001[ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1?ooooo`00Joooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04oooooo001/ooooo`?o00004oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Coooool0
06gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1?ooooo`00Poooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Coooool008?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04oooooo0023ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1?ooooo`00Poooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool008Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0024ooooo`05
o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo0_l00007ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0024ooooo`05o`000?oooooooooooooo
ool000004oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_l00007oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo053ooooo0024ooooo`05o`000?ooooooooooooooool000004oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
053ooooo0024ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00oooooo0_l00007ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0025ooooo`03
o`000?oooooo000001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o
00001oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1@ooooo`00QOooool00ol0003oooooo`00000Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`0000Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
D?ooool008Gooooo0ol0000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03ooo
ool2o`0000Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D?ooool009gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0?ooooo`;o00001oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`00WOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo1Ol00006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0D?ooool009gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo053ooooo002Nooooo`05o`000?ooooooooooooooool000002?ooool00onH
V9So8B4Qonk^kP07ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`00W_ooool01Ol0003o
oooooooooooooooo000000Wooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo053ooooo002Nooooo`05o`000?ooooooooooooooool000002_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool009ko
oooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0DOooool009kooooo00Co0000oooooooooooo00002?ooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1A
ooooo`00W_ooool01?l0003oooooooooool00008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooo`000005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo002Nooooo`04o`000?oooooo
ooooo`0001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Aooooo`00W_oo
ool00ol0003oooooo`00000Dooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
DOooool009oooooo0_l0000Dooooo`;o000000?oooooo`000?ooool00oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Aooooo`00X?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0DOooool00;Gooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Aooooo`00]Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo002e
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool00;Gooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Aooooo`00]Oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo057ooooo002eooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0DOooool00;Gooooo00Oo0000ooooooooooooooooo`000?oooooo000001Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057ooooo
002eooooo`;o00000_ooool00ol0003oooooo`00000Gooooo`05o`000?ooooooooooooooool00000
5oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Booooo`00]Oooool01ol0003ooooooooooooooooo0000ooooool0
00005oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D_ooool00;Go
oooo00?o0000ooooooooool00_ooool2o`0001Oooooo00Go0000ooooooooooooooooo`00000Goooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05;ooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05;ooooo002eooooo`03
o`000?oooooooooo01cooooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Boooo
o`00]Oooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`0001Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0D_ooool00;Gooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000Goooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05;ooooo002eooooo`03o`000?oooooooooo01cooooo00Co0000oooooooo
oooo00006?ooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Booooo`00]Oooool2o`0001gooooo00Co0000oooooooooooo00006?ooool0
1Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Booooo`00]Oooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`0001Sooooo00Go
0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
D_ooool00;Gooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000Hooooo`05o`00
0?ooooooooooooooool000006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05;o
oooo002eooooo`03o`000?oooooooooo01gooooo0_l0000Iooooo`05o`000?ooooooooooooooool0
00006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05;ooooo002eooooo`03o`00
0?oooooooooo01gooooo0_l0000Iooooo`05o`000?ooooooooooooooool000006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05;ooooo002/ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05;ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000Jooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0D_ooool00:[ooooo1Ol00006ooooo`03o`00
0?oooooooooo03Sooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05;ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000hooooo`04
o`000?ooooooooooo`0001[ooooo00Go0000ooooooooooooooooo`00001Eooooo`00Z_ooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000006_ooool0
1Ol0003ooooooooooooooooo000005Gooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0>Oooool00ol0003oooooo`00000Jooooo`05o`000?ooooooooooooooool00000EOoo
ool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
000001_ooooo00Co0000oooooooooooo0000EOooool00:cooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooo000001_ooooo00Co0000oooooooooooo0000EOoo
ool00;Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`00000Kooooo`04o`000?oooooo
ooooo`0005Gooooo002eooooo`03o`000?oooooooooo03Wooooo0ol0000Kooooo`04o`000?oooooo
ooooo`0005Gooooo002eooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool06_ooool0
1?l0003oooooooooool0001Eooooo`00]Oooool2o`0005Sooooo00Co0000oooooooooooo0000EOoo
ool00;Gooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool0001Eooooo`00]Oooool0
0ol0003oooooooooo`1Gooooo`04o`000?ooooooooooo`0005Gooooo002eooooo`03o`000?oooooo
oooo05Oooooo00Co0000oooooooooooo0000EOooool00;Gooooo00?o0000ooooooooool0Eoooool0
1?l0003oooooooooool0001Eooooo`00]Oooool00ol0003oooooooooo`1Hooooo`;o0000E_ooool0
0;Gooooo00?o0000ooooooooool0F?ooool2o`0005Kooooo002eooooo`03o`000?oooooooooo05So
oooo0_l0001Fooooo`00]Oooool2o`0005Wooooo0_l0001Fooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo
002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zj
o`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002c
ooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X06Oooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<alooooo`00QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007cooooo0025
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o0000ooooooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b07cooooo0025ooooo`06
o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
0_ooool01Oo<c<co0000o`000?l0003oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mE
EEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj
^[[o410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`00001looooo`00Q?ooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .17246 m
.00123 .17267 L
.00236 .17282 L
.00365 .17295 L
.00488 .17302 L
.00601 .17303 L
.00706 .173 L
.00821 .17291 L
.00942 .17276 L
.01065 .17255 L
.01196 .17227 L
.01434 .17164 L
.01975 .16984 L
.0297 .16622 L
.03243 .16534 L
.03393 .16494 L
.03534 .16463 L
.03665 .16442 L
.0374 .16433 L
.03808 .16427 L
.03929 .16422 L
.04057 .16425 L
.0413 .16431 L
.04198 .16438 L
.04275 .16449 L
.04349 .16463 L
.04479 .16493 L
.04621 .16536 L
.04943 .16667 L
.05241 .16835 L
.05787 .17262 L
.06367 .17861 L
.07384 .18942 L
.07663 .1918 L
.07815 .1929 L
.07956 .19378 L
.08088 .19447 L
.08207 .19496 L
.08339 .19535 L
.08412 .19549 L
.08481 .19557 L
.08599 .1956 L
.08729 .19546 L
.08864 .19512 L
.08991 .19464 L
.0911 .19403 L
.09218 .19337 L
.09462 .1915 L
.10007 .18591 L
.10525 .17954 L
Mistroke
.1097 .17393 L
.11444 .16862 L
.11716 .1662 L
.11963 .16454 L
.12082 .16395 L
.12211 .16346 L
.12333 .16315 L
.12445 .16301 L
.12578 .163 L
.12704 .16318 L
.12817 .16348 L
.1294 .16399 L
.13073 .16474 L
.13215 .16577 L
.1347 .16828 L
.13704 .17134 L
.13924 .17485 L
.14425 .18483 L
.15484 .21019 L
.15741 .21582 L
.16015 .22093 L
.16173 .2233 L
.16317 .22501 L
.16386 .22568 L
.16461 .22627 L
.16596 .22701 L
.16729 .22728 L
.16852 .22714 L
.16988 .22653 L
.17064 .22599 L
.17134 .22538 L
.17273 .2238 L
.17425 .2216 L
.17702 .21644 L
.1872 .19001 L
.19202 .17706 L
.19455 .171 L
.19722 .16544 L
.19957 .16136 L
.20213 .15783 L
.20326 .15661 L
.20447 .15552 L
.20561 .15471 L
.20664 .15417 L
.2079 .15375 L
.20907 .15361 L
.21035 .15375 L
.21171 .15424 L
.21288 .15495 L
.21398 .15587 L
Mistroke
.21519 .15717 L
.21649 .15891 L
.21941 .16413 L
.22218 .17078 L
.22738 .18746 L
.23805 .23291 L
.24113 .24543 L
.24402 .25513 L
.24528 .25847 L
.24662 .26129 L
.24732 .26245 L
.24808 .26348 L
.24943 .2646 L
.2501 .26483 L
.25082 .26483 L
.25215 .26418 L
.25343 .26273 L
.25462 .26071 L
.25591 .25784 L
.25733 .25391 L
.26019 .24384 L
.27024 .1983 L
.27504 .17812 L
.27755 .16912 L
.2802 .16105 L
.28253 .15517 L
.28508 .15004 L
.2862 .14821 L
.2874 .14655 L
.28851 .14528 L
.28955 .14433 L
.29085 .14347 L
.29153 .14316 L
.29227 .14294 L
.29305 .14284 L
.29378 .14288 L
.29515 .14327 L
.29644 .14403 L
.29762 .14508 L
.29893 .14663 L
.30032 .14874 L
.30347 .15538 L
.30644 .16406 L
.31198 .18703 L
.32228 .24926 L
.325 .26635 L
.3279 .28235 L
.32931 .28877 L
.33065 .2938 L
.33184 .29736 L
Mistroke
.33314 .3001 L
.33436 .30153 L
.33569 .30183 L
.33636 .30146 L
.33708 .30068 L
.33839 .29829 L
.33969 .29472 L
.34092 .29028 L
.34323 .27959 L
.35428 .21004 L
.35878 .18476 L
.36357 .16369 L
.36632 .15442 L
.36882 .14776 L
.37133 .14267 L
.3737 .13927 L
.37492 .13803 L
.37622 .13708 L
.37746 .13652 L
.37858 .1363 L
.3799 .1364 L
.38065 .13662 L
.38133 .13693 L
.3826 .13777 L
.38394 .13906 L
.38522 .14068 L
.3866 .14289 L
.38909 .14817 L
.39205 .15683 L
.39477 .16731 L
.39928 .19052 L
.40422 .22423 L
.40899 .26276 L
.41416 .3036 L
.41556 .31291 L
.41705 .32136 L
.41832 .32721 L
.41904 .32994 L
.41971 .332 L
.42101 .33476 L
.42173 .33555 L
.42241 .33579 L
.42363 .33503 L
.42495 .33248 L
.42624 .32833 L
.42741 .32325 L
.43003 .30798 L
.43475 .27188 L
.44032 .22671 L
.44621 .18716 L
Mistroke
.45123 .16287 L
.45408 .15287 L
.45674 .14578 L
.458 .1431 L
.45937 .14065 L
.46057 .13886 L
.46185 .13731 L
.46301 .13621 L
.46428 .1353 L
.46543 .13473 L
.46651 .13443 L
.4678 .13436 L
.46914 .13462 L
.47029 .13513 L
.47155 .13601 L
.47291 .13734 L
.47437 .13925 L
.47698 .14404 L
.47981 .15139 L
.48288 .16216 L
.48578 .17539 L
.48844 .19054 L
.4935 .22794 L
.49885 .27813 L
.50129 .30223 L
.50395 .32679 L
.50629 .34509 L
.50757 .35316 L
.50878 .35922 L
.51015 .3641 L
.51088 .36576 L
.51167 .3668 L
.51235 .36707 L
.51307 .36671 L
.51435 .36445 L
.51561 .36028 L
.51678 .35475 L
.51944 .33713 L
.52866 .25066 L
.53352 .20992 L
.53868 .17797 L
.5414 .16541 L
.54441 .15454 L
.54714 .14705 L
.5497 .14192 L
.55104 .13988 L
.55232 .13832 L
.55347 .13723 L
.55472 .13632 L
.55608 .13566 L
Mistroke
.55683 .13542 L
.55752 .13528 L
.55886 .13522 L
.56012 .1354 L
.56125 .13576 L
.56249 .13638 L
.56379 .1373 L
.565 .13844 L
.56717 .14124 L
.56949 .1455 L
.57221 .15243 L
.57479 .1612 L
.57729 .17196 L
.57963 .18434 L
.58445 .21799 L
.58977 .26905 L
.59539 .33238 L
.59785 .35799 L
.59915 .36975 L
.60054 .38044 L
.60177 .38798 L
.60289 .39306 L
.60401 .39635 L
.60507 .3977 L
.60626 .39716 L
.60736 .39475 L
.60857 .39007 L
.60985 .38295 L
.61232 .3638 L
.61462 .34109 L
.61988 .28274 L
.62511 .23021 L
.62787 .20795 L
.63081 .18871 L
.63364 .1741 L
.6362 .1637 L
.63877 .1555 L
.64119 .14954 L
.64356 .14512 L
.64486 .14323 L
.64606 .14177 L
.64718 .14067 L
.6482 .13986 L
.64933 .13915 L
.65055 .13861 L
.65184 .13826 L
.65304 .13813 L
.65435 .13819 L
.65501 .13831 L
.65574 .13849 L
Mistroke
.65696 .13894 L
.65828 .13964 L
.65952 .14051 L
.66065 .1415 L
.662 .14295 L
.66327 .14461 L
.66565 .14863 L
.66821 .15452 L
.67098 .1631 L
.67341 .17283 L
.67597 .18575 L
.68057 .21711 L
.69106 .33279 L
.69383 .36727 L
.69529 .38387 L
.69684 .39941 L
.69819 .41063 L
.69891 .41556 L
.69969 .41999 L
.70105 .42539 L
.70232 .42754 L
.70363 .42675 L
.70437 .42496 L
.70506 .42245 L
.70579 .41892 L
.70645 .41498 L
.70794 .40379 L
.71059 .37731 L
.71309 .34737 L
.71821 .28392 L
.72292 .23465 L
.7274 .20018 L
.72966 .18699 L
.73215 .17523 L
.73465 .16597 L
.73732 .15839 L
.73985 .15311 L
.74217 .14954 L
.74352 .1479 L
.7448 .1466 L
.74718 .14474 L
.74851 .14396 L
.74974 .14342 L
.75109 .14299 L
.75177 .14285 L
.75252 .14274 L
.75377 .14269 L
.75492 .14277 L
.75624 .14303 L
.75749 .14344 L
Mistroke
.75864 .14395 L
.75971 .14454 L
.76212 .14629 L
.76471 .14888 L
.76714 .15215 L
.76981 .15699 L
.77268 .16416 L
.77553 .17386 L
.77853 .1875 L
.78109 .20248 L
.78389 .22309 L
.78945 .27947 L
.79469 .3494 L
.79946 .41259 L
.80186 .43686 L
.80323 .4468 L
.8045 .45308 L
.80589 .45634 L
.80715 .45596 L
.80785 .45438 L
.80861 .45156 L
.81 .44365 L
.81127 .43347 L
.81263 .42 L
.81506 .39064 L
.82103 .30924 L
.82364 .27684 L
.82651 .24655 L
.82906 .2244 L
.83178 .20528 L
.83467 .18947 L
.83735 .1781 L
.83886 .17294 L
.8405 .16821 L
.84194 .16473 L
.84348 .16165 L
.84638 .15723 L
.84905 .15434 L
.85156 .15231 L
.85426 .15062 L
.85681 .14941 L
.85794 .14899 L
.85914 .14862 L
.85988 .14843 L
.86055 .14829 L
.86186 .14808 L
.8626 .14799 L
.86339 .14793 L
.86415 .14789 L
.86484 .14788 L
Mistroke
.86609 .14788 L
.86747 .14791 L
.86816 .14793 L
.86891 .14796 L
.87025 .14801 L
.87294 .14811 L
.87441 .14816 L
.8758 .14822 L
.87697 .1483 L
.87824 .1484 L
.87964 .14856 L
.88093 .14874 L
.88659 .14988 L
.89255 .15111 L
.90276 .15324 L
.90838 .15463 L
.91368 .15557 L
.91889 .15623 L
.92163 .15658 L
.92453 .15694 L
.92571 .15706 L
.92698 .15717 L
.9277 .15723 L
.92837 .15727 L
.92967 .15732 L
.93083 .15734 L
.9321 .15734 L
.93329 .15733 L
.9344 .1573 L
.93561 .15727 L
.93693 .15723 L
.93816 .15721 L
.9393 .15719 L
.94033 .15719 L
.94146 .15719 L
.94264 .15721 L
.94374 .15723 L
.94891 .15736 L
.95118 .15741 L
.95247 .15745 L
.95368 .1575 L
.95492 .15756 L
.95624 .15767 L
.95766 .15782 L
.95896 .158 L
.96175 .15852 L
.96468 .15926 L
.97509 .16273 L
.9852 .16739 L
.98974 .16942 L
Mistroke
.99459 .17113 L
.99743 .1719 L
1 .17246 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool008gooooo0ol0000Iooooo`Co00002?ooool00ol0003oooooooooo`0>ooooo`Co0000W_oo
ool008gooooo00Co0000ooooool0003o00005oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000ooooooooool05ooo
ool5o`0007oooooo001booooo`?o00005oooool01?l0003oooooooooooooool2o`0001Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`;o00000oooool00ol0003ooooooooo
o`0Iooooo`Co0000H?ooool0077ooooo0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`;o00000_ooool2
o`0005oooooo001aooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01[ooooo3?l0000fooooo`00L?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hoooo
o`;o00002oooool3o`0003?ooooo001Gooooo`Co00005Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool03_ooool6o`0002gooooo001Fooooo`04o`000?ooooooooooooooo`;o00005?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo4?l0000Mooooo`00EOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01[ooooo000Eooooo`;o000000Wo410@oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h01Ol0000Eooooo`03oiRHV?l@413o000000?o00000_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`Go00000oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooo`000003o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^k_oo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2?ooool00ol0003oooooooooo`0?ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool04oooool02?l0003ooooo
oooooonHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo1Ol0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2o`0001?ooooo0_l000001?oooooo
MgMgoc8b<_ooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?l000002?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
00001?ooool01OmgMgOo0000oooooonHV9SoMgMg00kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`08
ooooo`03o`000?oooooooooo00oooooo00GoV9RHob4Q8Oo^k^ko0000odA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Booooo`09o`000?ooooooooooooooool@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`;o00001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000;ooooo1?l0
00000ooooooo410@ooooo`06ooooo`03o`000?oooooooooo00Sooooo1_l00002ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo
00?o0000ooooooooool00oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool02?ooool6o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool00_ooool01Ol@413o0000oooooooooooo410@00kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go410@o`00
0?oooooooooooa0@4009ooooo`03o`000?oooooooooo00oooooo00?oV9RHob4Q8Ol000001?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Iooooo`Oo0000
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`004oooool00om4A4CogMgMoooo
o`04o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0>ooooo`06o`000?oooooooooooooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00kooooo00Go0000
ooooooooooooooooo`000004ooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`04ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04
odA4A?oMgMgoooooo`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00cooooo000Cooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo00cooooo00Oo0000oooooooooooooooooa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00omgMgOo
IVIVooooo`02ooooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo0000
00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0
003oMgMgofIVIP03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?l0003oooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00Go0000oooooooooooooooooa0@4002ooooo`03o`000?l@413ooooo00Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go410@
ooooool0003ooooooa0@400=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool2o`0000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00Go410@o`000?oooooooooooa0@4009ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003oooooooooo`09ooooo`08o`000?oooooooooooa0@4?nHV9SooooookZj^_l00003ooooo`05
ogMgMol0003ooooooiRHV?mgMgL02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mgMgL02_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHo`000?nHV9SoMgMg00gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0:ooooo`03
o`000?oooooooooo00gooooo0_l000000oooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool01oooool02Ol0003ooooo
ooooooooooooZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool00ol0003oooooooooo`09ooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0:ooooo`03o`000?oooooooooo00cooooo00Ko0000
ooooooooooooEEEEofIVI_l00004ooooo`05onk^k_lb<S;o0000o`000?o^k^h03Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000o`000?lb<S;o
k^k^00[ooooo00?o0000ooooooooool03Oooool01OnHV9So0000o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Moooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00;Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`16
ooooo`00;_ooool2o`0000?ooooo0_l0000@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool0
02oooooo1Ol0000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool004Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`16ooooo`00A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`16ooooo`005_ooooooo`00
043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00007ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo0018ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04Kooooo0018ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo0019ooooo`05o`000?oo
ooooooooooooool000004_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo
0019ooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Aoooool004[ooooo0ol0000Dooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0Aoooool0067ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`17oooo
o`00HOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo001Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0B?ooool0067ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000
2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`18ooooo`00H_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0000Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?oo
ool006;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo013ooooo0_l00008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Sooooo001Rooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o00002?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`18ooooo`00Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool2o`0000Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?ooool006?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
0_l00008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo04Sooooo001Tooooo`04o`000?ooooooooooo`0001Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04?ooool3o`0000Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?ooool006Cooooo00Co
0000ooooool0003o00005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`;o00002?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`18ooooo`00IOooool2o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool2o`0000Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0BOooool007gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo04Wooooo001mooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`19ooooo`00OOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool007kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Wooooo001nooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00O_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00O_ooool01Ol0
003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool007oooooo00Co0000oooo
oooooooo00005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00Ooooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo04Wooooo001oooooo`04o`000?ooooooooooo`0001Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0B_ooool0083ooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo0020ooooo`;o
00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo1Ol00006ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04[ooooo002Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP07ooooo`?o00001?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1:ooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo002J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009[ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04[ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo0_l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo002Jooooo`05o`000?oooooo
ooooooooool000002oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo0_l00004ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04[ooooo002Kooooo`03o`000?oooooo000001Oooooo0_l00004ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04[ooooo002Kooooo`03o`000?oooooo000001Oooooo0_l00004ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo002Looooo`;o00005oooool2o`0000Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool009co
oooo00?o0000ooooooooool05_ooool2o`0000Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00;Gooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`00]Oooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04_ooooo002eooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Boooool00;Gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1;oooo
o`00]Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo002eooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00;Gooooo00Ko0000oooooooooooo0000
ooooool0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1;ooooo`00]Oooool2o`000004ooooool0003oooooo`0001Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo002eooooo`03o`00
0?oooooooooo00;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Boooool00;Gooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`00]Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0
003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool0
0;Gooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0000Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04cooooo002eooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00006_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1<ooooo`00]Oooool2o`0001kooooo00Co0000oooooooooooo00006_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1<ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000
01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0C?ooool00;Gooooo00?o0000ooooooooool07_ooool2o`0001co
oooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04cooooo002eooooo`03o`000?oooooooooo01kooooo0_l0000Looooo`04o`000?ooooooooooo`00
01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0003o
ooooooooo`0looooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1<ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0C?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`04
o`000?ooooooooooo`0001cooooo00Go0000ooooooooooooooooo`00001?ooooo`00Z_ooool5o`00
00Kooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0000Looooo`05o`000?oooooo
ooooooooool00000Coooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`0003cooooo00Co
0000oooooooooooo00007?ooool01Ol0003ooooooooooooooooo000004oooooo002Zooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0000Loooo
o`05o`000?ooooooooooooooool00000Coooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`0looooo`03o`000?oooooo000001gooooo00Go0000ooooooooooooooooo`00001?
ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ool000007Oooool01Ol0003ooooooooooooooooo000004oooooo002/ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0?Oooool2o`0001gooooo00Go0000ooooooooooooooooo`00001?
ooooo`00]Oooool00ol0003oooooooooo`0mooooo`;o00007_ooool01?l0003oooooooooool0001?
ooooo`00]Oooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo002eoooo
o`03o`000?oooooooooo05gooooo00Co0000oooooooooooo0000Coooool00;Gooooo0_l0001Noooo
o`04o`000?ooooooooooo`0004oooooo002eooooo`03o`000?oooooooooo05gooooo00Co0000oooo
oooooooo0000Coooool00;Gooooo00?o0000ooooooooool0GOooool01?l0003oooooooooool0001?
ooooo`00]Oooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo002eoooo
o`03o`000?oooooooooo05gooooo00?o0000ooooool00000D?ooool00;Gooooo00?o0000oooooooo
ool0G_ooool2o`00053ooooo002eooooo`03o`000?oooooooooo05kooooo0_l0001@ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?o
oooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo0025ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooo
ooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@401looooo`00
QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooo
ooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000;
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[o
EEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o410@o`000?l000000ol0000Mooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00Q?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1571 m
.00123 .1568 L
.00236 .1566 L
.00365 .15647 L
.00488 .15645 L
.00601 .15651 L
.00706 .15664 L
.00821 .15686 L
.00942 .15719 L
.01065 .15762 L
.01196 .15818 L
.01434 .15949 L
.01716 .16154 L
.01975 .16392 L
.02485 .16994 L
.03042 .17791 L
.03565 .18565 L
.04057 .1922 L
.04336 .19525 L
.04484 .19656 L
.04639 .1977 L
.0477 .19844 L
.04845 .19876 L
.04914 .19899 L
.05036 .19924 L
.05167 .19927 L
.05246 .19918 L
.05319 .19901 L
.054 .19874 L
.05485 .19836 L
.05628 .1975 L
.05786 .19625 L
.06078 .19321 L
.06351 .18964 L
.07388 .17258 L
.07954 .16346 L
.0823 .1597 L
.08481 .15684 L
.08733 .15454 L
.0897 .15293 L
.09101 .1523 L
.09221 .15189 L
.09353 .15162 L
.0942 .15156 L
.09493 .15156 L
.09567 .15162 L
.09637 .15175 L
.09769 .15216 L
.09842 .1525 L
.0991 .15287 L
Mistroke
.10065 .15396 L
.10324 .15656 L
.106 .16038 L
.11125 .17052 L
.1162 .18308 L
.12543 .21059 L
.13033 .22333 L
.13168 .22609 L
.13312 .22859 L
.13447 .23046 L
.13571 .23173 L
.1371 .23264 L
.13838 .23298 L
.13905 .23296 L
.13979 .23278 L
.14056 .23242 L
.14128 .23192 L
.14261 .23061 L
.14382 .22899 L
.14655 .22392 L
.15108 .21209 L
.15602 .19634 L
.16596 .16589 L
.16864 .15936 L
.17153 .15335 L
.17408 .14905 L
.17548 .14711 L
.17678 .14558 L
.17805 .14434 L
.17922 .14344 L
.18051 .1427 L
.18189 .14222 L
.18305 .14206 L
.18431 .14215 L
.18549 .14248 L
.1866 .14301 L
.18785 .14387 L
.18921 .14511 L
.19166 .14823 L
.19458 .15345 L
.19726 .15978 L
.20279 .17766 L
.20861 .20276 L
.21375 .22766 L
.21861 .24945 L
.2213 .25897 L
.22282 .26313 L
.22354 .26476 L
.22422 .26606 L
.22539 .26779 L
Mistroke
.22669 .26886 L
.22795 .26905 L
.22931 .2683 L
.23059 .2667 L
.23178 .26447 L
.23308 .26125 L
.23447 .257 L
.23938 .23689 L
.24859 .19201 L
.25385 .16994 L
.2594 .15238 L
.2623 .14573 L
.26384 .14289 L
.26549 .14035 L
.267 .13845 L
.26838 .13707 L
.26977 .13602 L
.27109 .13533 L
.2723 .13496 L
.27364 .13484 L
.27432 .1349 L
.27504 .13506 L
.27636 .1356 L
.2776 .1364 L
.2789 .13757 L
.28123 .14055 L
.28256 .14275 L
.28397 .14553 L
.28651 .15171 L
.28953 .16114 L
.29227 .17176 L
.29737 .19695 L
.30276 .23023 L
.30742 .2607 L
.30999 .27594 L
.31243 .28803 L
.31377 .29336 L
.31448 .29572 L
.31524 .29788 L
.31657 .3007 L
.31781 .30216 L
.31917 .30244 L
.32044 .30142 L
.32159 .29948 L
.32283 .29632 L
.32422 .29158 L
.32574 .28507 L
.3288 .26859 L
.33427 .23337 L
.3398 .199 L
Mistroke
.34503 .17278 L
.34972 .1553 L
.35237 .14782 L
.35481 .14236 L
.35607 .14005 L
.35743 .13793 L
.35861 .1364 L
.35989 .13503 L
.36066 .13435 L
.36138 .13381 L
.36213 .13335 L
.36281 .13301 L
.3641 .13257 L
.36548 .13239 L
.36619 .13242 L
.36694 .13253 L
.36828 .13295 L
.36902 .13331 L
.36972 .13373 L
.3713 .13499 L
.37269 .13648 L
.37395 .13816 L
.37679 .14321 L
.37919 .14899 L
.38184 .15715 L
.3872 .18007 L
.39216 .20966 L
.39682 .24423 L
.40193 .28503 L
.40472 .30508 L
.40731 .32003 L
.40867 .3259 L
.40937 .3283 L
.41013 .3304 L
.41096 .33209 L
.41174 .33308 L
.4125 .33347 L
.41321 .33331 L
.41446 .33185 L
.41584 .32852 L
.41653 .3262 L
.41727 .32325 L
.41862 .31681 L
.42865 .24361 L
.43416 .20394 L
.43934 .17534 L
.4423 .16301 L
.4455 .15256 L
.4484 .14531 L
.45107 .1403 L
Mistroke
.45359 .13687 L
.45503 .13544 L
.45636 .13442 L
.45709 .13398 L
.45777 .13365 L
.45906 .13322 L
.46044 .13302 L
.46122 .13303 L
.46195 .13311 L
.46319 .13342 L
.46434 .1339 L
.46559 .13463 L
.46691 .13566 L
.46914 .13804 L
.47157 .1417 L
.47424 .14716 L
.47708 .155 L
.47976 .16457 L
.48219 .17533 L
.4875 .20653 L
.49325 .25282 L
.49864 .30313 L
.50128 .32613 L
.50368 .34373 L
.50486 .35065 L
.50615 .35662 L
.50736 .36063 L
.50848 .36281 L
.50967 .36348 L
.51098 .36224 L
.51235 .35879 L
.51364 .35363 L
.51497 .3465 L
.51638 .33728 L
.5189 .31738 L
.52458 .26542 L
.52968 .22213 L
.53513 .18665 L
.53827 .17162 L
.54112 .16093 L
.54398 .15263 L
.54669 .14668 L
.54919 .14255 L
.55153 .13971 L
.55288 .13848 L
.55411 .13758 L
.55478 .13718 L
.55552 .13681 L
.55687 .13631 L
.5576 .13614 L
Mistroke
.55829 .13604 L
.55958 .136 L
.56097 .13618 L
.56175 .13639 L
.56247 .13663 L
.56367 .13719 L
.565 .13801 L
.56638 .1391 L
.56767 .14037 L
.57018 .14358 L
.57256 .14768 L
.57469 .15242 L
.57701 .15891 L
.57954 .1678 L
.58222 .17967 L
.58703 .20842 L
.59217 .25105 L
.59687 .29928 L
.60194 .35138 L
.60333 .36349 L
.60481 .37456 L
.60621 .38285 L
.60748 .38829 L
.60868 .39145 L
.60979 .39258 L
.61101 .3918 L
.61229 .38872 L
.61341 .38424 L
.61445 .37863 L
.61683 .36145 L
.62668 .26253 L
.63191 .2176 L
.63487 .1979 L
.63761 .18316 L
.6402 .17199 L
.64263 .16363 L
.64544 .15619 L
.64798 .15114 L
.65036 .14759 L
.65286 .14482 L
.655 .1431 L
.65621 .14235 L
.65734 .1418 L
.65866 .14132 L
.6599 .14103 L
.66101 .1409 L
.66222 .1409 L
.66354 .14106 L
.66421 .1412 L
.66494 .14141 L
Mistroke
.66624 .14191 L
.66745 .14252 L
.67015 .14442 L
.67265 .14692 L
.6754 .15069 L
.67834 .15625 L
.68113 .16344 L
.68376 .17233 L
.68616 .18252 L
.68869 .19585 L
.69355 .23024 L
.69803 .27333 L
.70331 .33473 L
.70813 .38764 L
.70932 .39797 L
.71058 .40716 L
.71196 .41478 L
.71324 .41931 L
.71442 .42118 L
.71553 .42086 L
.71676 .41819 L
.71807 .4127 L
.71937 .40487 L
.72078 .39384 L
.72363 .36561 L
.72873 .30633 L
.73355 .25485 L
.7362 .23164 L
.7387 .21329 L
.74103 .19909 L
.74356 .18646 L
.74587 .17712 L
.74798 .17021 L
.75045 .16384 L
.75311 .15873 L
.75557 .15528 L
.7579 .15284 L
.76061 .15072 L
.76313 .14926 L
.76458 .1486 L
.76589 .14813 L
.76662 .14791 L
.7674 .14773 L
.76815 .14759 L
.76883 .14751 L
.77011 .14745 L
.77148 .14753 L
.77277 .14773 L
.77395 .14803 L
.77534 .14849 L
Mistroke
.77684 .14914 L
.77957 .15066 L
.78243 .1528 L
.78547 .15598 L
.78806 .15983 L
.79092 .16576 L
.79339 .17268 L
.79609 .18252 L
.79891 .19577 L
.80153 .21134 L
.80623 .24907 L
.81125 .30498 L
.81716 .38233 L
.82006 .41586 L
.82134 .42783 L
.82273 .43838 L
.82399 .4452 L
.82517 .44907 L
.82641 .45043 L
.82774 .4487 L
.82843 .44652 L
.82919 .44316 L
.83057 .4346 L
.83192 .42353 L
.83316 .41122 L
.83852 .34527 L
.8443 .27512 L
.84696 .24917 L
.84976 .22683 L
.85218 .21129 L
.85477 .19796 L
.8573 .18771 L
.8596 .18038 L
.86192 .17464 L
.86411 .1705 L
.86665 .16692 L
.86901 .1645 L
.87159 .1625 L
.87433 .16084 L
.87697 .15952 L
.87949 .1585 L
.88177 .15775 L
.88421 .15713 L
.88684 .15661 L
.88929 .15619 L
.89484 .15512 L
.89733 .15458 L
.90003 .15403 L
.90126 .15382 L
.90257 .15362 L
Mistroke
.9037 .15348 L
.90491 .15336 L
.90609 .15327 L
.90717 .15321 L
.90825 .15317 L
.90927 .15314 L
.91046 .15312 L
.91156 .15312 L
.91277 .15313 L
.91405 .15315 L
.91525 .15319 L
.91655 .15327 L
.91791 .15339 L
.91918 .15354 L
.92037 .15374 L
.92146 .15395 L
.92389 .15459 L
.9265 .1555 L
.92934 .1567 L
.93449 .15922 L
.94441 .16508 L
.94926 .16814 L
.95368 .17048 L
.95614 .17149 L
.95847 .17224 L
.95967 .17254 L
.96094 .17281 L
.96167 .17293 L
.96233 .17303 L
.96362 .17316 L
.96431 .1732 L
.96503 .17323 L
.96633 .17321 L
.96705 .17317 L
.96772 .1731 L
.96846 .173 L
.96925 .17287 L
.97068 .17254 L
.97203 .17214 L
.97455 .17114 L
.98005 .16816 L
.98514 .16498 L
.99061 .16158 L
.99373 .15979 L
.99664 .15834 L
1 .1571 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool008Wooooo0ol0000Kooooo`Co0000
2_ooool00ol0003oooooooooo`2`ooooo`00Joooool4o`0001Wooooo0_l00002ooooo`03o`000?oo
oooooooo01Oooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_oo
ool4o`0009kooooo001Zooooo`;o00000_ooool2o`0001Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0=ooooo`;o00000oooool00ol0003oooooooooo`2Kooooo`00Coooool3o`00
01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Sooooo1Ol0001mooooo`00C_ooool00ol0003oooooooooo`02o`0001Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1jooooo`00COooool2o`0000Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo1Ol0001Jooooo`00<_oo
ool4o`0001Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05oooool2o`0000Gooooo0_l0000Xooooo`03o`000?oo
oooooooo02gooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`go0000:_ooool0
01Kooooo1?l0000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool3o`00
00gooooo0ol0000Booooo`;o00004oooool001[ooooo0_l0000Dooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05oooool3o`0001?ooooo00?o0000ooooooooool03?ooool3o`0001Go
oooo000Eooooo`;o000000Go410@ooooooooooooooooonk^kP02o`000003oc8b<_o^k^kooooo00ko
oooo00?o0000ooooooooool01Oooool02?l0003ooooooooooonHV9So410@o`000?lb<S;oc<c<0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`Ko00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`03ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bo`0000cooooo00?o0000ooooooooool02oooool5o`0000?ooooo
00Go0000oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo017ooooo00KoV9RHoa0@4?l0
003o<S8bolc<c?l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0000_ooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9So0000oiRHV?mgMgL03oooool00ol0003oooooooooo`06oooo
o`07o`000?oooooo410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00KoV9RHob4Q8Oo^k^ko
ooooodA4A?l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Kooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooooonH
V9SoMgMg3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9So000000cooooo00?o0000ooooooooool02oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go0000oiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo013ooooo00Ko410@okZj^_ooooooMgMgoc8b<_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@
oooooooooooo0000oa0@400>ooooo`04o`000?ooooooooooooooo`Ko000000?oooooo`000?ooool0
0oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo1_l00003ooooo`05oiRHV?lQ8B7ok^k^oooo
ool000000_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool03?ooool6
o`0000Gooooo00Ko0000oooooooooooo0000ooooool@4103ooooo`03oa0@4?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Go410@ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^
k^h00oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool2o`00
00Gooooo1_l00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgM
gOoooooo00001?ooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool02Oooool0
1_l0003oooooooooooooooooZJVYoa0@40?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool01?nHV9So8B4Qonk^k_l00002oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00gooooo00?oV9RHob4Q8Oo^
k^h00_ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03
o`000?l@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`Go000000GoooooodA4
A?oMgMgoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00kooooo00KoMgMgofIVI_oooooo
0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo000000cooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooonj^[[o8B4Q00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00Ko0000
ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@00go
oooo00?o0000ooooooooool03_ooool01Ol0003oooooo`000?oooooo410@00?ooooo00?o410@oooo
ooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?nj^[[o8B4Q00?ooooo00Go410@oooo
oooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@
400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo0000
2_ooool00ol0003oooooooooo`0<ooooo`05oa0@4?l0003ooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`05o`000?nj^[[ooooooiRHV?l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`0:o`000?ooooooooooooooool0003o
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0=ooooo`03o`000?oo
oooooooo00[ooooo00Ko0000okZj^_ooooooV9RHoa0@4?l00002ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02Oooool00ol0003oooooooooo`0?ooooo`05oa0@4?nHV9So0000okZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Ook^k^oc8b<_l0003o<S8b
onk^k_oooooo000000Wooooo00?o0000ooooooooool03?ooool01OnYZJWo0000o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7o000000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00omEEEGoIVIV
o`000003ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?l0003o
k^k^00gooooo00?o0000ooooooooool02_ooool01_nHV9So410@o`000?lQ8B7oc<c<o`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00oooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0?_ooool0
02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0?_ooool002?ooooo0_l00003ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`009?ooool5o`0001Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`00?Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03oooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo000nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@?ooool003kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`10ooooo`00?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`11ooooo`00?oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`11ooooo`00@?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`11ooooo`00@?ooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@Oooool0047ooooo0ol0000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`11ooooo`00F_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo001Kooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0@_ooool005_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`12ooooo`00Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04;o
oooo001Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@_ooool005_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`12ooooo`00G?ooool01Ol0003ooooooooooooo
oooo000001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo04;ooooo001Looooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@_ooool005cooooo00Go
0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`12ooooo`00GOooool00ol0003oooooo`00000Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`13ooooo`00GOooool3
o`0001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo04?ooooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`13ooooo`00N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0@oooool007Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04?ooooo001hooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo0_l0
0006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04?ooooo001iooooo`05o`000?ooooooooooooooool000006?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo0ol00005ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04?ooooo001iooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Gooooo0_l00006ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo001i
ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Gooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo001jooooo`04o`000?oooooo
ooooo`0001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`;o00001_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`13ooooo`00N_ooool00ol0003oooooo`00000Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05Oooool2o`0000Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool0
07[ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Gooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo001kooooo`;o00006_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo1Ol00005ooooo`;o00001_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`13ooooo`00Uoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o00001_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`00
Uoooool01Ol0003ooooooooooooooooo000000oooooo00?oV9RHob4Q8Oo^k^h01_ooool4o`0000?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0@oooool009Oooooo00Go0000ooooooooooooooooo`00000@ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo0_l00005ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo002Gooooo`05o`00
0?ooooooooooooooool000004Oooool00omgMgOoIVIVooooo`04ooooo`;o00001Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`14ooooo`00Uoooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo002Gooooo`05o`00
0?ooooooooooooooool000003_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`14ooooo`00Uoooool01Ol0003ooooooooooooooooo0000
00kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0A?ooool009Sooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04Cooooo002Hooooo`?o00006_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Cooooo002Iooooo`03o`000?oooooooooo01Wooooo0_l00003ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Cooooo002eooooo`;o00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00]Oooool2
o`0000?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0A?ooool00;Gooooo0_l00003ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Cooooo002eooooo`;o00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00]Oooool2o`0000?ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0A?ooool00;Gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo002e
ooooo`05o`000?oooooo0000ooooool000006oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A?ooool00;Gooooo00Go0000ooooool0003oooooo`00
000Looooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00]Ooo
ool4o`0001gooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo
002eooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000Looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04Gooooo002eooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04Gooooo002eooooo`03o`000?oooooooooo01kooooo00Co
0000oooooooooooo00007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`00]Oooool00ol0003ooooooooo
o`0Nooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00;Gooooo00?o
0000ooooooooool07_ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo
002eooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000007Oooool01Ol0003ooooooooo
oooooooo000001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`00]Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001gooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00;Gooooo0_l0
000Pooooo`03o`000?oooooo000001gooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00;Gooooo00?o0000ooooooooool07ooo
ool3o`0001gooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0AOooool00;Gooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Mooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`15ooooo`00]Oooool00ol0003oooooooooo`10ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`00]Oooool00ol0003ooooooooo
o`10ooooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`000018ooooo`00
[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool01?l0003ooooo
ooooool0000Oooooo`05o`000?ooooooooooooooool00000B?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`10ooooo`04o`000?ooooooooooo`0001oooooo00Go0000oooo
ooooooooooooo`000018ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0@?ooool01?l0
003oooooooooool0000Oooooo`05o`000?ooooooooooooooool00000B?ooool00:[ooooo00CoA4A4
omgMgOoooooo00001oooool3o`00043ooooo00?o0000ooooool000008?ooool01Ol0003ooooooooo
oooooooo000004Sooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
@?ooool00ol0003oooooo`00000Pooooo`05o`000?ooooooooooooooool00000B?ooool00:_ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`11ooooo`;o00008?ooool01Ol0003ooooo
oooooooooooo000004Sooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000B?ooool00:cooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1Sooooo`05o`000?ooooooooooooooool0
0000B?ooool00;Gooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000004So
oooo002eooooo`03o`000?oooooooooo06?ooooo00Co0000oooooooooooo0000BOooool00;Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooo`000019ooooo`00]Oooool2o`0006Gooooo00?o
0000ooooool00000BOooool00;Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooo`000019
ooooo`00]Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo000004Wooooo002eooooo`03
o`000?oooooooooo06Cooooo0_l0001:ooooo`00]Oooool00ol0003oooooooooo`1Tooooo`;o0000
B_ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zoooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wo
oooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo
^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo
002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@
413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4
A?nj^[X06?ooool5o`0000?ooooo1Ol0001looooo`00QOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool06oooool00onH
V9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^07gooooo0025ooooo`06o`000?ooooooA4A4odA4
A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01Ooo
ool00onHV9So8B4Qonk^kP1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0
003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMgofIVI_ooool0Noooool008Go
oooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@
oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo07[ooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003o
ooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003o^[ZjoooooonHV9So
410@07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18273 m
.00488 .19137 L
.00942 .198 L
.01077 .19951 L
.01204 .20071 L
.01319 .20159 L
.01441 .2023 L
.01574 .20279 L
.01697 .20299 L
.01829 .20292 L
.01904 .20275 L
.01975 .20251 L
.02103 .20187 L
.02243 .20088 L
.02499 .19834 L
.02747 .19502 L
.02978 .1913 L
.04057 .1697 L
.04635 .15869 L
.0518 .15037 L
.05418 .14751 L
.05669 .14509 L
.058 .14409 L
.05945 .14322 L
.06076 .14263 L
.06198 .14227 L
.06272 .14214 L
.0634 .14208 L
.06415 .14208 L
.06494 .14215 L
.06627 .14245 L
.06703 .14273 L
.06774 .14305 L
.06906 .14381 L
.07027 .14471 L
.073 .14745 L
.07575 .15124 L
.07875 .15662 L
.08481 .1714 L
.0954 .20584 L
.1006 .22206 L
.10289 .22786 L
.1054 .23281 L
.10679 .23478 L
.10809 .23607 L
.10946 .23684 L
.11023 .23698 L
.11093 .23694 L
.11169 .23671 L
.1124 .23631 L
Mistroke
.11318 .23568 L
.11401 .23479 L
.11554 .23258 L
.11693 .22997 L
.11952 .22376 L
.12232 .21549 L
.1274 .19814 L
.13264 .17973 L
.13825 .16224 L
.14355 .14937 L
.14606 .14467 L
.14837 .14112 L
.15097 .13801 L
.15235 .13675 L
.1538 .13569 L
.15506 .13502 L
.15624 .13458 L
.15754 .13434 L
.15827 .13431 L
.15893 .13434 L
.15961 .13445 L
.16033 .13464 L
.16163 .13518 L
.16242 .13564 L
.16317 .13616 L
.16457 .13737 L
.16742 .14083 L
.17051 .14614 L
.17299 .15169 L
.17566 .15897 L
.18047 .17577 L
.19142 .22737 L
.19426 .24105 L
.19735 .25411 L
.19877 .25909 L
.20027 .26353 L
.20156 .26652 L
.20225 .2678 L
.20298 .26889 L
.20434 .27019 L
.20559 .27049 L
.20694 .26988 L
.2077 .2691 L
.20842 .26809 L
.20971 .26561 L
.21089 .26265 L
.21353 .25388 L
.22412 .20351 L
.22991 .1771 L
.23534 .15759 L
Mistroke
.23996 .14547 L
.24255 .14039 L
.24492 .13675 L
.24751 .13378 L
.24897 .13254 L
.25033 .13167 L
.25164 .13107 L
.25282 .13072 L
.25419 .13057 L
.25547 .13066 L
.25668 .13096 L
.25782 .13143 L
.25906 .13217 L
.26039 .13322 L
.2631 .13626 L
.26557 .14013 L
.26786 .14474 L
.27035 .15096 L
.27486 .1659 L
.28015 .18989 L
.28576 .22252 L
.29101 .25605 L
.29331 .26981 L
.29583 .28294 L
.29703 .28822 L
.29832 .29298 L
.29953 .29656 L
.30063 .29896 L
.30187 .30066 L
.30323 .30122 L
.3045 .30052 L
.30568 .29883 L
.30695 .29593 L
.30813 .29225 L
.31083 .28087 L
.31629 .24936 L
.32548 .19382 L
.33067 .16966 L
.33549 .15319 L
.33827 .1461 L
.34079 .14103 L
.34369 .1366 L
.34502 .13503 L
.34643 .13365 L
.34767 .13266 L
.34903 .1318 L
.35026 .13123 L
.35142 .13087 L
.35278 .13065 L
.35402 .13066 L
Mistroke
.35471 .13075 L
.35545 .13091 L
.35681 .13139 L
.35801 .13202 L
.35914 .1328 L
.36172 .13525 L
.36423 .13865 L
.36693 .14353 L
.36943 .14936 L
.37181 .15623 L
.37627 .1732 L
.38155 .20109 L
.38633 .2336 L
.39148 .27287 L
.3942 .2927 L
.39706 .31072 L
.39825 .31685 L
.39953 .32231 L
.40026 .32487 L
.40093 .32682 L
.40224 .3295 L
.40341 .33058 L
.40468 .33031 L
.40588 .32867 L
.407 .32599 L
.40811 .32226 L
.40916 .31786 L
.41154 .30503 L
.41636 .27123 L
.42668 .1988 L
.43187 .17289 L
.43481 .16177 L
.43755 .15352 L
.44008 .14749 L
.44246 .14302 L
.44461 .13987 L
.44694 .13723 L
.44947 .13515 L
.45075 .13439 L
.45149 .13403 L
.45216 .13376 L
.45336 .13341 L
.45464 .1332 L
.45584 .13318 L
.45697 .1333 L
.45828 .13363 L
.45902 .1339 L
.4597 .1342 L
.46095 .1349 L
.46226 .13584 L
Mistroke
.46455 .13798 L
.46706 .14114 L
.46974 .14562 L
.47262 .15195 L
.47533 .15972 L
.4778 .16859 L
.48256 .19128 L
.48772 .22527 L
.49712 .3053 L
.49957 .3252 L
.50086 .33442 L
.50222 .34286 L
.50341 .34902 L
.50472 .35421 L
.5059 .3574 L
.50701 .35899 L
.50769 .35929 L
.50843 .35902 L
.50977 .35697 L
.51108 .3531 L
.51228 .34801 L
.51502 .33177 L
.51791 .30943 L
.52856 .22115 L
.53162 .20122 L
.53453 .18554 L
.53717 .17388 L
.53998 .16395 L
.54241 .15715 L
.5451 .15127 L
.54754 .14714 L
.54983 .14412 L
.55252 .14144 L
.55499 .13971 L
.55629 .13905 L
.55771 .13853 L
.55842 .13835 L
.55919 .1382 L
.56056 .13808 L
.56186 .13812 L
.56305 .1383 L
.56436 .13863 L
.56574 .13914 L
.56695 .13972 L
.56807 .14037 L
.57064 .14229 L
.57294 .14463 L
.57505 .1474 L
.57749 .15154 L
.5798 .1566 L
Mistroke
.58252 .16422 L
.58508 .1733 L
.58987 .19622 L
.59256 .21307 L
.59503 .23142 L
.60061 .28217 L
.60546 .33097 L
.60783 .35251 L
.61 .36878 L
.61109 .37537 L
.61228 .38104 L
.61353 .38521 L
.61472 .38732 L
.61603 .3875 L
.61742 .38525 L
.61861 .3814 L
.61991 .37522 L
.63065 .28047 L
.6365 .22931 L
.63935 .20973 L
.64194 .19504 L
.64661 .17503 L
.64917 .16698 L
.65159 .16102 L
.65422 .15607 L
.65665 .15269 L
.65931 .15001 L
.66066 .14896 L
.66214 .14801 L
.66343 .14731 L
.66485 .14667 L
.6661 .14621 L
.66742 .14583 L
.66874 .14556 L
.66993 .14542 L
.67113 .14537 L
.67226 .14542 L
.67358 .1456 L
.67425 .14574 L
.67498 .14593 L
.67628 .14637 L
.67748 .14688 L
.68021 .14841 L
.68313 .15062 L
.68566 .15312 L
.68841 .15671 L
.69101 .16127 L
.69341 .16682 L
.69557 .17316 L
.69795 .18184 L
Mistroke
.70276 .20587 L
.70537 .22315 L
.70821 .246 L
.71339 .29818 L
.7185 .35599 L
.72072 .3789 L
.72313 .39911 L
.72384 .40389 L
.7246 .40823 L
.72596 .41401 L
.72723 .41695 L
.72795 .41751 L
.72862 .4173 L
.72938 .41623 L
.7301 .4144 L
.73145 .40891 L
.73221 .40475 L
.7329 .40024 L
.73449 .38795 L
.74504 .27514 L
.7499 .23143 L
.75245 .21353 L
.75514 .19822 L
.7575 .18744 L
.76008 .17808 L
.76243 .17146 L
.76462 .16665 L
.76597 .16424 L
.76744 .16205 L
.76873 .16044 L
.77009 .15903 L
.77133 .15798 L
.77268 .15705 L
.77391 .15638 L
.77507 .15588 L
.77577 .15563 L
.77652 .15541 L
.77785 .15511 L
.7786 .15499 L
.7794 .1549 L
.78016 .15485 L
.78084 .15482 L
.78218 .15483 L
.78293 .15486 L
.78363 .15491 L
.7849 .15505 L
.78624 .15526 L
.78892 .15583 L
.79146 .15658 L
.79374 .15744 L
Mistroke
.79621 .15858 L
.7989 .16009 L
.80176 .16203 L
.80423 .16409 L
.80689 .16688 L
.80935 .17026 L
.81161 .17426 L
.81377 .17914 L
.81604 .18562 L
.81854 .19468 L
.82087 .20525 L
.82614 .23895 L
.82891 .26315 L
.83145 .28972 L
.83721 .3605 L
.83983 .39276 L
.84228 .4188 L
.84362 .43022 L
.84484 .43847 L
.84619 .44485 L
.84694 .44702 L
.84765 .44816 L
.84888 .44797 L
.85 .44542 L
.85129 .43975 L
.8525 .43193 L
.85466 .4128 L
.85699 .3865 L
.86226 .31871 L
.86717 .26204 L
.87201 .2208 L
.87472 .20387 L
.87719 .19171 L
.8799 .18141 L
.88132 .17712 L
.88283 .17334 L
.88415 .17062 L
.88561 .16821 L
.88683 .16659 L
.88817 .16521 L
.88893 .16458 L
.88964 .16408 L
.89038 .16366 L
.89104 .16334 L
.89232 .16289 L
.89367 .16262 L
.89444 .16255 L
.89514 .16252 L
.89591 .16255 L
.89672 .16262 L
Mistroke
.89809 .16285 L
.89887 .16304 L
.8996 .16325 L
.9023 .16433 L
.90477 .16566 L
.91031 .16925 L
.91535 .17216 L
.9179 .17324 L
.91937 .17372 L
.92071 .17408 L
.92188 .17433 L
.9231 .17453 L
.92433 .17466 L
.92568 .17471 L
.92685 .17468 L
.9281 .17455 L
.92927 .17435 L
.93034 .17408 L
.9317 .17363 L
.93314 .17302 L
.93572 .17158 L
.94155 .16717 L
.95214 .15791 L
.95722 .15376 L
.95972 .15202 L
.96205 .15071 L
.96344 .15008 L
.96471 .14962 L
.96611 .14923 L
.96688 .14907 L
.96761 .14897 L
.96888 .14886 L
.97005 .14886 L
.97133 .14896 L
.97269 .14919 L
.97389 .1495 L
.97498 .14988 L
.97744 .15106 L
.97971 .1526 L
.98186 .15447 L
.98668 .16014 L
.99192 .16821 L
1 .18273 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001Vooooo`;o00007_ooool2o`0002gooooo0_l0002aooooo`00
I?ooool2o`0000;ooooo0_l0000Jooooo`;o000000?oooooo`000?l000007?ooool4o`0000cooooo
00?o0000ooooooooool0/?ooool004Kooooo1Ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05oooool2o`0000Cooooo00?o0000ooooooooool06?ooool2o`0000;ooooo0_l0
000;ooooo`03o`000?oooooooooo0;3ooooo0016ooooo`05o`000?ooooooooooooooool000006?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`Ko0000W?ooool002Wooooo0ol0000Iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0V_ooool002Sooooo00Go0000ooooooooooooooooo`00000G
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool5o`0007[ooooo000Woooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Sooooo0_l00003ooooo`;o0000F_ooool4o`0001_ooooo000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Kooooo0_l00006ooooo`;o0000E_ooool2o`0000Cooooo0_l0000Iooooo`00
9Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`;o00003?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`Ko0000
=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`;o00001Ooo
ool2o`00033ooooo0_l00009ooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Oooooo0_l0000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Eooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooo`000004o`0000?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0A
ooooo`03o`000?oooooooooo00Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00002oooool00ol0003o
ooooooooo`0<ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool00oo^k^ko<S8bo`000007o`00
00_ooooo00?o0000ooooooooool02_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL7ooooo`03o`000?oooooo
oooo00oooooo00Oo0000oooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
0000ogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000gooooo00?o
0000ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHo`00000=ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9Soooooo`000?mgMgL01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool02ooo
ool7o`0000Kooooo00Go0000oooooooooooo0000oa0@4003ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool7o`0000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
ooooool0003o410@013ooooo00?o0000ooooooooool01_l00005ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`07oa0@4?ooooooooooooooool@413oooooo`00
000=ooooo`03o`000?oooooooooo00Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
ool0003o410@00gooooo00?o0000ooooooooool03oooool02Ol0003ooooooooooooooooo410@oooo
ool0003ooooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00CoZJVYoa0@4?oooooooooo0_l00003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000kooooo00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oo
oooooooo00;o00003_ooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooool0003oooooo`000007ooooo`Oo00003Oooool01_m4A4CogMgMooooool0003oooooo`00
00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00Oo410@o`000?nj^[[oooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooo
oooo0000ooooool000003_ooool00ol0003oooooooooo`0:ooooo`03ogMgMomVIVKooooo00;ooooo
00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?nj^[X0
0oooool2o`0000;ooooo00?o0000ooooooooool06Oooool01?oMgMgoEEEEooooool00002ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool03?ooool001Cooooo00?oMgMgolc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`06okZj^_lQ8B7oooooo`000?oooooo410@0oooool00ol@413oooooooooo`06
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool2o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo0000
00oooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo410@00;ooooo00?o0000
oa0@4?ooool03_ooool00ol0003oooooooooo`0<ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
o`000?oooooooooooa0@400Looooo`03ogMgMoo<c<co000000;ooooo00?o0000ooooool@41000ooo
ool00ol@413oooooooooo`0<ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`07ogMgMonHV9So
oooooiRHV?mgMgOoooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00go410@oiRHV?oooooo
^[Zjo`000?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
3Oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonH
V9So000000oooooo00?o0000ooooooooool03?ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004?ooool00ol0003oooooooooo`06oooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00oooooo00?o
0000ooooooooool02Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgo`000?oooooo
V9RHogMgM`0Looooo`03onk^k_m4A4Co000000?ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL>
ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00004Ooo
ool00ol0003oooooooooo`05ooooo`06ojVYZOl@413o0000oa0@4?nYZJWo00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool02oooool02Ol0003ooooooooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00003_ooool00ol0
003oooooooooo`0:ooooo`04oeEEEOmVIVKo0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00omEEEGoIVIVo`00
0004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00004?ooool00ol0003oooooooooo`06ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00?o0000
ooooooooool02Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^o`000?l0003o<S8b
onk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00
5oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0hooooo`005oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`006?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0hooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`006_ooool4o`0001Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0iooooo`005_ooooooo`00043o0000
4oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`00=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03[ooooo000eoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0>_ooool003Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0j
ooooo`00=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0>_ooool003Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`00
0003ooooool0003ooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03[ooooo000hooooo`?o00006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0>_ooool005Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0j
ooooo`00E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo001Doooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool005Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0kooooo`00EOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03_ooooo001Eooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0>oooool005Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03_ooooo001Eooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool005Gooooo00Co0000oooo
oooooooo00006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>oooool005Kooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool005Oooooo0_l0000Joooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0koooo
o`00Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0>oooool007?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03cooooo001dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0looooo`00M?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`04o`000?oooooo
0000o`0000Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0??ooool007Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo001dooooo`05o`000?oooooooooo
ooooool000006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooool000001_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0looooo`00MOooool01?l0003oooooooooool0000J
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooo`000006
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03cooooo001eooooo`03o`000?oooooo000001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Hooooo`;o00001Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0loooo
o`00MOooool3o`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`;o
00001Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0looooo`00M_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool5o`0000Gooooo0_l00005ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03cooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_l00005ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo
002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00onHV9So8B4Qonk^
kP06ooooo`Co00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`00U?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo013ooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0?Oooool009Cooooo00Go0000ooooooooooooooooo`00000Dooooo`03ogMgMomVIVKo
oooo00Cooooo0_l00005ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo002Dooooo`05o`000?oooooooooo
ooooool000005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0?Oooool009Gooooo00Co0000oooooooooooo00004Oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00UOooool0
1?l0003oooooooooool0000Aooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03gooooo002Eooooo`03o`000?oooooo000001gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00U_ooool2o`0001gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00]Oooool2o`0000?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0?Oooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00
]Oooool2o`0000?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00;Gooooo0_l00002ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03gooooo002eooooo`;o00000_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`00]Oooool2o`00
00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0?Oooool00;Gooooo0_l000000ooooooo0000ooooo`0Mooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`00
]Oooool2o`000003ooooool0003ooooo01gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03kooooo002eooooo`04o`000?oooooo0000o`0001kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
002eooooo`;o00008Oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
002eooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0nooooo`00]Oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0?_ooool00;Gooooo00?o0000ooooooooool08?ooool01?l0003ooooooooo
ool0000Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03kooooo002eooooo`03o`000?oooooooooo023ooooo00Co
0000oooooooooooo00007oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`00]Oooool00ol0003ooooooooo
o`0Pooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00;Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002e
ooooo`03o`000?oooooooooo027ooooo0_l0000Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002eoooo
o`;o00008_ooool2o`00023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00;Gooooo00?o0000oooooooo
ool0A?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0nooooo`00]Oooool00ol0003oooooooooo`14ooooo`05o`000?oooooooooooooo
ool000008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002eooooo`03
o`000?oooooooooo04Cooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03kooooo002eooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooo
oooo00008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002/ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`14ooooo`04o`000?ooooooooooo`00
027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0oooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo00008Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo002Zooooo`Go00001_ooool00ol0003o
ooooooooo`14ooooo`04o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`000011
ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000A?ooool01?l0003oooooooooool0
000Rooooo`05o`000?ooooooooooooooool00000@Oooool00:[ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`15ooooo`;o00008oooool01Ol0003ooooooooooooooooo0000047o
oooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0AOooool2o`0002?ooooo
00Go0000ooooooooooooooooo`000011ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo06[ooooo00Go0000ooooooooooooooooo`000011ooooo`00[?ooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo06[ooooo00Co0000oooooooooooo0000@_ooool00;Gooooo
00?o0000ooooooooool0J_ooool01?l0003oooooooooool00012ooooo`00]Oooool00ol0003ooooo
ooooo`1Zooooo`04o`000?ooooooooooo`0004;ooooo002eooooo`03o`000?oooooooooo06[ooooo
00Co0000oooooooooooo0000@_ooool00;Gooooo0_l0001/ooooo`03o`000?oooooo000004;ooooo
002eooooo`03o`000?oooooooooo06_ooooo00?o0000ooooool00000@_ooool00;Gooooo00?o0000
ooooooooool0Joooool00ol0003oooooo`000012ooooo`00]Oooool00ol0003oooooooooo`1[oooo
o`;o0000@oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_o
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`oooo
o`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj
^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo
410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo
002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo
00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_l00000
0ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1kooooo`00QOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool5o`00
07cooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02ooo
ool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0001mooooo`00QOoo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKo
oooo00;ooooo00CogMgMoeEEEOoooooo0000OOooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03
oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`02ooooo`03ogMgMoo<c<co000007go
oooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00oo^k^koA4A4o`00001mooooo`00Q?ooool00ol@413o0000ohN7Q`02
ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00omgMgOo0000
ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18537 m
.00942 .16389 L
.01483 .15295 L
.01975 .14495 L
.02225 .14173 L
.02496 .13891 L
.02644 .13767 L
.02782 .13672 L
.02913 .136 L
.02986 .13567 L
.03053 .13542 L
.03171 .1351 L
.03299 .13492 L
.03418 .13491 L
.0353 .13505 L
.03661 .1354 L
.03782 .13589 L
.03915 .13664 L
.04057 .13767 L
.04356 .14067 L
.04631 .14446 L
.04933 .1498 L
.05251 .15684 L
.06377 .19186 L
.06898 .21057 L
.07392 .22615 L
.07665 .23268 L
.07819 .23546 L
.07893 .23653 L
.07962 .23737 L
.08081 .23845 L
.08213 .23907 L
.08342 .23907 L
.08481 .23841 L
.08611 .23718 L
.08731 .23553 L
.08863 .23319 L
.09005 .23012 L
.09557 .21376 L
.10543 .17815 L
.11062 .16157 L
.11551 .14898 L
.11991 .14046 L
.12239 .13678 L
.12468 .13408 L
.12599 .13281 L
.12724 .1318 L
.12838 .13105 L
.12959 .13041 L
.13089 .12991 L
Mistroke
.13211 .12963 L
.13285 .12954 L
.13355 .12952 L
.13486 .12964 L
.13602 .12991 L
.13724 .13038 L
.13829 .13093 L
.13944 .13169 L
.14199 .13402 L
.14438 .13701 L
.1472 .14163 L
.14986 .1472 L
.15485 .16105 L
.16022 .18118 L
.16605 .20823 L
.17082 .23184 L
.17595 .25422 L
.17738 .25916 L
.17889 .26347 L
.18017 .26637 L
.18091 .26767 L
.18158 .26862 L
.1829 .26982 L
.18363 .27008 L
.18431 .27008 L
.18553 .26946 L
.18686 .26791 L
.18823 .26537 L
.18952 .2622 L
.19244 .25248 L
.19835 .22589 L
.20893 .17656 L
.21417 .15809 L
.21694 .15039 L
.21988 .14368 L
.22245 .13897 L
.22528 .13488 L
.22785 .13208 L
.22901 .13109 L
.23027 .13019 L
.2315 .1295 L
.23265 .129 L
.23386 .12864 L
.23516 .12844 L
.23636 .12842 L
.23751 .12854 L
.23853 .12878 L
.23964 .12917 L
.24086 .12975 L
.24219 .1306 L
Mistroke
.2449 .13297 L
.2474 .13604 L
.24975 .13976 L
.25497 .15149 L
.25792 .16058 L
.26066 .17078 L
.27102 .22464 L
.27557 .25269 L
.28037 .27918 L
.28288 .28956 L
.28431 .29392 L
.28564 .29686 L
.28686 .29852 L
.28798 .29913 L
.28926 .29876 L
.29048 .29736 L
.29182 .29467 L
.2925 .29287 L
.29324 .29057 L
.2958 .28042 L
.30159 .2486 L
.30662 .21806 L
.31204 .18876 L
.31731 .16659 L
.31961 .15892 L
.32213 .15185 L
.32674 .14204 L
.32925 .13816 L
.33159 .13535 L
.33293 .13405 L
.33435 .1329 L
.33558 .13209 L
.3369 .13139 L
.33764 .13108 L
.33831 .13084 L
.33963 .13051 L
.34037 .13039 L
.34118 .13033 L
.34194 .13033 L
.34265 .13037 L
.34401 .13059 L
.3453 .13096 L
.34646 .13144 L
.3477 .1321 L
.34907 .13301 L
.35051 .13419 L
.35308 .13693 L
.35541 .14019 L
.35791 .14463 L
.3624 .15558 L
Mistroke
.36515 .1645 L
.36774 .17471 L
.37261 .19901 L
.38278 .26853 L
.38546 .28754 L
.38835 .30548 L
.38975 .31268 L
.39107 .31836 L
.39227 .32237 L
.39357 .32546 L
.39478 .32707 L
.39588 .32743 L
.39715 .32653 L
.39834 .32443 L
.39945 .32143 L
.40047 .31783 L
.40278 .30706 L
.40771 .27541 L
.41293 .23792 L
.41803 .20511 L
.42287 .18058 L
.42554 .16988 L
.42845 .16037 L
.43087 .15398 L
.43354 .14835 L
.43604 .14424 L
.43838 .14122 L
.44086 .13878 L
.44214 .13778 L
.44353 .13686 L
.44467 .13625 L
.44588 .13571 L
.44717 .13528 L
.44836 .13501 L
.44955 .13486 L
.45068 .13482 L
.45169 .13488 L
.45278 .13504 L
.45408 .13535 L
.45526 .13575 L
.45662 .13636 L
.45791 .13708 L
.46021 .13872 L
.46272 .14107 L
.46546 .14448 L
.46839 .14932 L
.47115 .1553 L
.47364 .16215 L
.47911 .18288 L
.48219 .19862 L
Mistroke
.48503 .21596 L
.4902 .25448 L
.49574 .30093 L
.49849 .32229 L
.5011 .33893 L
.50223 .34463 L
.50344 .34945 L
.50476 .35317 L
.50598 .35504 L
.50711 .35539 L
.50832 .35428 L
.50947 .35184 L
.51052 .34848 L
.51169 .34356 L
.51296 .33688 L
.51553 .32003 L
.52139 .27261 L
.52691 .2292 L
.53187 .19823 L
.53443 .18562 L
.53724 .17421 L
.53976 .16593 L
.54246 .15882 L
.54531 .15303 L
.54797 .14897 L
.55063 .14599 L
.55314 .14395 L
.5554 .14263 L
.55668 .14208 L
.55786 .14167 L
.55912 .14134 L
.56047 .14111 L
.56175 .141 L
.56293 .14099 L
.56423 .14109 L
.56497 .1412 L
.56565 .14133 L
.56704 .14169 L
.56853 .14223 L
.56999 .1429 L
.57158 .14379 L
.57447 .14588 L
.57728 .14855 L
.57987 .15171 L
.58476 .16017 L
.58751 .16686 L
.59003 .17455 L
.5949 .19467 L
.59954 .22148 L
.61002 .31005 L
Mistroke
.61279 .33517 L
.61578 .35862 L
.61715 .36724 L
.6186 .37443 L
.61984 .37883 L
.6212 .38164 L
.62193 .38225 L
.62262 .38224 L
.62392 .38066 L
.62465 .37891 L
.62532 .37675 L
.62684 .37007 L
.62805 .3631 L
.6294 .35395 L
.63211 .33183 L
.642 .24298 L
.64679 .20977 L
.64931 .19599 L
.65196 .18399 L
.65429 .17533 L
.65684 .16763 L
.65916 .16201 L
.66131 .15785 L
.66397 .15381 L
.66686 .1506 L
.66941 .14857 L
.67069 .14778 L
.6721 .14708 L
.67338 .14658 L
.67454 .14624 L
.67589 .14596 L
.67717 .14581 L
.67834 .14577 L
.67943 .1458 L
.68063 .14593 L
.6819 .14616 L
.68263 .14633 L
.6834 .14655 L
.68477 .14702 L
.68785 .14849 L
.69052 .15023 L
.69345 .1527 L
.69606 .15546 L
.69886 .15914 L
.7039 .16824 L
.70661 .17484 L
.70947 .18357 L
.71462 .20486 L
.71748 .22054 L
.72015 .23814 L
Mistroke
.72626 .28895 L
.73147 .33965 L
.73405 .36337 L
.73644 .38222 L
.73787 .39132 L
.73917 .39781 L
.73992 .40067 L
.74062 .40278 L
.74136 .40436 L
.74216 .40529 L
.74348 .40505 L
.74415 .40409 L
.74489 .40239 L
.74618 .3978 L
.7474 .39179 L
.75687 .30988 L
.76207 .26193 L
.76695 .22575 L
.7722 .19718 L
.77499 .18579 L
.778 .17598 L
.78059 .16926 L
.78333 .16361 L
.78822 .1562 L
.79089 .15325 L
.79373 .15081 L
.79512 .14988 L
.79642 .14915 L
.79758 .14862 L
.79886 .14817 L
.79959 .14797 L
.80027 .14782 L
.80099 .14769 L
.80177 .1476 L
.80249 .14755 L
.80317 .14754 L
.80445 .14759 L
.80518 .14767 L
.80595 .14779 L
.80668 .14793 L
.80735 .14808 L
.80897 .14858 L
.81051 .1492 L
.81308 .15062 L
.81579 .15271 L
.81811 .15503 L
.82066 .15819 L
.82633 .1677 L
.83163 .1803 L
.83689 .19801 L
Mistroke
.84262 .22533 L
.84802 .2606 L
.85302 .30191 L
.85759 .34466 L
.8624 .3873 L
.86492 .40484 L
.86635 .41241 L
.86768 .41763 L
.8689 .42075 L
.87002 .4221 L
.8713 .42187 L
.87251 .4199 L
.87374 .41622 L
.87504 .4106 L
.87737 .39658 L
.88263 .35235 L
.89213 .26721 L
.89746 .23043 L
.90244 .20426 L
.9079 .183 L
.91075 .17439 L
.91377 .16671 L
.91667 .16056 L
.9193 .1559 L
.92197 .15196 L
.92442 .14899 L
.9273 .14628 L
.92881 .14517 L
.9304 .14424 L
.93179 .14361 L
.93309 .14319 L
.93383 .14302 L
.93451 .14291 L
.93529 .14283 L
.93603 .1428 L
.93724 .14287 L
.93858 .14311 L
.93925 .14329 L
.93998 .14353 L
.94129 .14409 L
.94383 .14562 L
.94615 .14756 L
.94884 .15043 L
.95178 .15431 L
.95714 .16323 L
.96777 .18524 L
.97299 .19546 L
.97528 .19919 L
.97779 .2025 L
.97919 .20392 L
Mistroke
.98049 .20495 L
.98186 .20571 L
.98264 .20598 L
.98334 .20613 L
.98411 .20619 L
.98481 .20614 L
.98559 .20598 L
.98642 .20568 L
.98781 .20488 L
.9886 .20427 L
.98934 .2036 L
.99197 .20046 L
.99438 .19666 L
.99981 .18579 L
1 .18537 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo000oooooo`Co00007?ooool5o`0001gooooo1?l0000`ooooo`;o
0000/Oooool003gooooo0_l00003ooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Wooooo0_l00002ooooo`;o0000;oooool00ol0003oooooooooo`2`ooooo`007ooo
ool4o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01[ooooo1Ol0000=ooooo`03o`000?oooooooooo0;3ooooo000Nooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0/?ooool001gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0?ooooo`Go0000L_ooool4o`0002Kooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l0000Nooooo`Co0000COooool2o`0000;o
oooo0_l0000Uooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`;o00000oooool2o`00027ooooo
1_l0000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool001[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08Oooool001[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`0000cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`006_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Poooo
o`006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Oooooo`005Oooool2o`000009oa0@4?oooooo0000ooooooo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool03oooool01_l0003oV9RHoa0@4?l0
003o<S8bolc<c0?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000Aooooo`03o`000?oooooooooo
00Kooooo1Ol000002?oooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool00ol0003ooooo
ooooo`0<ooooo`Go000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPOooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`;o000000Wo
410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00[o0000oooooooo
oooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg1oooool00ol0003oooooooooo`0>ooooo`07o`00
0?oooooo410@okZj^_ooooooMgMgoc8b<P03ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00
000@ooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A002ooooo`06o`00
0?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Sooooo
1ol00005ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooo`00000@ooooo`Oo
00000oooool00onHV9So8B4Qonk^kP03ooooo`03o`000?l@413ooooo00;ooooo00?o410@oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003oooooo`000004ooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00KoA4A4omgMgOoooooo0000ooooool00002ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?oZJVY
oa0@4?ooool00_ooool01ol0003ooooooooooooooooo0000ooooool000003oooool00ol0003ooooo
ooooo`09ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool01?mgMgOoIVIVooooooooool2o`0000?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001Cooooo00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool01Ol0003oooooooooool0003o410@00?ooooo00?o410@ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool2o`0000[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@ooooooooooooooooo`00000@ooooo`03
o`000?oooooooooo00Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool01?o^k^koA4A4o`000?l00003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0;ooooo`08o`000?oo
oooooooooa0@4?nHV9SooooookZj^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05o`000?nHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03
ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo
00[ooooo00Wo0000ooooooooooooooooojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00[ooooo00?o0000
ooooooooool03oooool00ol0003oIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0@ooooo`07o`000?oooooooooooooooomEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00?oMgMgo`000?ooool00_ooool01_l0003ok^k^oc8b<_l0003o<S8b
onk^kPkooooo000Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo000Zooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;o
oooo000Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo000[
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000006ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`00;?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<Oooool002gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0aooooo`00;Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo000]ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0<_ooool002gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Eooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0boooo
o`00;_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooooooo0_l00006
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03;ooooo000_ooooo`03o`000?oooooo000001[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo000_ooooo`?o00006_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool004gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo001=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0booooo`00COooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03;ooooo001>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0<oooool004kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0c
ooooo`00C_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02o`0000Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool004kooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0cooooo`00Coooool01?l0003oooooooooool0000Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`00Cooo
ool00ol0003oooooo`00000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0cooooo`00D?ooool2o`0001cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo001^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`00Koooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool006oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?o
oooo001_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Wooooo00Co0000ooooool0003o00001Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0dooooo`00L?ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Co
oooo001`ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=?ooool0073ooooo
00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo0_l00005ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03Cooooo001aooooo`?o00007?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01_ooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Cooooo
001aooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo0_l0
0005ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03Cooooo002Aooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04Oooool5o`0000Gooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Cooooo002Aoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Gooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Cooooo002Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00onHV9So8B4Qonk^kP06ooooo`Co00000oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0dooooo`00T_ooool01Ol0003ooooooooooooooooo000001Gooooo00?oV9RHob4Q
8Oo^k^h01Oooool2o`0000Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool009;ooooo00Co0000oooooooo
oooo00005oooool00omgMgOoIVIVooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eoooo
o`00T_ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Gooooo002Cooooo`03o`000?oooooo000001Cooooo00Go0000okZj^_oo
ooooV9RHoa0@4005ooooo`;o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`00Toooool00ol0003o
ooooo`00000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool2o`0000Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=Oooool009?ooooo0_l0000Oooooo`;o00001?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`00
]?ooool2o`0000?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00;Gooooo0_l00002ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Gooooo002eooooo`05o`000?ooooooooooooooool000007oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00;Gooooo00Go0000
ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0fooooo`00]Oooool2o`0000;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool0
0;Gooooo0_l00002ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo002eooooo`;o000000?oooooo`000?oo
ool08?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00;Go
oooo0_l000000ooooooo0000ooooo`0Pooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0fooooo`00]Oooool01?l0003oooooo`000?l0000Qooooo`05o`000?oooooooooo
ooooool000008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0fooooo`00]Oooool00ol0003oooooooooo`0Roooo
o`05o`000?ooooooooooooooool000008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`00]Oooool2o`00
02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo002eoooo
o`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03Oooooo002eooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00008Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0gooooo`00]Oooool00ol0003oooooooooo`0Rooooo`04o`000?oooooooooo
o`00027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=oooool00;Gooooo00?o0000ooooooooool08oooool00ol0
003oooooo`00000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo002eooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooool000008_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`00]Oooool00ol0003ooooo
ooooo`0Sooooo`;o00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0gooooo`00]Oooool00ol0003oooooooooo`18ooooo`05o`00
0?ooooooooooooooool000008oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oo
oooo002eooooo`;o0000B_ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>?ooool00;Gooooo00?o0000ooooooooool0BOooool01?l0003ooooo
ooooool0000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00;Gooooo
00?o0000ooooooooool0BOooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>?ooool00;Gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
o`00000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00;Gooooo00?o
0000ooooooooool0BOooool00ol0003oooooo`00000Uooooo`05o`000?ooooooooooooooool00000
>_ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo0ol0
000Uooooo`05o`000?ooooooooooooooool00000>_ooool00:gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo0000
>oooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo077ooooo00Co0000oooooooooooo0000
>oooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`0007;ooooo00?o0000ooooool00000
>oooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooo000003_ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0L_oo
ool2o`0003cooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0L_ooool2
o`0003cooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0
003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_oo
ool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:coooo
o`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo
00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?l@413oc<c<
07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000go
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40O?ooool008Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooo
ooooool04?ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go0000oooo
ooooooooooooo`00001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0
000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooooooo
o`0Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c01looooo`00QOoo
ool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Mooooo`06o`000?oooooooooo
oooooomEEEGoQhN7Ooooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH07kooooo0024ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13035 m
.00123 .12995 L
.00236 .12972 L
.00365 .12961 L
.00488 .12966 L
.00601 .12986 L
.00706 .13016 L
.00821 .13063 L
.00942 .13129 L
.01196 .13319 L
.01434 .1356 L
.01694 .13895 L
.01975 .14345 L
.02532 .15547 L
.03062 .17087 L
.04057 .20621 L
.04588 .22392 L
.04884 .23173 L
.05025 .23464 L
.05154 .23678 L
.05276 .23832 L
.05405 .23937 L
.05535 .23983 L
.05609 .23981 L
.05678 .23962 L
.05803 .23883 L
.05916 .23764 L
.06048 .23573 L
.06172 .23342 L
.06451 .22669 L
.06746 .21772 L
.07278 .19892 L
.07905 .17627 L
.08481 .15836 L
.0896 .14668 L
.09465 .13756 L
.09727 .13397 L
.09971 .13129 L
.10239 .12908 L
.10389 .12817 L
.10525 .12754 L
.10645 .12714 L
.10772 .12688 L
.1088 .12677 L
.10999 .12679 L
.11127 .12696 L
.11264 .12732 L
.11394 .12782 L
.11513 .12842 L
.11741 .12997 L
Mistroke
.11991 .13231 L
.12226 .13521 L
.12445 .13858 L
.12979 .14988 L
.13281 .15831 L
.13557 .16743 L
.14604 .21268 L
.15096 .23635 L
.15555 .25507 L
.15786 .26198 L
.15916 .26489 L
.16034 .26687 L
.16163 .26827 L
.16236 .26869 L
.16304 .26885 L
.16427 .26853 L
.16559 .26737 L
.16679 .26557 L
.1681 .26285 L
.17074 .2552 L
.17545 .23609 L
.18607 .18658 L
.19089 .16803 L
.19603 .15257 L
.19853 .14664 L
.20088 .14193 L
.20528 .13522 L
.2078 .13246 L
.21016 .1305 L
.21148 .12963 L
.21274 .12895 L
.21419 .12835 L
.21552 .12795 L
.21682 .1277 L
.21821 .12759 L
.21939 .12763 L
.2207 .12781 L
.22143 .12798 L
.2221 .12818 L
.2236 .12878 L
.22494 .12949 L
.22634 .13042 L
.22865 .1324 L
.23113 .13517 L
.23559 .1421 L
.23832 .14781 L
.2409 .15442 L
.24573 .17045 L
.25058 .19173 L
.25592 .22056 L
Mistroke
.26112 .25129 L
.26399 .26728 L
.26671 .28034 L
.26921 .28949 L
.2699 .29141 L
.27063 .29316 L
.27194 .29548 L
.27323 .29668 L
.27444 .2968 L
.27554 .29607 L
.27672 .29442 L
.27785 .29202 L
.27909 .28852 L
.28159 .27902 L
.28608 .25614 L
.29113 .22678 L
.29661 .1969 L
.30145 .17535 L
.30658 .15814 L
.30942 .15093 L
.31255 .1446 L
.3154 .14013 L
.31807 .13688 L
.3207 .13447 L
.32312 .13286 L
.32438 .13222 L
.32576 .13168 L
.32646 .13147 L
.32721 .13128 L
.32855 .13104 L
.32984 .13094 L
.33058 .13094 L
.33127 .13097 L
.332 .13104 L
.33266 .13114 L
.33342 .13129 L
.33415 .13147 L
.33543 .13189 L
.33662 .13239 L
.33931 .13394 L
.34084 .1351 L
.34228 .1364 L
.34496 .13941 L
.34785 .14363 L
.35098 .14953 L
.35635 .1638 L
.35905 .17335 L
.36201 .18594 L
.37214 .24576 L
.37767 .28343 L
Mistroke
.38039 .29976 L
.38158 .30595 L
.38289 .31187 L
.38399 .31598 L
.38517 .31948 L
.38642 .32206 L
.38759 .32338 L
.38895 .32353 L
.39025 .3223 L
.39141 .32007 L
.39268 .31648 L
.39417 .31086 L
.39557 .30432 L
.3982 .28955 L
.40408 .25038 L
.40912 .21779 L
.41466 .18851 L
.41722 .17772 L
.41996 .16799 L
.42491 .15474 L
.42781 .14912 L
.43057 .14497 L
.43304 .14205 L
.43573 .13961 L
.43805 .13802 L
.44062 .13677 L
.4419 .13632 L
.44329 .13597 L
.4446 .13576 L
.44581 .13567 L
.44693 .13566 L
.44797 .13573 L
.44912 .13587 L
.45035 .13612 L
.45163 .13647 L
.45285 .13691 L
.45513 .13798 L
.45764 .13961 L
.45998 .14162 L
.46256 .14447 L
.46533 .14843 L
.46822 .15375 L
.47097 .16016 L
.47347 .16731 L
.47613 .17657 L
.48094 .1983 L
.4854 .22488 L
.4955 .301 L
.49825 .32031 L
.49975 .3294 L
Mistroke
.50114 .33662 L
.50244 .34203 L
.50361 .34578 L
.50492 .34851 L
.50564 .34935 L
.50633 .34969 L
.507 .3496 L
.50774 .34901 L
.50851 .34784 L
.50924 .34626 L
.51053 .34229 L
.51193 .33648 L
.51511 .31839 L
.51802 .29781 L
.52333 .25755 L
.529 .21952 L
.53435 .19218 L
.53921 .17445 L
.54177 .16745 L
.54412 .16219 L
.54666 .15759 L
.54945 .15357 L
.55414 .14857 L
.55671 .14658 L
.55911 .14512 L
.56046 .14446 L
.56192 .14386 L
.56322 .14342 L
.56459 .14305 L
.56583 .1428 L
.56719 .14259 L
.56843 .14247 L
.5696 .14241 L
.57097 .14241 L
.57166 .14244 L
.57242 .1425 L
.57376 .14268 L
.57501 .14293 L
.57649 .14335 L
.57783 .14386 L
.57939 .14462 L
.58085 .14553 L
.58336 .14755 L
.5857 .15008 L
.58827 .15366 L
.59104 .15868 L
.59393 .16553 L
.59668 .17392 L
.59917 .18345 L
.60183 .19592 L
Mistroke
.60664 .2252 L
.61109 .26022 L
.61601 .30471 L
.6212 .34904 L
.62249 .35798 L
.62388 .36606 L
.62468 .3699 L
.6254 .37284 L
.62614 .37527 L
.62682 .37698 L
.6281 .37876 L
.62948 .37856 L
.6307 .37656 L
.632 .37263 L
.63338 .36656 L
.63487 .35808 L
.63756 .33874 L
.64369 .28616 L
.64907 .24377 L
.65201 .22489 L
.65474 .21025 L
.65957 .19071 L
.66213 .18328 L
.66487 .17715 L
.66759 .17251 L
.67046 .16875 L
.67563 .16387 L
.67849 .16186 L
.68118 .16033 L
.68729 .1577 L
.69252 .15561 L
.69749 .15364 L
.69882 .1532 L
.70023 .15281 L
.70104 .15262 L
.70178 .15248 L
.70253 .15236 L
.70322 .15228 L
.70451 .1522 L
.70519 .15219 L
.70591 .15221 L
.70712 .15231 L
.70845 .15251 L
.70982 .15285 L
.71109 .15329 L
.71249 .15393 L
.71397 .15486 L
.71525 .1559 L
.71646 .15711 L
.71786 .15888 L
Mistroke
.71919 .16095 L
.72165 .16596 L
.72391 .17209 L
.72633 .18059 L
.72898 .19242 L
.73449 .22742 L
.73757 .2541 L
.74037 .28264 L
.74552 .34119 L
.74833 .3715 L
.7497 .38442 L
.75096 .39464 L
.75211 .40247 L
.75337 .40901 L
.7547 .41346 L
.75597 .41522 L
.75735 .41435 L
.75805 .41281 L
.75882 .41026 L
.76019 .40374 L
.76147 .39545 L
.7639 .37504 L
.76612 .35253 L
.77115 .29805 L
.77381 .2715 L
.77666 .2471 L
.7793 .22863 L
.78179 .21471 L
.78459 .20267 L
.78714 .19455 L
.78995 .1882 L
.79154 .18564 L
.793 .18384 L
.79431 .18264 L
.79556 .18181 L
.79668 .18129 L
.7979 .18094 L
.79922 .18075 L
.79996 .18072 L
.80063 .18072 L
.80194 .18081 L
.80317 .18094 L
.80539 .18123 L
.8066 .18136 L
.80774 .18145 L
.80897 .18151 L
.81031 .18151 L
.81146 .18145 L
.81268 .18133 L
.81339 .18123 L
Mistroke
.81413 .18111 L
.81547 .18082 L
.81691 .18041 L
.81851 .17983 L
.82135 .17841 L
.82402 .17656 L
.82899 .17182 L
.83435 .16577 L
.83921 .16078 L
.84189 .15852 L
.84441 .15678 L
.84584 .15599 L
.8466 .15565 L
.8474 .15536 L
.84807 .15517 L
.84881 .15503 L
.85011 .15498 L
.85143 .15524 L
.85217 .15555 L
.85285 .15593 L
.85416 .15702 L
.85541 .1585 L
.85681 .16075 L
.85808 .16336 L
.86092 .17144 L
.86355 .18206 L
.86602 .19531 L
.86891 .21566 L
.87157 .23978 L
.87757 .31419 L
.88253 .38649 L
.88526 .42132 L
.8866 .43513 L
.88784 .44532 L
.889 .45233 L
.89024 .4568 L
.89148 .45807 L
.89284 .45571 L
.89398 .45083 L
.8952 .44283 L
.89635 .43291 L
.8974 .42207 L
.90285 .35016 L
.90584 .30903 L
.90866 .27482 L
.9113 .24854 L
.91415 .22658 L
.91674 .21189 L
.91912 .20215 L
.92027 .19857 L
Mistroke
.92151 .19548 L
.92267 .19321 L
.92374 .19165 L
.92499 .19041 L
.92634 .18971 L
.92762 .18962 L
.92881 .18997 L
.93003 .1907 L
.93117 .19167 L
.93377 .19466 L
.93905 .20192 L
.94171 .20528 L
.94451 .20816 L
.94567 .20909 L
.9469 .2099 L
.94826 .21054 L
.94952 .21088 L
.95028 .21095 L
.95098 .21093 L
.95175 .2108 L
.95256 .21053 L
.95393 .2098 L
.95471 .20922 L
.95543 .20856 L
.95802 .20538 L
.96081 .20064 L
1 .13035 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000goooo
o`Co00007oooool3o`0005Sooooo00?o0000ooooooooool0/?ooool001Kooooo0ol0000Mooooo`;o
00000_ooool2o`0001gooooo0_l000001?oooooo0000o`000?l0000Oooooo`;o0000=Oooool2o`00
09gooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Looooo`;o000000Coooooo`000?l0003o0000<_ooool00ol0003oooooooooo`2Loooo
o`03o`000?oooooooooo017ooooo000Jooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool2o`0000Gooooo0_l0000Nooooo`Go00003_ooool00ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo01;ooooo000Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo0_l00005ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Aooooo`Go0000Q?ooool00ol0003oooooooooo`0Cooooo`007?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0?ooooo`?o00001?ooool2o`0008;ooooo00?o0000ooooooooool04oooool0
01gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool05?ooool001gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02;ooooo1?l0001Hooooo`03o`000?oooooooooo01Co
oooo000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`;o00003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo
0ol00003ooooo`;o0000:Oooool3o`0002[ooooo00?o0000ooooooooool05Oooool001kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo0_l0
0008ooooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool05Oooool001kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Wooooo0_l0000;ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo000Eoooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_l000004?ooool00ol0003ooooo
ooooo`07ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01_l0003ok^k^oc8b<_l0003o<S8b
onk^kPcooooo00?o0000ooooooooool03?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo
ooooooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPWooooo0_l0000=oooo
o`03o`000?oooooo000000Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo00?o0000
ooooooooool00_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So0000013ooooo00?o0000
ooooooooool01oooool01Ol@413o^[ZjoooooomgMgOo<S8b00;ooooo00Ko0000ogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03o`000?oooooooooo00gooooo00GoV9RHo`000?o^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00gooooo00Oo0000oooooonHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`000?oooooo
oooo00?ooooo00Go410@okZj^_l0003oMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7?ooool00ol0003oooooo`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo
1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo0000013ooooo00?o0000ooooool0
00001Ol00006ooooo`05o`000?ooooooooooo`000?l@41000oooool00ol@413oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?l0003ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4007ooooo`03o`000?oooooooooo00Wooooo1ol00004ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`0=ooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^1?ooool01Ol@
413ooooooooooooooooo410@01Cooooo00?o0000ooooooooool01oooool2o`0000?ooooo00Go410@
oooooooooooooooooa0@400Kooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo
000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooooooo00_ooooo00CoZJVYoa0@4?oooooooooo0_l00003ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03oooool00ol0003o8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00oooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3oooo
o`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`000?l@413o
oooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04o`000?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`04
o`000?ooooooooooooooo`;o00003_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00oooooo00?o0000
ogMgMomVIVH00oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0@ooooo`06
o`000?oooooooooooooooomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo000001;ooooo00?o
0000ooooooooool02?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000
6_ooool01Ol0003ogMgMoeEEEOoooooo000000Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`005?ooool00omgMgOoc<c<o`000004ooooo`06oa0@4?ooooooooooooooool@413o00003_ooool0
0ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go0000oooooooooooooooooa0@
400:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000000oooool01Ol@413ooooooooo
oooooooo410@00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool2o`0000[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooo
ooooooooool@41002Oooool4o`000003ooooool0003o000000;o00003?ooool00onj^[[o0000oooo
o`02ooooo`05oa0@4?ooooooooooooooool@41006_ooool01Ol0003oooooogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`06
ogMgMonHV9SooooooiRHV?mgMgOo00003_ooool00ol0003oooooooooo`08ooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01Ol0003oV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0
3_ooool01Ol0003o^[Zjooooool0003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
4_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`;o00000oooool2o`0000cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06Oooool01_l0003oooooooooooo^k^koA4A4o`0000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`07onk^k_lb<S;o0000oc8b
<_o^k^koooooo`00000<ooooo`03o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05o`000?lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0>ooooo`05oiRH
V?l@413o0000o`000?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool04Oooool01Ol0003ooooooeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo017ooooo00Ko0000ooooooooooooEEEEofIVI_l00004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Booooo`05o`000?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool04?oo
ool01OnYZJWo410@o`000?l@413o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`06
o`000?oooooooooooooooomgMgOo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Q
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo013ooooo0ol0000;ooooo`03o`000?oooooooooo01_ooooo000Qoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00oooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo
01_ooooo000Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo01cooooo000Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo000Rooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01gooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000005
ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo0ol00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool002?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0[ooooo`009?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo
000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;?ooool002Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02cooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0;?ooool002Gooooo0_l00002ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool002Kooooo00Co0000oooooooooooo0000
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
;?ooool002Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0]ooooo`00A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
;Oooool004Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02gooooo
0017ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`00Aooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;Oooool004Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02gooooo0017ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooooooo`;o00001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`00B?ooool01?l0003ooooooooo
ool0000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02gooooo0018ooooo`04o`000?ooooooooooo`0001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo0019ooooo`;o
00007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0;_ooool006[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02kooooo001Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0^ooooo`00Joooool01Ol0003ooooooooooooooooo0000
01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0;_ooool006_ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02kooooo001[ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_l0
0004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02kooooo001[ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0^ooooo`00Joooool01Ol0003ooooooooooooooooo000001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0;_ooool006cooooo00?o0000ooooool000008?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0_ooooo`00K?ooool2o`00027ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool008oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;oooool008oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Coooo
o`Go00001?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo002?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Cooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`00Soooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003o
ooooo`000002o`0000?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool0093ooooo00Co0000oooooooooooo
00006?ooool00onHV9So8B4Qonk^kP04ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0;oooool0093ooooo00Co0000oooooooooooo00006Oooool00omgMgOoIVIVooooo`04ooooo`;o
00001?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0_ooooo`00T?ooool01?l0003oooooooooool0000Jooooo`03
o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo002Aooooo`;o0000
5oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l00004ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oo
oooo002Aooooo`;o00005oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo0_l00004ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02oooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;oooool00;Gooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`00]Oooool2o`0000;ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0<?ooool00;Gooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`00]Oooool0
1Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo033ooooo002eooooo`;o000000?oooooo`000?ooool08Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool0
0;Gooooo0_l000000ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0`ooooo`00]Oooool3o`0002?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo002eooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo033ooooo002eooooo`03o`000?oooooooooo02Cooooo00Go0000oooooooooooooooo
o`00000Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo033ooooo002eooooo`03o`000?oooooooooo02Cooooo00Go
0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo002eooooo`;o00009Ooo
ool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00;Gooooo00?o
0000ooooooooool09?ooool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo
002eooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00009?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0`ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo000002Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0<Oooool00;Gooooo00?o0000ooooooooool09Oooool00ol0003oooooo`00000T
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo037ooooo002eooooo`03o`000?oooooooooo02Gooooo0_l0000Uoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo037ooooo002eooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<Oooool00;Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`00]Ooo
ool2o`0004gooooo00Go0000ooooooooooooooooo`00000Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<Oooool00;Gooooo00?o0000ooooooooool0COooool01?l0003ooooooooo
ool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Oooool00;Gooooo00?o
0000ooooooooool0COooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<Oooool00;Gooooo00?o0000ooooooooool0COooool01?l0003ooooooooo
ool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Oooool00;Gooooo00?o
0000ooooooooool0COooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<Oooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo04gooooo00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo037ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0COoo
ool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0003Cooooo002Zooooo`Go0000
1_ooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool01?l0003oooooooooool0000dooooo`00
Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000C_ooool2o`0002Sooooo00Co0000oooooooo
oooo0000=?ooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1>oooo
o`;o0000:?ooool01?l0003oooooooooool0000dooooo`00Zoooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo0000=?ooool00:_ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0003Cooooo002/oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0N?ooool01?l0003oooooooooool0000d
ooooo`00]Oooool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0003Cooooo002eoooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo0000=?ooool00;Gooooo00?o0000oooo
ooooool0N?ooool01?l0003oooooooooool0000dooooo`00]Oooool2o`0007Wooooo00Co0000oooo
oooooooo0000=?ooool00;Gooooo00?o0000ooooooooool0N?ooool01?l0003oooooooooool0000d
ooooo`00]Oooool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0003Cooooo002eoooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo0000=?ooool00;Gooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooo`00000eooooo`00]Oooool00ol0003oooooooooo`1iooooo`;o
0000=Oooool00;Gooooo00?o0000ooooooooool0NOooool2o`0003Gooooo002eooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0<oooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo
002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003o
c<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj
^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003ooooo
ofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l0
00001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool5o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01looooo`00QOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo
00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool0
0000O?ooool008Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01Omg
MgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;
ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?oo
ool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00omg
MgOoIVIVooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0O?ooool008Gooooo00Ko0000ohN7
QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03oa0@4?l0003o000000?o00007Oooool02Ol0003ooooooooooooooooo410@okZj
^_oooooo^[Zjoa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo^[Zjo`00001loooo
o`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01OnYZJWo410@o`000?l@413oZJVY07cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15903 m
.00942 .18972 L
.01483 .20929 L
.01975 .22519 L
.02243 .23193 L
.02365 .2344 L
.02496 .23653 L
.02634 .23819 L
.02763 .23914 L
.02901 .23953 L
.02979 .23945 L
.03053 .23918 L
.03182 .23826 L
.03305 .23685 L
.03416 .23518 L
.03536 .23293 L
.03806 .22649 L
.04057 .21909 L
.05251 .17704 L
.05838 .15905 L
.06377 .14612 L
.06868 .13734 L
.07116 .13393 L
.07388 .1309 L
.07661 .12857 L
.07811 .12756 L
.07953 .12679 L
.08085 .12622 L
.08155 .12597 L
.08229 .12575 L
.0836 .12546 L
.08481 .12531 L
.08604 .12527 L
.08734 .12535 L
.08844 .12552 L
.08966 .12582 L
.09096 .12627 L
.09236 .12691 L
.09488 .1285 L
.09743 .13072 L
.09984 .13341 L
.10434 .14023 L
.10695 .14539 L
.10972 .15195 L
.11468 .16677 L
.12589 .21377 L
.13098 .23715 L
.13348 .24742 L
.1358 .25551 L
.1372 .25951 L
Mistroke
.13846 .26247 L
.13987 .26496 L
.14064 .26594 L
.14137 .26662 L
.14264 .26719 L
.14381 .26702 L
.14509 .26608 L
.14645 .26425 L
.14765 .26195 L
.14874 .25933 L
.15119 .25183 L
.15562 .23415 L
.16568 .18892 L
.17074 .16975 L
.17611 .15393 L
.1807 .14397 L
.18576 .1362 L
.18859 .13308 L
.19118 .13089 L
.19402 .12913 L
.19545 .12849 L
.19626 .12819 L
.19701 .12796 L
.1984 .12763 L
.19966 .12744 L
.20102 .12736 L
.20178 .12736 L
.20249 .1274 L
.20366 .12754 L
.20496 .12781 L
.20631 .1282 L
.20757 .12869 L
.21029 .13016 L
.21281 .13207 L
.21558 .13485 L
.21853 .13871 L
.22346 .14769 L
.22627 .15448 L
.22891 .16216 L
.23828 .20082 L
.24352 .22922 L
.24839 .25663 L
.25088 .26937 L
.25324 .27965 L
.25454 .28435 L
.25595 .28851 L
.25724 .29134 L
.25842 .29311 L
.25973 .29406 L
.26096 .29399 L
Mistroke
.26231 .29285 L
.26306 .29172 L
.26376 .2904 L
.26514 .28695 L
.26665 .28206 L
.26941 .27061 L
.28102 .20861 L
.28651 .1834 L
.29155 .16561 L
.29667 .1526 L
.29936 .14749 L
.3022 .14316 L
.30451 .14034 L
.30698 .1379 L
.30969 .13584 L
.31222 .13443 L
.3137 .13381 L
.31506 .13335 L
.31656 .13298 L
.31731 .13284 L
.31814 .13272 L
.31887 .13264 L
.31954 .1326 L
.32027 .13257 L
.32104 .13258 L
.32233 .13265 L
.32307 .13273 L
.32375 .13283 L
.32512 .1331 L
.32641 .13346 L
.32883 .13438 L
.33018 .13507 L
.33143 .13581 L
.33425 .13794 L
.33682 .14048 L
.33916 .1434 L
.34169 .14729 L
.34444 .15257 L
.34933 .1653 L
.35397 .18226 L
.35942 .20921 L
.36522 .2454 L
.37029 .27926 L
.37306 .29594 L
.37564 .30867 L
.37695 .31368 L
.37834 .3178 L
.37914 .31953 L
.37989 .32073 L
.38056 .32144 L
Mistroke
.38129 .32182 L
.3826 .32144 L
.38399 .31959 L
.38518 .31687 L
.38648 .31274 L
.38939 .29982 L
.39252 .2817 L
.39819 .24457 L
.40386 .21015 L
.40925 .18448 L
.4141 .16781 L
.41684 .16076 L
.41938 .15551 L
.42216 .15101 L
.42471 .14779 L
.42751 .14511 L
.42894 .14403 L
.43047 .14307 L
.43182 .14238 L
.43305 .14186 L
.4343 .14143 L
.43545 .14112 L
.4368 .14085 L
.43751 .14075 L
.43826 .14066 L
.43952 .14058 L
.44024 .14056 L
.44092 .14056 L
.44206 .14059 L
.44331 .14069 L
.44461 .14084 L
.44582 .14103 L
.448 .1415 L
.45032 .1422 L
.45305 .14331 L
.45563 .14468 L
.46046 .14826 L
.46296 .15078 L
.46531 .15365 L
.4681 .15791 L
.47066 .16279 L
.47586 .17663 L
.47873 .18698 L
.48146 .19894 L
.49073 .25627 L
.49558 .2933 L
.49814 .31196 L
.50083 .32905 L
.50222 .33624 L
.50375 .34253 L
Mistroke
.50513 .3466 L
.50642 .34886 L
.50775 .34957 L
.50897 .34876 L
.50964 .34773 L
.51036 .34614 L
.51169 .34205 L
.51287 .33719 L
.51417 .33063 L
.5168 .31421 L
.52152 .27859 L
.52712 .23618 L
.53302 .20012 L
.53805 .17798 L
.5409 .16867 L
.54355 .16181 L
.54621 .15647 L
.54871 .15261 L
.55096 .14998 L
.55339 .14787 L
.55466 .14703 L
.55605 .14628 L
.5575 .14569 L
.55886 .1453 L
.56013 .14505 L
.56129 .14493 L
.56263 .14491 L
.5639 .14499 L
.56515 .14517 L
.56654 .14547 L
.56798 .1459 L
.56934 .14638 L
.57438 .1488 L
.57988 .15234 L
.58581 .15728 L
.591 .16282 L
.59583 .16932 L
.60114 .17887 L
.60411 .18592 L
.60681 .1938 L
.61227 .21507 L
.61535 .23086 L
.6182 .24812 L
.62338 .28564 L
.62896 .32945 L
.63168 .34832 L
.63302 .35616 L
.63426 .36232 L
.63538 .3668 L
.63658 .37033 L
Mistroke
.63791 .37263 L
.63911 .37319 L
.64034 .37223 L
.64147 .36999 L
.6427 .3661 L
.64401 .36045 L
.64621 .34779 L
.64862 .33032 L
.65444 .28092 L
.65995 .23633 L
.6649 .20423 L
.66746 .19093 L
.67028 .1787 L
.67544 .16211 L
.67827 .15567 L
.68093 .15102 L
.6834 .14771 L
.68567 .14543 L
.68815 .14364 L
.68941 .14301 L
.69077 .14249 L
.69149 .1423 L
.69226 .14215 L
.69299 .14206 L
.69366 .14201 L
.69493 .14204 L
.69628 .14223 L
.69697 .14239 L
.69772 .14261 L
.69907 .14311 L
.70068 .14389 L
.70215 .14478 L
.70758 .14937 L
.71274 .15551 L
.72283 .17187 L
.73358 .19422 L
.73881 .20713 L
.74372 .22157 L
.74847 .239 L
.7529 .25969 L
.75781 .28877 L
.76318 .32698 L
.7661 .34832 L
.76886 .36671 L
.77134 .38006 L
.77274 .3857 L
.77403 .38946 L
.77515 .39146 L
.7762 .39223 L
.77734 .39179 L
Mistroke
.77858 .3898 L
.77987 .38606 L
.7811 .381 L
.78341 .3679 L
.7882 .32955 L
.79344 .28111 L
.79901 .23418 L
.80426 .19933 L
.80898 .17606 L
.81408 .15826 L
.81674 .1515 L
.81965 .14568 L
.8227 .14108 L
.82416 .13934 L
.82554 .13796 L
.82682 .1369 L
.8282 .13597 L
.82947 .13533 L
.83063 .13491 L
.83189 .13462 L
.83261 .13454 L
.83328 .13452 L
.83463 .13462 L
.8354 .13476 L
.83609 .13495 L
.83743 .13544 L
.8387 .13606 L
.84106 .13765 L
.84361 .13998 L
.84638 .14325 L
.85135 .15124 L
.85595 .16102 L
.87767 .22489 L
.88716 .24921 L
.89239 .26266 L
.89736 .27927 L
.90015 .29163 L
.9032 .3084 L
.90855 .34611 L
.91358 .38558 L
.91623 .40327 L
.91756 .41031 L
.91902 .41612 L
.91975 .41816 L
.92053 .41968 L
.92126 .42044 L
.92193 .42054 L
.92331 .41896 L
.92461 .41522 L
.92592 .40931 L
Mistroke
.92713 .40204 L
.92987 .38005 L
.9397 .27347 L
.94521 .22159 L
.95038 .18573 L
.95298 .17206 L
.95578 .16012 L
.95888 .14981 L
.96173 .14264 L
.96413 .13799 L
.96631 .13471 L
.96752 .13322 L
.96883 .13185 L
.96996 .13086 L
.9712 .12995 L
.97235 .12929 L
.97343 .12882 L
.97457 .12847 L
.97579 .12826 L
.97692 .12822 L
.978 .12832 L
.97896 .12852 L
.98001 .12885 L
.98137 .12946 L
.98265 .13022 L
.98504 .1321 L
.98761 .13482 L
.99039 .13858 L
.9954 .14773 L
1 .15903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000_oooo
o`Go00008?ooool4o`0005gooooo00?o0000ooooooooool0/?ooool002gooooo0_l00005ooooo`;o
00007Oooool2o`0000;ooooo0ol0001Kooooo`;o0000U?ooool5o`0001Sooooo000/ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01kooooo1Ol0000fooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Fooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`;o00001?oo
ool2o`0003Gooooo00?o0000ooooooooool0IOooool5o`0002Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`00;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Kooooo0_l0000cooooo`03o`000?oooooooooo06Cooooo0_l00003ooooo`;o00009_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo000[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`So00003_ooool00ol0
003oooooooooo`0iooooo`Co00009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`00:_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool6o`0002?o
oooo00?o0000ooooooooool00_ooool2o`0002Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool002[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
0_l00006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`;o00003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000Foooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0@
ooooo`05o`000?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooool000001?l00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool00ol0003oooooooooo`0:ooooo`05oiRHV?l0003o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000ooooooooool01_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`;o00000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04?ooool01Ol0003o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo
00So0000ooooooooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wo
oooo00?o0000ooooooooool03?ooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool02_ooool01Ol@413o^[Zjo`00
0?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo
00Sooooo1_l00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool02oooool7o`0000;ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool03Oooool6o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4009ooooo`03o`000?oooooooooo00gooooo00Go0000oooooonHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000?ooooo00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Gooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00?oA4A4omgMgOooool0
0_l00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`05
o`000?ooooooooooojVYZOl@41000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool04Oooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`0=ooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^
0oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003o
ZJVYoa0@4003ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`05oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool0
1_oMgMgoEEEEooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01;ooooo00Co0000oa0@4?l0003o^[Zj0oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool03oooool01Ol0003o
oooooooooomgMgOoIVIV00?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo00gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001?ooooo00?o
0000ooooooooool01Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001Cooooo00GoMgMgolc<c?l0003oooooo`000002ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool00ol0003oooooooooo`0Booooo`04o`000?oooooo^[Zjob4Q8@?ooooo00Go410@
oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Co410@oooooooooooo00005?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4002oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool2o`0000[ooooo00?o0000oooo
ooooool04Oooool01Ol0003ooooooooooooooooo000000Cooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0>ooooo`03o`000?lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Kooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`05onk^k_m4A4Co0000
ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04Ooo
ool01Ol@413o0000oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03
o`000?oooooooooo01?ooooo0_l000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000005Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool01Ol0003ooooo
oooooooooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
00oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`0;ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool01oooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00_oMgMgo`000?ooooooooooo`000?ooooook^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01;ooooo00GoZJVYo`000?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Dooooo`06
o`000?nHV9So410@o`000?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03oeEEEOmVIVKo000000Cooooo00Oo
k^k^oc8b<_l0003o<S8bonk^k_oooooo000001Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00Co0000oeEEEOmVIVKo00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool03oooool01OnHV9So0000o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo
00GoZJVYoa0@4?l0003o410@o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`08ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`006Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo027ooooo000Iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool08Oooool001Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Qooooo`006Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo027ooooo000Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool0
01Koooooool00010o`0001?ooooo000Fooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`005_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`;o
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Rooooo`006oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo000Kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool08_ooool001cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Rooooo`007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo
000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool08_ooool001gooooo00Go0000oooooooooooooooo
o`00000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Iooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`00
7_ooool01?l0003oooooo`000?l0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Sooooo`007_ooool3o`0001kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02?ooooo000oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Sooooo`00@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool08oooool0043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Soooo
o`00@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo0011ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool0047ooooo00Go0000oooooooo
ooooooooo`00000Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_l00006oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02?ooooo0012ooooo`04o`000?ooooooooooo`0001oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo0012oooo
o`03o`000?oooooo0000027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02Cooooo0013ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo001Voooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0T
ooooo`00I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09?ooool006Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooo`000006oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Cooooo001Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool0
00001_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Tooooo`00Ioooool01Ol0003ooooooooooooooooo0000023o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`04o`000?oooooo0000o`00
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09?ooool006Oooooo00Co0000oooooooooooo00008Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Tooooo`00Ioooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Cooooo001Xooooo`;o00008_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`00S?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Uooooo`00S?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`00S?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Gooooo1Ol00004ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool09Oooool008gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2o`0000Gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool0
08gooooo00Go0000ooooooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^00Kooooo1?l00002
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02Gooooo002=ooooo`05o`000?ooooooooooooooool000006_ooool0
0onHV9So8B4Qonk^kP05ooooo`;o00001?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`00S_ooool01?l0
003oooooooooool0000Kooooo`03ogMgMomVIVKooooo00Cooooo0_l00004ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Gooooo002>ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool09Oooool008oooooo0_l0000Iooooo`05o`000?nj^[[ooooooiRH
V?l@41001Oooool2o`0000Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00:[ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00;Gooooo00Go0000oooo
ooooooooooooo`00000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Uooooo`00]Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo002eoooo
o`;o00000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Vooooo`00]Oooool2o`0000;ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09_ooool00;Gooooo0_l00002ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo002eooooo`;o00000_oo
ool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000009_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Vooooo`00]Oooool01?l0003oooooo`000?l0000Vooooo`05o`000?ooooooooooooooool0
00009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Vooooo`00]Oooool01?l0003oooooo`000?l0000Vooooo`05
o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`00]Oooool00ol0003o
ooooooooo`0Wooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Voooo
o`00]Oooool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool000009_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Vooooo`00]Oooool00ol0003oooooooooo`0Wooooo`05o`000?oooooooooooooo
ool000009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Vooooo`00]Oooool2o`0002Wooooo00Co0000oooooooo
oooo00009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Vooooo`00]Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooo000002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00;Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo002eooooo`03o`000?oo
oooooooo02Sooooo0ol0000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo002eooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00]Oooool00ol0
003oooooooooo`1Cooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Wooooo`00]Oooool00ol0003oooooooooo`1Cooooo`04o`000?oooooooooo
o`0002[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`00]Oooool00ol0
003oooooooooo`1Cooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Wooooo`00]Oooool2o`0005Gooooo00?o0000ooooool00000:_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo002eooooo`03o`000?oooooooooo05Co
oooo0ol0000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00;Gooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool0
0000:_ooool00;Gooooo00?o0000ooooooooool0POooool01Ol0003ooooooooooooooooo000002[o
oooo002eooooo`03o`000?oooooooooo087ooooo00Go0000ooooooooooooooooo`00000Zooooo`00
[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0POooool01Ol0003ooooo
oooooooooooo000002[ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
POooool01Ol0003ooooooooooooooooo000002[ooooo002Zooooo`Go00001_ooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooo000002_ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo
0ol00022ooooo`03o`000?oooooo000002_ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0P_ooool00ol0003oooooo`00000[ooooo`00Zoooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo08?ooooo0_l0000[ooooo`00Zoooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0:_ooool00:cooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_oo
ool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000
^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool0
0ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01So
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00QOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@
ooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo07[ooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
07cooooo0025ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01cooooo
00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`00
0?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003o
ooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23908 m
.00123 .23999 L
.00236 .24037 L
.00365 .24025 L
.00488 .2396 L
.00601 .23854 L
.00706 .23718 L
.00942 .23292 L
.01181 .22717 L
.01444 .21956 L
.01975 .20171 L
.02532 .18204 L
.03062 .16502 L
.03578 .15163 L
.04057 .14211 L
.04583 .13429 L
.04861 .13115 L
.05157 .12856 L
.05311 .12752 L
.05477 .12661 L
.05634 .12594 L
.05778 .12547 L
.05909 .12516 L
.05983 .12502 L
.06052 .12492 L
.06125 .12485 L
.06191 .1248 L
.06268 .12478 L
.06341 .12478 L
.06464 .12486 L
.06599 .12503 L
.06667 .12516 L
.06741 .12534 L
.06873 .12574 L
.06999 .12624 L
.0713 .12689 L
.07366 .12841 L
.07642 .13079 L
.07898 .13361 L
.08201 .13774 L
.08481 .14239 L
.09011 .15399 L
.09586 .17147 L
.10629 .21472 L
.11119 .23639 L
.11577 .25344 L
.11807 .2597 L
.11937 .26231 L
.12055 .26407 L
.12184 .26528 L
Mistroke
.12257 .26562 L
.12325 .26572 L
.12449 .26534 L
.12581 .26415 L
.12712 .26221 L
.12855 .25925 L
.13145 .25101 L
.13663 .23083 L
.14228 .20575 L
.14833 .18076 L
.15407 .1618 L
.1593 .14906 L
.16182 .14427 L
.16455 .13993 L
.16952 .13405 L
.17198 .132 L
.17463 .13034 L
.17585 .12976 L
.17713 .12924 L
.17833 .12886 L
.17942 .12857 L
.18073 .12832 L
.18144 .12821 L
.18212 .12814 L
.18333 .12806 L
.18463 .12806 L
.18532 .12809 L
.18607 .12815 L
.18686 .12825 L
.1876 .12837 L
.18891 .12866 L
.19033 .12909 L
.1918 .12966 L
.19316 .13031 L
.19625 .13224 L
.19897 .1345 L
.20187 .13752 L
.20687 .14459 L
.20972 .14995 L
.2124 .15607 L
.23177 .23661 L
.23708 .26389 L
.24 .27634 L
.24144 .28131 L
.24276 .28508 L
.24401 .28783 L
.24533 .28984 L
.24665 .29088 L
.24741 .29103 L
.24812 .29087 L
Mistroke
.24934 .28993 L
.25046 .28834 L
.25176 .28568 L
.25299 .28238 L
.25551 .27353 L
.2582 .26169 L
.26304 .23691 L
.26831 .20962 L
.274 .18434 L
.27712 .17306 L
.27999 .16429 L
.28267 .15735 L
.28562 .15104 L
.29074 .14285 L
.29354 .13964 L
.29615 .13729 L
.29888 .13539 L
.30141 .13406 L
.30419 .13303 L
.30559 .13266 L
.30634 .1325 L
.30713 .13237 L
.30848 .13221 L
.30972 .13215 L
.31105 .13217 L
.3118 .13222 L
.3125 .13229 L
.31378 .13249 L
.31494 .13274 L
.31627 .1331 L
.31754 .13354 L
.3199 .13456 L
.3224 .13599 L
.32689 .13958 L
.32938 .14229 L
.33172 .14538 L
.33447 .14983 L
.33702 .15486 L
.34226 .16838 L
.34796 .1891 L
.35299 .21326 L
.35834 .24412 L
.36361 .27581 L
.36619 .28979 L
.36856 .30061 L
.37073 .30818 L
.37182 .311 L
.37301 .31326 L
.37421 .31462 L
.37549 .31502 L
Mistroke
.37671 .31439 L
.37781 .31298 L
.37906 .31047 L
.38022 .30727 L
.38288 .29732 L
.38826 .26937 L
.3979 .21547 L
.40339 .19138 L
.40841 .17475 L
.41119 .16762 L
.41421 .16126 L
.41972 .15261 L
.4224 .14943 L
.4253 .14655 L
.42785 .14445 L
.43055 .14263 L
.43299 .14129 L
.43566 .14013 L
.43808 .13929 L
.44037 .13867 L
.44175 .13837 L
.44324 .13812 L
.44461 .13795 L
.44586 .13786 L
.44722 .13784 L
.448 .13787 L
.44872 .13792 L
.44948 .13801 L
.45018 .13812 L
.45095 .13827 L
.45176 .13847 L
.45303 .13887 L
.45439 .13941 L
.45683 .14071 L
.45974 .14285 L
.46239 .14546 L
.46481 .14855 L
.46748 .15289 L
.47026 .15872 L
.47286 .16559 L
.47752 .18187 L
.48252 .20588 L
.49385 .28337 L
.49669 .30378 L
.49936 .3206 L
.50176 .33246 L
.50311 .33741 L
.50436 .34072 L
.50555 .34271 L
.50686 .34352 L
Mistroke
.50823 .34281 L
.5095 .34076 L
.51089 .33708 L
.51215 .33253 L
.51499 .31876 L
.52054 .28324 L
.52658 .2438 L
.53221 .21441 L
.53469 .20434 L
.53742 .19511 L
.5424 .18253 L
.54513 .17753 L
.54768 .17378 L
.55263 .16842 L
.55803 .16413 L
.56891 .15675 L
.57891 .15035 L
.58382 .1474 L
.58598 .14631 L
.58835 .14534 L
.58965 .14493 L
.59087 .14464 L
.59216 .14445 L
.59354 .14436 L
.59426 .14437 L
.59505 .14443 L
.59579 .14453 L
.59648 .14467 L
.59778 .14505 L
.59916 .14565 L
.60031 .14632 L
.60156 .14723 L
.60382 .1495 L
.60513 .15124 L
.6065 .15345 L
.60897 .15852 L
.6116 .16575 L
.61441 .17591 L
.61947 .20166 L
.62257 .2228 L
.6255 .24671 L
.63098 .29917 L
.63351 .32413 L
.63624 .34853 L
.63756 .35866 L
.63881 .3669 L
.63995 .37303 L
.64116 .37798 L
.64244 .38128 L
.64362 .38254 L
Mistroke
.64434 .38244 L
.64503 .38174 L
.6463 .3789 L
.64699 .37656 L
.64772 .37352 L
.64902 .3667 L
.65196 .34594 L
.65716 .29958 L
.66209 .25702 L
.66651 .22684 L
.66901 .2138 L
.67132 .2042 L
.67362 .19678 L
.67615 .19074 L
.67742 .18846 L
.67879 .1865 L
.68009 .18507 L
.68128 .18408 L
.68256 .18332 L
.68376 .18286 L
.68507 .18259 L
.68581 .18253 L
.68648 .18252 L
.68783 .18262 L
.68859 .18274 L
.68929 .18287 L
.69195 .18354 L
.69409 .18413 L
.6964 .18469 L
.69772 .18492 L
.69893 .18506 L
.70015 .18512 L
.7013 .18508 L
.70249 .18493 L
.70376 .18466 L
.70495 .18427 L
.70604 .18382 L
.7087 .18229 L
.7112 .18031 L
.72054 .16932 L
.73054 .1553 L
.73349 .15179 L
.73628 .14902 L
.73879 .1471 L
.74021 .14629 L
.74151 .14574 L
.74273 .14542 L
.74387 .14531 L
.74513 .14543 L
.74648 .14588 L
Mistroke
.74715 .14624 L
.74788 .14674 L
.74922 .14798 L
.75053 .14964 L
.75174 .15161 L
.75306 .15426 L
.75448 .15779 L
.75706 .16615 L
.75958 .17706 L
.76189 .18994 L
.76716 .23142 L
.76981 .25937 L
.77272 .29485 L
.77824 .36663 L
.77983 .38514 L
.78134 .40042 L
.78271 .4118 L
.78346 .41686 L
.78417 .42078 L
.78543 .42567 L
.7861 .42709 L
.78682 .42771 L
.78811 .42641 L
.78929 .42259 L
.79058 .41563 L
.792 .40501 L
.79486 .37606 L
.79993 .31294 L
.8026 .28082 L
.80544 .25122 L
.80791 .22996 L
.81063 .21154 L
.81311 .19888 L
.81543 .19013 L
.81692 .18593 L
.81833 .18289 L
.8196 .18089 L
.82098 .17945 L
.82177 .17897 L
.82248 .17871 L
.8233 .17864 L
.82408 .17877 L
.82546 .17944 L
.82623 .18003 L
.82695 .1807 L
.82938 .1837 L
.83204 .18786 L
.83742 .19722 L
.84006 .20173 L
.84293 .20621 L
Mistroke
.84546 .20951 L
.84674 .21083 L
.84748 .21147 L
.84815 .21196 L
.84941 .21263 L
.85077 .21295 L
.85197 .21288 L
.85323 .21243 L
.85439 .21169 L
.85547 .21073 L
.85793 .20767 L
.86079 .20284 L
.8635 .19741 L
.86855 .18579 L
.87396 .17215 L
.87989 .15788 L
.88244 .15284 L
.88518 .14839 L
.88776 .14508 L
.89012 .14274 L
.8914 .14172 L
.89277 .14087 L
.89356 .14049 L
.89427 .14023 L
.89499 .14005 L
.89567 .13997 L
.89699 .14009 L
.8982 .14056 L
.89953 .14153 L
.9002 .14222 L
.90093 .14315 L
.90224 .14525 L
.90347 .14782 L
.90578 .15427 L
.90827 .16382 L
.91096 .17773 L
.91332 .19349 L
.91583 .21469 L
.92031 .26653 L
.92538 .34423 L
.93019 .41929 L
.93148 .43565 L
.93285 .45009 L
.93363 .45677 L
.93435 .46169 L
.93507 .46548 L
.93574 .46796 L
.93701 .46966 L
.93818 .4678 L
.93946 .46205 L
Mistroke
.94082 .45205 L
.94202 .44024 L
.94311 .42739 L
.94556 .39311 L
.94998 .32411 L
.95486 .25793 L
.95732 .23261 L
.96003 .21119 L
.9625 .19697 L
.96389 .19086 L
.96516 .18631 L
.96638 .18285 L
.96751 .18033 L
.96869 .17841 L
.96998 .17706 L
.97118 .1765 L
.97231 .17653 L
.97332 .177 L
.97442 .17794 L
.97563 .17945 L
.9769 .18154 L
.97918 .18632 L
1 .23908 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo000Yooooo`;o0000R_ooool00ol0003oooooooooo`2`
ooooo`009oooool6o`0008Sooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000oooooooo
ool01?ooool2o`0001kooooo1ol0001Qooooo`;o0000/Oooool002Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
7oooool6o`0003Wooooo00?o0000ooooooooool0/?ooool002Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?oo
ool2o`0000Kooooo0_l0000gooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`Oo00003_ooool0
0ol0003oooooooooo`1jooooo`;o0000=?ooool002?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`;o00003?ooool00ol0
003oooooooooo`1iooooo`;o000000?oooooo`000?l00000<_ooool002?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo0_l0000:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool6o`0002_ooooo1?l0000[ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool002;ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo0_l00004ooooo`;o0000
:Oooool2o`0000;ooooo0_l0000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
<?ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Gooooo0_l00007ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00005Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;oooool0
023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo0_l0000<ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;oooool0023o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013o
oooo0_l0000>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool001Gooooo
0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bo`00000Cooooo`03o`000?oooooo
oooo00Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko
00004_ooool00ol0003oooooooooo`05ooooo`Go00000oooool01_o^k^ko<S8bo`000?lb<S;ok^k^
o`0001;ooooo00?o0000ooooooooool01_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^6Oooool6o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool05Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Cooooo`03o`00
0?oooooooooo00Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?l000004oooool00ol0003oooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`0001?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`;o
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Ko0000oiRHV?lQ8B7ok^k^oooooom4
A4@3ooooo`05ogMgMonHV9So0000oiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00Go0000oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`00
00?ooooo00Go410@ooooooooooooooooo`00000Booooo`Ko00001_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo000001?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`05
oa0@4?ooooooooooooooool@41006?ooool01_l0003ooooooooooonHV9So8B4Qonk^kPCooooo00Go
410@ooooool0003ooooooa0@400Oooooo`05o`000?ooooooooooooooool000000oooool00ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo01?ooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo
000001Cooooo00?o0000ooooooooool01_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000004oooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01ol0003ooooooooooooooooo0000ooooool000005?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00?o0000ooooooooool00_l0000Nooooo`04ojVYZOl@413oooooooooo`;o00000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Co
oooo00?o0000ooooooooool00_l0000Dooooo`03o`000?oooooooooo00Gooooo00?o410@o`000?nj
^[X00oooool00ol0003oooooooooo`02o`0001Cooooo00?o0000ooooooooool01oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000001Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool0
1?ooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00;o00007Oooool00ol@413o0000
okZj^P02ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo
0_l000001?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413oooooooooool0003o410@01Gooooo00?o0000oooo
ooooool01Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41005?ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@oooo
o`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01_l@413ooooooooo
oooooooo410@o`0001Kooooo00?o0000ooooooooool01?ooool2o`0000cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005Oooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`0@
ooooo`?o00002_ooool01_nj^[[o8B4Qooooool0003ooooooa0@40?ooooo00?o410@ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`07o`000?oooooo0000oooooomgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01Omg
MgOoV9RHooooool0003oMgMg01Gooooo00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Dooooo`03o`000?oooooooooo00Cooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mgMgL05Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0
000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`Go0000
0_ooool2o`0000Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`00
0?mgMgL04?ooool01Ol0003ooooooooooooooooo000000Kooooo00go410@oiRHV?oooooo^[Zjo`00
0?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03_ooool0
2?l0003ooooooooooooooooo0000onk^k_m4A4Co00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Eoooo
o`03o`000?oooooooooo00;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000o`000?o^k^h05?ooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Gooooo00?o0000ooooooooool01?ooool00omEEEGo
IVIVo`000004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00005_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool01?mEEEGoIVIVo`000?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`02ooooo`Co0000
1_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0@oooo
o`05o`000?ooooooooooooooool000001_ooool01_nYZJWo410@o`000?l@413oZJVYo`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00kooooo00So0000oooooooo
ooooooooo`000?ooooooMgMgo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`00000Jooooo`007Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0G
ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Gooooo`007?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool4
o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool04Oooool001_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`006_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo000Iooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool001Wooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Booooo`006Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_oo
ool001Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`005_ooool3o`00023ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Ooo
ool003[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo000j
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0L
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`00>_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool003_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo000kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`00>oooool01Ol0003ooooooooooooo
oooo0000023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02o`0000Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07oooool003cooooo00?o0000ooooool000008_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0M
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool003cooooo0ol0000R
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Oooooo`00HOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07oooool0067ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo001Rooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`00H_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool006?ooooo00Co0000oooo
oooooooo00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Pooooo`00Hoooool01?l0003oooooooooool0000R
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool01?l0003oooooo`000?l0
0004ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo023ooooo001Sooooo`04o`000?ooooooooooo`0002?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08?ooool006Cooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo002:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo002;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08Oooool2o`0000Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool008_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Qooooo`;o00001Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`00Rooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo1Ol00005ooooo`;o00001?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Pooooo`00S?ooool01?l0003oooooooooool0000Jooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01Oooool2o`0000Cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool008cooooo00Co
0000oooooooooooo00006oooool00onHV9So8B4Qonk^kP06ooooo`Co00000_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Pooooo`00S?ooool00ol0003oooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0
0004ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo027ooooo002=ooooo`;o00007_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00:kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo002Zooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
027ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo002eooooo`05o`000?ooooooooooooooool000009Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00;Go
oooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Qooooo`00]Oooool2o`0000;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool08Oooool00;Gooooo0_l000000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`00]Oooool2o`000003ooooool0
003ooooo02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo027ooooo002eooooo`03o`000?oooooo000002Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo002eooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
027ooooo002eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo027ooooo002eooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo
002eooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo027ooooo002eooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000
:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Qooooo`00]Oooool2o`0002[ooooo00Co0000oooooooooooo0000
:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Rooooo`00]Oooool00ol0003oooooooooo`0Yooooo`04o`000?oo
ooooooooo`0002Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00;Gooooo00?o0000ooooooooool0:Ooo
ool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo002eooooo`03o`000?oo
oooooooo02Wooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00]Ooo
ool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8_ooool00;Gooooo00?o0000ooooooooool0:_ooool3o`0002Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_oo
ool00;Gooooo00?o0000ooooooooool0:_ooool2o`0002[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool0
0;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02;ooooo002eooooo`;o0000Eoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00]Oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02;ooooo002eooooo`03o`000?oooooooooo05Kooooo00Go
0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8_ooool00;Gooooo00?o0000ooooooooool0E_ooool01Ol0003ooooooooooooooooo000002[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00]Oooool00ol0003ooooooooo
o`1Fooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02;ooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`1Fooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02;ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_oo
ool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Rooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0Eoooool01?l0003ooooooooo
ool0000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00:[ooooo00Co
A4A4omgMgOoooooo00001oooool3o`0005Oooooo00?o0000ooooool00000;?ooool01Ol0003ooooo
oooooooooooo000002Gooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooo`00000/ooooo`05o`000?ooooooooooooooool000009Oooool00:_o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo000002co
oooo00Go0000ooooooooooooooooo`00000Uooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooool00000;?ooool01Ol0003ooooooooooooooooo0000
02Gooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0F?ooool2o`0002co
oooo00Go0000ooooooooooooooooo`00000Uooooo`00]Oooool00ol0003oooooooooo`1Hooooo`;o
0000;?ooool01Ol0003ooooooooooooooooo000002Gooooo002eooooo`03o`000?oooooooooo08Ko
oooo00Go0000ooooooooooooooooo`00000Uooooo`00]Oooool00ol0003oooooooooo`26ooooo`05
o`000?ooooooooooooooool000009Oooool00;Gooooo0_l00027ooooo`05o`000?oooooooooooooo
ool000009Oooool00;Gooooo00?o0000ooooooooool0Q_ooool01Ol0003ooooooooooooooooo0000
02Gooooo002eooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo00009Oooool00;Go
oooo00?o0000ooooooooool0Qoooool01?l0003oooooooooool0000Uooooo`00]Oooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooo000002Kooooo002eooooo`03o`000?oooooooooo08Oooooo
00?o0000ooooool000009_ooool00;Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooo`00
000Vooooo`00]Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo000002Kooooo002eoooo
o`;o0000R?ooool00ol0003oooooo`00000Vooooo`00]Oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooo000002Kooooo002eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
9Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[o
oooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@
0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/ooo
ool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`00
0?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03
olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A01looooo`00QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_oo
ool00onHV9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo
1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00Cooooo00?oV9RHob4Q8Oo^
k^h0O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07?oo
ool00ol@413o0000okZj^P06ooooo`03ogMgMomVIVKooooo07_ooooo0025ooooo`06o`000?n7QhOo
ZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol@413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool01_ooool00ol0003o
ooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00Go0000okZj^_ooooooV9RHoa0@401looooo`00Q?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<07cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21416 m
.00488 .187 L
.00942 .16755 L
.01441 .15186 L
.01721 .14521 L
.01975 .14028 L
.02488 .1329 L
.02778 .12997 L
.03045 .12791 L
.03279 .12655 L
.03536 .12549 L
.03666 .12511 L
.03737 .12495 L
.03805 .12482 L
.03936 .12464 L
.04057 .12456 L
.04126 .12455 L
.042 .12457 L
.04335 .12468 L
.04467 .12488 L
.04588 .12515 L
.04719 .12553 L
.04863 .12607 L
.05154 .12755 L
.05408 .12931 L
.0568 .13174 L
.06172 .13776 L
.06469 .14259 L
.06792 .14905 L
.0738 .16447 L
.07952 .18433 L
.08481 .20626 L
.0894 .22632 L
.09424 .2455 L
.09677 .25351 L
.09811 .25693 L
.09954 .25986 L
.10086 .26186 L
.10206 .26303 L
.10327 .26359 L
.10441 .26354 L
.10576 .26274 L
.10644 .26204 L
.10719 .26105 L
.10852 .25875 L
.10976 .25599 L
.11256 .24791 L
.11556 .23701 L
.12604 .19353 L
.13119 .17492 L
Mistroke
.13668 .15927 L
.13983 .1522 L
.14269 .14693 L
.1456 .14254 L
.14827 .13925 L
.15077 .13675 L
.1535 .13454 L
.15625 .13282 L
.15915 .13147 L
.1617 .13063 L
.16314 .13029 L
.16444 .13005 L
.16566 .12988 L
.16698 .12977 L
.16823 .12973 L
.16938 .12973 L
.17062 .12979 L
.17193 .12992 L
.17304 .13008 L
.17426 .13031 L
.17558 .13062 L
.17698 .13104 L
.17951 .13202 L
.18208 .13335 L
.1845 .13495 L
.18902 .13903 L
.19165 .14221 L
.19443 .14636 L
.19941 .1563 L
.20477 .17144 L
.21066 .19423 L
.22117 .24747 L
.22367 .26017 L
.22634 .27219 L
.22861 .28056 L
.22992 .28438 L
.23112 .28714 L
.23249 .28935 L
.2332 .2901 L
.23396 .29058 L
.23523 .29065 L
.23595 .29027 L
.23662 .28966 L
.2374 .28863 L
.23813 .28736 L
.23951 .28422 L
.24099 .27981 L
.2426 .27397 L
.25307 .22205 L
.25786 .19877 L
Mistroke
.263 .17814 L
.26594 .16864 L
.26864 .16137 L
.27392 .15066 L
.27673 .14658 L
.27934 .14362 L
.2822 .14115 L
.28366 .14015 L
.28525 .13926 L
.28676 .13855 L
.28815 .13804 L
.28948 .13764 L
.29089 .13732 L
.29215 .13712 L
.29333 .137 L
.29462 .13692 L
.29601 .13692 L
.29729 .13697 L
.29802 .13703 L
.2987 .1371 L
.30008 .13727 L
.30156 .13753 L
.30424 .13813 L
.3067 .13884 L
.31236 .14109 L
.31521 .1426 L
.31832 .1446 L
.32362 .14911 L
.32658 .15243 L
.32927 .15611 L
.33179 .16025 L
.33451 .16568 L
.33946 .17859 L
.34933 .21926 L
.35993 .28019 L
.36305 .29626 L
.36459 .30286 L
.36601 .30795 L
.3673 .31159 L
.36867 .31434 L
.36945 .31536 L
.37019 .31595 L
.37156 .31606 L
.37289 .31493 L
.37356 .31391 L
.37429 .31246 L
.37559 .30905 L
.37679 .30498 L
.37952 .29302 L
.38244 .27704 L
Mistroke
.38778 .24412 L
.39358 .21027 L
.39869 .18599 L
.40149 .17527 L
.40411 .16682 L
.40899 .15476 L
.41158 .15003 L
.41437 .14603 L
.4169 .14323 L
.41931 .14121 L
.42147 .13986 L
.4227 .13927 L
.42384 .13884 L
.42518 .13844 L
.42586 .13829 L
.42661 .13817 L
.42793 .13803 L
.42916 .13801 L
.42991 .13803 L
.43062 .13809 L
.43194 .13827 L
.43268 .13841 L
.43337 .13857 L
.43492 .13901 L
.43733 .13991 L
.43999 .14119 L
.44537 .14465 L
.45022 .14867 L
.45545 .1539 L
.46491 .16596 L
.47011 .17456 L
.47495 .18451 L
.48026 .19861 L
.48594 .21871 L
.49746 .27738 L
.50253 .30563 L
.5054 .31921 L
.50681 .32465 L
.50809 .32875 L
.50938 .33193 L
.51061 .33399 L
.5119 .3351 L
.51263 .33523 L
.51331 .33501 L
.51404 .33443 L
.51472 .33356 L
.51599 .33109 L
.51736 .32724 L
.51884 .32181 L
.5218 .30758 L
Mistroke
.52491 .28902 L
.5305 .25226 L
.53537 .22186 L
.54059 .19452 L
.54631 .17168 L
.55165 .1565 L
.55435 .1507 L
.55721 .14568 L
.55969 .14217 L
.56236 .13915 L
.56521 .1367 L
.56789 .13507 L
.56944 .13441 L
.57022 .13415 L
.57107 .13392 L
.5718 .13376 L
.57258 .13364 L
.57332 .13357 L
.57399 .13354 L
.57531 .13358 L
.57597 .13364 L
.57671 .13374 L
.578 .13402 L
.57921 .13439 L
.58064 .13495 L
.58194 .13558 L
.58486 .13744 L
.58739 .13955 L
.59013 .14239 L
.59512 .14899 L
.60497 .16749 L
.61585 .19591 L
.6379 .27475 L
.64777 .31825 L
.65017 .32776 L
.65274 .3364 L
.65421 .34038 L
.65555 .34323 L
.6569 .34527 L
.65818 .34636 L
.65956 .34657 L
.66026 .34627 L
.66102 .34563 L
.66238 .34368 L
.66365 .34092 L
.66514 .33654 L
.66651 .33153 L
.66959 .31715 L
.68006 .25145 L
.68972 .19619 L
Mistroke
.69511 .17339 L
.7 .15766 L
.7028 .15053 L
.70582 .14415 L
.70848 .13953 L
.71129 .13556 L
.71389 .13263 L
.71675 .13016 L
.718 .1293 L
.71934 .12854 L
.72059 .12796 L
.72177 .12754 L
.72305 .1272 L
.72373 .12708 L
.72446 .12698 L
.72519 .12693 L
.72595 .12693 L
.72732 .12703 L
.72859 .12726 L
.72977 .12759 L
.73107 .12808 L
.73245 .12875 L
.73559 .13089 L
.73854 .13372 L
.7412 .137 L
.74407 .14141 L
.74942 .15222 L
.75507 .16775 L
.7652 .20636 L
.77587 .25599 L
.786 .29798 L
.79509 .32605 L
.80029 .33937 L
.80499 .34944 L
.80627 .35157 L
.80764 .35347 L
.80894 .3548 L
.81013 .35556 L
.8114 .35581 L
.81212 .35567 L
.81279 .35535 L
.81414 .35411 L
.8149 .35305 L
.81559 .35185 L
.81685 .34909 L
.81801 .34585 L
.82064 .3362 L
.82542 .31136 L
.83674 .23631 L
.84228 .20339 L
Mistroke
.84736 .179 L
.85221 .16097 L
.85682 .14804 L
.86169 .13811 L
.86444 .13389 L
.867 .13073 L
.86983 .12801 L
.87249 .12609 L
.87489 .12486 L
.87623 .12436 L
.87748 .12401 L
.87881 .12376 L
.88007 .12364 L
.88144 .12364 L
.88221 .12369 L
.88291 .12378 L
.88364 .12391 L
.88432 .12406 L
.88586 .12454 L
.88721 .1251 L
.88865 .12585 L
.89115 .12755 L
.89377 .12992 L
.89848 .13587 L
.9011 .14028 L
.90354 .14522 L
.90908 .15982 L
.91393 .17706 L
.91835 .19661 L
.92826 .25143 L
.93331 .2806 L
.93804 .30444 L
.94296 .32324 L
.94558 .33052 L
.94839 .33663 L
.95974 .3559 L
.96237 .36117 L
.96518 .36679 L
.96654 .36926 L
.96782 .37127 L
.96897 .37272 L
.97022 .3738 L
.9711 .37421 L
.97207 .37425 L
.97308 .37382 L
.97402 .37293 L
.97491 .37164 L
.97571 .37007 L
.97752 .36513 L
.97948 .35756 L
Mistroke
.98162 .34684 L
.98549 .32185 L
1 .21416 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo000Rooooo`;o0000TOooool00ol0003oooooooooo`1e
ooooo`Co0000=oooool001oooooo1?l000001?oooooo0000o`000?l0002>ooooo`03o`000?oooooo
oooo04?ooooo1?l0000/ooooo`;o00000oooool2o`0003Kooooo000Oooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07oooool6o`0006Kooooo0_l00013ooooo`;o00000_ooool3o`00
02Wooooo0_l00006ooooo`03o`000?oooooooooo03?ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07?ooool2o`0000Kooooo0_l0001Tooooo`03o`000?oooooooooo01?o
oooo1?l0000Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03;ooooo000Mooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06oooool2o`0000Sooooo0_l0000Pooooo`Co0000?oooool00ol0003ooooo
ooooo`0Booooo`;o00000_ooool2o`0002Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool001cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06oooool3o`0000?ooooo0ol0000Sooooo`Ko00004oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo0_l0000Uooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000L
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Wooooo0_l00008ooooo`;o00007oooool2o`0000Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`006oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00[ooooo0_l0000Mooooo`03o`000?oooooooooo00Kooooo0_l0000@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo033ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0`ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0;oooool001[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0;oooool001[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo000Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`005Oooool2o`000009
oa0@4?oooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o0000ooooooooool02_oo
ool03OnHV9So410@o`000?lb<S;oc<c<ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03ooo
ool00ol0003oooooooooo`09ooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^017ooooo
00?o0000ooooooooool02?ooool4o`000009oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko
0000017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooool000000ol000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^4Oooool00ol0003oooooooooo`06ooooo`Go00000oooool01Ol0003o<S8bo`000?lb<S;ok^k^
01_ooooo00Go0000oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h03_ooool001Kooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
3Oooool00ol0003oooooooooo`0:ooooo`0=oa0@4?nj^[[oooooogMgMolb<S;oooooo`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo00Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05o`000?nHV9SooooooiRHV?mgMgL04Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Cooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00Kooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL06_ooool01_l0
003o410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000;ooooo`Ko00000_ooool5o`000004ooooool0003ooooooa0@40?ooooo00?o410@oooooooo
ool03?ooool01?l0003oooooooooooooool6o`0000Kooooo00Go0000ooooool0003ooooooa0@4003
ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool01_l00003ooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go0000oooooooooooooooooa0@400Booooo`Oo00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00004ooooo`05
oa0@4?ooooooooooooooool@41004Oooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@o`000?oooooooooooa0@400Jooooo`03o`000?oooooooooo00;ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01_m4A4CogMgMoooo
ool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00cooooo00?oZJVYoa0@4?l000000_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooooooool02_ooool00onHV9So8B4Qonk^kP02ooooo`;o00000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo0000013ooooo
00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP03ooooo`;o00000_ooool00ol0003ooooo
ooooo`0Hooooo`06o`000?oooooooooooooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04_ooool01?m4A4CogMgMooooool00004ooooo`05o`000?oo
ooooooooooooool000003_ooool001?ooooo00KogMgMoeEEEOoooooo0000ooooool00002ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0;ooooo`04oa0@4?l0003o^[Zj
o`0000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00_ooooo00Co
MgMgofIVI_oooooooooo0_l00003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`000004ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0:oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooool0003oooooo`00000Iooooo`07o`000?oooooo
ooooooooool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`0Aooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>
ooooo`005?ooool01OmgMgOoc<c<o`000?oooooo000000;ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjob4Q8Ol000000_ooool01Ol@413ooooooooo
oooooooo410@017ooooo00?o0000ooooooooool02oooool01Ol0003oooooooooool0003o410@00?o
oooo00?o410@ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00Go410@ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00Kooooo0_l0000<oooo
o`03o`000?oooooooooo01;ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0;ooooo`09o`000?ooooooooooooooool@413oooooo`000?oooooo410@01Wo
oooo00?o0000ooooooooool00_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001oooool00ol0003oooooooooo`0Booooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@400>ooooo`005?ooool01?o^k^koA4A4o`000?l00003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`04oa0@4?nHV9SooooookZj^P;o0000
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo00?o0000ooooooooool01oooool01Ol0003o
^[ZjoooooonHV9So410@00;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgLCooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg01Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo
0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01Wooooo00Oo0000
ooooool@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03
o`000?oooooooooo01;ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00kooooo000Eooooo`03ogMgMol0003o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?oooo
o`03o`000?oooooooooo00Sooooo00GoZJVYoa0@4?l0003o410@o`000003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`07ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o0000ooooooooool01_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000o`000?o^k^h05_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00omEEEGo0000o`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`08ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Oo0000oooooonY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oo
oooooooo01?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
000Gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0[ooooo`005oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0:oooool001Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02_ooooo000Gooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0[ooooo`005_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0:oooool001Koooooool00010o`0001?ooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo000booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`00
<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
4Oooool003;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo017ooooo000booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Booooo`00<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_oo
ool003?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo000c
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`00<oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool003Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`00=?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo000dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool003Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`00=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo000e
ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool01?l0003oooooo`00
0?l00008ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo000fooooo`?o00009?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool003Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04oooool005kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01?ooooo001Nooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Dooooo`00G_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`;o0000
2?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Dooooo`00G_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`;o00002?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Dooooo`00G_ooool01Ol0003ooooooooooooooooo000002Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`;o00002?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Dooooo`00Goooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08_ooool3o`0000Kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool005oooooo00Co0000
oooooooooooo00009Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`00H?ooool2o`0002Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05?ooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool008Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05Oooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05Oooool008[ooooo00Go0000oooooooooooooooo
o`00000Kooooo`Go00001_ooool2o`0000Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool008[ooooo00Go
0000ooooooooooooooooo`00000Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool2o`0000Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05Oooool008[ooooo00Co0000oooooooooooo00007Oooool00onHV9So
8B4Qonk^kP07ooooo`?o00001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`00Roooool00ol0003ooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l00005ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo
002;ooooo`?o00007oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Kooooo002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo002Zooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo002eoooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00;Gooooo00Ko0000oooooooo
oooo0000ooooool0000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`00]Oooool2o`000004ooooool0003o0000o`0002_ooooo00Go0000
ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo002eooooo`03o`000?oooooo
oooo02kooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`00]Oooool0
0ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05ooo
ool00;Gooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000Zooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Oooooo002eooooo`03o`000?oooooooooo02oooooo0_l0000/ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Oooooo002eooooo`03o`000?oooooooooo05kooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00;Gooooo00?o0000oooo
ooooool0G_ooool2o`000003ooooool0003ooooo02_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`1Oooooo`;o0000;_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooooooo08oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`00]Oooool2o`00097ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00;Gooooo00?o0000oooo
ooooool0TOooool01Ol0003ooooooooooooooooo000001[ooooo002eooooo`03o`000?oooooooooo
09;ooooo00?o0000ooooool000006oooool00;Gooooo00?o0000ooooooooool0Toooool00ol0003o
ooooooooo`0Jooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002/ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool00:[ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`2`ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`oooo
o`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000
olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj
^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooo
oomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o
000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o000000?o410@oooo
ooooool0N_ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko
00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0
003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool04?ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooooooo`Go0000O?ooool008Go
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00onYZJWo410@ooooo`02ooooo`04odA4A?oMgMgoooooo`0007gooooo0025ooooo`06o`000?oM
gMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooo
ooooooooooooo`00000Booooo`03o`000?oooooooooo01cooooo00?o410@o`000?nj^[X00oooool0
1?oMgMgoEEEEooooool0001mooooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l0
00000ol0000Looooo`03okZj^_lQ8B7ooooo00?ooooo00?oMgMgolc<c?l00000OOooool008Gooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0004ooooo`03onk^k_m4A4Co000007gooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7
o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oo
oooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo07cooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33996 m
.00488 .26606 L
.00942 .2142 L
.01204 .19233 L
.01441 .17663 L
.01716 .1626 L
.01975 .15267 L
.02227 .14568 L
.02354 .14302 L
.02494 .14068 L
.02613 .13914 L
.02741 .13788 L
.02862 .13703 L
.02973 .13649 L
.03111 .13611 L
.03239 .13599 L
.03312 .13602 L
.03379 .1361 L
.03456 .13625 L
.03529 .13646 L
.03661 .13699 L
.03782 .13766 L
.03916 .1386 L
.04057 .13985 L
.04332 .14309 L
.04583 .14699 L
.05147 .15887 L
.0567 .17337 L
.06166 .19035 L
.07288 .23508 L
.07561 .24442 L
.07855 .25251 L
.08024 .25599 L
.08097 .25722 L
.08178 .25835 L
.08249 .25916 L
.08325 .25981 L
.08406 .26026 L
.08481 .26046 L
.08549 .26044 L
.08622 .26023 L
.08751 .25935 L
.08823 .25857 L
.08891 .25767 L
.09044 .255 L
.09301 .2488 L
.09576 .24013 L
.10571 .2018 L
.11057 .18414 L
.11575 .1681 L
Mistroke
.12063 .15609 L
.12505 .14784 L
.13054 .14035 L
.13569 .13528 L
.1386 .13314 L
.14127 .13162 L
.1442 .13039 L
.14567 .12992 L
.14729 .12949 L
.14871 .12919 L
.15005 .12896 L
.15125 .12879 L
.15256 .12866 L
.15324 .12861 L
.15399 .12857 L
.15477 .12855 L
.1555 .12855 L
.15681 .1286 L
.15754 .12866 L
.15821 .12873 L
.15944 .12892 L
.16058 .12916 L
.16184 .1295 L
.16318 .12994 L
.16591 .13113 L
.1684 .13253 L
.1735 .13653 L
.17608 .13926 L
.1789 .143 L
.18391 .15195 L
.18858 .16344 L
.19409 .18142 L
.19912 .2023 L
.2046 .22889 L
.21043 .25726 L
.21281 .26724 L
.21537 .27605 L
.21684 .27997 L
.21818 .28274 L
.21947 .28459 L
.22082 .28566 L
.22197 .28585 L
.2232 .28532 L
.22436 .28413 L
.22542 .28249 L
.22666 .2799 L
.228 .27636 L
.23045 .26821 L
.24082 .22198 L
.24632 .19891 L
Mistroke
.25223 .17917 L
.25512 .17159 L
.25786 .16558 L
.26052 .16073 L
.263 .157 L
.26782 .15138 L
.27308 .14697 L
.27597 .14512 L
.27869 .14368 L
.28377 .14159 L
.28921 .13982 L
.29208 .13901 L
.29517 .13826 L
.29659 .13798 L
.29794 .13776 L
.29916 .1376 L
.30047 .13747 L
.30172 .13738 L
.30305 .13734 L
.30418 .13735 L
.30543 .1374 L
.30611 .13745 L
.30683 .13752 L
.30812 .13769 L
.3095 .13795 L
.31102 .13834 L
.31233 .13878 L
.31374 .13938 L
.31626 .14085 L
.31877 .14289 L
.32149 .14589 L
.32406 .14959 L
.32643 .15387 L
.33092 .16474 L
.33318 .17184 L
.33566 .18108 L
.34115 .20719 L
.34635 .23851 L
.35107 .26943 L
.3561 .29871 L
.35757 .30544 L
.35896 .31065 L
.36021 .31431 L
.36155 .31705 L
.36283 .31845 L
.36418 .31859 L
.36534 .31763 L
.3666 .31545 L
.36737 .31358 L
.3681 .31144 L
Mistroke
.36946 .30656 L
.37252 .29206 L
.37804 .25901 L
.38329 .22737 L
.38822 .20253 L
.39335 .18323 L
.39607 .17573 L
.39901 .16956 L
.40148 .16569 L
.40279 .16407 L
.40419 .16261 L
.40553 .16146 L
.40674 .16058 L
.40798 .15985 L
.40911 .1593 L
.4102 .15888 L
.4114 .15851 L
.4126 .15824 L
.41388 .15806 L
.415 .15797 L
.4162 .15795 L
.41733 .15798 L
.41836 .15804 L
.4196 .15816 L
.42076 .1583 L
.42341 .15863 L
.42466 .15878 L
.42599 .1589 L
.42668 .15895 L
.42744 .15899 L
.42877 .15903 L
.43003 .15902 L
.43118 .15897 L
.4325 .15888 L
.43375 .15875 L
.43598 .15843 L
.43839 .15797 L
.44102 .1573 L
.4439 .15634 L
.44973 .15374 L
.45473 .15137 L
.4561 .15081 L
.45756 .1503 L
.45883 .14992 L
.46019 .14961 L
.46096 .14947 L
.46167 .14938 L
.46234 .14931 L
.46306 .14928 L
.4643 .1493 L
Mistroke
.46566 .14945 L
.46696 .14975 L
.46768 .14999 L
.46835 .15027 L
.46963 .15095 L
.47085 .15181 L
.47203 .15287 L
.47328 .15427 L
.47552 .15757 L
.47794 .16245 L
.4806 .16967 L
.48344 .17978 L
.48605 .19148 L
.49192 .22744 L
.49705 .26906 L
.50253 .31621 L
.50532 .33627 L
.50668 .34414 L
.50794 .34993 L
.50908 .35386 L
.5103 .35651 L
.51151 .35754 L
.51285 .35678 L
.5141 .35428 L
.51524 .35056 L
.51655 .34466 L
.5178 .33765 L
.52243 .30278 L
.52787 .25541 L
.53297 .2163 L
.5383 .18645 L
.54113 .17513 L
.54418 .166 L
.54671 .16059 L
.54814 .15829 L
.54948 .15662 L
.5502 .15589 L
.55089 .15531 L
.55218 .15449 L
.55356 .15397 L
.55434 .15383 L
.55506 .15379 L
.55625 .15391 L
.55737 .1542 L
.55859 .15471 L
.55991 .15544 L
.56259 .15743 L
.56505 .15975 L
.57441 .17118 L
.57954 .17743 L
Mistroke
.58206 .17992 L
.58438 .18173 L
.58565 .1825 L
.58699 .18316 L
.58833 .18363 L
.58909 .18382 L
.5898 .18395 L
.59105 .18405 L
.59218 .18401 L
.59348 .1838 L
.59472 .18345 L
.59588 .18297 L
.59711 .18232 L
.59932 .18077 L
.6017 .1786 L
.60432 .17572 L
.60985 .16889 L
.61287 .16531 L
.61567 .16237 L
.61828 .16012 L
.61941 .15933 L
.62064 .15861 L
.622 .15804 L
.62327 .15773 L
.62398 .15767 L
.62473 .15771 L
.62608 .15805 L
.62734 .15874 L
.62849 .15972 L
.62982 .1613 L
.63108 .1633 L
.63332 .16817 L
.63576 .17563 L
.63843 .18671 L
.64128 .2023 L
.6464 .24154 L
.65196 .29924 L
.65499 .33324 L
.65782 .36209 L
.66023 .38155 L
.66159 .38945 L
.66282 .39443 L
.66417 .39727 L
.66493 .39762 L
.66564 .39712 L
.66693 .3942 L
.6683 .38836 L
.66958 .38055 L
.67096 .3699 L
.67346 .34599 L
Mistroke
.67913 .28164 L
.682 .25055 L
.68513 .221 L
.68812 .19788 L
.69083 .18116 L
.69361 .16783 L
.69503 .16233 L
.69657 .15729 L
.698 .15339 L
.69931 .15043 L
.70065 .14797 L
.7019 .14615 L
.70303 .14487 L
.70424 .14384 L
.70559 .1431 L
.70682 .14277 L
.7081 .14273 L
.70882 .14284 L
.70949 .14302 L
.71072 .14355 L
.71203 .14437 L
.71322 .14533 L
.71452 .14662 L
.71715 .1499 L
.72185 .15783 L
.73245 .18212 L
.73725 .19361 L
.73989 .19927 L
.74239 .20388 L
.74471 .20733 L
.74594 .20878 L
.74723 .21 L
.74832 .21078 L
.74953 .21135 L
.75062 .21162 L
.75164 .21165 L
.75295 .21136 L
.75368 .21105 L
.75435 .21067 L
.75564 .20969 L
.75686 .20847 L
.7596 .2048 L
.76255 .1996 L
.7676 .18905 L
.77292 .17777 L
.77776 .16926 L
.77908 .16742 L
.7805 .16574 L
.78184 .1645 L
.78306 .16368 L
Mistroke
.78425 .16322 L
.78535 .16312 L
.78656 .16342 L
.78785 .16423 L
.78896 .16539 L
.79 .1669 L
.79115 .16905 L
.79238 .17197 L
.81303 .35331 L
.81594 .39003 L
.81737 .40535 L
.81869 .41711 L
.81941 .42243 L
.82021 .42726 L
.82101 .43096 L
.82185 .43355 L
.82257 .43464 L
.82334 .43467 L
.82407 .43361 L
.82473 .43173 L
.82611 .42507 L
.8274 .41581 L
.82881 .40264 L
.83031 .38578 L
.8356 .3141 L
.84102 .24472 L
.84387 .21586 L
.84687 .1916 L
.8495 .17493 L
.85239 .16088 L
.85502 .15139 L
.85746 .145 L
.85869 .14258 L
.86003 .14048 L
.8613 .13897 L
.86246 .13792 L
.86352 .13724 L
.86467 .13673 L
.86588 .13645 L
.86702 .13639 L
.86833 .13655 L
.86959 .13692 L
.87071 .13742 L
.87194 .13817 L
.87327 .13921 L
.87469 .1406 L
.87724 .14388 L
.87997 .14849 L
.88286 .15448 L
.88804 .16747 L
Mistroke
.89972 .20467 L
.90459 .22016 L
.90727 .22709 L
.90981 .23212 L
.91125 .23422 L
.91201 .2351 L
.91281 .23587 L
.91348 .23637 L
.91423 .23678 L
.91554 .23711 L
.91687 .23695 L
.91762 .23664 L
.9183 .23621 L
.91957 .23508 L
.9209 .23341 L
.93084 .20846 L
.94024 .18123 L
.94276 .17552 L
.94543 .17051 L
.94683 .16842 L
.94757 .16749 L
.94836 .16663 L
.94909 .16599 L
.94976 .16555 L
.95106 .16507 L
.95232 .16517 L
.95348 .16579 L
.95475 .16712 L
.95611 .16931 L
.95741 .1722 L
.95863 .17568 L
.9609 .18428 L
1 .33996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo0014ooooo`So0000JOooool2o`000;7ooooo0012ooooo`;o0000
1oooool2o`0006Sooooo00?o0000ooooooooool0/?ooool001oooooo0ol0000Nooooo`;o00002ooo
ool00ol0003oooooooooo`0Vooooo`;o0000?Oooool00ol0003oooooooooo`1aooooo`?o0000??oo
ool001kooooo00Co0000oooooooooooooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08?ooool5o`000003ooooool0003o000000;o0000>_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00;o0000>oooool001gooooo0_l00004ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`?o00002Oooool2
o`0003Wooooo00?o0000ooooooooool0?_ooool3o`0002kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0iooooo`007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`00
0?l00000;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Wooooo0_l0000?ooooo`03o`000?oooooooooo02Sooooo0ol0000:ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo0_l00003ooooo`;o0000
2?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`;o00001_oo
ool00ol0003oooooooooo`06ooooo`;o00003_ooool4o`0002_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_oo
ool001cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Oooooo3?l00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool2
o`0000?ooooo00?o0000ooooooooool03oooool3o`0001Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool0
01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Gooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=_ooool001Gooooo0_l000002Ol@413ooooooooooooooooo0000
oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo013ooooo00GoV9RHo`000?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0=ooooo`Go
000000Soooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kQ3ooooo00?o0000ooooooooool02Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_l0000Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo1?l000001?l@413oooooooooooo^k^h2o`000003oc8b<_o^k^kooooo00oooooo00?o0000
ooooooooool01oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`?o00004ooo
ool01Ol0003o410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Booooo`;o
00002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000F
ooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oo
oooooooo013ooooo00Go410@o`000?ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ol0003oooooooooo`0=ooooo`0=oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9So000001Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`05ogMgMol0003ooooooiRHV?mgMgL04?ooool00ol0003oooooooooo`07
ooooo`05o`000?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00Co0000oooooooooooo00004oooool01Ol0003o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRH
V?oooooo0000ogMgM`0Aooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol0003ooooooooooooo
oooo410@00Oooooo00?o0000ooooooooool02?ooool6o`0000?ooooo00Co0000oooooooooooo0000
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool01Oooool6o`0000?o
oooo00GoV9RHob4Q8Oo^k^koooooo`000002ooooo`05oa0@4?ooooooooooooooool@41004Oooool0
0ol0003oooooo`000005o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0
003o410@01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool2o`0000Cooooo00Go410@o`000?oooooooooo
oa0@400@ooooo`03o`000?oooooooooo00Oooooo00Co0000oiRHV?lQ8B7ok^k^1?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4002ooooo`03o`000?l@413o
oooo013ooooo00Co0000oooooooooooo00001_ooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`004oooool01?m4A4CogMgMooooool00003ooooo`;o00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooZJVYoa0@4003ooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0?ooooo`04oiRHV?lQ8B7ok^k^
o`0000;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02o`0001Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooo`000004ooooo`05o`000?oooooo0000ooooool000004?ooool00ol0003ooooo
ooooo`08ooooo`04o`000?nHV9So8B4Qonk^kP?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool01_l0003ooooooooooooooooo
ZJVYoa0@40?ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool0
00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01?ooooo00CogMgMoeEEEOoooooo00000oooool2o`0000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`05o`000?oooooo410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000000cooooo00?o0000ooooooooool03oooool00omgMgOo0000ooooo`02ooooo`05o`00
0?ooooooooooooooool000004_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooool0003oooooo`00000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool01Ol0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooogMgMomVIVH3ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo00Ko0000oooooooooooo410@o`000?nj^[X3
ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Dooooo`03ogMgMoo<c<co000000?ooooo00?o0000oa0@4?ooool00_ooool00ol@413ooooo
ooooo`06ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooo^[Zjob4Q8@03ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool01Ol@413oooooo`000?oooooo410@01Wooooo00?o0000ooooooooool00_oo
ool2o`0000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo0000ooooool@41003oooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooooooooa0@4002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool01_l0003ooooooooooooooooo
^[Zjob4Q8@?ooooo00Go410@ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001Cooooo00?ok^k^odA4A?l000000oooool01_l0003oMgMgoiRHV?ooooooV9RHogMg
M`Wooooo00?o0000ooooooooool03Oooool01_l0003o410@oiRHV?oooooo^[Zjo`0000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00cooooo00Go0000okZj^_oooooo
V9RHo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`Go00001?ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL03oooool00ol0003ooooooooo
o`08ooooo`05o`000?nj^[[o0000oiRHV?l@41000oooool01omgMgOoV9RHoooooonHV9SoMgMgoooo
ool000001_ooool00ol0003oooooooooo`0?ooooo`06o`000?l@413oV9RHoooooonj^[[o00000ooo
ool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`005Oooool00omgMgOo0000ooooo`02ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^2Oooool0
0ol0003oooooooooo`0=ooooo`06o`000?nYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?l0003oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo00Oooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko0000o`000?lb<S;ok^k^01Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?l0003ok^k^00oooooo00?o0000ooooooooool02?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Kooooo00?o0000
ooooooooool03_ooool01ol0003oooooojVYZOl@413o0000oa0@4?nYZJT00oooool01_o^k^ko<S8b
o`000?lb<S;ok^k^o`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`006_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Mooooo`006_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Looooo`006_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0L
ooooo`005_ooooooo`00043o00004oooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool04Oooool001Kooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`;o0000
1_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`05o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo
000Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6_ooool001Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06_ooool001Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6_ooool001Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06_ooool001Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Cooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo000H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Cooooo0ol0000Aooooo`03o`000?oooooooooo01Wooooo000H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool001Sooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01Sooooo000Hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
6?ooool001Sooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000002Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`005oooool00ol0003ooooooooo
o`0Eooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Hooooo`005oooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool09Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Rooooo`04o`000?oooooo0000o`0000Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oo
oooooooo01Kooooo0_l0000Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`005oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l00007ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003ooooo
ooooo`10ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Cooooo0_l00007ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003oooooooooo`10ooooo`05o`00
0?ooooooooooooooool000009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Co
oooo0_l00007ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Fooooo`005oooool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`0002Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`;o00001oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05_ooool001Oooooo
00?o0000ooooooooool0@Oooool3o`0002Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Uooooo`;o00001_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool05Oooool001Oooooo00?o0000ooooooooool0@_ooool2o`0002Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo000G
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Cooooo000Gooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo000Gooooo`03o`000?oo
oooooooo06gooooo00Go0000ooooooooooooooooo`00000Nooooo`Go00001_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Dooooo`005_ooool00ol0003oooooooooo`1_ooooo`04o`000?ooooooooooo`0001kooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000ooooooooool0
Koooool01?l0003oooooooooool0000Oooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00004ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`00
5_ooool00ol0003oooooooooo`1_ooooo`04o`000?ooooooooooo`00023ooooo00?oV9RHob4Q8Oo^
k^h01_ooool2o`0000Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01?ooooo000Fooooo`03o`000?oooooooooo06oooooo00Co0000ooooool0003o
00008Oooool00omgMgOoIVIVooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool001Kooooo00?o0000ooooooooool0
L?ooool2o`0002?ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo000Fooooo`03o`000?oo
oooooooo097ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`;o00001?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool001Kooooo00?o
0000ooooooooool0TOooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo0_l00004ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`005_oo
ool00ol0003oooooooooo`2Looooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooo
oooo09cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool0W?ooool3o`00
00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01;ooooo000Fooooo`03o`000?oooooooooo09cooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool001Kooooo
00?o0000ooooooooool0W?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`00]Oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00;Gooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo002eoooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16oooo
o`00]Oooool01_l0003oooooooooool0003oooooo`0002cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool0
0;Gooooo00?o0000ooooooooool00_l0000]ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo002eooooo`05
o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00]Oooool2o`00033o
oooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0A_ooool00;Gooooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo0000
02gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00]Oooool00ol0003o
ooooooooo`0_ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04Kooooo002eooooo`03o`000?oooooooooo02oooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00;Go
oooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0<?ooool01?l0003o
ooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00;Go
oooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0<?ooool01?l0003o
ooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00;Go
oooo0_l0000aooooo`03o`000?oooooo000002kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`17ooooo`00]Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo000002kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`17ooooo`00]Oooool00ol0003ooooooooo
o`0aooooo`;o0000;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo002e
ooooo`03o`000?oooooooooo037ooooo0_l0000^ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0H_ooool01Ol0003ooooooooooooooooo
000004Wooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Roooo
o`05o`000?ooooooooooooooool00000BOooool00:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Rooooo`05o`000?ooooooooooooooool00000BOooool00:[ooooo1Ol00006oooo
o`03o`000?oooooooooo06;ooooo00Go0000ooooooooooooooooo`000019ooooo`00Z_ooool01?m4
A4CogMgMooooool00007ooooo`?o0000H_ooool01?l0003oooooooooool0001:ooooo`00Z_ooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06;ooooo00Co0000oooooooooooo0000
B_ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Rooooo`04o`000?oo
ooooooooo`0004[ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooo`00001:ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooool00000B_ooool00;Gooooo00?o0000ooooooooool0Hoooool00ol0
003oooooo`00001:ooooo`00]Oooool00ol0003oooooooooo`1Sooooo`;o0000Boooool00;Gooooo
00?o0000ooooooooool0Hoooool2o`0004_ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00
Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@
4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@
o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002c
ooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c01looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmEEEGoMgMgoooooonH
V9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko
0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo0000
00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00onY
ZJWo410@ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40O?ooool008Gooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000001;ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000I
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0
003o000000?o00007?ooool00onj^[[o8B4Qooooo`02ooooo`03oeEEEOn7QhOooooo07kooooo0025
ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool00ooMgMgo410@oiRHV01nooooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03
ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`000?l@
411looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .44169 m
.00123 .44954 L
.00236 .4541 L
.00365 .45617 L
.00488 .45492 L
.00601 .45104 L
.00706 .44525 L
.00821 .43666 L
.00942 .42528 L
.01475 .35823 L
.01975 .29279 L
.02219 .26624 L
.02452 .24556 L
.0272 .22717 L
.02966 .21498 L
.03096 .21009 L
.03236 .20601 L
.03368 .20315 L
.03487 .20134 L
.03561 .20058 L
.03628 .20011 L
.03702 .19984 L
.0378 .19983 L
.03912 .2004 L
.03987 .20103 L
.04057 .20182 L
.04199 .20397 L
.04331 .20654 L
.0463 .21402 L
.05174 .23093 L
.05699 .24727 L
.05956 .25398 L
.06192 .25879 L
.06316 .26067 L
.06446 .2621 L
.06576 .26291 L
.06651 .26308 L
.06719 .26305 L
.06795 .2628 L
.06867 .26235 L
.07001 .26097 L
.07076 .2599 L
.07145 .25872 L
.07302 .25544 L
.07575 .24791 L
.07875 .23763 L
.08481 .21374 L
.08982 .1939 L
.09528 .17463 L
.1001 .1609 L
Mistroke
.10523 .14986 L
.10835 .14464 L
.11118 .1407 L
.11383 .13761 L
.11669 .13491 L
.1195 .13288 L
.12209 .1315 L
.12456 .13055 L
.1258 .13018 L
.12717 .12985 L
.12845 .1296 L
.12981 .12939 L
.13052 .1293 L
.13131 .12923 L
.13269 .12914 L
.13398 .12912 L
.13471 .12913 L
.13538 .12916 L
.13661 .12927 L
.13791 .12944 L
.13908 .12966 L
.14033 .12996 L
.14258 .13065 L
.14769 .13284 L
.15054 .13438 L
.15362 .13636 L
.15921 .14111 L
.16465 .14759 L
.16967 .15537 L
.17459 .16513 L
.17987 .17871 L
.18941 .21197 L
.19486 .23441 L
.20067 .25744 L
.20305 .26545 L
.20562 .27241 L
.20709 .27542 L
.20844 .27749 L
.20973 .2788 L
.21109 .27944 L
.21237 .27936 L
.21373 .27854 L
.21502 .27709 L
.21619 .27522 L
.21756 .27241 L
.21905 .26865 L
.22176 .26023 L
.23337 .21314 L
.24342 .17744 L
.24914 .16271 L
Mistroke
.25449 .15216 L
.25974 .14446 L
.26453 .13927 L
.26718 .13698 L
.27007 .13488 L
.27278 .13325 L
.27533 .13203 L
.27673 .13149 L
.27824 .13101 L
.2795 .13068 L
.28088 .13041 L
.28165 .13029 L
.28238 .1302 L
.28314 .13013 L
.28396 .13008 L
.28472 .13006 L
.28544 .13005 L
.28679 .1301 L
.28807 .1302 L
.28944 .13039 L
.2906 .1306 L
.29188 .13091 L
.29326 .13132 L
.29474 .13187 L
.29742 .13318 L
.29994 .13481 L
.30263 .13699 L
.30748 .14214 L
.31324 .15071 L
.31848 .16149 L
.32395 .17646 L
.32988 .19719 L
.34064 .24466 L
.34543 .26615 L
.34808 .27651 L
.35059 .28474 L
.352 .28853 L
.35354 .29188 L
.35422 .29308 L
.35494 .29417 L
.35624 .29562 L
.35693 .29612 L
.35767 .29645 L
.35901 .2965 L
.36032 .29588 L
.36152 .29474 L
.36281 .29295 L
.36418 .29042 L
.36666 .28446 L
.37228 .26614 L
Mistroke
.38362 .2248 L
.39434 .19325 L
.40598 .16847 L
.41698 .15083 L
.42187 .14461 L
.42713 .1389 L
.43243 .13422 L
.43727 .13105 L
.4396 .12994 L
.44083 .12946 L
.44215 .12904 L
.44341 .12871 L
.44455 .12847 L
.4457 .12831 L
.44678 .12821 L
.44804 .12819 L
.44941 .12827 L
.45011 .12836 L
.45085 .12849 L
.4522 .12882 L
.45353 .1293 L
.4548 .12988 L
.45718 .13136 L
.45998 .13381 L
.46257 .13682 L
.46541 .14106 L
.46843 .14681 L
.47356 .16022 L
.47827 .17747 L
.48343 .20252 L
.48887 .23527 L
.49404 .26969 L
.49892 .29982 L
.50105 .31051 L
.50331 .31935 L
.50448 .32279 L
.50578 .32557 L
.50696 .32715 L
.50806 .3278 L
.50935 .32757 L
.51058 .32638 L
.51168 .32457 L
.51289 .32184 L
.51558 .31334 L
.51807 .30327 L
.52369 .27753 L
.52878 .25583 L
.53359 .23969 L
.53812 .22867 L
.54289 .22034 L
Mistroke
.54806 .21326 L
.56862 .17988 L
.5795 .158 L
.58549 .14739 L
.59116 .13894 L
.59654 .13274 L
.59958 .13006 L
.60239 .12808 L
.60476 .12677 L
.60611 .12617 L
.60736 .12573 L
.60867 .12538 L
.60936 .12524 L
.61008 .12513 L
.6113 .12505 L
.61263 .1251 L
.61398 .12531 L
.61526 .12566 L
.61641 .12611 L
.61765 .12674 L
.61901 .12762 L
.62044 .12876 L
.62301 .13144 L
.62539 .13474 L
.62761 .13869 L
.63004 .14418 L
.63266 .15168 L
.63534 .1614 L
.63819 .17432 L
.64332 .2052 L
.64883 .24993 L
.65492 .30789 L
.65747 .33085 L
.66016 .35128 L
.66157 .3597 L
.66231 .3634 L
.66311 .36672 L
.66384 .36919 L
.66451 .37091 L
.66581 .37282 L
.66712 .37279 L
.66833 .37105 L
.66966 .36734 L
.67033 .36481 L
.67107 .36154 L
.67364 .34689 L
.67604 .32982 L
.68125 .28961 L
.68401 .2702 L
.68694 .25267 L
Mistroke
.68976 .23941 L
.69232 .23044 L
.69355 .2271 L
.69489 .22415 L
.69615 .22197 L
.69731 .22043 L
.69843 .21934 L
.69964 .21855 L
.70078 .21814 L
.70182 .218 L
.70303 .21809 L
.70436 .21842 L
.70561 .2189 L
.70677 .21944 L
.70927 .22072 L
.71161 .22178 L
.71279 .22217 L
.71406 .22245 L
.71475 .22252 L
.71547 .22254 L
.71676 .22239 L
.71806 .22201 L
.71879 .22167 L
.71946 .22129 L
.7207 .22038 L
.72201 .21914 L
.72429 .21628 L
.72679 .21215 L
.73232 .19996 L
.73749 .18643 L
.74672 .16263 L
.7516 .15179 L
.75678 .14237 L
.76245 .13475 L
.76771 .12974 L
.77052 .12779 L
.7719 .12704 L
.77316 .12648 L
.77431 .12607 L
.77553 .12577 L
.77675 .12558 L
.77809 .12553 L
.7794 .12562 L
.78064 .12584 L
.78175 .12614 L
.78296 .1266 L
.78427 .12723 L
.78566 .12809 L
.78816 .13016 L
.79047 .13283 L
Mistroke
.79263 .13619 L
.795 .14107 L
.79755 .148 L
.80021 .1574 L
.80305 .17032 L
.80815 .20285 L
.81128 .2299 L
.81422 .26068 L
.81973 .32787 L
.82465 .38425 L
.82585 .39496 L
.82713 .40447 L
.82787 .40888 L
.82854 .4122 L
.82985 .41662 L
.83058 .41785 L
.83126 .4182 L
.832 .41771 L
.83278 .41621 L
.8341 .41149 L
.83485 .40763 L
.83556 .40329 L
.83809 .38288 L
.84081 .35483 L
.84567 .30092 L
.85085 .25299 L
.85383 .23335 L
.85654 .22051 L
.85785 .21588 L
.85926 .21192 L
.8606 .20911 L
.86184 .20728 L
.86311 .2061 L
.86448 .20557 L
.86578 .20574 L
.86696 .2064 L
.86834 .20773 L
.86985 .20978 L
.87259 .21473 L
.87846 .2275 L
.88134 .23319 L
.8826 .23533 L
.88399 .23735 L
.88521 .23881 L
.88652 .24001 L
.88791 .24084 L
.8892 .24116 L
.88992 .24115 L
.89071 .24097 L
.89146 .24064 L
Mistroke
.89215 .2402 L
.89345 .23899 L
.89483 .23719 L
.89725 .2328 L
.89951 .22739 L
.90466 .21172 L
.9154 .17633 L
.92125 .16003 L
.92669 .148 L
.93159 .14017 L
.93434 .13687 L
.93683 .13439 L
.93956 .13211 L
.941 .13109 L
.94253 .13015 L
.94386 .12946 L
.94533 .12885 L
.94666 .12845 L
.94791 .12822 L
.94911 .12812 L
.95042 .12816 L
.95166 .12832 L
.95281 .12859 L
.95394 .12894 L
.95497 .12935 L
.95728 .13053 L
.95977 .13229 L
.96247 .13496 L
.96501 .13854 L
.96734 .14306 L
.96938 .14822 L
.97124 .15405 L
.97324 .16171 L
.97541 .17183 L
.97927 .1955 L
.98293 .22627 L
.98724 .27517 L
.9918 .3396 L
1 .44169 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo01kooooo1_l0000_ooooo`Go0000F?ooool003gooooo2?l0000Yooooo`Ko
0000;?ooool7o`0000kooooo0_l0000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`03ooooo`;o0000;oooool6o`00027ooooo000looooo`;o0000
1oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool2o`0002[ooooo00?o0000ooooooooool0
1Oooool2o`0000cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07_ooool003_ooooo00?o0000ooooooooool02?oo
ool2o`0002?ooooo0_l00008ooooo`;o0000:?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`;o00001ooo
ool00ol0003oooooooooo`0Mooooo`00>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`00>Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`00=oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Kooooo`00=oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`00=oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool2o`0001Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo000foooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01[ooooo000fooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05_ooool02Ol0003ooooooooooooo
ooooV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`0Booooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000
ooooooooool03Oooool4o`00000:oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^koooooo`00
01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`000008oooo
ool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo00kooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg01Gooooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01;ooooo00GoV9RHob4Q8Oo^k^ko
0000odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Eooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Jooooo`0=oiRHV?lQ8B7ok^k^oooooom4
A4Coooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo
00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`Ko00000oooool00onHV9So0000onk^kP04ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003o
ooooooooo`02ooooo`06oa0@4?ooooooooooooooool@413o00005Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooo`000?l@41006oooool01OnHV9So8B4Qonk^k_oooooo000000;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool03oooool6o`00
00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`06ooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01?ooooo
00?o0000ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;o00007?ooool01?nHV9So8B4Qonk^k_l00002
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0@ooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo
00Go0000odA4A?oMgMgoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000
ooooooooool01Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Booooo`04o`000?ooooooMgMgofIVIP?ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`00
01gooooo00?oMgMgo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool03oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0@ooooo`05o`000?oMgMgoEEEEooooool000001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400Cooooo`03o`000?oooooooooo00Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooo0000oa0@400Gooooo`03o`000?oooooooooo00Cooooo
0_l0000Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
ooooool0003o410@01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00[ooooo00?o0000ooooooooool03oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0@oooo
o`;o000000?ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL05ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?l000006_ooool01Ol0003o^[Zj
oooooonHV9So000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00ol0003oooooooooo`0@ooooo`05o`000?ooooook^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Cooooo`03o`000?oooooooooo00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0@ooooo`05o`000?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00?o0000ooooooooool0
2_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_l000006_ooool01OnHV9So410@o`000?l0003o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00cooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0Booooo`04o`000?ooooooMgMgo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00<_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Hooooo`00<_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`00
<_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Hooooo`008Oooool2o`0000oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?oo
ool0023ooooo1?l0000>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo000Foooooooo0000@?l0000Coooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`09o`000?ooooooooooooooool0003o
ooooo`000?oooooo000000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000oooool2o`0000Oooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`0Aooooo`007oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo000O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool3o`0000Gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo000Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool03Oooool2o`0000;ooooo1_l0000Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05_ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo0_l0000Mooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`007_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooooooo0_l0000:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000006ooo
ool00ol0003oooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`05o`000?oooooo
ooooooooool000002_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo0ol0
000Looooo`03o`000?oooooooooo01Kooooo000Mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00Go0000
ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo000Mooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo023ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Q
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01Kooooo000Mooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool05Oooool001gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000002Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`007Ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01Gooooo000Mooooo`03o`000?oooooooooo00[ooooo0ol0
000Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05Oooool001gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool05Oooool001gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Gooooo000Mooooo`03o`000?oooooooooo03Oooooo00Go0000oooo
ooooooooooooo`00000Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Eooooo`007Oooool00ol0003oooooooooo`0hooooo`04o`000?oooooooooo
o`0002Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
000000Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Gooooo000Mooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool00000:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05Oooool001go
oooo00?o0000ooooooooool0>?ooool2o`0002_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Wooooo`;o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool05Oooool001cooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Oooooo0ol00005ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Eooooo`007?ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool2o`0000Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo000L
ooooo`03o`000?oooooooooo06Oooooo00Go0000ooooooooooooooooo`00000Yooooo`;o00001_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05Ooo
ool001cooooo00?o0000ooooooooool0Ioooool2o`000003ooooool0003ooooo02Wooooo0_l00005
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0E
ooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o0000:oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Eoooo
o`007?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`00
0?oooooooooo08_ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`000?oo
oooooooo08_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo
000Looooo`03o`000?oooooooooo08cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000?ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo000K
ooooo`03o`000?oooooooooo08kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0D
ooooo`006oooool00ol0003oooooooooo`2?ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool05?ooool001_ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`04ooooo`;o
00000oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool05?ooool001_ooooo00?o0000ooooooooool0S?ooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo0_l00002ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Dooooo`006oooool00ol0003oooooooooo`2<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool3o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Dooooo`006oooool00ol0003oooooooooo`2Gooooo`04o`000?oooooo0000o`0002ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Dooooo`006oooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Dooooo`006oooool00ol0003oooooooooo`2Gooooo`;o0000<?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01Cooooo000Kooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Cooooo000Koooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01Cooooo000Kooooo`03o`000?oooooooooo09Oooooo00?o0000oooooooo
ool0<?ooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000002kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo000Jooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo0000
02kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Cooooo000Jooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0<?ooool01Ol0003o
oooooooooooooooo000002kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo09Sooooo00?o0000oooooooo
ool0<?ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo033ooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool04oooool001[ooooo00?o0000oooooooo
ool0V?ooool2o`0003;ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool0
V?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00000`ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`006_ooool0
0ol0003oooooooooo`2Hooooo`03o`000?oooooooooo037ooooo0_l0000aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Cooooo`006_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo000J
ooooo`03o`000?oooooooooo09Sooooo0_l0001Uooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`00000`ooooo`03o`000?oooooo
oooo01?ooooo000Iooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0IOooool01Ol0
003ooooooooooooooooo0000037ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000oooo
ooooool0VOooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0003;ooooo00?o0000
ooooooooool04_ooool001Wooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1Uoooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000oooo
ooooool0T?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0IOooool01?l0
003oooooooooool0000booooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo
097ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`04o`000?oooooooooo
o`0003;ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool0S_ooool5o`00
00Kooooo00?o0000ooooooooool0IOooool00ol0003oooooo`00000cooooo`03o`000?oooooooooo
01;ooooo000Iooooo`03o`000?oooooooooo08kooooo00CoA4A4omgMgOoooooo00001oooool3o`00
06Gooooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0Booooo`006Oooool00ol0003o
ooooooooo`2>ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0I_ooool2o`00
03?ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool0Soooool00omgMgOo
c<c<o`000007ooooo`03o`000?oooooooooo06Kooooo0_l0000cooooo`03o`000?oooooooooo01;o
oooo000Iooooo`03o`000?oooooooooo08oooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo093ooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000I
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0A
ooooo`006Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo09cooooo00?o0000oooo
ooooool04Oooool001Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`2Looooo`03
o`000?oooooooooo017ooooo000Hooooo`03o`000?oooooooooo09[ooooo0_l0002Mooooo`03o`00
0?oooooooooo017ooooo000Fooooo`03o`000?oooooo000009cooooo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooo`00002Looooo`03o`000?oooooo
oooo0;3ooooo000Fooooo`03o`000?oooooo000009cooooo00?o0000ooooooooool0/?ooool001Ko
oooo00?o0000ooooool00000W?ooool00ol0003oooooooooo`2`ooooo`005_ooool00ol0003ooooo
o`00002Looooo`03o`000?oooooooooo0;3ooooo000Gooooo`03o`000?oooooooooo09_ooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co
0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[o
oooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY
0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/ooo
ool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<oooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c01looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OlQ8B7oV9RHoooooonHV9So8B4Q07cooooo
0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00onYZJWo410@ooooo`02
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05olc<c?l0003o0000
o`000?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o0000
7?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100O?ooool008Gooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28517 m
.00236 .29813 L
.00488 .31016 L
.00706 .31862 L
.00942 .32549 L
.01087 .32848 L
.0122 .33045 L
.01348 .33169 L
.01483 .33237 L
.01604 .33252 L
.01717 .33234 L
.01841 .33187 L
.01975 .33118 L
.02104 .33045 L
.02241 .32974 L
.0232 .32941 L
.02392 .3292 L
.02464 .32908 L
.02532 .32907 L
.02665 .32938 L
.02787 .3301 L
.02921 .33143 L
.02988 .33232 L
.03062 .33347 L
.0331 .33861 L
.03576 .34597 L
.04057 .36105 L
.042 .36506 L
.04352 .36859 L
.04482 .37081 L
.04556 .37168 L
.04626 .37221 L
.04702 .37244 L
.04781 .37227 L
.04849 .37178 L
.04924 .37087 L
.05004 .36942 L
.0509 .36735 L
.05245 .36224 L
.05391 .35588 L
.05548 .3474 L
.05835 .32848 L
.06371 .28603 L
.06855 .24733 L
.07376 .21174 L
.07674 .1951 L
.07947 .1823 L
.08224 .17151 L
.08481 .1633 L
.0875 .15635 L
Mistroke
.08993 .15131 L
.09264 .14688 L
.09551 .14327 L
.09803 .14088 L
.10075 .13896 L
.102 .13827 L
.10332 .13767 L
.10453 .13722 L
.10568 .13687 L
.10706 .13655 L
.10831 .13634 L
.10966 .13619 L
.11043 .13613 L
.11113 .1361 L
.11231 .13609 L
.1136 .13611 L
.11495 .13619 L
.11622 .13629 L
.11763 .13644 L
.11912 .13663 L
.12178 .13706 L
.12777 .13833 L
.13782 .14112 L
.14344 .14311 L
.14854 .14559 L
.15331 .14885 L
.156 .15126 L
.15848 .15396 L
.16303 .1605 L
.16784 .1703 L
.17853 .20574 L
.18867 .25328 L
.19308 .27198 L
.19531 .27925 L
.19658 .28249 L
.19777 .28487 L
.19906 .28665 L
.20025 .28753 L
.20155 .28763 L
.20292 .28676 L
.20409 .28522 L
.20519 .28315 L
.20639 .28021 L
.20768 .27634 L
.21319 .25324 L
.21839 .22652 L
.22814 .18117 L
.23361 .16284 L
.23867 .15069 L
.24131 .14595 L
Mistroke
.24421 .14184 L
.24725 .13864 L
.24862 .13751 L
.25009 .13651 L
.25151 .13572 L
.2528 .13515 L
.25409 .13471 L
.25531 .13441 L
.256 .13429 L
.25673 .13419 L
.25804 .1341 L
.25877 .1341 L
.25945 .13413 L
.2602 .13419 L
.261 .1343 L
.26233 .13455 L
.26379 .13492 L
.26642 .13587 L
.26899 .13709 L
.27137 .13843 L
.2808 .14539 L
.29082 .15429 L
.30091 .16288 L
.31152 .17109 L
.3159 .17489 L
.32058 .18003 L
.32327 .18385 L
.32571 .18808 L
.33048 .19901 L
.3355 .21513 L
.34094 .23836 L
.34564 .26199 L
.35081 .28763 L
.35348 .29857 L
.35495 .30341 L
.35635 .30703 L
.35711 .30855 L
.35793 .30985 L
.35868 .31067 L
.35938 .31112 L
.36075 .31113 L
.36152 .31061 L
.36221 .30982 L
.36357 .30741 L
.36481 .30422 L
.36618 .2997 L
.36762 .29389 L
.37271 .26699 L
.3827 .20679 L
.3882 .17981 L
Mistroke
.39339 .16042 L
.39823 .14734 L
.40096 .14176 L
.40348 .13761 L
.40578 .13455 L
.40794 .13224 L
.41018 .13035 L
.41266 .12882 L
.41397 .12823 L
.41468 .12796 L
.41536 .12775 L
.41668 .12745 L
.41787 .12728 L
.41856 .12723 L
.41929 .12722 L
.4206 .12729 L
.42133 .12738 L
.42201 .1275 L
.42275 .12767 L
.42355 .12788 L
.42489 .12834 L
.42633 .12896 L
.42897 .13042 L
.43154 .13226 L
.43391 .13433 L
.44334 .14591 L
.45336 .16316 L
.49298 .22149 L
.49567 .22702 L
.49854 .23454 L
.5037 .25295 L
.5091 .27827 L
.515 .308 L
.51761 .31909 L
.51898 .32384 L
.52043 .32781 L
.52171 .33026 L
.52243 .3312 L
.52311 .33175 L
.52429 .33197 L
.52557 .33107 L
.5268 .32911 L
.52815 .32575 L
.52942 .32146 L
.53059 .31657 L
.53518 .29087 L
.54524 .22152 L
.55053 .19049 L
.5561 .16541 L
.561 .14956 L
Mistroke
.56377 .14273 L
.56636 .13754 L
.57092 .13068 L
.57347 .12788 L
.57579 .12589 L
.57713 .12496 L
.57855 .12414 L
.57978 .12356 L
.58111 .12306 L
.58185 .12283 L
.58252 .12266 L
.58385 .12242 L
.58456 .12233 L
.58533 .12228 L
.58613 .12226 L
.58688 .12227 L
.58825 .12239 L
.58954 .1226 L
.5907 .12288 L
.59196 .12326 L
.59478 .12447 L
.59737 .12603 L
.6019 .12986 L
.60687 .13581 L
.61207 .14413 L
.61692 .15406 L
.65773 .25074 L
.66289 .25678 L
.6655 .26102 L
.66839 .26722 L
.67149 .27607 L
.67441 .28655 L
.67999 .31106 L
.68494 .33274 L
.68743 .34109 L
.68811 .34287 L
.68884 .3445 L
.69015 .34664 L
.69089 .34735 L
.69169 .34771 L
.69244 .34763 L
.69314 .3472 L
.69446 .34541 L
.69513 .34402 L
.69586 .34213 L
.69717 .33782 L
.69857 .33193 L
.70111 .31836 L
.71113 .2465 L
.71663 .2094 L
Mistroke
.72181 .18159 L
.72476 .16899 L
.72796 .15776 L
.73353 .14327 L
.73628 .13805 L
.73919 .13364 L
.74192 .13036 L
.7444 .12797 L
.74678 .12613 L
.74937 .12458 L
.75079 .12391 L
.7521 .12339 L
.75343 .12296 L
.75469 .12265 L
.75575 .12244 L
.7569 .12228 L
.75817 .12218 L
.75934 .12215 L
.76049 .12218 L
.76175 .12228 L
.76306 .12246 L
.76429 .12269 L
.76565 .12304 L
.76713 .12351 L
.76981 .12466 L
.77243 .12616 L
.77484 .12793 L
.78031 .13351 L
.78307 .13726 L
.78611 .14226 L
.79158 .15399 L
.79678 .16888 L
.80653 .20684 L
.81716 .25468 L
.82022 .26654 L
.8231 .27589 L
.82568 .28254 L
.82712 .28552 L
.82847 .28785 L
.83099 .29117 L
.83233 .29248 L
.83376 .29364 L
.83662 .29555 L
.83933 .29747 L
.84184 .29993 L
.84325 .30179 L
.84456 .30389 L
.84687 .30858 L
.84931 .31498 L
.85448 .33227 L
Mistroke
.85703 .34136 L
.8594 .34897 L
.86154 .35435 L
.86273 .35649 L
.86382 .35778 L
.86501 .3584 L
.8663 .35805 L
.86751 .3567 L
.86864 .35455 L
.86982 .35134 L
.87092 .34749 L
.87343 .33588 L
.87851 .3031 L
.88913 .22518 L
.89389 .19717 L
.8984 .17644 L
.90089 .16728 L
.90359 .15893 L
.90834 .14776 L
.91078 .14342 L
.91342 .13959 L
.91819 .13448 L
.92096 .13236 L
.92387 .13066 L
.92636 .12955 L
.92908 .12866 L
.93057 .12829 L
.93197 .12801 L
.93323 .12781 L
.9346 .12765 L
.93531 .12759 L
.93609 .12754 L
.93691 .12751 L
.93767 .1275 L
.93903 .12751 L
.9398 .12754 L
.9405 .12758 L
.94185 .1277 L
.94311 .12786 L
.94449 .12809 L
.94595 .12839 L
.94867 .12912 L
.95113 .13002 L
.95358 .13115 L
.95626 .13274 L
.95906 .13483 L
.96167 .13728 L
.96635 .14312 L
.96897 .14741 L
.97136 .15209 L
Mistroke
.97675 .16595 L
.9826 .18729 L
.98812 .21411 L
.99323 .24383 L
1 .28517 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo01Kooooo1_l0000`
ooooo`So0000G?ooool009[ooooo1?l0000Gooooo`03o`000?oooooooooo01Cooooo0_l00006oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0`oooo
o`Co00009Oooool009Sooooo0_l00003ooooo`;o00005_ooool2o`0001Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0;?ooool3o`0000?ooooo1?l0000Rooooo`00Ioooool3o`0002kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`07ooooo`;o00008Oooool003Oooooo1ol0000Wooooo`?o000000Co
ooooo`000?l0003o0000:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo
0_l0000Oooooo`00=_ooool2o`0000Kooooo0ol0000Sooooo`;o00001_ooool2o`0002Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo000d
ooooo`;o00002oooool4o`0001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0L
ooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Looooo`00<oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`00
<_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Jooooo`00<_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool2o`00017ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo000booooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Wooooo000booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01Wooooo000Eooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooo`000004o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`;o00005?ooool4o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^k_ooool03_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool5
o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Wooooo00?o0000ooooooooool03oooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool00ol0003ooooo
ooooo`06ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Cooooo00?o0000ooooooooool04_ooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo
00Go0000oiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Iooooo`06o`000?nHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Wooooo00?o0000ooooooooool03oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo01Gooooo00Co0000oooo
oooooooo00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo000000Go00001_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41002_ooool00ol0003oooooooooo`06ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03oooool01_l0003oooooooooool0003ooooooa0@40?ooooo00?o
410@ooooooooool05oooool01Ol0003ooooooiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4009ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool000005oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`0:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`0Gooooo`06o`000?oooooooooooiRHV?lQ
8B7ok^k^0oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04_ooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Fooooo`04odA4A?l0003oooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`00
4oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000004?ooool00ol0
003oooooooooo`09ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooo`;o00000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooooooo`;o
00000oooool00ol0003oooooooooo`0Gooooo`06o`000?oooooooooooooooomgMgOoIVIV0oooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04Oooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Fooooo`04omgM
gOl0003oooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOo
c<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0;oooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool02oooool00ol0003oooooooooo`0>ooooo`06o`000?ooooooooooooooool0003o
410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`03
o`000?oooooooooo013ooooo00Ko0000ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooo
oooo01Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo01Oooooo00?o0000olc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo00Sooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0?
ooooo`09o`000?ooooooooooooooool0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00gooooo00[o0000ooooooooooooooooo`000?mg
MgOoV9RHoooooonHV9SoMgMg4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRH
V?mgMgL06?ooool01ol0003oooooo`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00[ooooo00?o0000ooooooooool03_ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo01Oooooo00?ok^k^o`00
0?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0>ooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00_ooooo00?oEEEEofIVI_l000000ooo
ool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQCooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?oEEEEofIVI_l000001?ooool01Ol0003o
<S8bo`000?lb<S;ok^k^01Sooooo00Oo0000oooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooooooo00kooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000Kooooo`;o00001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo000^oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo000Foooooooo0000@?l0000C
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Aooooo`00;Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`00;Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00003Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05Oooool0
02gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Gooooo000]ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Dooooo`00;Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooool000003Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool05?ooool002cooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Cooooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08oooool3o`0000cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Cooooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08oooool2o`0000cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Cooooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Cooooo`00;?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool04oooool002cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09Oooool2o`0000_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool09Oooool2o`0000_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool2o`0000_ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000[ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool09Oooool2o`0000[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01;ooooo000[ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Booooo`00:oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04_ooool002_ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000[ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Booooo`00
:oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04_ooool002_ooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000002co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
017ooooo000Zooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000;Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool0
02[ooooo00?o0000ooooooooool09oooool2o`000003ooooool0003ooooo02cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Wooooo`;o000000?oooooo`000?ooool01_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool001Ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Xooooo`?o0000;Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo000Fooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0=oooool001Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Oooooo0_l0000;ooooo`03o`000?oooooooooo03Sooooo000Fooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0F_ooool01Ol0003ooooooooooooooooo000002[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool0
01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Kooooo`04o`000?oooooooooo
o`0001oooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo000Gooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Foooool01?l0003oooooooooool0000Oooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0hooooo`005oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo05_ooooo0ol0000Qooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0h
ooooo`005oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05cooooo0_l0000Roooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool001Sooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`21ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0>?ooool001Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool001Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1oooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`00
6Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07oooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000<?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0iooooo`006Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Wooooo000Jooooo`03o`000?oooooo000000?o00002?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo00Cooooo0_l0000booooo`05o`000?ooooooooooooooool00000<Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo000Jooooo`;o00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08[ooooo0_l0000iooooo`05o`000?oooooooooooooo
ool00000<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo000Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0hooooo`05
o`000?ooooooooooooooool00000<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03Wooooo000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`0iooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0iooooo`008?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08_o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooo`00000cooooo`05o`000?oooooooooooooo
ool00000??ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo03Wooooo0ol0000cooooo`05o`000?ooooooooooooooool00000??ooool0027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo06oo
oooo00Go0000ooooooooooooooooo`00000looooo`008_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08_ooooo00?o0000ooooooooool0Koooool01Ol0003ooooooooooooooooo0000
03cooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooo000003gooooo000Rooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03cooooo
000Sooooo`04o`000?ooooooooooo`0008kooooo0_l0002aooooo`008oooool01?l0003ooooooooo
ool0002>ooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooo000008kooooo00?o
0000ooooooooool0/?ooool002Cooooo0_l0002?ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:cooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/?ooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`2`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000
o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo
00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wo
oooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool0
08Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05
oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<
c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07cooooo0025ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo013ooooo00?o0000ooooooooool06_ooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@401looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05
ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
001looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o
<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Joooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool0
1_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Jooooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8b
o`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o
0000ooooooooool06oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24435 m
.00942 .21311 L
.0122 .20459 L
.01483 .19752 L
.01739 .19174 L
.01975 .18755 L
.02096 .18591 L
.02225 .18459 L
.02353 .18377 L
.02427 .18354 L
.02496 .18349 L
.02567 .18362 L
.02636 .18392 L
.02764 .18498 L
.02902 .18688 L
.0298 .18832 L
.03053 .18991 L
.03308 .19742 L
.03539 .20708 L
.03805 .22198 L
.04057 .24021 L
.0509 .35843 L
.05363 .3938 L
.05513 .41132 L
.05655 .42577 L
.05787 .43677 L
.05857 .44148 L
.05931 .44559 L
.06061 .45044 L
.06182 .45205 L
.06249 .45173 L
.06322 .45041 L
.06453 .44549 L
.06529 .44121 L
.06609 .43565 L
.06753 .42326 L
.07052 .38944 L
.07379 .34581 L
.07946 .27306 L
.08224 .24383 L
.08481 .22148 L
.08999 .18826 L
.09271 .17586 L
.0956 .16569 L
.09801 .15911 L
.10027 .15425 L
.10274 .15002 L
.1054 .14645 L
.10822 .14341 L
.1113 .14072 L
Mistroke
.11401 .13878 L
.11689 .13714 L
.11975 .13593 L
.12234 .13515 L
.1236 .13487 L
.12495 .13462 L
.12622 .13445 L
.1274 .13435 L
.12873 .13428 L
.12999 .13429 L
.13112 .13436 L
.13235 .13451 L
.13368 .13478 L
.13436 .13496 L
.1351 .13519 L
.13643 .13571 L
.13765 .13631 L
.14002 .13785 L
.14258 .14011 L
.14483 .14268 L
.1472 .14604 L
.14981 .15061 L
.15258 .15667 L
.15758 .17122 L
.16352 .19522 L
.16891 .22247 L
.17402 .25011 L
.17681 .26416 L
.17942 .27542 L
.18165 .2829 L
.18289 .28606 L
.18403 .28821 L
.18528 .28973 L
.18663 .29035 L
.18791 .28994 L
.1891 .28871 L
.19035 .28657 L
.19169 .28333 L
.19413 .27531 L
.19969 .24982 L
.20552 .21976 L
.21095 .19499 L
.2158 .17784 L
.21851 .17045 L
.22098 .16504 L
.22369 .16041 L
.22512 .15846 L
.22663 .15675 L
.22795 .15551 L
.22941 .15441 L
Mistroke
.23073 .15364 L
.23197 .15308 L
.23333 .15265 L
.23411 .15248 L
.23483 .15237 L
.23614 .15228 L
.23688 .15229 L
.23754 .15232 L
.2388 .15246 L
.24017 .15271 L
.24146 .15303 L
.24264 .15338 L
.24818 .15546 L
.25411 .15777 L
.25686 .15864 L
.25822 .15899 L
.25947 .15926 L
.2606 .15945 L
.2618 .1596 L
.26301 .15969 L
.26435 .15971 L
.26558 .15966 L
.26672 .15955 L
.26796 .15936 L
.26927 .15909 L
.27148 .15845 L
.27389 .15751 L
.27933 .15466 L
.28514 .15088 L
.29022 .14745 L
.293 .14575 L
.2956 .14439 L
.29699 .14378 L
.29826 .14332 L
.29968 .14293 L
.30046 .14277 L
.3012 .14266 L
.30248 .14257 L
.30367 .14262 L
.30497 .14282 L
.30636 .14324 L
.30715 .14358 L
.30788 .14395 L
.30952 .14507 L
.31096 .14639 L
.31248 .14815 L
.31513 .15224 L
.31803 .15847 L
.3208 .16639 L
.32332 .1755 L
Mistroke
.32898 .20325 L
.33423 .23776 L
.33919 .2746 L
.34403 .30693 L
.34536 .31388 L
.34678 .32004 L
.34813 .32442 L
.34936 .32708 L
.35073 .32846 L
.35201 .32819 L
.35274 .32737 L
.3534 .32621 L
.35417 .32438 L
.35489 .3222 L
.35742 .3114 L
.36015 .29514 L
.37016 .22237 L
.37505 .19273 L
.37951 .17237 L
.38198 .16377 L
.38432 .15727 L
.3868 .15198 L
.38949 .14787 L
.3908 .14642 L
.39224 .14519 L
.39297 .14471 L
.39375 .1443 L
.39449 .14399 L
.39517 .14378 L
.3964 .14357 L
.39774 .14356 L
.39841 .14364 L
.39914 .14379 L
.40044 .14421 L
.40116 .14452 L
.40192 .14492 L
.4033 .14578 L
.4064 .14838 L
.41202 .155 L
.42255 .17014 L
.42763 .17689 L
.43013 .17968 L
.43245 .1818 L
.43385 .18282 L
.43511 .18355 L
.43579 .18387 L
.43652 .18415 L
.43729 .18438 L
.43801 .18454 L
.4393 .18465 L
Mistroke
.44066 .18456 L
.44182 .18431 L
.4431 .18387 L
.44439 .18325 L
.44561 .1825 L
.4479 .18074 L
.45304 .17524 L
.46232 .16244 L
.46756 .15591 L
.47013 .15339 L
.47248 .15159 L
.47368 .15088 L
.47495 .15032 L
.47622 .14995 L
.4776 .14981 L
.47835 .14985 L
.47902 .14997 L
.4798 .15021 L
.48053 .15055 L
.48184 .15141 L
.48258 .15206 L
.48326 .15278 L
.48437 .1542 L
.48557 .1561 L
.48774 .16056 L
.49031 .16781 L
.49266 .17646 L
.49511 .18776 L
.49777 .20296 L
.50261 .23875 L
.50775 .28576 L
.51045 .31113 L
.51329 .33517 L
.51579 .35164 L
.51648 .35514 L
.51721 .35832 L
.51853 .36251 L
.51982 .36458 L
.52105 .36462 L
.52215 .36305 L
.52334 .35969 L
.5246 .35435 L
.52598 .34653 L
.52878 .3256 L
.53381 .27849 L
.53974 .22408 L
.54267 .20193 L
.54538 .18478 L
.55047 .16081 L
.55316 .15189 L
Mistroke
.55603 .14479 L
.55729 .14235 L
.55866 .14015 L
.55987 .13856 L
.56114 .1372 L
.56229 .13623 L
.56355 .13544 L
.5647 .13494 L
.56577 .13464 L
.56713 .13449 L
.5679 .13451 L
.56861 .13459 L
.56992 .13488 L
.5713 .1354 L
.57254 .13604 L
.5737 .13679 L
.57635 .13901 L
.5792 .14221 L
.58181 .14585 L
.58769 .15615 L
.5973 .17721 L
.60258 .18941 L
.60757 .19951 L
.6104 .20396 L
.612 .20592 L
.61347 .20735 L
.61471 .20825 L
.61607 .20892 L
.61676 .20914 L
.6175 .20927 L
.61883 .20925 L
.62017 .20892 L
.62093 .20859 L
.62164 .20819 L
.62293 .20724 L
.62431 .20593 L
.62693 .20262 L
.62931 .19884 L
.63916 .17922 L
.64455 .16949 L
.64717 .16569 L
.64956 .16295 L
.65091 .16175 L
.65219 .1609 L
.65354 .16031 L
.6543 .16015 L
.655 .16011 L
.65638 .16037 L
.65716 .16073 L
.65789 .16123 L
Mistroke
.65867 .16191 L
.65937 .1627 L
.66096 .16505 L
.66229 .16768 L
.66353 .1707 L
.66633 .1798 L
.6688 .19071 L
.67144 .20571 L
.67706 .25059 L
.68223 .30538 L
.68491 .3352 L
.68779 .36407 L
.68944 .37763 L
.69095 .38731 L
.69167 .39092 L
.69246 .394 L
.69321 .39607 L
.6939 .39722 L
.69512 .39745 L
.69627 .39555 L
.69753 .39115 L
.69889 .38386 L
.70024 .37428 L
.70166 .36202 L
.70419 .33598 L
.70989 .27073 L
.71507 .21897 L
.71754 .19928 L
.72022 .18159 L
.72254 .16908 L
.72508 .15794 L
.72779 .14872 L
.73065 .14146 L
.73193 .13893 L
.7333 .13664 L
.73459 .13486 L
.73578 .13349 L
.73708 .13228 L
.73825 .13139 L
.73956 .13063 L
.74028 .1303 L
.74095 .13005 L
.74216 .12972 L
.74348 .12953 L
.74463 .12951 L
.74585 .12962 L
.74695 .12985 L
.74813 .13022 L
.74924 .13069 L
.75025 .13122 L
Mistroke
.75272 .13292 L
.75506 .13504 L
.75989 .14093 L
.76521 .14978 L
.77077 .16193 L
.77599 .17592 L
.78523 .20392 L
.79012 .21757 L
.7928 .22377 L
.79534 .22837 L
.79669 .23024 L
.79739 .23105 L
.79815 .23177 L
.79947 .2327 L
.80069 .23315 L
.80192 .23321 L
.80307 .23291 L
.80432 .2322 L
.80568 .231 L
.80707 .22931 L
.80859 .227 L
.81136 .2217 L
.81655 .20925 L
.82137 .1969 L
.82657 .18512 L
.82896 .18078 L
.83026 .17879 L
.83148 .17721 L
.83261 .17601 L
.83363 .17515 L
.83477 .17449 L
.83599 .17415 L
.83666 .17414 L
.83738 .17427 L
.83867 .17491 L
.84005 .1762 L
.84084 .17724 L
.84158 .17841 L
.84413 .18415 L
.84556 .1886 L
.84686 .19352 L
.84928 .20491 L
.85191 .22119 L
.85671 .26227 L
.86266 .33086 L
.86558 .3661 L
.86827 .3945 L
.86953 .40541 L
.87072 .41373 L
.87195 .42018 L
Mistroke
.8733 .4244 L
.87468 .42544 L
.87593 .42347 L
.87662 .42121 L
.87738 .41783 L
.87875 .40934 L
.88002 .399 L
.88122 .38745 L
.88395 .35622 L
.88948 .2861 L
.89431 .23304 L
.8994 .19228 L
.90204 .17667 L
.90493 .16315 L
.90756 .15361 L
.91 .14676 L
.91289 .14077 L
.91552 .13686 L
.91856 .13363 L
.92142 .13145 L
.92263 .13072 L
.92393 .13007 L
.92506 .12962 L
.92628 .12924 L
.92702 .12908 L
.92771 .12896 L
.92907 .12886 L
.93031 .12891 L
.93163 .12911 L
.93236 .12927 L
.93303 .12946 L
.93455 .13001 L
.9373 .13134 L
.9398 .1329 L
.94243 .13493 L
.94474 .13713 L
.94722 .14005 L
.95167 .14712 L
.95698 .15874 L
.96181 .17218 L
.97069 .20415 L
.97555 .22389 L
.98011 .24059 L
.98268 .24817 L
.98503 .25355 L
.9863 .25575 L
.98764 .25749 L
.98898 .25861 L
.98974 .25897 L
.99045 .25912 L
Mistroke
.9917 .25893 L
.99287 .25825 L
.99393 .25721 L
.99507 .25565 L
.99632 .25345 L
.99764 .25061 L
1 .24435 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000B_ooool4o`0003Kooooo1Ol0000Xooooo`00
]Oooool00ol0003oooooooooo`18ooooo`;o00000oooool00ol0003oooooooooo`0booooo`;o0000
1?ooool2o`0002Kooooo000kooooo`So0000L_ooool00ol0003oooooooooo`0@ooooo`Go0000<_oo
ool2o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02?ooooo000jooooo`03o`000?oooooooooo00Gooooo0_l0001aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02;ooooo000hooooo`;o00002_ooool00ol0003oooooooooo`0^ooooo`?o00007?ooool2o`00
01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool08_ooool003Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0[ooooo`;o00000oooool2o`0001Sooooo1Ol0000Nooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027o
oooo000gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool2o`0000Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
0_l00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo023ooooo000fooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool06?ooool4o`0000cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool5o`0000Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08?ooool003Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0F
ooooo`;o00000oooool4o`0000Oooooo0_l0000:ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool2o`0000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01oooooo000eooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05?ooool2o`0000Sooooo0_l00002ooooo`?o00003Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool003Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo0ol0000?ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04?ooool3o`0001Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07oooool001Go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Dooooo`03o`000?oo
oooooooo00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00005?ooool00ol0003oooooooooo`03ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?o0000ooooooooool03?ooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`Co0000
00[o410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_oooooo00000oooool00ol0003ooooooooo
o`0Booooo`Go00000oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000006Oooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Dooooo`03o`000?oooooooooo00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`06ogMgMonHV9SooooooiRHV?mgMgOo00005?ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00003oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1omgMgOoV9RHoooooonHV9SoMgMgooooool000001?ooool00ol0003oooooooooo`0@ooooo`06o`00
0?nHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000
ooooooooool05_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooo`00000Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool0
0ol0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00003_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l@413ooooo
oooooooooooo410@o`0000Gooooo00?o0000ooooooooool04?ooool01Ol0003ooooooiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo01[ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`03ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Coooo
o`03o`000?oooooooooo00Oooooo00?oZJVYoa0@4?ooool00_ooool01ol0003ooooooooooooooooo
0000ooooool000004_ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00005oooo
o`03o`000?oooooooooo013ooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`0@ooooo`?o00001_ooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000Cooooo`03o`000?oooooooooo00Kooooo00?o410@o`000?nj^[X00oooool01ol0003ooooooooo
oooooooo0000ooooool000004Oooool00ol0003oooooooooo`08ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?ooool2
o`0000cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool03oooool01_l0003oooooooooooooooooMgMgofIVIP?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000ooooo`04oooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooo
oooooooo410@01?ooooo00?o0000ooooooooool01oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03?ooool01?l0003oooooo`000?l0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooo`000?l@41001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000004?ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9So0000o`000?mgMgL04oooool00ol0003oooooooooo`04ooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`Ko00003_ooool00ol0003oooooo`00000=ooooo`03o`00
0?oooooooooo00oooooo00Go0000ooooooooooooooooo`000004ooooo`05ogMgMonHV9Soooooo`00
0?mgMgL01oooool00ol0003oooooooooo`0>ooooo`07o`000?oooooo0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0=ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMg
o`000?ooool00oooool00oo^k^ko0000o`000002o`0001;ooooo00?o0000ooooooooool01Oooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00_ooooo00CoEEEEofIV
I_l0003o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000@ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03oooool01Ol0003ooooooeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo00gooooo00Oo0000oooooonH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool00_ooool02?l0003ooooooooooonYZJWo410@o`000?l@
413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`03ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`007?ooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool08oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo000K
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`006oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool0
01[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09?ooool2o`0000cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool001[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool09?ooool2o`0000cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool001Kooooo
ool00010o`0001?ooooo000Fooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`Go00001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool04Oooool001Kooooo00Co0000oooo
oooooooo00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oo
oooooooo017ooooo000Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo000Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Wooooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Wooooo000Hooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Wooooo
000Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooo
oooooooo000000gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Wooooo000Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05ooo
ool2o`000003ooooool0003o000000gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Sooooo000Gooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo0_l0000;
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`?o00003_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06?ooool001Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool2o`0000_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo000Gooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Oooooo0_l0000:ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Gooooo`005_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`;o0000
2_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
5oooool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool09oooool2o`0000[ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Ooo
ool002?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Oooooo0_l0000:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Sooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o00002_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000D
ooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0:?ooool2o`0000[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooo000001Gooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Xooooo`;o00002_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01_ooooo0ol0000Eooooo`009?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool2o`0000[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0dooooo`009?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Cooooo000Tooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0dooooo`009?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Mooooo`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Cooooo000Tooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0=?ooool002Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Noooo
o`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Y
ooooo`?o00002?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo000Toooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooo`00000_oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Nooooo`?o0000;oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Cooooo000Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo000Tooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Cooooo000Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo000Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01oooooo1Ol00006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0dooooo`009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05;ooooo00Go0000ooooooooooooooooo`00000Rooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
=Oooool002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Booooo`05o`000?oo
ooooooooooooool000008oooool00onHV9So8B4Qonk^kP07ooooo`Co00001_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Gooooo000Uooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Doooool01?l0003oooooooooool0000Tooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Go
oooo000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Doooool01?l0003ooooo
ooooool0000Uooooo`03ogMgMomVIVKooooo00Gooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo000Uooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Doooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Gooooo000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Doooool01?l0
003oooooooooool0000Rooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool002Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Dooooo`;o00008oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=Oooool002Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Dooooo`;o0000;_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0eooooo`009Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=Oooool002Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`25ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0=Oooool002Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`25ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Gooooo000Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0QOoo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0fooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=_ooool002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`25ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`009_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo000Vooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0003?ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0=_ooool002Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<oooool01Ol0003o
oooooooooooooooo000003?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0foooo
o`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`00000dooooo`05o`000?ooooooooooooooool00000<oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo000Vooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0QOooool2o`0000Cooooo0_l0000dooooo`05o`000?oooooooooooooo
ool00000<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo000Vooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`03ooooo`;o
0000=?ooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0fooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Go
oooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0fooooo`009_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo0000
03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`009_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0>Oooool01Ol0003o
oooooooooooooooo000003?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0goooo
o`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool0>Oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0gooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool0>Oooool01?l0003oooooooooool0000eooooo`05o`000?oooooooooo
ooooool00000>Oooool002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooool00000=Oooool01Ol0003ooooooooooooooooo
000003Wooooo000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Q_ooool2o`00
03_ooooo00?o0000ooooool00000=Oooool01Ol0003ooooooooooooooooo000003Wooooo000Woooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooo000003Gooooo00Go0000ooooooooooooooooo`00000iooooo`009oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0>_ooool00ol0
003oooooo`00000eooooo`05o`000?ooooooooooooooool00000>Oooool002Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo03[ooooo0_l0000foooo
o`05o`000?ooooooooooooooool00000>Oooool002Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo07;ooooo00Go0000ooooooooooooooooo`00000i
ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07gooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo07?ooooo00Co0000oooooooooooo0000>Oooool0
02Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Loooool00ol0003oooooo`00000jooooo`009oooool01Ol0003o
oooooooooooooooo000007kooooo1Ol00006ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ool00000>_ooool002Oooooo00Go0000ooooooooooooooooo`00001nooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol0001cooooo`03o`000?oooooo000003[ooooo000Wooooo`05o`000?oooooooooo
ooooool00000O_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooool00000>_ooool002Oooooo00Go0000ooooooooooooooooo`00001oooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0Loooool00ol0003oooooo`00000jooooo`00:?ooool0
1?l0003oooooooooool0001oooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Looo
ool00ol0003oooooo`00000jooooo`00:?ooool01?l0003oooooooooool00020ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0M?ooool2o`0003[ooooo000Xooooo`04o`000?oooooo
ooooo`0008Wooooo00?o0000ooooooooool0/?ooool002Sooooo00Co0000oooooooooooo0000ROoo
ool00ol0003oooooooooo`2`ooooo`00:?ooool01?l0003oooooooooool00029ooooo`03o`000?oo
oooooooo0;3ooooo000Xooooo`04o`000?ooooooooooo`0008Wooooo0_l0002aooooo`00:?ooool0
0ol0003oooooo`00002:ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`000?oooooo0000
08[ooooo00?o0000ooooooooool0/?ooool002Wooooo0_l0002:ooooo`03o`000?oooooooooo0;3o
oooo000Yooooo`;o0000R_ooool00ol0003oooooooooo`2`ooooo`00:Oooool2o`0008[ooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@
4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00
Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj
^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o
0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`00
0004oa0@4?ooooooooooooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00003?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0O?ooool008Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@
40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`Go00001?ooool00onH
V9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?oV9RHob4Q8Oo^k^h0
O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool0
1?oMgMgoEEEEooooool00007ooooo`03ogMgMomVIVKooooo07_ooooo0025ooooo`06o`000?n7QhOo
ZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol@413o0000o`000003o`0001[ooooo00?oMgMgolc<c?l000002?ooool00ol0003o
ooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool0
0oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool008Cooooo00?o410@
o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`03ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19084 m
.00488 .17932 L
.00942 .17053 L
.01483 .16209 L
.01975 .15573 L
.02223 .15304 L
.02492 .15065 L
.02746 .14893 L
.02981 .1478 L
.03109 .14735 L
.03229 .14702 L
.03361 .14677 L
.03435 .14668 L
.03503 .14663 L
.03639 .14664 L
.03716 .14673 L
.03787 .14686 L
.03917 .14728 L
.0399 .14762 L
.04057 .14801 L
.04189 .14905 L
.04334 .15064 L
.04485 .1529 L
.04627 .15563 L
.0488 .16224 L
.05151 .17212 L
.05469 .18817 L
.0577 .209 L
.06041 .23358 L
.06335 .2676 L
.06826 .33965 L
.07355 .42095 L
.07502 .43937 L
.07658 .45491 L
.07791 .46441 L
.07866 .46807 L
.07936 .47031 L
.08074 .47129 L
.08199 .46821 L
.08269 .46491 L
.08344 .46011 L
.08481 .44834 L
.08731 .41828 L
.09006 .37677 L
.09561 .2888 L
.09809 .2551 L
.10076 .22499 L
.10326 .2024 L
.10557 .18572 L
.1084 .16996 L
Mistroke
.11002 .16286 L
.11148 .15749 L
.1142 .14993 L
.1157 .14699 L
.1171 .14493 L
.11838 .14359 L
.11974 .14268 L
.12089 .14227 L
.12216 .14216 L
.12353 .14239 L
.12429 .14266 L
.12499 .14298 L
.12635 .14381 L
.12763 .14483 L
.13013 .14749 L
.13246 .15083 L
.13503 .15557 L
.13779 .16201 L
.14342 .17909 L
.14858 .19831 L
.15794 .23785 L
.16041 .24782 L
.16308 .25737 L
.16561 .26464 L
.16681 .26738 L
.16793 .26947 L
.16918 .27127 L
.17056 .27257 L
.1719 .27316 L
.17265 .2732 L
.17334 .27307 L
.17455 .27244 L
.17586 .2712 L
.1771 .26955 L
.17825 .26762 L
.1829 .25664 L
.18784 .24145 L
.1983 .21059 L
.20419 .1982 L
.20959 .1896 L
.21434 .18373 L
.21953 .17852 L
.23001 .16826 L
.2492 .1467 L
.25977 .1358 L
.26497 .13152 L
.26976 .12824 L
.27244 .12678 L
.27529 .1256 L
.27676 .12515 L
Mistroke
.27814 .12483 L
.27893 .12469 L
.27965 .12458 L
.28049 .12449 L
.28128 .12444 L
.28254 .12442 L
.28388 .12449 L
.28514 .12465 L
.28629 .12487 L
.28764 .12525 L
.2891 .1258 L
.29048 .12648 L
.29175 .12725 L
.29433 .12932 L
.29669 .13186 L
.29941 .13566 L
.30198 .14023 L
.30656 .15109 L
.31153 .16786 L
.317 .19344 L
.32281 .22838 L
.32825 .26448 L
.33063 .27939 L
.33323 .29369 L
.33444 .2993 L
.33572 .30441 L
.33683 .30804 L
.33803 .31106 L
.33939 .31327 L
.34068 .31414 L
.34193 .31385 L
.34308 .3126 L
.34435 .31018 L
.34554 .307 L
.34824 .2969 L
.35369 .26881 L
.35814 .24426 L
.36288 .2215 L
.36561 .21092 L
.36808 .20311 L
.37056 .19695 L
.37289 .19263 L
.37423 .19075 L
.37563 .1892 L
.37684 .1882 L
.37815 .1874 L
.3789 .18708 L
.37957 .18687 L
.38035 .18669 L
.38109 .1866 L
Mistroke
.3824 .1866 L
.38315 .18667 L
.38383 .18678 L
.38507 .18706 L
.38623 .18741 L
.38887 .1884 L
.39161 .18951 L
.39421 .19047 L
.39534 .19081 L
.39655 .19109 L
.39788 .19128 L
.39911 .19135 L
.40032 .19128 L
.40146 .19109 L
.40248 .19081 L
.40359 .19039 L
.40481 .18978 L
.40614 .18892 L
.40884 .18665 L
.41368 .18095 L
.42507 .16251 L
.43587 .14476 L
.44057 .13847 L
.44556 .13296 L
.44817 .13059 L
.45104 .12841 L
.45366 .12685 L
.45493 .12624 L
.45611 .12576 L
.45736 .12535 L
.45849 .12506 L
.45976 .12483 L
.4611 .12471 L
.4624 .1247 L
.46313 .12475 L
.46381 .12483 L
.46505 .12506 L
.46636 .12545 L
.46748 .12589 L
.46867 .1265 L
.47084 .12797 L
.47341 .13044 L
.47576 .13352 L
.47846 .13818 L
.48096 .1438 L
.48371 .15167 L
.48663 .16234 L
.49205 .1897 L
.49695 .22415 L
.5068 .31071 L
Mistroke
.50919 .32931 L
.51051 .33797 L
.51176 .34487 L
.51246 .34814 L
.51323 .35114 L
.51457 .35491 L
.51593 .35673 L
.51719 .35655 L
.51855 .35437 L
.51982 .35054 L
.52055 .34761 L
.52122 .3445 L
.52272 .33608 L
.52859 .29114 L
.53366 .24947 L
.53644 .2295 L
.53906 .2135 L
.54166 .20053 L
.54447 .1896 L
.54571 .18575 L
.54702 .18231 L
.54938 .17765 L
.55052 .17605 L
.55174 .17478 L
.55289 .17397 L
.55395 .17355 L
.55518 .17341 L
.55652 .17365 L
.55779 .17423 L
.55896 .17502 L
.56021 .1761 L
.56155 .17753 L
.56397 .18065 L
.5695 .18963 L
.57531 .19982 L
.57814 .20417 L
.57937 .20579 L
.58071 .20733 L
.58201 .20856 L
.5832 .20945 L
.58434 .21008 L
.58556 .2105 L
.58683 .21066 L
.58802 .21054 L
.58933 .21012 L
.59007 .20975 L
.59074 .20933 L
.59213 .20822 L
.59343 .20689 L
.59637 .20292 L
Mistroke
.60172 .19281 L
.61312 .16638 L
.61872 .1546 L
.62386 .14538 L
.6289 .13819 L
.63422 .13268 L
.63698 .13061 L
.63956 .12915 L
.64104 .12851 L
.64238 .12807 L
.64313 .12788 L
.64394 .12773 L
.64471 .12764 L
.64542 .1276 L
.64653 .12762 L
.64774 .12777 L
.64888 .12804 L
.64992 .12841 L
.65108 .12895 L
.65234 .12972 L
.65368 .13075 L
.65489 .13189 L
.65741 .13497 L
.66011 .13954 L
.6626 .14523 L
.66496 .15216 L
.66747 .16156 L
.66982 .17253 L
.67261 .18875 L
.67517 .20694 L
.68038 .25456 L
.68598 .31682 L
.68828 .34208 L
.69073 .36575 L
.69214 .37695 L
.69342 .38512 L
.69471 .39117 L
.69592 .3947 L
.69707 .39602 L
.69828 .39522 L
.69932 .39277 L
.70045 .38829 L
.70168 .3815 L
.70299 .3722 L
.70535 .35122 L
.71055 .29559 L
.71607 .24055 L
.71894 .21769 L
.72212 .19768 L
.725 .18384 L
Mistroke
.7277 .17426 L
.72901 .17073 L
.73043 .16761 L
.73177 .16533 L
.73302 .16375 L
.73425 .16267 L
.73537 .16206 L
.73667 .16177 L
.73789 .16184 L
.73922 .16229 L
.73989 .16264 L
.74063 .16311 L
.74315 .16543 L
.74457 .16716 L
.74609 .16934 L
.74884 .17411 L
.75951 .20004 L
.76514 .21405 L
.76823 .22053 L
.77113 .22544 L
.77235 .2271 L
.77363 .22853 L
.77431 .22914 L
.77504 .2297 L
.77634 .23038 L
.77709 .23058 L
.77778 .23065 L
.77857 .23058 L
.77932 .23036 L
.78065 .22963 L
.7814 .22902 L
.78209 .22834 L
.78444 .22522 L
.78702 .22056 L
.79225 .20848 L
.80359 .17798 L
.80918 .16429 L
.81436 .1542 L
.81943 .14643 L
.82403 .14073 L
.82666 .13816 L
.82914 .13634 L
.8305 .13561 L
.83175 .1351 L
.83313 .13473 L
.83382 .1346 L
.83458 .13452 L
.83589 .13448 L
.83663 .13452 L
.83731 .1346 L
Mistroke
.83857 .13485 L
.8399 .13526 L
.84109 .13579 L
.84221 .13644 L
.84344 .13737 L
.84475 .13865 L
.84608 .1403 L
.84753 .14258 L
.84894 .14535 L
.85044 .14898 L
.85314 .15744 L
.85566 .16782 L
.8582 .18121 L
.86096 .19956 L
.86596 .24542 L
.87532 .36724 L
.8778 .39704 L
.87917 .41059 L
.88046 .42094 L
.88166 .42803 L
.88298 .43274 L
.88417 .43416 L
.88527 .43299 L
.88596 .43106 L
.8867 .42798 L
.88805 .41989 L
.88937 .40919 L
.89057 .39724 L
.89621 .32569 L
.90178 .25537 L
.90697 .20736 L
.90958 .19017 L
.91238 .17616 L
.91398 .16992 L
.91549 .16504 L
.91685 .16141 L
.91831 .15827 L
.91962 .15608 L
.92081 .15456 L
.92201 .15344 L
.92315 .15275 L
.92448 .15236 L
.92571 .15235 L
.92705 .15271 L
.92781 .15306 L
.92849 .15347 L
.92988 .15454 L
.93116 .15579 L
.93405 .15947 L
.93659 .16364 L
Mistroke
.93928 .16896 L
.94851 .19374 L
.95864 .22568 L
.96121 .23283 L
.964 .23955 L
.96528 .24216 L
.96664 .24457 L
.96781 .2463 L
.96908 .24779 L
.9703 .24883 L
.97141 .24944 L
.97248 .24969 L
.97361 .24961 L
.97484 .24912 L
.97599 .2483 L
.97725 .24699 L
.9786 .24517 L
.98137 .24023 L
.98437 .23344 L
.98981 .21896 L
1 .19084 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo001^ooooo`?o0000=oooool2o`0000_ooooo00?o0000
ooooooooool0/?ooool006cooooo0ol00002ooooo`?o0000<_ooool3o`000004ooooool0003o0000
o`0000Sooooo00?o0000ooooooooool0:_ooool3o`0008?ooooo001[ooooo`;o00001_ooool00ol0
003oooooooooo`0^ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`;o0000:Oooool3o`00
0004ooooool0003o0000o`00087ooooo001Yooooo`;o00002Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool006Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=?ooool5o`0004Gooooo001Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`12ooooo`00>oooool3o`0002Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo000Pooooo`?o00006?ooool0
1?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`11ooooo`007_ooool3o`000003ooooool0003o000001Kooooo0_l00003
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo047ooooo000Mooooo`;o00001?ooool2o`0001Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Eooooo`;o0000:_ooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`;o00009?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`;o
000000?oooooo`000?l00000:Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool01Ol0003ooooo
oooooooooooo000002Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
02Wooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool2o`0001Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool09_ooool001Gooooo0_l000002Ol@413oooooooooool0003ok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo017ooooo00Ko0000oiRHV?l@413o0000oc8b<_o<c<`3ooooo`05
o`000?lb<S;o0000oc8b<_o^k^h06Oooool00ol0003oooooo`000004o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo013ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooooooo
ool000008Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h7ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?l0003o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`;o000000Wo410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00[o0000oooooooooooo
0000oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool00ol0003oooooooooo`0Aooooo`06o`000?l@
413o^[ZjoooooomgMgOo<S8b0oooool01Ol0003oV9RHoooooonHV9SoMgMg01Sooooo00So0000oooo
ooooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04?oo
ool03OnHV9So0000onk^k_ooooooA4A4ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`0;ooooo`05oa0@4?l0003oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;o
oooo1Ol000001?oooooo0000ooooool@4103ooooo`03oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool7o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03oa0@4?oooooo
oooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400:ooooo`03o`000?oooooooooo00Kooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooo
ooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008oooo
o`03o`000?oooooooooo013ooooo00?o0000ob4Q8Oo^k^h00_ooool00ol0003ooooooa0@4003oooo
o`03oa0@4?oooooooooo00_ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00003
ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00Co
A4A4omgMgOoooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03ojVYZOl@413ooooo00;ooooo
0_l00002ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
01?ooooo00Go0000ooooooooooooooooo`00000?ooooo`Co00003oooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo00Go0000oooooonHV9So8B4Q
onk^kP02ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`004oooool01_oMgMgoEEEEooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00oooooo00Oo0000oooooooo
oooooooooa0@4?l0003o^[Zj00?ooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00003oooool01?l0003o
ooooooooool0000?ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool03oooool01Ol0003ooooooooooomgMgOoIVIV00;ooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03_ooool2o`000005okZj^_ooooooooooooooool00000
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
o`000?oooooooooooa0@400Dooooo`;o00002Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00_l0000>ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooo`000004oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
3_ooool00ol0003o^[Zjob4Q8@03ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo00gooooo00So0000oooooooooooo410@oiRH
V?oooooo^[Zjo`0000?ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo
00Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00003_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool03_ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00Go0000oiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo00Go
410@oiRHV?l0003o^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o000000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP07ooooo`03o`000?oooooooooo00gooooo00So0000ooooooooooooZJVYoa0@4?l0
003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo00Ko
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
0ol0003oooooooooo`0>ooooo`03oeEEEOmVIVKo000000Co000000Ook^k^oc8b<_l0003o<S8bonk^
k_oooooo000001Wooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Wooooo00Co0000oeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Wooooo00?o0000ooooooooool03_ooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Go
0000oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00gooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`;o00000_ooool4o`000003ooooool0003o000001[ooooo00Co0000oooo
oooooooo00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`005_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05oooo
o`?o00006oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04Oooool002Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo017ooooo000Wooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Booooo`00:?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooo`00000<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000002ooooo`;o000000?oooooo`00
0?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo0_l00005
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?o00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`00:?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo
000Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Xooooo`;o00002oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05?ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`00:Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool2o`0000[ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo0_l00002oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool002Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`?o
00006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Eooooo`00:Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool3o`0000Wooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5_ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02Wooooo0_l0000:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo000Yooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`;o00002_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Oooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Aooooo`;o00000_ooool00ol0003oooooooooo`0Hooooo`00:Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool3o`0001_ooooo
000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0`ooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0<?ooool002[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02_ooooo0_l00009ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0<?ooool002[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo033ooooo000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0`ooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo033ooooo000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04ooo
ool4o`0002oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`;o00002?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo000Zooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05Oooool2o`00037ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0/ooooo`;o00002?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo037ooooo000Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo0_l00008ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0<Oooool002[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool2o`0000So
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0]ooooo`;o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
000Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02gooooo0_l00007ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0<Oooool002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]oooo
o`;o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo000Zooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02gooooo0_l00007ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0<Oooool002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooo`000006ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool002[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`19ooooo`05o`000?ooooooooooooooool000009Oooool5o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
000[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool01?l0003ooooooooo
ool0000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool002_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooo`0002Kooooo00?oV9RHob4Q8Oo^
k^h01oooool3o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`00
:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo0ol0000Xooooo`03oiRH
V?lQ8B7ok^k^00Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03;ooooo000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?oo
ool2o`0002Wooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<_ooool002_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo000[ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0M?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo000[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03;ooooo000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Ooooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_oo
ool002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`00:oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo0_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool002_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1oooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0booooo`00:oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo07oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03;ooooo000[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Ooooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0booooo`00:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07oooooo00Oo0000ooooooooooooooooo`000?oooooo000003Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<ooo
ool002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`07o`000?oooooo
ooooooooool0003oooooo`00000eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo000[ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Ooooool01ol0003ooooooooooooooooo0000ooooool0
0000=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0cooooo`00:oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool00_ooool2o`0003Kooooo00Go0000oooooooooooo
ooooo`00000eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool002_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo03[ooooo
00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<oooool002cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`20ooooo`;o0000
>oooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo083ooooo00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000003Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0>_ooool01Ol0003ooooo
oooooooooooo000003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`00
;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
>_ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0>_ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0<oooool002cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo0000=_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Cooooo000/ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0003Oo
oooo00Go0000ooooooooooooooooo`00000fooooo`00;?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo083ooooo0_l0000kooooo`04o`000?ooooooooooo`0003Oooooo00Go0000oooo
ooooooooooooo`00000fooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00000gooooo`05o`000?oooooooooo
ooooool00000=_ooool002cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo03_ooooo0_l0000hooooo`05o`000?ooooooooooooooool00000=_ooool0
02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo000003Kooooo000/oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`1eoooo
o`05o`000?ooooooooooooooool00000=_ooool002gooooo00Go0000ooooooooooooooooo`00001j
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1eooooo`05o`000?oooooo
ooooooooool00000=_ooool002gooooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0M_ooool01?l0003oooooooooool0000fooooo`00;Ooo
ool01Ol0003ooooooooooooooooo000007Sooooo1Ol00006ooooo`03o`000?oooooooooo07Kooooo
00Co0000oooooooooooo0000=_ooool002gooooo00Go0000ooooooooooooooooo`00001hooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0001fooooo`04o`000?ooooooooooo`0003Kooooo000]oooo
o`05o`000?ooooooooooooooool00000N?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooool00000=oooool002gooooo00Go0000ooooooooooooooooo`00
001iooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0M_ooool00ol0003oooooo`00
000gooooo`00;Oooool01Ol0003ooooooooooooooooo000007Wooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooo000003Oooooo000]ooooo`05o`000?oooooo
ooooooooool00000N_ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooool00000=oooool002gooooo00Go0000ooooooooooooooooo`000023ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooool00000=oooool002gooooo00Go0000ooooooooooooooooo`00
0023ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooool00000=oooool002kooooo00Co0000
oooooooooooo0000Poooool00ol0003oooooooooo`1gooooo`;o0000=oooool002kooooo00Co0000
oooooooooooo0000Poooool2o`000;7ooooo000^ooooo`04o`000?ooooooooooo`0008?ooooo00?o
0000ooooooooool0/?ooool002kooooo00Co0000oooooooooooo0000Poooool00ol0003ooooooooo
o`2`ooooo`00;_ooool01?l0003oooooooooool00023ooooo`03o`000?oooooooooo0;3ooooo000^
ooooo`04o`000?ooooooooooo`0008?ooooo00?o0000ooooooooool0/?ooool002kooooo00Co0000
oooooooooooo0000Poooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooo`000024
ooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`000?oooooo000008Cooooo00?o0000oooo
ooooool0/?ooool002kooooo00?o0000ooooool00000Q?ooool2o`000;7ooooo000^ooooo`03o`00
0?oooooo000008Cooooo00?o0000ooooooooool0/?ooool002oooooo0_l00024ooooo`03o`000?oo
oooooooo0;3ooooo000_ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00
Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l0
0000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/ooo
ool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooo
oooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj
01[ooooo0_l000000ol@413oooooooooo`03ooooo`;o000000?o410@ooooooooool0N_ooool008Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07_ooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool0
6_ooool5o`0000?ooooo1Ol0001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4
omgMgOoooooo0000OOooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool06_ooool01?oMgMgoEEEEooooool00004ooooo`04omgMgOmEEEGoooooo`0007gooooo0025
ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001[ooooo00?oMgMgolc<c?l0
00001Oooool00omgMgOoc<c<o`00001mooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`00
01Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000
ooooooooool06oooool00oo^k^koA4A4o`000005ooooo`03onk^k_m4A4Co000007gooooo0024oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01cooooo00?oMgMgo`000?ooool01Oooool0
0omgMgOo0000ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15261 m
.00488 .14419 L
.00942 .13803 L
.01441 .13277 L
.01975 .1286 L
.02244 .12705 L
.02385 .12639 L
.02535 .1258 L
.02666 .12536 L
.02811 .12497 L
.02942 .12469 L
.03065 .12449 L
.03193 .12434 L
.03314 .12426 L
.03424 .12424 L
.03543 .12427 L
.03672 .12438 L
.03809 .12459 L
.03939 .12489 L
.04057 .12525 L
.04189 .12577 L
.04334 .12648 L
.04627 .12841 L
.04898 .13083 L
.05151 .13371 L
.0545 .13806 L
.05722 .14323 L
.06037 .15107 L
.06335 .16091 L
.06594 .17176 L
.06869 .18608 L
.07363 .22054 L
.07894 .27236 L
.08481 .34383 L
.08748 .3764 L
.08997 .40294 L
.09133 .41491 L
.09257 .42379 L
.09394 .43114 L
.09469 .43397 L
.09541 .4358 L
.09658 .43705 L
.09783 .43594 L
.0989 .43306 L
.10007 .42796 L
.10133 .42041 L
.10268 .41023 L
.10512 .38769 L
.11063 .32928 L
.11365 .29966 L
Mistroke
.11649 .27606 L
.11914 .25823 L
.12202 .24336 L
.12462 .23337 L
.12702 .22675 L
.1283 .22411 L
.12949 .22216 L
.1308 .22053 L
.13153 .21984 L
.1322 .21934 L
.13354 .21868 L
.1343 .2185 L
.135 .21845 L
.13629 .21861 L
.13766 .2191 L
.13903 .21989 L
.14051 .22101 L
.14318 .22365 L
.14926 .23194 L
.15934 .24968 L
.16211 .25422 L
.16505 .25832 L
.16649 .25995 L
.16784 .26122 L
.16905 .26212 L
.17036 .26282 L
.17168 .26322 L
.1729 .26329 L
.17425 .26302 L
.17501 .26269 L
.1757 .26229 L
.17708 .26116 L
.17859 .25944 L
.18134 .25501 L
.18388 .24949 L
.18659 .24237 L
.19145 .22726 L
.20211 .19103 L
.20771 .17368 L
.21361 .15835 L
.2187 .14771 L
.22426 .1384 L
.22932 .1319 L
.23403 .12738 L
.23889 .12399 L
.24331 .12181 L
.24575 .12094 L
.24713 .12057 L
.2484 .1203 L
.24952 .12012 L
Mistroke
.25074 .11999 L
.25202 .11992 L
.25322 .11993 L
.25453 .12 L
.25526 .12007 L
.25592 .12015 L
.25722 .12036 L
.25844 .12061 L
.26117 .12139 L
.26271 .12197 L
.26413 .1226 L
.26917 .12568 L
.27171 .12781 L
.27449 .13062 L
.27935 .13677 L
.28456 .14533 L
.29395 .16693 L
.30405 .19807 L
.31477 .23319 L
.32036 .24795 L
.32354 .25437 L
.32653 .259 L
.32926 .26212 L
.33176 .26416 L
.33307 .26496 L
.33451 .26564 L
.33601 .26616 L
.33668 .26635 L
.3374 .26651 L
.33876 .26673 L
.34002 .26686 L
.34137 .26692 L
.34214 .26693 L
.34286 .26692 L
.34416 .26687 L
.34534 .26679 L
.34671 .26665 L
.34801 .26647 L
.34917 .26626 L
.3504 .26598 L
.35262 .26528 L
.35398 .26469 L
.35526 .264 L
.35764 .26227 L
.36028 .25958 L
.36306 .25572 L
.36804 .24608 L
.37339 .2321 L
.37926 .21379 L
.38982 .17989 L
Mistroke
.3998 .15413 L
.40532 .14348 L
.41131 .13475 L
.41675 .12896 L
.41938 .12677 L
.42178 .12506 L
.42412 .12365 L
.42667 .1224 L
.42936 .12137 L
.43071 .12097 L
.43192 .12066 L
.43307 .12042 L
.43431 .12021 L
.43562 .12004 L
.43685 .11993 L
.43801 .11987 L
.43924 .11986 L
.44028 .11988 L
.44143 .11995 L
.44213 .12001 L
.44288 .1201 L
.44426 .12031 L
.4456 .12059 L
.44684 .12092 L
.44964 .12191 L
.45263 .12338 L
.45519 .12501 L
.4576 .1269 L
.46044 .12962 L
.46309 .13274 L
.46801 .14041 L
.4734 .15235 L
.47865 .16837 L
.48427 .19105 L
.49437 .24468 L
.49881 .2692 L
.50369 .2916 L
.50499 .2962 L
.50639 .30036 L
.50771 .30348 L
.50891 .30563 L
.51027 .30723 L
.51104 .30774 L
.51175 .30798 L
.51305 .30781 L
.51444 .30684 L
.51523 .30594 L
.51596 .30492 L
.51759 .30198 L
.52056 .29496 L
Mistroke
.5261 .27943 L
.52867 .27265 L
.53142 .26637 L
.53398 .26168 L
.53639 .25828 L
.53769 .25684 L
.5391 .25557 L
.54157 .25393 L
.543 .25324 L
.54452 .25265 L
.54725 .25173 L
.54976 .25073 L
.55102 .25007 L
.5524 .24916 L
.55484 .24695 L
.55711 .2441 L
.5598 .23962 L
.56225 .23455 L
.56773 .22024 L
.57706 .19109 L
.58693 .16275 L
.59194 .15154 L
.59744 .14179 L
.60244 .13504 L
.60711 .1304 L
.60994 .12828 L
.61262 .12665 L
.61505 .12545 L
.61765 .12443 L
.61898 .124 L
.62046 .1236 L
.62181 .12331 L
.62306 .1231 L
.62377 .12301 L
.62452 .12293 L
.62528 .12287 L
.6261 .12283 L
.62681 .12281 L
.62758 .12281 L
.62896 .12286 L
.63025 .12296 L
.63098 .12304 L
.63167 .12313 L
.63317 .12337 L
.63454 .12363 L
.63702 .12425 L
.63969 .12514 L
.64254 .1264 L
.64566 .12825 L
.6486 .13053 L
Mistroke
.65133 .13316 L
.6541 .13643 L
.6567 .14018 L
.66157 .14956 L
.6643 .15659 L
.66681 .16448 L
.67248 .18826 L
.67742 .21676 L
.68271 .2554 L
.68728 .2927 L
.69225 .32996 L
.69372 .33883 L
.69528 .34666 L
.69661 .35185 L
.69737 .35414 L
.69808 .35584 L
.69947 .35784 L
.70074 .35815 L
.70141 .35774 L
.70214 .35684 L
.7029 .35543 L
.7036 .35369 L
.70495 .34933 L
.70623 .34408 L
.70861 .3319 L
.71395 .29889 L
.71923 .2683 L
.72181 .25645 L
.72416 .24786 L
.72665 .24115 L
.72801 .23844 L
.72931 .23649 L
.72999 .23568 L
.73072 .23499 L
.73202 .23415 L
.73282 .23387 L
.73357 .23375 L
.73424 .23377 L
.73497 .2339 L
.73619 .23436 L
.73732 .23502 L
.73856 .23596 L
.73989 .23716 L
.74255 .2399 L
.74507 .24249 L
.7474 .24449 L
.74871 .24533 L
.74993 .24587 L
.75095 .24612 L
.75207 .24615 L
Mistroke
.75325 .24591 L
.75435 .24541 L
.75565 .24446 L
.75638 .24376 L
.75705 .24302 L
.75955 .23933 L
.76248 .23338 L
.76524 .22638 L
.77559 .19379 L
.78486 .16628 L
.78977 .15473 L
.79503 .14484 L
.80033 .13734 L
.80527 .1323 L
.80818 .13007 L
.81093 .12837 L
.81344 .12713 L
.8161 .12611 L
.81839 .12548 L
.81969 .12522 L
.82092 .12504 L
.82204 .12494 L
.82306 .12489 L
.82419 .12488 L
.82538 .12492 L
.82659 .12501 L
.82788 .12516 L
.8291 .12536 L
.83021 .12557 L
.83292 .12628 L
.83549 .12721 L
.83799 .12841 L
.84034 .12984 L
.84313 .132 L
.84568 .13446 L
.85089 .14119 L
.85376 .1462 L
.85648 .15214 L
.85881 .15837 L
.86129 .16643 L
.86575 .18541 L
.87105 .21722 L
.87585 .25608 L
.88569 .35335 L
.88808 .37344 L
.8894 .38254 L
.89065 .38957 L
.89135 .3928 L
.89212 .39566 L
.89346 .39893 L
Mistroke
.89482 .39996 L
.89608 .39884 L
.89744 .39547 L
.89871 .39041 L
.9001 .38296 L
.90161 .37304 L
.90747 .32365 L
.9129 .27829 L
.91555 .26017 L
.91795 .24661 L
.92045 .23541 L
.92282 .22748 L
.92411 .22415 L
.92531 .22168 L
.92662 .2196 L
.92729 .21879 L
.92801 .21807 L
.92875 .21753 L
.92945 .21718 L
.93075 .21692 L
.93149 .21699 L
.93216 .21718 L
.93291 .21753 L
.9337 .21804 L
.93514 .21933 L
.93649 .2209 L
.93901 .22461 L
.9446 .23497 L
.9498 .24474 L
.95242 .24874 L
.95377 .25037 L
.95523 .25176 L
.95606 .25236 L
.95683 .25277 L
.95756 .25304 L
.95834 .25318 L
.95969 .25308 L
.96046 .25282 L
.96118 .25244 L
.96242 .25149 L
.96379 .25 L
.96627 .24619 L
.96868 .24122 L
.97093 .23565 L
.98142 .20278 L
1 .15261 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Tooooo`Ko0000=?ooool7o`00013ooooo00?o0000ooooooooool0/?ooool001oooooo1?l0000n
ooooo`?o00001Oooool2o`0003;ooooo0_l00006ooooo`;o00003_ooool00ol0003oooooooooo`0R
ooooo`So0000Q_ooool001gooooo0ol00002ooooo`;o0000??ooool00ol0003oooooooooo`08oooo
o`;o0000;_ooool2o`0000[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qoooo
o`;o00001_ooool2o`0003Kooooo2?l00017ooooo`006oooool2o`0000Oooooo0_l0000jooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo0_l0000Pooooo`;o00002_ooool2o`0003;ooooo0_l00007ooooo`;o
0000A_ooool001[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02gooooo0_l0000;ooooo`03o`000?oooooooooo04?ooooo000Jooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0@_ooool001Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`11ooooo`006?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
043ooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?oooool001Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0oooooo`005_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04Oooool002Wooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`06ooooo`;o00006oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo017ooooo000Zooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool04_ooool002[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Booooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o0000
ooooooooool03Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Booooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00ol0003oooooooooo`0Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQKooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1oooool00ol0
003oooooooooo`0@ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool04_ooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Mooooo`;o000000Wo410@ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool03?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo013ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Booooo`05
oa0@4?nj^[[oooooo`000?lb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo00Cooooo1_l0
0006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0@ooooo`Oo0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003o
ooooooooo`0<ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003ooooooooo
ool@41005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool0
0ol0003oooooooooo`0Aooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@4100
6oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0?oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo
oooo00Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo017ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool05_ooool00ol0003o410@ooooo`02ooooo`05o`000?oooooooooooooo
ool000006oooool01_m4A4CogMgMooooool0003oooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00002oooool00ol0003oooooooooo`0>ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`;o00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01;ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05Oooool00ol@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool00ooMgMgoEEEEooooo`02o`0000?o
oooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0>ooooo`03okZj^_lQ8B7ooooo
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00cooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41006?ooool00ol0003ooooo
ooooo`03ooooo`;o00006?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00onj
^[[o0000ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool01?mgMgOoc<c<o`000?l0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02oooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo
00Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RH
ogMgM`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo00oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0Dooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`03o`000?oooooooooo00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`08ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
4oooool00omEEEGoIVIVo`000003ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0>
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00?o0000ooooooooool05?ooool01OnYZJWo410@o`000?l@413o000000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00;?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Gooooo000/ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool05_ooool002cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Fooooo`00;?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01Kooooo000/ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05oooool0
01Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04Oooool001Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aoooo
o`00;Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000005Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01Sooooo000]ooooo`03o`000?oooooooooo013o
oooo0_l0000Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Pooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?oooo
o`?o00003Oooool00ol0003oooooooooo`0Hooooo`00;Oooool00ol0003oooooooooo`0?ooooo`;o
000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00kooooo0_l000000ooooooo0000o`00000;ooooo`03o`000?oooooooooo01Wooooo000]ooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`04o`000?oooooooooo
o`0001Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06Oooool002gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Iooooo`00;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Wooooo000]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00;o00004_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00kooooo0_l00007ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06_ooool002kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02;ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00001_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01[ooooo000^ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo000001;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo000^ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooo0000017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000Tooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01_ooooo000^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0ol0000Uooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01co
oooo000^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooo000000oooooo0_l0000Xooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`00000Nooooo`00;_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00000=ooooo`?o0000
:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`?o00007oooool002kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooool000002ooo
ool2o`0002cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0;?ooool002kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo0ol00009ooooo`;o0000;Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0/ooooo`00;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00cooooo1?l0000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool2o`00
00[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`00;oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo0_l0000aooooo`?o00000oooool3o`0002co
oooo0_l0000:ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool002oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`12ooooo`Go0000;_ooool2o`0000Wooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`00;oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo07Kooooo0_l00009ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0;Oooool002oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1f
ooooo`;o00002?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo000_oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool002oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0]ooooo`00;oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo07Oooooo0_l00006ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
;Oooool002oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`00;oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo0_l00005ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0;Oooool0033ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1hooooo`;o00001Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02gooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0N?ooool2o`0000Co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`00<?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0KOooool5o`0000Kooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02kooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0KOooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ol0
000fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02kooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0K_ooool00onHV9So8B4Qonk^kP07ooooo`Go0000=oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0^
ooooo`00<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06oooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo000`ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool0033ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0^ooooo`00<?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06kooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0;_ooool0033ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1^ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02kooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo000aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02kooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0NOooool2o`00
03_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0;_ooool0037ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool0037ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo03_ooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;oooool0037o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo03_o
oooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;oooool0037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0;oooool0037ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000>Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo000aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`00
03Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`00<Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0??ooool2o`0003[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`00<Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0??ooool2o`0003[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`00<_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07[ooooo0_l0001iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0;oooool003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`
ooooo`00<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo000booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool003;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0`ooooo`00<_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo033ooooo000booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`1iooooo`04o`000?ooooooooooo`0003?ooooo000booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`1iooooo`04o`000?oooooo
ooooo`0003?ooooo000booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool2
o`0007[ooooo00Co0000oooooooooooo0000<oooool003;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo07Wooooo00Co0000oooooooooooo0000<ooo
ool003;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo07Wooooo00Co0000oooooooooooo0000<oooool003;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo07[ooooo0_l0000dooooo`00<_ooool01Ol0
003ooooooooooooooooo000007kooooo00?o0000ooooooooool0N_ooool2o`0003Cooooo000boooo
o`05o`000?ooooooooooooooool00000MOooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool003;ooooo00Go0000ooooooooooooooooo`00001fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool003;ooooo00Go0000ooooooooooooooooo`00001c
ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00<oooool01?l0003oooooooooool0001c
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00<oooool01?l0003oooooooooool0
001cooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool003?ooooo00Co
0000oooooooooooo0000M?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo
000cooooo`04o`000?ooooooooooo`0007Cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`2`ooooo`00<oooool01?l0003oooooooooool0001eooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool0/?ooool003?ooooo00Co0000oooooooooooo0000O_ooool00ol0003ooooo
ooooo`2`ooooo`00=?ooool00ol0003oooooo`00001nooooo`03o`000?oooooooooo0;3ooooo000d
ooooo`;o0000Ooooool00ol0003oooooooooo`2`ooooo`00=?ooool2o`0007oooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@
okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Z
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj
^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oa0@4?o<c<`0O?ooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B40O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04
o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Joooo
o`Go00000oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`000?ooooooA4A4
odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003oV9RHoooooonHV9So8B4Q07cooooo0025ooooo`06o`000?oMgMgo<S8boeEE
EOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`00000Booooo`03o`000?oooooooooo01[ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
EEEEo`000?l@413oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`00
0003o`0001[ooooo00?oMgMgolc<c?l000001?ooool00omEEEGoQhN7ooooo`1nooooo`00QOooool0
1_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00oo^k^koA4A4o`000004ooooo`03
omgMgOl@413oV9RH07kooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@4100
6?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01co
oooo00?oMgMgo`000?ooool01?ooool01?o<c<coA4A4o`000?l@411looooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .12761 m
.00123 .12729 L
.00236 .12709 L
.00365 .12694 L
.00488 .1269 L
.00601 .12694 L
.00706 .12703 L
.00821 .1272 L
.00942 .12744 L
.01196 .12817 L
.01434 .12909 L
.01975 .132 L
.02499 .13579 L
.02978 .13993 L
.04057 .15048 L
.06172 .16876 L
.06751 .17285 L
.0707 .1754 L
.07369 .17831 L
.07649 .18175 L
.07952 .18664 L
.08228 .19252 L
.08481 .19946 L
.10469 .32301 L
.10748 .34547 L
.11013 .36388 L
.11159 .37219 L
.11318 .37935 L
.11389 .38182 L
.11463 .38395 L
.11597 .38648 L
.11721 .38731 L
.11855 .38658 L
.11982 .38442 L
.12098 .38127 L
.12226 .37663 L
.12367 .37037 L
.1265 .35519 L
.13184 .32471 L
.13447 .31234 L
.13689 .30376 L
.13824 .30032 L
.13893 .29897 L
.13968 .29779 L
.14043 .29691 L
.14124 .29632 L
.142 .29607 L
.1427 .29611 L
.144 .29681 L
.14473 .29754 L
Mistroke
.14541 .29843 L
.14666 .3005 L
.14798 .30326 L
.15338 .31735 L
.15467 .32056 L
.15603 .32353 L
.1572 .32558 L
.15847 .32719 L
.15961 .32797 L
.16083 .32804 L
.16198 .32732 L
.16303 .32595 L
.16425 .32353 L
.16557 .31987 L
.16796 .31064 L
.17779 .25023 L
.18294 .21598 L
.18836 .1854 L
.19125 .17205 L
.19442 .15985 L
.19996 .14383 L
.20269 .13806 L
.2056 .13315 L
.20835 .12954 L
.21084 .127 L
.21342 .12501 L
.21472 .12423 L
.21615 .12353 L
.21737 .12306 L
.21868 .12267 L
.21992 .1224 L
.22104 .12224 L
.22173 .12218 L
.22245 .12215 L
.22376 .12216 L
.22448 .12221 L
.22516 .12229 L
.22591 .12239 L
.22671 .12254 L
.22808 .12288 L
.22952 .12333 L
.23209 .12442 L
.23448 .12574 L
.23704 .12748 L
.24165 .13143 L
.25213 .14417 L
.26226 .1606 L
.27301 .17815 L
.27862 .18517 L
.28015 .18665 L
Mistroke
.28181 .18801 L
.28323 .18897 L
.28479 .18981 L
.28552 .19012 L
.2863 .1904 L
.28698 .19059 L
.2877 .19076 L
.28845 .19089 L
.28915 .19097 L
.29047 .19102 L
.29179 .19095 L
.29245 .19087 L
.29318 .19076 L
.29446 .19051 L
.29566 .19022 L
.29827 .18947 L
.29965 .18907 L
.30111 .18867 L
.30238 .18839 L
.3031 .18826 L
.30378 .18817 L
.30497 .18809 L
.30626 .18814 L
.30743 .18834 L
.30871 .18875 L
.31005 .18943 L
.3113 .19031 L
.31247 .19139 L
.31353 .19259 L
.31591 .19614 L
.3187 .20195 L
.32127 .20901 L
.32708 .23123 L
.33216 .25656 L
.33761 .285 L
.34034 .29709 L
.34169 .30199 L
.34294 .30573 L
.34406 .30838 L
.34526 .31037 L
.3466 .31149 L
.3478 .3115 L
.34903 .3105 L
.35016 .30869 L
.3514 .30574 L
.35271 .30161 L
.35491 .29252 L
.35733 .28004 L
.36868 .20971 L
.37405 .18167 L
Mistroke
.37901 .1617 L
.38407 .14676 L
.38673 .14078 L
.38956 .13563 L
.39431 .1292 L
.39701 .12654 L
.39955 .12456 L
.40238 .12287 L
.40378 .12222 L
.40507 .12171 L
.40634 .1213 L
.40749 .121 L
.40877 .12073 L
.41013 .12053 L
.41085 .12046 L
.4116 .1204 L
.41295 .12036 L
.4137 .12036 L
.4144 .12039 L
.41517 .12044 L
.416 .12051 L
.41671 .1206 L
.41748 .12072 L
.41889 .12098 L
.42153 .12169 L
.42397 .1226 L
.42661 .12387 L
.43139 .127 L
.43707 .13228 L
.44228 .13885 L
.44741 .14721 L
.45302 .15858 L
.46433 .18676 L
.46988 .20085 L
.4726 .20704 L
.47512 .21204 L
.47736 .21578 L
.47982 .21903 L
.4811 .22034 L
.48229 .22132 L
.48356 .22212 L
.48492 .2227 L
.48562 .2229 L
.48638 .22303 L
.48774 .22308 L
.48857 .223 L
.48935 .22286 L
.49005 .22269 L
.49081 .22245 L
.49373 .2212 L
Mistroke
.49641 .21989 L
.49758 .21938 L
.49885 .21893 L
.50023 .2186 L
.50152 .21851 L
.50221 .21856 L
.50297 .21871 L
.50434 .21926 L
.50568 .22016 L
.50691 .22137 L
.50815 .22297 L
.50946 .22511 L
.51179 .23016 L
.5143 .23746 L
.51704 .24767 L
.52654 .29579 L
.52933 .30993 L
.53197 .32094 L
.53342 .32557 L
.53419 .32751 L
.535 .32914 L
.53568 .33017 L
.53644 .33093 L
.53776 .33126 L
.53912 .33024 L
.54036 .3281 L
.54104 .32644 L
.54179 .32425 L
.54315 .31931 L
.54576 .30666 L
.54818 .29209 L
.55759 .22709 L
.56254 .19746 L
.56775 .17317 L
.57052 .16309 L
.57356 .15407 L
.57889 .1425 L
.58151 .13841 L
.58431 .13493 L
.58672 .13255 L
.58937 .13048 L
.59207 .12884 L
.59495 .12756 L
.59761 .12669 L
.6001 .12613 L
.6016 .12588 L
.60303 .1257 L
.60431 .12558 L
.60503 .12553 L
.60571 .1255 L
Mistroke
.6065 .12547 L
.60724 .12545 L
.60791 .12545 L
.60863 .12546 L
.60942 .12547 L
.61025 .12551 L
.61096 .12555 L
.61174 .1256 L
.61316 .12573 L
.6145 .12589 L
.61702 .12627 L
.61973 .12683 L
.62268 .12762 L
.62525 .12847 L
.62798 .12959 L
.63289 .13225 L
.63539 .134 L
.63803 .1362 L
.64273 .14122 L
.6478 .14857 L
.65334 .15949 L
.65815 .17179 L
.66329 .18791 L
.67254 .22222 L
.67776 .24108 L
.68062 .24989 L
.6833 .25666 L
.68481 .25975 L
.68619 .26207 L
.68772 .26408 L
.68856 .26494 L
.68936 .26559 L
.69075 .26636 L
.69204 .26669 L
.69278 .26674 L
.69345 .26669 L
.69423 .26655 L
.69496 .26634 L
.69991 .26382 L
.70111 .2632 L
.7024 .26266 L
.70314 .26244 L
.70381 .2623 L
.70513 .26226 L
.70586 .26239 L
.70654 .26261 L
.70728 .26298 L
.70807 .26353 L
.7094 .26483 L
.71086 .26687 L
Mistroke
.71216 .26925 L
.71357 .27243 L
.71612 .27977 L
.72125 .2997 L
.72671 .32331 L
.72833 .32932 L
.72986 .33408 L
.73123 .33741 L
.732 .33882 L
.73271 .33981 L
.73401 .34077 L
.73474 .34081 L
.73542 .34052 L
.73681 .3389 L
.73758 .3374 L
.73829 .33566 L
.73959 .33155 L
.74098 .32596 L
.74347 .31315 L
.74912 .27543 L
.75447 .23702 L
.75938 .20583 L
.76416 .18148 L
.7692 .1624 L
.77182 .15486 L
.77426 .14909 L
.77711 .14367 L
.7798 .13966 L
.78213 .13691 L
.78466 .13458 L
.78696 .13296 L
.78908 .13183 L
.79137 .13096 L
.79267 .13061 L
.79389 .13036 L
.79517 .13018 L
.79635 .13008 L
.7977 .13003 L
.79899 .13004 L
.8003 .13012 L
.80104 .13018 L
.80171 .13025 L
.80428 .13063 L
.80661 .13112 L
.80907 .13175 L
.81981 .13549 L
.82991 .13967 L
.83912 .14407 L
.8439 .14683 L
.84909 .15065 L
Mistroke
.85194 .15332 L
.85457 .15629 L
.85976 .16397 L
.8642 .17315 L
.8691 .18701 L
.87422 .2065 L
.87902 .22958 L
.88936 .28765 L
.89187 .30043 L
.89455 .31195 L
.8961 .31728 L
.8975 .32121 L
.89817 .32277 L
.89891 .32421 L
.90023 .32617 L
.90144 .32721 L
.90258 .32758 L
.90382 .32735 L
.90515 .32642 L
.90582 .32572 L
.90654 .32481 L
.90787 .32278 L
.91035 .31811 L
.91967 .303 L
.93124 .31571 L
.934 .32214 L
.93551 .32539 L
.93691 .32801 L
.93811 .3298 L
.9394 .33115 L
.94013 .33162 L
.94082 .33184 L
.94212 .33162 L
.9433 .33066 L
.94455 .32881 L
.94562 .32654 L
.9468 .32331 L
.94943 .31346 L
.95189 .3013 L
.96243 .23399 L
.96687 .2071 L
.97171 .18258 L
.97628 .1645 L
.98053 .1518 L
.98545 .14124 L
.9882 .13694 L
.9907 .13385 L
.993 .1316 L
.99549 .12973 L
.99663 .12904 L
Mistroke
.99784 .12843 L
1 .12761 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Gooooo`Ko00006?ooool00ol0003oooooooooo`2`ooooo`00F_ooool7o`0003Cooooo0_l00006
ooooo`;o00005_ooool00ol0003oooooooooo`2`ooooo`005_ooool4o`0003oooooo0_l00005oooo
o`;o0000<_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool06oooool:o`0007Oooooo00?o0000ooooooooool04Oooool001Wooooo0ol0000looooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo0_l0000Jooooo`;o00002_ooool2o`0003?ooooo1Ol0000looooo`03
o`000?oooooooooo01;ooooo000Looooo`;o0000>Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool03?ooool2o`0002oooooo0_l00005ooooo`?o0000
=oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:ooo
ool2o`0000Wooooo1?l0000booooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`;o0000<?ooool0
0ol0003oooooooooo`0Eooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Kooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Aooooo`;o0000;?ooool00ol0003oooooooooo`0Fooooo`008_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01Oooooo000Sooooo`;o0000<?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Gooooo`009Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo0_l0000E
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool002Kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Gooooo`009oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01Sooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`0?ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o0000ooooooooool02oooool5o`0000;ooooo
00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQ3ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool0
0ol0003oooooooooo`0Dooooo`Go00000oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool00000
6Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`05o`000?oooooo0000o`000?l@41000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000F
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oo
oooooooo00kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03Oooool00ol0003oooooooooo`0;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Ol0
003oV9RHoooooonHV9SoMgMg01kooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003ooooo
ooooo`0Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01omgMgOoV9RHoooooonHV9SoMgMg
ooooool000006Oooool01Ol@413o^[Zjo`000?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Kooooo`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0
003oooooooooo`05ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool02_ooool00ol0003oooooooooo`04ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?l0003oooooooooool@41004oooool6o`0000Gooooo0_l00003ooooo`05oa0@4?oo
ooooooooooooool@41004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`0Dooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooo
oooooooooa0@4?l0000Mooooo`;o00000oooool01Ol@413ooooooooooooooooo410@01[ooooo1_l0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03oooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0>oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooool0003oooooo`00000Nooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Gooooo00?oV9RHob4Q8Oo^k^h0
0oooool01?l0003oooooooooooooool2o`0001gooooo00?oZJVYo`000?ooool00_ooool01Ol0003o
oooooooooooooooo000001[ooooo00Go0000odA4A?oMgMgoooooo`000004ooooo`05o`000?oooooo
ooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000cooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;o
oooo00?o0000ooooooooool00_l0000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo01Gooooo00?oMgMgofIVI_ooool00_ooool01?l0003ooooooooooooo
ool2o`0001cooooo00?o410@o`000?l000000oooool01Ol0003ooooooooooooooooo000001[ooooo
00Go0000omgMgOmEEEGoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000oooo
ooooool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@oooo
o`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Booooo`03o`00
0?oooooooooo00Wooooo0_l0000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool05_ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o0000ooooooooool07?ooool00onj^[[o0000ooooo`02oooo
o`05oa0@4?ooooooooooooooool@41006Oooool01_l0003ooooooooooomgMgOoc<c<o`0000Cooooo
00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`09ooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03Oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Nooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01;ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?l000006oooool01?l@413oV9RHoooo
oonj^[X2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`06o`000?ooooooooooonk^
k_m4A4Co00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003o
ooooooooo`0=ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01?o^k^ko<S8bo`000?lb<S82
o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
4Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Koooo
o`06ojVYZOl@413o0000oa0@4?nYZJWo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo
00Ko0000ooooooooooooooooogMgMol00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
02oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`?o000000?oooooo`00
0?l000001Ol0000Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool0033o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`;o00001Oooool2o`00017o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`00<?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01[ooooo000aooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool0037ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0K
ooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0A
ooooo`00<_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo000booooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool2o`00017ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`;o0000
0_ooool5o`00013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`00<_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Sooooo`?o00000_ooool01?l0003oooooo`000?l0000>ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07?ooool003;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?oo
ool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
7?ooool003;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooooooo000000gooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`00<oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool07Oooool003?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`00<oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01gooooo000cooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Ooo
ool003?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`00<oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo000cooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool07_ooool003Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Nooooo`00=?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07_ooool003Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`?o00003Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool003Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`02o`000003ooooool0003o000000cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo000dooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02[ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo000dooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool07oooool003Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Oooooo`00=Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01oooooo000eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07oooool003Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:oooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01oooooo000eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool07oooool003Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Oooooo`00=Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo000foooo
o`03o`000?oooooooooo00Wooooo0ol00007ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo000fooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0cooooo`05
o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`00=_ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0coooo
o`05o`000?ooooooooooooooool000008oooool5o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Pooooo`00=_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0002?ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`05ooooo`;o00002Oooool00ol0003oooooooooo`0Pooooo`00=_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooo000002Gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool08?ooool003Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_oo
ool2o`0002Kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool08Oooool003Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Goooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Qooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000Hoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Qooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000Goooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000002Cooooo000gooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003ooooo05kooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000>_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00Co0000ooooool0003o00002?oo
ool01?l0003oooooooooool0000Tooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo0ol0001Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000>_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo0ol00009ooooo`04o`000?oo
oooo0000o`0002Cooooo000gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`08ooooo`;o0000??ooool01?l0003oooooooooool0000nooooo`?o0000
9Oooool003Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1cooooo`;o0000Aooo
ool01?l0003oooooooooool0001Vooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool0A_ooool01?l0003oooooooooool0001Vooooo`00>?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0Aooo
ool2o`0006Oooooo000hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`2`ooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool0/?ooool003Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2`ooooo`00>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool2o`000;7ooooo000iooooo`05
o`000?ooooooooooooooool00000Moooool00ol0003oooooooooo`2`ooooo`00>Oooool01Ol0003o
oooooooooooooooo000007Oooooo00?o0000ooooooooool0/?ooool003Wooooo00Go0000oooooooo
ooooooooo`00001gooooo`03o`000?oooooooooo0;3ooooo000iooooo`05o`000?oooooooooooooo
ool00000Moooool00ol0003oooooooooo`2`ooooo`00>_ooool01?l0003oooooooooool0001goooo
o`03o`000?oooooooooo0;3ooooo000jooooo`03o`000?oooooo000007Sooooo00?o0000oooooooo
ool0/?ooool003[ooooo00?o0000ooooool00000N?ooool00ol0003oooooooooo`2`ooooo`00>ooo
ool00ol0003oooooooooo`1gooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool0
0:[ooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05
oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002ioooo
o`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`00
0?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2
o`000009oa0@4?ooooooooooooooooo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooo
ooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool0
6_ooool5o`0000?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003ooooo
odA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1looooo`00QOooool01_l0003ogMgMoc8b
<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool000004_ooool00ol0003oooooooooo`0Jooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
c<c<o`000?l0003o0000olc<c01looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wo
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`00
0?l000000ol0000Jooooo`03ogMgMoo<c<co000000Cooooo00Go410@okZj^_oooooo^[Zjoa0@401l
ooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00oo^k^koA4A4
o`000004ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo00?o410@o`000?n7QhL0
0_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;o
oooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15283 m
.00488 .15535 L
.00942 .1576 L
.01199 .15865 L
.01441 .15942 L
.01575 .15974 L
.01646 .15987 L
.01721 .15999 L
.01853 .16013 L
.01975 .16018 L
.02104 .16015 L
.02221 .16006 L
.02357 .15986 L
.02486 .15959 L
.02715 .15892 L
.02966 .15795 L
.03531 .15499 L
.04057 .15162 L
.04635 .14784 L
.04919 .14627 L
.05043 .14569 L
.0518 .14515 L
.05295 .14477 L
.05418 .14446 L
.05548 .14424 L
.05669 .14414 L
.05737 .14414 L
.05811 .14418 L
.05946 .14436 L
.06077 .1447 L
.06198 .14517 L
.06329 .14587 L
.06469 .14687 L
.06724 .14941 L
.06872 .15138 L
.07027 .15389 L
.07305 .15961 L
.07596 .16743 L
.07867 .1765 L
.08481 .20378 L
.09011 .23414 L
.09586 .2692 L
.09849 .28327 L
.09994 .28979 L
.10128 .29495 L
.10253 .29879 L
.10367 .30145 L
.10493 .30342 L
.10629 .30435 L
.10749 .30413 L
Mistroke
.10877 .30283 L
.10998 .30066 L
.11108 .29793 L
.11377 .28855 L
.1163 .27701 L
.12122 .25103 L
.12581 .22867 L
.12817 .21986 L
.1295 .21606 L
.13071 .21341 L
.13203 .21144 L
.13278 .21078 L
.13347 .21047 L
.13474 .2107 L
.13609 .21209 L
.13737 .21459 L
.13875 .21862 L
.14005 .22378 L
.14124 .22974 L
.14402 .24845 L
.14693 .27583 L
.15217 .34211 L
.15474 .37811 L
.15711 .40901 L
.15926 .43225 L
.16035 .44137 L
.16154 .44898 L
.16274 .45381 L
.16402 .45565 L
.16523 .45412 L
.16634 .45 L
.16762 .44209 L
.16881 .43202 L
.1715 .40116 L
.17639 .32974 L
.18148 .25881 L
.18419 .22862 L
.18711 .20266 L
.18962 .18523 L
.19193 .17262 L
.19414 .16311 L
.19646 .15543 L
.19765 .15234 L
.19892 .14961 L
.20002 .14769 L
.20121 .14604 L
.20194 .14523 L
.20261 .14461 L
.20393 .14372 L
.20513 .14323 L
Mistroke
.20641 .14301 L
.20768 .14303 L
.20906 .1433 L
.21036 .14374 L
.21157 .1443 L
.21386 .14569 L
.2163 .14764 L
.22188 .15395 L
.22694 .16115 L
.23628 .17361 L
.24099 .17849 L
.24366 .18064 L
.24486 .18141 L
.24616 .18209 L
.24752 .1826 L
.24882 .18288 L
.25008 .18295 L
.25124 .18286 L
.2525 .18257 L
.25389 .18206 L
.25533 .18131 L
.25669 .18044 L
.26136 .17647 L
.26638 .17093 L
.27683 .15734 L
.27969 .15405 L
.28274 .15112 L
.28423 .14996 L
.28563 .14901 L
.28687 .1483 L
.28825 .14766 L
.28957 .14721 L
.2908 .14694 L
.29211 .14683 L
.29284 .14685 L
.29351 .14694 L
.2947 .14724 L
.29599 .14781 L
.29722 .14861 L
.29835 .14959 L
.29979 .1512 L
.30114 .1531 L
.30366 .15777 L
.30637 .16455 L
.3093 .17411 L
.31493 .19981 L
.32086 .23786 L
.32641 .2793 L
.32904 .29769 L
.33146 .3121 L
Mistroke
.33264 .31779 L
.33393 .32291 L
.33522 .32671 L
.3366 .32916 L
.33781 .32989 L
.3391 .32918 L
.34033 .3271 L
.34145 .32403 L
.34281 .31892 L
.34407 .31293 L
.34693 .29564 L
.35214 .2566 L
.35664 .22249 L
.3614 .1917 L
.36661 .16608 L
.37141 .14938 L
.37414 .14239 L
.3767 .13728 L
.3795 .13305 L
.38093 .13136 L
.3825 .12984 L
.38396 .12869 L
.38531 .12783 L
.38657 .12718 L
.38796 .12662 L
.38921 .12625 L
.39038 .12602 L
.39162 .12589 L
.39295 .12588 L
.39418 .12599 L
.39532 .1262 L
.39657 .12654 L
.39791 .12705 L
.40065 .12848 L
.40314 .13023 L
.40794 .13469 L
.41248 .14018 L
.43171 .17736 L
.43697 .18875 L
.43988 .19444 L
.44263 .19914 L
.44519 .20263 L
.44664 .20417 L
.44798 .20529 L
.44922 .20605 L
.45034 .20651 L
.45164 .20676 L
.45286 .20673 L
.45407 .20646 L
.4554 .20588 L
Mistroke
.45679 .20498 L
.45808 .2039 L
.4604 .20139 L
.46289 .19802 L
.47372 .17861 L
.47657 .17354 L
.47966 .16866 L
.48239 .16506 L
.48388 .16341 L
.48528 .16209 L
.48664 .16102 L
.48788 .16026 L
.48927 .15966 L
.48999 .15946 L
.49075 .15933 L
.49201 .15935 L
.49317 .15961 L
.49445 .16021 L
.49581 .16124 L
.49711 .16261 L
.49854 .1646 L
.50142 .17029 L
.50409 .17775 L
.50659 .18683 L
.51222 .21563 L
.51537 .23711 L
.51826 .25962 L
.52346 .30322 L
.5262 .32442 L
.52771 .33446 L
.52912 .34245 L
.53034 .34803 L
.53166 .35249 L
.53238 .35417 L
.53313 .35538 L
.53447 .35604 L
.5357 .35495 L
.53684 .35251 L
.53809 .34831 L
.53943 .34219 L
.54956 .26352 L
.55511 .21921 L
.5603 .18704 L
.563 .17408 L
.56591 .16268 L
.56913 .15269 L
.57208 .14564 L
.57474 .1407 L
.57765 .13654 L
.5804 .13355 L
Mistroke
.58295 .1314 L
.58559 .12967 L
.58697 .12893 L
.58844 .12827 L
.58972 .1278 L
.59113 .12737 L
.5924 .12708 L
.5936 .12688 L
.59485 .12674 L
.59604 .12668 L
.5971 .12669 L
.59826 .12674 L
.59952 .12687 L
.60085 .12707 L
.60199 .12729 L
.60325 .1276 L
.60605 .12851 L
.60862 .12967 L
.61144 .13134 L
.61441 .13366 L
.61941 .13901 L
.62489 .1472 L
.63637 .17362 L
.64721 .20701 L
.65193 .22025 L
.65452 .22611 L
.65694 .23036 L
.6582 .23203 L
.65955 .23336 L
.66032 .23389 L
.66105 .23425 L
.66242 .23452 L
.66368 .2343 L
.66485 .2337 L
.66612 .23263 L
.66748 .23103 L
.67708 .21014 L
.68231 .19613 L
.6872 .18461 L
.68975 .1798 L
.69107 .17775 L
.69249 .17591 L
.6933 .17506 L
.69405 .17439 L
.69477 .17388 L
.69553 .17348 L
.69684 .17313 L
.69759 .17313 L
.69829 .17328 L
.69961 .17395 L
Mistroke
.70086 .17507 L
.70198 .17651 L
.7032 .17857 L
.70453 .18141 L
.70594 .18517 L
.70849 .19399 L
.71141 .20767 L
.71457 .22714 L
.7203 .27447 L
.72541 .32393 L
.72831 .34993 L
.72973 .36082 L
.73102 .36928 L
.73235 .37625 L
.73361 .38102 L
.73494 .38394 L
.73569 .3846 L
.73638 .38456 L
.73769 .38278 L
.73843 .38079 L
.73913 .37831 L
.74054 .37158 L
.74205 .36199 L
.74735 .31549 L
.75221 .26777 L
.75718 .22585 L
.75991 .20739 L
.76249 .19291 L
.7649 .18175 L
.76751 .17192 L
.76986 .16484 L
.77206 .15957 L
.77468 .15474 L
.77755 .15084 L
.78035 .14804 L
.78337 .14575 L
.78616 .14408 L
.78881 .14282 L
.79119 .14194 L
.79379 .14121 L
.80444 .139 L
.80699 .13839 L
.80967 .1378 L
.81196 .13738 L
.81327 .1372 L
.81447 .13707 L
.81586 .13695 L
.81657 .1369 L
.81734 .13685 L
.81872 .1368 L
Mistroke
.82002 .13676 L
.82074 .13676 L
.82154 .13676 L
.82237 .13677 L
.82314 .13679 L
.82453 .13687 L
.82531 .13694 L
.82603 .13703 L
.82729 .13724 L
.82847 .13751 L
.82975 .13792 L
.83113 .13849 L
.83394 .14012 L
.8365 .14221 L
.83893 .14474 L
.8416 .14818 L
.8442 .15229 L
.84699 .1577 L
.85199 .17052 L
.85666 .1864 L
.868 .23408 L
.87085 .2455 L
.87352 .25479 L
.87592 .26133 L
.87727 .26407 L
.87851 .26592 L
.87971 .26705 L
.88102 .26753 L
.88239 .26718 L
.88367 .2661 L
.88438 .26518 L
.88506 .26413 L
.88632 .26167 L
.88916 .25422 L
.89519 .23296 L
.90077 .21243 L
.9033 .20438 L
.90568 .19823 L
.90687 .19578 L
.90816 .19371 L
.90889 .19282 L
.90958 .19216 L
.91089 .19149 L
.91221 .19159 L
.91294 .192 L
.91361 .1926 L
.91492 .19441 L
.91614 .19691 L
.91758 .20086 L
.9189 .20552 L
Mistroke
.92188 .21993 L
.92446 .23709 L
.92681 .25674 L
.9321 .31318 L
.93705 .37097 L
.93923 .39249 L
.94039 .4019 L
.94164 .41008 L
.94298 .41627 L
.94423 .41946 L
.94493 .42009 L
.94566 .41984 L
.94698 .41711 L
.94767 .41451 L
.94841 .41087 L
.94975 .40225 L
.95134 .38892 L
.95278 .37442 L
.95791 .31331 L
.96334 .25102 L
.96769 .21266 L
.97017 .19603 L
.97249 .18351 L
.97457 .17446 L
.97656 .16756 L
.97884 .16138 L
.98093 .15718 L
.98322 .15391 L
.9845 .15261 L
.98566 .1517 L
.98675 .15107 L
.98792 .15059 L
.98903 .1503 L
.99005 .15016 L
.99125 .15014 L
.99236 .15023 L
.99358 .15044 L
.99489 .15077 L
.99757 .15173 L
1 .15283 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002@oooo
o`Go00008?ooool00ol0003oooooooooo`0Iooooo`Ko0000TOooool008oooooo0_l00004ooooo`;o
00007_ooool2o`0001Wooooo0_l00005ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Fooooo`;o0000
2?ooool2o`0008kooooo002>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>ooo
ool6o`0004[ooooo002>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=_ooool4
o`0000Gooooo0ol00018ooooo`00Eoooool2o`0003Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0cooooo`?o00003?ooool00ol0003oooooooooo`15ooooo`009Oooool6o`0002_o
oooo0_l000000ooooooo0000o`00000Hooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0`ooooo`;o00004?ooool00ol0003oooooooooo`14ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01;ooooo1_l0000Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04?ooooo000Fooooo`03o`000?oo
oooooooo00Wooooo0_l00008ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l0000Eooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02[ooooo1_l0000Cooooo`005oooool2o`0000Oooooo0_l0000:ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Oooooo0_l0000Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05_ooool0
01Wooooo0_l00003ooooo`;o00003?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`04o`000?oooooooooo
o`0001Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`006_ooool5o`00
00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04Oooool6o`0001Cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Hooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?o0000ooooooooool02_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0@
ooooo`Go000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool03oooool2o`0000?ooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo1?l000001?l@413o
ooooooooooo^k^h2o`000003oc8b<_o^k^kooooo01Wooooo1Ol00003ooooo`07onk^k_lb<S;o0000
oc8b<_o^k^koooooo`00000Hooooo`06o`000?nHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01_ooooo00Go0000ooooool0003o0000oa0@4003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo00?o0000ooooooooool02Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Wooooo00So0000oooooooo
ooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgo`000?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo013ooooo00Co0000oooooooooooo00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o00005?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool0
00006?ooool01_l0003o410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
2oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool01?l0003o
ooooooooooooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool7o`0000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol0003ooooooooooooooooo410@00Wooooo00?o0000ooooooooool01oooool6o`0000;ooooo00Co
0000oooooooooooo00001?ooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41006oooool00onH
V9So8B4Qonk^kP04ooooo`06oa0@4?ooooooooooooooool@413o00006_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool02oooool01_l0003ooooooooo
oonHV9So8B4Qonk^kP?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool00000
3oooool4o`0000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooooooool2o`0001[o
oooo00Go0000ooooooooooooZJVYoa0@4003ooooo`05o`000?ooooooooooooooool000006_ooool0
1Ol0003oA4A4omgMgOoooooo000000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`0:ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo00_ooooo00Oo0000ooooooooooooooooogMgMomVIVKooooo00?o00000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooool0003oooooo`00000?ooooo`04o`000?ooooooooooo`0000[ooooo00?oMgMg
ofIVI_ooool00_ooool01?l0003oooooooooooooool2o`0001[ooooo00Go0000ooooool@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ogMgMoeEEEOoooooo0000
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00cooooo0_l0
0002ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00Wooooo00?o0000ooooooooool0
3oooool01?l0003oooooooooool00004ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@00kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol0003oooooooooo`0Jooooo`04o`000?oooooo^[Zjob4Q8@?ooooo00Go410@oooooooooooo
oooooa0@400Iooooo`06o`000?ooooooooooogMgMoo<c<co00001?ooool01Ol@413ooooooooooooo
oooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0?ooooo`03o`000?oooooooooo00Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0=ooooo`03o`000?nj^[[o000000?o
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9So000001_ooooo00Go410@o`000?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01_l0003oooooooooooo^k^koA4A4o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`07ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03
o`000?oooooooooo00gooooo00Go0000oooooomEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooool000004?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o0000onk^kP0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Kooooo`05
ojVYZOl0003o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Ko0000
ooooooooooooooooogMgMol00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0033ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000004?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`00<?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0>ooooo`?o00004Oooool00ol0003oooooooooo`0Jooooo`00<?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
000?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0<ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool06_ooool0033ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00003_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo01[o
oooo000aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000@oooo
o`03o`000?oooooooooo01[ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool2o`0000Kooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool2
o`0000Cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0Aooooo`00<Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02[ooooo00Go0000ooooooooooooooooo`00
000<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Kooooo`00<Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02_ooooo00Go
0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Kooooo`00<_ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000003Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo000booooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07?ooool003;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`00<_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool01?l0003o
ooooooooool0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0:oooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Nooooo`Co00003_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07?ooool003;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01cooooo000booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool003?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo000cooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`00
<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7Oooool003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo000cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0/ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01gooooo000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool01?l0
003oooooooooool0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool0
03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`00=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool07Oooool003Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool003Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07Oooool003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07Oooool003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00=_oo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Nooooo`00=_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Nooooo`00=_ooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07_ooool003Kooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo000gooooo`;o00003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Sooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00>?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01kooooo0015ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;_ooool01Ol0003ooooooooooooooooo000002Oooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01kooooo0015ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool0
1Ol0003ooooooooooooooooo000002Sooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Nooooo`00AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02kooooo00Go0000
ooooooooooooooooo`00000Yooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_oo
ool004Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`04o`000?oooooo
ooooo`0002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00AOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00009_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_ooool004Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo000002Oooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo0015ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01kooooo0016ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool2
o`0003;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000003[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07_ooool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1T
ooooo`;o00001oooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07ooo
ool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`00A_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool0000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo0016ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0003cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07oooool004Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000??oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Oooooo`00A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01oooooo0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooo000003cooooo00Go0000ooooooooooooooooo`00000l
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool004Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Oooooo0_l0000moooo
o`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01oooooo0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`16ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01oooooo0017ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0IOooool2o`0004Oooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08?ooool004Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo04Kooooo00Go0000ooooooooooooooooo`00000m
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool004Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo04Kooooo00Co0000oooo
oooooooo0000?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo0017oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`16oooo
o`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0P
ooooo`00Aoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooo`00000nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08?ooool004Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooool00000?_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo023ooooo0017ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`17ooooo`03o`000?oooooo000003kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Pooooo`00Aoooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool0B?ooool2o`0003oooooo00Go0000oooooooooooooooo
o`00000Rooooo`00Aoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo0_l0
002:ooooo`05o`000?ooooooooooooooool000008_ooool004Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo08Wooooo00Go0000oooooooooooooooo
o`00000Rooooo`00Aoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool0ROooool01Ol0003ooooooooooooooooo000002;ooooo0018ooooo`05o`000?oo
ooooooooooooool00000J?ooool00ol0003oooooooooo`29ooooo`05o`000?ooooooooooooooool0
00008_ooool004Sooooo00Go0000ooooooooooooooooo`00001Xooooo`03o`000?oooooooooo08Wo
oooo00Co0000oooooooooooo00008oooool004Sooooo00Go0000ooooooooooooooooo`00001Ooooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`29ooooo`04o`000?oooooooooo
o`0002?ooooo0018ooooo`05o`000?ooooooooooooooool00000H?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08Wooooo00Co0000oooooooooooo00008oooool004Sooooo00Go0000
ooooooooooooooooo`00001Mooooo`Go00001_ooool00ol0003oooooooooo`29ooooo`04o`000?oo
ooooooooo`0002?ooooo0018ooooo`05o`000?ooooooooooooooool00000GOooool01?m4A4CogMgM
ooooool00007ooooo`?o0000ROooool01?l0003oooooooooool0000Sooooo`00B?ooool01Ol0003o
oooooooooooooooo000005gooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2:
ooooo`;o00009?ooool004Sooooo00Co0000oooooooooooo0000Goooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo08[ooooo0_l0000Tooooo`00B?ooool01?l0003oooooooooool0001O
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool004Sooooo00Co0000oooo
oooooooo0000H?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo0018oooo
o`04o`000?ooooooooooo`0006Wooooo00?o0000ooooooooool0/?ooool004Sooooo00Co0000oooo
oooooooo0000JOooool00ol0003oooooooooo`2`ooooo`00B?ooool01?l0003oooooooooool0001Y
ooooo`03o`000?oooooooooo0;3ooooo0019ooooo`03o`000?oooooo000006Wooooo0_l0002aoooo
o`00BOooool00ol0003oooooo`00001Yooooo`03o`000?oooooooooo0;3ooooo0019ooooo`03o`00
0?oooooo000006Wooooo00?o0000ooooooooool0/?ooool004Wooooo00?o0000ooooool00000JOoo
ool00ol0003oooooooooo`2`ooooo`00BOooool00ol0003oooooo`00001Yooooo`03o`000?oooooo
oooo0;3ooooo001:ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0/?ooool004[o
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@
okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Z
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj
^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo0025ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Koooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0O
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0N_ooool008Gooooo00Ko0000
oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko0000omgMgOlb
<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEE
o`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
410@o`000?l000000ol0000Jooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool06oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16291 m
.00488 .15285 L
.00942 .14531 L
.01441 .13869 L
.01975 .13327 L
.02244 .13111 L
.02535 .12916 L
.02811 .12772 L
.02942 .12718 L
.03065 .12676 L
.03175 .12646 L
.03294 .12623 L
.03426 .12608 L
.03546 .12604 L
.03671 .12611 L
.03808 .12631 L
.03937 .12664 L
.04057 .12706 L
.04201 .12773 L
.04334 .12851 L
.04635 .13094 L
.049 .13395 L
.0518 .13819 L
.05431 .14306 L
.05665 .14864 L
.06198 .16558 L
.06774 .19128 L
.073 .22092 L
.07872 .2559 L
.08186 .27321 L
.0834 .28047 L
.08481 .28617 L
.08595 .29001 L
.08719 .29334 L
.08844 .2957 L
.08976 .29706 L
.09112 .29723 L
.09189 .29676 L
.09259 .296 L
.09394 .29359 L
.09522 .29027 L
.09762 .28155 L
.09984 .27118 L
.10485 .24307 L
.11028 .21203 L
.11327 .19692 L
.11611 .18452 L
.11874 .17486 L
.12162 .16638 L
.12423 .16051 L
Mistroke
.12665 .15656 L
.12789 .15508 L
.12923 .15387 L
.13049 .1531 L
.13165 .15269 L
.13271 .15257 L
.13386 .1527 L
.13507 .15314 L
.13619 .15382 L
.13751 .15497 L
.13876 .15641 L
.1411 .16011 L
.14361 .16566 L
.14635 .17379 L
.14895 .18376 L
.15181 .19761 L
.15761 .23619 L
.16298 .28555 L
.16802 .3402 L
.17062 .36804 L
.17338 .39427 L
.17473 .40485 L
.176 .41317 L
.17714 .41909 L
.17837 .4237 L
.17969 .42644 L
.18035 .42695 L
.18108 .42684 L
.18237 .42495 L
.18357 .42131 L
.18431 .41825 L
.185 .4148 L
.18631 .40703 L
.18925 .38465 L
.19849 .30226 L
.20375 .2651 L
.2087 .23932 L
.21356 .2205 L
.21882 .20503 L
.22958 .1802 L
.23959 .16069 L
.24891 .14586 L
.25416 .13914 L
.25894 .13432 L
.26425 .13032 L
.26717 .12869 L
.26848 .1281 L
.26993 .12756 L
.27131 .12716 L
.27261 .12691 L
Mistroke
.27398 .12677 L
.27475 .12675 L
.27545 .12678 L
.2767 .12692 L
.27806 .12722 L
.27935 .12765 L
.28055 .12819 L
.28205 .12905 L
.28347 .13008 L
.28613 .13261 L
.28898 .13643 L
.29207 .14214 L
.29457 .14821 L
.29724 .15642 L
.30206 .17634 L
.3078 .20961 L
.31302 .24817 L
.31847 .29055 L
.32134 .30967 L
.32291 .31813 L
.32439 .3244 L
.32567 .32836 L
.32704 .33095 L
.32779 .3316 L
.32857 .33171 L
.32924 .33134 L
.32998 .33044 L
.33127 .32762 L
.33265 .32298 L
.33396 .31718 L
.33515 .31085 L
.34577 .23357 L
.35157 .19582 L
.35441 .18138 L
.357 .17057 L
.35922 .16302 L
.36163 .15641 L
.36418 .15109 L
.3666 .14742 L
.36799 .14586 L
.36925 .14477 L
.36995 .14428 L
.37071 .14385 L
.37207 .1433 L
.37336 .14304 L
.37472 .14302 L
.37588 .14319 L
.37715 .14357 L
.37845 .14417 L
.37987 .14503 L
Mistroke
.38244 .14713 L
.38494 .14979 L
.38725 .15273 L
.39807 .17108 L
.40745 .18899 L
.41016 .19346 L
.41273 .19713 L
.41504 .19981 L
.41634 .20102 L
.41756 .20196 L
.41889 .20275 L
.4201 .20324 L
.42141 .20353 L
.42214 .20358 L
.42282 .20355 L
.42395 .20336 L
.42519 .20292 L
.42649 .20223 L
.4277 .20137 L
.4301 .19911 L
.43229 .19647 L
.43721 .18898 L
.44846 .16864 L
.4534 .16023 L
.45886 .15226 L
.46354 .14674 L
.46857 .1421 L
.47135 .14014 L
.4739 .13874 L
.47516 .13819 L
.47633 .13778 L
.47755 .13745 L
.47889 .13721 L
.48026 .1371 L
.48102 .1371 L
.48173 .13714 L
.48303 .13732 L
.48441 .13767 L
.48565 .13812 L
.4868 .13868 L
.48807 .13946 L
.48943 .14051 L
.49087 .14189 L
.49245 .14375 L
.49531 .14826 L
.4981 .15431 L
.50069 .16169 L
.52046 .29441 L
.52326 .31943 L
.52587 .3396 L
Mistroke
.5273 .34852 L
.5286 .35501 L
.52929 .35776 L
.53004 .36015 L
.53083 .36198 L
.53159 .36302 L
.53281 .36327 L
.53417 .36145 L
.53485 .35972 L
.53558 .35726 L
.5369 .35134 L
.53947 .33513 L
.54182 .31611 L
.55279 .21808 L
.5583 .18238 L
.56143 .16747 L
.56433 .15663 L
.5671 .14868 L
.5697 .14302 L
.57205 .13925 L
.57458 .13632 L
.5759 .13521 L
.57735 .13426 L
.57808 .13389 L
.57886 .13356 L
.5796 .13332 L
.58027 .13315 L
.58156 .13297 L
.58229 .13295 L
.58297 .13297 L
.5842 .13315 L
.58552 .13352 L
.58671 .13401 L
.58801 .13471 L
.59064 .13667 L
.59307 .13911 L
.59534 .14189 L
.60045 .14993 L
.60593 .16124 L
.6159 .18833 L
.62511 .21393 L
.6278 .21986 L
.63032 .22429 L
.63159 .22603 L
.63295 .2275 L
.63372 .22814 L
.63446 .22861 L
.63584 .22913 L
.63658 .22921 L
.63724 .22916 L
Mistroke
.63801 .22897 L
.63873 .22865 L
.64002 .22778 L
.64074 .22711 L
.64141 .22639 L
.64437 .22212 L
.64749 .21601 L
.6577 .19072 L
.66331 .17717 L
.66864 .16661 L
.67381 .15902 L
.67673 .15581 L
.67943 .15348 L
.68169 .15198 L
.68298 .15132 L
.6842 .15082 L
.68547 .15044 L
.68663 .15021 L
.68791 .1501 L
.68926 .15014 L
.69047 .15032 L
.69157 .15059 L
.69283 .15103 L
.69403 .15157 L
.69615 .15286 L
.69846 .15476 L
.701 .15757 L
.70369 .16155 L
.70599 .16597 L
.70851 .17215 L
.71114 .18026 L
.71399 .19139 L
.71919 .21891 L
.72425 .25595 L
.72894 .29805 L
.73157 .32273 L
.73442 .34757 L
.73572 .35758 L
.7371 .36677 L
.73829 .37334 L
.73957 .37876 L
.74034 .38115 L
.74103 .38273 L
.7424 .38412 L
.74317 .38389 L
.744 .38283 L
.74478 .38105 L
.7455 .37877 L
.74675 .37348 L
.74811 .36579 L
Mistroke
.75088 .34527 L
.76131 .24733 L
.76646 .20792 L
.77124 .1808 L
.77389 .16925 L
.77671 .15923 L
.77978 .15061 L
.78268 .1443 L
.78532 .1398 L
.78817 .13598 L
.79077 .13327 L
.79316 .13132 L
.79448 .13045 L
.79573 .12974 L
.79687 .1292 L
.79808 .12874 L
.7994 .12836 L
.80061 .12813 L
.80192 .128 L
.80267 .12798 L
.80337 .128 L
.80453 .12811 L
.80576 .12834 L
.80681 .12862 L
.80795 .12902 L
.81052 .13028 L
.8129 .13193 L
.81573 .13456 L
.81839 .13781 L
.82339 .14626 L
.82618 .15251 L
.82876 .15931 L
.83459 .17842 L
.84408 .21823 L
.84931 .24005 L
.85188 .24897 L
.85427 .25547 L
.85563 .25823 L
.85632 .25937 L
.85707 .26038 L
.85789 .26122 L
.85867 .26174 L
.85943 .262 L
.86012 .26202 L
.86136 .26153 L
.86272 .26025 L
.86341 .25932 L
.86414 .25811 L
.86546 .25543 L
.86828 .24778 L
Mistroke
.87095 .23863 L
.87594 .21879 L
.88118 .19793 L
.88609 .18116 L
.89121 .16785 L
.89393 .16262 L
.89545 .16025 L
.89687 .15839 L
.89922 .15602 L
.90046 .15513 L
.90179 .15445 L
.90246 .15421 L
.90318 .15402 L
.9045 .1539 L
.90578 .15402 L
.90696 .15435 L
.90807 .15484 L
.9091 .15546 L
.91146 .15746 L
.91375 .16021 L
.91621 .16412 L
.91889 .16962 L
.92174 .17711 L
.92687 .19562 L
.93001 .2107 L
.93296 .22784 L
.93847 .268 L
.94875 .35837 L
.95125 .37649 L
.95262 .38454 L
.95392 .39062 L
.95465 .39334 L
.95545 .39566 L
.95618 .39718 L
.95685 .39807 L
.95818 .39838 L
.95885 .39779 L
.95958 .39658 L
.96025 .39497 L
.96099 .39269 L
.96232 .38716 L
.96482 .37261 L
.97046 .32705 L
.97539 .28391 L
.98065 .24382 L
.98591 .21252 L
.99069 .19106 L
.99548 .17472 L
1 .16291 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000Ooooo
o`Go0000B?ooool4o`0004Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1@oooo
o`007Oooool2o`0000Cooooo0_l00015ooooo`;o00000oooool2o`0004Cooooo0_l0001Looooo`Ko
0000Coooool001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Fooooo`?o0000
@?ooool2o`0000Gooooo00?o0000ooooooooool0COooool001_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Ooo
ool2o`0000Gooooo00?o0000ooooooooool05Oooool01?l0003oooooooooooooool2o`0003kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`006_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0gooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04_ooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo0ol0000Kooooo`;o00001_oo
ool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo000Iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Gooooo0_l000000ooooooo0000o`00000Iooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`19ooooo`006?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool000005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`19ooooo`005oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Cooooo0_l0000Sooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05oooool5o`0001[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18
ooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo0_l000000ooo
oooo0000ooooo`0Pooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool3o`00
01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool4o`00
033ooooo000Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool01Ol0003o
oooooooooooooooo0000023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:oooo
o`;o00004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo000Fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0/ooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000
ooooooooool03_ooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^o`000?l0003o<S8b
onk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`04o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^
k_ooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h8ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00006ooooo`03o`000?oo
oooooooo01?ooooo0_l000002Ol@413oooooooooool0003ok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0
003oooooooooo`0>ooooo`05oa0@4?nj^[[o0000ogMgMolb<S800oooool01OmgMgOo0000oooooonH
V9SoMgMg01[ooooo00Ko0000oiRHV?lQ8B7ok^k^oooooom4A4@3ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01OmgMgOo0000oooooonHV9SoMgMg00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?l000001oooool00ol0003oooooooooo`0Dooooo`0:o`000?oooooo
ooooooooool0003oMgMgoiRHV?ooooooV9RHogMgM`kooooo000;ooooo`Ko00000_ooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Kooooo1_l00004oooo
o`03o`000?oooooo000000?ooooo00Go410@ooooool0003ooooooa0@400Cooooo`Ko000000Kooooo
o`000?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo0000oooo
ool@41003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03Oooool2o`0000Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00Go
0000oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4?ooool5o`000004ooooool0003ooooooa0@40?ooooo00?o410@ooooooooool03?ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool03_ooool01?l0003oooooojVYZOl@4103ooooo`05o`000?oooooo0000ooooool000006Ooo
ool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooool0003oooooo`00000<ooooo`03o`000?oooooooooo00oooooo0_l0000A
ooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`06ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo013ooooo00CoA4A4omgMgOoooooo00000_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00cooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo00kooooo00Co0000oa0@4?l0003o^[Zj0ooo
ool01Ol0003oooooo`000?oooooo000001Wooooo00?o0000ooooooooool00_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000co
oooo00?o0000ooooooooool03oooool2o`00013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool01ol0003ooooooooooooooooo
0000ooooool000004oooool00ol0003oooooooooo`05ooooo`03oa0@4?l0003o^[Zj00?ooooo00?o
0000ooooooooool00_l00009ooooo`03o`000?oooooooooo00oooooo00CogMgMoeEEEOoooooo0000
0_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00cooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo00kooooo
00Co0000oooooonj^[[o8B4Q0oooool01Ol@413oooooooooool0003o410@01Sooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1Ol@413oooooooooool0003o410@00_ooooo00?o0000ooooooooool04?ooool2o`00013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooo000001?ooooo00?o0000ooooooooool01_ooool00onj^[[o
8B4Qooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41002Oooool00ol0003oooooooooo`0@oooo
o`05ogMgMoo<c<co0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oo
oooooooo00gooooo00Go410@o`000?oooooo^[Zjo`000003ooooo`05ogMgMonHV9Soooooo`000?mg
MgL06?ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000;ooooo`03o`000?oooooooooo013o
oooo0_l0000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool00000
4oooool00ol0003oooooooooo`03ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHooooool0003oMgMg00[ooooo00?o0000ooooooooool03oooool01Oo^k^koA4A4o`000?oooooo
000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0=ooooo`05ojVYZOl0
003o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Oooooo00Wo0000oooooooo
oooooooooiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool03Oooool01ol0003oooooooooooooooooEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;o000000_ooooo00?o0000ooooooooool04?ooool2o`00013ooooo00?o0000
ooooooooool03Oooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000Cooooo`03o`000?oooooo
oooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2_ooool00ol0003oooooooooo`0@ooooo`04ogMgMol0003oooooo`0000;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`00:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo0_l0000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo
0_l0000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooool000003oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool002_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooool000003oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05?ooool002cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo017ooooo0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooo0000
00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Cooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
4Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo000/ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
000000kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Gooooo000]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo000]ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`04o`000?oooooooooo
o`0000gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Kooooo000]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo000]ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^ooooo`04o`000?oooooooooo
o`0000gooooo00?o0000ooooooooool05_ooool01?l0003oooooo`000?l0000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`00;Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool0
1?l0003oooooooooool0000=ooooo`03o`000?oooooooooo01Oooooo0_l0000Iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`00;_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool2
o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool002kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`00;_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05oooool002kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Oooooo000^ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Gooooo`00;oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05oooool002oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Oooooo000_ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0_ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool002oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0_l00002
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Sooooo000_ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool07?ooool2o`0001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`00;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`00<?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00
<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Hooooo`00<?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00<?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Iooooo`00<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`00<?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool2o`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wo
oooo000aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Iooooo`00<Oooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06Oooool0037ooooo00Co0000oooooooooooo00005Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000booooo`;o00005_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Wooooo001:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool5o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool06Oooool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Toooo
o`05o`000?ooooooooooooooool00000:Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06Oooool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0T
ooooo`05o`000?ooooooooooooooool00000:_ooool00onHV9So8B4Qonk^kP07ooooo`?o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_oo
ool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`05o`000?oooooo
ooooooooool00000:oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo001;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooo
oooo000002cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`00Boooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00
000]ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool004_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000:Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool004_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0002Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo001;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00000eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01[ooooo001;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09ooo
ool2o`0003Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000003gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool004_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Nooooo`;o00001_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6_ooool004_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo
001;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool00000?_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`00Booo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000003kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool004_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo0000?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`00Boooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool0000nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01_ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0003kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06oooool004cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000?oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Kooooo`00C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool01_ooool00ol0003oooooo`00000oooooo`05o`000?ooooooooooooooool00000?ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo001<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Goooool2o`0000Sooooo0_l0000oooooo`05o`000?oooooo
ooooooooool00000?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo001<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`18
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01cooooo001<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01cooooo001<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`18ooooo`04o`000?ooooooooooo`00047ooooo00Go
0000ooooooooooooooooo`00000Nooooo`00C?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0BOooool00ol0003oooooo`000011ooooo`05o`000?oo
ooooooooooooool000007_ooool004cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo04Wooooo00?o0000ooooool00000@Oooool01Ol0003ooooooooo
oooooooo000001kooooo001<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooo0000047ooooo00Co0000oooooooooooo0000
7oooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo04[ooooo0_l00011ooooo`04o`000?ooooooooooo`0001oooooo001=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0H?ooool2o`0008kooooo00Co0000oooooooooooo0000
7oooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo08gooooo00Co0000oooooooooooo00007oooool004gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo08kooooo0ol0000Oooooo`00COooool0
1Ol0003ooooooooooooooooo000006?ooooo00?o0000ooooooooool0S_ooool2o`00023ooooo001=
ooooo`05o`000?ooooooooooooooool00000Hoooool00ol0003oooooooooo`2?ooooo`03o`000?oo
oooooooo01kooooo001=ooooo`05o`000?ooooooooooooooool00000F_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0/?ooool004gooooo00Go0000ooooooooooooooooo`00
001Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool004gooooo00Go0000
ooooooooooooooooo`00001Hooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00C_ooool0
1?l0003oooooooooool0001Hooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00C_oo
ool01?l0003oooooooooool0001Hooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool004kooooo00?o0000ooooool00000F_ooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo0;3ooooo001>ooooo`03o`000?oooooo000005[ooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`2`ooooo`00C_ooool00ol0003oooooo`00001Kooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0/?ooool004oooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`
ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o
0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`00
0?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00
oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024oooo
o`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So
0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`Go0000O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooV9RH
ob4Q8Oo^k^koooooodA4A01looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oo
oooooooo01oooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^07gooooo0025ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000gooooo00?oMgMg
oc8b<_ooool00oooool00onHV9So8B4Qonk^kP1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGo
gMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00omg
MgOoIVIVooooo`1kooooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000
ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0
000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko0000
oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool01Ol0003o
^[ZjoooooonHV9So410@07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo
01_ooooo1?l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(54) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16655 m
.00236 .15551 L
.00488 .14624 L
.00726 .13957 L
.00942 .135 L
.01197 .13119 L
.01341 .12966 L
.01473 .12859 L
.01589 .12788 L
.01717 .12731 L
.0185 .12695 L
.01975 .12679 L
.02103 .1268 L
.02176 .12689 L
.02243 .12702 L
.02367 .12739 L
.02499 .12796 L
.02628 .12873 L
.0275 .12963 L
.02978 .13183 L
.03248 .13533 L
.03496 .13944 L
.04057 .15194 L
.06166 .24346 L
.06463 .25763 L
.06744 .269 L
.06899 .27409 L
.07068 .27847 L
.07142 .27999 L
.07221 .28131 L
.07289 .28219 L
.07363 .28289 L
.07434 .2833 L
.07508 .28344 L
.07641 .28299 L
.07715 .28235 L
.07783 .28151 L
.07859 .28032 L
.0794 .27876 L
.08223 .2711 L
.08481 .2618 L
.09504 .21813 L
.09785 .20763 L
.10081 .19806 L
.10338 .19117 L
.10614 .18525 L
.10746 .18294 L
.10872 .18108 L
.10995 .17957 L
.11109 .17842 L
Mistroke
.11216 .17755 L
.11331 .17685 L
.11458 .17631 L
.11572 .17603 L
.11709 .17591 L
.11834 .176 L
.11971 .17626 L
.1204 .17646 L
.12116 .17671 L
.1238 .17789 L
.12627 .1793 L
.13154 .1829 L
.13432 .18488 L
.13727 .18673 L
.13851 .18737 L
.13985 .18793 L
.14061 .18819 L
.14131 .18838 L
.14268 .18864 L
.14385 .18872 L
.14512 .18868 L
.14645 .1885 L
.14768 .18822 L
.1489 .18785 L
.15023 .18735 L
.15263 .18628 L
.15712 .1838 L
.15963 .18225 L
.16232 .18061 L
.16362 .17991 L
.16486 .17936 L
.16597 .179 L
.16718 .17881 L
.16837 .17886 L
.16969 .17927 L
.17106 .18015 L
.17235 .18147 L
.17355 .18318 L
.17466 .18519 L
.17714 .19148 L
.17846 .19591 L
.17969 .2008 L
.18247 .21508 L
.18519 .23401 L
.18809 .26073 L
.19367 .33116 L
.19673 .3758 L
.19959 .41518 L
.20202 .44215 L
.20339 .45321 L
Mistroke
.20464 .46018 L
.206 .46401 L
.20677 .46436 L
.20749 .46349 L
.2088 .45895 L
.20953 .45479 L
.2102 .45008 L
.21158 .43756 L
.21286 .42321 L
.21573 .38353 L
.22094 .30283 L
.2266 .22937 L
.22946 .20207 L
.23259 .1788 L
.23535 .16296 L
.23787 .15165 L
.24078 .1417 L
.24353 .13489 L
.24607 .13043 L
.24842 .12749 L
.251 .12519 L
.25231 .12428 L
.25374 .12345 L
.25495 .12287 L
.25624 .12237 L
.25761 .12198 L
.25888 .12176 L
.26015 .12168 L
.26134 .12175 L
.26242 .12193 L
.26359 .12226 L
.26486 .12277 L
.26627 .1235 L
.26911 .12549 L
.27174 .12787 L
.2742 .1306 L
.27668 .13398 L
.27904 .13794 L
.28346 .14798 L
.28593 .15535 L
.28821 .16339 L
.2934 .1861 L
.30453 .25498 L
.30719 .27289 L
.30999 .29006 L
.31238 .30218 L
.31375 .3077 L
.315 .31168 L
.31621 .31451 L
.31735 .31621 L
Mistroke
.31856 .31697 L
.31987 .31657 L
.32102 .3152 L
.32223 .31277 L
.32326 .30992 L
.32441 .30604 L
.32693 .29506 L
.32965 .2805 L
.33456 .25115 L
.33969 .22258 L
.34516 .19946 L
.34831 .19007 L
.35116 .18383 L
.35254 .18154 L
.35404 .17955 L
.35544 .17812 L
.35674 .17717 L
.35796 .17659 L
.35927 .17627 L
.3605 .17626 L
.36163 .17646 L
.36295 .17695 L
.36369 .17733 L
.36438 .17774 L
.36699 .17978 L
.37225 .18542 L
.37783 .19235 L
.38262 .19802 L
.38523 .20061 L
.38766 .20247 L
.38894 .20319 L
.3903 .20375 L
.39108 .20397 L
.39182 .2041 L
.39319 .20416 L
.39446 .20401 L
.39563 .20369 L
.39691 .20315 L
.39827 .20237 L
.40054 .20062 L
.40299 .19815 L
.4074 .19233 L
.41746 .17492 L
.42809 .15683 L
.4337 .14862 L
.43968 .14133 L
.44543 .13584 L
.45063 .1318 L
.45586 .12852 L
.45841 .12726 L
Mistroke
.46078 .12631 L
.46315 .12555 L
.46568 .12492 L
.46713 .12464 L
.4685 .12444 L
.46972 .1243 L
.47106 .12422 L
.47236 .1242 L
.4731 .12423 L
.47379 .12428 L
.47452 .12436 L
.47519 .12447 L
.47592 .12461 L
.47669 .1248 L
.47798 .12521 L
.47918 .12571 L
.4819 .12726 L
.48443 .12932 L
.48682 .13188 L
.48896 .13482 L
.49129 .13881 L
.49382 .14439 L
.4965 .15196 L
.5013 .17088 L
.51199 .24353 L
.51725 .29193 L
.51957 .3128 L
.52212 .33325 L
.52322 .34066 L
.5244 .34753 L
.52542 .35239 L
.52653 .35647 L
.52772 .35928 L
.52898 .36046 L
.53014 .35989 L
.53122 .35794 L
.53251 .3539 L
.53373 .34849 L
.53601 .33476 L
.54113 .29299 L
.54629 .24813 L
.54912 .22649 L
.55176 .2091 L
.55643 .18565 L
.55891 .1768 L
.56158 .16978 L
.56293 .16712 L
.5644 .16485 L
.56507 .16402 L
.56579 .16326 L
Mistroke
.56708 .16223 L
.56843 .16156 L
.56971 .1613 L
.57086 .16135 L
.5721 .16168 L
.57348 .16236 L
.57427 .16289 L
.575 .16346 L
.57805 .16672 L
.5807 .17053 L
.58353 .17544 L
.59421 .19804 L
.59985 .2094 L
.60294 .21452 L
.60445 .21661 L
.60583 .21824 L
.60703 .21941 L
.60835 .22042 L
.60966 .22115 L
.61105 .22159 L
.61181 .22169 L
.61249 .2217 L
.61329 .22161 L
.61404 .22143 L
.61537 .22089 L
.61612 .22047 L
.61681 .22001 L
.61916 .21794 L
.62174 .2149 L
.62696 .20685 L
.63832 .18615 L
.6491 .16973 L
.65878 .15895 L
.66933 .15033 L
.67958 .14352 L
.6852 .14045 L
.68796 .13912 L
.69049 .13805 L
.6929 .13726 L
.69411 .13697 L
.69544 .13675 L
.69677 .13663 L
.69752 .13662 L
.6982 .13664 L
.69953 .13679 L
.70078 .13706 L
.70191 .13741 L
.7031 .13793 L
.70412 .13849 L
.70525 .13925 L
Mistroke
.70646 .14026 L
.70775 .1416 L
.7101 .14483 L
.71276 .15002 L
.7156 .15781 L
.71827 .16773 L
.7207 .17928 L
.72356 .19651 L
.72666 .22012 L
.73227 .27636 L
.73761 .33837 L
.74053 .36859 L
.74195 .38067 L
.74325 .38958 L
.74445 .39572 L
.74558 .39955 L
.74677 .40138 L
.74807 .40073 L
.7494 .39722 L
.75007 .39438 L
.75082 .39047 L
.75336 .37151 L
.76408 .25208 L
.76946 .20349 L
.77252 .18321 L
.77536 .16859 L
.77799 .15829 L
.78047 .15106 L
.7827 .14639 L
.78396 .14444 L
.78512 .14302 L
.78636 .14187 L
.78753 .14113 L
.78881 .14063 L
.79018 .14044 L
.79087 .14048 L
.79162 .1406 L
.79299 .14106 L
.79432 .14178 L
.79555 .1427 L
.7981 .14537 L
.80086 .14942 L
.80586 .15983 L
.81073 .1732 L
.8152 .1877 L
.82044 .20647 L
.82604 .22646 L
.82875 .23484 L
.83133 .24133 L
.83363 .24568 L
Mistroke
.83494 .24746 L
.83614 .24865 L
.83728 .24937 L
.8385 .24971 L
.83965 .24962 L
.84071 .2492 L
.84188 .24837 L
.84316 .24702 L
.8445 .24517 L
.84574 .24306 L
.85067 .23174 L
.85593 .21692 L
.86178 .20125 L
.86731 .1895 L
.87226 .18169 L
.87506 .17844 L
.87764 .17618 L
.87895 .17529 L
.8802 .17459 L
.88255 .17361 L
.88386 .17321 L
.88508 .1729 L
.88783 .17234 L
.89736 .17048 L
.9002 .16985 L
.90287 .16914 L
.90527 .1683 L
.90786 .16709 L
.91365 .16338 L
.91904 .15977 L
.92153 .15839 L
.92388 .1573 L
.92518 .1568 L
.92659 .15634 L
.92787 .15603 L
.92906 .15586 L
.93037 .15583 L
.93159 .156 L
.93294 .15645 L
.93369 .15686 L
.93439 .15733 L
.93577 .15862 L
.93728 .16062 L
.93871 .16314 L
.94004 .16609 L
.94293 .17484 L
.94565 .18638 L
.9481 .19999 L
.95075 .21881 L
.95364 .24499 L
Mistroke
.9567 .27921 L
.96217 .35163 L
.96471 .38421 L
.96711 .41003 L
.96816 .41892 L
.96927 .42645 L
.97049 .4322 L
.97161 .435 L
.97281 .43524 L
.9741 .43233 L
.97531 .42666 L
.97643 .41912 L
.97766 .40839 L
.97901 .3942 L
.98174 .35991 L
1 .16655 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Yooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?ooool006Kooooo1Ol0000o
ooooo`Co00001oooool00ol0003oooooooooo`2`ooooo`006oooool4o`0004Kooooo0_l00004oooo
o`;o0000>oooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo0;3ooooo000Jooooo`05
o`000?ooooooooooooooool00000AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo0_l0002aooooo`006Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00002boooo
o`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`00000looooo`Co0000L_ooool001Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooo`0003Wooooo1?l00003ooooo`;o00006Oooool00ol0
003oooooooooo`1Dooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00go
oooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Kooooo1?l0001Dooooo`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool00000=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`005oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000=_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1@ooooo`005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo017ooooo0_l0
000dooooo`;o00003Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0D?ooool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0B
ooooo`?o0000<Oooool2o`0000oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Gooooo0_l0000Yooooo`005_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo01?ooooo0_l0000aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo0ol000000ooo
oooo0000o`00000Wooooo`005_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?o
oooo0_l0000Dooooo`?o00006_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09Oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo01?ooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool6o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`03o`000?oooooooooo01Oooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo0_l0
0002ooooo`03o`000?oooooooooo00Oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
0_l00007ooooo`03o`000?oooooooooo00_ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0Cooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Ko0000oiRHV?lQ8B7ok^k^oooooom4A4@3oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool0
4_ooool02?l0003ooooooooooonHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00009ooooo`03
o`000?oooooooooo00cooooo00[o0000ooooooooooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Cooooo
00?o0000ooooooooool02oooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo017ooooo1_l000001_oooooo0000oooooonHV9So8B4Qonk^kPCooooo00Go410@
oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00kooooo1_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01ol@413ooooooooooooooooo410@ooooool000005Oooool01ol0
003oooooooooooooooooV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413o0000o`000002o`0000_ooooo00?o0000ooooooooool02Oooool5o`0000;o
oooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`004oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Foooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Iooooo`07o`000?oooooo
oooooooooonHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo
0000ooooool000005Oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00onYZJWo410@ooooo`02ooooo`Go00004?ooool00ol0003oooooooooo`08ooooo`04odA4
A?oMgMgoooooo`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00cooooo000Cooooo`04omgM
gOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
017ooooo1Ol000001Onj^[[ooooooooooooooooo000000?ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo01;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooooooool2o`0001Oooooo00?o0000ooooooooool00_ooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00cooooo00?o410@o`000?nj^[X00oooool2o`0000;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`08ooooo`04omgMgOmEEEGoooooo`0000?ooooo0_l00003
ooooo`03o`000?oooooooooo00cooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo013ooooo0_l00003ooooo`03okZj^_l0003o
000000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`Co00004oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo000001?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol0003oooooooooo`0Hooooo`;o00004Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
000001Sooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00?ooooo00Co
410@oooooooooooo00002oooool00ol0003oooooooooo`0=ooooo`06okZj^_lQ8B7oooooooooool0
003o410@0oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?oMgMgolc<
c?l000000oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo000Dooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
013ooooo00oo0000ooooool@413oV9RHoooooonj^[[o0000ooooool0003oooooogMgMonHV9Sooooo
oiRHV?mgMgL00ol00003ooooo`03o`000?oooooooooo013ooooo00Oo0000ooooool0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00oo
oooo0_l00004ooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`03o`000?oooooooooo01Wooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?l000006?ooool0
1ol0003oooooo`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`0=oa0@4?nHV9SooooookZj
^_l0003oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00So
oooo00?ok^k^odA4A?l000000oooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`kooooo000Eoooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo00oooooo00Wo0000ooooooooooooZJVYoa0@4?l0003o410@ojVYZOooool00ol000001?lb<S;o
0000oc8b<_l00006ooooo`03o`000?oooooooooo013ooooo00Oo0000oooooonHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool00omEEEGo0000o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool00ol0003oooooooooo`0Iooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?l0003ok^k^
01Sooooo00Oo0000oooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool03OnYZJWo410@
o`000?l@413oZJVYooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003ooooo
ooooo`09ooooo`0;ogMgMol0003oooooooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool002Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`Co00001oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool2
o`00013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01;ooooo000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool2o`00
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01;ooooo000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool2o`0000oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;o
oooo000Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool2o`0000oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
000Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`09ooooo`?o000000?oooooo`000?l000007oooool00ol0003oooooo`00000>ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`005_oooooo
o`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0001?ooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooo
ooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00004oooool002Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooool000003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04_ooool002Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0>
ooooo`;o00000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`009oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo00oooooo1?l0000Rooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`00:?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo000Xooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool002Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0C
ooooo`00:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0<Oooool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool002So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo000Yooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool002Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;o00008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01?ooooo000Yooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool000002_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool3o`00
02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`00:_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Doooo
o`00:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Dooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<_ooool2o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Cooooo000Zooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo000[ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Co
oooo000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0cooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Cooooo000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo000/ooooo`05o`000?oo
ooooooooooooool000008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo
000/ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Dooooo`00;?ooool4o`0002;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Dooooo`00;Oooool2o`0002?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool2o`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo001Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool005;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Eooooo`00D_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Gooooo001Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Ooo
ool005?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`00Doooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000/
ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`00Doooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000/ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`00Doooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000;Oooool00onHV9So8B4Qonk^
kP07ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05Oooool005?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooo000002oooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0E
ooooo`00Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo0ol0000`oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool005?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`;o0000<Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo001Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Boooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool005?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Fooooo`00Doooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000043o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool005?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000010ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo001Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Eoooool2o`0000Gooooo00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Ko
oooo001Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000@?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`00
Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo0000043ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool005?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo001Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`00043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool005?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
0000@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Gooooo`00Doooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000011ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Oooooo001Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05ooo
ool005Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo00Kooooo0_l00011ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo001Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Eoooool2o`0000Oooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Gooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00E?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Gooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`00E?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0G
ooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0B_ooool01Ol0003ooooooooooooooooo000004;ooooo00Go0000ooooooooooooooooo`00
000Jooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0B_ooool01Ol0003ooooooooooooooooo000004;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0B_ooool01?l0003oooooooooool00013ooooo`05o`000?ooooooooooooooool0
00006_ooool005Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`;o0000
Boooool01?l0003oooooooooool00013ooooo`05o`000?ooooooooooooooool000006_ooool005Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04[o
oooo00Co0000oooooooooooo0000@oooool01Ol0003ooooooooooooooooo000001[ooooo001Doooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooo000004Cooooo00Go0000ooooooooooooooooo`00000Jooooo`00EOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Boooool2o`00
04Cooooo00Go0000ooooooooooooooooo`00000Jooooo`00EOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Boooool2o`0004Gooooo00Co0000oooo
oooooooo00006_ooool005Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1?oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
04Cooooo00Co0000oooooooooooo00006_ooool005Gooooo00Go0000ooooooooooooooooo`00001C
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T_ooool01?l0003oooooooooool0
000Jooooo`00EOooool01Ol0003ooooooooooooooooo0000053ooooo1Ol00006ooooo`03o`000?oo
oooooooo09;ooooo00Co0000oooooooooooo00006_ooool005Gooooo00Go0000oooooooooooooooo
o`00001@ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002Booooo`04o`000?ooooooooooo`00
01[ooooo001Eooooo`05o`000?ooooooooooooooool00000D?ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooo00006_ooool005Gooooo00Go0000
ooooooooooooooooo`00001Aooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0T_oo
ool01?l0003oooooooooool0000Jooooo`00EOooool01Ol0003ooooooooooooooooo0000057ooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2Booooo`04o`000?ooooooooooo`0001[o
oooo001Eooooo`05o`000?ooooooooooooooool00000D_ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo09;ooooo00?o0000ooooool000006oooool005Gooooo00Go0000oooooooooooo
ooooo`00001Kooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000006oooool005Kooooo
00Co0000oooooooooooo0000Foooool00ol0003oooooooooo`2Cooooo`;o00006oooool005Kooooo
00Co0000oooooooooooo0000Foooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo01[o
oooo001Fooooo`04o`000?ooooooooooo`0005_ooooo0_l0002aooooo`00E_ooool01?l0003ooooo
ooooool0001Kooooo`03o`000?oooooooooo0;3ooooo001Fooooo`04o`000?ooooooooooo`0005_o
oooo00?o0000ooooooooool0/?ooool005Kooooo00Co0000oooooooooooo0000Foooool00ol0003o
ooooooooo`2`ooooo`00E_ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo0;3o
oooo001Fooooo`04o`000?ooooooooooo`0005_ooooo00?o0000ooooooooool0/?ooool005Kooooo
00?o0000ooooool00000G?ooool00ol0003oooooooooo`2`ooooo`00Eoooool2o`0005cooooo00?o
0000ooooooooool0/?ooool005Oooooo0_l0001Looooo`;o0000/Oooool005Sooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<
c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool0
0:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413o
ZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b
/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000=
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Go0000O?ooool0
08Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3Oooool02?mgMgOo<S8booooooooooooA4A4omgMgOoooooo0000OOooool008Gooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000001;ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00CogMgMoeEEEOoooooo0000OOooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@
4?l0003o000000?o00006_ooool00ol0003oooooooooo`05ooooo`03ogMgMoo<c<co000007gooooo
0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Gooooo00?ok^k^odA4A?l00000OOooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooo
ooooool06oooool4o`0000Gooooo00?oMgMgo`000?ooool0O?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(56) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24027 m
.00236 .21983 L
.00488 .20237 L
.00726 .18967 L
.00942 .18093 L
.01066 .17703 L
.01197 .17369 L
.01341 .1709 L
.01473 .16908 L
.01596 .168 L
.01712 .16748 L
.01839 .16743 L
.01975 .16792 L
.02113 .16895 L
.02241 .17033 L
.02382 .17227 L
.02532 .17478 L
.03062 .18672 L
.04057 .21783 L
.04631 .23575 L
.04933 .24349 L
.05097 .24701 L
.05251 .24978 L
.05398 .25193 L
.05531 .25346 L
.05602 .2541 L
.05679 .25465 L
.0576 .25508 L
.05838 .25535 L
.05974 .25546 L
.06042 .25536 L
.06118 .25512 L
.06252 .2544 L
.06377 .2534 L
.06634 .25051 L
.06905 .24659 L
.07389 .23861 L
.07961 .22981 L
.08211 .22661 L
.08481 .22372 L
.08749 .22148 L
.08996 .21996 L
.09233 .21894 L
.09352 .21854 L
.09483 .21817 L
.09748 .21753 L
.09999 .21687 L
.10138 .21642 L
.10289 .21583 L
.10554 .21446 L
Mistroke
.10804 .21274 L
.11071 .21038 L
.1155 .20462 L
.12039 .19661 L
.12482 .18785 L
.13551 .16547 L
.14134 .15406 L
.14678 .14469 L
.1564 .13283 L
.16149 .12832 L
.16435 .12636 L
.16558 .12569 L
.16695 .12509 L
.16825 .12467 L
.16946 .12441 L
.17075 .12427 L
.17214 .12427 L
.17336 .12438 L
.17464 .12461 L
.17573 .12491 L
.17693 .12533 L
.17836 .12599 L
.17965 .12677 L
.18114 .12795 L
.18255 .12939 L
.18506 .13301 L
.18647 .13578 L
.18778 .13888 L
.19013 .146 L
.19234 .15466 L
.19476 .16675 L
.19735 .18332 L
.20007 .20566 L
.20265 .23256 L
.20748 .29944 L
.2127 .38666 L
.21525 .42607 L
.2176 .45451 L
.2188 .46495 L
.22006 .47244 L
.22133 .47604 L
.22271 .47532 L
.22345 .47294 L
.22413 .46962 L
.2249 .46444 L
.22564 .45831 L
.22836 .42655 L
.23756 .28096 L
.24008 .2479 L
.24279 .21914 L
Mistroke
.24535 .198 L
.24769 .183 L
.25019 .17073 L
.25151 .16558 L
.25292 .16102 L
.25427 .15747 L
.25549 .15492 L
.25672 .15295 L
.25788 .15161 L
.2592 .15065 L
.26059 .15021 L
.26177 .15025 L
.26307 .15068 L
.2638 .15108 L
.26447 .15154 L
.26597 .15285 L
.26868 .15612 L
.27116 .16009 L
.27345 .16466 L
.27863 .17868 L
.2832 .19512 L
.28805 .21542 L
.2979 .25864 L
.30059 .26887 L
.30207 .27369 L
.30343 .27756 L
.3047 .28058 L
.30586 .28278 L
.30714 .28461 L
.30851 .28583 L
.30971 .28628 L
.31098 .28613 L
.31206 .28554 L
.31325 .28442 L
.31453 .28271 L
.3159 .28037 L
.31839 .27504 L
.32771 .24908 L
.33287 .23596 L
.33575 .23038 L
.33836 .22662 L
.33985 .225 L
.34146 .22365 L
.34298 .22271 L
.3437 .22237 L
.34438 .2221 L
.34567 .22171 L
.34636 .22157 L
.34709 .22146 L
.34786 .22139 L
Mistroke
.34859 .22136 L
.34996 .22139 L
.35117 .22149 L
.35251 .22167 L
.35522 .22215 L
.35643 .22237 L
.35773 .22257 L
.35896 .2227 L
.36008 .22275 L
.36075 .22273 L
.36147 .22267 L
.36277 .22244 L
.36357 .22222 L
.36431 .22193 L
.36571 .22123 L
.36705 .22032 L
.36828 .21928 L
.37107 .21624 L
.376 .20883 L
.38128 .19873 L
.39083 .17729 L
.40209 .1543 L
.41252 .13846 L
.41769 .13281 L
.42319 .12823 L
.42871 .12456 L
.43189 .12285 L
.43481 .12161 L
.43736 .12079 L
.44005 .12015 L
.44275 .11966 L
.4443 .11943 L
.4457 .11926 L
.44693 .11913 L
.44826 .11903 L
.449 .11898 L
.44967 .11896 L
.451 .11894 L
.45214 .11898 L
.4534 .11907 L
.45471 .11922 L
.45593 .11942 L
.45725 .1197 L
.45864 .12006 L
.46116 .12086 L
.46409 .12202 L
.46685 .12336 L
.46947 .12492 L
.4723 .12704 L
.47723 .13215 L
Mistroke
.47958 .13533 L
.48216 .13943 L
.48737 .15001 L
.49219 .16355 L
.49669 .18046 L
.50619 .23101 L
.51628 .29543 L
.51882 .30875 L
.52015 .31459 L
.52155 .3197 L
.5223 .32195 L
.52311 .32401 L
.52386 .32553 L
.52454 .32658 L
.52525 .32734 L
.526 .32778 L
.52735 .32763 L
.52867 .32635 L
.52988 .32422 L
.53121 .32094 L
.53262 .3165 L
.53758 .29515 L
.54271 .2694 L
.54822 .24449 L
.55138 .23315 L
.55427 .22504 L
.55566 .22188 L
.55717 .21898 L
.55858 .21674 L
.55992 .21501 L
.56123 .21365 L
.56244 .21267 L
.56378 .21186 L
.56449 .21155 L
.56523 .2113 L
.56591 .21113 L
.56663 .21102 L
.56793 .21098 L
.56873 .21104 L
.56948 .21116 L
.57016 .21132 L
.57089 .21154 L
.57211 .212 L
.57345 .21263 L
.57617 .21421 L
.58105 .21741 L
.58366 .21896 L
.58504 .21966 L
.58651 .22028 L
.58792 .22076 L
Mistroke
.5892 .22108 L
.59049 .22128 L
.5917 .22137 L
.59288 .22134 L
.59414 .22119 L
.59521 .22097 L
.59638 .2206 L
.59764 .22007 L
.599 .21934 L
.60144 .21757 L
.60426 .21481 L
.60733 .211 L
.61291 .2025 L
.62336 .18381 L
.64372 .14966 L
.6493 .14239 L
.65531 .13591 L
.66051 .13137 L
.66619 .12714 L
.66882 .12545 L
.67162 .1239 L
.67667 .12181 L
.67965 .12094 L
.68245 .12031 L
.68368 .12008 L
.68498 .11988 L
.68565 .11979 L
.6864 .11971 L
.68771 .11962 L
.68902 .1196 L
.69027 .11965 L
.6914 .11977 L
.69262 .11999 L
.69395 .12032 L
.69536 .1208 L
.6979 .12198 L
.70048 .12362 L
.7029 .12563 L
.70508 .12789 L
.70743 .13098 L
.70993 .13521 L
.71261 .1411 L
.71514 .14821 L
.71744 .15621 L
.72014 .16771 L
.72308 .18314 L
.72841 .22033 L
.73894 .32225 L
.74183 .34832 L
.74342 .36022 L
Mistroke
.74493 .36935 L
.74633 .37558 L
.74713 .37809 L
.74786 .37972 L
.74916 .38095 L
.75055 .37994 L
.75123 .37857 L
.75195 .37653 L
.75324 .3714 L
.75463 .36398 L
.75616 .35389 L
.76146 .3095 L
.76663 .26525 L
.77136 .2337 L
.77418 .21999 L
.77686 .21039 L
.77833 .20639 L
.77969 .20343 L
.78118 .20094 L
.78194 .19996 L
.78277 .19909 L
.78415 .1981 L
.78541 .19765 L
.78608 .19758 L
.7868 .19763 L
.78756 .19781 L
.78827 .19809 L
.78957 .19886 L
.79076 .19982 L
.79343 .20267 L
.8032 .2164 L
.80855 .22317 L
.81116 .22581 L
.81356 .2277 L
.81489 .22851 L
.81616 .22911 L
.8175 .22955 L
.81826 .22972 L
.81896 .22983 L
.81974 .22989 L
.82047 .22989 L
.82184 .22977 L
.82261 .22964 L
.82332 .22948 L
.82491 .22901 L
.82734 .22805 L
.83001 .22675 L
.83539 .22359 L
.84592 .21564 L
.85589 .20647 L
Mistroke
.8614 .19962 L
.86739 .19062 L
.87786 .17285 L
.88858 .15409 L
.89864 .13985 L
.90412 .13343 L
.90914 .12885 L
.91471 .1252 L
.91785 .12355 L
.92071 .1223 L
.92194 .12186 L
.92328 .12148 L
.92453 .12121 L
.9257 .12106 L
.92693 .121 L
.92828 .12107 L
.92896 .12116 L
.9297 .1213 L
.93102 .12164 L
.93225 .12208 L
.93359 .12268 L
.93603 .12412 L
.9384 .12606 L
.9406 .12849 L
.94197 .13041 L
.94345 .13292 L
.94613 .13888 L
.94874 .14679 L
.95114 .15624 L
.95374 .16927 L
.95659 .18744 L
.95957 .2116 L
.96234 .23957 L
.9672 .30073 L
.97248 .37348 L
.9749 .40176 L
.97622 .41421 L
.97746 .4234 L
.97851 .4291 L
.97965 .43289 L
.98091 .43414 L
.98206 .43254 L
.98316 .42859 L
.98434 .42192 L
.98545 .4135 L
.98646 .40428 L
.99126 .34643 L
1 .24028 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Pooooo`[o00002oooool00ol0003oooooooooo`0fooooo`Ko0000B?ooool3o`0002Wooooo001;
ooooo`?o0000D?ooool2o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo03Cooooo0_l00006
ooooo`;o0000A?ooool2o`0000;ooooo0ol0000Wooooo`00B_ooool2o`0000;ooooo0_l0001=oooo
o`03o`000?oooooooooo00_ooooo0_l00008ooooo`03o`000?oooooooooo03;ooooo0_l00009oooo
o`;o0000@Oooool2o`0000Kooooo00?o0000ooooooooool09Oooool004Sooooo0_l00006ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`;o
0000<_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool01oooool2o`0002Gooooo0017ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
;oooool2o`0000kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02?ooooo0017ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Sooooo`00A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool08_ooool004Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo0014ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`00A?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool004?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`Co0000;?ooool00ol0003ooooooooo
o`0Gooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`00@ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooooooo
o`00000Zooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooooooo0_l0000[ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo023ooooo0013ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4Oooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000002_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool004;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0002_ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool08?ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^
kPgooooo00?o0000ooooooooool02oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0L
ooooo`Co000000Go410@ooooooooooook^k^oc8b<P02o`000003onk^k_oooooooooo01Wooooo00Co
0000oooooooooooo00008Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hH
ooooo`03o`000?oooooo000000Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00ol0003o
ooooooooo`07ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool2o`000003oooooonHV9SoMgMg01[ooooo00Go410@
okZj^_ooooooMgMgoc8b<P02ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg3Oooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?lQ8B7ok^k^ooooool000000oooool01OmgMgOoV9RHooooool0003o
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg01_ooooo00Co
0000oooooooooooo00008oooool00ol0003oooooooooo`02ooooo`05ogMgMol0003ooooooiRHV?mg
MgL06?ooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mg
MgL04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00002ooooo`06o`000?l@413o0000o`00
0?oooooo410@4_ooool6o`0000Kooooo00Go0000ooooool0003ooooooa0@4003ooooo`03oa0@4?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?oV9RHob4Q8Ol000001?oo
ool01Ol@413oooooooooool0003o410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@o`000?oooooooooooa0@400Looooo`03o`000?oooooo000002?ooooo00?o0000oooooooo
ool00_ooool01Ol@413o0000oooooooooooo410@01Sooooo00Ko0000ooooooooooooV9RHob4Q8Oo^
k^h4ooooo`05oa0@4?ooooooooooooooool@41007oooool01_l0003ooooooooooooooooo410@o`00
00;ooooo00?o410@ooooooooool04Oooool00ol0003oooooooooo`05ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000;ooooo00Co0000
ooooool0003ooooo0ol0000Mooooo`06ojVYZOl@413oooooo`000?oooooo00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?oV9RHo`000?o^k^h00oooool01Ol0003o
oooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Hooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooooooo
ool000004oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00002ooooo`03o`000?oo
oooo000000;ooooo0_l0000Looooo`04oa0@4?l0003o^[Zjo`0000;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001cooooo00?o0000ooooool000008oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000006Oooool01_l0003oooooooooooooooooMgMgofIVIP?ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000C
ooooo`03o`000?oooooooooo00Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000;ooooo00?o0000ooooool@41000_oo
ool00ol0003o410@ooooo`0Looooo`03okZj^_lQ8B7o000000;ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`05oa0@4?ooooooooooooooool0
00007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41007Oooool3o`00
02;ooooo00Ko0000ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo01Oooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
7?ooool01_nj^[[o8B4Qoooooooooooo0000oa0@40?ooooo00?o410@ooooooooool04_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`005?ooool00oo^k^koA4A4o`000002ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHo`00
000Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjooooool0003o410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHo`00000Nooooo`0:o`000?ooooooooooooooool0003oMgMgoiRHV?ooooooV9RHogMg
Magooooo0_l0000Sooooo`0:o`000?ooooooooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgMaWo
oooo0_l000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
3Ol@413oV9RHoooooonj^[[o0000ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL05?ooool0
0ol0003oooooooooo`05ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`005Oooool01?mgMgOo0000ooooool00002ooooo`05onk^k_lb<S;o0000oc8b<_l00000
6_ooool01OnYZJWo410@o`000?l@413o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o0000olc<c003ooooo`06onk^k_lb<S;o
0000oc8b<_o^k^ko00006oooool00omEEEGoIVIVo`000003ooooo`06o`000?o^k^ko<S8bo`000?lb
<S;ok^k^7Oooool2o`00027ooooo00?oEEEEofIVI_l000000_ooool01ol0003oooooonk^k_lb<S;o
0000oc8b<_o^k^h06Oooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Kooooo`0=ojVYZOl@413o0000oa0@4?nYZJWoooooo`000?ooooook^k^oc8b<_l0
003o<S8bonk^kP0Dooooo`03o`000?oooooooooo00Kooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo000Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo027ooooo0_l0000Uoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01oooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Oooooo`006?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07oooool001Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03ooo
ool3o`0001Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`005oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01kooooo000Foooooooo0000@?l0000Cooooo`005_ooool2o`00
00Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`;o00001Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo000Fooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool5o`0000Oooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04Oooool2o`0001gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09_ooool2o`00017ooooo
00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01kooooo000Fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool4o`0001kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09_ooool2o`00013ooooo0_l0
0006ooooo`;o00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool07_ooool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo1Ol000001?oooooo0000o`000?l0000Yooooo`;o00004?oo
ool00ol0003oooooooooo`06ooooo`Go0000:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01kooooo000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`;o00000oooool3o`0002_ooooo00?o0000ooooool000003_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`005_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o0000:Oooool00ol0
003oooooooooo`0Mooooo`005_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000000go
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo1?l0000[ooooo`03o`000?oooooooooo01gooooo000Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo
0ol0000=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo01gooooo000Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Mooooo`005_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0A
ooooo`009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0<oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04Oooool002Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo017ooooo000Vooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`009oooool00ol0003oooooooooo`02o`00
02_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool002Sooooo0ol0000/ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo017ooooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000ooooo`09oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool005Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04_ooool005Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`00Eoooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0fooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01;ooooo001Gooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool005Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Booooo`00Eoooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo001Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool0000jooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01;ooooo001Gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04oooool01?l0003oooooo`000?l0000jooooo`;o00000_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool005Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Dooooo`;o0000>oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Boooo
o`00F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool005Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01;ooooo001Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`00F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`16ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`00F?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo001Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0B?ooool00onHV9So8B4Qonk^kP07ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`19ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4oooool005Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1:ooooo`03ogMgMomV
IVKooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000047ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo0000047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`17ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`00047ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool005Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`17ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000004;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04oooool005Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Gooooo0_l00012ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo001Hooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo001Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D_ooool2
o`0004[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05?ooool005Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool005So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05?ooool005Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`000014ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04[ooooo00Go0000oooooooooooo
ooooo`000014ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04[ooooo
00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool005Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo04[ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`000014ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04[ooooo00Go0000oooooooooooo
ooooo`000014ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`;o0000Boooool01Ol0003ooooo
oooooooooooo000004Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`00
FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
Boooool01?l0003oooooooooool00014ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool005Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo04_ooooo00Co0000oooooooooooo0000A?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Cooooo001Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Dooooo`00FOooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool00014ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04cooooo0_l00015ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05Oooool005Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04cooooo0_l00015ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool005Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Eooooo`00FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
05?ooooo0_l0002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool005Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09Co
oooo00Go0000ooooooooooooooooo`00000Gooooo`00FOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0U?ooool01Ol0003ooooooooooooooooo0000
01Oooooo001Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`2Dooooo`05o`000?ooooooooooooooool000005oooool005Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09Cooooo00Go0000oooooooo
ooooooooo`00000Gooooo`00FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[o
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo09Cooooo00Go0000oooooooo
ooooooooo`00000Gooooo`00FOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`05o`000?oooooooooooooo
ool000005oooool005[ooooo00Go0000ooooooooooooooooo`00001;ooooo`Go00001_ooool00ol0
003oooooooooo`2Dooooo`04o`000?ooooooooooo`0001Sooooo001Jooooo`05o`000?oooooooooo
ooooool00000Boooool01?m4A4CogMgMooooool00007ooooo`?o0000U?ooool01?l0003ooooooooo
ool0000Hooooo`00F_ooool01Ol0003ooooooooooooooooo000004_ooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`2Dooooo`04o`000?ooooooooooo`0001Sooooo001Jooooo`05
o`000?ooooooooooooooool00000C?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
09Cooooo00Co0000oooooooooooo00006?ooool005[ooooo00Go0000ooooooooooooooooo`00001<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0UOooool00ol0003oooooo`00000H
ooooo`00F_ooool01Ol0003ooooooooooooooooo000004gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooo000001Sooooo001Jooooo`05o`000?oooooooooo
ooooool00000E_ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooo000001Sooooo001Joooo
o`05o`000?ooooooooooooooool00000E_ooool00ol0003oooooooooo`2Eooooo`;o00006Oooool0
05[ooooo00Go0000ooooooooooooooooo`00001Fooooo`03o`000?oooooooooo09Kooooo00?o0000
ooooooooool05oooool005[ooooo00Go0000ooooooooooooooooo`00001Fooooo`;o0000/Oooool0
05_ooooo00Co0000oooooooooooo0000E_ooool00ol0003oooooooooo`2`ooooo`00Foooool01?l0
003oooooooooool0001Fooooo`03o`000?oooooooooo0;3ooooo001Kooooo`04o`000?oooooooooo
o`0005Kooooo00?o0000ooooooooool0/?ooool005_ooooo00Co0000oooooooooooo0000E_ooool0
0ol0003oooooooooo`2`ooooo`00Foooool01?l0003oooooooooool0001Fooooo`03o`000?oooooo
oooo0;3ooooo001Kooooo`04o`000?ooooooooooo`0005Kooooo00?o0000ooooooooool0/?ooool0
05_ooooo00Co0000oooooooooooo0000E_ooool00ol0003oooooooooo`2`ooooo`00Foooool01?l0
003oooooooooool0001Fooooo`;o0000/Oooool005_ooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`2`ooooo`00Foooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo0;3o
oooo001Looooo`;o0000Eoooool00ol0003oooooooooo`2`ooooo`00G?ooool2o`0005Oooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@
413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool0
0:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o
^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@
o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0O?ooool008Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8b
ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooEEEEogMgMooo
ooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_o
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1jooooo`00QOooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000=ooooo`09ogMg
Molb<S;oooooooooool0003oV9RHoooooonHV9So8B4Q07cooooo0025ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@
4?l0003o000000?o00006_ooool00ol0003oooooooooo`04ooooo`03oeEEEOn7QhOooooo07kooooo
0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Cooooo00?ogMgMoa0@4?nHV9P0O_ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooo
ooooool06oooool4o`0000Cooooo00Coc<c<odA4A?l0003o410@O?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3493 m
.00942 .30865 L
.01975 .27141 L
.02496 .25741 L
.03053 .24511 L
.03575 .23578 L
.03804 .23241 L
.04057 .22934 L
.0419 .22802 L
.04334 .22687 L
.04413 .22636 L
.04486 .22597 L
.04558 .22565 L
.04628 .22543 L
.04702 .22527 L
.04781 .2252 L
.04856 .22523 L
.04924 .22533 L
.05004 .22554 L
.05091 .22589 L
.05172 .22633 L
.05248 .22683 L
.05508 .22922 L
.05657 .23102 L
.05795 .23296 L
.06373 .24317 L
.06896 .25323 L
.07153 .25742 L
.07266 .25893 L
.0739 .26032 L
.07523 .26141 L
.07595 .26183 L
.07664 .26209 L
.07738 .26224 L
.07807 .26224 L
.07882 .26209 L
.07961 .26175 L
.08089 .26081 L
.08209 .25949 L
.08341 .25756 L
.08481 .25496 L
.08753 .24846 L
.0904 .23976 L
.09556 .22097 L
.10722 .17703 L
.11208 .16222 L
.1173 .14935 L
.12302 .13869 L
.12838 .13161 L
.13105 .12893 L
Mistroke
.1339 .12655 L
.13636 .12485 L
.13902 .12332 L
.14215 .12194 L
.14359 .12144 L
.1451 .12101 L
.14647 .12069 L
.14798 .12041 L
.14934 .12021 L
.15061 .12007 L
.15193 .11996 L
.15262 .11991 L
.15336 .11987 L
.1547 .11982 L
.15595 .1198 L
.15714 .11981 L
.15826 .11984 L
.15949 .1199 L
.16081 .12 L
.16214 .12015 L
.16359 .12036 L
.16651 .12093 L
.17172 .12237 L
.1744 .12326 L
.17729 .12439 L
.17984 .12558 L
.18254 .12712 L
.18765 .13111 L
.19235 .13629 L
.19497 .14 L
.19778 .14494 L
.20284 .15753 L
.20594 .16842 L
.20887 .18163 L
.21437 .21581 L
.21917 .25793 L
.22449 .31699 L
.22966 .37691 L
.23108 .3912 L
.23257 .40432 L
.23386 .4137 L
.23524 .42138 L
.23654 .42617 L
.23771 .42842 L
.23889 .42861 L
.24 .42692 L
.2413 .42275 L
.2425 .41696 L
.24382 .40871 L
.24521 .39816 L
Mistroke
.25458 .31106 L
.25723 .29034 L
.25974 .27432 L
.262 .26301 L
.26447 .25377 L
.26587 .24981 L
.26714 .24695 L
.26861 .24443 L
.26999 .24274 L
.27127 .24171 L
.27245 .24115 L
.27374 .24093 L
.27511 .24105 L
.2763 .24141 L
.27739 .24189 L
.27985 .2433 L
.28427 .24601 L
.28547 .24659 L
.28674 .2471 L
.28741 .24731 L
.28814 .2475 L
.28944 .24772 L
.29065 .24779 L
.29196 .24772 L
.29319 .24753 L
.29433 .24726 L
.29927 .24523 L
.30394 .2428 L
.3052 .24223 L
.30653 .24173 L
.30722 .24152 L
.30798 .24134 L
.30932 .24116 L
.31054 .24118 L
.31185 .24141 L
.31308 .24185 L
.31421 .24245 L
.31565 .24348 L
.31698 .24471 L
.31999 .2484 L
.32548 .25755 L
.32813 .26246 L
.33094 .26736 L
.33219 .26932 L
.33353 .27117 L
.33478 .27261 L
.33595 .27367 L
.33729 .27448 L
.33851 .27481 L
.33985 .27468 L
Mistroke
.34061 .27436 L
.34131 .27391 L
.34264 .27261 L
.3434 .27162 L
.34411 .27052 L
.34709 .26425 L
.34972 .25663 L
.35213 .24829 L
.35756 .2265 L
.36702 .18751 L
.37222 .16948 L
.37711 .15571 L
.38253 .14391 L
.38744 .13585 L
.39205 .13023 L
.39704 .12589 L
.39966 .12419 L
.40255 .12269 L
.40556 .1215 L
.407 .12105 L
.40837 .12069 L
.40963 .12042 L
.411 .12018 L
.41225 .12003 L
.4134 .11993 L
.41464 .11986 L
.41602 .11985 L
.41671 .11986 L
.41745 .11989 L
.41879 .11997 L
.42011 .12009 L
.42131 .12023 L
.424 .12067 L
.42649 .1212 L
.42884 .12183 L
.43411 .12369 L
.43983 .12636 L
.45135 .13352 L
.46198 .14249 L
.47215 .1536 L
.48167 .16784 L
.48713 .17853 L
.49212 .19053 L
.50334 .22622 L
.51301 .26181 L
.51579 .27093 L
.51841 .27831 L
.52076 .28364 L
.52208 .286 L
.5233 .28779 L
Mistroke
.52467 .28927 L
.52539 .28985 L
.52617 .2903 L
.52698 .29059 L
.52775 .2907 L
.52844 .29067 L
.52919 .29049 L
.53055 .28981 L
.53124 .2893 L
.532 .28862 L
.5346 .28546 L
.54001 .27626 L
.54508 .26713 L
.54747 .26344 L
.55002 .26025 L
.55149 .25882 L
.55282 .25778 L
.55416 .25698 L
.55542 .25646 L
.55674 .25613 L
.55741 .25604 L
.55814 .256 L
.55943 .25606 L
.56064 .25624 L
.56137 .25641 L
.56207 .25659 L
.56337 .25699 L
.5663 .25797 L
.56751 .25834 L
.56864 .25861 L
.56982 .2588 L
.57113 .25886 L
.57225 .25876 L
.57328 .25852 L
.57441 .25808 L
.5756 .2574 L
.57681 .25645 L
.57811 .25515 L
.58044 .252 L
.58322 .24691 L
.58574 .2411 L
.59632 .2086 L
.60754 .17271 L
.61712 .14946 L
.62257 .13977 L
.62767 .13273 L
.63288 .12728 L
.63782 .12344 L
.64226 .12089 L
.64478 .11978 L
Mistroke
.64711 .11894 L
.64842 .11855 L
.64984 .1182 L
.6511 .11794 L
.65242 .11771 L
.65361 .11756 L
.65492 .11743 L
.65612 .11736 L
.65723 .11733 L
.6579 .11733 L
.65863 .11734 L
.65995 .1174 L
.66124 .1175 L
.66244 .11763 L
.66372 .11781 L
.66514 .11807 L
.66802 .11878 L
.67048 .11959 L
.67318 .12069 L
.67862 .12364 L
.68365 .12729 L
.68834 .13159 L
.69893 .14515 L
.70485 .15532 L
.71024 .16643 L
.72072 .19383 L
.73039 .22688 L
.74167 .2746 L
.74719 .29831 L
.7496 .30762 L
.75223 .31641 L
.75345 .31988 L
.75476 .32308 L
.75588 .32538 L
.7571 .32735 L
.75835 .32879 L
.75953 .32958 L
.76068 .32981 L
.76173 .32956 L
.76295 .32871 L
.7641 .32739 L
.76535 .32539 L
.76669 .32263 L
.76944 .31528 L
.77193 .307 L
.7774 .28604 L
.7832 .26414 L
.78815 .24904 L
.79097 .24259 L
.79223 .24025 L
Mistroke
.79361 .2381 L
.79495 .2364 L
.7962 .23517 L
.79739 .2343 L
.79866 .23369 L
.79991 .23339 L
.80108 .23338 L
.80214 .23358 L
.80328 .23399 L
.80454 .23468 L
.80592 .23567 L
.8087 .23828 L
.81369 .24395 L
.81649 .2469 L
.81786 .24811 L
.81913 .24902 L
.81983 .24943 L
.8206 .24979 L
.82137 .25005 L
.82219 .2502 L
.82288 .25024 L
.82362 .25017 L
.82497 .24975 L
.82625 .249 L
.82697 .24841 L
.82765 .24775 L
.83047 .24393 L
.8329 .23925 L
.83551 .23299 L
.84565 .20105 L
.8564 .16723 L
.86201 .15322 L
.86818 .1412 L
.8738 .1331 L
.87905 .12749 L
.88165 .12531 L
.88447 .12331 L
.88696 .12185 L
.88962 .12056 L
.89225 .11953 L
.89463 .11879 L
.89702 .1182 L
.89927 .11778 L
.90054 .11759 L
.90192 .11743 L
.90262 .11737 L
.90337 .11732 L
.90472 .11725 L
.90606 .11723 L
.90733 .11725 L
Mistroke
.90848 .11729 L
.90972 .11738 L
.91107 .11752 L
.91256 .11771 L
.91559 .11828 L
.91838 .119 L
.92101 .11987 L
.92595 .12211 L
.92875 .1238 L
.93135 .12571 L
.93661 .13074 L
.94222 .13838 L
.94747 .14845 L
.95241 .16153 L
.95685 .17708 L
.96166 .19883 L
1 .3493 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02cooooo
1_l00019ooooo`Oo0000;_ooool004?ooooo2Ol0001;ooooo`Oo00005oooool00ol0003ooooooooo
o`0Zooooo`?o00001Oooool4o`0004?ooooo0ol00006ooooo`;o0000;?ooool0047ooooo0ol00008
ooooo`?o0000A_ooool2o`0000Oooooo1?l0000Cooooo`03o`000?oooooooooo02Sooooo0_l0000<
ooooo`03o`000?oooooooooo03kooooo0_l0000;ooooo`;o0000:_ooool0043ooooo00?o0000oooo
ooooool03?ooool2o`0004?ooooo00?o0000ooooooooool02oooool2o`00017ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03Oooool2o`0002Sooooo000oooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo0_l0000Xooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Gooooo000oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0@ooooo`;o00003_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02Gooooo000nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Tooooo`00?Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool08oooool003gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo000looooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`00>oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08_ooool003_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02;ooooo000j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Kooooo0_l0000Rooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo027ooooo000joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Qoooo
o`00>Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool08?ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0I
ooooo`06o`000?nHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013o
oooo00?o0000ooooooooool02?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQOooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kQCooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?o
oooo00?o0000ooooooooool01oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Iooooo`06o`000?l@413o^[ZjoooooomgMgOo<S8b0oooool01OmgMgOoV9RHoooooonHV9SoMgMg
013ooooo00?o0000ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o0000oooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko0000
0_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Oo00001Oooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`06o`00
00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00004
ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@01Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Pooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@01Gooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41007?ooool01?l0003oooooooooool00003ooooo`05oa0@4?ooooooooooooooool@41005?ooool0
0ol0003oooooooooo`04ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000C
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`00
0?oooooooooo00;ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000013o
oooo00?o0000ooooooooool02_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000007Oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07oooool00ol0003oooooo`000004ooooo`05o`000?oooooo
ooooooooool000005_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Looooo`04o`000?ooooooZJVYoa0@40?ooooo00Go0000oooooooo
ooooooooo`00000Dooooo`03o`000?oooooooooo00Cooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000Hooooo`07o`000?ooooooooooooooool@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0:ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`;o00001?ooool01Ol0003ooooooooo
oooooooo000001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooo000000Cooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Co
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00Go0000oooo
ool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003ooooooooo
o`04ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`00
5?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41006?ooool00ol0003o
ooooooooo`02ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Aoooo
o`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo01[ooooo00?o0000ooooool000001?ooool01Ol@413ooooooooooooooooo410@01[ooooo00Co
0000oooooooooooooooo0_l0000Pooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooo
oooooa0@400Fooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01Wooooo00Go0000oooooooooooo^[Zjob4Q8@03ooooo`05oa0@4?oooooo
ooooooooool@41005?ooool00ol0003oooooooooo`05ooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06?ooool01ol0003ooooooa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg017ooooo00?o0000ooooooooool01oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03o`000?oooooo000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?ooooooooooooooool000008?ooool01?l0
003oooooooooool00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool02?l0003ooooooooo
ool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003ooooo
ooooo`05ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
5Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool02?l0003o
oooooooooonYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo
00?o0000ooooooooool01oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Looooo`03o`000?mVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0K
ooooo`04o`000?ooooooooooo`00023ooooo00Co0000oeEEEOmVIVKo00001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Oooooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Jooooo`06o`000?nYZJWo410@o`000?l@413oZJVY0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01Gooooo00?o0000ooooooooool01Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00008?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Nooooo`00=oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000Oooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01kooooo000fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooo000001oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool0
03Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooool000007oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`00=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooo`00000Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo01gooooo000Foooooooo0000@?l0000Cooooo`005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`0Aooooo`00=Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01cooooo000dooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07?ooool003Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`00
9Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Zooooo`;o00006oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`008ooo
ool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo02[ooooo0_l0000Kooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo000S
ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0:_ooool2o`0001_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06ooo
ool002;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`;o00006_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo0ol00009ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool06_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00ko
oooo00Co0000ooooool0003o00001_ooool5o`0000cooooo00?o0000ooooooooool0:oooool00ol0
003oooooo`00000Hooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Jooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000o`000?l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0;?ooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;Ooo
ool00ol0003oooooooooo`0Iooooo`007oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool0
1?l0003oooooooooool0000Fooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`06ooooo`Co0000;_ooool00ol0003oooooooooo`0Iooooo`007oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool06Ooo
ool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;Oooool01?l0003oooooooooool0000>ooooo`?o00000ooo
ool2o`00037ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo01Wooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool2
o`0000;ooooo1Ol0000cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`0<ooooo`?o0000:oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0H
ooooo`007Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo000Mooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo0000<Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool05oooool001co
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Go
oooo1?l0000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Gooooo`007?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool05oooool001_ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1:ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000012ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Fooooo`006oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`05ooooo`?o0000@oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool05_ooool001[o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool05_ooool001[ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool05Oooool001[ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool05Oooool001[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo043ooooo1Ol00006ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Gooooo000Ioooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`10oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Eooooo`006Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool00onH
V9So8B4Qonk^kP07ooooo`?o0000C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool05?ooool001Wooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04;ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Dooooo`006Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Cooooo
000Hooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05?ooool001Sooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo043ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04kooooo00Go0000oooooooooooooooo
o`000017ooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`10ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1>ooooo`04o`000?ooooooooooo`0004Sooooo00?o0000oooooooo
ool04oooool001Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`000018ooooo`03o`00
0?oooooooooo01?ooooo000Gooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Cooooo`005oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0C?ooool2o`0009cooooo00?o0000ooooooooool04_ooool0
01Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`005oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0Aooooo`005_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo017ooooo001Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2`oooo
o`00G_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0/?ooool005kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo0;3ooooo001Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0COoo
ool2o`000;7ooooo001Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`2`ooooo`00Goooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0/?ooool005oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo0;3ooooo001Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`2`ooooo`00Goooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0/?ooool005oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0;3ooooo001Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2`oooo
o`00Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo0_l0002aooooo`00
Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
/?ooool005oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo0;3ooooo001Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`2`ooooo`00H?ooool01Ol0003ooooooooooooooooo0000053ooooo00?o0000
ooooooooool0/?ooool0063ooooo00Go0000ooooooooooooooooo`000017ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00H?ooool01?l0003oooooooooool00019
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool0063ooooo00Co0000oooo
oooooooo0000A_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool0063ooooo00Co0000oooo
oooooooo0000A_ooool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool0063ooooo00Co0000
oooooooooooo0000A_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo
001Qooooo`03o`000?oooooo000004Oooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`2`ooooo`00HOooool00ol0003oooooo`000017ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0/?ooool0067ooooo00?o0000ooooool00000B?ooool00omgMgOo0000ooooo`06oooo
o`03o`000?oooooooooo0;3ooooo001Qooooo`;o0000D_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_oo
ool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000
^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool0
0ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wo
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool02OmgMgOo<S8boooooooooooo8B4Q
oiRHV?ooooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oo
oooooooo01oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1jooooo`00QOoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000=oooo
o`09ogMgMolb<S;ooooooooooolb<S;oV9RHoooooonHV9So<S8b07cooooo0025ooooo`06o`000?oM
gMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooo
ooooooooooooo`00000Booooo`03o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05olc<c?l0003o0000o`000?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[Zj
oeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@oooo
o`03oa0@4?l0003o000000?o00006_ooool00ol0003oooooooooo`04ooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100O?ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool01Ol0003o^[Zjoooooonj^[[o000007cooooo0024ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo1?l00003ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .316 m
.04057 .26122 L
.05077 .28816 L
.05346 .29776 L
.05488 .30237 L
.05638 .30664 L
.05769 .30969 L
.05839 .31101 L
.05914 .31216 L
.06045 .31348 L
.06168 .31384 L
.06248 .3136 L
.06336 .31289 L
.06419 .31179 L
.06496 .31041 L
.06641 .30683 L
.06795 .30171 L
.07094 .28845 L
.07365 .2735 L
.08481 .20546 L
.08981 .18071 L
.09509 .16078 L
.09785 .15275 L
.10088 .14558 L
.10366 .14029 L
.1062 .1364 L
.11123 .13076 L
.114 .12857 L
.11663 .12698 L
.11905 .12586 L
.12129 .12507 L
.12375 .12444 L
.12499 .12419 L
.12636 .12398 L
.12755 .12383 L
.12882 .1237 L
.12956 .12364 L
.13022 .1236 L
.13152 .12354 L
.13286 .12351 L
.13362 .12351 L
.13432 .12352 L
.1356 .12355 L
.13696 .12361 L
.13811 .12369 L
.13935 .1238 L
.14158 .12404 L
.14667 .12482 L
.15254 .12603 L
.15812 .12765 L
Mistroke
.16312 .12965 L
.16857 .1325 L
.17417 .13641 L
.17943 .1414 L
.18416 .14716 L
.18927 .15488 L
.20075 .17822 L
.21131 .20351 L
.21664 .215 L
.22168 .22384 L
.2275 .23113 L
.23279 .23635 L
.23521 .23907 L
.23778 .24272 L
.23997 .24679 L
.24239 .25265 L
.24498 .26093 L
.24777 .27259 L
.25282 .3018 L
.25809 .34145 L
.26298 .3783 L
.26545 .39275 L
.26683 .39872 L
.26809 .40256 L
.26946 .4049 L
.27024 .40529 L
.27096 .40506 L
.27227 .40314 L
.27294 .40144 L
.27366 .39904 L
.27494 .39351 L
.27615 .38686 L
.27842 .37127 L
.28353 .32778 L
.28828 .28786 L
.29061 .27149 L
.29275 .25904 L
.29506 .24862 L
.29627 .24445 L
.29756 .24103 L
.29887 .23856 L
.30009 .23718 L
.30143 .23668 L
.30218 .23686 L
.30287 .2373 L
.30425 .23897 L
.30552 .24141 L
.30692 .24503 L
.3084 .24987 L
.31363 .27329 L
Mistroke
.31806 .29642 L
.32051 .30798 L
.32283 .31686 L
.32414 .3206 L
.32487 .32225 L
.32556 .32345 L
.32677 .32477 L
.32806 .325 L
.32938 .32393 L
.33063 .32171 L
.33175 .31875 L
.33296 .31455 L
.34287 .25414 L
.34833 .21651 L
.3535 .18671 L
.35642 .17308 L
.3596 .16084 L
.36224 .15255 L
.36516 .1452 L
.3679 .13979 L
.37081 .13537 L
.3735 .13228 L
.37603 .13009 L
.37846 .12852 L
.37983 .12784 L
.38111 .12732 L
.38246 .12689 L
.38369 .1266 L
.38438 .12647 L
.38511 .12636 L
.38645 .12624 L
.3876 .12621 L
.38887 .12624 L
.39019 .12634 L
.39142 .12648 L
.39258 .12666 L
.39363 .12685 L
.396 .12738 L
.40128 .12893 L
.40704 .13111 L
.41752 .13562 L
.43996 .14411 L
.44511 .14594 L
.45055 .14826 L
.45519 .15082 L
.46027 .15456 L
.46555 .16003 L
.47047 .16704 L
.47579 .177 L
.48148 .19039 L
Mistroke
.49185 .21918 L
.49641 .23081 L
.49883 .23593 L
.50143 .2403 L
.50283 .24211 L
.50412 .24339 L
.50541 .24433 L
.50663 .24488 L
.508 .24511 L
.50927 .24496 L
.51 .24473 L
.51067 .24444 L
.51143 .24399 L
.51215 .24348 L
.51506 .24061 L
.51774 .23717 L
.52087 .23281 L
.52379 .22907 L
.52501 .22778 L
.52616 .22675 L
.52748 .22586 L
.52869 .22535 L
.53003 .22518 L
.53127 .22542 L
.53263 .22618 L
.53331 .22676 L
.53407 .22758 L
.53548 .22956 L
.53677 .23195 L
.53968 .23939 L
.54224 .24829 L
.54494 .25981 L
.55009 .28584 L
.55495 .30978 L
.55626 .31506 L
.55764 .31979 L
.55836 .32185 L
.55916 .32376 L
.55989 .32516 L
.56056 .32613 L
.56183 .32712 L
.56319 .32688 L
.56446 .32542 L
.56566 .32296 L
.56687 .31941 L
.56797 .31533 L
.57044 .30353 L
.57488 .27555 L
.58494 .20637 L
.59007 .1785 L
Mistroke
.59548 .15658 L
.60011 .14327 L
.60273 .13757 L
.60518 .13325 L
.60802 .12926 L
.6107 .12631 L
.61312 .12425 L
.61574 .12255 L
.61709 .12187 L
.61859 .12126 L
.62015 .12077 L
.62087 .12059 L
.62162 .12044 L
.62298 .12024 L
.62423 .12014 L
.62558 .12012 L
.62634 .12014 L
.62705 .12018 L
.62839 .12032 L
.62907 .12041 L
.62982 .12053 L
.63236 .1211 L
.6338 .12152 L
.63534 .12205 L
.63812 .12321 L
.64358 .12624 L
.64856 .1298 L
.66809 .1485 L
.67778 .15783 L
.6831 .16195 L
.68809 .16486 L
.69068 .16596 L
.69347 .16686 L
.69656 .16758 L
.6994 .16806 L
.70447 .16883 L
.70592 .1691 L
.7073 .16941 L
.70855 .16975 L
.70988 .17019 L
.71244 .17132 L
.7148 .17281 L
.71735 .17501 L
.72015 .17834 L
.72253 .18202 L
.72509 .187 L
.72972 .19891 L
.73553 .21944 L
.74106 .24365 L
.7465 .26854 L
Mistroke
.75144 .2874 L
.75393 .29417 L
.75533 .29695 L
.75662 .2988 L
.75776 .29985 L
.759 .30039 L
.7603 .30029 L
.76151 .29962 L
.76217 .29902 L
.7629 .2982 L
.76422 .29629 L
.76669 .29156 L
.77224 .27845 L
.77475 .27306 L
.7771 .26913 L
.77829 .26771 L
.77956 .26666 L
.78025 .26632 L
.78097 .26613 L
.78227 .26625 L
.78338 .26684 L
.78457 .26796 L
.78569 .26948 L
.7867 .27124 L
.78919 .27698 L
.79155 .28396 L
.79682 .30236 L
.7994 .31082 L
.80176 .31701 L
.80303 .31944 L
.80424 .32104 L
.80552 .32187 L
.80624 .32193 L
.80691 .32171 L
.80765 .32115 L
.80835 .32032 L
.80965 .31796 L
.81038 .31618 L
.81105 .31427 L
.81257 .30901 L
.81707 .28687 L
.822 .25579 L
.83195 .19479 L
.83747 .16945 L
.84269 .15187 L
.84738 .14055 L
.85003 .13565 L
.85248 .13191 L
.85755 .12609 L
.86044 .12373 L
Mistroke
.86314 .12201 L
.86599 .12065 L
.86859 .11972 L
.87003 .11932 L
.8716 .11897 L
.87308 .11871 L
.87445 .11853 L
.8758 .11842 L
.87648 .11839 L
.87723 .11837 L
.87854 .11837 L
.87978 .11842 L
.88052 .11847 L
.88123 .11854 L
.88256 .1187 L
.88398 .11893 L
.88554 .11924 L
.88817 .11991 L
.89096 .12082 L
.89598 .12306 L
.90077 .126 L
.90526 .12956 L
.91551 .14073 L
.9349 .17166 L
.94021 .18002 L
.94313 .18404 L
.94588 .18729 L
.94845 .18976 L
.94981 .19084 L
.95124 .19181 L
.95245 .19249 L
.95377 .19311 L
.95611 .1939 L
.95731 .19418 L
.9586 .19439 L
.95933 .19447 L
.96 .19454 L
.96131 .19462 L
.96368 .19472 L
.96501 .19478 L
.96624 .19488 L
.96692 .19496 L
.96767 .19508 L
.96845 .19524 L
.96917 .19544 L
.9705 .19593 L
.97125 .19629 L
.97193 .19668 L
.97321 .19759 L
.9746 .1989 L
Mistroke
.97713 .20226 L
.9785 .2047 L
.98002 .20796 L
.98308 .2166 L
.98591 .2273 L
.98857 .23988 L
.99928 .31085 L
1 .316 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07Cooooo
0ol0000iooooo`00]Oooool00ol0003oooooooooo`0Sooooo`Go0000BOooool4o`0000;ooooo1?l0
000eooooo`00?Oooool9o`0006oooooo00?o0000ooooooooool08Oooool2o`0000Gooooo0ol00015
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool003_ooooo0_l00009oooo
o`Co0000AOooool6o`00023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02_ooool2o`0003;ooooo000iooooo`;o
00003oooool00ol0003oooooooooo`10ooooo`;o00001_ooool4o`0001cooooo0_l0000Pooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02oooooo000hooooo`03o`000?oooooooooo013ooooo0_l00010ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
;oooool003Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00cooooo0_l0000Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;_oo
ool003Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00oooooo0ol0000Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool0
03Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01;ooooo0_l0000Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool003Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Go
oooo0ol0000@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool003Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Sooooo
0_l0000>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:oooool003Gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo000e
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00[ooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo000doooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Goooo
o`;o0000<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo000dooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`;o
0000<?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Sooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05?ooool00ol0003oooooooooo`03
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?o0000ooooooooool03?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`03
o`000?oooooooooo00Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo00?o0000ooooooooool02Oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`09o`000?oooooooooooooooonHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooo
oooo00oooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003o
ooooooooo`04ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00gooooo00?o0000ooooooooool02oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00oooooo1?l00007ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004ooo
ool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo1?l00004ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Fooooo`03o`000?oooooooooo
00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00_ooooo00?o0000
ooooooooool02oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`07ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_oo
ool2o`0000Cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001Kooooo
00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`0;ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`03ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Cooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
2_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000oooo
ooooool02?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01Kooooo00?o0000ooooooooool01Oooool2o`0001_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006?ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Doooo
o`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool02_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool01Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00Sooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o000000Co^[ZjoooooonHV9So
410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000ooooooooool00_ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oo
oooooooo00Wooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`00
0?oooooooooo00Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04?ooool00ol0003oooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Eooooo`03o`000?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`09ooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00<_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool003;ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Rooooo`?o00008Oooool0037ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`Ko00007?ooool0037ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo000aooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Fooooo`00<?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000Jooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Kooooo000`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0001Wooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool05_ooool0033ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Gooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo000000Oooooo1?l0000>ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Gooooo000`ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0]ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool05Oooool002oooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo02gooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`00;oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01;ooooo0_l0000=ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool05Oooool002oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0@oooo
o`;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Gooooo000_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo02kooooo0_l00002ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Eooooo`00;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`0^ooooo`04o`000?oooooo0000o`0000Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Eooooo`00;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00oooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Gooooo000^oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo
000000[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Dooooo`00;_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oo
oooo0_l0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05?ooool002?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Cooooo
000Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo01Cooooo000Rooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo0ol0000;
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05?ooool0027ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool04oooool0023ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01?ooooo
000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Cooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool04oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool2o`0000kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool04oooool001gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool04_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Booooo`006_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0iooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool02ooo
ool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool5o`0000Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01;ooooo
000Iooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000>_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Vooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool0
3Oooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000002[ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`16ooooo`05o`000?oooooooooo
ooooool00000>oooool00ol0003oooooooooo`0Aooooo`005oooool00ol0003oooooooooo`0>oooo
o`?o0000>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`00000[ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo00Go0000ooooooooooooooooo`00
000kooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo013ooooo0_l0000l
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000002cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0?ooooo`05o`000?oo
ooooooooooooool00000B?ooool01Ol0003ooooooooooooooooo000003_ooooo00?o0000oooooooo
ool04Oooool006Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0002kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooo`0004[ooooo00?o0000ooooool00000D?ooool006Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000002[ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000Boooool2
o`00053ooooo001Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool3o`00
02[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo013ooooo0ol0002M
ooooo`00Ioooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool04?ooool2o`0009kooooo001Wooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04;ooooo0_l0002aooooo`00J?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0/?ooool006Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0/?ooool006Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;3ooooo
001Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`2`ooooo`00J?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0/?ooool006Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0A?ooool2o`000;7ooooo001Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`2`ooooo`00JOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0/?ooool006Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2`ooooo`00JOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0/?ooool006Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;3ooooo
001Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`2`ooooo`00J_ooool01Ol0003ooooooooooooooooo000004Kooooo0_l0002aooooo`00J_ooool0
1Ol0003ooooooooooooooooo000004Kooooo00?o0000ooooooooool0/?ooool006[ooooo00Co0000
oooooooooooo0000Aoooool00ol0003oooooooooo`2`ooooo`00J_ooool01?l0003oooooooooool0
0017ooooo`03o`000?oooooooooo0;3ooooo001[ooooo`03o`000?oooooo000004Oooooo00?o0000
ooooooooool0/?ooool006_ooooo0ol0000nooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`2`ooooo`00Joooool2o`00043ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Co
A4A4omgMgOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`2`ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`00
00gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo
00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@03
ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool06_ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000
ooooooooooooooooo`00001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l0
00000ol0000Iooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@401loooo
o`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@oiRH
V005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30417 m
.00123 .30592 L
.00236 .30669 L
.00365 .30663 L
.00488 .30563 L
.00601 .30394 L
.00706 .30175 L
.00942 .29487 L
.01444 .27428 L
.017 .26266 L
.01975 .25096 L
.02242 .24148 L
.02369 .23789 L
.02486 .23518 L
.02604 .23311 L
.02732 .23164 L
.02845 .23106 L
.02966 .23123 L
.03039 .23174 L
.03107 .23249 L
.03182 .23364 L
.0326 .23522 L
.03393 .23876 L
.03538 .24395 L
.03806 .25717 L
.04057 .27368 L
.04582 .31866 L
.04859 .34467 L
.05153 .36996 L
.05277 .37892 L
.0541 .38701 L
.05486 .39081 L
.05556 .39369 L
.05693 .39755 L
.05809 .39887 L
.05936 .39818 L
.06069 .39507 L
.06192 .39006 L
.06267 .38607 L
.06348 .381 L
.06495 .36999 L
.06771 .34444 L
.07389 .27767 L
.07953 .22391 L
.08229 .20308 L
.08481 .1872 L
.0896 .16426 L
.09224 .15504 L
.09475 .14813 L
.09746 .14233 L
Mistroke
.09998 .13821 L
.10274 .13473 L
.10568 .13189 L
.10855 .12978 L
.11006 .12889 L
.11165 .1281 L
.11305 .12753 L
.11458 .12703 L
.11598 .12667 L
.11727 .12642 L
.11864 .12623 L
.11993 .12611 L
.12109 .12604 L
.12234 .126 L
.12371 .12601 L
.1244 .12602 L
.12517 .12605 L
.12651 .12613 L
.12777 .12625 L
.12901 .1264 L
.13034 .12661 L
.13272 .12715 L
.13418 .12759 L
.13555 .12808 L
.13812 .1292 L
.14335 .13229 L
.14901 .13695 L
.15393 .1425 L
.15913 .15017 L
.16845 .16793 L
.17839 .18971 L
.181 .19497 L
.18386 .19997 L
.18655 .20375 L
.18784 .20518 L
.18904 .20629 L
.19016 .20709 L
.19136 .20772 L
.1927 .20812 L
.19392 .20821 L
.19513 .20805 L
.19645 .20757 L
.19782 .20676 L
.19911 .20571 L
.20143 .20315 L
.20354 .20017 L
.20829 .19177 L
.21806 .17272 L
.22298 .16502 L
.22433 .16334 L
Mistroke
.22578 .16179 L
.22714 .1606 L
.22841 .15975 L
.22911 .1594 L
.22986 .15911 L
.23069 .15891 L
.23145 .15885 L
.23216 .15889 L
.23293 .15906 L
.23366 .15934 L
.23434 .1597 L
.23559 .16065 L
.23697 .16215 L
.23841 .16423 L
.23976 .16669 L
.2424 .17309 L
.24482 .18091 L
.2476 .19253 L
.25023 .20632 L
.26038 .28225 L
.26306 .30475 L
.26594 .3269 L
.26727 .33572 L
.26866 .34374 L
.26987 .34946 L
.27115 .35417 L
.27235 .35716 L
.27343 .35867 L
.27452 .35903 L
.27555 .35831 L
.27675 .35621 L
.27785 .35314 L
.27907 .34865 L
.28035 .34277 L
.28566 .31129 L
.2905 .28318 L
.29294 .27287 L
.29431 .26865 L
.29559 .2659 L
.29682 .26438 L
.29793 .26397 L
.29921 .2647 L
.30042 .26657 L
.30172 .26989 L
.30309 .27487 L
.30554 .28745 L
.30818 .30582 L
.31107 .33026 L
.31588 .37324 L
.31726 .3841 L
Mistroke
.31857 .393 L
.31976 .39962 L
.32103 .40486 L
.32213 .40777 L
.32334 .40906 L
.32444 .40842 L
.32547 .40625 L
.32669 .40179 L
.3278 .396 L
.3303 .37765 L
.34076 .26663 L
.34377 .23796 L
.34661 .21518 L
.34919 .19809 L
.35191 .18347 L
.35431 .17318 L
.35693 .16425 L
.35932 .15795 L
.36155 .15339 L
.36419 .14933 L
.36659 .14662 L
.36936 .14436 L
.37198 .14285 L
.37428 .1419 L
.37559 .14148 L
.37682 .14116 L
.37802 .1409 L
.37929 .14069 L
.38068 .1405 L
.38196 .14038 L
.38306 .14029 L
.38424 .14022 L
.38636 .14011 L
.38887 .14 L
.39118 .13986 L
.39388 .13967 L
.39681 .1394 L
.40213 .13885 L
.40732 .13825 L
.41207 .13769 L
.41328 .13756 L
.41459 .13745 L
.41583 .13736 L
.41698 .1373 L
.41832 .13727 L
.41953 .13728 L
.4202 .1373 L
.42093 .13734 L
.42225 .13745 L
.4234 .1376 L
Mistroke
.42466 .13781 L
.42598 .1381 L
.42721 .13844 L
.42941 .13922 L
.43177 .14035 L
.43456 .14213 L
.43759 .14471 L
.44046 .14789 L
.44311 .15152 L
.44812 .16039 L
.45343 .17275 L
.46329 .20198 L
.46847 .21757 L
.47129 .22485 L
.47391 .23029 L
.4751 .23225 L
.47623 .23376 L
.47752 .23508 L
.4787 .23586 L
.48001 .23626 L
.48121 .23617 L
.48253 .23559 L
.4832 .2351 L
.48393 .23442 L
.48513 .23299 L
.48622 .23134 L
.48868 .2266 L
.49311 .21513 L
.50281 .18587 L
.50771 .17353 L
.5105 .16812 L
.51312 .16436 L
.5145 .16296 L
.51519 .16242 L
.51596 .16196 L
.5173 .1615 L
.51856 .1615 L
.51932 .16171 L
.52004 .16207 L
.5214 .16316 L
.52215 .16403 L
.52285 .16499 L
.52443 .16777 L
.52685 .17377 L
.52951 .18303 L
.5323 .19591 L
.53491 .21116 L
.54012 .25062 L
.54581 .30193 L
.54841 .32419 L
Mistroke
.54984 .33498 L
.55118 .34381 L
.55244 .35062 L
.5538 .35621 L
.55503 .35952 L
.55617 .36098 L
.5573 .3609 L
.5585 .35911 L
.55964 .35584 L
.56068 .3516 L
.5619 .3452 L
.56322 .33668 L
.56563 .31787 L
.57079 .27033 L
.57562 .2274 L
.58038 .1935 L
.5855 .16739 L
.58827 .15728 L
.59118 .14924 L
.59367 .14419 L
.59639 .14028 L
.59788 .13873 L
.59929 .1376 L
.60055 .13682 L
.60192 .1362 L
.60263 .13595 L
.60341 .13575 L
.60423 .1356 L
.60499 .13552 L
.60636 .1355 L
.60712 .13555 L
.60782 .13565 L
.60918 .13593 L
.61043 .13632 L
.61181 .13686 L
.61328 .13757 L
.61845 .14088 L
.62928 .14929 L
.63498 .15358 L
.63809 .15562 L
.64098 .15719 L
.64353 .15823 L
.64496 .15866 L
.64625 .15898 L
.64768 .15923 L
.64848 .15933 L
.64922 .15939 L
.65058 .15945 L
.65127 .15945 L
.65203 .15943 L
Mistroke
.65335 .15934 L
.65455 .15918 L
.65522 .15907 L
.65594 .15893 L
.65727 .15861 L
.65981 .15779 L
.66218 .15679 L
.67326 .1508 L
.6759 .14948 L
.6787 .14825 L
.68129 .14732 L
.68255 .14695 L
.68371 .14668 L
.68481 .14649 L
.68586 .14637 L
.68697 .14633 L
.68818 .14639 L
.68941 .14657 L
.69072 .14691 L
.69185 .14733 L
.69308 .14794 L
.6956 .14967 L
.69702 .15096 L
.69832 .15234 L
.70324 .15953 L
.70584 .16477 L
.70821 .1705 L
.71352 .18687 L
.72309 .22555 L
.72845 .24719 L
.73127 .25656 L
.73282 .26071 L
.73426 .26383 L
.73552 .26589 L
.73688 .26736 L
.73765 .26784 L
.73838 .26805 L
.73975 .2678 L
.74101 .26685 L
.74217 .26537 L
.74345 .26312 L
.74482 .26006 L
.75563 .22248 L
.76132 .20324 L
.76418 .1961 L
.76581 .19312 L
.76653 .19208 L
.76732 .19116 L
.76807 .19051 L
.76875 .1901 L
Mistroke
.77011 .18985 L
.77134 .1903 L
.77265 .19152 L
.77332 .19245 L
.77405 .1937 L
.77536 .1966 L
.77693 .20117 L
.77836 .20648 L
.78072 .21771 L
.7833 .23362 L
.78851 .27675 L
.79407 .33188 L
.7968 .35654 L
.79799 .36574 L
.79931 .37426 L
.80049 .38026 L
.8016 .3843 L
.80277 .38678 L
.80402 .38731 L
.80539 .38535 L
.80668 .38108 L
.80785 .37536 L
.80912 .36727 L
.82067 .25115 L
.82612 .20301 L
.83112 .17151 L
.83362 .15984 L
.83626 .15 L
.83891 .14232 L
.8418 .13601 L
.84431 .13202 L
.8457 .13031 L
.847 .12896 L
.84822 .1279 L
.84954 .12696 L
.85065 .12631 L
.85184 .12575 L
.85321 .12527 L
.85449 .12496 L
.85527 .12484 L
.85601 .12476 L
.85668 .12473 L
.85741 .12474 L
.85818 .12479 L
.85889 .12487 L
.8597 .12501 L
.86046 .12518 L
.86183 .12559 L
.8633 .12616 L
.86598 .12752 L
Mistroke
.86882 .12937 L
.87389 .13361 L
.88384 .14532 L
.8945 .16127 L
.89935 .16847 L
.9045 .17519 L
.90662 .17748 L
.9089 .17956 L
.9102 .18054 L
.9114 .18128 L
.91254 .18186 L
.91375 .18233 L
.91504 .18266 L
.91624 .1828 L
.91697 .18282 L
.91766 .18278 L
.91895 .18258 L
.92032 .18219 L
.92158 .18167 L
.92297 .18093 L
.92443 .17997 L
.92996 .17499 L
.93605 .16795 L
.94131 .16176 L
.94421 .15871 L
.94696 .15626 L
.94952 .15446 L
.95096 .15368 L
.9523 .15312 L
.95354 .15277 L
.95466 .15258 L
.95596 .15255 L
.95718 .1527 L
.9584 .15305 L
.95971 .15366 L
.96095 .15447 L
.96208 .15543 L
.9634 .15683 L
.96484 .1587 L
.96745 .16315 L
.97019 .16934 L
.97309 .17776 L
.9783 .19797 L
.98831 .25248 L
.99283 .27795 L
.99538 .28996 L
.99651 .29447 L
.9977 .29854 L
1 .30417 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo06kooooo0_l00010
ooooo`00>_ooool7o`0007Cooooo00?o0000ooooooooool0K?ooool6o`0003kooooo000hooooo`;o
00001oooool2o`0007;ooooo0_l0001/ooooo`03o`000?oooooooooo00Cooooo0_l0000looooo`00
=oooool00ol0003oooooooooo`09ooooo`;o0000L?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool003Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Booooo`?o00006?ooool00ol0003oooooooooo`0Mooooo`Co0000BOoo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo000fooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0A_ooool<o`000003ooooool0003o000000;o00005Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo0_l00017ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>?ooool003Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`12ooooo`?o00004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01?ooool2o`0004Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0gooooo`00=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo043o
oooo0_l0000Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo0ol0000_ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0=_ooool003Cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool3o`0000;ooooo
0_l0000/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool003Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool2o`0000Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01;ooooo0ol0000Pooooo`00<oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?
ooooo`;o00006_ooool00ol0003oooooooooo`0<ooooo`;o00002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`;o00000_ooool2o`0001oooooo000cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool2o`0002Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool3o`000003ooooool0003o0000
00;o00002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`03ooooo`;o00007_ooool003;ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo0000o`0002Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo0_l0000Eoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01cooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`05ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Sooooo00Co0000oooo
oooooooooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
4oooool00ol0003oooooooooo`04ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Go
oooo00?o0000ooooooooool00oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Ook^k^oc8b
<_l0003o<S8bonk^k_oooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool01Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Ol0003o8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooo
ooooool03Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04ooo
ool00ol0003oooooooooo`04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01?ooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00;ooooo00?o0000ooooooooool03?ooool6o`0000;ooooo00Co0000oiRHV?lQ8B7o
k^k^1?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00?o0000ooooooooool0
1?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41005?ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool@41000oooool01?l@413oooooooooool0000:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000001?l00003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool02?ooool00onYZJWo410@ooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00Co0000oiRHV?lQ8B7ok^k^0oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Dooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000001Cooooo00?o0000ooooooooool01oooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00Ko0000oooooom4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000017o
oooo00?o0000ooooooooool02?ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`03
o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
01Cooooo00?o0000ooooooooool01_ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00Ko0000
oooooooMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@017ooooo00?o0000oooooooo
ool02Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000oooool01Ol@
413ooooooooooooooooo410@01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0;ooooo`?o00001_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01Gooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03
okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00000oooool00ol0
003oooooooooo`0<ooooo`06o`000?ooooooooooogMgMoo<c<co00001?ooool01Ol@413ooooooooo
oooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Aooooo`03o`000?oooooooooo00Kooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00Go0000okZj^_l0003oV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0@ooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL05Oooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01?ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`Co00003oooool01_l0003ooooo
ooooooo^k^koA4A4o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omg
MgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`06
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00?o0000ooooooooool00_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`0;
ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo00Wo0000oooooooooooooooo
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000
ooooooooool01?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Jooooo`05o`000?ooooooooooogMgMol000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0:ooooo`;o00001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool03_ooool2o`00017ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Iooooo`00<Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000013ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`00<?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Sooooo000`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool0033ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo0_l0
0009ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Sooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00006ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000006ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool04Oooool001Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool04Oooool002oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01Oooooo000_ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Gooooo`00;oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool002oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Oooooo
000_ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Kooooo000Nooooo`;o00003oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool09oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool05_ooool001kooooo0ol0000>ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`04o`000?oo
ooooooooo`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Mooooo`;o000000?o
ooooo`000?ooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0:?ooool3o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Fooooo`007Oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool05_ooool001gooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool05_ooool001gooooo00Go0000ooooooooooooooooo`00
000<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05Oooool001cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool05Oooool001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05Oooool001cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool05Oooool001_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0`ooooo`;o0000
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Eooooo`006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Dooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o0000
3?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?ooool03?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05?ooool001_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo0ol0
000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Dooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Cooooo`006_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0`ooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo01?ooooo000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;o
oooo000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo000I
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo01;ooooo000Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo1Ol00006oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Boooo
o`005_ooool3o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`009?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00onHV9So
8B4Qonk^kP07ooooo`?o00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`009?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool002Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo000T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<
ooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1<ooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1<ooooo`009?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04gooooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00gooooo00Go0000oooooooo
ooooooooo`000019ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool002Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;o
oooo0_l0000>ooooo`05o`000?ooooooooooooooool00000BOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04gooooo000Uooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000019
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool002Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000004Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1=ooooo`009Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04gooooo000Uooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`000019ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool002Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooo0000BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04gooooo000Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooo000004[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1=ooooo`009Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooool000002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooo`00001:ooooo`05o`000?ooooooooooooooool0
0000D?ooool002Kooooo00Go0000ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00ko
oooo00?o0000ooooool00000B_ooool01Ol0003ooooooooooooooooo0000053ooooo000Vooooo`05
o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03?ooooo0_l0000@ooooo`03o`000?oooooooooo04[ooooo00Co0000oooooooooooo0000D?ooool0
02Kooooo00Go0000ooooooooooooooooo`00001?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`00053ooooo000V
ooooo`05o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool0001@ooooo`009_oo
ool01Ol0003ooooooooooooooooo000004oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo05cooooo00Co0000oooooooooooo0000D?ooool002Kooooo
00Go0000ooooooooooooooooo`00001?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`00053ooooo000Vooooo`05
o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool0001@ooooo`009_ooool01Ol0
003ooooooooooooooooo0000053ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooool00000D?ooool002Oooooo00Co0000oooooooooooo0000D?oo
ool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool0GOooool2o`00057ooooo
000Wooooo`04o`000?ooooooooooo`00053ooooo00Go0000ooooooooooooooooo`00000eooooo`;o
0000G_ooool2o`00057ooooo000Wooooo`03o`000?oooooo0000057ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`2`ooooo`009oooool00ol0003oooooo`00001Aooooo`04o`00
0?ooooooooooo`0003Kooooo00?o0000ooooooooool0/?ooool002Sooooo0_l0001Aooooo`04o`00
0?ooooooooooo`0003Kooooo00?o0000ooooooooool0/?ooool002Sooooo0_l0001Aooooo`04o`00
0?ooooooooooo`0003Kooooo00?o0000ooooooooool0/?ooool007_ooooo00Co0000oooooooooooo
0000;Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool007cooooo
0_l0000_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool007cooooo0_l0
000/ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01?m4A4CogMgMooooool0
0007ooooo`?o0000/?ooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`2`ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool00:cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool0
1Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Ooo
ool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0
003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo
00Gok^k^oc8b<_l0003o410@olc<c003ooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A01looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^07gooooo0025ooooo`06
o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@05ooooo`03oiRHV?lQ8B7ok^k^07cooooo0025ooooo`06o`000?oM
gMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooo
ooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03ogMgMomVIVKooooo07_ooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
6Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o
0000o`000003o`0001Wooooo00?oEEEEohN7Qoooool02Oooool00ol0003oooooooooo`1jooooo`00
QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@oiRHV005
ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool0
0on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o
0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26231 m
.00942 .21309 L
.01483 .18955 L
.01719 .18142 L
.01975 .17414 L
.02114 .17086 L
.02243 .16826 L
.02373 .16606 L
.02496 .16442 L
.02624 .16315 L
.02693 .16267 L
.02766 .16232 L
.02843 .16214 L
.02916 .16215 L
.03053 .16267 L
.03173 .16368 L
.03302 .16538 L
.03423 .16758 L
.03533 .17012 L
.03803 .17864 L
.04057 .18996 L
.04313 .20511 L
.04595 .22666 L
.05164 .28704 L
.05696 .35667 L
.05929 .38524 L
.06182 .41062 L
.06256 .41646 L
.06335 .42172 L
.06408 .42566 L
.06477 .4285 L
.06609 .43152 L
.0668 .43176 L
.06756 .43094 L
.0683 .42907 L
.06912 .42584 L
.06997 .42118 L
.07077 .41574 L
.07371 .38758 L
.07904 .31835 L
.08481 .24588 L
.0876 .21807 L
.09056 .19441 L
.09308 .1784 L
.09586 .16458 L
.09846 .1547 L
.09989 .15035 L
.10125 .14689 L
.10251 .1442 L
.10388 .14181 L
Mistroke
.10504 .14018 L
.10629 .13879 L
.10762 .13767 L
.10886 .13692 L
.11008 .13643 L
.11119 .13616 L
.11241 .13606 L
.11374 .13613 L
.11512 .13642 L
.11642 .13687 L
.11764 .13745 L
.11879 .13815 L
.12095 .13987 L
.12328 .14231 L
.12581 .14563 L
.1462 .1867 L
.15179 .19788 L
.15332 .20033 L
.15493 .20253 L
.15632 .2041 L
.1578 .20542 L
.15853 .20593 L
.15922 .20632 L
.1605 .20684 L
.1617 .20707 L
.163 .20702 L
.16369 .20688 L
.16444 .20663 L
.16523 .20626 L
.16596 .20582 L
.16727 .2048 L
.16868 .20338 L
.17144 .1997 L
.17399 .19535 L
.17976 .18338 L
.19027 .16116 L
.19519 .15247 L
.19982 .14589 L
.20214 .14332 L
.20464 .14112 L
.20599 .14018 L
.20742 .13938 L
.20863 .13883 L
.20997 .13839 L
.21135 .13808 L
.21262 .13794 L
.21329 .13793 L
.21402 .13795 L
.21479 .13804 L
.21551 .13817 L
Mistroke
.21682 .13854 L
.21803 .13904 L
.21942 .13983 L
.22074 .1408 L
.22317 .14321 L
.22542 .14622 L
.2279 .15045 L
.23053 .15609 L
.23339 .16364 L
.23647 .17371 L
.24207 .1978 L
.25252 .26079 L
.25734 .29019 L
.26 .30338 L
.2613 .30865 L
.26251 .31267 L
.26393 .31625 L
.26468 .31761 L
.26548 .31863 L
.26676 .31934 L
.2675 .31923 L
.26818 .31878 L
.26951 .31699 L
.27073 .31431 L
.27207 .31031 L
.27347 .30502 L
.28417 .24716 L
.28699 .2324 L
.29005 .21849 L
.29269 .20851 L
.29419 .20377 L
.2956 .19997 L
.29703 .19677 L
.29835 .19449 L
.29902 .19356 L
.29975 .19275 L
.30052 .19212 L
.30125 .19175 L
.30256 .19163 L
.3033 .19188 L
.30396 .19231 L
.30525 .19371 L
.30647 .19571 L
.30767 .19837 L
.30894 .20194 L
.31121 .21039 L
.31366 .22268 L
.31634 .24046 L
.32116 .28515 L
.32633 .34841 L
Mistroke
.33084 .40464 L
.33312 .42728 L
.33442 .43713 L
.33563 .44396 L
.33635 .4468 L
.33703 .44864 L
.33832 .44973 L
.3397 .44744 L
.34048 .44458 L
.3412 .44093 L
.34251 .43214 L
.3437 .42189 L
.34635 .39263 L
.35194 .31783 L
.35488 .28 L
.35799 .24536 L
.36069 .22046 L
.36366 .19835 L
.36888 .17021 L
.37144 .16034 L
.37418 .15206 L
.37677 .14608 L
.37914 .14186 L
.38153 .13852 L
.38418 .13561 L
.38694 .13322 L
.38954 .13148 L
.39072 .13086 L
.39195 .13032 L
.39301 .12995 L
.39417 .12965 L
.39542 .12946 L
.39676 .12939 L
.39802 .12945 L
.39917 .12961 L
.40052 .12992 L
.40196 .13038 L
.40454 .13151 L
.40732 .13321 L
.41037 .13576 L
.41301 .13867 L
.41584 .14268 L
.42096 .15238 L
.431 .17985 L
.44169 .21613 L
.44486 .22531 L
.44641 .22906 L
.44784 .23198 L
.44912 .23411 L
.45052 .23589 L
Mistroke
.45125 .23658 L
.45193 .23707 L
.45264 .23743 L
.45341 .23763 L
.45414 .23764 L
.45481 .2375 L
.45555 .23718 L
.45634 .23665 L
.45765 .23532 L
.4591 .23325 L
.46178 .2279 L
.46429 .22131 L
.4749 .18556 L
.48069 .16739 L
.48607 .15377 L
.49068 .14496 L
.49326 .14127 L
.49561 .13872 L
.49695 .1376 L
.49818 .13678 L
.49953 .1361 L
.50022 .13585 L
.50097 .13564 L
.50223 .13545 L
.50358 .13547 L
.50486 .13569 L
.50602 .13608 L
.50722 .13667 L
.50854 .13756 L
.50992 .13878 L
.51121 .14021 L
.51352 .14352 L
.51601 .14831 L
.51878 .15528 L
.52169 .16472 L
.52689 .1877 L
.53179 .21729 L
.53634 .25148 L
.54172 .29541 L
.54408 .31326 L
.54669 .32989 L
.54792 .33625 L
.54925 .34175 L
.54999 .34415 L
.55066 .34592 L
.55197 .34819 L
.5527 .34875 L
.55338 .34881 L
.55412 .34839 L
.55492 .34737 L
Mistroke
.55567 .34587 L
.55638 .344 L
.55771 .33937 L
.56032 .32658 L
.56272 .31151 L
.56813 .27244 L
.57304 .23915 L
.57762 .21437 L
.5824 .19564 L
.58493 .1883 L
.58764 .1821 L
.59033 .17741 L
.59319 .17372 L
.59563 .17137 L
.59832 .1694 L
.60432 .16614 L
.60995 .16341 L
.63108 .14935 L
.6414 .14136 L
.64703 .13747 L
.64978 .13586 L
.65227 .13464 L
.65458 .13375 L
.65676 .13312 L
.65796 .13286 L
.65906 .13268 L
.66027 .13254 L
.66155 .13247 L
.66276 .13248 L
.66405 .13257 L
.66527 .13275 L
.66639 .133 L
.66769 .1334 L
.66912 .13399 L
.67046 .13471 L
.67171 .13553 L
.67449 .13793 L
.67706 .1409 L
.67987 .14505 L
.68283 .15055 L
.68783 .16279 L
.6933 .18113 L
.70335 .22524 L
.70829 .24649 L
.71046 .25429 L
.71285 .26114 L
.71414 .26391 L
.71535 .26586 L
.71663 .26718 L
.71801 .26772 L
Mistroke
.71872 .26764 L
.7195 .26725 L
.72024 .26661 L
.72093 .26578 L
.72222 .26361 L
.7236 .26048 L
.72624 .25239 L
.72873 .24278 L
.73339 .22193 L
.74407 .17558 L
.74945 .15858 L
.75251 .15154 L
.75387 .14901 L
.75536 .14668 L
.75678 .14486 L
.75809 .14352 L
.75934 .14254 L
.76068 .14182 L
.76186 .14146 L
.76298 .14139 L
.7642 .14161 L
.76552 .14224 L
.76685 .14329 L
.7676 .14409 L
.76829 .14498 L
.7697 .14721 L
.77121 .15029 L
.77394 .15788 L
.77642 .16727 L
.77891 .17932 L
.78121 .19306 L
.7864 .23449 L
.79581 .33755 L
.79833 .36289 L
.80071 .38171 L
.80203 .38913 L
.80277 .39227 L
.80347 .39445 L
.80468 .39652 L
.80598 .39621 L
.80722 .3935 L
.80855 .38805 L
.80981 .38068 L
.81097 .37222 L
.8155 .32831 L
.82091 .26919 L
.82389 .24039 L
.82671 .21745 L
.82933 .20011 L
.83218 .18534 L
Mistroke
.83477 .17521 L
.83716 .16827 L
.8383 .16571 L
.83952 .16342 L
.84057 .16181 L
.84173 .16041 L
.84301 .15925 L
.84435 .15844 L
.8456 .15803 L
.84676 .1579 L
.84809 .15801 L
.84934 .15835 L
.85047 .15881 L
.85169 .15947 L
.85443 .16142 L
.85695 .16368 L
.86236 .16937 L
.86817 .17538 L
.87098 .17775 L
.87236 .17872 L
.87365 .17949 L
.87491 .18012 L
.87604 .18057 L
.87731 .18095 L
.87865 .18119 L
.87989 .18127 L
.8812 .1812 L
.88232 .18101 L
.88354 .18067 L
.88486 .18015 L
.88627 .17941 L
.88882 .17765 L
.89382 .17282 L
.89838 .16739 L
.90965 .1529 L
.9146 .14727 L
.92005 .14229 L
.92248 .14053 L
.92509 .13897 L
.92636 .13834 L
.92756 .13783 L
.92874 .1374 L
.92981 .13709 L
.93105 .13683 L
.93238 .13666 L
.9336 .13663 L
.93476 .13669 L
.93611 .13691 L
.93735 .13723 L
.93871 .13774 L
Mistroke
.94016 .13844 L
.94275 .14018 L
.94553 .14279 L
.94816 .14607 L
.95056 .14988 L
.95337 .15548 L
.95642 .16315 L
.96198 .18169 L
.97074 .22274 L
.97578 .2502 L
.98041 .27309 L
.98278 .28228 L
.98399 .28601 L
.98527 .28918 L
.98657 .29147 L
.98778 .29275 L
.98851 .29311 L
.98921 .29316 L
.99051 .2925 L
.99166 .29111 L
.99288 .28884 L
.99392 .28629 L
.99507 .28288 L
1 .26231 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002Booooo`Go00007_ooool2o`000;7ooooo002Aooooo`;o0000
0oooool2o`0001gooooo00?o0000ooooooooool0;_ooool6o`0007cooooo000hooooo`Co0000E?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo1?l0000]ooooo`03o`000?oo
oooooooo00?ooooo0_l0001@ooooo`Co00009oooool003Oooooo0_l00002ooooo`;o00006_ooool6
o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`?o00000_ooool0
0ol0003oooooooooo`0Xooooo`;o00001oooool00ol0003oooooooooo`1<ooooo`?o00000oooool2
o`0002Gooooo000gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool2o`00
00Cooooo0_l0000`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo02Gooooo0_l0000:ooooo`03o`000?oooooooooo
01Oooooo1?l0000`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool003Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool2o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo000fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool08Oooool2o`0000kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo0_l0000:ooooo`03o`000?oooooooooo
027ooooo000eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Booooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qoooo
o`00=Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`0Mooooo`;o
00004_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo000eooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo0ol0000Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
8?ooool001kooooo0_l0000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o00003_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo000Eooooo`;o000000Ko410@
ooooooooooooooooonk^k_lb<S84o`0001?ooooo00?o0000ooooooooool00oooool01OnHV9So410@
o`000?lb<S;oc<c<00;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooool000001?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?oo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool00ol0003ooooo
ooooo`09ooooo`Go00000_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00?o0000oooo
ooooool04Oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Ko
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`07ogMgMonHV9So0000oiRHV?mgMgOoooooo`00000Booooo`03o`00
0?oooooooooo00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P02ooooo`06o`000?mgMgOoV9RHoooo
oonHV9SoMgMg2_ooool00ol0003oooooooooo`0<ooooo`07o`000?ooooooV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00ol0003oooooo`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`09
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`?o
oooo00?o0000ooooooooool04?ooool2o`0000?ooooo00Go410@okZj^_l0003oMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;
ooooo`Ko00000_ooool5o`0000?ooooo00Oo410@o`000?oooooooooooa0@4?oooooo0000013ooooo
1_l00006ooooo`05o`000?ooooooooooo`000?l@41000oooool00ol@413oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo1_l000001_oooooo0000oooooonHV9So8B4Qonk^kPCooooo00Go410@
oooooooooooooooooa0@400Cooooo`Ko00000oooool00ol0003oooooo`000004ooooo`05oa0@4?oo
ooooooooooooool@41001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0:ooooo`03
oiRHV?lQ8B7ok^k^00;ooooo00?o0000ooooool@41000oooool01Ol@413ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00Oo410@oooooooooooooooooa0@4?oo
oooo000001?ooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`;o00000_ooool00ol0003ooooo
o`00000Aooooo`03o`000?oooooooooo00Oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool03_ooool01_l0003ooooooooooonHV9So8B4Q
onk^kP?ooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooo000000Cooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`0:ooooo`07oiRHV?lQ8B7ok^k^ooooool0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000004Oooool00ol0003oooooooooo`06ooooo`03ojVYZOl0003ooooo00;ooooo00Co
0000oooooooooooooooo0_l0000Dooooo`03o`000?oooooooooo00?ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`00
00Cooooo0_l00002ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool01_ooool0
0ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`0>ooooo`06o`000?oooooooooooooooomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo0000
01cooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00KoMgMgofIVI_oooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`03oa0@4?l0003o^[Zj00;o000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go0000oooo
oooooooooooooa0@4002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?l0003oooooooooool@41002Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo01Wooooo00Co0000oooooooooooo00001?ooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool03?ooool01Ol0003oooooo`000?oo
oooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Kooooo00?o^[Zjob4Q8Oooool01_l000000ol@413oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo
000Dooooo`03onk^k_m4A4Co000000Cooooo00Go0000oiRHV?ooooooV9RHogMgM`02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgo`000?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo013ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01?l0003ooooooooo
ool00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00oooooo00?o0000ooooooooool02?ooool03Ol0003o^[ZjoooooonHV9So410@ooooool0003ooooo
ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_oo
ool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05o`000?lb<S;o0000oc8b<_o^k^h0
0oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0@oooo
o`05o`000?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Co
0000oeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l0
0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h05_ooool00ol0003oooooooooo`04ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01gooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`?o00004_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01co
oooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0>ooooo`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01cooooo000Foooooooo0000@?l0
000Cooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`0Aooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`0Aooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01_ooooo000Ioooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool001Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Jooooo`006?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01[ooooo000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06_oo
ool001Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Jooooo`006?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Hooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`;o00002?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Jooooo`006?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`?o00003Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01[ooooo000Gooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Iooooo`005oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06Oooool001Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Wooooo000Goooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Ioooo
o`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool06Oooool001Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02[ooooo0_l00009ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:_ooool01Ol0003ooooooooooooooooo000001Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo
000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo00005?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Aooooo`009Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0:oooool01?l0003oooooo`000?l0000Dooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
000Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0/ooooo`;o00005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`009Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0B
ooooo`009_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Booooo`009_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`00
9_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo
00005Oooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02_ooooo0_l0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo
00005Oooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`04o`00
0?ooooooooooo`0001Gooooo000Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<_ooool01?l0003oooooo`000?l0000Eooooo`009_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03?ooooo0_l0000Fooooo`009_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo000Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool0
02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
027ooooo1Ol00006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool002Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Boooool002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02;ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool002Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`009oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000004?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04cooooo000Wooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>?ooool2o`00017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1<ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo000Wooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo027ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00cooooo
00Go0000ooooooooooooooooo`00001:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0C?ooool002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`05o`00
0?ooooooooooooooool00000B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04co
oooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000004[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`00
9oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0/ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000004[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`009oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000Boooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04cooooo000Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool0001;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0C?ooool002Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooo000004_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1<ooooo`00:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo0ol0
001;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool002Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`;o0000C?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04cooooo000Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0G?ooool01Ol0003ooooooooooooooooo000004oooooo000Xooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0G?ooool01Ol0003ooooooooooooooooo000004oooooo000Xoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0G?ooool01Ol0003ooooooooooooooooo
000004oooooo000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo0_l0001Mooooo`05o`000?oooooooooo
ooooool00000Coooool002Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Loooo
o`05o`000?ooooooooooooooool00000Coooool002Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`1Looooo`05o`000?ooooooooooooooool00000Coooool002Wooooo00Go0000oooo
ooooooooooooo`00001@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`1Looooo`05o`000?ooooooooooooooool00000Coooool002Wooooo00Go0000
ooooooooooooooooo`00001@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo000Yooooo`05o`000?oo
ooooooooooooool00000D?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0GOooool01?l0003oooooooooool0001?ooooo`00:Oooool01Ol0003ooooo
oooooooooooo0000057ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo05gooooo00Co0000oooooooooooo0000Coooool002Wooooo00Go0000oooooooo
ooooooooo`00001Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo000Yooooo`05o`000?oooooooooo
ooooool00000DOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo0_l0001N
ooooo`03o`000?oooooo0000053ooooo000Yooooo`05o`000?ooooooooooooooool00000DOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0GOooool0
0ol0003oooooo`00001@ooooo`00:Oooool01Ol0003ooooooooooooooooo0000057ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooool00000D?ooool002Wooooo00Go0000ooooooooooooooooo`00001Aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo04oooooo000Yooooo`05o`000?ooooooooooooooool00000DOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0/?ooool002Wooooo00Co0000oooo
oooooooo0000D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo000Yooooo`04o`000?oooooooooo
o`0005;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool002Wooooo00Co0000oooooooooooo0000D_ooool0
1Ol0003ooooooooooooooooo000002Kooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo000Y
ooooo`04o`000?ooooooooooo`0005;ooooo00Go0000ooooooooooooooooo`00000Vooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00:_ooool00ol0003oooooo`00001Booooo`05o`00
0?ooooooooooooooool000009_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0;3ooooo000Zooooo`03o`000?oooooo000005?ooooo00Co0000oooooooooooo00009oooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooo000005?o
oooo00Co0000oooooooooooo00009oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0;3ooooo000Zooooo`03o`000?oooooo000005?ooooo00Co0000oooooooooooo0000:?ooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`;o0000E?ooool01?l0003o
ooooooooool0000aooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo05;o
oooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`2`ooooo`00P?ooool01?l0003o
ooooooooool0000aooooo`03o`000?oooooooooo0;3ooooo0020ooooo`03o`000?oooooo000003;o
oooo0_l0002aooooo`00P?ooool00ol0003oooooo`00000booooo`03o`000?oooooooooo0;3ooooo
0021ooooo`;o0000<_ooool00ol0003oooooooooo`2`ooooo`00POooool2o`0003;ooooo00?o0000
ooooooooool0/?ooool0087ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?o
oooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool2o`000003oa0@4?oooooooooo07[ooooo
0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00Wo
MgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo07_ooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o
0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol0001looooo`00QOoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01?m4A4CogMgMooooool0001mooooo`00QOooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05o`000?mEEEGo0000
oa0@4?o<c<`00oooool01?oMgMgoEEEEooooool0001mooooo`00QOooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o410@o`000?l000000ol0000Iooooo`03oeEEEOn7QhOooooo00Kooooo00?oMgMgolc<c?l0
0000OOooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00?ogMgM
oa0@4?nHV9P01_ooool00oo^k^koA4A4o`00001mooooo`00Q?ooool00ol@413o0000ohN7Q`02oooo
o`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool0
0ol0003oooooooooo`0Kooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?oMgMgo`000?ooool0O?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(66) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18954 m
.00488 .16898 L
.00942 .15456 L
.01441 .14325 L
.01721 .13873 L
.01975 .13569 L
.02104 .13454 L
.02242 .13359 L
.02359 .133 L
.02488 .13257 L
.02627 .13238 L
.02704 .13238 L
.02776 .13246 L
.02914 .1328 L
.03045 .13336 L
.03166 .13411 L
.03296 .13515 L
.03529 .13778 L
.03671 .13993 L
.03806 .14239 L
.04057 .1483 L
.04313 .15636 L
.04595 .16794 L
.04889 .18355 L
.05164 .20185 L
.05655 .24484 L
.06182 .30435 L
.06478 .34015 L
.06799 .37568 L
.06947 .38923 L
.07103 .40093 L
.07237 .40834 L
.07313 .41139 L
.07384 .41344 L
.07519 .41513 L
.07586 .41491 L
.0766 .41385 L
.0779 .40995 L
.07912 .40413 L
.08056 .39481 L
.08187 .38439 L
.08481 .3563 L
.08986 .30335 L
.09459 .26115 L
.09697 .24476 L
.09953 .23089 L
.10098 .22461 L
.10236 .21966 L
.10372 .21566 L
.10495 .21273 L
Mistroke
.10632 .21019 L
.10702 .20915 L
.10777 .20821 L
.10912 .20698 L
.11039 .20628 L
.11111 .20606 L
.11189 .20595 L
.11271 .20595 L
.11348 .20606 L
.11485 .20646 L
.11562 .20677 L
.11631 .2071 L
.1214 .20992 L
.12263 .21052 L
.12396 .21105 L
.12472 .2113 L
.12542 .21147 L
.12679 .21167 L
.12805 .21166 L
.12922 .21148 L
.13051 .21108 L
.13188 .21041 L
.13332 .20941 L
.13468 .20821 L
.13723 .20526 L
.14186 .1979 L
.14687 .18797 L
.15726 .16636 L
.16277 .15652 L
.16868 .14829 L
.17158 .14516 L
.17433 .14271 L
.17701 .14075 L
.17949 .13932 L
.18184 .1383 L
.18302 .13791 L
.18433 .13756 L
.18563 .13731 L
.18637 .13721 L
.18704 .13714 L
.18828 .13707 L
.18959 .13706 L
.19098 .13713 L
.19223 .13725 L
.19293 .13734 L
.19369 .13746 L
.19506 .13772 L
.1977 .13839 L
.20015 .13925 L
.20282 .14047 L
Mistroke
.20576 .14218 L
.2117 .14679 L
.21716 .15256 L
.22235 .16023 L
.22701 .16977 L
.2321 .18379 L
.2376 .20414 L
.24347 .23246 L
.2486 .26121 L
.25402 .29012 L
.25671 .30151 L
.25823 .30659 L
.25896 .3086 L
.25966 .31025 L
.26096 .31261 L
.26216 .31387 L
.26344 .31423 L
.26416 .31398 L
.26484 .31344 L
.2655 .31262 L
.26623 .31142 L
.26753 .30844 L
.26908 .30361 L
.2705 .29806 L
.27652 .26614 L
.28183 .23403 L
.2875 .2031 L
.2924 .18119 L
.29771 .16303 L
.3005 .15593 L
.30307 .15082 L
.30553 .1471 L
.30678 .14558 L
.30813 .14421 L
.30935 .14321 L
.31046 .14248 L
.31158 .14194 L
.31264 .14162 L
.31387 .14152 L
.31501 .14172 L
.31626 .14229 L
.31759 .14337 L
.31831 .14418 L
.31907 .1452 L
.32042 .14754 L
.32188 .15081 L
.32347 .15537 L
.32634 .1664 L
.329 .18049 L
.33162 .19865 L
Mistroke
.33399 .21977 L
.33933 .28591 L
.3444 .36754 L
.34718 .41155 L
.34854 .43047 L
.34978 .44542 L
.35084 .45593 L
.35199 .46477 L
.35321 .47079 L
.35437 .47317 L
.35564 .47194 L
.35699 .46629 L
.35827 .45707 L
.35943 .44576 L
.36495 .3662 L
.37079 .27541 L
.37319 .24526 L
.37577 .21912 L
.3786 .19728 L
.38125 .18235 L
.38384 .17192 L
.38531 .16764 L
.38667 .16463 L
.38786 .16272 L
.38916 .16133 L
.39053 .16063 L
.39181 .16065 L
.39299 .16117 L
.39423 .16221 L
.39529 .16344 L
.39645 .16512 L
.40145 .17538 L
.4129 .20987 L
.41553 .21812 L
.41831 .22578 L
.42069 .23097 L
.42204 .23324 L
.4233 .23487 L
.42458 .23603 L
.42575 .23665 L
.4271 .23684 L
.42838 .23651 L
.42975 .23562 L
.43102 .23432 L
.43241 .23239 L
.43389 .22978 L
.43659 .22367 L
.43913 .21659 L
.44389 .2012 L
.45459 .168 L
Mistroke
.45997 .15557 L
.46306 .14986 L
.46588 .14562 L
.46859 .14244 L
.47115 .14023 L
.47256 .13932 L
.47386 .13865 L
.47529 .13808 L
.47608 .13783 L
.4768 .13764 L
.47801 .1374 L
.4793 .13725 L
.48045 .1372 L
.48165 .13723 L
.48297 .13737 L
.4842 .1376 L
.48555 .13797 L
.48699 .1385 L
.48951 .13977 L
.49223 .14162 L
.49717 .14595 L
.5064 .15686 L
.51155 .16516 L
.51636 .17465 L
.52208 .18838 L
.5273 .20424 L
.53796 .2496 L
.54351 .2783 L
.54655 .29394 L
.54941 .30739 L
.55198 .31754 L
.55311 .32118 L
.55434 .32449 L
.55562 .3271 L
.55696 .32889 L
.55767 .32941 L
.55843 .32964 L
.55979 .32919 L
.56103 .32783 L
.56238 .32534 L
.56365 .32207 L
.56483 .31832 L
.56941 .2982 L
.58066 .23385 L
.58616 .20578 L
.5912 .18504 L
.59573 .17025 L
.60067 .1575 L
.6059 .14717 L
.61086 .13984 L
Mistroke
.6163 .13385 L
.61929 .13122 L
.6221 .1291 L
.62472 .12745 L
.62757 .12604 L
.62882 .12555 L
.63015 .1251 L
.63252 .12449 L
.6338 .12426 L
.63448 .12416 L
.6352 .12408 L
.63651 .12398 L
.63773 .12394 L
.6389 .12397 L
.63999 .12405 L
.64119 .12421 L
.64248 .12447 L
.64377 .12483 L
.64519 .12536 L
.64667 .12606 L
.64805 .12687 L
.65051 .12871 L
.65315 .13129 L
.65564 .13433 L
.65834 .13841 L
.66324 .14826 L
.66801 .16158 L
.6724 .17743 L
.6819 .22065 L
.68714 .24473 L
.68972 .25465 L
.69211 .26187 L
.69347 .26491 L
.69416 .26613 L
.69491 .2672 L
.69573 .26805 L
.69651 .26853 L
.69727 .2687 L
.69796 .2686 L
.6992 .26781 L
.70056 .26606 L
.70125 .26484 L
.70198 .26329 L
.70331 .25992 L
.70613 .25055 L
.70879 .23958 L
.71378 .21626 L
.72395 .17203 L
.72908 .15604 L
.732 .14908 L
Mistroke
.73474 .14385 L
.73723 .14005 L
.7396 .13722 L
.74173 .13531 L
.74294 .13448 L
.74406 .13387 L
.74537 .13333 L
.7466 .13301 L
.74771 .13287 L
.74891 .13286 L
.75022 .13302 L
.75161 .13339 L
.75279 .13384 L
.75409 .1345 L
.75672 .13633 L
.75959 .1391 L
.76229 .14255 L
.76479 .14655 L
.76953 .15655 L
.77456 .17116 L
.77994 .19213 L
.78499 .21764 L
.79651 .29237 L
.79909 .30902 L
.80185 .32487 L
.80441 .33683 L
.80566 .3415 L
.80682 .34501 L
.80812 .34799 L
.80881 .34913 L
.80954 .35001 L
.81071 .35073 L
.81201 .3505 L
.81275 .3499 L
.81342 .34907 L
.8142 .34778 L
.81494 .34625 L
.81768 .33818 L
.82002 .32895 L
.8225 .31751 L
.82697 .29521 L
.83711 .24887 L
.84792 .21286 L
.85961 .18412 L
.87065 .16297 L
.8808 .14841 L
.88574 .14312 L
.89103 .13875 L
.89603 .13553 L
.90058 .13329 L
Mistroke
.90193 .13278 L
.90336 .13231 L
.9046 .13197 L
.90593 .13167 L
.90735 .13142 L
.90869 .13125 L
.90946 .13118 L
.91028 .13112 L
.91097 .13108 L
.91173 .13105 L
.91312 .13104 L
.91438 .13108 L
.91508 .13112 L
.91583 .13118 L
.9172 .13134 L
.91849 .13156 L
.91985 .13187 L
.92101 .13222 L
.92229 .13269 L
.92491 .13397 L
.92777 .13592 L
.93047 .13832 L
.93297 .14108 L
.9377 .14812 L
.94034 .15338 L
.94273 .15917 L
.94817 .17654 L
.95404 .20212 L
.96467 .26016 L
.96864 .27926 L
.96978 .2837 L
.97086 .28733 L
.97184 .29009 L
.97288 .29243 L
.97404 .29426 L
.97511 .29521 L
.97626 .29542 L
.97753 .29466 L
.97861 .29323 L
.97977 .2909 L
.98087 .28799 L
.98187 .28477 L
.98631 .26524 L
.99116 .23806 L
1 .18954 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo02Oooooo1Ol00024
ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool2o`0008?ooooo002eooooo`;o
00009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo053ooooo0_l0000^ooooo`00
7Oooool4o`0009Cooooo00?o0000ooooooooool08_ooool2o`0000[ooooo00?o0000ooooooooool0
6_ooool3o`0002kooooo1?l000000ooooooo0000o`000002o`0002_ooooo000Looooo`05o`000?oo
ooooooooooooool00000<?ooool3o`0005[ooooo0_l00005ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`;o00000oooool2o`0002[ooooo
0_l00009ooooo`03o`000?oooooooooo02Sooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:oooool2o`0000;ooooo1?l0001Eooooo`;o00000_ooool3o`0000;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09oooool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0X
ooooo`;o00002?ooool2o`0001oooooo1?l0000_ooooo`03o`000?oooooooooo00Cooooo0_l00000
0ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Vooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`;o00000_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo0_l0000Qooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`006_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`08ooooo`;o00008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool09Oooool001Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Uooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`;o00007oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool001Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Sooooo`006?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool2o`0001?ooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Sooooo`005Oooool2o`000009oa0@4?l0003ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool04oooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool4o`000008oa0@4?oooooo
0000onk^k_lb<S;o0000oc8b<_o^k^h@ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`00000Jooooo`03o`000?oooooooooo00Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPOooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00Ook^k^oc8b<_l0003o
<S8bonk^k_oooooo000001Wooooo00goV9RHoa0@4?l0003o<S8bolc<c?oooooo0000ooooooo^k^ko
<S8bo`000?lb<S;ok^k^017ooooo00?o0000ooooooooool02Oooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo000000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01?ooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000Dooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00[o0000oooooooooooo
0000oooooomgMgOoV9RHo`000?nHV9SoMgMg3oooool00ol0003oooooooooo`0<ooooo`05o`000?oo
ooooooooooooool000006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00oooooo00Go0000ob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0F
ooooo`0=oa0@4?nj^[[oooooogMgMolb<S;oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0A
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
4004ooooo`03o`000?oooooooooo00_ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooo`00000Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooooo
o`Ko00001Oooool01_l0003oooooooooool0003ooooooa0@40;ooooo00?o0000oa0@4?ooool03_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo00kooooo00Go0000oooooonHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0Jooooo`;o00000_ooool01Ol@
413ooooooooooooooooo410@017ooooo00?o0000ooooooooool01oooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`004oooool00om4A4CogMgMooooo`02o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Kooooo00?oZJVYoa0@4?ooool00_oo
ool01?l0003oooooooooooooool2o`0001Kooooo00?o0000ooooooooool00oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00cooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o00003oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00kooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Iooooo`03ojVYZOl0003ooooo
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00Kooooo00CoA4A4
omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`03omgMgOmE
EEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
5?ooool00ol@413o0000okZj^P03ooooo`04o`000?ooooooooooooooo`;o00005oooool00ol0003o
ooooooooo`03ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00gooooo
00Ko0000ooooooooooooooooogMgMomVIVH3ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Hooooo`03oa0@4?l0003o000000?ooooo00Go0000ooooooooooooooooo`00
000Booooo`03o`000?oooooooooo00Kooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`04ogMgMoo<c<co0000o`0000?ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`03o`000?oooooooooo01Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@
413ooooooooooooooooo000001Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooool000000_ooool01Ol@413ooooooooooooooooo000000kooooo
00?o0000ooooooooool03Oooool2o`0000Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4009ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00Go410@ooooooooooooooooo`00000Jooooo`03o`000?lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@400Booooo`03o`000?oooooooooo00Oooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01;ooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9Soooooo`000?mgMgL06Oooool01ol0003oooooo`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oooooo
V9RHo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool03?ooool01ol0003oooooo`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool0
5Oooool01Ol@413oV9RHo`000?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Boooo
o`03o`000?oooooooooo00Oooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000o`000?o^k^h06Oooool01ol0003ooooooiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`05oeEEEOmVIVKo0000ooooool000000_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02_ooool00ol0003oooooooooo`0;ooooo`07o`000?ooooooV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Eooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooo
ooooool02?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
017ooooo000Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool002Kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`009_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo017ooooo000Vooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04_ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000ooooool0003ooooo0_l000001?oooooo0000ooooooooool2o`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
0_l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00000oooool5o`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`04ooooo`;o00004oooool002Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Booooo`009oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01?ooooo000Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04ooo
ool002Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`009oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo000Wooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool000005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04oooool002Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00Co0000oooooooooooo00005Oooool2o`0000Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool4o`0001Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`00:?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool002Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Cooooo000Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`;o00002oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000006ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`00:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08_ooool2o`000003ooooool0003ooooo01_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05Oooool002Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02?ooooo0_l0000Mooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo000Xooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Kooooo000Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo000Yooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Kooooo000Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool0
1Ol0003ooooooooooooooooo000001Wooooo000Yooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Vooooo`;o00003?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Y
ooooo`05o`000?ooooooooooooooool000006Oooool002Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0001Wooooo000Yooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0000Iooooo`00:Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo0ol0000Jooooo`00:Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo0_l0000Jooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04Sooooo000Yooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`Go00001_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04Sooooo000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<oooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`18ooooo`00:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?o
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01gooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool002Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`?o00005oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0=?ooool2o`0001Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`19ooooo`00:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00:Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0L
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0>ooooo`04o`000?oo
ooooooooo`0004_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00:_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Looooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0>ooooo`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1:ooooo`00:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo
0_l0001<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool002[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`;o0000C?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04[ooooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo0_l0001O
ooooo`05o`000?ooooooooooooooool00000COooool002[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool00000COooool002[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool00000COoo
ool002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Nooooo`04o`000?oooooo
ooooo`0004kooooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Goooool0
0ol0003oooooo`00001>ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
05oooooo0ol0001>ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3o
oooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool002_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0X
ooooo`;o0000/Oooool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2`oooo
o`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo0;3ooooo000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool002co
oooo00Go0000ooooooooooooooooo`00001Booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`2`ooooo`00;?ooool01Ol0003ooooooooooooooooo0000
05;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`;o0000/Oooool002co
oooo00Co0000oooooooooooo0000Doooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0/?ooool002cooooo00Co0000oooooooooooo0000E?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/?ooool002co
oooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0/?ooool002cooooo00Co0000oooooooooooo0000E?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/?ooool002co
oooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
023ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03
o`000?oooooo000005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool002gooooo0_l0001Eooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool07_ooool5o`0000Kooooo00?o0000ooooooooool0
/?ooool002gooooo0_l0001Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_oo
ool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool002kooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`2`ooooo`00Q?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01oooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Q?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`2`ooooo`00QOooool01Ol0003ooooooooooooooooo000002;ooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00QOooool01?l0003oooooooooool0000/
ooooo`03o`000?oooooooooo0;3ooooo0025ooooo`04o`000?ooooooooooo`0002cooooo00?o0000
ooooooooool0/?ooool008Gooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`2`
ooooo`00QOooool01?l0003oooooooooool0000/ooooo`;o0000/Oooool008Gooooo00Co0000oooo
oooooooo0000;?ooool00ol0003oooooooooo`2`ooooo`00QOooool01?l0003oooooooooool0000/
ooooo`03o`000?oooooooooo0;3ooooo0025ooooo`04o`000?ooooooooooo`0002cooooo00?o0000
ooooooooool0/?ooool008Gooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`2`
ooooo`00QOooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo0;3ooooo0025oooo
o`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0/?ooool008Gooooo00Co0000oooo
oooooooo0000;?ooool00ol0003oooooooooo`2`ooooo`00Q_ooool2o`0002gooooo0_l0002aoooo
o`00Q_ooool2o`0002gooooo00?o0000ooooooooool0/?ooool008Kooooo0_l0000]ooooo`03o`00
0?oooooooooo0;3ooooo0026ooooo`;o0000;Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05
oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002ioooo
o`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`00
0?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c01looooo`00QOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo
00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003oV9RH
oooooonHV9So8B4Q07cooooo0025ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooooooo01[ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00006Oooool0
0omEEEGoQhN7ooooo`05ooooo`03oeEEEOn7QhOooooo07kooooo0025ooooo`06o`000?lb<S;ooooo
oooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`0Jooooo`03omgMgOl@413oV9RH00Gooooo00?ogMgMoa0@4?nHV9P0
O_ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool01?o<c<coA4A4
o`000?l@4104ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14335 m
.00123 .14166 L
.00236 .14034 L
.00357 .13915 L
.00488 .1381 L
.00609 .13735 L
.00722 .13684 L
.00829 .1365 L
.00942 .13629 L
.01065 .13625 L
.01196 .13639 L
.0132 .13669 L
.01434 .13712 L
.01566 .13778 L
.01711 .13871 L
.01975 .14092 L
.02249 .14391 L
.02497 .14723 L
.03054 .15663 L
.04057 .17926 L
.06182 .23245 L
.08481 .30842 L
.09032 .34029 L
.09301 .35518 L
.09546 .3667 L
.0967 .37137 L
.09805 .37536 L
.09879 .377 L
.09948 .37815 L
.10083 .37932 L
.10219 .37896 L
.10296 .37805 L
.10369 .37673 L
.10445 .37486 L
.10515 .37272 L
.10672 .36645 L
.10915 .35323 L
.11141 .33783 L
.11654 .29677 L
.12192 .25367 L
.12688 .22018 L
.13218 .19296 L
.13497 .18199 L
.13793 .1726 L
.14289 .16111 L
.14572 .15648 L
.14836 .15312 L
.15088 .15061 L
.15328 .14874 L
.15542 .14741 L
Mistroke
.15777 .14629 L
.16031 .14538 L
.16301 .1447 L
.16557 .14424 L
.16788 .14393 L
.18813 .14184 L
.19367 .14112 L
.19502 .14096 L
.19646 .14082 L
.19729 .14075 L
.19805 .1407 L
.19881 .14066 L
.19953 .14064 L
.20079 .14064 L
.20214 .14069 L
.20328 .14079 L
.20455 .14096 L
.2059 .14123 L
.20736 .14164 L
.20874 .14215 L
.21 .14273 L
.21262 .14437 L
.21499 .14648 L
.21774 .14987 L
.22032 .15419 L
.22272 .15939 L
.22493 .16533 L
.22991 .18357 L
.23495 .20969 L
.24048 .24692 L
.24622 .28905 L
.24905 .3072 L
.25029 .31393 L
.25166 .3202 L
.25294 .32477 L
.25414 .32784 L
.25541 .3297 L
.25678 .33005 L
.25746 .32958 L
.2582 .32859 L
.25897 .32702 L
.25969 .32509 L
.26098 .32053 L
.26236 .31422 L
.26747 .28118 L
.27212 .2452 L
.27753 .2061 L
.28039 .1887 L
.28341 .17307 L
.28605 .16173 L
Mistroke
.28895 .15155 L
.29161 .14417 L
.29407 .13876 L
.29668 .13434 L
.29818 .13235 L
.29954 .13085 L
.30074 .12974 L
.30205 .12876 L
.30343 .12795 L
.30473 .12741 L
.3059 .12708 L
.30719 .1269 L
.30854 .12692 L
.3098 .12712 L
.31098 .12746 L
.31205 .12791 L
.31329 .12859 L
.31447 .1294 L
.31711 .13182 L
.31993 .13533 L
.32233 .13916 L
.32497 .14438 L
.32781 .15128 L
.33087 .16048 L
.3364 .18253 L
.34638 .24194 L
.35704 .32147 L
.36019 .34172 L
.36317 .35696 L
.36447 .3622 L
.36584 .36676 L
.36656 .36874 L
.36735 .37059 L
.36874 .37306 L
.36946 .37396 L
.37015 .37459 L
.37145 .37517 L
.37217 .37519 L
.37284 .37504 L
.37358 .37468 L
.37436 .37411 L
.37504 .37346 L
.37578 .37263 L
.37712 .37082 L
.37961 .36667 L
.39017 .34486 L
.39549 .33062 L
.40131 .30914 L
.41155 .25775 L
.42124 .20912 L
Mistroke
.4264 .18872 L
.42911 .17991 L
.43199 .17203 L
.43441 .16651 L
.43708 .1615 L
.43949 .15786 L
.44178 .1551 L
.44314 .15375 L
.44463 .15252 L
.446 .15158 L
.44725 .1509 L
.44872 .15026 L
.44953 .14999 L
.4503 .14979 L
.45166 .14953 L
.45242 .14944 L
.45313 .14939 L
.4544 .14938 L
.45559 .14946 L
.4569 .14963 L
.45763 .14976 L
.4583 .14989 L
.4611 .15066 L
.46376 .1516 L
.47389 .15616 L
.47656 .15731 L
.47944 .1584 L
.48198 .1592 L
.48466 .15986 L
.48576 .16008 L
.48694 .16026 L
.48824 .16042 L
.48945 .16053 L
.49063 .16058 L
.49175 .1606 L
.49276 .16058 L
.49385 .16053 L
.49507 .16043 L
.49641 .16028 L
.49913 .15984 L
.50399 .15888 L
.50661 .15842 L
.50733 .15832 L
.50809 .15823 L
.50946 .15811 L
.51014 .15809 L
.51087 .15808 L
.51219 .15814 L
.51348 .1583 L
.51466 .15855 L
Mistroke
.51583 .15891 L
.51692 .15936 L
.51812 .16001 L
.5194 .1609 L
.52075 .16208 L
.52202 .16347 L
.5244 .16688 L
.52705 .17214 L
.52987 .17975 L
.53227 .18816 L
.53492 .19974 L
.54081 .23507 L
.54634 .2788 L
.5517 .3227 L
.55431 .34014 L
.55545 .34621 L
.55668 .35151 L
.55798 .35548 L
.5592 .35761 L
.55988 .35809 L
.56059 .35804 L
.56188 .35651 L
.56256 .35499 L
.56328 .35281 L
.56459 .34751 L
.56614 .33912 L
.56756 .32973 L
.57698 .24833 L
.58215 .20733 L
.587 .17759 L
.59194 .15583 L
.59456 .14723 L
.59739 .13987 L
.59983 .13488 L
.6024 .13074 L
.6046 .12795 L
.60701 .12554 L
.60847 .12437 L
.60986 .12344 L
.61112 .12275 L
.61246 .12217 L
.61315 .12192 L
.61391 .1217 L
.61525 .12142 L
.61601 .12132 L
.61682 .12127 L
.61759 .12126 L
.61829 .1213 L
.61962 .12146 L
.62086 .12173 L
Mistroke
.62222 .12215 L
.62367 .12274 L
.62636 .12424 L
.62879 .12609 L
.63123 .12848 L
.63391 .1318 L
.63652 .13583 L
.63932 .14114 L
.64433 .15344 L
.64901 .16845 L
.66036 .21744 L
.66536 .23977 L
.6682 .25043 L
.66959 .25478 L
.67087 .25815 L
.67206 .26072 L
.67336 .26284 L
.67467 .26421 L
.67605 .26479 L
.67743 .26449 L
.6782 .26393 L
.6789 .2632 L
.68027 .26113 L
.68156 .25847 L
.68446 .25023 L
.68713 .24046 L
.69318 .21467 L
.69848 .19255 L
.70344 .17514 L
.70862 .16138 L
.71136 .15597 L
.71431 .15153 L
.71698 .14864 L
.71848 .14746 L
.71983 .14662 L
.7211 .14604 L
.72247 .1456 L
.72376 .14537 L
.72495 .1453 L
.72562 .14532 L
.72634 .14538 L
.72764 .14562 L
.72844 .14583 L
.72919 .14608 L
.73059 .14667 L
.73345 .14831 L
.73655 .15071 L
.75766 .1738 L
.77806 .18623 L
.78092 .18721 L
Mistroke
.78364 .18836 L
.78515 .18918 L
.78679 .1903 L
.78829 .1916 L
.78966 .19305 L
.79239 .19693 L
.79389 .19972 L
.7953 .20285 L
.79782 .20977 L
.80054 .21945 L
.80552 .24392 L
.81099 .28112 L
.81632 .32322 L
.81926 .34472 L
.8207 .35381 L
.82204 .36097 L
.82328 .36633 L
.8246 .37049 L
.82593 .37293 L
.82668 .3735 L
.82739 .37348 L
.82862 .37219 L
.82974 .36962 L
.83097 .36532 L
.83227 .35922 L
.83464 .34455 L
.83684 .32768 L
.84183 .28382 L
.84713 .23898 L
.85287 .20031 L
.8555 .18652 L
.85829 .17435 L
.8607 .16563 L
.86329 .15788 L
.8658 .15175 L
.86809 .14713 L
.87258 .1402 L
.87509 .13725 L
.87782 .13459 L
.8828 .13091 L
.88549 .12943 L
.88839 .12817 L
.89113 .12725 L
.89365 .12659 L
.89593 .12615 L
.89723 .12596 L
.89843 .12583 L
.89971 .12574 L
.90087 .1257 L
.90221 .12573 L
Mistroke
.90348 .12582 L
.90475 .12598 L
.90547 .12611 L
.90614 .12625 L
.9075 .1266 L
.90897 .1271 L
.91161 .12834 L
.91404 .1299 L
.91671 .13218 L
.91963 .13549 L
.92268 .14008 L
.92551 .14562 L
.93082 .16001 L
.93382 .1708 L
.93657 .1826 L
.94701 .24123 L
.95192 .27016 L
.95431 .28197 L
.9565 .29046 L
.95768 .29392 L
.95881 .29639 L
.95999 .29808 L
.96128 .29883 L
.9626 .29838 L
.96334 .2976 L
.96401 .29657 L
.96531 .29372 L
.96654 .29007 L
.96863 .28187 L
.97059 .2724 L
.97503 .24677 L
.98398 .19452 L
.98796 .17614 L
.99172 .16237 L
.9938 .15622 L
.99606 .15064 L
1 .14335 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo027ooooo0ol0002<ooooo`00]Oooool00ol0003oooooooooo`0O
ooooo`?o000000Coooooo`000?l0003o0000R_ooool007Kooooo1?l0000kooooo`03o`000?oooooo
oooo01kooooo0_l00006ooooo`03o`000?oooooooooo053ooooo1ol0000`ooooo`00MOooool2o`00
00;ooooo0_l0000jooooo`;o00007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04gooooo0ol00006ooooo`;o0000;_ooool007Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool001Sooooo
0ol0001Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool2o`0000cooooo
00?o0000ooooooooool0:oooool001Kooooo0_l00003ooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0:_ooool001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0`
ooooo`_o00006Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo000Moooo
o`03o`000?oooooooooo02Sooooo1ol0000:ooooo`;o00006?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Oooooo1?l0000[ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Aooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
00004oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09Oooool4o`0000cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08_ooool3o`0000;ooooo1?l00009ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool001oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Qooooo`;o00002?ooool2o`0000Oooooo0_l0000Kooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01?ooooo000Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`08ooooo`?o00001Oooool6o`0001Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool0
01oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00cooooo1_l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool001Go
oooo0_l000002_l@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^k_l0000Iooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko0000o`000?lb<S;ok^k^01Kooooo00?o0000oooo
ooooool00_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo1?l000002_l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^ooooool0000Booooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`06o`00
0?o^k^ko<S8bo`000?lb<S;ok^k^6oooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00kooooo0ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01_mgMgOoV9RHoooo
oonHV9SoMgMgo`0001Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMol0003ooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMg
ooooool000004_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Ol0003oV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_oooooo0000oc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0>ooooo`;o00000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Oo410@oooo
oooooooooooooa0@4?oooooo0000013ooooo1_l00006ooooo`05o`000?ooooooooooooooool00000
0oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`07oa0@
4?ooooooooooooooool@413oooooo`00000?ooooo`03o`000?oooooo000000Go00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo0000017ooooo
00?o0000ooooooooool01Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?l0003oooooooooool@
41007Oooool00ol0003oooooo`000003ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0;ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Coooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001Oooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP03ooooo`07o`000?ooooooooooooooool0
003oooooo`00000?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`07o`000?ooooooooooooooool0003oooooo`00000Aooooo`03o`000?oooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h00oooool00ol0003oooooo`000002o`0001gooooo00?o0000ojVYZOl@4100
0oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool02oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEE
EOoooooo00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05ooo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooo
ooooo`04ooooo`03ogMgMomVIVKooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool2o`000005okZj
^_ooooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooo
oooo01Oooooo00Ko^[Zjob4Q8Oooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo01Kooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool0
00004?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4007ooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?l0003o000001_ooooo00?o0000okZj^_lQ8B400ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool02oooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l00000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool05?ooool01Ol@413o
V9RHoooooonj^[[o000000;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgLHooooo`08o`000?oo
ooooooooo`000?nj^[[ooooooiRHV?l@4103ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000
ooooooooool05_ooool01Ol@413o0000oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo00_ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`03o`000?oooooooooo01?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02oooo
o`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6?ooool02?l0003ooooooooooonHV9So410@o`000?lQ
8B7oc<c<0oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`00017ooooo00?o0000ooooooooool01ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`04ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00005_ooool01OnYZJWo0000o`000?l@
413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00cooooo
00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Tooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05oooool2o`0001Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`009Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool0
02Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Kooooo000Uooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Fooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0A
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool04Oooool002Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo000Wooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`009ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05ooo
ool002Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Sooooo000Xooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Hooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06?ooool002Wooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Oooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06?ooool002Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`00:_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool002[ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo000[ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`00:ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Ooo
ool002_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01_ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000/
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0I
ooooo`;o00003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Go0000
ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000/ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
000002Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool002cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0000Xooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01[ooooo000]ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01[ooooo000^ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo000^oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000001gooooo000^ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Kooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000007Oooool002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`04o`000?ooooooooooo`0001kooooo000_ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08Oooool01?l0003oooooooooool0000Nooooo`00;oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooool000007_ooool0033ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Sooooo`?o00007_ooool0033ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Sooooo`;o00007oooool0033ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo1Ol00006ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A?ooool0037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool0037ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool000007?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A?ooool0037ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool000007Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04Cooooo000aooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0:?ooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Eooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`14ooooo`00<Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Sooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0AOooool0037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Y
ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Cooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04Gooooo000aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooo`00000Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`15ooooo`00<_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo0_l0
000Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04Gooooo000booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:oooool2o`0001kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool003;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool07_ooool2o`0000oooooo00Go0000ooooooooooooooooo`00001?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0AOooool003;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000D?ooool01Ol0003ooooooooooooo
oooo000004Sooooo000booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool0
1Ol0003ooooooooooooooooo0000053ooooo00Go0000ooooooooooooooooo`000018ooooo`00<_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`00001@ooooo`05o`000?ooooooooooooooool00000B?ooool003;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo0000057ooooo00Go0000oooooooooooo
ooooo`000018ooooo`00<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo
00?o0000ooooool00000DOooool01Ol0003ooooooooooooooooo000004Sooooo000cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00001Aooooo`05o`00
0?ooooooooooooooool00000B?ooool003?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooo0000057ooooo00Go0000ooooooooooooooooo`000018ooooo`00
<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
D?ooool01Ol0003ooooooooooooooooo000004Sooooo000dooooo`05o`000?ooooooooooooooool0
0000DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo0_l0001Tooooo`05
o`000?ooooooooooooooool00000B?ooool003Cooooo00Go0000ooooooooooooooooo`00001Aoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooo000004Wooooo000dooooo`05o`000?ooooooooooooooool00000DOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooo`000019ooooo`00=?ooool01?l0003oooooooooool0001Cooooo`04o`000?oooooo0000
o`0002Kooooo00?o0000ooooooooool0I?ooool3o`0004Wooooo000eooooo`03o`000?oooooo0000
05?ooooo0ol0000Wooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0B?ooool003Go
oooo0ol0001mooooo`03o`000?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00[?ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo0;3ooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[o
oooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<
c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00
Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:c
ooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00co
oooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40O?oo
ool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?ooool008Gooooo00Ko
0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01Ol0003oEEEEo`000?l@
413oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c01looooo`00QOooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o410@o`000?l000000ol0000Iooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@okZj
^_oooooo^[Zjoa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool00ooMgMgo410@oiRHV005ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16383 m
.00942 .17705 L
.01483 .18521 L
.01975 .19163 L
.02225 .19426 L
.02496 .19647 L
.02644 .19737 L
.02782 .19798 L
.02913 .19837 L
.0298 .19848 L
.03053 .19856 L
.03183 .19853 L
.03302 .19834 L
.0344 .19793 L
.03571 .19735 L
.03803 .19593 L
.04057 .19389 L
.05167 .18162 L
.0546 .17828 L
.05777 .17504 L
.0605 .17273 L
.06206 .17168 L
.06351 .17089 L
.06487 .17033 L
.06564 .1701 L
.06634 .16994 L
.06707 .16983 L
.06787 .16978 L
.06863 .1698 L
.06933 .16988 L
.07056 .17018 L
.07192 .17076 L
.07261 .17117 L
.07335 .17169 L
.07468 .17288 L
.07591 .17429 L
.07725 .1762 L
.07996 .18139 L
.08247 .18805 L
.08481 .19607 L
.08719 .2063 L
.08975 .21989 L
.09436 .25209 L
.09918 .29611 L
.10448 .35069 L
.10746 .37836 L
.10892 .38971 L
.11028 .39836 L
.11151 .40437 L
.11281 .40868 L
Mistroke
.11356 .41012 L
.11426 .41077 L
.11558 .41013 L
.11682 .40732 L
.11814 .4021 L
.11926 .39595 L
.12049 .38758 L
.12581 .33795 L
.13141 .27903 L
.13741 .22692 L
.14031 .20745 L
.14307 .19222 L
.14822 .17069 L
.15078 .16277 L
.15349 .15593 L
.15836 .14665 L
.1636 .13931 L
.16938 .13328 L
.17456 .12939 L
.18 .12641 L
.18225 .12542 L
.18465 .12453 L
.18603 .12411 L
.18729 .12381 L
.18855 .12358 L
.18973 .12345 L
.191 .1234 L
.19172 .12342 L
.1924 .12346 L
.19375 .12364 L
.19452 .1238 L
.19521 .12397 L
.19645 .12437 L
.1978 .12493 L
.20026 .12632 L
.20162 .12732 L
.20312 .12866 L
.20617 .13224 L
.20899 .13689 L
.21165 .14269 L
.21657 .15794 L
.21936 .16961 L
.22195 .1827 L
.23281 .25999 L
.23764 .29783 L
.24001 .31327 L
.2422 .32418 L
.24342 .32856 L
.24472 .3317 L
.24602 .33322 L
Mistroke
.24676 .33333 L
.24746 .33294 L
.24866 .33115 L
.24976 .32831 L
.25103 .32368 L
.25223 .31805 L
.26308 .23923 L
.26839 .2022 L
.27073 .18892 L
.27328 .1766 L
.27774 .16043 L
.28018 .15415 L
.28245 .14973 L
.28373 .1478 L
.28495 .14632 L
.28604 .14527 L
.28723 .14441 L
.28852 .14379 L
.2899 .14346 L
.29107 .14345 L
.29236 .1437 L
.29366 .14421 L
.29504 .14501 L
.29621 .14591 L
.29749 .14709 L
.30036 .1505 L
.30302 .15455 L
.30786 .16395 L
.31303 .17642 L
.3186 .19141 L
.32449 .2068 L
.32953 .21754 L
.3309 .21985 L
.33238 .22196 L
.33377 .22356 L
.33506 .22469 L
.33644 .22551 L
.33717 .22578 L
.33794 .22595 L
.33869 .22598 L
.33938 .22591 L
.34068 .2255 L
.34197 .22477 L
.34315 .22382 L
.34582 .22088 L
.3515 .21208 L
.35749 .20199 L
.36001 .19831 L
.3614 .19659 L
.36271 .19522 L
Mistroke
.36394 .1942 L
.36526 .19343 L
.36647 .19307 L
.36759 .19306 L
.3689 .19349 L
.37014 .19435 L
.3715 .19588 L
.37226 .19701 L
.37296 .19823 L
.37435 .20123 L
.37587 .2054 L
.37865 .21564 L
.38133 .22913 L
.38422 .24826 L
.38948 .29564 L
.39416 .34824 L
.3993 .40348 L
.40069 .41521 L
.40218 .42531 L
.4029 .42916 L
.40359 .43211 L
.40487 .43576 L
.40558 .43668 L
.40634 .43678 L
.40769 .43471 L
.40845 .43233 L
.40915 .42934 L
.41076 .41991 L
.41205 .41005 L
.41341 .39781 L
.41584 .37252 L
.42132 .31072 L
.42647 .26101 L
.43133 .22701 L
.43402 .21306 L
.43694 .2011 L
.43959 .1926 L
.44203 .18643 L
.44649 .17829 L
.44903 .17485 L
.4514 .17204 L
.46132 .16188 L
.48081 .14361 L
.49111 .13542 L
.49407 .13339 L
.49686 .13169 L
.49936 .13044 L
.50077 .12989 L
.50207 .1295 L
.50345 .12921 L
Mistroke
.50474 .12907 L
.50549 .12904 L
.50616 .12905 L
.50694 .1291 L
.50768 .12919 L
.50839 .12932 L
.50915 .1295 L
.51052 .12993 L
.51198 .13059 L
.5136 .13156 L
.51499 .13265 L
.51626 .13389 L
.51762 .13553 L
.51912 .13772 L
.52164 .14256 L
.52429 .14947 L
.52707 .15898 L
.52958 .16994 L
.53523 .20398 L
.54046 .24844 L
.5454 .29817 L
.54775 .32137 L
.55027 .34321 L
.55172 .35345 L
.55304 .36093 L
.55436 .36638 L
.55562 .36949 L
.55693 .37047 L
.55831 .369 L
.5595 .36573 L
.5608 .36009 L
.5622 .35188 L
.56371 .34085 L
.56644 .31655 L
.57129 .26743 L
.57648 .21892 L
.58137 .18385 L
.58583 .16138 L
.5883 .15223 L
.59098 .14457 L
.59352 .13923 L
.59585 .1357 L
.59716 .13426 L
.59839 .13321 L
.59974 .13238 L
.60049 .13205 L
.60119 .13182 L
.60257 .1316 L
.60335 .1316 L
.60408 .13167 L
Mistroke
.60541 .13199 L
.60616 .13227 L
.60684 .13258 L
.60822 .13341 L
.60969 .13455 L
.61231 .13727 L
.61514 .14121 L
.61824 .14679 L
.62379 .16015 L
.62898 .17633 L
.63996 .21856 L
.64257 .22849 L
.64536 .23795 L
.64793 .24518 L
.6492 .24805 L
.65035 .25024 L
.65137 .2518 L
.65249 .25309 L
.65361 .25395 L
.65479 .25436 L
.65602 .25426 L
.65733 .25357 L
.65856 .25238 L
.65969 .25086 L
.66219 .24615 L
.66491 .23929 L
.66984 .22387 L
.67504 .20653 L
.68063 .19005 L
.68333 .18348 L
.6859 .1782 L
.68823 .17421 L
.69072 .17078 L
.69209 .16923 L
.69333 .16805 L
.69459 .16704 L
.69575 .16628 L
.69711 .16559 L
.69782 .16531 L
.69858 .16507 L
.69985 .1648 L
.70057 .16472 L
.70124 .16468 L
.70196 .16469 L
.70274 .16474 L
.70348 .16483 L
.70416 .16495 L
.70546 .16525 L
.70683 .16568 L
.70968 .16686 L
Mistroke
.71281 .16848 L
.7178 .17146 L
.72325 .17474 L
.72574 .17602 L
.7271 .17661 L
.72839 .1771 L
.7296 .17748 L
.7309 .1778 L
.73208 .17802 L
.73317 .17816 L
.73454 .17824 L
.73582 .17824 L
.73656 .17819 L
.73723 .17813 L
.738 .17803 L
.73873 .17791 L
.7402 .17759 L
.74155 .1772 L
.74461 .17596 L
.74703 .17465 L
.74969 .17288 L
.75509 .16855 L
.76497 .15991 L
.77036 .15539 L
.77538 .1518 L
.77802 .15038 L
.77949 .14977 L
.78083 .14934 L
.7816 .14915 L
.78231 .14902 L
.78308 .14891 L
.7839 .14884 L
.78528 .14884 L
.78607 .14892 L
.7868 .14904 L
.78815 .1494 L
.78944 .14994 L
.79059 .15059 L
.79185 .15153 L
.79321 .15285 L
.79466 .15464 L
.79728 .15907 L
.79858 .16196 L
.80002 .1657 L
.80291 .17531 L
.80559 .18703 L
.80809 .20077 L
.81373 .24334 L
.81978 .30527 L
.82251 .33494 L
Mistroke
.82547 .36397 L
.82683 .37502 L
.82828 .3846 L
.82951 .39073 L
.83087 .39506 L
.83217 .39667 L
.83337 .39588 L
.83469 .39252 L
.83608 .38631 L
.83729 .37881 L
.83841 .37029 L
.84097 .34654 L
.84628 .28745 L
.85203 .22793 L
.85467 .20581 L
.85746 .1863 L
.85988 .1724 L
.86247 .16016 L
.86498 .15061 L
.86727 .1436 L
.86961 .13792 L
.87177 .13375 L
.87428 .12999 L
.87702 .12692 L
.87943 .12491 L
.88199 .12337 L
.88331 .12279 L
.88474 .12232 L
.88547 .12215 L
.88625 .12201 L
.88698 .12193 L
.88764 .12189 L
.88892 .12192 L
.89031 .1221 L
.89162 .12241 L
.89283 .12282 L
.89423 .12342 L
.89554 .12413 L
.89852 .12627 L
.90142 .12911 L
.90454 .13321 L
.90725 .13785 L
.91021 .14424 L
.91561 .16007 L
.92086 .18127 L
.92574 .20614 L
.93107 .2372 L
.93387 .25353 L
.93683 .2692 L
.93943 .28046 L
Mistroke
.9409 .28547 L
.94227 .28907 L
.94354 .2914 L
.94469 .29266 L
.94602 .29308 L
.94728 .29243 L
.9484 .29102 L
.94964 .2886 L
.95093 .28515 L
.95214 .28114 L
.95664 .26114 L
.96682 .20734 L
.97119 .18863 L
.97525 .1753 L
.9773 .17008 L
.97949 .16556 L
.98074 .16346 L
.98192 .16178 L
.98297 .16052 L
.98413 .15938 L
.98506 .15865 L
.98605 .15804 L
.9871 .15757 L
.98809 .1573 L
.98907 .15718 L
.99 .1572 L
.99083 .15731 L
.99174 .15754 L
.99283 .15795 L
.99382 .15845 L
.99603 .15995 L
.99807 .16177 L
1 .16383 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo001@ooooo`Go0000H?ooool00ol0003oooooooooo`1f
ooooo`Ko0000=?ooool004kooooo0ol00004ooooo`;o0000G_ooool00ol0003oooooooooo`1eoooo
o`;o00001Oooool00ol0003oooooooooo`0aooooo`00COooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo05cooooo1Ol0001booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<?ooool004cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Iooooo`?o0000
0oooool2o`0001Wooooo1?l0001Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
;oooool004_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`;o00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool2o`00057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`00B_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool0
04Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0;_ooool004Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Dooooo`Go0000>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0^ooooo`00B?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000hooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool4o`0001Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0^ooooo`00Aoooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l0000Fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0;Oooool004Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`07ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`00Aoooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Dooooo`Co00005Oooool004Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo0_l0000:ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`;o00000oooool00ol0
003oooooooooo`0Booooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_l0
00005?ooool00ol0003oooooooooo`04ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o0000
00Wooooo00?o0000ooooooooool04?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hAooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Cooooo1?l000002?l@413o0000ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^4Oooool4o`0000Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool00ol0003oooooooooo`0>ooooo`05oiRHV?l@413o0000o`000?o<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04_ooool3o`000009oa0@4?ooooooooooo`00
0?o^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9So000001Gooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHo`000009ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo
ool02_l0003ooooooooooooooooo0000ogMgMonHV9SooooooiRHV?mgMgL?ooooo`;o00001?ooool2
o`0000?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL0
2_ooool00ol0003oooooooooo`0>ooooo`05oa0@4?nj^[[oooooo`000?lb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooo`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Wooooo1Ol00004ooooo`Ko00001_ooool01Ol0003ooooooooooooo
oooo410@00;ooooo00?o0000oa0@4?ooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413oooooooooool0003o410@00Wooooo00?o0000ooooooooool01oooool6o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01_ooool01_l0003ooooooooooooooooo0000oa0@40?ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`05ooooo`;o00000_ooool00onHV9So8B4Qonk^kP04ooooo`05o`000?oooooo
ooooooooool@41002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000?ooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo013ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00KoA4A4omgMgOoooooo0000ooooool00002oooo
o`05o`000?ooooooooooooooool000002?ooool2o`0000?ooooo0_l0000>ooooo`03ojVYZOl@413o
oooo00;ooooo00?o0000ooooooooool00_l0000Eooooo`03o`000?oooooooooo00Gooooo00?oV9RH
ob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`07ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h2ooooo`;o00000oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ojVYZOl@41000oooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04?ooool01?l0003ogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo0000
0_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0;ooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000ooooooooool0
0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool00ol0003ooooo
ooooo`02o`0000[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00[ooooo1ol000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool2o`00
0005okZj^_ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00kooooo00Go0000omgMgOmEEEGoooooo`000004ooooo`05o`000?ooooooooooooooool00000
3_ooool001Cooooo00?oMgMgolc<c?l000000_ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@ooooool0003ooooooa0@400Eooooo`03o`000?oooooooooo00Oooooo
00Go0000oooooooooooooooooa0@4002ooooo`03o`000?l@413ooooo00Wooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0>ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@00gooooo00?o0000
ooooooooool03_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?nj^[[o8B4Q00?ooooo00Go410@oooooooooooooooo
oa0@4009ooooo`03o`000?oooooooooo00kooooo00Go0000oooooomgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000000oooool01_l0003o
MgMgoiRHV?ooooooV9RHogMgM`Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01Gooooo
00?o0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
oooo0000ogMgM`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`05o`000?nHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03?ooool01Ol@413oV9RHo`000?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09
ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00_ooool01_l0003ok^k^oc8b
<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo00?o0000
ooooooooool00oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`03o`000?oooooooooo00kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05
onk^k_l0003o0000oc8b<_o^k^h03?ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool03?oo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03
o`000?oooooooooo00gooooo00Ko0000ooooooooooooooooogMgMol00004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0J
ooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`;o00005_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Joooo
o`007Oooool2o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo0_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[o
oooo000Nooooo`Co00003oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo000aooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06oooool001Koooooool00010o`0001?ooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo017ooooo000booooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06oooool003;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`;o00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool003;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool07?ooool003;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool2o`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`00<oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool003?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo0_l0000:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool003?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo000cooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`00
<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7Oooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01kooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Eooooo`;o00000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01kooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Fooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool0
03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Oooooo0_l0000aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo000dooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`;o00002oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool003Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07oooool003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool003Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool003Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool003Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08?ooool003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`05o`00
0?ooooooooooooooool000008_ooool003Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Kooooo`05o`000?ooooooooooooooool000008_ooool003Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo0_l0000<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000Rooooo`00=Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00008oooool003Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000002?ooooo
000eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool2o`0002Cooooo000e
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool003Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`12ooooo`00=Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool5o`0000Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`12ooooo`00=Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`13ooooo`00=Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00000[ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`?o
00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`13ooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo023ooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0@oooool003Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04?ooooo000fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`13ooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0@oooool003Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`04
o`000?ooooooooooo`0002cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04?ooooo000fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0
003oooooo`00000]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo000fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08oooool2o`0002gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@oooool003Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`;o00003_ooool01Ol0003ooooo
oooooooooooo000005;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`00
=_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`00001Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A?ooool003Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
0000D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Cooooo000gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000005;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`00=oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00001Booooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0A?ooool003Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000D_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Cooooo000gooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000005?ooooo00Go0000oooooooo
ooooooooo`000016ooooo`00=oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00go
oooo00Go0000ooooooooooooooooo`00001Cooooo`05o`000?ooooooooooooooool00000A_ooool0
03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
05Cooooo00Go0000ooooooooooooooooo`000016ooooo`00=oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hoooo
o`;o00003oooool00ol0003oooooo`00001Dooooo`05o`000?ooooooooooooooool00000A_ooool0
03Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
05Cooooo00Go0000ooooooooooooooooo`000016ooooo`00>?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Doooool01Ol0003ooooooooooooooooo
000004Kooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Cooooo`05o`000?ooooooooooooooool00000A_ooool003Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1Uooooo`05o`000?ooooooooooooooool00000A_ooool0
03Sooooo00Go0000ooooooooooooooooo`00001Gooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo000h
ooooo`05o`000?ooooooooooooooool00000Eoooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool00017ooooo`00>?oo
ool01Ol0003ooooooooooooooooo000005Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo0000Aoooool003Sooooo
00Go0000ooooooooooooooooo`00001Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06Oooool2o`0006Kooooo00Co0000oooooooooooo0000Aoooool003Sooooo00Go0000oooooooo
ooooooooo`00001Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooo000004Oooooo000hooooo`05o`000?oooooooooooooo
ool00000F?ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0I_ooool2
o`0004Sooooo000iooooo`04o`000?ooooooooooo`0005Sooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oooooooooo06Kooooo0_l00018ooooo`00>Oooool01?l0003oooooooooool0
001Hooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`2`ooooo`00>Ooo
ool00ol0003oooooo`00001Iooooo`05o`000?ooooooooooooooool000004_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000ooooool00000FOoo
ool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2`ooooo`00>_ooool00ol0003oooooooooo`1Hooooo`05o`000?ooooooooooooooool00000
4?ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool003[ooooo00?o0000ooooooooool0F?oo
ool01Ol0003ooooooooooooooooo0000013ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3o
oooo002Eooooo`04o`000?ooooooooooo`00017ooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`2`ooooo`00UOooool01?l0003oooooooooool0000Booooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0/?ooool009Kooooo00?o0000ooooool000004_ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooo000001?ooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00U_ooool00ol0003oooooo`00
000Looooo`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooo000001cooooo00?o0000
ooooooooool0/?ooool009Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2`oooo
o`00Uoooool00ol0003oooooooooo`0Kooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<
c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool0
0:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413o
ZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b
/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002oooool0
0omEEEGoZJVYooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00?ooooo00Go
410@oooooooooooooooooa0@401looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00001looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003o
ooooooooo`0Mooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000ooooooooooooooooo`00001loooo
o`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03ojVYZOmg
MgOooooo00;ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003o<S8boooo
oooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01;ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1looooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o
410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003ooooooooo
o`0Jooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19653 m
.04057 .16941 L
.06168 .15562 L
.06747 .15181 L
.07065 .14988 L
.07365 .1484 L
.07501 .14786 L
.07646 .1474 L
.07721 .1472 L
.07804 .14701 L
.0788 .14688 L
.0795 .14678 L
.08082 .14667 L
.08155 .14666 L
.08224 .14668 L
.08347 .14682 L
.08481 .14715 L
.08616 .14771 L
.08692 .14814 L
.08763 .14862 L
.08892 .14975 L
.09028 .15135 L
.09264 .15525 L
.09398 .15821 L
.09524 .16153 L
.09804 .17113 L
.1006 .1829 L
.10356 .20083 L
.10636 .22297 L
.11586 .33754 L
.11847 .37316 L
.11984 .39037 L
.12128 .40652 L
.12254 .41849 L
.12393 .42869 L
.12519 .43496 L
.12636 .43802 L
.12768 .43811 L
.12893 .43493 L
.13005 .42944 L
.13126 .42087 L
.13258 .40873 L
.13398 .39319 L
.1365 .36037 L
.14206 .28135 L
.14726 .21981 L
.1517 .18251 L
.1542 .16691 L
.15647 .15539 L
.15896 .14535 L
Mistroke
.16167 .137 L
.16423 .13123 L
.16661 .12736 L
.16796 .12566 L
.16939 .12419 L
.17195 .12221 L
.17338 .1214 L
.17471 .1208 L
.17546 .12054 L
.17617 .12033 L
.17699 .12014 L
.17773 .12002 L
.179 .11993 L
.18034 .12001 L
.18148 .12022 L
.18275 .1206 L
.1841 .1212 L
.18556 .12205 L
.1882 .1241 L
.19057 .12649 L
.19317 .12973 L
.1957 .13363 L
.1984 .13882 L
.20325 .15165 L
.20775 .16844 L
.21336 .19652 L
.21853 .22903 L
.22409 .26771 L
.22704 .28683 L
.22866 .29605 L
.2302 .30357 L
.23153 .30893 L
.23224 .31128 L
.23298 .3134 L
.2343 .31613 L
.23552 .31748 L
.23674 .31767 L
.23788 .31682 L
.23914 .31477 L
.24049 .31132 L
.24181 .30684 L
.24326 .30082 L
.24617 .28589 L
.25137 .25457 L
.25691 .22293 L
.25963 .21009 L
.26214 .20024 L
.26438 .19313 L
.26684 .18703 L
.26932 .18258 L
Mistroke
.27067 .18082 L
.27194 .17956 L
.2733 .17862 L
.27407 .17827 L
.27478 .17805 L
.27608 .17792 L
.27681 .178 L
.27747 .17815 L
.27873 .17865 L
.28008 .1795 L
.28136 .18055 L
.28254 .18171 L
.28808 .18907 L
.29393 .19845 L
.29905 .2064 L
.30156 .20979 L
.30389 .21243 L
.30516 .21362 L
.30657 .21469 L
.30798 .21549 L
.30875 .21582 L
.30948 .21604 L
.31075 .21626 L
.31193 .21627 L
.31321 .21605 L
.31456 .2156 L
.31577 .21502 L
.31687 .21435 L
.31933 .21242 L
.32376 .20774 L
.33382 .19418 L
.33892 .18794 L
.34431 .1829 L
.34892 .17975 L
.35153 .17839 L
.35398 .17742 L
.35533 .17701 L
.3568 .17667 L
.35748 .17655 L
.3582 .17644 L
.35948 .1763 L
.36085 .1762 L
.36212 .17614 L
.36327 .17611 L
.36451 .17608 L
.36597 .17605 L
.36734 .17601 L
.36892 .17595 L
.37037 .17588 L
.37164 .17583 L
Mistroke
.37298 .17578 L
.37368 .17577 L
.37446 .17576 L
.37582 .17578 L
.37712 .17583 L
.37831 .17592 L
.37969 .17605 L
.38099 .17623 L
.38331 .17664 L
.38462 .17694 L
.38584 .17729 L
.38727 .17782 L
.38862 .17847 L
.38984 .17922 L
.39115 .18027 L
.39258 .18176 L
.3941 .18381 L
.39552 .18626 L
.39681 .18901 L
.39945 .19633 L
.40227 .20725 L
.40489 .2208 L
.40737 .23731 L
.41291 .28976 L
.41895 .3677 L
.4214 .39977 L
.42268 .41508 L
.42404 .42935 L
.42523 .43986 L
.42653 .44877 L
.42771 .45423 L
.42881 .45686 L
.4295 .45726 L
.43023 .45662 L
.43157 .45263 L
.43288 .44537 L
.43408 .43594 L
.43681 .40639 L
.4397 .36689 L
.44516 .28846 L
.45034 .22763 L
.45319 .20218 L
.4563 .18023 L
.45913 .16464 L
.46176 .15325 L
.46445 .14417 L
.46698 .13761 L
.46925 .13302 L
.47171 .12909 L
.47439 .12568 L
Mistroke
.47723 .1228 L
.47968 .12078 L
.4823 .11911 L
.48358 .11848 L
.48479 .11799 L
.48596 .1176 L
.48705 .11732 L
.48808 .11711 L
.48917 .11695 L
.49026 .11683 L
.49147 .11676 L
.49278 .11674 L
.49397 .11676 L
.49528 .11685 L
.49666 .11701 L
.49787 .11722 L
.49899 .11749 L
.50022 .11788 L
.50153 .11841 L
.50425 .11997 L
.50563 .12102 L
.50714 .12239 L
.50984 .12545 L
.5123 .12903 L
.51521 .13444 L
.51834 .1421 L
.52123 .15141 L
.52397 .16265 L
.52923 .19194 L
.53411 .22892 L
.53941 .27779 L
.5422 .30422 L
.54514 .32948 L
.54765 .3466 L
.54908 .35374 L
.5504 .35843 L
.55162 .36094 L
.55273 .36166 L
.55402 .36062 L
.55523 .35784 L
.55638 .35367 L
.55759 .34776 L
.55977 .33384 L
.56471 .2926 L
.56966 .24906 L
.575 .21054 L
.57805 .19394 L
.58085 .18226 L
.58219 .17778 L
.58366 .17367 L
Mistroke
.58495 .17069 L
.58633 .16817 L
.58772 .16622 L
.58901 .16494 L
.59039 .16406 L
.59117 .16378 L
.59191 .16365 L
.59323 .16372 L
.59444 .16412 L
.59511 .16446 L
.59584 .16493 L
.59716 .16603 L
.59964 .16892 L
.60227 .17306 L
.60699 .18292 L
.61759 .211 L
.62315 .22485 L
.62619 .231 L
.62767 .23348 L
.62901 .23537 L
.63019 .23675 L
.63148 .2379 L
.63283 .23873 L
.63411 .23914 L
.63478 .23921 L
.63552 .23918 L
.63629 .23902 L
.63701 .23876 L
.6383 .23804 L
.63968 .23692 L
.6423 .23396 L
.64479 .23031 L
.64946 .22202 L
.65465 .21186 L
.65954 .20286 L
.66429 .19571 L
.66866 .19088 L
.67102 .18891 L
.67351 .18725 L
.67601 .186 L
.67743 .18545 L
.67875 .18505 L
.67942 .18489 L
.68015 .18474 L
.68147 .18454 L
.68276 .18443 L
.68394 .1844 L
.68523 .18441 L
.68596 .18444 L
.68664 .18448 L
Mistroke
.6895 .18469 L
.69069 .18479 L
.69199 .18487 L
.69322 .18493 L
.69436 .18496 L
.69549 .18496 L
.69651 .18494 L
.69769 .18488 L
.69881 .1848 L
.70002 .18469 L
.70131 .18452 L
.70362 .18412 L
.7049 .18382 L
.7061 .18348 L
.70882 .1825 L
.71155 .18114 L
.71407 .17954 L
.71978 .17495 L
.73017 .16473 L
.74965 .14403 L
.75907 .13566 L
.76923 .12926 L
.77206 .12784 L
.77505 .12651 L
.77759 .12562 L
.77829 .12543 L
.77904 .12526 L
.78038 .12503 L
.78173 .12491 L
.7825 .12489 L
.7832 .12491 L
.7845 .12503 L
.78587 .12527 L
.78709 .12559 L
.78824 .12598 L
.79085 .12726 L
.79217 .12813 L
.79356 .12929 L
.79607 .13209 L
.79761 .13439 L
.79906 .13704 L
.80177 .14348 L
.80436 .15181 L
.80675 .16163 L
.80937 .17518 L
.81214 .19317 L
.81694 .23495 L
.82142 .28573 L
.8267 .35052 L
.82903 .37497 L
Mistroke
.83035 .38639 L
.83159 .39503 L
.83282 .40131 L
.83415 .40531 L
.83484 .40622 L
.83556 .40628 L
.83686 .40411 L
.83754 .40182 L
.83828 .39852 L
.83959 .3905 L
.84116 .37785 L
.84258 .36391 L
.84758 .3047 L
.85299 .24141 L
.85552 .21681 L
.85821 .19513 L
.86069 .17885 L
.86302 .16656 L
.86537 .15664 L
.86752 .14952 L
.86991 .14354 L
.87123 .14103 L
.87248 .13911 L
.87379 .13753 L
.87448 .13688 L
.87521 .1363 L
.87655 .13555 L
.87778 .13518 L
.87897 .13508 L
.88007 .1352 L
.88129 .13556 L
.88258 .13618 L
.88397 .13711 L
.88548 .13844 L
.88821 .1417 L
.89088 .146 L
.89334 .15101 L
.8978 .16269 L
.90272 .17923 L
.91266 .222 L
.91812 .2464 L
.92081 .25673 L
.9233 .26451 L
.92446 .2674 L
.92556 .26966 L
.92682 .27168 L
.92796 .27294 L
.92923 .27371 L
.9304 .27383 L
.93168 .27332 L
Mistroke
.93304 .27208 L
.9344 .27014 L
.93565 .26783 L
.93844 .26098 L
.94349 .24474 L
.94905 .22538 L
.95496 .20798 L
.95734 .20253 L
.95991 .19773 L
.96272 .1937 L
.96399 .19229 L
.96537 .19101 L
.96655 .19012 L
.96781 .18939 L
.96915 .18883 L
.97039 .1885 L
.97163 .18833 L
.9728 .18833 L
.97386 .18843 L
.975 .18864 L
.97635 .18901 L
.97762 .18945 L
.9805 .1907 L
.98634 .19351 L
.98892 .19461 L
.99138 .19548 L
.99273 .19587 L
.99421 .19621 L
.99555 .19644 L
.99679 .19658 L
.99766 .19662 L
.99848 .19663 L
.99921 .1966 L
1 .19653 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool6o`000;;ooooo001=ooooo`Co0000
GOooool2o`0000Gooooo0ol0002`ooooo`00C?ooool00ol0003oooooooooo`02ooooo`;o0000Fooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000;3ooooo001;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0005;ooooo1ol0001Fooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool01_ooool2o`0000;ooooo00?o0000ooooooooool0C_ooool2
o`0000Kooooo00?o0000ooooooooool0Doooool004[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00001>
ooooo`;o00002Oooool00ol0003oooooooooo`1Booooo`00BOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eoooo
o`Co0000>?ooool004Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000oooooooo
ool0=Oooool004Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Gooooo000_ooooo`;o00005oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=?ooool002cooooo1?l000000ooooooo0000o`00000E
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0d
ooooo`00:_ooool2o`0000Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool002Sooooo0_l00009ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00Wooooo0_l00005ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<oooool002Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`009_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo000Eooooo`;o000000Wo410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`06onk^k_lb<S;o0000
oc8b<_o^k^ko00003oooool00ol0003oooooooooo`08ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool3
o`0000?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@
4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003ooooooooo
o`0Hooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`00013ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000oooooooo
ool02oooool01Ol@413o^[Zjooooool0003o<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
4002ooooo`;o00003_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?l0003ooooo00oooooo00?o0000ooooool000001Ol00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol@413ooooooooooooooooo410@01Wooooo00Go0000oooooonHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0>ooooo`;o
00000oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool05_ooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004
ooooo`07o`000?ooooooooooooooool0003oooooo`00000Cooooo`03o`000?oooooooooo00Gooooo
00?oZJVYoa0@4?ooool00_ooool01?l0003oooooooooooooool2o`00013ooooo00?o0000oooooooo
ool02Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000001Sooooo
00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00kooooo00?o0000oa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool05Oooool01?m4A4CogMgMooooool00004ooooo`05o`00
0?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01?l0003o
ooooooooooooool2o`0001Cooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09ooooo`03ogMgMomVIVKo
oooo00;ooooo00?o0000ooooooooool00_l0000Gooooo`go00000oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000005oooool00ol0003oooooooooo`03ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?nj
^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool05Oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMg
olc<c?l000001?ooool01Ol@413oooooo`000?l0003o410@01Kooooo00?o0000ooooooooool01?oo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`0:ooooo`06o`000?ooooooooooooooool@413ooooo1?l0000Dooooo`?o00001_ooool01?l0
003oooooooooooooool2o`0000?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`0;
ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001?ooool01Ol@413ooooooooooooooooo410@01Gooooo0_l00007ooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0;ooooo`03o`000?oooooooooo00ko
oooo00?o0000ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooo
ooooool05_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo0000oooooonHV9SoMgMg01Kooooo00Wo0000
oooooooooooooooooa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So0000
01;ooooo00?o0000ooooooooool01_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00OoMgMg
o`000?ooooooV9RHogMgMooooooo000001;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMol0003ooooooiRHV?mgMgL04?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00001?ooool3o`00
00Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`0;ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00?o0000ooooooooool05_ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00_ooool2o`000004oc8b
<_l0003o<S8bonk^kQKooooo00Wo0000ooooooooooooooooojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;o000001;ooooo00?o0000ooooooooool01_ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Ook^k^o`000?l0003o<S8bonk^k_oooooo000001;ooooo00?o0000
ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`05ooooo`03o`000?mVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP09ooooo`Co000000?oooooo`000?l000000ol00007ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo00?o0000ooooooooool02_ooool01OnY
ZJWo410@o`000?l0003oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oo
oooooooo01Oooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
000Hooooo`;o00007?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`Oo00006?ooool001Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool2o`0002cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00oooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo000Foooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06oooo
o`Co00004oooool003Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`00
=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oooooo000Foooooooo0000@?l0
000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Cooooo00?o0000ooooool000001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo0_l00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool003Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03?ooool2o`000003ooooool0003o000001[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Pooooo`00>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`;o00007Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo023ooooo000hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`00>?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool003Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo000hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`00
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool00000=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`00>?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool2o`000003oooo
ool0003ooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08_ooool003Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo0ol0000hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02;ooooo000hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo000iooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02?ooooo000iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02?ooooo000iooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo
000iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Cooooo000iooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`;o00002_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool003Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000009oooool0
03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`05o`000?oooooooooo
ooooool000009oooool003Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`05o`000?ooooooooooooooool000009oooool003Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Dooooo`;o000000?oooooo`000?ooool09oooool003Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Eooooo`;o0000:Oooool003Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`11ooooo`00>Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo047ooooo000jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`00>_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo000jooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`11ooooo`00>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo000j
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo1Ol00006ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooo000003Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11
ooooo`00>_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ool00000=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo000jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool003_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`11ooooo`00>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo000kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00>ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_oo
ool003_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04?ooool2o`0000cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool0
03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04;ooooo000kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool01Ol0003o
oooooooooooooooo000005Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12oooo
o`00>oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo
oooo0000EOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo000kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0001Eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@_ooool003_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0005Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`12ooooo`00>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooool00000EOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04?ooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooo`00001Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
@oooool003_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`;o0000E_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo000kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo0_l0000>ooooo`;o0000E_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04?ooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0I_ooool01Ol0
003ooooooooooooooooo000004Gooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo000kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo000koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00016
ooooo`00>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Kooooo00Co0000oooo
oooooooo0000A_ooool003_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Voooo
o`04o`000?ooooooooooo`0004Kooooo000looooo`05o`000?ooooooooooooooool00000F_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0I_ooool0
1?l0003oooooooooool00016ooooo`00??ooool01Ol0003ooooooooooooooooo000005_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`;o0000Ioooool01?l0003ooooooooo
ool00016ooooo`00??ooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo
0000A_ooool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`00
04Kooooo000looooo`05o`000?ooooooooooooooool00000Foooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00016
ooooo`00??ooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo0000A_oo
ool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Iooo
ool2o`0004Oooooo000looooo`05o`000?ooooooooooooooool00000Foooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Wooooo`;o0000Aoooool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool5o`0000Kooooo00?o0000ooooooooool0/?oo
ool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool003gooooo00Co
0000oooooooooooo0000Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00?Oooool00ol0003ooooo
o`00001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;3ooooo000mooooo`03o`000?oooooo000005cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0/?ooool003gooooo00?o0000ooooool00000GOooool01?l0003oooooooooool0
000;ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool003gooooo00?o0000
ooooool00000GOooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo0;3ooooo000m
ooooo`03o`000?oooooo000005gooooo00Co0000oooooooooooo00005?ooool00ol0003ooooooooo
o`2`ooooo`00?_ooool2o`0005gooooo00Co0000oooooooooooo00005?ooool00ol0003ooooooooo
o`2`ooooo`00?_ooool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`0001Cooooo0_l0
002aooooo`00WOooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo0;3ooooo002M
ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0/?ooool009gooooo00Co0000
oooooooooooo00005?ooool00ol0003oooooooooo`2`ooooo`00WOooool01?l0003oooooooooool0
000Dooooo`03o`000?oooooooooo0;3ooooo002Nooooo`;o00005Oooool00ol0003oooooooooo`2`
ooooo`00W_ooool2o`0001Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj
^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_oo
ool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[o
oooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool00ol0003o
k^k^ooooo`03ooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002ooo
ool00omEEEGoZJVYooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0O?ooool008Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00Cooooo
00?oV9RHob4Q8Oo^k^h0OOooool008Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko
00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`Ko00003?ooool00olQ8B7oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^
07cooooo0025ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo
00?oEEEEolc<c?ooool01Oooool00omgMgOoIVIVooooo`1kooooo`00QOooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o410@o`000?l000000ol0000Looooo`03ojVYZOmgMgOooooo00Kooooo00?o0000oooo
ooooool0N_ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go
410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool008Cooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool5o`0000?ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c01looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(74) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19161 m
.01975 .17197 L
.04057 .14496 L
.05077 .13409 L
.05638 .12902 L
.06168 .12518 L
.06795 .1218 L
.07092 .12048 L
.07365 .11942 L
.07625 .11863 L
.07756 .11834 L
.07831 .11822 L
.079 .11814 L
.07975 .11807 L
.08046 .11804 L
.0818 .11807 L
.08255 .11813 L
.08324 .11822 L
.084 .11834 L
.08481 .11851 L
.08611 .11886 L
.08754 .11936 L
.08894 .11997 L
.09043 .12078 L
.09183 .12171 L
.09311 .12274 L
.09561 .12541 L
.0971 .12753 L
.09848 .12993 L
.10161 .13721 L
.10436 .14618 L
.10729 .1589 L
.10979 .17292 L
.11248 .19206 L
.11736 .2398 L
.12311 .31779 L
.12592 .35929 L
.12847 .39393 L
.12967 .408 L
.13097 .42097 L
.1322 .43065 L
.13333 .43705 L
.13453 .441 L
.13585 .44182 L
.13723 .4387 L
.13852 .43222 L
.1392 .42752 L
.13994 .42144 L
.14129 .40808 L
.14382 .37679 L
Mistroke
.14951 .2951 L
.15508 .22771 L
.15819 .20049 L
.16101 .18176 L
.16365 .16844 L
.16504 .16285 L
.1665 .15788 L
.16778 .15427 L
.16919 .15106 L
.17047 .14878 L
.17167 .14717 L
.173 .14592 L
.17367 .1455 L
.17441 .14517 L
.17572 .14495 L
.17694 .1451 L
.17764 .14532 L
.17838 .14566 L
.1797 .14651 L
.18112 .14773 L
.18267 .1494 L
.18528 .15301 L
.18807 .15802 L
.19308 .17056 L
.19834 .18838 L
.2033 .20826 L
.21258 .24843 L
.21513 .25867 L
.21787 .2682 L
.21919 .27209 L
.22045 .27525 L
.22159 .27764 L
.22281 .27967 L
.22409 .28122 L
.22528 .28211 L
.22656 .28252 L
.22728 .28249 L
.22797 .28231 L
.22866 .28198 L
.22939 .28148 L
.23069 .2802 L
.2321 .27834 L
.23363 .2758 L
.2436 .25219 L
.2485 .2406 L
.25302 .23253 L
.25553 .22931 L
.25819 .22673 L
.26085 .2248 L
.26379 .22323 L
Mistroke
.26623 .22226 L
.26885 .2215 L
.27132 .221 L
.27359 .22064 L
.2762 .22018 L
.27766 .21984 L
.27898 .21946 L
.28203 .2182 L
.28486 .21659 L
.29558 .20902 L
.30541 .20228 L
.3078 .2009 L
.31037 .19972 L
.31184 .1992 L
.31318 .19882 L
.3158 .19829 L
.3186 .19785 L
.32165 .19733 L
.32453 .19669 L
.32719 .19596 L
.33227 .19435 L
.33484 .19334 L
.33767 .19185 L
.34014 .1901 L
.34283 .18764 L
.34827 .18131 L
.358 .1682 L
.36948 .15054 L
.3799 .13795 L
.38499 .13258 L
.38767 .13018 L
.38913 .1291 L
.3905 .12826 L
.3918 .12762 L
.39298 .12717 L
.3943 .1268 L
.39502 .12665 L
.39571 .12654 L
.3969 .12641 L
.39801 .12636 L
.39922 .12637 L
.40051 .12648 L
.40123 .12659 L
.402 .12676 L
.40337 .12722 L
.40413 .12758 L
.40484 .12799 L
.40567 .1286 L
.40646 .1293 L
.40788 .13094 L
Mistroke
.40916 .13292 L
.41055 .13562 L
.41206 .13932 L
.41469 .14788 L
.41749 .16028 L
.41988 .1741 L
.42251 .19371 L
.42512 .21886 L
.42796 .25406 L
.43315 .33779 L
.43577 .38475 L
.43825 .42591 L
.44047 .45602 L
.44173 .46876 L
.44288 .47724 L
.44415 .48263 L
.44488 .48375 L
.44555 .4835 L
.44692 .47923 L
.44768 .4747 L
.44838 .46928 L
.44982 .45453 L
.45139 .4338 L
.45424 .38746 L
.45969 .29227 L
.46235 .25219 L
.4648 .22175 L
.46707 .19893 L
.46954 .17912 L
.47204 .16364 L
.47466 .15113 L
.47739 .14148 L
.47892 .13738 L
.4803 .13437 L
.4816 .13213 L
.483 .13027 L
.48433 .12897 L
.48555 .12812 L
.48682 .12753 L
.48819 .12717 L
.48948 .12702 L
.49065 .12704 L
.49203 .1272 L
.49281 .12736 L
.49353 .12755 L
.49485 .12801 L
.49626 .12868 L
.49774 .1296 L
.49933 .13088 L
.50222 .13405 L
Mistroke
.50503 .13823 L
.50761 .14299 L
.51255 .15449 L
.51785 .17126 L
.52285 .19298 L
.5274 .21809 L
.53288 .25293 L
.53868 .29005 L
.54107 .30328 L
.54364 .31491 L
.54512 .31999 L
.54646 .32348 L
.54775 .3257 L
.54911 .32682 L
.55037 .32673 L
.55152 .32572 L
.55284 .32351 L
.55408 .32047 L
.5563 .31311 L
.5587 .30295 L
.56918 .25234 L
.5747 .23216 L
.57748 .22496 L
.57906 .22179 L
.58053 .21942 L
.58189 .21773 L
.58317 .21653 L
.58432 .21576 L
.58558 .21522 L
.58694 .21495 L
.58763 .21493 L
.58839 .21499 L
.58973 .21527 L
.59099 .21572 L
.59222 .2163 L
.59354 .21706 L
.59591 .2187 L
.60129 .22313 L
.60397 .22533 L
.60687 .22738 L
.6082 .22813 L
.60961 .22877 L
.61082 .22916 L
.61215 .22944 L
.61347 .22954 L
.61468 .22948 L
.61534 .22939 L
.61607 .22925 L
.6174 .22888 L
.61863 .22841 L
Mistroke
.61995 .22779 L
.62232 .22641 L
.62717 .22275 L
.63157 .21874 L
.63665 .21396 L
.6414 .21016 L
.64635 .20735 L
.64897 .20628 L
.65178 .20538 L
.65484 .20461 L
.65774 .20406 L
.66317 .20331 L
.6656 .20294 L
.66683 .2027 L
.66819 .20237 L
.66965 .20193 L
.67102 .20142 L
.67364 .20015 L
.6762 .19853 L
.67858 .19671 L
.68397 .19156 L
.69484 .17709 L
.71427 .14815 L
.72533 .13525 L
.73076 .13036 L
.73576 .12641 L
.74022 .12344 L
.74513 .12088 L
.75006 .11883 L
.75528 .11698 L
.7579 .11622 L
.75928 .11588 L
.76076 .11557 L
.76217 .11533 L
.76345 .11516 L
.76474 .11503 L
.76595 .11494 L
.76714 .11487 L
.7684 .11482 L
.76947 .1148 L
.77064 .11479 L
.77191 .1148 L
.77326 .11483 L
.77454 .1149 L
.7757 .11499 L
.77707 .11515 L
.77776 .11526 L
.77851 .11541 L
.78111 .1161 L
.78257 .11664 L
Mistroke
.78414 .11736 L
.78698 .11902 L
.78983 .1212 L
.79255 .12385 L
.79498 .12686 L
.79764 .13108 L
.80032 .13662 L
.80321 .14447 L
.80595 .15402 L
.80846 .16494 L
.81324 .19236 L
.81828 .2327 L
.82373 .28848 L
.8289 .34304 L
.83175 .36723 L
.83254 .37252 L
.83337 .37738 L
.83409 .38092 L
.83486 .384 L
.83619 .38741 L
.83744 .3884 L
.83817 .38798 L
.83893 .38675 L
.8403 .38263 L
.84158 .37661 L
.84276 .36951 L
.84539 .34904 L
.85013 .30353 L
.85529 .25544 L
.85801 .23457 L
.8609 .21668 L
.86335 .20481 L
.86465 .19969 L
.86604 .19501 L
.86732 .19144 L
.8685 .18874 L
.86969 .18652 L
.87079 .18491 L
.8719 .18369 L
.87308 .18283 L
.8744 .18235 L
.87559 .18232 L
.87671 .18262 L
.87793 .18328 L
.87908 .18419 L
.88014 .18526 L
.88273 .18865 L
.88508 .19253 L
.89038 .20322 L
.89993 .22519 L
Mistroke
.90527 .23589 L
.90829 .24055 L
.90973 .24236 L
.91108 .24379 L
.91235 .2449 L
.91351 .24573 L
.9148 .24643 L
.91548 .2467 L
.9162 .24693 L
.91754 .24717 L
.91879 .24719 L
.92016 .24699 L
.92093 .24678 L
.92163 .24653 L
.92289 .24596 L
.92406 .24528 L
.92673 .24329 L
.93213 .2379 L
.9418 .22713 L
.95301 .21647 L
.96364 .20915 L
.97274 .20442 L
.98265 .20028 L
1 .19161 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
D?ooool7o`0005Wooooo000^ooooo`Co0000N?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0COooool4o`0000Gooooo0_l0001Hooooo`00;?ooool3o`0000;ooooo0ol0
0021ooooo`03o`000?oooooooooo04[ooooo0ol0000;ooooo`;o0000E_ooool002[ooooo0_l00007
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05?ooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0001Loooo
o`Ko00006Oooool3o`000003ooooool0003ooooo04Sooooo0_l0000Booooo`03o`000?oooooooooo
05;ooooo000Wooooo`;o00003?ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool2o`0001Ko
oooo0_l00002ooooo`Co0000Aoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo057o
oooo000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool2o`0004Oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1Aooooo`009_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`;o00001Oooool2o`0004Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Aooooo`009Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo0_l00015
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool002Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000004?ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`1@ooooo`008oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01?ooooo0ol0000mooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000004;ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`1@ooooo`008oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00_l0000kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00043o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`008_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`00043ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1?ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Coooool0023ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1?ooooo`007oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo04kooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_l0
00006?ooool01ol0003ooooooiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00?o0000ooooool000000ol000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o0000ooooooooool01?ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?oooooo0000ogMgM`0Iooooo`06o`000?l@413o^[ZjoooooomgMgOo<S8b0ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0;ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@ooooool0003ooooooa0@400Booooo`Ko000000?oooooo`000?ooool00ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@400Cooooo`Oo00001?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Booooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool03oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`;o00000_ooool00ol0
003oooooooooo`0Gooooo`06o`000?oooooooooooooooonYZJWo410@0oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004Oooool0
0ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000I
ooooo`06o`000?oooooooooooa0@4?l0003o^[Zj0oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003ooooooooo
o`0:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000?ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0Goooo
o`06o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooooooo410@00;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l00000
0_ooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL06Oooool01_l0003o410@oiRHV?oooooo
^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooooooo
ool02_ooool01_l@413oV9RHoooooonj^[[o0000ooooo`Co000000?ooooooiRHV?mgMgL07?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00CoMgMg
o`000?oooooo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Ko0000ojVYZOl@413o
0000oa0@4?nYZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo00?o0000ooooooooool02Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oo
oooooooo00[ooooo00WoZJVYoa0@4?l0003o410@ojVYZOoooooo0000ooooooo^k^h00_l000000olb
<S;ok^k^ooooo`0Looooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`005oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0fooooo`005_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`;o
00006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo0_l0000Cooooo`00
>Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9Oooool3o`0001cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`;o0000
5Oooool003Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo027ooooo1?l0000Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo0_l0000[ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Gooooo000iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Mooooo`?o00008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`Co0000;Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool3
o`0001Sooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00oooooo0ol0000=ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool07oooool003[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Gooooo0_l0000/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_l0000;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool003[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017o
oooo1Ol0000]ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`00>_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool2o`0003;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o0000
?Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool2o`0002Gooooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`08ooooo`?o0000?oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`00>oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool2
o`0000Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Kooooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oo
oooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool2o`0000Cooooo
00?o0000ooooooooool0:?ooool003_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0?ooooo`Go0000:oooool003_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0o
ooooo`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03oooooo000kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0?oooool003_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03oooooo000looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?ooo
ool003cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0oooooo`00??ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03oooooo000looooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0@?ooool003cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`10ooooo`00??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00Go
0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043ooooo000looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooo`00000oooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo043ooooo000looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool2
o`00043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`10ooooo`00??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0@?ooool003cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo043ooooo000looooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`00??ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool003cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo000moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06oooo
o`03o`000?oooooo000000Co00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
047ooooo000mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`06ooooo`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0@Oooool003gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00Ko0000ooooooooooooV9RHob4Q8Oo^
k^h7ooooo`?o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`00?Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool01ol0003ooooooooooooo
ooooV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
0000EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047ooooo000mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool00000EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047o
oooo000mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`04o`000?ooooooooooo`0005Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`11ooooo`00?Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool01?ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@1_ooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0005Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`11ooooo`00?Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool01?ooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7o
c<c<1_ooool00ol0003oooooooooo`0<ooooo`?o0000E_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo047ooooo000mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@_ooool003gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0@_ooool003gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool2
o`0006Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00?Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`12ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12
ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00
?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`;o0000Iooo
ool01Ol0003ooooooooooooooooo000004Gooooo000nooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo000nooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo
000nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ioooool01?l0003ooooooooo
ool00015ooooo`00?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Oooooo00Co
0000oooooooooooo0000AOooool003oooooo00Go0000ooooooooooooooooo`00001Looooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Wooooo`04o`00
0?ooooooooooo`0004Gooooo000oooooo`05o`000?ooooooooooooooool00000G?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ioooool01?l0003o
ooooooooool00015ooooo`00?oooool01Ol0003ooooooooooooooooo000005cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ool00000A_ooool003oooooo00Go0000ooooooooooooooooo`00001Looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03?ooool2o`0006Wooooo0_l00016ooooo`00?oooool01Ol0003o
oooooooooooooooo000005cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo0;3ooooo000oooooo`05o`000?ooooooooooooooool00000G?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0/?ooool003oo
oooo00Go0000ooooooooooooooooo`00001Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`2`ooooo`00?oooool01Ol0003ooooooooooooooooo0000
05cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0;3ooooo000oooooo`05o`000?ooooooooooooooool00000G?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo000oooooo`05o`000?ooooooooooooooool00000GOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00?oooool01Ol0003ooooooooooooooooo000005gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool0/?ooool003oooooo00Go0000oooo
ooooooooooooo`00001Mooooo`05o`000?ooooooooooooooool000001?ooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000/?ooool003oooooo00Go0000ooooooooooooooooo`00001Mooooo`05o`00
0?ooooooooooooooool000001?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0;3ooooo000oooooo`04o`000?ooooooooooo`0005kooooo00Go0000ooooooooooooooooo`000005
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool003oooooo00Co0000oooo
oooooooo0000G_ooool01Ol0003ooooooooooooooooo000000Gooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`2`ooooo`00?oooool01?l0003oooooooooool0001Nooooo`05o`000?oo
ooooooooooooool000001_ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo
0010ooooo`03o`000?oooooo000005kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`00
0?oooooooooo0;3ooooo0010ooooo`03o`000?oooooo000005kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo0;3ooooo0010ooooo`03o`000?oooooo000005kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo0;3ooooo0010ooooo`;o0000Gooo
ool01Ol0003ooooooooooooooooo000000oooooo0_l0002aooooo`00@Oooool00ol0003ooooooooo
o`1Mooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`2`ooooo`00X_oo
ool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo0;3ooooo002Rooooo`04o`000?oo
ooooooooo`0000oooooo00?o0000ooooooooool0/?ooool00:;ooooo00Co0000oooooooooooo0000
3oooool00ol0003oooooooooo`2`ooooo`00X_ooool01?l0003oooooooooool0000?ooooo`03o`00
0?oooooooooo0;3ooooo002Rooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool0
/?ooool00:;ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`2`ooooo`00X_oo
ool00ol0003oooooo`00000@ooooo`;o0000/Oooool00:;ooooo00?o0000ooooool000004?ooool0
0ol0003oooooooooo`2`ooooo`00X_ooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo
0;3ooooo002Rooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0/?ooool00:?ooooo
0_l0000@ooooo`03o`000?oooooooooo0;3ooooo002Sooooo`;o00004?ooool00ol0003ooooooooo
o`2`ooooo`00Xoooool2o`00013ooooo00?o0000ooooooooool0/?ooool00:?ooooo0_l0000@oooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Z
ooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@
402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o
0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?o
oooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`03o`000?o^k^kooooo00Gooooo
0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;
ooooo`03oeEEEOnYZJWooooo00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00?ooooo1Ol0001l
ooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00CoA4A4omgMgOoooooo0000OOooool008Gooooo
00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00omEEEGoc<c<oooo
o`02ooooo`04omgMgOmEEEGoooooo`0007gooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo
00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@
413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool00oooool00omgMgOoc<c<o`00001moooo
o`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?ok^k^odA4A?l00000OOooool008Cooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06_ooool5o`0000Gooooo00?oMgMgo`000?ooool0O?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(76) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1618 m
.00942 .14435 L
.01975 .13089 L
.02496 .12593 L
.03053 .12182 L
.03578 .11905 L
.04057 .11716 L
.04332 .11626 L
.04624 .11545 L
.04873 .11491 L
.05014 .11468 L
.05147 .11449 L
.05301 .11433 L
.05442 .11423 L
.0552 .11418 L
.05593 .11415 L
.05678 .11412 L
.05758 .11409 L
.05828 .11407 L
.05904 .11406 L
.06036 .11404 L
.0611 .11404 L
.06189 .11404 L
.06257 .11404 L
.06331 .11405 L
.064 .11406 L
.06475 .11409 L
.06612 .11415 L
.06745 .11424 L
.06868 .11436 L
.07 .11453 L
.07147 .11476 L
.07443 .11538 L
.07978 .11685 L
.08239 .11773 L
.08481 .11868 L
.08974 .12135 L
.09235 .1233 L
.09513 .12587 L
.09806 .12916 L
.10083 .13295 L
.10334 .13714 L
.106 .14263 L
.10831 .14852 L
.11085 .15648 L
.11532 .17508 L
.11784 .18859 L
.12055 .20595 L
.12543 .24556 L
.13058 .2978 L
Mistroke
.13607 .35552 L
.13769 .37026 L
.13923 .38216 L
.1406 .39085 L
.14131 .3945 L
.14209 .3978 L
.14282 .40022 L
.1435 .40185 L
.14422 .40291 L
.14499 .40328 L
.14571 .40292 L
.14639 .40196 L
.14766 .39861 L
.14888 .39364 L
.15022 .38635 L
.15292 .36695 L
.15778 .32398 L
.16314 .27868 L
.16606 .25882 L
.16877 .24408 L
.17123 .23369 L
.17385 .2254 L
.17535 .22181 L
.17676 .2191 L
.17802 .21719 L
.1794 .21562 L
.18057 .21465 L
.18186 .21393 L
.1832 .21354 L
.18446 .21347 L
.18564 .21362 L
.18671 .21392 L
.18795 .21442 L
.18913 .21505 L
.19457 .21914 L
.19962 .22392 L
.21104 .23661 L
.22045 .24833 L
.2254 .25439 L
.23061 .25977 L
.23195 .26083 L
.23339 .26179 L
.23421 .26223 L
.23496 .26257 L
.23572 .26285 L
.23643 .26304 L
.23774 .26323 L
.23843 .26324 L
.23917 .26318 L
.2404 .26291 L
Mistroke
.24176 .26237 L
.24312 .26159 L
.24437 .26066 L
.24717 .25789 L
.25223 .25089 L
.26189 .23451 L
.26444 .23056 L
.26719 .22683 L
.26962 .22412 L
.27218 .2219 L
.27366 .22094 L
.27527 .22013 L
.27598 .21985 L
.27674 .2196 L
.27811 .2193 L
.2788 .2192 L
.27955 .21915 L
.28092 .21916 L
.28224 .21931 L
.28347 .21954 L
.28472 .21987 L
.28589 .22024 L
.28855 .22123 L
.29135 .22231 L
.29271 .22276 L
.29395 .2231 L
.29518 .22334 L
.29634 .22346 L
.29756 .22346 L
.29889 .2233 L
.30025 .22293 L
.30094 .22266 L
.3017 .22231 L
.30303 .22151 L
.30428 .22056 L
.30702 .21782 L
.30953 .21453 L
.31516 .20457 L
.33459 .15944 L
.33962 .14934 L
.34497 .14018 L
.35458 .12827 L
.36047 .12309 L
.36336 .12104 L
.36602 .11948 L
.37099 .11734 L
.37361 .1165 L
.37636 .11575 L
.37905 .1151 L
.38037 .11483 L
Mistroke
.38159 .1146 L
.38268 .11444 L
.38387 .11429 L
.38508 .11419 L
.38635 .11414 L
.38774 .11414 L
.38901 .11419 L
.38971 .11424 L
.39047 .1143 L
.39187 .11444 L
.39458 .11476 L
.39704 .11509 L
.39936 .11546 L
.40187 .11599 L
.40326 .11638 L
.40453 .11682 L
.40703 .11795 L
.40918 .1192 L
.41154 .12087 L
.41631 .12519 L
.41894 .12835 L
.42181 .13288 L
.42451 .1387 L
.42702 .14585 L
.42927 .15403 L
.43175 .16533 L
.43678 .19738 L
.43963 .22253 L
.44223 .25106 L
.44811 .33335 L
.45325 .40992 L
.45473 .42825 L
.45613 .44266 L
.45738 .45268 L
.45874 .46003 L
.45998 .46327 L
.46134 .46294 L
.46203 .46123 L
.46276 .45827 L
.46409 .45011 L
.46542 .43873 L
.46667 .42534 L
.46903 .3951 L
.47366 .3278 L
.4786 .26433 L
.48143 .23654 L
.484 .21691 L
.48657 .20181 L
.489 .19118 L
.49038 .18647 L
Mistroke
.49184 .18245 L
.49308 .17975 L
.49445 .1775 L
.49522 .17654 L
.49592 .17586 L
.49673 .17528 L
.49749 .17493 L
.49885 .17475 L
.49962 .17487 L
.50033 .17512 L
.50157 .17584 L
.50288 .17694 L
.50521 .17965 L
.50772 .18344 L
.51046 .18849 L
.51996 .21277 L
.53131 .24712 L
.53667 .2611 L
.54161 .27126 L
.54408 .27501 L
.5467 .2779 L
.54806 .27896 L
.54933 .27972 L
.55004 .28005 L
.55072 .28031 L
.5515 .28054 L
.55222 .28069 L
.55342 .28084 L
.55471 .28086 L
.5558 .28079 L
.55701 .28062 L
.5583 .28034 L
.5597 .27995 L
.56223 .27899 L
.56489 .27766 L
.56781 .27585 L
.5737 .27137 L
.58424 .26058 L
.62678 .22329 L
.6317 .22594 L
.63411 .22721 L
.63631 .22819 L
.6375 .22861 L
.63863 .22891 L
.63982 .22909 L
.64112 .22913 L
.64245 .22896 L
.64319 .22876 L
.64387 .22852 L
.64518 .22788 L
Mistroke
.64642 .22705 L
.64776 .22589 L
.64919 .22439 L
.65174 .22102 L
.6575 .21065 L
.66773 .18623 L
.6784 .16077 L
.68405 .14962 L
.69011 .13965 L
.69583 .13226 L
.70104 .12707 L
.7059 .12319 L
.71125 .1198 L
.7163 .11748 L
.71907 .11652 L
.72167 .11577 L
.7263 .11468 L
.72891 .11421 L
.7313 .11389 L
.73257 .11377 L
.73393 .11368 L
.73521 .11363 L
.73637 .11361 L
.73774 .11363 L
.73851 .11365 L
.73923 .11367 L
.74054 .11374 L
.74192 .11383 L
.74467 .11406 L
.74724 .11435 L
.75007 .11479 L
.7531 .11543 L
.75578 .11617 L
.75862 .11713 L
.76374 .11918 L
.76983 .12225 L
.77534 .12597 L
.78057 .13048 L
.78622 .13649 L
.79155 .14366 L
.79645 .15207 L
.8014 .16276 L
.8067 .17724 L
.81626 .2143 L
.82755 .27628 L
.83251 .30437 L
.83533 .31813 L
.83671 .32388 L
.83797 .32843 L
.83917 .33206 L
Mistroke
.84048 .33519 L
.84186 .33751 L
.84317 .33874 L
.84456 .339 L
.84533 .33869 L
.84603 .33813 L
.8474 .33632 L
.84869 .33379 L
.8501 .33019 L
.8516 .32557 L
.85428 .31565 L
.86032 .2896 L
.86518 .26951 L
.8704 .25223 L
.87339 .24488 L
.87612 .23983 L
.87743 .23792 L
.87886 .23622 L
.88022 .23493 L
.88147 .23402 L
.88266 .23336 L
.88391 .23288 L
.88517 .23261 L
.88655 .23253 L
.88774 .23263 L
.88902 .23289 L
.89023 .23327 L
.89132 .23371 L
.89692 .23693 L
.90221 .24016 L
.90488 .2414 L
.90623 .24186 L
.907 .24208 L
.90771 .24224 L
.90897 .24244 L
.91033 .24253 L
.91159 .24249 L
.91279 .24235 L
.91417 .24206 L
.91494 .24184 L
.91563 .24161 L
.91827 .24041 L
.92136 .23846 L
.92426 .23622 L
.92957 .23173 L
.93453 .22803 L
.93702 .22656 L
.9397 .22534 L
.94122 .22481 L
.94266 .22441 L
Mistroke
.94396 .22414 L
.94469 .22403 L
.94536 .22395 L
.94648 .22386 L
.94767 .22382 L
.9488 .22383 L
.94984 .22389 L
.95099 .22399 L
.95225 .22413 L
.95478 .22446 L
.95606 .22461 L
.95728 .22472 L
.95795 .22475 L
.95868 .22477 L
.95995 .22474 L
.96117 .22461 L
.96246 .22437 L
.96356 .22406 L
.96477 .22359 L
.96695 .22242 L
.96933 .22062 L
.97157 .2184 L
.97365 .2159 L
.98176 .20219 L
1 .1618 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`009Oooool:o`0005oooooo1ol0000Eooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`14ooooo`[o0000H_ooool002;ooooo0ol0000:ooooo`;o0000F_oo
ool4o`0000Kooooo0ol0000Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`11ooooo`?o00002_ooool3o`0005oooooo000Pooooo`;o00003oooool2o`0005Kooooo0_l0
000=ooooo`;o00006oooool00ol0003oooooooooo`0oooooo`;o00004?ooool2o`0005gooooo000O
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0B
ooooo`;o0000Foooool001gooooo0_l0000Eooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Hooooo`007?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`;o
0000?Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Oooooo000Looooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05Kooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo000Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo05Cooooo000Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo05?ooooo000Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05?o
oooo000Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo05;ooooo000Hooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05;ooooo000G
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Cooooo0_l0000hooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0D_ooool001Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0DOooool001Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Aooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Ko0000oiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aoooo
o`03o`000?oooooooooo00Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
2?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0<ooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Oooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@oooooooo
oooo0000onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`00
0?oooooooooo00gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ol0003oooooooooo`0=ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooo
oonHV9SoMgMg3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@01;ooooo1_l00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooo
oooooooo410@01?ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000
ooooooooool03_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Iooooo`Go000000Coooooo`000?oooooo410@0oooool00ol@413oooooooooo`0<ooooo`00
4oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0
003ooooooooooonYZJWo410@00?ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool04_ooool2o`0002?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool04?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000003?ooool00ol0003oooooooooo`0?ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Kooooo`06odA4A?oMgMgoooooo`000?oooooo00000_ooool01Ol0003o
oooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000Jooooo`05o`000?oooooo410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`0@ooooo`Co00008_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Aooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00KogMgMoeEEEOoooooo
0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@01[ooooo00Go0000oooooooooooo^[Zjob4Q
8@03ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ool000000_l0000Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008
ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41007?ooool01?mgMgOoc<c<o`000?l00003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01[ooooo00Go410@o`000?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Wooooo00?o0000ooooooooool03oooool01_l0003oooooooooool0003oooooo`00027ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
3oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=oooo
o`03o`000?oooooooooo00_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07?ooool01?o^k^koA4A4o`000?l00003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[o
oooo00GoZJVYo`000?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`00
0?oooooooooo00_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wo
oooo00?o0000ooooooooool03oooool01_l0003oooooooooool0003oooooo`0001oooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03
o`000?oooooooooo00[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07Oooool00omgMgOo0000o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool003_ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Eooooo`00>oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05Oooool003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Kooooo000looooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Fooooo`00??ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool05oooool001Koooooool00010o`0001?ooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool04Oooool003cooooo00?o0000ooooooooool04?oo
ool4o`0002Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Iooooo`00?Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo000mooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`Oo00000oooool2o`00
02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool06oooool003gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool5o`0002_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07Oooool3o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Tooooo`[o00007Oooool003gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Kooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0003Kooooo00?o0000oooooooo
ool08Oooool2o`0002Oooooo000mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`04ooooo`?o0000=oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02Kooooo000mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool04?ooool5o`0000[ooooo0_l0000Yooooo`00?Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0?ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0:Oooool0
03kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_l0000/ooooo`00?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Ko
oooo1?l0000^ooooo`00?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo
000nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>Oooool003kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0jooooo`00?_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo0_l00006ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0>_ooool003kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo0_l00009ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo000nooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04_ooool4o`0003kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2oooool2o`0004_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`00?_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo0_l0000oooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03_ooooo000nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0looooo`00?_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0??ooool003oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03cooooo000oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`00?oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00cooooo1_l0001Cooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0??ooool003oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`0006Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0mooooo`00?oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0moooo
o`00?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0mooooo`00?oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`00?ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0mooooo`00?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0nooooo`00?oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool5o`00
00Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03kooooo000oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`04ooooo`05oiRHV?lQ8B7ok^k^o`000?m4A4@01_ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool003oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Ol0
00001oooool3o`0006Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0nooooo`00
?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
1_ooool00onHV9So0000onk^kP06ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0oooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool01Oooool00ol0003oMgMgofIVIP06ooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`00@?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000006ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0oooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool00oooool01Ol0003o^[Zjo`000?nHV9So410@00Kooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo0010oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@?ooool0043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool0043o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Yooooo`04o`000?ooooooooooo`00
04?ooooo0010ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0001Zooooo`04o`000?ooooooooooo`00
04?ooooo0010ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J_ooool2o`0004Co
oooo0010ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J_ooool2o`0004Cooooo
0011ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/?ooool0047ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2`ooooo`00@Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0;3ooooo0011ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/?ooool0047ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2`ooooo`00@Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo0011ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo0_l0002aooooo`00@_ooool01Ol0003ooooooooooooooooo000005kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0012oooo
o`05o`000?ooooooooooooooool00000G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool004;ooooo00Go0000ooooooooooooooooo`00001N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00@_ooool01Ol0003ooooooooooooooooo000005kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0012ooooo`05o`000?oooooooooo
ooooool00000G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool004;ooooo00Go0000ooooooooooooooooo`00001Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00@_ooool01Ol0
003ooooooooooooooooo000005kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo0012ooooo`05o`000?ooooooooooooooool00000G_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l0002aooooo`00@_ooool01Ol0
003ooooooooooooooooo000005kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`03o`000?oooooo0000063ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`03
o`000?oooooo0000063ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;3ooooo0013ooooo`03o`000?oooooo0000063ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`;o0000HOoo
ool00ol0003oooooooooo`02ooooo`?o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`2`ooooo`00Y_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool0/?ooool00:Kooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooo
oooo0;3ooooo002Vooooo`08o`000?ooooooooooooooool0003ogMgMooooool00007ooooo`?o0000
/?ooool00:Kooooo00So0000ooooooooooooooooo`000?mEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0/?ooool00:Kooooo00So0000ooooooooooooooooo`000?mgMgOoc<c<o`0000Oooooo00?o
0000ooooooooool0/?ooool00:Kooooo00So0000ooooooooooooooooo`000?o^k^koA4A4o`0000Oo
oooo00?o0000ooooooooool0/?ooool00:Kooooo00So0000ooooooooooooooooo`000?ooooooMgMg
o`0000Oooooo00?o0000ooooooooool0/?ooool00:Kooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooooooo0;3ooooo002Vooooo`05o`000?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`2`ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool0/?ooool00:Oooooo00Co0000oooooooooooo00002_ooool2o`000;7ooooo002Woooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0/?ooool00:Oooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`2`ooooo`00Yoooool00ol0003oooooo`00000;oooo
o`03o`000?oooooooooo0;3ooooo002Wooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo
ool0/?ooool00:Oooooo00?o0000ooooool000002oooool00ol0003oooooooooo`2`ooooo`00Yooo
ool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0;3ooooo002Xooooo`;o00002oooool0
0ol0003oooooooooo`2`ooooo`00Z?ooool2o`0000_ooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Z
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
0omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<
0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oo
oooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWo
oooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l00000
1_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000
odA4A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0O?oo
ool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002oooool00omEEEGoZJVYooooo`03oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B40O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool0
0ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00?ooooo00Go0000ooooooooooooooooo`00
001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@1loooo
o`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03oeEE
EOo<c<cooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c01looooo`00QOooool01_l0003oQhN7
ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o410@o`000?l000000ol0000Looooo`03ojVYZOmgMgOooooo00;ooooo00?oEEEE
ohN7Qoooool0O_ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo
00Go410@oooooooooooooooooc8b<P03ooooo`03omgMgOl@413oV9RH07kooooo0024ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo1Ol00004ooooo`04olc<c?m4A4Co0000oa0@
47cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(78) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .12237 m
.00488 .11947 L
.00942 .11756 L
.01204 .11674 L
.01441 .11615 L
.01716 .11563 L
.01839 .11544 L
.01975 .11526 L
.02096 .11513 L
.02227 .11501 L
.02365 .11492 L
.02494 .11486 L
.02622 .11482 L
.02744 .11481 L
.02854 .11481 L
.02973 .11484 L
.03047 .11486 L
.03116 .11489 L
.03245 .11497 L
.03384 .11508 L
.03535 .11522 L
.03807 .11555 L
.04057 .11593 L
.04587 .11701 L
.05082 .1184 L
.05626 .12041 L
.06208 .12316 L
.06819 .12682 L
.07397 .13114 L
.08481 .14156 L
.10571 .16891 L
.11502 .18302 L
.12505 .20147 L
.13033 .2148 L
.13516 .23099 L
.13979 .25103 L
.14465 .27726 L
.15003 .31043 L
.15511 .34034 L
.15792 .35336 L
.1595 .35891 L
.16026 .36102 L
.16097 .36266 L
.1622 .36472 L
.16355 .36576 L
.16487 .36553 L
.16561 .36486 L
.16628 .36393 L
.16756 .36132 L
.16892 .35743 L
Mistroke
.17137 .34793 L
.17692 .31888 L
.18177 .29211 L
.1845 .2789 L
.18701 .26868 L
.18955 .26045 L
.19094 .25688 L
.19223 .25414 L
.19345 .25205 L
.19457 .25056 L
.19581 .24936 L
.19713 .24856 L
.19831 .24825 L
.19939 .24827 L
.20058 .2486 L
.20184 .24926 L
.20294 .25006 L
.20396 .25097 L
.2063 .2535 L
.21166 .26013 L
.21428 .26289 L
.21542 .26387 L
.21665 .26472 L
.21794 .26536 L
.21917 .2657 L
.21984 .26578 L
.22056 .26576 L
.22185 .2655 L
.22253 .26524 L
.22325 .26487 L
.22456 .26396 L
.22611 .26249 L
.22753 .26082 L
.23696 .24525 L
.23925 .24149 L
.24172 .238 L
.24313 .23637 L
.24443 .23514 L
.24567 .23425 L
.24697 .2336 L
.24822 .2333 L
.24954 .23331 L
.2508 .23364 L
.25194 .23422 L
.25328 .23523 L
.25473 .2367 L
.25737 .2403 L
.26699 .25865 L
.26836 .26106 L
.26983 .26333 L
Mistroke
.2712 .26507 L
.27249 .26633 L
.27318 .26683 L
.27394 .26722 L
.27527 .26751 L
.27603 .26743 L
.27685 .26714 L
.27762 .26667 L
.27832 .26607 L
.27967 .26446 L
.28091 .26245 L
.28371 .25616 L
.28617 .24879 L
.28878 .23954 L
.2995 .19503 L
.30477 .17488 L
.30965 .15926 L
.31398 .14802 L
.31876 .13831 L
.32357 .13099 L
.32623 .12781 L
.32867 .12537 L
.33376 .12149 L
.33643 .12 L
.33925 .11876 L
.3417 .11793 L
.34399 .11732 L
.34649 .11684 L
.3479 .11664 L
.34917 .11649 L
.35054 .11638 L
.35123 .11634 L
.35199 .1163 L
.35334 .11627 L
.35459 .11626 L
.35536 .11627 L
.35608 .11629 L
.35743 .11634 L
.35818 .11638 L
.35889 .11643 L
.36047 .11656 L
.36318 .11685 L
.36564 .11718 L
.37114 .11816 L
.3817 .12073 L
.3914 .12381 L
.40205 .1281 L
.40793 .13108 L
.41328 .13439 L
.41807 .13799 L
Mistroke
.42327 .14287 L
.42876 .14959 L
.43396 .15804 L
.43882 .16848 L
.44398 .18329 L
.44838 .2 L
.45323 .22385 L
.45868 .25843 L
.46386 .2984 L
.46857 .33744 L
.4736 .37468 L
.47506 .38334 L
.47645 .3902 L
.47769 .39515 L
.47903 .39911 L
.48031 .40146 L
.48166 .40242 L
.48281 .40199 L
.48408 .40024 L
.48484 .39855 L
.48557 .39654 L
.48693 .39176 L
.48999 .37702 L
.49552 .34228 L
.50565 .28139 L
.51076 .25925 L
.51371 .24933 L
.51641 .2419 L
.5187 .23679 L
.52121 .23238 L
.52373 .22912 L
.52511 .22783 L
.52638 .22693 L
.5276 .22635 L
.52876 .22604 L
.52979 .22598 L
.53091 .22612 L
.53213 .22655 L
.53343 .2273 L
.53453 .22819 L
.53575 .22944 L
.5471 .2528 L
.55269 .26877 L
.55541 .27613 L
.55787 .28196 L
.55903 .2843 L
.56029 .28649 L
.56137 .28806 L
.56256 .28941 L
.56382 .2904 L
Mistroke
.56516 .29091 L
.56639 .29089 L
.56755 .29045 L
.56892 .28941 L
.57021 .28793 L
.57264 .28399 L
.57525 .27837 L
.57809 .27121 L
.5834 .25724 L
.58599 .25114 L
.58837 .24646 L
.59086 .24274 L
.59218 .24134 L
.59355 .24031 L
.59424 .23997 L
.59497 .23972 L
.59629 .23962 L
.59709 .23976 L
.59785 .24003 L
.59853 .24039 L
.59927 .2409 L
.60049 .24199 L
.60163 .24328 L
.60422 .24705 L
.60946 .25691 L
.61182 .2615 L
.61433 .26583 L
.61648 .26872 L
.6177 .26991 L
.61885 .27067 L
.62016 .27108 L
.62137 .27099 L
.62269 .27034 L
.62336 .26979 L
.62409 .26901 L
.62552 .26698 L
.62704 .26405 L
.6298 .25694 L
.63523 .23744 L
.64018 .21634 L
.64963 .17753 L
.65481 .16044 L
.65965 .14769 L
.66463 .1376 L
.67011 .1294 L
.67476 .12435 L
.67976 .12047 L
.68256 .11884 L
.68561 .11744 L
.68849 .11642 L
Mistroke
.69116 .11571 L
.69252 .11542 L
.69381 .1152 L
.69498 .11503 L
.69621 .1149 L
.69755 .11479 L
.69879 .11473 L
.70013 .11469 L
.70088 .11469 L
.70159 .1147 L
.70291 .11475 L
.70358 .11478 L
.70432 .11483 L
.70562 .11493 L
.70685 .11506 L
.7096 .11545 L
.71257 .11601 L
.71799 .11743 L
.72296 .11916 L
.73246 .12346 L
.74245 .12929 L
.76342 .14376 L
.78247 .15699 L
.78756 .16092 L
.79307 .16595 L
.79783 .17133 L
.80307 .17881 L
.80863 .18903 L
.81452 .20282 L
.82507 .23431 L
.83008 .25049 L
.83555 .26683 L
.84071 .2794 L
.84318 .2841 L
.84549 .28773 L
.84841 .29125 L
.85105 .29358 L
.85389 .29537 L
.85549 .29614 L
.85696 .29673 L
.86206 .29829 L
.86462 .29889 L
.86608 .29917 L
.86743 .29938 L
.86872 .29952 L
.87008 .29959 L
.87145 .29954 L
.87223 .29945 L
.87296 .29932 L
.87427 .29897 L
Mistroke
.87547 .29848 L
.87686 .2977 L
.87818 .29673 L
.88061 .29429 L
.88286 .29121 L
.88796 .28141 L
.89928 .25196 L
.90198 .24531 L
.90483 .23919 L
.90727 .23494 L
.90867 .23297 L
.90994 .2315 L
.91127 .23032 L
.91252 .22954 L
.91385 .22907 L
.91459 .22898 L
.91529 .22899 L
.91644 .22924 L
.91771 .22983 L
.91903 .23078 L
.92028 .23199 L
.92309 .23568 L
.92566 .24003 L
.93147 .25147 L
.93366 .25562 L
.93601 .25942 L
.93736 .26118 L
.93859 .26245 L
.93982 .26335 L
.94098 .26383 L
.9422 .26392 L
.94348 .26353 L
.94458 .26279 L
.94579 .26154 L
.94709 .25969 L
.94848 .25714 L
.951 .25111 L
.97172 .17405 L
.97739 .15695 L
.98344 .14303 L
.98915 .13346 L
.99432 .12722 L
1 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`007?ooool6o`0008Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo03[ooooo1_l0001`ooooo`006?ooool5o`0000Gooooo1_l0001Jooooo`go00006ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0>?ooool3o`0000Gooooo
1?l0001/ooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Gooooo0ol0
000<ooooo`?o00008oooool00ol0003oooooooooo`0fooooo`;o00003?ooool3o`0006Wooooo000F
ooooo`03o`000?oooooooooo013ooooo0_l0001Dooooo`03o`000?oooooooooo013ooooo0_l0000Q
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03oooool2o`0005;ooooo0_l0000C
ooooo`00:oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01?ooooo0_l0000Ooooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool05_ooool3o`0001cooooo0_l0000dooooo`03o`000?oooooooooo01Cooooo0_l0001>ooooo`03
o`000?oooooooooo01?ooooo000]ooooo`;o0000C_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool05?ooool002oooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0Jooooo`;o00006_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Sooooo0_l0001:ooooo`03o`000?oooooooooo01Cooooo000`ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Gooooo000aooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo01Kooooo000aooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool07_ooool2o`0004Cooooo00?o0000ooooooooool05_ooool003;ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool05oooool003?ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Qooooo`;o0000@?ooool00ol0003oooooooooo`0Gooooo`00<oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04oooool2o`00033ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Oooooo000doooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01Sooooo000eooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Sooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05Oooool00ol0003oooooooooo`02
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0@ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00?o0000ooooooooool05?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`03o`000?oooooooooo017ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h06_ooool00ol0003oooooooooo`02o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`09o`000?ooooooooooooooool@413o^[ZjoooooomgMgOo<S8b00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?o0000ooooooooool05?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`;o00004Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?ooooooooooooooool000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool02?ooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4002ooooo`03
o`000?oooooooooo01Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00[ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool06?ooool6o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooo
ooooo`03ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool04Oooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000006Oooool01_l0003oooooodA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000006?ooool01ol0003ooooooooooooooooo410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooooooo`0?ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`06o`000?oooooogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400Iooooo`06o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooo
oooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002oooool00ol0003oooooooooo`0@ooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0Iooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01Wooooo00Ko0000ooooooooooooMgMg
olc<c?l00004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo01Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0=ooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo00Oo0000ooooooooooooooooonk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003o410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool01oo^k^ko<S8bo`000?lb<S;ok^k^oooo
ool000006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`03o`000?oooooooooo00cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06?ooool00ol0003oooooooooo`02ooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00>oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Kooooo`00
??ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Looooo`00??ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Looooo`00?Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Looooo`00?_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Looooo`005_ooooooo`00043o
00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`00?oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Nooooo`00
?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Nooooo`00@?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Nooooo`00@?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Nooooo`00@?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`Co00008?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool0047o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Hooooo`Co00002oooool00ol0003oooooooooo`0Ooooo
o`00@Oooool00ol0003oooooooooo`0Pooooo`?o00003?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00cooooo0_l00005ooooo`05o`000?ooooooooooooooool000007oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooooooo01oooooo0011ooooo`03o`000?oooooooooo01oooooo0_l000000ooo
oooo0000o`00000:ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo0011ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03oooool2o`0000_ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Pooooo`00@_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023o
oooo0012ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Pooooo`00@_ooool00ol0003oooooooooo`0?ooooo`?o00002_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo027ooooo0012ooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00@_ooool00ol0003ooooooooo
o`0>ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`00
@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02o`0002?ooooo0013ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000003Sooooo
00?o0000ooooooooool02_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`Co00009?ooool004?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`Co00003_ooool01?l0003ooooo
o`000?l0000hooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000012
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool2o`0002Gooooo0013oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool3o`0003Wooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01?l0003oooooo`000?l00012ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<oooool004?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo0ol00013ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<oooool004Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooool000003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0doooo
o`00A?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Cooooo0014ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0=Oooool004Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Wooooo0ol0000?ooooo`;o00000ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Ooo
ool004Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooool000004?ooool01?l0003oooooooooool0001Gooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0=_ooool004Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Wooooo0_l0000Booooo`?o0000F?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo0014ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`09ooooo`;o0000K_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo0015ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`09ooooo`;o0000Koooool2o`0000Go
oooo00?o0000ooooooooool0>?ooool004Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00Wooooo0_l0001aooooo`Ko0000>_ooool004Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`Ko00001_ooool2o`000;7ooooo0015
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool01_l0003oV9RHob4Q8Oo^
k^koooooodA4A0Kooooo00?o0000ooooooooool0/?ooool004Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Gooooo`05o`000?ooooooV9RHob4Q8Oo^k^h01oooool3o`000;3ooooo
0015ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooiRH
V?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0/?ooool004Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Iooooo`05o`000?ooooooooooogMgMomVIVH01_ooool00ol0003ooooo
ooooo`2`ooooo`00AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo0016ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0FOooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
0_l0002booooo`00A_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00Go
0000oa0@4?l0003o8B4Qolc<c005ooooo`;o0000/_ooool004Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oooooo0_l0002booooo`00A_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01_ooool2
o`000;;ooooo0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`06ooooo`?o0000/Oooool004Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000/_ooool004Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool00000/_ooool004Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000/_ooool004Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool00000/_ooool004Sooooo00Go0000ooooooooooooooooo`00001Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool00000/_ooool004Sooooo00Go0000ooooooooooooooooo`00001N
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000/_ooool004Sooooo00Co0000oooo
oooooooo0000Goooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000;;ooooo0018oooo
o`04o`000?ooooooooooo`00063ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00002b
ooooo`00BOooool00ol0003oooooo`00001Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_l0002aooooo`00BOooool3o`00063ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool0002booooo`00[?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
0;;ooooo002/ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000/_ooool00:co
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0002booooo`00[?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`000;;ooooo002]ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000/_ooool00:gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0002booooo`00[Oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0002aoooo
o`00[Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0/?ooool00:go
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?l0003ooooo00Cooooo00?o
0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`
ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoo
oooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00
Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[o
oooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o0000
0;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo
00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooo
oooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0J
ooooo`03o`000?o^k^kooooo00?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01looooo`00QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;ooooo`03oeEEEOnYZJWooooo00?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooo
oooo01cooooo00?oZJVYoeEEEOooool00oooool01Ol0003ooooooooooooooooo000007cooooo0025
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o8B4Qooooooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b07cooooo0025ooooo`06
o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?oEEEEolc<c?ooool0
0_ooool01Oo<c<co0000o`000?l0003oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mE
EEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol@413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool00_ooool01Ol@413o^[Zjoooooonj
^[[o410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05
oa0@4?oooooooooooooooolb<S800oooool01Ol0003o^[Zjoooooonj^[[o000007cooooo0024oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo1Ol00003ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .11662 m
.00123 .11668 L
.00236 .11677 L
.00365 .11689 L
.00488 .11705 L
.00706 .11739 L
.00942 .11786 L
.01479 .11931 L
.01975 .12112 L
.02985 .12632 L
.04057 .13416 L
.05157 .14425 L
.06341 .15541 L
.06914 .1599 L
.07196 .1617 L
.07458 .16308 L
.07695 .16407 L
.07947 .16485 L
.08091 .16517 L
.08227 .16539 L
.08349 .16552 L
.08481 .1656 L
.08601 .16562 L
.08729 .16559 L
.0885 .16551 L
.08961 .16541 L
.0909 .16526 L
.09231 .16506 L
.09487 .16464 L
.09755 .16419 L
.09901 .16397 L
.10039 .16381 L
.10156 .16371 L
.10282 .16365 L
.1035 .16364 L
.10422 .16366 L
.1055 .16376 L
.10669 .16393 L
.10778 .16416 L
.10903 .16453 L
.11021 .16499 L
.11231 .1661 L
.11459 .16776 L
.1171 .17023 L
.11976 .17366 L
.12454 .18211 L
.1352 .2121 L
.14532 .24799 L
.14972 .26145 L
.15214 .26738 L
Mistroke
.15441 .27182 L
.15571 .27384 L
.15711 .2756 L
.15838 .27685 L
.15955 .27772 L
.16066 .27833 L
.16187 .27879 L
.16314 .27909 L
.16432 .27925 L
.16559 .27934 L
.16697 .27944 L
.16827 .27959 L
.16948 .27985 L
.17056 .28022 L
.17176 .28084 L
.17301 .28176 L
.17418 .28292 L
.17547 .28457 L
.17683 .28678 L
.17926 .29198 L
.18188 .29939 L
.18474 .30934 L
.19024 .33094 L
.19169 .33627 L
.19326 .34143 L
.19462 .34519 L
.19539 .34697 L
.19611 .34837 L
.19684 .34952 L
.19751 .35031 L
.19823 .35086 L
.19899 .35111 L
.20036 .35063 L
.20165 .34908 L
.2029 .34656 L
.20405 .34336 L
.20667 .33329 L
.21609 .27881 L
.22104 .25144 L
.22352 .24058 L
.22625 .23157 L
.2277 .2281 L
.2285 .22661 L
.22926 .22547 L
.22996 .22464 L
.23073 .22401 L
.23206 .22357 L
.23341 .22396 L
.23409 .22448 L
.23484 .2253 L
Mistroke
.23616 .22737 L
.2374 .23001 L
.24003 .23775 L
.24244 .24709 L
.24787 .27335 L
.25288 .29786 L
.25432 .3037 L
.25568 .30836 L
.2569 .31172 L
.25822 .31435 L
.25938 .31572 L
.26065 .31616 L
.26198 .31539 L
.26322 .31353 L
.26438 .31081 L
.26544 .30755 L
.26782 .2977 L
.27913 .22637 L
.2841 .19623 L
.28958 .16985 L
.292 .16065 L
.2946 .15227 L
.29931 .14068 L
.30194 .13589 L
.3047 .13187 L
.30729 .1289 L
.30964 .12674 L
.31225 .12486 L
.31504 .12336 L
.31762 .12235 L
.32006 .12168 L
.32144 .1214 L
.3229 .12117 L
.32415 .12102 L
.32552 .12089 L
.32629 .12084 L
.327 .12081 L
.32781 .12077 L
.32858 .12076 L
.32995 .12075 L
.33073 .12076 L
.33144 .12078 L
.3328 .12083 L
.33349 .12087 L
.33423 .12091 L
.3368 .12113 L
.33979 .12148 L
.34258 .12186 L
.35305 .1236 L
.3625 .12572 L
Mistroke
.37261 .12868 L
.37818 .13088 L
.38333 .13339 L
.38886 .13672 L
.39497 .14133 L
.40523 .1516 L
.41611 .16522 L
.4211 .17173 L
.42655 .17821 L
.4317 .18322 L
.43416 .1851 L
.43648 .18652 L
.43788 .18721 L
.43938 .1878 L
.44076 .18821 L
.44202 .18849 L
.44339 .18868 L
.44416 .18874 L
.44489 .18878 L
.44566 .18878 L
.44635 .18877 L
.44716 .18874 L
.44792 .18869 L
.44919 .18857 L
.45053 .18843 L
.45169 .1883 L
.45294 .18818 L
.45428 .18808 L
.45554 .18804 L
.45626 .18805 L
.45703 .1881 L
.4584 .18827 L
.45969 .18857 L
.46042 .18882 L
.4611 .18909 L
.46234 .18974 L
.46365 .19066 L
.46592 .19291 L
.46721 .19464 L
.46841 .19658 L
.47111 .20223 L
.47357 .20918 L
.47642 .21964 L
.47912 .23221 L
.4839 .26106 L
.48834 .29428 L
.49358 .33616 L
.49588 .35279 L
.4984 .36799 L
.49975 .37436 L
Mistroke
.501 .37903 L
.50232 .38251 L
.50307 .38379 L
.50374 .38453 L
.50448 .38488 L
.50517 .38478 L
.50591 .38421 L
.50671 .3831 L
.50805 .38014 L
.50881 .37789 L
.50952 .37545 L
.51456 .35182 L
.51998 .32399 L
.52256 .31342 L
.52495 .30603 L
.52616 .30328 L
.52745 .30105 L
.52819 .30011 L
.52888 .29943 L
.53018 .29867 L
.53132 .29853 L
.53252 .29884 L
.53354 .29943 L
.53467 .30036 L
.53718 .30321 L
.53953 .30622 L
.54085 .30779 L
.54225 .3092 L
.54345 .31009 L
.54477 .31065 L
.54551 .31073 L
.54618 .31065 L
.54693 .31038 L
.54771 .30988 L
.54903 .30852 L
.54978 .30745 L
.55048 .30627 L
.55311 .30018 L
.5555 .29265 L
.56086 .2712 L
.56566 .2509 L
.56819 .2414 L
.57087 .23306 L
.57321 .22764 L
.57455 .22545 L
.57579 .22403 L
.57694 .22329 L
.57798 .22309 L
.57919 .22346 L
.58034 .2244 L
Mistroke
.58164 .22619 L
.58287 .22855 L
.58414 .23171 L
.58554 .23598 L
.58847 .24752 L
.59117 .26077 L
.59651 .29103 L
.59884 .3039 L
.60137 .31595 L
.60256 .32054 L
.60383 .32448 L
.60491 .32698 L
.6061 .32874 L
.60721 .32937 L
.60841 .32892 L
.60954 .32742 L
.61058 .32513 L
.61177 .32146 L
.61288 .31711 L
.61539 .30428 L
.62045 .26986 L
.62602 .2284 L
.63127 .194 L
.63599 .16972 L
.64111 .15047 L
.6438 .14291 L
.64665 .13651 L
.64911 .13211 L
.65176 .12834 L
.65456 .12527 L
.65717 .12309 L
.65877 .12205 L
.66029 .12124 L
.66165 .12064 L
.66313 .12013 L
.66455 .11975 L
.66586 .11949 L
.66711 .11931 L
.66843 .1192 L
.66962 .11916 L
.67072 .11916 L
.67193 .11921 L
.67323 .11932 L
.67461 .11949 L
.67612 .11973 L
.67885 .12031 L
.68398 .12187 L
.69402 .12612 L
.7033 .13084 L
.71276 .13571 L
Mistroke
.72294 .14014 L
.72877 .14208 L
.73411 .1434 L
.74459 .14525 L
.74959 .14612 L
.75233 .1467 L
.75491 .14738 L
.75733 .14816 L
.75994 .14922 L
.76451 .15171 L
.76713 .15357 L
.77001 .15602 L
.77583 .16244 L
.78122 .17023 L
.78626 .17886 L
.79151 .18866 L
.79722 .19914 L
.80225 .20699 L
.8048 .21008 L
.80626 .21153 L
.80761 .21263 L
.80881 .21342 L
.81012 .21407 L
.81143 .21451 L
.81282 .21475 L
.81405 .21477 L
.81536 .21461 L
.8166 .2143 L
.81772 .21389 L
.82003 .21277 L
.82254 .21124 L
.82709 .20832 L
.82835 .20763 L
.82956 .20708 L
.83094 .20662 L
.83221 .20639 L
.8334 .20638 L
.83451 .20657 L
.83572 .20702 L
.83701 .20781 L
.83775 .20842 L
.83843 .20908 L
.83996 .21097 L
.84132 .21311 L
.84274 .21588 L
.84522 .22199 L
.84794 .23063 L
.85949 .28517 L
.86215 .2984 L
.86497 .31049 L
Mistroke
.86737 .31828 L
.86874 .32141 L
.87002 .32339 L
.87129 .32438 L
.87245 .32444 L
.87373 .32357 L
.87507 .32163 L
.87643 .31866 L
.87769 .31508 L
.88056 .30455 L
.88569 .28118 L
.89053 .26019 L
.8932 .2512 L
.89471 .24727 L
.8961 .24447 L
.89727 .24275 L
.89856 .24155 L
.8999 .2411 L
.90116 .24142 L
.90186 .2419 L
.90262 .24268 L
.90335 .24366 L
.90402 .24476 L
.90663 .25085 L
.90812 .2555 L
.90947 .26034 L
.9125 .27285 L
.91764 .29577 L
.92045 .30648 L
.92182 .31062 L
.92307 .31359 L
.92422 .31557 L
.9253 .3167 L
.92645 .31707 L
.9277 .31647 L
.92898 .31477 L
.93033 .31177 L
.93149 .30828 L
.93277 .30349 L
.93561 .28976 L
.93821 .27438 L
.94407 .23561 L
.94919 .20347 L
.95465 .17542 L
.96007 .15474 L
.96499 .14141 L
.96736 .1365 L
.96993 .13211 L
.97458 .12612 L
.97721 .12362 L
Mistroke
.98009 .12146 L
.9831 .11974 L
.98591 .11855 L
.98855 .11774 L
.99095 .11722 L
.99227 .117 L
.99372 .11682 L
.99508 .1167 L
.99634 .11663 L
.99724 .1166 L
.99808 .11659 L
.999 .1166 L
1 .11662 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool001Kooooo1?l0002@ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`2Hooooo`Go00004oooool001[ooooo1?l0001Nooooo`Oo0000<_ooool00ol0003ooooooooo
o`0`ooooo`Oo0000Goooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l00007
ooooo`Ko0000;?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo0ol0001K
ooooo`03o`000?oooooooooo01Sooooo000Oooooo`;o0000Eoooool2o`0000oooooo0ol0000Yoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool4o`0005Kooooo00?o0000oooo
ooooool06Oooool0027ooooo0_l0001Eooooo`03o`000?oooooooooo017ooooo1?l0000Uooooo`;o
0000;_ooool00ol0003oooooooooo`0>ooooo`;o0000Doooool00ol0003oooooooooo`0Jooooo`00
8oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Kooooo`008oooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01;ooooo0ol0001>ooooo`03o`000?oooooooooo01_ooooo000Tooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool05Oooool2o`0004cooooo00?o0000ooooooooool06oooool0
02Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Kooooo`;o00008?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo1?l00017ooooo`03o`000?oooooooooo
01cooooo000Vooooo`;o0000COooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Looooo`Co0000@oooool00ol0003o
ooooooooo`0Looooo`00:?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo027ooooo
0ol0000oooooo`03o`000?oooooooooo01gooooo000Yooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01gooooo000Z
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0K
ooooo`;o0000:oooool00ol0003oooooooooo`0Uooooo`;o0000>oooool00ol0003oooooooooo`0N
ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Nooooo`00;?ooool2o`0004Gooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01kooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03Oooool=o`000005oiRHV?l@413o
0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Eooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Oooooo`Co000000Go410@ooooooooooook^k^oc8b<P02o`000003onk^k_oooooooooo01Sooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Eooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo00?o0000
ooooooooool01Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o
000000Co^[ZjoooooomgMgOo<S8b0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9So0000oiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01Cooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;o
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000?ooooo00Co0000oooo
oooooooo00000oooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00gooooo
1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?oooooo0000ooooool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41001?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo1Ol00003ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000001cooooo00?o0000ojVYZOl@41000oooool01Ol0003ooooooooooooooooo0000
01gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_oo
ool01Ol0003oooooo`000?oooooo000001cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool05oooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`04ooooo`04odA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000007?ooool2o`000005okZj^_ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`00000Mooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Gooooo
00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooooooo
ool01?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01gooooo00?o0000
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooo
oa0@4003ooooo`04oa0@4?ooooooooooo`0001_ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool05?ooool2o`0002;ooooo00?o0000oooo
ooooool00_ooool01Ol@413oooooo`000?oooooo410@01kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool00ol0003oooooooooo`05ooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool00ol@413oV9RHooooo`02o`0000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg01[o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`0Booooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Cooooo00?o0000ooooooooool01Oooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o0000ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo01Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Wooooo0_l0000Cooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko0000o`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0Aooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo00?o0000oooooooo
ool01oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003ko
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`So00002oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Pooooo`00?_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Pooooo`00?oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo023ooooo000o
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo023ooooo000oooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo000Foooooooo
0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool6o`00
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?oooooo0000o`0000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
0011ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool4o`0000Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Rooooo`00@Oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0R
ooooo`00@_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Rooooo`00@_ooool00ol0003oooooooooo`0Jooooo`;o
00003_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool2o`0000kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02;ooooo0012ooooo`03o`000?oooooooooo01Wooooo0_l000000ooooooo0000
ooooo`0<ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Dooooo`;o000000?oooooo`000?ooool03?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool08_ooool004;ooooo00?o0000ooooooooool06Ooo
ool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0000gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo0013ooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Cooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool08oooool004?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Sooooo`00@ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo0013ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo00_ooooo0ol0000<ooooo`03o`000?oooooooooo02?ooooo0014ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Sooooo`00A?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool09?ooool0
04Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool09?ooool004Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool004Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`02ooooo`;o00004_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`00
AOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`00AOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`00A_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Uooooo`00Aoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`00Aoooool2o`0001;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Go
oooo0018ooooo`;o00004?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09Oooool004Wooooo1Ol0000<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Uooooo`00COooool2o`0000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooooooooooo
0_l0000@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Gooooo001>ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00Go
0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo001>ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo
001?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04?ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Gooooo001?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00Go0000oooooooooooooooo
o`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Gooooo001@ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00Go
0000ooooooooooooooooo`000008ooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`00D?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000nooooo`Go00000_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000:?ooool0057ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooo`0003oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000002So
oooo001Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01?l0003ooooo
ooooool00010ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool00ol00005ooooo`03
o`000?oooooooooo00;ooooo1?l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
oooo0000:Oooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`04
o`000?ooooooooooo`00047ooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00Cooooo0_l0000@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0C?ooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo0000
:Oooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`;o0000@ooo
ool00omgMgOoIVIVooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
5_ooool01Ol0003ooooooooooooooooo000004oooooo00Go0000ooooooooooooooooo`00000>oooo
o`;o0000:_ooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Kooooo00Go0000ooooooooooooooooo`00001@ooooo`04o`000?ooooooooooo`0000kooooo0_l0
000Zooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04oooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooo`00001Aooooo`03o`000?oooooo000003_ooooo001Booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Coooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000005;o
oooo0_l0000kooooo`00D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`0Hooooo`?o0000Soooool005;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2>ooooo`00D_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Wooooo00Co0000ooooool0003o00001?ooool00ol0003ooooooooo
o`2Zooooo`00Doooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`2Zooooo`00Doooool01Ol0003ooooooooooooooooo000005_ooooo00?o
0000ooooool000001?ooool00ol0003oooooooooo`2[ooooo`00Doooool01Ol0003ooooooooooooo
oooo000005_ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`2[ooooo`00E?ooool0
0ol0003oooooo`00001Mooooo`;o00001?ooool00ol0003oooooooooo`2[ooooo`00E?ooool3o`00
05gooooo0_l00004ooooo`03o`000?oooooooooo0:_ooooo001Eooooo`03o`000?oooooooooo05co
oooo0_l00004ooooo`03o`000?oooooooooo0:_ooooo002dooooo`;o00001?ooool00ol0003ooooo
ooooo`2[ooooo`00]?ooool2o`0000Cooooo00?o0000ooooooooool0Zoooool00;Cooooo0ol00002
ooooo`03o`000?oooooooooo0:cooooo002dooooo`;o00000oooool00ol0003oooooooooo`2/oooo
o`00]?ooool2o`0000?ooooo00?o0000ooooooooool0[?ooool00;Cooooo0_l00002ooooo`03o`00
0?oooooooooo0:gooooo002eooooo`04o`000?ooooooooooo`000:oooooo002eooooo`04o`000?oo
ooooooooo`000:oooooo002eooooo`03o`000?oooooo00000;3ooooo002eooooo`?o0000/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo
002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zooo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo
002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zj
oa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@
413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool0
0;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo0025ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Koooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0J
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@07cooooo
0025ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oo
ooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`00
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool00000O?oo
ool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01Oo<
c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool0
1_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj
^_l@41000oooool01Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?lb<S;ooooo
oooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo
01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(82) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13307 m
.00942 .14117 L
.01975 .15048 L
.02496 .15467 L
.02782 .15656 L
.03053 .15803 L
.03305 .1591 L
.03438 .15955 L
.03578 .15993 L
.03697 .16018 L
.03827 .16038 L
.03946 .16048 L
.04057 .16052 L
.04125 .1605 L
.04198 .16046 L
.0433 .16032 L
.0441 .16019 L
.04486 .16003 L
.04627 .15966 L
.04888 .15875 L
.0517 .15747 L
.06188 .15167 L
.06769 .1485 L
.07061 .14722 L
.07227 .14665 L
.07301 .14644 L
.07382 .14624 L
.07456 .14609 L
.07525 .14598 L
.0766 .14586 L
.07782 .14585 L
.07912 .14596 L
.0798 .14607 L
.08052 .14622 L
.08183 .1466 L
.08338 .14723 L
.08481 .148 L
.08742 .14989 L
.08979 .15219 L
.09252 .15561 L
.0951 .15966 L
.0997 .16886 L
.10468 .18153 L
.11503 .2127 L
.11786 .22074 L
.12091 .22815 L
.12239 .23111 L
.12379 .23346 L
.12504 .23516 L
.12641 .23653 L
Mistroke
.1271 .23701 L
.12783 .23739 L
.12917 .23767 L
.13047 .23746 L
.13166 .23685 L
.13296 .23575 L
.13438 .23404 L
.13724 .22921 L
.14244 .21705 L
.14728 .20422 L
.14991 .19762 L
.15277 .19132 L
.15408 .18885 L
.15546 .18659 L
.15666 .18496 L
.15795 .18358 L
.15872 .18296 L
.15942 .18252 L
.1608 .18206 L
.16153 .18204 L
.16233 .1822 L
.16316 .18257 L
.16393 .18312 L
.16532 .18461 L
.16657 .18653 L
.16801 .18947 L
.16938 .19298 L
.17166 .20055 L
.17415 .21132 L
.17868 .23786 L
.18389 .27785 L
.18865 .31705 L
.19141 .33697 L
.19292 .34601 L
.19433 .35291 L
.19554 .35738 L
.19683 .36065 L
.19754 .36171 L
.19827 .36229 L
.1996 .36192 L
.20082 .36 L
.20212 .35636 L
.20336 .35153 L
.20448 .34609 L
.20982 .31104 L
.21498 .27476 L
.2177 .25919 L
.21918 .25231 L
.22058 .24704 L
.22179 .24345 L
Mistroke
.22309 .24063 L
.22383 .23952 L
.22454 .23881 L
.22586 .23837 L
.22707 .239 L
.22819 .24047 L
.22942 .24306 L
.23073 .24693 L
.23223 .25272 L
.2336 .25927 L
.23671 .27793 L
.24233 .3199 L
.24498 .33914 L
.24744 .35405 L
.24869 .35988 L
.25002 .36457 L
.25078 .36647 L
.2515 .3677 L
.25284 .36849 L
.25404 .3675 L
.25533 .36464 L
.25655 .36029 L
.25767 .35497 L
.26026 .33836 L
.26299 .31598 L
.26857 .26417 L
.27376 .22026 L
.27823 .19061 L
.28301 .16734 L
.28573 .15736 L
.2883 .14982 L
.29062 .14437 L
.29311 .13973 L
.29562 .1361 L
.29798 .13343 L
.30077 .13096 L
.30333 .12919 L
.30598 .12774 L
.30738 .12712 L
.30888 .12658 L
.31031 .12615 L
.31161 .12583 L
.31291 .12559 L
.31414 .12541 L
.31527 .12529 L
.3165 .12518 L
.31779 .12511 L
.319 .12506 L
.32013 .12502 L
.32115 .125 L
Mistroke
.32234 .12498 L
.32346 .12498 L
.32468 .12498 L
.32597 .12501 L
.32707 .12506 L
.32828 .12514 L
.32958 .12525 L
.33099 .12542 L
.33352 .12584 L
.33618 .12643 L
.33902 .12716 L
.34412 .12873 L
.34725 .12993 L
.35019 .13133 L
.3557 .13475 L
.36583 .14338 L
.37679 .15639 L
.38761 .17029 L
.3929 .17606 L
.39521 .17814 L
.39772 .17997 L
.39908 .18073 L
.40033 .18128 L
.40153 .18167 L
.40281 .18192 L
.40414 .18203 L
.4054 .18197 L
.40677 .18175 L
.40755 .18156 L
.40826 .18134 L
.41095 .18016 L
.41248 .17926 L
.4139 .1783 L
.41983 .173 L
.42513 .16717 L
.43088 .16113 L
.43351 .15885 L
.4363 .1569 L
.43868 .15566 L
.44004 .15515 L
.4413 .15481 L
.44251 .15464 L
.44382 .15462 L
.44507 .15479 L
.44622 .15512 L
.44736 .15563 L
.44839 .15626 L
.44959 .15719 L
.45071 .15828 L
.45324 .16152 L
Mistroke
.45557 .16548 L
.46082 .17799 L
.47119 .217 L
.47689 .24292 L
.4797 .25454 L
.48229 .26361 L
.48473 .27011 L
.48596 .27253 L
.48732 .27448 L
.48867 .27564 L
.48943 .27594 L
.49013 .276 L
.49142 .27556 L
.49277 .27436 L
.49392 .27278 L
.49514 .27057 L
.49734 .26539 L
.50232 .25003 L
.50483 .24195 L
.50749 .23442 L
.50888 .23121 L
.50961 .22977 L
.5104 .22844 L
.51179 .22671 L
.51309 .22587 L
.51439 .22582 L
.51513 .22618 L
.51581 .22676 L
.51707 .22851 L
.5184 .23138 L
.51958 .23485 L
.5207 .23894 L
.52324 .25146 L
.52556 .26688 L
.52801 .28717 L
.53238 .33137 L
.53481 .35753 L
.53744 .38381 L
.53865 .39424 L
.53993 .40369 L
.54103 .41021 L
.54223 .41553 L
.54354 .4189 L
.54427 .41965 L
.54494 .4196 L
.54624 .41753 L
.54747 .41318 L
.54865 .40697 L
.54975 .39958 L
.55223 .37805 L
Mistroke
.55784 .31718 L
.56028 .29129 L
.56293 .26686 L
.56543 .24832 L
.56653 .24175 L
.56773 .23567 L
.56879 .23128 L
.56993 .22759 L
.57113 .22482 L
.57226 .22326 L
.57354 .22268 L
.57426 .2229 L
.57493 .22346 L
.57616 .22537 L
.57746 .22863 L
.57862 .2326 L
.57971 .23721 L
.5822 .25078 L
.59253 .33443 L
.59504 .35276 L
.59642 .36082 L
.59772 .36675 L
.59846 .36931 L
.59926 .37138 L
.59999 .3726 L
.60066 .37315 L
.60199 .37259 L
.60266 .37147 L
.6034 .3696 L
.6047 .36475 L
.60593 .35841 L
.60824 .34254 L
.61344 .29477 L
.61828 .24771 L
.62283 .21016 L
.62538 .19317 L
.62813 .17799 L
.63293 .15843 L
.63565 .15061 L
.63853 .14447 L
.64098 .14068 L
.64237 .13903 L
.64367 .13774 L
.64489 .13675 L
.6462 .13587 L
.6473 .13528 L
.6485 .13474 L
.64981 .13429 L
.65119 .13394 L
.65247 .13372 L
Mistroke
.65367 .1336 L
.65488 .13354 L
.65602 .13356 L
.65704 .13362 L
.65816 .13374 L
.65938 .13392 L
.66067 .13416 L
.663 .1347 L
.67378 .13742 L
.67674 .13803 L
.67986 .1386 L
.68256 .13901 L
.68405 .13918 L
.68546 .13932 L
.68676 .13941 L
.6875 .13944 L
.68819 .13947 L
.68939 .13949 L
.69068 .13947 L
.69187 .13944 L
.69299 .13938 L
.69422 .13931 L
.69555 .1392 L
.70129 .13864 L
.70663 .13806 L
.70913 .1378 L
.71148 .13759 L
.71279 .1375 L
.71352 .13746 L
.7142 .13743 L
.7154 .13741 L
.71667 .13742 L
.71797 .13747 L
.7187 .13752 L
.71937 .13759 L
.72067 .13774 L
.7219 .13795 L
.72333 .13825 L
.72465 .1386 L
.72765 .13964 L
.73055 .14103 L
.73328 .14272 L
.73838 .14703 L
.74387 .15354 L
.7498 .16274 L
.76064 .18348 L
.76594 .19351 L
.77076 .20094 L
.77201 .20245 L
.77338 .20386 L
Mistroke
.77455 .20487 L
.77585 .20574 L
.77723 .20637 L
.77798 .20659 L
.77869 .20672 L
.77995 .20674 L
.78131 .20648 L
.78204 .20621 L
.78272 .2059 L
.78425 .20492 L
.78575 .20364 L
.78735 .20195 L
.79288 .19397 L
.80365 .17508 L
.8066 .17064 L
.80973 .16681 L
.81101 .16554 L
.81239 .16441 L
.81318 .16388 L
.81391 .16347 L
.81465 .16313 L
.81532 .16289 L
.81663 .16264 L
.81734 .16262 L
.81802 .16268 L
.81922 .163 L
.82052 .16365 L
.8212 .16413 L
.82196 .16476 L
.82347 .16641 L
.82487 .1684 L
.82618 .17068 L
.82879 .17647 L
.83116 .18326 L
.83649 .20395 L
.84624 .25717 L
.84882 .27173 L
.85158 .28569 L
.85292 .29144 L
.8542 .29612 L
.85535 .29962 L
.85659 .30249 L
.85793 .30453 L
.85917 .30538 L
.85993 .30539 L
.86065 .30506 L
.86199 .30356 L
.86271 .30228 L
.86347 .30058 L
.86484 .29674 L
Mistroke
.86793 .28479 L
.87341 .25715 L
.87841 .23207 L
.88085 .22189 L
.88215 .21734 L
.88352 .21324 L
.88471 .21032 L
.88603 .20785 L
.88723 .20632 L
.88836 .20553 L
.88966 .20543 L
.89103 .20629 L
.89221 .20784 L
.89349 .21041 L
.89488 .21423 L
.89636 .21954 L
.89902 .23236 L
.90151 .24801 L
.90421 .26857 L
.90911 .31175 L
.91353 .34856 L
.9148 .35709 L
.91601 .36388 L
.91709 .3687 L
.91827 .37246 L
.91956 .37462 L
.92094 .37461 L
.92223 .37239 L
.92341 .36856 L
.9246 .36301 L
.92588 .35529 L
.92821 .33742 L
.93914 .23138 L
.94474 .18894 L
.94756 .17278 L
.95065 .15861 L
.9533 .14909 L
.95613 .14117 L
.9588 .13551 L
.96123 .1316 L
.96346 .12886 L
.96592 .12657 L
.96715 .12566 L
.96848 .12483 L
.96963 .12423 L
.97089 .1237 L
.97207 .1233 L
.97316 .12302 L
.97431 .12282 L
.97555 .1227 L
Mistroke
.9767 .12267 L
.97778 .12271 L
.97876 .12281 L
.97981 .12297 L
.98107 .12322 L
.98225 .12352 L
.98492 .12437 L
.99032 .12671 L
.99499 .12942 L
1 .13307 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo09;ooooo1ol0000G
ooooo`00Moooool<o`0003;ooooo00?o0000ooooooooool0TOooool2o`0000Kooooo00?o0000oooo
ooooool05?ooool007Gooooo0_l0000<ooooo`;o0000<?ooool2o`00097ooooo00?o0000oooooooo
ool01oooool2o`0001Cooooo000Fooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
3Oooool2o`0002kooooo00?o0000ooooooooool0;Oooool4o`0005oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`005oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo013ooooo0_l0000/ooooo`03o`000?oooooooooo02_ooooo0ol00003ooooo`?o00003Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01kooooo000Hooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo02[ooooo0_l00008oooooa;o0000BOooool00ol0003oooooooooo`0Nooooo`006Oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo0_l00016ooooo`03o`000?oooooooooo
01oooooo000Jooooo`03o`000?oooooooooo013ooooo1?l00011ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`006oooool00ol0003ooooo
ooooo`0<ooooo`?o00000oooool3o`0003kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo023ooooo000Looooo`;o00002_ooool2o`0000Sooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool08?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0A
ooooo`Co00004?ooool2o`0002Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo027ooooo000Oooooo`;o00001?ooool2o`0000cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00oooooo0_l00003oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool08Oooool0027ooooo1?l0000?ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Qooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000
ooooooooool00oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Kooooo`Go00000oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000006_ooool5o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Oooooo`Co000000Co410@ooooooooooook^k^0_l0
00000olb<S;ok^k^ooooo`0Iooooo`Go00000_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kPko
oooo1?l00009ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool02?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Eooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Oo
MgMgoiRHV?ooooooV9RHogMgMooooooo000001cooooo00[o0000oooooooooooo0000oooooomgMgOo
V9RHoooooonHV9SoMgMg1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMol0003ooooooiRHV?mg
MgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mg
MgL=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01ol@413ooooooooooooooooo410@ooooool000004Oooool6o`0000Gooooo
00Ko0000ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol0003ooooooooooooooooo410@00cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0?ooooo`03o`00
0?oooooooooo00Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooo
ooooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool0
0onHV9So8B4Qonk^kP03ooooo`07o`000?ooooooooooooooool0003oooooo`00000Looooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo0_l00002oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo
oooo00Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Fooooo`03
o`000?oooooooooo00?ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
01kooooo00?oMgMgofIVI_ooool00_ooool01?l0003oooooooooooooool2o`0001gooooo00?o0000
ooooooooool00_ooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool2o`0000;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0
1oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000oooo
ooooool01?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@o`000?ooool07?ooool00ol0003ooooooooo
o`02ooooo`06oa0@4?oooooo0000o`000?l@413ooooo0_l0000>ooooo`03o`000?oooooooooo00[o
oooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@400Noooo
o`09o`000?ooooooooooooooool@413oooooo`000?oooooo410@00_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Aooooo`03o`000?oooooooooo00Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Gooooo`08o`000?oooooooooooa0@4?nHV9SooooookZj^_l00003ooooo`06ogMg
MonHV9SooooooiRHV?mgMgOooooo0ol0000Gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`0001gooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RH
oooooonHV9P2o`00013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHooooool0003oMgMg00_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg013ooooo00?o0000ooooooooool02Oooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Oooooo00So0000ooooooooooooZJVYoa0@4?l0003o410@ojVYZ@?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02o`000003ooooool0003o000001Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_l000007?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01oooooo00?oEEEEofIVI_l000000oooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQ[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h02_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`0:ooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00>?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo02?ooooo000hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8oooool003Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`00>Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000iooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08oooool001Koooooool00010o`0001?ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`09o`000?ooooooooooooooool0003oooooo`00
0?oooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool03?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool09?ooool0
03_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`0Tooooo`00>oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Cooooo000kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Dooooo`;o00003_ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Cooooo000looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03o`00013ooooo00?o0000ooooool000003_ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Cooooo000mooooo`05o`000?ooooooooooooooool00000
3?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1Oooool01Ol0003oooooooooool0003ooooo00;o00003oooool01?l0003oooooooooool0000=oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool003gooooo00Co0000oooooooo
oooo00003_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool01Oooool3o`0000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool003gooooo1?l0000>oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`00Coooool00ol0
003oooooooooo`0;ooooo`;o00003Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Cooooo0_l00004ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000<
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool004oooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooo
oooo000000cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`00Coooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02Gooooo001?ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool09Oooool004oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Gooooo001?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool0053o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Gooooo001@ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09Oooool0053ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`02ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo001@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Uooooo`00D?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`12oooo
o`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo001@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo1?l000000ooooooo0000ooooo`06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool0053ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0@oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02Kooooo001@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo001@ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04Sooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9_ooool0053ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09_ooool0057ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool0
057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09_ooool0057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04[ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Kooooo001Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooo`0000gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00DOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0moooo
o`Go00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo001Aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Boooool2o`0000kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Wooooo`00DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Wooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09oooool005;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@Oooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Oooooo001Booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00D_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0noooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00D_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0W
ooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo001Cooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0:?ooool005?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool2o`0000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo001Cooooo`05
o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0:?ooool005?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xoooo
o`00Doooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Goooool01Ol0
003ooooooooooooooooo000002[ooooo001Cooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
001Qooooo`05o`000?ooooooooooooooool00000:_ooool005?ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?ooooooooooooooool00000C?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
067ooooo00Co0000oooooooooooo0000:oooool005Cooooo00?o0000ooooool000003Oooool01Ol0
003ooooooooooooooooo000004cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001Qooooo`04o`000?oo
ooooooooo`0002_ooooo001Dooooo`03o`000?oooooo000000gooooo00Go0000oooooooooooooooo
o`00001<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool00000HOooool01?l0003oooooooooool0000[oooo
o`00E?ooool00ol0003oooooo`00000>ooooo`03o`000?oooooo000004gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooo0000HOooool01?l0003oooooooooool0000[ooooo`00E?ooool2o`0000oooooo00?o0000oooo
ool00000COooool2o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`00067ooooo00Co0000oooooooooooo0000:oooool006Gooooo0ol0001=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo000006;ooooo00Co0000oooooooooooo0000:oooool006Kooooo0_l0001=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo000006?ooooo00?o0000ooooool00000:oooool00;Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0ol0001Soooo
o`;o0000;?ooool00;Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0H_ooool2o`0002cooooo002eooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Oooooo`00]Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Wooo
ool00;Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo09oooooo002eooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09oooooo002eooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00002Roooo
o`00]Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000X_ooool00;Go
oooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:;ooooo002eooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooo0000X_ooool00:cooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo0000X_ooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo00000:?o
oooo002Zooooo`Go00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo00000:?ooooo
002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000:ooooo`03o`000?oooooo00000:?ooooo
002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
o`00002Sooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00_ooooo0_l0
002Sooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool5o`0007cooooo0025ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000001?ooool00onHV9So8B4Qonk^kP1m
ooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00onHV9So8B4Qonk^kP1looooo`00
QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00omgMgOoIVIVooooo`1kooooo`00QOooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@41001oooool0
0ol0003oooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go0000okZj^_ooooooV9RHoa0@401loooo
o`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<07cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(84) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15932 m
.01975 .1486 L
.02981 .14093 L
.0327 .13896 L
.03544 .13734 L
.03793 .13613 L
.04057 .13517 L
.04186 .13482 L
.04255 .13466 L
.04329 .13453 L
.04459 .13436 L
.04581 .13428 L
.04654 .13427 L
.04733 .1343 L
.04808 .13435 L
.04878 .13443 L
.0501 .13467 L
.05083 .13485 L
.0515 .13505 L
.05402 .13609 L
.05544 .13691 L
.05674 .13781 L
.05914 .13988 L
.06168 .14268 L
.06738 .15135 L
.07271 .16258 L
.08481 .19802 L
.09007 .21427 L
.09284 .2217 L
.09578 .22812 L
.09702 .23025 L
.09835 .23212 L
.09911 .23298 L
.09981 .23363 L
.10118 .23451 L
.10234 .23482 L
.10362 .23472 L
.10494 .2341 L
.10618 .23307 L
.1074 .23163 L
.10872 .22963 L
.11111 .22495 L
.1156 .21338 L
.12566 .18311 L
.13045 .17038 L
.1356 .1596 L
.13855 .15507 L
.14125 .15207 L
.14255 .15102 L
.14323 .15058 L
Mistroke
.14396 .15018 L
.14529 .14967 L
.14653 .14945 L
.14726 .14944 L
.14803 .14952 L
.1494 .14991 L
.15017 .15027 L
.15088 .1507 L
.15251 .15205 L
.15393 .15366 L
.15522 .15551 L
.15813 .1611 L
.16071 .16791 L
.16352 .17747 L
.16863 .201 L
.17936 .27323 L
.18193 .29166 L
.18462 .309 L
.18692 .32093 L
.18822 .32611 L
.18943 .32977 L
.19071 .33232 L
.19188 .3334 L
.19322 .33317 L
.19449 .33152 L
.19585 .32827 L
.1971 .32402 L
.19993 .31062 L
.20551 .27493 L
.2115 .23609 L
.21424 .22153 L
.21684 .21055 L
.21917 .20336 L
.22049 .2005 L
.22171 .19865 L
.22284 .19765 L
.2239 .19734 L
.22507 .19773 L
.22633 .19901 L
.22758 .20119 L
.22889 .20448 L
.23002 .20814 L
.23124 .21305 L
.23409 .22824 L
.23667 .24686 L
.24247 .30396 L
.24745 .36039 L
.25028 .38807 L
.25167 .39881 L
.25293 .4065 L
Mistroke
.25419 .41184 L
.25538 .41463 L
.25664 .41505 L
.25801 .41251 L
.25936 .40704 L
.26012 .40276 L
.2608 .39818 L
.2634 .37559 L
.27305 .26227 L
.27845 .21084 L
.2815 .18922 L
.28429 .17345 L
.28696 .16156 L
.28944 .15283 L
.29203 .14581 L
.29488 .14017 L
.29761 .13635 L
.30014 .13386 L
.30146 .13286 L
.30292 .13195 L
.30445 .13119 L
.30586 .13065 L
.30712 .1303 L
.30845 .13006 L
.30978 .12996 L
.31053 .12996 L
.31123 .13 L
.31251 .13016 L
.31366 .13041 L
.315 .13082 L
.31626 .1313 L
.32113 .13389 L
.32562 .13706 L
.33054 .14149 L
.33575 .1475 L
.34567 .16097 L
.35114 .16839 L
.35632 .1748 L
.35865 .17721 L
.36113 .17928 L
.36256 .1802 L
.36385 .18086 L
.36515 .18134 L
.36638 .18163 L
.3675 .18176 L
.36868 .18176 L
.36968 .18166 L
.37079 .18143 L
.37198 .18105 L
.37326 .18051 L
Mistroke
.37556 .17916 L
.37826 .17699 L
.38113 .17403 L
.38628 .16739 L
.39792 .15117 L
.40276 .14539 L
.40798 .14039 L
.40951 .13926 L
.41096 .13836 L
.41238 .13767 L
.4137 .13718 L
.41494 .13686 L
.41626 .13668 L
.41702 .13665 L
.41773 .13667 L
.41906 .13683 L
.42028 .13712 L
.42159 .1376 L
.42282 .13821 L
.42394 .13891 L
.42526 .13993 L
.4267 .14129 L
.42931 .14451 L
.43203 .14902 L
.43493 .15524 L
.44013 .17016 L
.44935 .20741 L
.45421 .23021 L
.45696 .24249 L
.45953 .25252 L
.46202 .2603 L
.46342 .26358 L
.46468 .26582 L
.46603 .26737 L
.46678 .26786 L
.46748 .26807 L
.46876 .26783 L
.47012 .26672 L
.47127 .26511 L
.47251 .26272 L
.47474 .25685 L
.4774 .24767 L
.47983 .23771 L
.48533 .21274 L
.49119 .18791 L
.49404 .17799 L
.49672 .17023 L
.49916 .16455 L
.50049 .16201 L
.50173 .16001 L
Mistroke
.50297 .15834 L
.50411 .15715 L
.50537 .1562 L
.50673 .15563 L
.50786 .15554 L
.50909 .15584 L
.51025 .15654 L
.51132 .15755 L
.51256 .15915 L
.51371 .16111 L
.51635 .16729 L
.51892 .17571 L
.52169 .18769 L
.52434 .2022 L
.52723 .22178 L
.53305 .27244 L
.53805 .32179 L
.54068 .34548 L
.54346 .36553 L
.54484 .37281 L
.54563 .37603 L
.54636 .3784 L
.54765 .38102 L
.54903 .38161 L
.5497 .38105 L
.55043 .37984 L
.55177 .37606 L
.55307 .37055 L
.55427 .36403 L
.55903 .32897 L
.56408 .28744 L
.56668 .26924 L
.56804 .26116 L
.56947 .25393 L
.57074 .24873 L
.57212 .24433 L
.57337 .24151 L
.57454 .23992 L
.57526 .23943 L
.57604 .23933 L
.57678 .23965 L
.57746 .24031 L
.57875 .24249 L
.58012 .24615 L
.58159 .25164 L
.58296 .25825 L
.58609 .27842 L
.59131 .32498 L
.59406 .35255 L
.597 .37998 L
Mistroke
.59845 .39156 L
.59982 .40068 L
.60104 .40709 L
.60237 .41189 L
.60363 .41422 L
.60497 .41422 L
.60611 .4122 L
.60736 .40788 L
.60866 .40117 L
.6099 .39293 L
.61222 .37335 L
.61742 .31819 L
.62226 .26692 L
.62681 .22765 L
.63163 .19708 L
.63419 .18483 L
.63695 .17415 L
.63969 .16573 L
.64257 .15879 L
.64506 .15409 L
.64772 .15006 L
.65251 .14457 L
.65696 .1407 L
.66226 .1372 L
.66707 .1349 L
.67216 .13308 L
.67495 .13226 L
.67755 .13164 L
.67977 .13124 L
.68102 .13108 L
.68215 .13099 L
.6834 .13093 L
.68475 .13093 L
.68603 .131 L
.68722 .13111 L
.68859 .13131 L
.69008 .13159 L
.69277 .13231 L
.69539 .13328 L
.69779 .13443 L
.70041 .13603 L
.70327 .13825 L
.70906 .14435 L
.72049 .16262 L
.73131 .1853 L
.73602 .19452 L
.7386 .19879 L
.74102 .20208 L
.74238 .20358 L
.74362 .20471 L
Mistroke
.74501 .20568 L
.74577 .20607 L
.7465 .20636 L
.74775 .20664 L
.74892 .20666 L
.7502 .20639 L
.75156 .20579 L
.75291 .20487 L
.75432 .20358 L
.75687 .20048 L
.76261 .19058 L
.77302 .1686 L
.77749 .15974 L
.78229 .15162 L
.78505 .14783 L
.78756 .145 L
.79009 .1428 L
.79133 .14195 L
.79248 .14132 L
.79367 .14081 L
.79496 .14043 L
.7961 .14025 L
.79729 .14023 L
.7986 .1404 L
.79983 .14077 L
.80117 .14142 L
.80192 .1419 L
.8026 .14242 L
.80526 .14514 L
.80676 .14724 L
.80814 .14954 L
.81084 .15518 L
.81337 .16188 L
.81783 .17742 L
.82275 .20029 L
.8327 .25932 L
.83523 .27358 L
.83792 .28635 L
.83947 .29213 L
.84087 .29617 L
.84155 .29768 L
.84229 .29897 L
.84361 .30038 L
.84487 .30059 L
.84624 .29956 L
.84693 .29855 L
.84768 .29711 L
.84902 .29362 L
.85035 .28907 L
.85161 .28388 L
Mistroke
.85398 .27224 L
.86323 .21727 L
.8685 .19036 L
.87108 .17993 L
.87344 .17209 L
.87582 .16589 L
.87703 .1634 L
.87833 .16125 L
.87963 .15964 L
.88084 .15864 L
.88158 .15828 L
.88228 .15812 L
.88359 .15828 L
.8849 .15908 L
.88628 .16064 L
.88746 .16257 L
.88876 .16535 L
.89016 .16913 L
.89166 .17414 L
.89437 .18587 L
.89685 .19993 L
.89956 .21913 L
.90448 .26449 L
.90892 .31321 L
.91125 .33857 L
.91371 .36235 L
.91511 .37356 L
.91664 .38336 L
.91731 .38673 L
.91803 .38965 L
.91932 .39304 L
.92 .39382 L
.92074 .39387 L
.92208 .39188 L
.92339 .3874 L
.92459 .38118 L
.92686 .36471 L
.92937 .34109 L
.93443 .28589 L
.93992 .23157 L
.94294 .20803 L
.94581 .19017 L
.94848 .17718 L
.95138 .16636 L
.95402 .15913 L
.95648 .15432 L
.95783 .15236 L
.95925 .15074 L
.96047 .14969 L
.9618 .14885 L
Mistroke
.96256 .1485 L
.96324 .14825 L
.96404 .14803 L
.96479 .1479 L
.96612 .14781 L
.96687 .14783 L
.96757 .14788 L
.96881 .14808 L
.96998 .14835 L
.97126 .14874 L
.97264 .14925 L
.97802 .15196 L
.98295 .15491 L
.98754 .15729 L
.98985 .15819 L
.99104 .15855 L
.99232 .15888 L
.99306 .15904 L
.99373 .15916 L
.99507 .15934 L
.99628 .15943 L
.99756 .15946 L
.99872 .15943 L
1 .15932 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001gooooo`Co0000>_ooool2o`0003Sooooo0_l0001gooooo`00
9Oooool00ol0003oooooooooo`1=ooooo`?o00000_ooool3o`0003Sooooo00?o0000ooooooooool0
<oooool4o`0000;ooooo0ol0001dooooo`008Oooool7o`0004cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Iooooo`?o00006Oooool00ol0003oooooooooo`0aooooo`;o00002Ooo
ool2o`0007;ooooo000Pooooo`03o`000?oooooooooo00Gooooo0_l0001:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05oooool2o`0000;ooooo0_l0000Gooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`;o0000Doooool0
01kooooo0_l00009ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0^ooooo`;o00003_ooool00ol0003oooooooooo`0Hooooo`;o000000?oooooo`00
0?l00000D_ooool001gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?ooooo`00
6oooool2o`0000gooooo00?o0000ooooooooool05oooool2o`0002gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo1_l0000Kooooo`006Ooo
ool2o`00013ooooo00?o0000ooooooooool05Oooool4o`0002_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00ooo
ool2o`0001Wooooo000Gooooo`;o00004_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`Co0000:_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool0
01Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`00
0?l00000:?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`;o00005Oooool00ol0003oooooooooo`08oooo
o`?o000000?oooooo`000?ooool04_ooool002cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01Ol0003o
oooooooooooooooo000002Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003ooooo
01?ooooo00?o0000ooooooooool02oooool2o`0001?ooooo000Eooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0003oooooooooo`0:ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool02?l0003ok^k^oc8b<_l0003o<S8bonk^k_oooooo00006Oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01?ooool4o`000008oa0@4?ooooooooooo`000?lb<S;o0000oc8b<_o^k^h:oooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000Mooooo`Co000000Go410@
ooooooooooook^k^oc8b<P02o`000003onk^k_oooooooooo01Kooooo00?o0000ooooool000001?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`03o`000?lb<S;o000000;o
00004oooool00ol0003oooooooooo`07ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00gooooo00?o0000ooooooooool02_ooool03Ol@413o^[ZjoooooomgMgOo<S8booooool0
003oooooogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Fooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oMgMgoiRHV?oo
ooooV9RHogMgM`[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg01So
oooo00Oo0000oooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00Go0000oiRHV?ooooooV9RHo`00000Cooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`04o`000?oooooooooo
ooooo`Ko00001_ooool2o`0000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oo
oooooooo00kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Oo410@oooooooooooooooo
oa0@4?oooooo0000017ooooo1_l00005ooooo`06o`000?ooooooooooo`000?oooooo410@0oooool0
0ol@413oooooooooo`09ooooo`03o`000?oooooooooo00oooooo0_l00004ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@01Wooooo00Go
0000oooooonHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413o000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h0
0oooool01ol0003ooooooooooooooooo0000ooooool000005_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00oooooo0_l00005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000001Wooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`07
o`000?ooooooooooooooool0003oooooo`00000>ooooo`03o`000?oooooooooo00_ooooo00CoZJVY
oa0@4?oooooooooo0_l00003ooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0;oooo
o`04oa0@4?l0003o^[Zjo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo01Sooooo00?oMgMgofIVI_ooool00_ooool01ol0003ooooooooooooooooo0000ooooool0
00005oooool00ol0003oooooooooo`02ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000001[ooooo00Go0000
ooooooooooooMgMgofIVIP03ooooo`07o`000?ooooooooooooooool0003oooooo`00000>ooooo`03
o`000?oooooooooo00[ooooo00?o410@o`000?nj^[X00_ooool2o`0000?ooooo0_l0000Aooooo`03
o`000?oooooooooo00Kooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjo`000?ooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooool000006?ooool2o`000003ooooool0003o000000Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00001?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go410@ooooool0003ooooooa0@400K
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko410@oooooooooooooooooa0@4?l0000?ooooo`03
o`000?oooooooooo00_ooooo00Ko^[Zjob4Q8Ooooooo0000ooooool@4103ooooo`03oa0@4?l0003o
oooo013ooooo00?o0000ooooooooool01oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00oooooo00?o0000ooooooooool02?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo01Gooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00006_ooool4o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003o
V9RHogMgM`0Jooooo`;o000000?ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So0000
013ooooo00?o0000ooooooooool02?ooool03_l@413oV9RHoooooonj^[[o0000ooooool0003ooooo
ogMgMonHV9SooooooiRHV?mgMgOo00004Oooool00ol0003oooooooooo`07ooooo`03onk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`08ooooo`05ojVYZOl@
413o0000oa0@4?l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool05Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
000Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Hooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o0000017ooooo00?o0000ooooooooool01ooo
ool01_nYZJWo410@o`000?l@413oZJVYo`0000;ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000@
ooooo`03o`000?oooooooooo00Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_oo
ool0033ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`00<?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo000aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`?o00004?ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_ooool0037ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo0_l00000
0ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Sooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oo
oooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool2o`0000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000b
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Sooooo`00<_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool0
03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Cooooo000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Tooooo`00=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09?ooool003Gooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Tooooo`00=Oooool3o`0001Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`00=_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Cooooo001=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03?ooool2o`0000kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Toooo
o`00COooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
00003_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo001=ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09Oooool004kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Uooooo`00C_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool09Oooool004kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Gooooo001>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00Go0000oooooooooooooooo
o`000007ooooo`;o00002?ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00003?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo001>ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool09Oooool004kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool2o`000003
ooooool0003ooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Gooooo001?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03[ooooo0_l00009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`00Coooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Uooooo`00Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`00Coooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0V
ooooo`00Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Vooooo`00Coooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16ooooo`;o
00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo001@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Kooooo001@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Kooooo001@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0001;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`00D?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool01?l0003ooooooooo
ool0000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo0_l0
000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0>oooool5o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0
053ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP07ooooo`?o00002?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0?Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Ko
oooo001@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Wooooo`00DOooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9oooool0057ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oo
oooo001Aooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0looooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Woooo
o`00D_ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`00D_ooool00ol0003oooooo`00000>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00D_oo
ool2o`00013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`17ooooo`;o00002_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09ooo
ool006Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Oooooo001Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Wooooo`00I?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09oooool006Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Oooooo001Tooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00I?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool006Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0GOooool01Ol0003ooooooooooooooooo000002[ooooo001Tooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`05o`000?oooooo
ooooooooool00000:_ooool006Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`18
ooooo`;o00003?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0GOooool01Ol0003ooooooooooooooooo000002[ooooo001Tooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`04o`000?oo
ooooooooo`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`05o`00
0?ooooooooooooooool00000:_ooool006Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`00000Zoooo
o`00I?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool02oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0GOooool01Ol0003ooooooooooooooooo000002[ooooo001Uooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`04o`000?oooooooooo
o`0002_ooooo001Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05gooooo00Co0000oooooooooooo0000:oooool006Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0G_ooool00ol0003oooooo`00000[ooooo`00IOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooool00000:oooool006Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`;o00007Oooool01Ol0003ooooo
oooooooooooo0000067ooooo00?o0000ooooool00000:oooool006Gooooo00Go0000oooooooooooo
ooooo`00001;ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00001Qoooo
o`03o`000?oooooo000002_ooooo001Uooooo`05o`000?ooooooooooooooool00000Boooool00ol0
003oooooooooo`0Looooo`05o`000?ooooooooooooooool00000HOooool2o`0002cooooo001Voooo
o`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0
002?ooooo`00I_ooool01?l0003oooooooooool0001;ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooool00000T?ooool006Kooooo00Co0000oooooooooooo0000@_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00002@ooooo`00I_ooool0
0ol0003oooooo`000014ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooo`00002@ooooo`00I_ooool00ol0003oooooo`000011ooooo`Go00001_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooo0000093ooooo001Wooooo`;o0000@Oooool01?m4A4Co
gMgMooooool00007ooooo`?o00007Oooool00ol0003oooooo`00002@ooooo`00Ioooool00ol0003o
ooooooooo`10ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`2?ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3o
oooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool00:cooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02ioooo
o`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj
^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00
/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@
oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01Sooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`;o000000?o410@ooooooooool0N_oo
ool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000oooool5o`0007cooooo0025
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`04odA4A?oMgMgoooooo`0007gooooo0025oooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Goc<c<o`000?l0
003o0000olc<c003ooooo`04omgMgOmEEEGoooooo`0007gooooo0025ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol@413o0000o`000003o`0001Wooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03
ogMgMoo<c<co000007gooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0J
ooooo`05o`000?nj^[[ooooookZj^_l000001?ooool00oo^k^koA4A4o`00001mooooo`00Q?ooool0
0ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1Oooool00omgMgOo0000ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(86) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13231 m
.00236 .13097 L
.00488 .12976 L
.00706 .1289 L
.00821 .12853 L
.00942 .1282 L
.01011 .12804 L
.01087 .1279 L
.0122 .12771 L
.01356 .12762 L
.01483 .12761 L
.01607 .12768 L
.0172 .12782 L
.01851 .12805 L
.01975 .12834 L
.02225 .12916 L
.02491 .1304 L
.02742 .13197 L
.0297 .13376 L
.03239 .13641 L
.0353 .13996 L
.04057 .14829 L
.06208 .20558 L
.06731 .21961 L
.07024 .22571 L
.07163 .228 L
.07292 .22973 L
.07443 .23125 L
.07523 .23181 L
.07607 .23223 L
.07681 .23243 L
.0775 .23249 L
.07825 .2324 L
.07907 .23213 L
.07976 .23175 L
.08053 .23119 L
.08206 .2296 L
.08348 .2276 L
.08481 .22533 L
.09641 .19525 L
.10211 .17899 L
.10737 .16565 L
.11205 .15596 L
.1172 .14789 L
.12238 .14213 L
.12521 .13989 L
.12659 .13904 L
.12786 .1384 L
.12909 .13793 L
.1304 .13759 L
Mistroke
.13114 .13747 L
.13185 .1374 L
.13316 .1374 L
.13442 .13756 L
.13558 .13784 L
.13685 .13829 L
.13819 .13895 L
.14052 .14052 L
.14269 .14255 L
.14508 .14551 L
.14763 .14972 L
.15036 .15567 L
.15334 .16408 L
.15874 .1853 L
.164 .21392 L
.16886 .24682 L
.17374 .28237 L
.1763 .29949 L
.1777 .30769 L
.17899 .31434 L
.18024 .31967 L
.18137 .32351 L
.18262 .32658 L
.18395 .32839 L
.18508 .3287 L
.18629 .32779 L
.18744 .32577 L
.1885 .32294 L
.18975 .31849 L
.19109 .31249 L
.19351 .29897 L
.19902 .26062 L
.2048 .21987 L
.20734 .20435 L
.21014 .18964 L
.21263 .17888 L
.21531 .16958 L
.21679 .16543 L
.21815 .1622 L
.21943 .15964 L
.22081 .15743 L
.22154 .15648 L
.22221 .15575 L
.22351 .15472 L
.22424 .15437 L
.22503 .15418 L
.22577 .15419 L
.22646 .15437 L
.22784 .15521 L
.22862 .15599 L
Mistroke
.22936 .15693 L
.23083 .15945 L
.23242 .16313 L
.23513 .1719 L
.23808 .18541 L
.24086 .2025 L
.24345 .22265 L
.24834 .27272 L
.25354 .33849 L
.25628 .37244 L
.25777 .38888 L
.25917 .40212 L
.26046 .41209 L
.26164 .41899 L
.26295 .42394 L
.26367 .42538 L
.26435 .42589 L
.26502 .42557 L
.26576 .42429 L
.26653 .42191 L
.26726 .41876 L
.26855 .41103 L
.26995 .39997 L
.27313 .36678 L
.27604 .33105 L
.28139 .26746 L
.28636 .22245 L
.28887 .2059 L
.29155 .19226 L
.29308 .18612 L
.29452 .18131 L
.29582 .17771 L
.29722 .17458 L
.29854 .17226 L
.29974 .17063 L
.30094 .16943 L
.30209 .16866 L
.30342 .16815 L
.30465 .16801 L
.306 .16817 L
.30676 .16838 L
.30744 .16864 L
.30884 .16932 L
.31012 .1701 L
.31301 .17225 L
.31825 .17675 L
.32061 .17877 L
.32313 .18075 L
.32547 .18227 L
.32662 .18286 L
Mistroke
.32768 .18331 L
.32888 .18367 L
.33017 .1839 L
.33127 .18394 L
.33243 .18385 L
.33371 .18357 L
.33491 .18314 L
.33622 .1825 L
.33763 .18163 L
.34029 .17948 L
.34313 .17656 L
.34824 .16996 L
.35981 .15189 L
.36551 .14372 L
.37087 .1372 L
.37569 .13247 L
.37821 .1305 L
.3809 .12881 L
.38229 .12812 L
.3836 .12758 L
.38488 .12715 L
.38606 .12685 L
.38718 .12665 L
.38837 .12652 L
.38956 .12648 L
.39088 .12655 L
.39157 .12663 L
.3923 .12675 L
.3936 .12707 L
.39432 .12729 L
.395 .12755 L
.39653 .12825 L
.39909 .1299 L
.40183 .13237 L
.40469 .13581 L
.40779 .14063 L
.41342 .15265 L
.41889 .1689 L
.42395 .18794 L
.43344 .22941 L
.43617 .24048 L
.43877 .24952 L
.4411 .25595 L
.44241 .25873 L
.44364 .2607 L
.44434 .26155 L
.4451 .26223 L
.44648 .26284 L
.44782 .26263 L
.44906 .26175 L
Mistroke
.4504 .26008 L
.45116 .25881 L
.45187 .25743 L
.45483 .24979 L
.45989 .23173 L
.46531 .20975 L
.4705 .19011 L
.47601 .17312 L
.47888 .16614 L
.48205 .15993 L
.48494 .15559 L
.48623 .15403 L
.48764 .15257 L
.49023 .15054 L
.49164 .14975 L
.49295 .14921 L
.49419 .14887 L
.49531 .1487 L
.4966 .14865 L
.49782 .14876 L
.49915 .14904 L
.49982 .14926 L
.50056 .14955 L
.50186 .1502 L
.50308 .15098 L
.50583 .15336 L
.50878 .15697 L
.51146 .16131 L
.51431 .1672 L
.51943 .18179 L
.52228 .19261 L
.52495 .20486 L
.53104 .2408 L
.54112 .314 L
.54388 .33106 L
.5454 .33868 L
.54684 .34442 L
.54817 .34831 L
.54893 .34985 L
.54962 .35081 L
.55085 .35146 L
.55216 .35063 L
.55338 .34846 L
.55469 .34469 L
.55593 .33985 L
.55706 .33444 L
.56246 .29956 L
.56765 .26134 L
.57331 .22533 L
.57581 .21278 L
Mistroke
.57848 .20203 L
.57977 .19787 L
.58099 .19463 L
.58209 .19229 L
.58327 .1904 L
.58441 .18923 L
.58567 .1887 L
.58698 .18901 L
.5882 .19012 L
.58934 .19189 L
.59039 .19415 L
.59159 .19754 L
.59273 .20155 L
.59506 .21231 L
.59722 .22575 L
.59948 .2437 L
.60194 .26823 L
.60712 .33465 L
.61187 .40121 L
.61329 .41863 L
.61463 .43284 L
.61585 .44339 L
.61714 .45168 L
.61781 .4547 L
.61854 .45695 L
.61984 .45813 L
.62057 .4572 L
.62135 .45494 L
.62209 .45162 L
.62276 .44762 L
.62407 .43746 L
.62527 .42545 L
.62801 .39106 L
.63299 .31722 L
.63817 .24822 L
.64305 .20162 L
.64575 .183 L
.64867 .16747 L
.65132 .15678 L
.65376 .1494 L
.65504 .14635 L
.65641 .14366 L
.65759 .14176 L
.65888 .14011 L
.66039 .13862 L
.66108 .13809 L
.66182 .13761 L
.66248 .13726 L
.66321 .13693 L
.66449 .13653 L
Mistroke
.66525 .13638 L
.66596 .1363 L
.66731 .13627 L
.66806 .13634 L
.66876 .13645 L
.66952 .13662 L
.67034 .13687 L
.67182 .1375 L
.67321 .13831 L
.67582 .1404 L
.67834 .14313 L
.6807 .14623 L
.68606 .15473 L
.69688 .1766 L
.70138 .18671 L
.70616 .19629 L
.70866 .20033 L
.70998 .20214 L
.71141 .20382 L
.71272 .20509 L
.71392 .20602 L
.71506 .2067 L
.71627 .20718 L
.71758 .20742 L
.71831 .20741 L
.71898 .20733 L
.72028 .20692 L
.7215 .20626 L
.7222 .20575 L
.72293 .20512 L
.72425 .20375 L
.72723 .19958 L
.73218 .19019 L
.73762 .17816 L
.74761 .15627 L
.75253 .14703 L
.7571 .14015 L
.76219 .13435 L
.76489 .13196 L
.76775 .12991 L
.76902 .12918 L
.77039 .12853 L
.77168 .12806 L
.77287 .12774 L
.77394 .12757 L
.77512 .12749 L
.77635 .12755 L
.7775 .12773 L
.77886 .12809 L
.77963 .12837 L
Mistroke
.78034 .12868 L
.78163 .12935 L
.78304 .13028 L
.78549 .13236 L
.78809 .13534 L
.7909 .13968 L
.79394 .14591 L
.7968 .1535 L
.79943 .16202 L
.80986 .21143 L
.8156 .24654 L
.81841 .26344 L
.821 .27728 L
.82346 .2878 L
.82469 .29189 L
.82605 .2953 L
.82741 .2975 L
.82818 .29818 L
.82888 .29845 L
.83023 .29801 L
.83152 .29643 L
.83267 .29411 L
.83389 .29074 L
.83609 .28261 L
.84106 .257 L
.84627 .22595 L
.8519 .19541 L
.85448 .18378 L
.85721 .1734 L
.85956 .16596 L
.86208 .15948 L
.86454 .15453 L
.86678 .15113 L
.86786 .14985 L
.86903 .14872 L
.87014 .1479 L
.87116 .14734 L
.87235 .14694 L
.87346 .14679 L
.87468 .14688 L
.87599 .14725 L
.87736 .14795 L
.87866 .1489 L
.88111 .15142 L
.88382 .15538 L
.88638 .16032 L
.89117 .17325 L
.89385 .18293 L
.89632 .19355 L
.9019 .22395 L
Mistroke
.91121 .29207 L
.91634 .33063 L
.91887 .34618 L
.9212 .35703 L
.92244 .36113 L
.92376 .36407 L
.92509 .36551 L
.92584 .36564 L
.92655 .36531 L
.92777 .36372 L
.92889 .36118 L
.93013 .35726 L
.93142 .35198 L
.93598 .32622 L
.94097 .29175 L
.94681 .25294 L
.95233 .22316 L
.95729 .20268 L
.96266 .1858 L
.96722 .17454 L
.97205 .16482 L
.98071 .15126 L
.9899 .14037 L
.99512 .13569 L
1 .13231 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000Ioooo
o`?o0000M?ooool4o`00027ooooo00?o0000ooooooooool0E?ooool2o`0005[ooooo000Fooooo`Co
00000_ooool3o`0006oooooo0_l00004ooooo`;o00007oooool2o`0005?ooooo0_l00002ooooo`;o
0000F?ooool001Kooooo00?o0000ooooooooool01Oooool2o`0006gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo017ooooo000Pooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0<Oooool3o`0001cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0nooooo`;o00005?ooool0027ooooo00?o0000ooooooooool06_ooool5
o`0004Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02oooooo0_l00003ooooo`;o00006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool05?ooool0027ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Dooooo`008_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05Oooool002?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`Co00008Oooool00ol0003ooooo
ooooo`0Fooooo`008oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo0_l0
0002ooooo`;o0000;oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool00000
7oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool3o`0002Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo0ol0000]ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Oooooo000Tooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`009?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool2o`0000;ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool001Gooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
013ooooo00Oo0000oooooonHV9So410@o`000?lb<S;oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_l0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h05oooool00ol0003oooooooooo`02ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000007Oooool4o`00000:oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^koooooo`0000cooooo00?o0000ooooooooool02Oooool5o`000008oooo
ool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo00kooooo00GoV9RH
oa0@4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h06Oooool01?l0003ooooo
ooooooooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000F
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo013ooooo00Oo0000ooooool@413o^[ZjoooooomgMgOo<S8b00?ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol0000Cooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooonHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`?o00003Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000001oooooo00?o0000ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMgooooool00000
3Oooool00ol0003oooooooooo`08ooooo`0=oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo00kooooo00Go410@okZj^_l0003o
MgMgoc8b<P03ooooo`05ogMgMonHV9Soooooo`000?mgMgL06Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`00
00;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0:
ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@o`000?ooool04Ooo
ool6o`000006ooooool0003ooooooiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@
00Kooooo0_l000000ooooooo0000ooooo`08ooooo`Ko00001Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Oo
410@oooooooooooooooooa0@4?oooooo000000kooooo00?o0000ooooooooool02?ooool01OnHV9So
8B4Qonk^k_oooooo000000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool000000oooool01Ol@413ooooooooooooooooo000001Sooooo00?o
0000ooooooooool01Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00Co
A4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03ojVYZOl@413ooooo00;ooooo00Co0000oooooooo
oooooooo0_l0000Booooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooV9RHob4Q8Oo^
k^h3ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000?ooooo0_l00009ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`07o`000?oooooooooooooo
ool0003oooooo`00000>ooooo`03o`000?oooooooooo00Wooooo00CoV9RHob4Q8Oo^k^ko00000_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03oooool00ol0003oZJVY
oa0@4003ooooo`05o`000?ooooooooooooooool000006?ooool01ol0003ooooooooooom4A4CogMgM
ooooool000001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol@413o0000okZj^P03ooooo`07o`000?ooooooooooooooool0
003oooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooogMgMomV
IVH3ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l0000@ooooo`03o`000?oooooooooo00Wooooo00?oMgMgo`00
0?ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03oooool2
o`000005okZj^_ooooooooooooooool000000oooool00ol0003oooooooooo`0Fooooo`07o`000?oo
ooooooooomgMgOmEEEGoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03okZj^_lQ8B7ooooo00;ooooo00Oo410@oooo
oooooooooooooa0@4?oooooo0000013ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`06ooooo`;o00000oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;o
oooo00Ko410@oooooooooooooooooa0@4?l0000@ooooo`03o`000?oooooooooo00[ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool01?l0003ooooookZj^_lQ8B43ooooo`06oa0@4?ooooooooooooooool@413o00005_ooool00ol0
003oooooooooo`02ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool0
0ol0003oooooooooo`0<ooooo`09o`000?ooooooooooooooool@413oV9RHoooooonj^[[o000000?o
oooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo0000013ooooo00?o0000ooooooooool01Oooool2
o`000004okZj^_ooooooV9RHoa0@40?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooooooo00Oooooo1Ol0000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool01_mgMgOo
V9RHoooooonHV9SoMgMgo`00017ooooo00?o0000ooooooooool01Oooool01Ol0003o^[Zjooooool0
003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00cooooo
00Go410@o`000?oooooo^[Zjo`000003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00005_ooool0
0ol0003oooooooooo`02ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000@ooooo`03o`000?oooooooooo
00Gooooo00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool00ol0003oooooooooo`0Eooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?oEEEEofIVI_l000001?ooool01_o^k^ko
<S8bo`000?lb<S;ok^k^o`00017ooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?l0
003oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00cooooo
00GoZJVYo`000?l0003o410@ojVYZ@03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00005Oooool0
0ol0003oooooooooo`04ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`009oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`?o00004Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0M
ooooo`00:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool07_ooool002Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000?oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo000Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01kooooo000Yooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo01;ooooo0_l00004oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00:_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo000Zooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool08?ooool002_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Pooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo000/
ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool08?ooool002gooooo00Co0000ooooool0003o00006Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?oo
ool002kooooo0_l0000Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`;o00002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo027ooooo001;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Qooooo`00Boooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool08Oooool004_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`00Boooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool004_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo001;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`00C?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0aooooo`04o`000?oooooo0000o`0000kooooo0_l00009ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool08_ooool004cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool3o`0000oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo001<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02?ooooo001<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo001<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02?ooooo001<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo001=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02?ooooo001=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo001=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04?ooooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00Go0000oooooooooooooooo
o`00000Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool004gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00Go
0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9?ooool004gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Wooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Cooooo001>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0>_ooool2o`0001Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0>_ooool2o`0001Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`Go00001_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03
oiRHV?lQ8B7ok^k^00Oooooo0ol0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03oiRH
V?lQ8B7ok^k^00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09Oooool004oooooo00Go0000oooooooooooooooo
o`00000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Gooooo001?ooooo`04o`000?ooooooooooo`0001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09Oooool004oooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Wooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02Gooooo001?ooooo`04o`000?oooooo0000o`0001?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Uooooo`00D?ooool2o`0001Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Gooooo001Vooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Uooooo`00I_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Co
oooo0_l0000<ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uoooo
o`00I_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool006Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00_o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo001Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooo0000013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool006Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Vooooo`00I_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool03?ooool3o`00013ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Hooooo`05o`000?ooooooooooooooool00000:Oooool006Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00Co
0000oooooooooooo0000:Oooool006Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Jooooo`04o`000?ooooooooooo`0002Wooooo001Wooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0F_ooool01?l0003oooooooooool0000Yooooo`00Ioooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04Gooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0F_ooool00ol0003oooooo`00000Zooooo`00Ioooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05_ooooo0_l0000Zooooo`00Ioooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo08Oooooo001Wooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Qoooool006Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27ooooo`00Iooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo001Wooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Qoooool006Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`27ooooo`00J?ooool01Ol0003ooooooooooooooooo000004Sooooo0_l0000Qoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool006Sooooo00Go0000oooooooo
ooooooooo`000018ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`27ooooo`00J?ooool01Ol0003ooooooooooooooooo000004Sooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo001Xooooo`05
o`000?ooooooooooooooool00000B?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Qoooool006Sooooo00Go0000ooooooooooooooooo`000018oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27oooo
o`00J?ooool01Ol0003ooooooooooooooooo000003oooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27oooo
o`00J?ooool01Ol0003ooooooooooooooooo0000043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool006Wo
oooo00?o0000ooooool00000?_ooool5o`0000Kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08Sooooo001Yooooo`03o`000?oooooo000003kooooo
00CoA4A4omgMgOoooooo00001oooool3o`00027ooooo00Go0000ooooooooooooooooo`00002:oooo
o`00JOooool00ol0003oooooo`00000nooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool08Oooool01Ol0003ooooooooooooooooo000008[ooooo001Yooooo`03o`000?oooooo0000
03oooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool00000R_ooool006Wooooo00?o0000ooooool00000?oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00002:ooooo`00JOooool2o`00
047ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool00000R_ooool00;Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000008[ooooo002eooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00002:
ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0008_ooooo002eoooo
o`;o00008_ooool01?l0003oooooooooool0002;ooooo`00]Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooo000008_ooooo002eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool0
0000Roooool00;Gooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00002;ooooo`00]Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000008_ooooo002eooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooool00000Roooool00;Gooooo00?o0000ooooooooool08_ooool3o`00
08_ooooo002eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0R_ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Co
c<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_oo
ool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100
^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`00
0?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002coooo
o`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o410@olc<c01looooo`00QOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wo
oooo1_l00009ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So
8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool06_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003oV9RHoooooonHV9So8B4Q07cooooo0025
ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Goc<c<o`00
0?l0003o0000olc<c003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0O?ooool008Gooooo00Ko0000
ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413o^[Zjoooooonj^[[o410@
00?ooooo00?oEEEEohN7Qoooool0O_ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000I
ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oo
oooooooo01[ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`03omgMgOl@413oV9RH07kooooo
0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(88) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13178 m
.00236 .13331 L
.00488 .13534 L
.00942 .14013 L
.01483 .14793 L
.01975 .15711 L
.03057 .18396 L
.04057 .21191 L
.0433 .21836 L
.04586 .2234 L
.04726 .22564 L
.04853 .22735 L
.04995 .22882 L
.05073 .22944 L
.05147 .22989 L
.05222 .2302 L
.05289 .23037 L
.05367 .23042 L
.05441 .23033 L
.05572 .22984 L
.05645 .22938 L
.05713 .22884 L
.05856 .22735 L
.06014 .22519 L
.06331 .21937 L
.07456 .19002 L
.08481 .16367 L
.08985 .1535 L
.09533 .14476 L
.1005 .13843 L
.10529 .13409 L
.1079 .13228 L
.11036 .13092 L
.11304 .12976 L
.11456 .12926 L
.11594 .12889 L
.11731 .12863 L
.11857 .12846 L
.1193 .12841 L
.11997 .12839 L
.12073 .12839 L
.12145 .12843 L
.12216 .1285 L
.1229 .12861 L
.12424 .1289 L
.12498 .12912 L
.12567 .12936 L
.12725 .13006 L
.12857 .13081 L
.12997 .13177 L
Mistroke
.13248 .13402 L
.13547 .13766 L
.13818 .14209 L
.14075 .14749 L
.14353 .1549 L
.14856 .17332 L
.15349 .19862 L
.1587 .23301 L
.16349 .26881 L
.16802 .30049 L
.17052 .31424 L
.17194 .32018 L
.17324 .3243 L
.17434 .32665 L
.17555 .328 L
.17681 .328 L
.178 .3267 L
.17931 .32383 L
.18068 .31929 L
.18314 .30777 L
.18868 .27127 L
.19388 .23376 L
.19878 .20317 L
.20318 .1821 L
.20566 .17301 L
.20794 .16633 L
.21027 .16106 L
.21283 .1569 L
.21412 .1554 L
.2155 .1542 L
.2168 .15342 L
.21799 .15301 L
.21936 .15286 L
.22063 .15301 L
.22129 .1532 L
.22202 .1535 L
.22278 .1539 L
.2235 .15436 L
.22601 .15661 L
.22742 .1583 L
.22871 .16011 L
.2332 .16823 L
.23811 .18033 L
.24324 .19656 L
.24801 .21518 L
.26766 .32372 L
.27304 .35335 L
.27576 .36478 L
.2773 .36972 L
.27799 .37151 L
Mistroke
.27875 .37315 L
.28007 .37519 L
.28132 .3761 L
.28254 .376 L
.28368 .37502 L
.28502 .37277 L
.28624 .36973 L
.28765 .36508 L
.28898 .35968 L
.29458 .32814 L
.29973 .29237 L
.30528 .25403 L
.31136 .21743 L
.31633 .19312 L
.32165 .17248 L
.32727 .15601 L
.33252 .14461 L
.33521 .13995 L
.33807 .13577 L
.34321 .13003 L
.34606 .12771 L
.34874 .12602 L
.35167 .12465 L
.35332 .12407 L
.35483 .12367 L
.35607 .12342 L
.35738 .12325 L
.35862 .12316 L
.35975 .12315 L
.36108 .12322 L
.36183 .1233 L
.36252 .1234 L
.36379 .12366 L
.36513 .12401 L
.3678 .12501 L
.37029 .12628 L
.37303 .12805 L
.37597 .13044 L
.38149 .13655 L
.38661 .14444 L
.39223 .15592 L
.39822 .17161 L
.40922 .2086 L
.41404 .22533 L
.41678 .23384 L
.41933 .24067 L
.42188 .2461 L
.4233 .24843 L
.4246 .25006 L
.42597 .25124 L
Mistroke
.42675 .25166 L
.42746 .25189 L
.42877 .25191 L
.42944 .25172 L
.43017 .25135 L
.43094 .2508 L
.43168 .2501 L
.43308 .2484 L
.43457 .24601 L
.43621 .24282 L
.44187 .22835 L
.45298 .1956 L
.46306 .17229 L
.46817 .16396 L
.47369 .15697 L
.47891 .15194 L
.48371 .14848 L
.48881 .14577 L
.49171 .14461 L
.49301 .14418 L
.49442 .1438 L
.49518 .14364 L
.49588 .14351 L
.49656 .14341 L
.49727 .14333 L
.49851 .14328 L
.49988 .14334 L
.50063 .14343 L
.50133 .14355 L
.50209 .14373 L
.50289 .14397 L
.50425 .1445 L
.50573 .14528 L
.50711 .14622 L
.50839 .14728 L
.51127 .15049 L
.51382 .15448 L
.51651 .1602 L
.51892 .1669 L
.52118 .17475 L
.52631 .19925 L
.52915 .21717 L
.53185 .23709 L
.53691 .28036 L
.53999 .30774 L
.54289 .33115 L
.54549 .3478 L
.54621 .35136 L
.54696 .35458 L
.5483 .35886 L
Mistroke
.54951 .36096 L
.55079 .36135 L
.55201 .35994 L
.55312 .35717 L
.55441 .35222 L
.55583 .34492 L
.55839 .3274 L
.5636 .28207 L
.56913 .23353 L
.57391 .19933 L
.57644 .18491 L
.57917 .17229 L
.58167 .16325 L
.58396 .15689 L
.58615 .15238 L
.58725 .15064 L
.58845 .14912 L
.58913 .14843 L
.58984 .14783 L
.59112 .14708 L
.5925 .14675 L
.59328 .14678 L
.59401 .14695 L
.59534 .14764 L
.59654 .14871 L
.59721 .14949 L
.59794 .1505 L
.59926 .1528 L
.60173 .15876 L
.60435 .16777 L
.60659 .17791 L
.60907 .19207 L
.61453 .23636 L
.6176 .27018 L
.62042 .30632 L
.62557 .37714 L
.6284 .41133 L
.6298 .42493 L
.63108 .43498 L
.63233 .44215 L
.63366 .44666 L
.63499 .44787 L
.63575 .44705 L
.63646 .44532 L
.63769 .44019 L
.63882 .43327 L
.64135 .4112 L
.65092 .29935 L
.65349 .27455 L
.65624 .25341 L
Mistroke
.65782 .24366 L
.65926 .23625 L
.66071 .22997 L
.66205 .22522 L
.6633 .2216 L
.66467 .21844 L
.66605 .21603 L
.66681 .21501 L
.6675 .21424 L
.66879 .21322 L
.67016 .21262 L
.67143 .21246 L
.67264 .21257 L
.67384 .21289 L
.67513 .21338 L
.67746 .21443 L
.67881 .21501 L
.67955 .21529 L
.68023 .21551 L
.68145 .2158 L
.68278 .21594 L
.68345 .21594 L
.68418 .21587 L
.68551 .21557 L
.6868 .21504 L
.68799 .21436 L
.68927 .2134 L
.69069 .21207 L
.69355 .20852 L
.69607 .20445 L
.69837 .20002 L
.70354 .18813 L
.71289 .16511 L
.71792 .15404 L
.72326 .14381 L
.72788 .1366 L
.73287 .13065 L
.73594 .12782 L
.73876 .12566 L
.74141 .124 L
.7428 .12327 L
.7443 .1226 L
.74567 .12211 L
.74691 .12175 L
.74816 .12149 L
.74934 .12133 L
.75066 .12124 L
.75188 .12126 L
.75323 .12137 L
.7539 .12146 L
Mistroke
.75465 .12159 L
.756 .1219 L
.75725 .12227 L
.75874 .12284 L
.7601 .12346 L
.7626 .12495 L
.76528 .1271 L
.76768 .1296 L
.77029 .13301 L
.77501 .14126 L
.78056 .15493 L
.78642 .17512 L
.79693 .22571 L
.80203 .25206 L
.80454 .26354 L
.80686 .27251 L
.80813 .27655 L
.80953 .28019 L
.81094 .2829 L
.81171 .28397 L
.81244 .28469 L
.81372 .28528 L
.81489 .28506 L
.81617 .28401 L
.81753 .282 L
.81873 .2795 L
.81983 .27669 L
.82228 .2688 L
.82671 .25083 L
.83677 .20842 L
.84185 .19215 L
.84442 .1858 L
.84724 .18023 L
.84964 .17655 L
.85223 .17352 L
.85467 .17139 L
.8569 .16994 L
.85824 .16927 L
.85967 .16869 L
.86103 .16827 L
.86225 .16798 L
.8637 .16773 L
.86451 .16762 L
.86526 .16755 L
.86664 .16747 L
.86733 .16744 L
.86809 .16743 L
.87056 .16742 L
.87192 .16742 L
.87319 .16741 L
Mistroke
.87456 .16739 L
.87528 .16737 L
.87606 .16734 L
.87873 .1672 L
.88013 .16712 L
.88089 .16709 L
.8816 .16705 L
.88286 .16701 L
.88424 .167 L
.88556 .16702 L
.88676 .16709 L
.88815 .16723 L
.88946 .16744 L
.89064 .1677 L
.8919 .16807 L
.89297 .16847 L
.89415 .16902 L
.89542 .16977 L
.89678 .17079 L
.89923 .17335 L
.9007 .17542 L
.90205 .17776 L
.90512 .18488 L
.90783 .19362 L
.91072 .2059 L
.91355 .22141 L
.91622 .23937 L
.9212 .28133 L
.92653 .33257 L
.92913 .35542 L
.93149 .37222 L
.93278 .37909 L
.934 .38385 L
.93528 .38687 L
.936 .38762 L
.93667 .38769 L
.93798 .38608 L
.93873 .38415 L
.93943 .3817 L
.94083 .37493 L
.94235 .36518 L
.95241 .2674 L
.95732 .22244 L
.96176 .19085 L
.9663 .16743 L
.96879 .15781 L
.97113 .15051 L
.97352 .14461 L
.97605 .13976 L
.97882 .13578 L
Mistroke
.98136 .1331 L
.98358 .13139 L
.98482 .13066 L
.98596 .13011 L
.98701 .12972 L
.98816 .12939 L
.98924 .12919 L
.99025 .12909 L
.99141 .12907 L
.9925 .12914 L
.99369 .12932 L
.99498 .12962 L
.99625 .13002 L
.9976 .13055 L
1 .13178 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo04cooooo0ol0001Qooooo`00Q_ooool5o`0002[ooooo00?o0000
ooooooooool0B_ooool2o`0000;ooooo0ol0001Oooooo`00Q?ooool2o`0000Gooooo0_l0000Xoooo
o`03o`000?oooooooooo04Sooooo0_l00006ooooo`;o0000G_ooool003Wooooo1ol00013ooooo`03
o`000?oooooooooo00Kooooo0_l0000Wooooo`;o0000B?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo04;ooooo1Ol0000Dooooo`005_ooool00ol0003oooooooooo`0Nooooo`;o0000
1_ooool2o`00047ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`10ooooo`;o0000
1?ooool00ol0003oooooooooo`0Aooooo`005oooool2o`0001kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool06Oooool001Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Pooooo`?o0000A_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Mooooo`?o000000Coooooo`000?l0003o00006_ooool2o`0002Sooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool2o`0000Cooooo00Co0000oooooooo
oooo00006?ooool4o`0002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Fooooo`;o00008_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Goooo
o`;o00000_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Jooooo`006oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool4o`00023ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Jooooo`007?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01_ooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`06
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`03o`000?oooooooooo00_ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`Go000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kQKooooo00Co0000oooooooooooooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Cooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00?o0000ooooooooool00oooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Aooooo`03o`000?oooooooooo00Kooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL04Oooool00ol0003o
ooooooooo`05ooooo`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?l0003oV9RHogMgM`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00Wo0000oooooooooooooooooiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooooooo
ool04oooool00ol@413o^[Zjo`00000;o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go
00000oooool01Ol@413oooooo`000?oooooo410@013ooooo00?o0000ooooool000001Ol00006oooo
o`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`0@ooooo`03o`000?oooooo
000000Ko00000_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
oooo0000ooooool@41004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00Go410@oooooooooooooooooa0@400Eooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool05?ooool2
o`000003ooooool0003ooooo00;ooooo00Go410@oooooooooooooooooa0@4002o`0001Gooooo00Co
0000oooooooooooooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool00ol0003oooooooooo`02o`00013ooooo00?o0000oooooooo
ool02_ooool00onYZJWo410@ooooo`02ooooo`03o`000?oooooooooo00;o00004?ooool00ol0003o
ooooooooo`06ooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooool0003oooooo`00000Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
1?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool01?ooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooojVYZOl@41000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool04_ooool02?l0003oooooooooooooooooA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00?o0000
ooooooooool00_l0000?ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?nj^[X00oooool0
0ol0003oooooooooo`02o`00013ooooo00?o0000ooooooooool01oooool01_l0003ooooooooooooo
ooooMgMgofIVIP?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0001;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000005Oooool00ol0
003oooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo017ooooo00Ko0000oooooooooooo410@o`000?nj^[X3ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0001?ooooo00So0000ooooooooooooooooomgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooo`000?l@41003oooool00ol0003oooooooooo`0;ooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooo0000oa0@400Aooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000004ooooo`05oa0@4?oooooo
ooooooooool@41005?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
0_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHo`00000>ooooo`03o`000?oooooooooo00Wooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?l000003oooool00ol0003oooooooooo`08ooooo`;o000000Co
^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL04Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0D
ooooo`03o`000?oooooooooo00?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0@ooooo`07o`000?oooooo410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00
000>ooooo`03o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_l000003oooool00ol0003oooooooooo`09ooooo`05o`000?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool03Oooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_l000004?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`07ooooo`03oeEEEOl0003o000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`03o`00
0?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`0@ooooo`07o`000?ooooooZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Cooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool0023ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool07Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o
00001oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01?ooool2o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0ol00004ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03oooool8o`00023ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool002?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo0_l0
000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01oooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07oooool002Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ooooo
o`009Oooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Oooooo`009_ooool3o`0001oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo0018ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o0000
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo0018ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`00B?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool0
04Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01oooooo0019ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000Doooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ooooo
o`00BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l000005?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool004Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool08oooool3o`0001Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo0019
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03_ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool004[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08?ooool004[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool004[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00Go
0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02kooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00008?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo023ooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo0_l0
000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooool000008?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo023ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`00Boooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08Oooool004_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`00Booo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03;ooooo1Ol00006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001<oooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001<ooooo`05o`000?oooooooooo
ooooool000006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`00C?ooool01?l0003oooooooooool0000J
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo027ooooo001<ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08_ooool004cooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo
001=ooooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000004oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00COooool2o`0001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo001[ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00K?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`05o`000?ooooooooooooooool0
00005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Rooooo`00K?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool08_ooool006cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo001/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Rooooo`00K?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08_ooool006gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;o
oooo001]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Gooooo`05o`000?ooooooooooooooool000009Oooool006gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000
5Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00Go0000oooooooooooo
ooooo`00000Uooooo`00KOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool03?ooool2o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Hooooo`05o`000?ooooooooooooooool000009Oooool006gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`10ooooo`;o00003_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooooooooooooo000002Go
oooo001]ooooo`05o`000?ooooooooooooooool00000@oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooooooooooooo0000
02Gooooo001^ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00Go0000ooooooooooooooooo`00000U
ooooo`00K_ooool00ol0003oooooo`000014ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Hooooo`04o`000?ooooooooooo`0002Kooooo001^oooo
o`?o0000A?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0F?ooool01?l0003oooooooooool0000Vooooo`00]Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0FOooool00ol0003oooooo`00000Voooo
o`00]Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0FOooool00ol0003oooooo`00000Vooooo`00]Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0FOooool00ol0003oooooo`00000Vooooo`00]Ooo
ool2o`0002Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`;o00009ooo
ool00;Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08;ooooo002eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`22ooooo`00]Oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooooooo
ool00000QOooool00;Gooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo0000
08Gooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`05
o`000?ooooooooooooooool00000QOooool00:gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Vooooo`05o`000?ooooooooooooooool00000QOooool00:[ooooo1Ol00006ooooo`03
o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`000025ooooo`00Z_ooool01?m4A4Co
gMgMooooool00007ooooo`?o00009_ooool01Ol0003ooooooooooooooooo000008Gooooo002Zoooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooo
oooo000008Gooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool09_ooool0
1Ol0003ooooooooooooooooo000008Gooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool09_ooool01Ol0003ooooooooooooooooo000008Gooooo002/ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool00026ooooo`00]Oooool0
0ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0008Kooooo002eooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooool00000Q_ooool00;Gooooo00?o0000ooooooooool09oooool00ol0
003oooooo`000026ooooo`00]Oooool2o`0002Sooooo00?o0000ooooool00000Q_ooool00;Gooooo
00?o0000ooooooooool09oooool00ol0003oooooo`000026ooooo`00]Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooo000008Kooooo002eooooo`03o`000?oooooooooo02Oooooo0_l00027
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zoooo
o`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402i
ooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000
oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo
0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
0oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B40O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007cooooo0025oooo
o`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?ooool008Go
oooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01Oo<c<co0000
o`000?l0003oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c01looooo`00QOooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool01Ol@413o^[Zjoooooonj^[[o410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb
<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool0
0ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooookZj^_l000000oooool01Ol0003o^[Zjoooo
oonj^[[o000007cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?oo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0O?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16802 m
.00942 .19128 L
.01483 .20595 L
.01975 .21812 L
.02225 .22321 L
.02496 .22747 L
.02568 .22835 L
.02644 .22915 L
.02782 .23024 L
.02911 .23084 L
.02984 .231 L
.03053 .23103 L
.03182 .23075 L
.03305 .2301 L
.03416 .22921 L
.03536 .22791 L
.03806 .22386 L
.04057 .21886 L
.05251 .18612 L
.05838 .1698 L
.06377 .15689 L
.06859 .14735 L
.07388 .13895 L
.07919 .13252 L
.08208 .1298 L
.08481 .12764 L
.08738 .12594 L
.09017 .12441 L
.0925 .12338 L
.09506 .12249 L
.09649 .12211 L
.09783 .12184 L
.09852 .12173 L
.09925 .12163 L
.10004 .12155 L
.10077 .1215 L
.10208 .12148 L
.1033 .12152 L
.10463 .12165 L
.10538 .12175 L
.10606 .12187 L
.10729 .12215 L
.1086 .12252 L
.11095 .12341 L
.11348 .12474 L
.11626 .12672 L
.11866 .12896 L
.12124 .13199 L
.12589 .13946 L
.12857 .14513 L
Mistroke
.13141 .15246 L
.13653 .1696 L
.14262 .19748 L
.14813 .2291 L
.15336 .26113 L
.1561 .27669 L
.159 .2906 L
.16023 .29542 L
.16155 .29973 L
.1623 .30178 L
.16299 .30335 L
.16434 .30562 L
.16554 .30671 L
.16685 .30686 L
.16809 .30604 L
.16924 .30448 L
.17048 .30197 L
.17178 .29848 L
.17412 .29041 L
.17937 .26699 L
.18397 .24554 L
.18887 .22606 L
.19168 .21726 L
.19424 .21088 L
.1968 .20595 L
.19922 .20258 L
.20059 .20117 L
.20204 .20003 L
.20328 .1993 L
.20464 .19873 L
.20541 .1985 L
.20611 .19833 L
.20692 .19819 L
.20768 .1981 L
.20904 .198 L
.20981 .19797 L
.21052 .19795 L
.21175 .19793 L
.21305 .19789 L
.21416 .19783 L
.21537 .19773 L
.21668 .19756 L
.21742 .19742 L
.21809 .19728 L
.2194 .19693 L
.22061 .19651 L
.22295 .19543 L
.22549 .19379 L
.22772 .19189 L
.23009 .18938 L
Mistroke
.24051 .17445 L
.24626 .16648 L
.24909 .16324 L
.25047 .1619 L
.25172 .16085 L
.25291 .16003 L
.2542 .15936 L
.25556 .15895 L
.25684 .15891 L
.25752 .15903 L
.25826 .1593 L
.25904 .15972 L
.25976 .16028 L
.26105 .16165 L
.26244 .16373 L
.2637 .16621 L
.26507 .1696 L
.26757 .17777 L
.27 .18856 L
.27224 .20142 L
.27668 .23651 L
.28156 .2913 L
.28629 .35405 L
.28897 .38748 L
.29146 .41257 L
.29277 .4223 L
.29396 .42866 L
.29534 .43276 L
.29663 .43331 L
.29799 .43038 L
.29924 .42459 L
.30062 .41509 L
.30207 .40185 L
.31179 .27635 L
.31682 .22109 L
.31965 .19778 L
.32223 .18088 L
.32527 .16544 L
.32815 .15453 L
.33081 .14719 L
.33231 .14404 L
.3337 .14167 L
.33506 .13983 L
.33649 .13831 L
.33771 .13732 L
.33905 .13649 L
.3405 .13585 L
.34131 .13559 L
.34204 .13541 L
.34273 .13529 L
Mistroke
.34348 .13519 L
.34483 .13512 L
.34609 .13518 L
.34748 .13538 L
.34817 .13553 L
.34892 .13573 L
.35028 .13621 L
.35162 .13683 L
.3529 .13755 L
.3553 .13921 L
.36015 .14358 L
.36465 .14846 L
.37486 .16351 L
.39459 .21092 L
.39999 .2257 L
.40294 .23282 L
.4057 .2384 L
.40806 .24215 L
.40926 .24367 L
.41058 .245 L
.41133 .24559 L
.41202 .24603 L
.41338 .2466 L
.41462 .24675 L
.41593 .24652 L
.41732 .24585 L
.41858 .24483 L
.41997 .24329 L
.42144 .2412 L
.42391 .23668 L
.42661 .23053 L
.4384 .19741 L
.44411 .18165 L
.4495 .16844 L
.45474 .15784 L
.45958 .14992 L
.46428 .14349 L
.46946 .13771 L
.47466 .1334 L
.4775 .13161 L
.48016 .13021 L
.483 .12894 L
.4844 .1284 L
.4857 .12797 L
.48697 .12761 L
.48812 .12736 L
.4894 .12716 L
.49076 .12705 L
.49148 .12705 L
.49223 .12708 L
Mistroke
.49359 .12723 L
.49434 .12736 L
.49504 .12753 L
.49663 .12804 L
.49803 .12863 L
.4993 .1293 L
.50216 .13128 L
.50456 .13358 L
.50722 .13699 L
.50999 .14184 L
.51259 .1479 L
.51723 .16313 L
.51984 .17458 L
.52223 .18715 L
.52731 .22111 L
.53286 .26852 L
.53562 .29388 L
.53861 .31972 L
.53998 .33019 L
.54143 .33985 L
.5428 .3473 L
.54404 .35254 L
.54532 .35625 L
.5467 .3582 L
.54798 .35807 L
.54919 .35624 L
.54987 .3545 L
.55059 .35212 L
.5519 .34652 L
.55485 .32851 L
.56466 .24704 L
.56725 .22771 L
.57005 .20991 L
.57247 .19729 L
.57511 .18634 L
.57805 .17742 L
.57965 .17385 L
.58114 .17127 L
.58186 .17027 L
.58254 .16946 L
.58381 .16831 L
.58518 .16756 L
.58595 .16735 L
.58667 .16729 L
.58798 .16749 L
.58922 .16804 L
.59034 .16881 L
.59156 .16993 L
.59429 .17339 L
.59682 .17757 L
Mistroke
.60634 .198 L
.61169 .21017 L
.61451 .21597 L
.61749 .22126 L
.6201 .22502 L
.62296 .22821 L
.62799 .23223 L
.63076 .23445 L
.63337 .23724 L
.63482 .23928 L
.63639 .24205 L
.6377 .24487 L
.63914 .24863 L
.64176 .2576 L
.64455 .27076 L
.64713 .28692 L
.64955 .30576 L
.65406 .34885 L
.65888 .39742 L
.66031 .40976 L
.66165 .41971 L
.66286 .42689 L
.66417 .43248 L
.66541 .43545 L
.66673 .43595 L
.66785 .43416 L
.66909 .42984 L
.67043 .42246 L
.67166 .41345 L
.67442 .38656 L
.67942 .32469 L
.68462 .26076 L
.68736 .23221 L
.69029 .20675 L
.693 .18741 L
.69546 .17303 L
.70026 .15208 L
.7026 .14468 L
.70513 .1384 L
.70752 .13384 L
.70972 .13058 L
.71231 .12762 L
.71467 .12555 L
.71598 .12463 L
.71739 .12377 L
.71862 .12317 L
.71997 .12263 L
.72122 .12226 L
.72238 .12203 L
.72361 .12189 L
Mistroke
.72494 .12187 L
.72617 .12195 L
.72734 .12212 L
.72838 .12234 L
.72953 .12265 L
.73238 .12368 L
.73498 .1249 L
.73777 .12651 L
.74079 .12868 L
.74617 .13395 L
.75124 .14062 L
.76121 .15836 L
.76687 .17178 L
.77216 .18643 L
.78351 .22109 L
.7891 .2373 L
.79156 .24352 L
.79427 .24941 L
.79683 .25384 L
.79923 .25693 L
.80055 .25817 L
.80176 .25903 L
.80309 .25966 L
.80376 .25986 L
.80449 .25998 L
.80524 .26001 L
.80595 .25994 L
.80728 .25959 L
.80802 .25926 L
.80871 .25887 L
.81026 .25772 L
.8115 .25653 L
.81286 .25495 L
.81562 .25101 L
.82568 .23106 L
.8351 .20961 L
.85458 .16859 L
.85992 .15937 L
.86561 .15099 L
.87052 .14511 L
.87584 .13994 L
.87897 .13745 L
.88034 .13652 L
.88184 .13564 L
.88317 .13499 L
.88459 .13444 L
.88538 .1342 L
.88609 .13402 L
.88681 .13389 L
.88749 .13379 L
Mistroke
.88877 .13372 L
.89012 .13378 L
.89128 .13395 L
.89255 .13427 L
.89392 .13477 L
.89539 .13551 L
.89678 .13644 L
.89805 .13751 L
.9006 .14043 L
.90296 .14428 L
.90556 .15007 L
.90833 .1584 L
.91125 .16996 L
.914 .18394 L
.91915 .21969 L
.92937 .32578 L
.93186 .35203 L
.93453 .37538 L
.93606 .3854 L
.93678 .38911 L
.93745 .3919 L
.93812 .39405 L
.93886 .39563 L
.94019 .39643 L
.94141 .39481 L
.94273 .39058 L
.94397 .38437 L
.94512 .37694 L
.94958 .33609 L
.95441 .28302 L
.95957 .23217 L
.96226 .211 L
.9648 .19455 L
.96727 .18159 L
.96956 .17201 L
.97172 .1648 L
.97402 .15894 L
.97633 .15468 L
.97764 .1529 L
.97886 .15163 L
.98017 .15065 L
.98091 .15026 L
.98159 .14999 L
.98284 .14972 L
.98418 .14974 L
.98549 .15002 L
.98673 .15052 L
.98784 .15114 L
.98905 .152 L
.99182 .15467 L
Mistroke
.99475 .15853 L
1 .16802 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
000eooooo`?o0000OOooool00ol0003oooooooooo`2`ooooo`00<_ooool4o`000003ooooool0003o
000000;o0000N_ooool00ol0003oooooooooo`12ooooo`Ko0000J?ooool0037ooooo0_l00008oooo
o`03o`000?oooooooooo07;ooooo1?l000000ooooooo0000ooooo`11ooooo`;o00001_ooool2o`00
06Kooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0LOooool2o`0000?o
oooo0ol00011ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool002oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1^ooooo`;o00001_ooool2o`00043ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`?o0000=Oooool002kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`11ooooo`Ko00009Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`;o00000_ooool2o`0003Cooooo000]ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0?oooool2o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool00000?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo0_l00005
ooooo`03o`000?oooooooooo037ooooo000]ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool0000mooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo037ooooo000/oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000l
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo033ooooo000/ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000003_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Fooooo`00;?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo1Ol0000F
ooooo`00:oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo0_l00002oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo
000001Kooooo000Zooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool2o`00
01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00:_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo0_l000000ooooooo0000o`00000Cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool001Gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00kooooo00GoV9RH
oa0@4?l0003o<S8bolc<c002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6oooool5o`0000;o
oooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h>ooooo`03o`000?oooooooooo00_ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hAooooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_l000006oooool01OnHV9So0000o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooooooo0_l00000
2Ol@413oooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0>ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgMa_ooooo00Go
V9RHob4Q8Ol0003oooooodA4A003ooooo`05o`000?nHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Coooo
o`?o00001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool0
0ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooo
oonHV9So000001_ooooo00Go410@o`000?ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00[o0000oooo
ooooooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg3_ooool000_ooooo1_l00002ooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool01oooool6o`0000Ko
oooo00Go0000oooooooooooo0000oa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003oooo
o`03o`000?lQ8B7ok^k^00Cooooo00Go0000oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00;ooooo1_l00005ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooo
oooooooooa0@4?l0000Kooooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Booooo`04ojVYZOl@413ooooooooo
o`;o00000oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03_ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003o
ooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000oooooooooooooooo0_l0000Joooo
o`05o`000?ooooooooooojVYZOl@41000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool03oooool01ol0003ooooooooooom4A4CogMgMooooool000001?ooool01Ol0003o
oooooooooooooooo000000kooooo000Cooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool04_ooool00ol@413o0000okZj^P02oooo
o`;o00000oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooogMgMomVIVH00oooool2
o`0000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`00
0?oooooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01ol0003ooooooooooooooooo0000oooo
ool000006Oooool01Ol0003ooooooa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00oooooo00Oo0000oooooooooooogMgMoeEEEOoooooo000000Co
oooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool01?mgMgOoc<c<o`000?l00003oooo
o`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0Cooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go0000oooooooooooooooooa0@400Jooooo`03o`000?oooooooooo00;ooooo00Ko
0000oooooooooooooooooa0@4?l00002ooooo`03oa0@4?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0>ooooo`;o00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooo`00000Hooooo`06o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool03_ooool01ol0003ooooooooooooooooo
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`05onk^k_m4
A4Co0000ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000oooooooo
ool04?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go0000oiRHV?ooooooV9RHogMgM`0I
ooooo`07o`000?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMol0003ooooooiRHV?mg
MgL03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000006?ooool01_l0
003o410@oiRHV?oooooo^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`00
0?oooooooooo00kooooo00Oo0000ooooooooooooooooonk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`005Oooool01?mgMgOo0000ooooool00002ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Aooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Ol0003o<S8bo`000?lb<S;ok^k^01Wooooo00Oo0000oooooonHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000000_ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00oooooo00?o0000ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo01Cooooo00Oo0000oooooonYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0K
ooooo`006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06?ooool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool001Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo0_l0000>ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01cooooo000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0@ooooo`Ko00004?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`006_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03ooo
ool2o`0001Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool07?ooool001Koooooool00010o`0001?ooooo000Foooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Kooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07Oooool001cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Mooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01go
oooo000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool001kooooo00Co
0000oooooooooooo00008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07_ooool001kooooo1?l0000Sooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`00AOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool2o`0000Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`;o00004Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01kooooo0015ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Nooooo`00A_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool004Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02o`0001Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01kooooo0016ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo1?l0
000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Nooooo`00A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`00A_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Noooo
o`00Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Nooooo`00Aoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`;o0000
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Qooooo`Go00008_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01kooooo0017ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Oooooo`00Aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01oooooo0017ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool004Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`00Aoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01oooooo0017ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07oooool004Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0O
ooooo`00Aoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0iooooo`;o00002Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool004Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Oooooo`00B?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01oooooo0018ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07ooo
ool004Wooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07oooool004Wooooo00Co0000oooooooooooo00008_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?oo
ool004Wooooo0_l000000ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;oooool5o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool004[ooooo0ol0000Roooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08?ooool0073ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0`ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00009ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`00L?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo037ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Pooooo`00L?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`00L?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Pooooo`00L?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo001`ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08?ooool0073ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo027ooooo001`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Qooooo`00L?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo0_l0000;
ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00L?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool0077ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00[ooooo00Co0000
oooooooooooo00008?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00LOooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0
000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo027ooooo001aooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000023ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08Oooool0077ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooool000008?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qoooo
o`00LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo001aooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooo0000023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08Oooool0077ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Rooooo`00LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03_ooooo0_l0000_ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo001aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Coooool01Ol0003ooooooooooooooooo000002Cooooo001aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool01Ol0003ooooooooooooooooo
000002Cooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool01Ol0
003ooooooooooooooooo000002Cooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0D?ooool01Ol0003ooooooooooooooooo000002Cooooo001booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0D?ooool01Ol0003ooooooooooooooooo000002Cooooo001boooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool0000T
ooooo`00L_ooool01Ol0003ooooooooooooooooo000003kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000009Oooool0
07;ooooo00Go0000ooooooooooooooooo`00000nooooo`;o0000<?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000009Oooool007;ooooo00Go0000oooo
ooooooooooooo`00000nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooo000002Gooooo001booooo`05o`000?oooooooooo
ooooool00000?_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0DOooool2o`0002Kooooo001booooo`05o`000?ooooooooooooooool00000?_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Tooooo`00L_ooool01Ol0003ooooooooooooooooo000003kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wooooo001boooo
o`05o`000?ooooooooooooooool00000=Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wooooo001boooo
o`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00Go0000ooooooooooooooooo`00001kooooo`00L_ooool01Ol0003ooooooooooooo
oooo000003?ooooo1Ol00006ooooo`03o`000?oooooooooo033ooooo00Go0000oooooooooooooooo
o`00001kooooo`00L_ooool01?l0003oooooooooool0000dooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0000`ooooo`05o`000?ooooooooooooooool00000Noooool007;ooooo00Co0000oooooooo
oooo0000=?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo033ooooo00Go0000
ooooooooooooooooo`00001kooooo`00Loooool00ol0003oooooo`00000eooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0001looooo`00Loooool0
0ol0003oooooo`00000eooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<?ooool0
1?l0003oooooooooool0001looooo`00Loooool00ol0003oooooo`00000fooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00001looooo`00Loooool00ol0
003oooooo`00000oooooo`03o`000?oooooooooo037ooooo00?o0000ooooool00000O?ooool007?o
oooo00?o0000ooooool00000?oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000007co
oooo001dooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`1kooooo`00]Oooool2o`0003?ooooo00?o0000ooooooooool0Noooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00
Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@
4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@
o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002c
ooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01?l@413o0000odA4A?o<c<`4
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool008Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009oooo
o`Ko00002oooool00onHV9So410@omgMg@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03ohN7QomEEEGo
oooo00;ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003oooooodA4A?m4
A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEE
EOl000000oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go8B4QohN7QoooooooV9RHo`000003oooo
o`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@
4?l0003o000000?o00006Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooo
oooooooooa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_oo
ool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00
Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05olc<c?l@413o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(92) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23543 m
.00123 .23697 L
.00236 .23808 L
.00365 .23899 L
.00488 .23945 L
.00601 .23951 L
.00706 .23925 L
.00821 .23861 L
.00942 .23753 L
.01065 .23605 L
.01196 .23403 L
.01434 .22935 L
.01975 .21484 L
.0297 .18212 L
.03496 .16602 L
.04057 .15182 L
.04671 .13977 L
.05241 .13151 L
.05545 .12821 L
.05832 .12573 L
.06092 .12394 L
.06367 .12242 L
.06619 .12132 L
.06753 .12085 L
.06896 .12043 L
.07028 .12012 L
.07148 .11992 L
.07268 .11979 L
.07382 .11973 L
.07515 .11974 L
.07582 .11978 L
.07656 .11986 L
.07786 .12005 L
.07909 .1203 L
.08184 .12109 L
.08481 .12227 L
.08733 .12356 L
.09001 .12527 L
.09486 .12943 L
.10062 .1364 L
.10585 .14456 L
.11725 .16877 L
.12801 .19726 L
.13821 .22254 L
.14336 .23264 L
.14902 .24127 L
.1684 .26672 L
.17101 .2701 L
.17387 .27333 L
.17518 .27453 L
Mistroke
.17589 .2751 L
.17657 .27557 L
.17788 .27625 L
.17907 .27659 L
.18025 .27662 L
.18151 .2763 L
.18258 .27572 L
.18375 .27475 L
.18502 .27329 L
.18637 .27125 L
.18882 .26639 L
.19164 .25902 L
.19472 .24925 L
.2003 .22837 L
.21075 .18765 L
.21552 .17216 L
.22065 .15859 L
.22628 .14701 L
.23156 .13916 L
.23424 .13626 L
.23717 .13383 L
.24023 .13195 L
.2417 .13124 L
.24308 .13068 L
.24436 .13024 L
.24504 .13005 L
.24575 .12988 L
.24702 .12965 L
.24818 .12953 L
.24952 .12952 L
.25078 .12963 L
.25215 .1299 L
.25292 .13012 L
.25363 .13036 L
.25602 .13148 L
.25738 .13232 L
.25866 .13325 L
.26146 .13573 L
.26402 .13868 L
.26627 .14198 L
.26865 .1464 L
.27103 .15208 L
.27364 .16004 L
.2765 .17122 L
.2791 .18399 L
.28189 .20098 L
.28493 .22382 L
.29033 .27699 L
.29543 .33778 L
.2979 .36655 L
Mistroke
.30056 .39314 L
.30184 .40344 L
.30306 .41126 L
.30416 .41644 L
.30535 .41998 L
.30609 .42102 L
.30679 .42118 L
.3081 .41936 L
.30883 .41715 L
.3095 .41439 L
.31102 .40577 L
.31224 .39668 L
.31358 .38482 L
.31628 .35654 L
.32221 .28845 L
.32513 .25853 L
.32783 .23495 L
.33288 .20177 L
.33554 .1893 L
.33836 .17918 L
.34078 .17269 L
.34205 .17 L
.34339 .16764 L
.34457 .16594 L
.34585 .16444 L
.34702 .16339 L
.34811 .16265 L
.34878 .1623 L
.34951 .162 L
.35084 .16169 L
.35212 .16163 L
.35331 .16179 L
.3546 .16216 L
.35533 .16247 L
.35601 .16282 L
.35738 .16371 L
.35886 .16493 L
.36168 .16803 L
.36475 .17261 L
.37034 .18412 L
.38083 .21453 L
.38643 .23235 L
.38918 .24018 L
.3917 .24624 L
.394 .2505 L
.39516 .2521 L
.39643 .25339 L
.39771 .25417 L
.39908 .25442 L
.40037 .25409 L
Mistroke
.40154 .25332 L
.40291 .25186 L
.40437 .24968 L
.40697 .24426 L
.40978 .2366 L
.41287 .22654 L
.42358 .18757 L
.42903 .1701 L
.43422 .15649 L
.43893 .14664 L
.44395 .13844 L
.44939 .1319 L
.45443 .12758 L
.45752 .12556 L
.46043 .124 L
.46324 .1228 L
.46587 .12194 L
.46708 .12163 L
.46823 .12139 L
.46955 .12118 L
.47075 .12104 L
.47209 .12094 L
.47332 .12091 L
.47468 .12093 L
.47536 .12096 L
.47612 .12102 L
.4768 .12108 L
.47752 .12117 L
.4788 .12136 L
.48019 .12164 L
.4817 .12204 L
.48442 .12302 L
.48694 .1243 L
.48947 .12602 L
.49185 .1281 L
.49632 .1333 L
.49882 .13711 L
.50112 .1413 L
.50634 .15381 L
.51124 .17037 L
.51651 .19408 L
.52603 .25008 L
.53184 .2852 L
.5347 .2993 L
.53609 .30488 L
.53735 .30907 L
.53858 .31231 L
.53975 .31455 L
.54097 .31605 L
.5423 .31667 L
Mistroke
.54367 .31625 L
.54436 .31566 L
.54511 .31473 L
.54645 .3124 L
.5477 .30954 L
.58859 .24091 L
.60943 .1897 L
.62041 .15856 L
.62595 .14704 L
.62911 .14238 L
.63052 .14075 L
.63206 .13928 L
.63335 .13828 L
.63473 .13744 L
.63549 .13707 L
.63618 .1368 L
.63753 .13646 L
.63877 .13637 L
.64011 .13656 L
.64138 .13706 L
.64254 .13782 L
.64389 .13914 L
.64516 .14084 L
.64654 .14328 L
.64803 .14664 L
.65106 .15615 L
.65383 .16841 L
.65639 .18341 L
.65877 .20111 L
.66138 .22561 L
.66415 .25824 L
.66892 .32898 L
.67394 .40924 L
.67639 .4411 L
.67777 .45487 L
.67906 .46421 L
.68025 .46951 L
.68133 .47142 L
.68258 .47012 L
.68376 .46549 L
.68504 .4569 L
.6864 .44415 L
.68884 .4137 L
.69435 .32827 L
.69875 .2659 L
.70118 .23842 L
.70348 .21718 L
.70619 .19762 L
.70867 .184 L
.711 .17425 L
Mistroke
.71353 .1664 L
.71493 .16318 L
.71622 .16082 L
.71763 .15885 L
.71834 .15808 L
.71912 .15739 L
.72043 .15656 L
.72116 .15625 L
.72183 .15605 L
.72314 .15587 L
.72437 .15589 L
.72556 .15606 L
.72682 .15634 L
.72908 .15706 L
.73151 .15807 L
.7342 .15945 L
.74569 .16793 L
.75072 .17145 L
.75622 .1755 L
.76135 .1805 L
.76612 .18647 L
.77116 .19454 L
.77654 .20631 L
.78794 .24162 L
.79294 .25733 L
.79578 .26479 L
.79717 .26781 L
.79844 .27012 L
.79973 .27197 L
.80096 .27322 L
.80226 .27395 L
.80299 .27408 L
.80367 .27402 L
.80439 .27376 L
.80507 .27333 L
.80635 .27204 L
.80772 .26995 L
.8092 .26694 L
.81216 .25883 L
.81528 .24791 L
.82086 .22509 L
.83108 .18384 L
.83681 .16576 L
.84202 .15329 L
.84711 .14408 L
.8498 .1402 L
.85264 .13676 L
.85513 .13431 L
.85787 .13213 L
.86038 .13053 L
Mistroke
.86269 .12932 L
.86498 .12832 L
.86748 .12741 L
.86885 .127 L
.87012 .12667 L
.87141 .1264 L
.87263 .1262 L
.87377 .12607 L
.875 .12598 L
.87612 .12594 L
.87714 .12595 L
.87826 .126 L
.87948 .1261 L
.88076 .12624 L
.88196 .12642 L
.88468 .12697 L
.8872 .12768 L
.88997 .12877 L
.89292 .13042 L
.89546 .13235 L
.89785 .13468 L
.90048 .13789 L
.90331 .14229 L
.90825 .15316 L
.91074 .16069 L
.91346 .17095 L
.91829 .19541 L
.92278 .2264 L
.92808 .27258 L
.93382 .32702 L
.93645 .34875 L
.93789 .35863 L
.93924 .3662 L
.94039 .37118 L
.94162 .3749 L
.94299 .37693 L
.94424 .37683 L
.94545 .37497 L
.94673 .37119 L
.94793 .36602 L
.94903 .36013 L
.95425 .32112 L
.95887 .28162 L
.96376 .24567 L
.96584 .23342 L
.96808 .22261 L
.97054 .21345 L
.97164 .21025 L
.97283 .20736 L
.97399 .20513 L
Mistroke
.97507 .20355 L
.9761 .20246 L
.97719 .20173 L
.97817 .20144 L
.97909 .20144 L
.98009 .20174 L
.98117 .20238 L
.98236 .20343 L
.98346 .20469 L
.98596 .20841 L
.991 .21823 L
1 .23543 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
000[ooooo`Ko0000NOooool6o`0000Gooooo00?o0000ooooooooool0/?ooool002Wooooo0_l00006
ooooo`03o`000?oooooooooo07Cooooo0ol00004ooooo`?o00000oooool00ol0003oooooooooo`2`
ooooo`00:?ooool00ol0003oooooooooo`07ooooo`;o0000L_ooool2o`0000[ooooo00Co0000oooo
oooooooo0000M?ooool7o`0003Oooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0;?ooool4o`0003oooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o0000
077ooooo0_l00007ooooo`;o0000=Oooool002Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Yooooo`?o00000oooool2o`0003cooooo00?o0000ooooooooool03?ooool2o`00077o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0booooo`009_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:?ooool3o`0004;ooooo
0_l0000=ooooo`03o`000?oooooooooo037ooooo000Uooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Wooooo`;o000000?oooooo`000?l00000@?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo037ooooo000Uooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00;ooooo0_l0000oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool0
02Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool002Cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Aooooo`;o00009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0_ooooo`008oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo017ooooo0_l0000Vooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo
000Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool3o`0002Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`?o00009?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02kooooo000Rooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04_ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04_ooool2o`000004ooooool0003o0000o`0002;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0^ooooo`008_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`?o00006?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooo000002?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l0000Pooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0;Oooool001Gooooo0_l000002Ol@413ooooooooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo01Gooooo00Go0000oa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool00ol0003oooooooooo`04oooo
o`Go00000oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Gooooo0_l000000ooooooo0000o`000002
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPSooooo00?o0000oooooooo
ool04oooool01?l0003oooooooooool0000Nooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00?o0000ooooooooool04?ooool01?l0003oooooooooooooool6o`0000;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Gooooo`09o`000?oooooooooooooooonHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Cooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000Hooooo`05oa0@4?l0003o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool0
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Doooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`00023ooooo
0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0@ooooo`0:
o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A4ooooo`;o000000GoMgMgoiRHV?oooooo
V9RHogMgM`0Fooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003
ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000@ooooo`Ko00000oooool01?l0003ooooo
ooooool00003ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo000001?ooooo1_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oo
oooooooo01Cooooo00Co0000oooooooooooo00008?ooool2o`0000?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00onHV9So
8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool@41005_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4
omgMgOoooooo00001?ooool01?l0003oooooooooooooool2o`0001[ooooo00Co0000oooooonYZJWo
410@0oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo00008?ooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`06
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo017ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooooooo0_l0000Koooo
o`;o000000Go^[Zjooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool02?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00008?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool3o`000003ooooool0003o
oooo01Cooooo00?o0000ooooooooool01Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`0Aooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`06oa0@
4?ooooooooooooooool@413o00006oooool00ol0003o^[Zjob4Q8@03ooooo`05oa0@4?oooooooooo
ooooool@41004oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413o0000ooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool05Oooool2o`0000;ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
oooooooooa0@4002ooooo`03o`000?l@413ooooo01Cooooo00?o0000ooooooooool01_ooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0B
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?l000006_ooool01Ol@413oV9RHo`00
0?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Ko
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004Ooo
ool00ol0003oooooooooo`08ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000001oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9So000001Cooooo00?o0000ooooooooool01?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01;ooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05ojVYZOl@413o0000o`000?nYZJT00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool01_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000Aooooo`03o`000?oooooooooo
00Oooooo00?oEEEEo`000?l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool05Oooool01Ol0003ooooooooooooooooo000001gooooo00?oEEEEo`000?l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^
o`0001?ooooo00?o0000ooooooooool01?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo01;ooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Oooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo
00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:oooool001kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0[ooooo`007Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool3o`00
01Wooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`04ooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`;o
00000oooool01Ol0003ooooooooooooooooo000001?ooooo000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000004oooool001cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0D
ooooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo000Kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool001_ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo000Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool0
01Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06_ooool2o`0000Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo000Fooooo`04o`000?ooooooooooo`00
02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool001Kooooo0ol0000[ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`00AOooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool004Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo0016
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`00Aoooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Cooooo`;o000000?oooooo`000?ooool07Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool004Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05?ooool2o`0001oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01cooooo0018ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo0_l00006ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool004Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
7Oooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01cooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07Oooool004_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07Oooool004cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00Co0000ooooool0003o0000
9Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo001=ooooo`;o000000?o
ooooo`000?l000008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`;o00009_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01kooooo001>ooooo`?o00008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool007;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo001booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool2o`0000Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo001booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`00L_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_oo
ool007;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo001cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Nooooo`00Loooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool07_ooool007?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0[ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`00Loooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01oooooo001cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Ooo
ool00onHV9So8B4Qonk^kP07ooooo`?o00002Oooool01?l0003oooooooooool0000Uooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01oooooo001cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_oo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Oooooo`00Loooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02oooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0:ooooo`;o00009ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Oooooo`00Loooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07oooool007?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0/ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01oooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0;?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`00M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`00M?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`00M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo
0_l0000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo001d
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo001dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo001eooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo000002?ooooo
001eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooo
oooooooo000002?ooooo001eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Booo
ool01Ol0003ooooooooooooooooo000002?ooooo001eooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0>?ooool2o`0003Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1;ooooo`05o`000?ooooooooooooooool000008oooool007Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooo000002Cooooo001eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooo`00000Tooooo`00MOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo00?o0000ooooool000009?ooool007Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo000002Co
oooo001eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0Sooooo`00MOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07?ooooo001e
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Loooool007Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0hooooo`;o0000=Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07?ooooo001eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Loooool007Gooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1dooooo`00MOooool01Ol0003ooooo
oooooooooooo000003_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo07Cooooo001fooooo`04o`000?ooooooooooo`0003_ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo001fooooo`04o`00
0?ooooooooooo`0003;ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1dooooo`00M_ooool01?l0003ooooo
ooooool0000cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07Cooooo001fooooo`04o`000?ooooooooooo`00033o
oooo1Ol00006ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1dooooo`00M_ooool00ol0003oooooo`00000aooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0000dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool007Oooooo
0_l0000aooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07Cooooo001gooooo`;o0000<_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1dooooo`00Moooool00ol0003oooooooooo`0aooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo002/
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo07Cooooo002eooooo`03o`000?oooooooooo03Gooooo00Go0000oooo
ooooooooooooo`00001fooooo`00]Oooool00ol0003oooooooooo`0eooooo`04o`000?oooooooooo
o`0007Oooooo002eooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000Moooool0
0;Gooooo0_l0000fooooo`04o`000?ooooooooooo`0007Oooooo002eooooo`03o`000?oooooooooo
03Gooooo00Co0000oooooooooooo0000Moooool00;Gooooo00?o0000ooooooooool0=Oooool01?l0
003oooooooooool0001gooooo`00]Oooool00ol0003oooooooooo`0eooooo`04o`000?oooooooooo
o`0007Oooooo002eooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000Moooool0
0;Gooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0001gooooo`00]Oooool00ol0
003oooooooooo`0eooooo`04o`000?ooooooooooo`0007Oooooo002eooooo`03o`000?oooooooooo
03Gooooo00Co0000oooooooooooo0000Moooool00;Gooooo0_l0000gooooo`;o0000N?ooool00;Go
oooo00?o0000ooooooooool0=_ooool2o`0007Sooooo002eooooo`03o`000?oooooooooo03Kooooo
0_l0001hooooo`00]Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Kooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[o
oooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o0000
0;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo
00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooo
oooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`04oa0@4?l0003oA4A4olc<c0Cooooo1Ol0001looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l0000;ooooo`03oiRHV?l@413ogMgM00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A01l
ooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?oQhN7
oeEEEOooool00oooool00onHV9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl0
00001Oooool00onHV9So8B4Qonk^kP1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`00
01Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`0Jooooo`05ob4Q8On7QhOooooooiRHV?l000001_ooool00omgMgOoIVIV
ooooo`1kooooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Ioooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`1jooooo`00QOooool01_l0
003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?o
oooo00Go0000okZj^_ooooooV9RHoa0@401looooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03
ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`0Jooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ
8B7oc<c<07cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(94) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23254 m
.00488 .20445 L
.00942 .18184 L
.01441 .162 L
.01975 .14634 L
.02244 .14037 L
.02535 .13512 L
.02792 .13143 L
.03065 .12834 L
.0331 .1262 L
.03441 .1253 L
.03581 .12449 L
.03709 .12388 L
.03826 .12343 L
.03944 .12309 L
.04057 .12285 L
.04126 .12274 L
.042 .12266 L
.04335 .12261 L
.04467 .12266 L
.04588 .1228 L
.04719 .12304 L
.04863 .12342 L
.05013 .12394 L
.05154 .12453 L
.05645 .12743 L
.05921 .12961 L
.06172 .13194 L
.07358 .14685 L
.08481 .1648 L
.09004 .17276 L
.09495 .17898 L
.09741 .18144 L
.10006 .18348 L
.1015 .18431 L
.10228 .18468 L
.10301 .18497 L
.1043 .18536 L
.10498 .18549 L
.10571 .18559 L
.10702 .18565 L
.10821 .18556 L
.10953 .18533 L
.1102 .18517 L
.11093 .18494 L
.11347 .18391 L
.11585 .18266 L
.12063 .17979 L
.12295 .17849 L
.12505 .17751 L
Mistroke
.12636 .17706 L
.12759 .17675 L
.12888 .1766 L
.12961 .17659 L
.13028 .17665 L
.13161 .17693 L
.13236 .1772 L
.13306 .17754 L
.13447 .17846 L
.13598 .17986 L
.13732 .18147 L
.13877 .18366 L
.14141 .18889 L
.14398 .19568 L
.14636 .20354 L
.15085 .22258 L
.1558 .24892 L
.16059 .27643 L
.1633 .29073 L
.16582 .30181 L
.16711 .30633 L
.16833 .30973 L
.169 .31122 L
.16973 .31251 L
.171 .31389 L
.17238 .31413 L
.17307 .31375 L
.17383 .31293 L
.17518 .31051 L
.17645 .30716 L
.1789 .29792 L
.18114 .28687 L
.18617 .25664 L
.19169 .22225 L
.19755 .19122 L
.20256 .17123 L
.20541 .1625 L
.20809 .15586 L
.21053 .15097 L
.21311 .14685 L
.21534 .14402 L
.21772 .1416 L
.22028 .13961 L
.22267 .13823 L
.22414 .13759 L
.22552 .13711 L
.22676 .13677 L
.2281 .1365 L
.22946 .1363 L
.23072 .13618 L
Mistroke
.23145 .13613 L
.23211 .13611 L
.23288 .13609 L
.2336 .13609 L
.23431 .13609 L
.23505 .13611 L
.23639 .13617 L
.23721 .13622 L
.23799 .13627 L
.23943 .1364 L
.24205 .13669 L
.24446 .13703 L
.24989 .13802 L
.25483 .13903 L
.25755 .13961 L
.26012 .14023 L
.26252 .14091 L
.26512 .14185 L
.26967 .14417 L
.27227 .14599 L
.27514 .14859 L
.27814 .15223 L
.28095 .15688 L
.28357 .16263 L
.28597 .16943 L
.2886 .17891 L
.29137 .19157 L
.30217 .27439 L
.30747 .33182 L
.3098 .35644 L
.31236 .38003 L
.31346 .38847 L
.31465 .39604 L
.31577 .40159 L
.3168 .40518 L
.31795 .40746 L
.31921 .40774 L
.3204 .40592 L
.3215 .40246 L
.3228 .39635 L
.32402 .38876 L
.3263 .37071 L
.33141 .32029 L
.33623 .27412 L
.33886 .25344 L
.34132 .23783 L
.34398 .22493 L
.34539 .21974 L
.34689 .21538 L
.34827 .21242 L
Mistroke
.34958 .21048 L
.35075 .20942 L
.35202 .20897 L
.35338 .20925 L
.35466 .21018 L
.35539 .21099 L
.35606 .21189 L
.35757 .21446 L
.36059 .22147 L
.36346 .22978 L
.369 .24733 L
.37161 .25492 L
.37402 .26074 L
.37521 .26305 L
.37651 .26507 L
.37782 .26651 L
.3792 .26732 L
.38042 .2674 L
.38172 .2668 L
.38295 .26559 L
.38408 .26394 L
.38545 .26126 L
.38672 .25816 L
.38959 .24922 L
.39481 .22831 L
.40409 .18803 L
.40897 .16979 L
.41411 .15431 L
.41938 .14236 L
.42421 .13427 L
.42874 .12863 L
.43131 .12617 L
.4337 .12431 L
.43651 .1226 L
.43917 .12138 L
.44156 .12056 L
.4429 .1202 L
.44415 .11993 L
.4455 .1197 L
.44621 .1196 L
.44698 .11952 L
.44778 .11947 L
.44854 .11944 L
.44922 .11944 L
.44997 .11946 L
.45131 .11956 L
.45206 .11965 L
.45275 .11976 L
.45408 .12003 L
.45533 .12037 L
Mistroke
.45786 .12127 L
.46023 .12238 L
.46304 .12404 L
.4656 .1259 L
.47083 .13099 L
.47371 .13467 L
.47644 .13879 L
.48574 .15748 L
.49585 .18514 L
.50101 .20022 L
.50658 .21439 L
.50914 .21959 L
.51183 .2239 L
.51413 .22655 L
.51543 .22763 L
.51664 .22835 L
.51801 .22884 L
.5193 .22902 L
.52046 .22896 L
.52172 .22869 L
.52309 .22818 L
.52454 .22747 L
.52714 .22595 L
.5298 .2245 L
.53056 .22416 L
.53129 .2239 L
.53265 .22359 L
.53343 .22354 L
.53415 .22359 L
.53494 .22375 L
.53578 .22406 L
.5365 .22445 L
.53717 .22492 L
.53871 .22642 L
.53994 .22809 L
.54125 .23035 L
.54363 .23577 L
.54644 .24458 L
.54901 .25481 L
.55421 .28066 L
.55696 .29542 L
.55986 .31002 L
.56234 .32026 L
.56374 .32473 L
.56506 .32785 L
.56626 .3297 L
.56737 .33048 L
.56864 .33026 L
.56985 .32892 L
.57098 .32667 L
Mistroke
.57219 .32324 L
.57436 .31458 L
.57694 .30072 L
.57928 .28568 L
.58911 .21676 L
.59449 .18633 L
.5995 .16517 L
.60212 .15667 L
.60493 .1493 L
.60805 .14302 L
.61089 .1388 L
.61346 .13601 L
.61492 .1348 L
.61627 .13389 L
.61754 .13318 L
.61874 .13265 L
.61998 .13222 L
.62136 .13188 L
.6226 .1317 L
.62392 .13162 L
.62516 .13166 L
.62629 .13179 L
.62763 .13206 L
.62838 .13226 L
.62907 .13247 L
.63169 .13354 L
.6342 .13489 L
.63697 .13665 L
.64256 .14091 L
.6474 .14556 L
.6526 .15186 L
.65715 .15853 L
.66199 .16725 L
.66489 .17382 L
.66751 .18109 L
.67263 .20026 L
.67551 .21472 L
.67861 .23411 L
.68423 .28134 L
.6891 .33437 L
.6943 .39355 L
.69584 .40855 L
.69729 .42068 L
.6986 .42945 L
.69927 .43308 L
.70001 .43632 L
.70136 .44004 L
.70209 .44086 L
.70278 .44084 L
.70401 .43888 L
Mistroke
.70534 .4341 L
.70601 .43065 L
.70673 .42627 L
.70802 .41667 L
.71095 .38834 L
.71629 .32533 L
.72111 .2717 L
.72632 .22697 L
.72943 .20725 L
.7323 .19308 L
.73503 .18266 L
.73643 .1784 L
.73793 .17455 L
.73928 .17167 L
.74052 .16951 L
.74178 .16774 L
.74295 .16645 L
.7443 .16537 L
.74501 .16497 L
.74577 .16466 L
.74705 .16441 L
.74777 .16441 L
.74846 .16451 L
.74969 .16493 L
.75101 .1657 L
.75225 .16675 L
.75338 .16798 L
.75615 .17212 L
.75877 .17759 L
.76398 .193 L
.76963 .21585 L
.77446 .23873 L
.77966 .26308 L
.78218 .27311 L
.78342 .2773 L
.78457 .28065 L
.78569 .28336 L
.78671 .2853 L
.78784 .28683 L
.78905 .28772 L
.79033 .2878 L
.79151 .28709 L
.7928 .28546 L
.79416 .28281 L
.79535 .27978 L
.79646 .27638 L
.79898 .26692 L
.8099 .21289 L
.81538 .18778 L
.82057 .16883 L
Mistroke
.82343 .16047 L
.82654 .1529 L
.82917 .14761 L
.83199 .14288 L
.83465 .13923 L
.83709 .13648 L
.84187 .1324 L
.84441 .1308 L
.84719 .12938 L
.85012 .1282 L
.85278 .12736 L
.85414 .12701 L
.85562 .12669 L
.85831 .12624 L
.8598 .12607 L
.86062 .126 L
.86138 .12594 L
.86273 .12586 L
.86344 .12584 L
.86421 .12582 L
.86557 .12582 L
.86635 .12584 L
.86706 .12586 L
.86837 .12593 L
.8691 .12598 L
.86977 .12604 L
.87102 .12618 L
.87238 .12637 L
.87484 .12685 L
.87735 .12754 L
.88003 .12852 L
.88256 .12973 L
.88486 .13109 L
.88757 .13307 L
.8905 .13578 L
.89584 .14262 L
.8985 .14718 L
.90143 .15327 L
.90735 .16961 L
.91284 .19021 L
.91798 .21419 L
.92319 .24146 L
.92887 .27032 L
.93147 .28151 L
.93425 .29112 L
.93559 .29476 L
.93686 .29754 L
.938 .29947 L
.93923 .30096 L
.94045 .30185 L
Mistroke
.94158 .30218 L
.94283 .30202 L
.94416 .30132 L
.94483 .30078 L
.94556 .30008 L
.94688 .29853 L
.94936 .295 L
.95868 .28486 L
1 .23254 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Rooooo`Ko00003Oooool00ol0003oooooooooo`2`ooooo`008Oooool7o`0007Sooooo0_l00006
ooooo`;o00002oooool00ol0003oooooooooo`2`ooooo`008?ooool2o`0000Kooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003oooooooooo`1]oooo
o`Wo0000>_ooool001oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2o`0006cooooo0_l00009ooooo`;o
0000>?ooool001oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`Ko0000
@Oooool2o`0000gooooo00?o0000ooooooooool0=Oooool001kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0aooooo`So0000>?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`007Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo0_l00007ooooo`Go0000<_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0cooooo`007Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool02oooool3o`0002oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?ooool2o`00
03_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`007?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo000Looooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0<Oooool001_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0aooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00oooool2o`0001kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<?ooool001_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0`ooooo`006_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02oooooo000Eooooo`;o000000Wo410@oooooooooooo0000onk^k_lb<S;o0000
oc8b<_o^k^h04Oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo00?o0000ooooooooool02?ooool5o`0000?ooooo
00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001[ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^0_ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00007oooool00ol0003oooooo`000003o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`03o`000?oooooooooo01;ooooo1Ol000002?oooooo0000o`000?o^k^ko<S8bo`000?lb
<S;ok^k^4_ooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool05_ooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`0:o`000?oooooooooooooo
ool0003oMgMgoiRHV?ooooooV9RHogMgMa7ooooo00?o0000ooooooooool01_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo
00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`07ogMgMonHV9SooooooiRHV?mgMgOooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03
o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Oooooo`05o`000?oooooooooo
ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool04_oo
ool01_nHV9So8B4Qonk^k_ooooooA4A4o`0000;ooooo0_l000000oooooooV9RHogMgM`0Aooooo`03
o`000?oooooooooo00Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00002ooooo`03o`000?l@413o
oooo00;ooooo00?o410@ooooooooool04?ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00gooooo00Co0000oooooooooooooooo1_l00003ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00ko
oooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo
000001Wooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01?ooooo00CoV9RHob4Q8Oo^
k^ko00000oooool01Ol@413o0000oooooooooooo410@017ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oM
gMgoooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000001Wooooo00Co0000oooooooooooo00007_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01?ooooo00?oV9RHob4Q8Ol000000oooool2o`0000;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo01?ooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000;ooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
410@o`000?l000000_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
oooo0_l0000Jooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0D
ooooo`03ogMgMol0003ooooo00;ooooo00Go0000ooooool0003oooooo`00000@ooooo`03o`000?oo
oooooooo00[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool04oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001Cooooo00?oMgMgolc<c?l000000_ooool00ol0003ooooooa0@4003ooooo`03
oa0@4?oooooooooo01;ooooo00?o0000ooooooooool01Oooool2o`000005ob4Q8Ooooooo0000o`00
0?l@41000oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000006_ooool00ol0003ooooooooo
o`02ooooo`06oa0@4?ooooooooooooooool@413o00006oooool01?l0003oooooo`000?l0000Moooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Oooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Go410@ooooool0003ooooooa0@
400@ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool05?ooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000000_ooool01ol0003ooooo
ogMgMonHV9SooooooiRHV?mgMgL05Oooool2o`0000?ooooo0_l000000ooooooo^[Zjo`000002oooo
o`;o000000CoV9RHoooooonHV9SoMgMg3_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00006oooool00ol0
003oooooo`00000Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04?ooool01Ol0003o^[Zjooooool0
003o410@00?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`03o`000?oooooooooo00Sooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0Cooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`005Oooool02omgMgOo0000oooooooooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^01Ko
oooo1?l000001OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go0000oc8b<_l0003o<S8bonk^kP0>
ooooo`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Fooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bo`00000Mooooo`;o00007Oooool01ol0003oooooooooooooooooEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?oo
ool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0?ooooo`03
o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Dooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`006Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01_ooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01_ooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02cooooo000Gooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`005_ooooooo`00043o00004oooool0
01Kooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Oooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0[ooooo`005oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000001Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_o
oooo000Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000;ooooo`03
o`000?oooooooooo01kooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0:oooool001Kooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool07oooool01Ol0003ooooooooooooooooo000000Cooooo1?l0000?ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Zooooo`005_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Oooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo02[ooooo000Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool2o`00
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0:_ooool001Kooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool2o`0000_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`00A_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool004Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo0017
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`00Aoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool05?ooool004Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Gooooo0017ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Eooooo`00Aoooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool05_ooool004Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo0_l0000=ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05oooool004Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool0000Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Hooooo`00B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo0000
02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Wooooo0018ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0_l0000Uooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`00B?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Jooooo`00BOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Kooooo`00BOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000002[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`00BOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooo
oooooooo000002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`00BOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0aooooo`;o00003oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`04o`000?oo
ooooooooo`0002[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00B_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_oo
ool3o`0002cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`00B_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo001:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool08?ooool004[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`00000Soooo
o`00B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0@oooool01?l0003oooooooooool0000Tooooo`00B_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`Go
00001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo0ol0000Tooooo`00
Boooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1[ooooo`00Boooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0:?ooool00onHV9So8B4Qonk^kP07ooooo`?o00004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1[ooooo`00Boooool3o`0002Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1[ooooo`00C?ooool2o`0002Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0[ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1[ooooo`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo001hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Joooool007Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Aooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[oooo
o`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool04_ooool2o`0002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[ooooo`00
N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
4_ooool2o`0002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[ooooo`00N?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo0_l0000jooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Joooool007Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1[ooooo`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
06_ooooo001hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K?ooool007Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1/ooooo`00N?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06cooooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0K?ooool007Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/oooo
o`00N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo001hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool2o`0003_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1/ooooo`00N?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06cooooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K?ooool0
07Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`00NOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06gooooo001iooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0KOooool007Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1]ooooo`00NOooool01Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo001iooooo`05o`000?oooooo
ooooooooool00000=oooool2o`0003cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1]ooooo`00NOooool01Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo001jooooo`04o`000?oooooo
ooooo`0003Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo06gooooo001jooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo001jooooo`03o`000?oooooo0000
03Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06gooooo001jooooo`03o`000?oooooo000002oooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00001`ooooo`00Noooool2o`00033o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`05o`000?oooooooooooooo
ool00000L?ooool007_ooooo00?o0000ooooooooool0;?ooool5o`0000Kooooo00?o0000oooooooo
ool0>oooool01Ol0003ooooooooooooooooo0000073ooooo002Zooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0000kooooo`05o`000?ooooooooooooooool00000L?ooool00:[ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool00000L?oo
ool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0looooo`04o`000?oooooo
ooooo`00073ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0??ooool0
1?l0003oooooooooool0001`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo03cooooo00Co0000oooooooooooo0000L?ooool00;Gooooo00?o0000ooooooooool0??ooool0
1?l0003oooooooooool0001`ooooo`00]Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
0000077ooooo002eooooo`03o`000?oooooooooo03cooooo00?o0000ooooool00000LOooool00;Go
oooo0_l0000nooooo`;o0000LOooool00;Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`1`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zoooo
o`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402i
ooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000
oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo
0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`04oa0@4?l0003oA4A4olc<c0Kooooo
0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;
ooooo`03oiRHV?l@413ogMgM00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03ohN7QomEEEGooooo00;ooooo1Ol0001l
ooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01?m4A4CogMgMooooool0001moooo
o`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05ob4Q
8On7QhOooooooiRHV?l000000oooool01?oMgMgoEEEEooooool0001mooooo`00QOooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o410@o`000?l000000ol0000Iooooo`05o`000?ooooooooooooooool00000
1?ooool00omgMgOoc<c<o`00001mooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wo
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool06_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00Cooooo00?ok^k^odA4A?l00000OOooool0
08Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool01Oo<c<co410@o`000?lb
<S;ok^k^00Gooooo00?oMgMgo`000?ooool0O?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(96) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20612 m
.00236 .19032 L
.00488 .1764 L
.00706 .16662 L
.00942 .15812 L
.01087 .15392 L
.0122 .15065 L
.01345 .14808 L
.01483 .14576 L
.01598 .14419 L
.01722 .14284 L
.01852 .14176 L
.01975 .14104 L
.02113 .14052 L
.02241 .14028 L
.02315 .14024 L
.02382 .14027 L
.02459 .14035 L
.02532 .1405 L
.02665 .1409 L
.02787 .14142 L
.02921 .14216 L
.03062 .14312 L
.03536 .14755 L
.04057 .15395 L
.05161 .16835 L
.05479 .17205 L
.0578 .17508 L
.06051 .17723 L
.06203 .17815 L
.06345 .1788 L
.06467 .17921 L
.06599 .17947 L
.06723 .17957 L
.06837 .17953 L
.06964 .17934 L
.07102 .17899 L
.07172 .17875 L
.07246 .17845 L
.07381 .17781 L
.07677 .17593 L
.07957 .17362 L
.08481 .16816 L
.09502 .15651 L
.1006 .15134 L
.10333 .14931 L
.10582 .14782 L
.10691 .1473 L
.1081 .14683 L
.10923 .1465 L
Mistroke
.11027 .14629 L
.11149 .14617 L
.11259 .14619 L
.11385 .14636 L
.11505 .14668 L
.11629 .14716 L
.11759 .14786 L
.11993 .1496 L
.12244 .15225 L
.1252 .15619 L
.12784 .16118 L
.13072 .16817 L
.13594 .18561 L
.14103 .20883 L
.14572 .23517 L
.15123 .26896 L
.15639 .29722 L
.15898 .3075 L
.15969 .30967 L
.16043 .31162 L
.16177 .31421 L
.16248 .3151 L
.16324 .31567 L
.1646 .31569 L
.16544 .31507 L
.16623 .31405 L
.16693 .31279 L
.1677 .31106 L
.17018 .3031 L
.17285 .2912 L
.17766 .26435 L
.1829 .23341 L
.18861 .20395 L
.19169 .191 L
.19454 .18093 L
.19722 .17305 L
.20017 .16586 L
.20528 .15647 L
.20808 .15263 L
.21072 .14969 L
.21564 .14553 L
.22102 .14225 L
.22627 .13973 L
.23188 .13759 L
.23715 .13598 L
.24194 .13469 L
.2464 .13365 L
.24762 .13342 L
.24893 .1332 L
.25007 .13304 L
Mistroke
.25131 .1329 L
.25267 .13279 L
.25396 .13273 L
.25522 .13271 L
.25639 .13274 L
.25775 .13282 L
.25899 .13293 L
.25968 .13302 L
.26042 .13313 L
.26177 .13339 L
.26294 .13368 L
.26422 .13406 L
.2668 .13513 L
.26919 .13654 L
.27143 .13828 L
.27426 .14119 L
.27694 .14477 L
.28196 .15409 L
.28477 .16114 L
.28737 .16908 L
.29325 .19284 L
.30269 .24669 L
.30765 .27784 L
.31035 .29321 L
.31287 .3053 L
.31432 .31102 L
.31565 .31525 L
.31712 .31882 L
.31793 .32025 L
.31869 .32125 L
.32002 .32221 L
.32125 .32223 L
.3226 .32136 L
.32328 .3206 L
.32403 .31954 L
.32664 .31436 L
.32944 .30724 L
.3321 .30037 L
.3345 .29506 L
.33588 .29272 L
.33718 .29112 L
.33855 .29015 L
.33932 .28996 L
.34003 .29002 L
.34122 .29064 L
.34252 .29207 L
.34388 .29443 L
.34515 .29738 L
.34809 .30671 L
.35076 .31748 L
Mistroke
.35387 .33101 L
.35675 .34226 L
.35806 .34633 L
.35928 .34934 L
.36055 .35148 L
.36123 .35215 L
.36196 .35251 L
.36268 .35245 L
.36347 .35192 L
.36421 .35095 L
.36491 .34965 L
.36621 .34614 L
.3676 .34093 L
.37037 .32645 L
.37299 .30879 L
.37787 .2701 L
.38316 .22804 L
.38811 .19473 L
.39327 .16822 L
.39601 .1574 L
.39894 .14795 L
.40143 .14142 L
.40414 .13568 L
.40654 .13164 L
.40908 .12825 L
.41136 .12589 L
.41388 .12394 L
.41499 .12327 L
.41618 .12267 L
.41728 .1222 L
.41833 .12185 L
.41965 .12152 L
.42085 .12133 L
.42213 .12122 L
.42286 .12121 L
.42353 .12123 L
.42465 .12134 L
.42588 .12154 L
.42717 .12187 L
.42837 .12228 L
.43114 .12358 L
.43367 .12522 L
.43662 .12766 L
.43936 .13045 L
.4448 .13754 L
.45073 .14792 L
.46151 .1728 L
.46686 .18608 L
.46967 .19266 L
.47263 .19887 L
Mistroke
.47523 .2034 L
.47661 .20536 L
.47808 .20709 L
.47944 .2083 L
.48068 .20909 L
.48192 .20957 L
.4831 .20973 L
.48422 .20962 L
.48546 .20922 L
.48675 .20848 L
.48796 .20751 L
.49013 .20516 L
.49246 .20185 L
.50264 .18165 L
.50751 .17182 L
.51019 .16721 L
.51271 .16358 L
.51415 .16186 L
.5157 .16032 L
.51711 .15923 L
.51842 .15849 L
.51964 .15806 L
.52099 .15789 L
.52167 .15795 L
.5224 .15811 L
.52372 .15869 L
.52443 .15917 L
.52519 .15982 L
.52656 .16135 L
.52804 .16356 L
.52966 .16673 L
.53257 .17441 L
.5353 .1842 L
.54039 .20965 L
.54588 .24786 L
.55073 .28771 L
.55591 .32728 L
.55744 .33639 L
.55889 .34335 L
.56018 .34803 L
.56092 .34995 L
.56159 .35126 L
.56282 .35244 L
.56416 .35195 L
.56484 .351 L
.56557 .34947 L
.56689 .3454 L
.56836 .33904 L
.56972 .3316 L
.57282 .31056 L
Mistroke
.57845 .26552 L
.58396 .225 L
.58903 .19675 L
.59162 .18588 L
.59436 .17673 L
.59711 .16967 L
.59869 .16644 L
.60013 .16398 L
.60274 .16052 L
.60418 .1591 L
.60554 .15804 L
.60679 .15727 L
.60796 .15672 L
.60923 .15626 L
.61059 .15592 L
.61179 .15573 L
.61289 .15562 L
.6141 .15557 L
.61538 .15557 L
.61649 .1556 L
.61753 .15566 L
.61866 .15575 L
.61987 .15587 L
.62485 .15644 L
.62617 .1566 L
.62758 .15675 L
.62889 .15686 L
.63013 .15694 L
.63079 .15697 L
.63152 .15699 L
.63279 .15698 L
.63353 .15695 L
.63431 .1569 L
.63505 .15683 L
.63572 .15675 L
.637 .15655 L
.63838 .15628 L
.64088 .15564 L
.64696 .1536 L
.65254 .15135 L
.65787 .14888 L
.66048 .1477 L
.66284 .14677 L
.66404 .14638 L
.66535 .14603 L
.66672 .14577 L
.66803 .14562 L
.66871 .14558 L
.66946 .14558 L
.67024 .14561 L
Mistroke
.67098 .14567 L
.67229 .14588 L
.67303 .14605 L
.67371 .14624 L
.67505 .14674 L
.67633 .14738 L
.67747 .14811 L
.6787 .1491 L
.68005 .15045 L
.68148 .15224 L
.68403 .15661 L
.68639 .16222 L
.6886 .16909 L
.69102 .17871 L
.69362 .19184 L
.69642 .20978 L
.69946 .23457 L
.705 .29471 L
.71035 .36401 L
.71297 .39538 L
.71412 .40729 L
.71537 .41855 L
.71649 .42673 L
.71768 .43333 L
.71894 .43772 L
.72012 .43929 L
.72149 .43803 L
.7228 .43382 L
.72396 .42771 L
.72523 .41882 L
.72798 .39311 L
.73089 .36011 L
.73612 .30113 L
.73873 .2769 L
.74154 .25658 L
.7429 .24894 L
.74419 .24299 L
.74546 .23831 L
.74662 .23505 L
.748 .23228 L
.74877 .23128 L
.74948 .23066 L
.75076 .2303 L
.75214 .23093 L
.75287 .23168 L
.75367 .2328 L
.75528 .23597 L
.75678 .2399 L
.75817 .24431 L
.76344 .26505 L
Mistroke
.76621 .27659 L
.76916 .28744 L
.7704 .29123 L
.77173 .29464 L
.77249 .29624 L
.77319 .29747 L
.77456 .29918 L
.77573 .29986 L
.777 .29975 L
.77833 .29867 L
.77956 .2968 L
.78078 .29413 L
.7821 .29038 L
.7845 .2815 L
.78899 .2595 L
.79905 .2044 L
.80385 .18273 L
.809 .16435 L
.81196 .15601 L
.81466 .14966 L
.81994 .14023 L
.82276 .13648 L
.82537 .13359 L
.82848 .13076 L
.83129 .12867 L
.83379 .12717 L
.8365 .12589 L
.83936 .12487 L
.84077 .12448 L
.84205 .12418 L
.84325 .12394 L
.84455 .12373 L
.84593 .12356 L
.84723 .12346 L
.84845 .1234 L
.84975 .1234 L
.85085 .12345 L
.85207 .12356 L
.8528 .12365 L
.85349 .12376 L
.8548 .12402 L
.8562 .1244 L
.85773 .12492 L
.86049 .12616 L
.86304 .1277 L
.86594 .12993 L
.86866 .13259 L
.87376 .13934 L
.87662 .14431 L
.87925 .14973 L
Mistroke
.88518 .16507 L
.89472 .19751 L
.89997 .21657 L
.90495 .23186 L
.90776 .2381 L
.90853 .23941 L
.90934 .2406 L
.91005 .24146 L
.91081 .2422 L
.91213 .24302 L
.91336 .24325 L
.91407 .24314 L
.91482 .24285 L
.91616 .24186 L
.91742 .24043 L
.91876 .23839 L
.92117 .23355 L
.92664 .21883 L
.93186 .20354 L
.93472 .19617 L
.93739 .1906 L
.93878 .18838 L
.9395 .18745 L
.94028 .18661 L
.94113 .1859 L
.94194 .18546 L
.94273 .18525 L
.94346 .18525 L
.94419 .18546 L
.94488 .18585 L
.94617 .1871 L
.94755 .18925 L
.94833 .19084 L
.94905 .19255 L
.95159 .2007 L
.95396 .21139 L
.95656 .22681 L
.95934 .24767 L
.96499 .30121 L
.97021 .35273 L
.97205 .36753 L
.97377 .37844 L
.97463 .38262 L
.97556 .38604 L
.9766 .38845 L
.97754 .38932 L
.97851 .38889 L
.9794 .38728 L
.98038 .38421 L
.98143 .37949 L
Mistroke
.98253 .37302 L
.98357 .36563 L
.98552 .34899 L
1 .20612 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Kooooo`?o00005oooool00ol0003oooooooooo`2`ooooo`00VOooool3o`0000;ooooo0_l0000E
ooooo`03o`000?oooooooooo06Wooooo1_l00011ooooo`00VOooool00ol0003oooooooooo`04oooo
o`;o00004oooool00ol0003oooooooooo`1Wooooo`?o00001Oooool2o`0003oooooo002Hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0006Kooooo0_l0000:ooooo`03
o`000?oooooooooo03cooooo001Tooooo`Oo0000;?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03_ooooo001Qooooo`?o00001oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0>_ooool001cooooo0ol0000nooooo`Co00002oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>Oooool0
01_ooooo0_l000000ooooooo0000o`00000kooooo`;o00004?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>Oooool001[ooooo0_l00004ooooo`03
o`000?oooooooooo01Gooooo0ol0000Oooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0<Oooool5o`0002cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l00002ooooo`;o0000
7?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo0ol00004ooooo`;o0000
:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oooooo000Jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=ooo
ool001Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`;o00008Oooool5
o`0000Gooooo0ol0000:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0fooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool4o`0001Sooooo0_l00005ooooo`Go00003Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=_ooool001Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooooooo
o`;o00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo000Eooooo`;o
000000Wo410@o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@4?l0003o<S8bo`000003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`09ooooo`Go00000oooool01oo^k^ko
<S8bo`000?lb<S;ok^k^ooooool000006_ooool4o`000004oa0@4?ooooooooooonk^kP;o000000?o
<S8bonk^k_ooool03oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000?o000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kPgooooo00?o0000ooooooooool02_ooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h07Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo000000;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool01_l@413o^[ZjoooooomgMgOo<S8bo`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go
MgMgo`000?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool02Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oo
oooooooo00_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Soooooo`000?mg
MgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_o
oooo1_l00002ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`000005o`0000Kooooo0_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`02ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0>ooooo`Ko00001Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41004Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00gooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo410@00;ooooo00?o0000
oa0@4?ooool06_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
0om4A4CogMgMooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001_oo
ool00ol0003oooooooooo`0;ooooo`06ojVYZOl@413oooooo`000?oooooo00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02oooo
o`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool02oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooooooo
o`0>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool00ooMgMgo
EEEEooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooooooo
ooooo`;o00003Oooool01ol@413o0000okZj^_oooooo0000ooooool000000oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool03_oo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00CoMgMgolc<c?l0
003o00000oooool01Ol@413ooooooooooooooooo410@00[ooooo1?l0000?ooooo`06okZj^_lQ8B7o
ooooo`000?oooooo410@0oooool00ol@413oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000006_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41004_ooool00ol0003oooooooooo`09
ooooo`;o00002Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02_ooool00ol0003ooooo
ooooo`0?ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@ooooooooooooooooo`00000Looooo`03
ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool01?o^k^ko
A4A4o`000?l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj
^[[o000000;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL=ooooo`03o`000?oooooooooo00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHogMg
M`0Cooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3oooool00ol0003oooooooooo`08ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03?ooool01Ol@413oV9RHoooooonj^[[o
000000?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Kooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Ko0000onk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Fooooo`03
oeEEEOmVIVKo000000Cooooo00Go0000oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo
00Sooooo0_l00009ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`08
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?o0000ooooooooool03?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Kok^k^oc8b<_l0
003o<S8bonk^k_l0000>ooooo`?o00002oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000ooooo`0Sooooo`005_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool2o`00
00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000008oooool001Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Kooooo0_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo000Fooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool001Kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Pooooo`005_ooooooo`00043o00004oooool001Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo1Ol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo00?o0000ooooool000001Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo0013ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo0013ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo0013
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo017ooooo0014ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo0014ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo0014ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3Oooool2o`0000gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`00A?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Rooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03Oooool3o`0000_ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01;ooooo0014ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool08_ooool01?l0003ooooooooo
ool0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool004Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`0Rooooo`?o00003Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo0015
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01?ooooo0015ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo0015ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02?ooooo0_l0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04oooool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04oooool004Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04ooo
ool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool004Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool004Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04oooool004Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool004Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05?ooool004Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09Oooool2o`0000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Dooooo`00Aoooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000003Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`00Aoooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool2o`0000[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool004Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05?ooool004Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`;o000000?oooooo`000?ooool0>Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Cooooo0017ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2
o`0003_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`00Aoooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool5o`00
00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05?ooool004Sooooo00Go0000ooooooooooooooooo`00000/oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Cooooo0018ooooo`;o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Loooo
o`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`00BOooool00ol0003oooooo`00000^ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`00
BOooool3o`0002kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo001kooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool007_ooooo0ol0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool05Oooool008Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0?ooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`00
Q_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool008Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo
00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo0026ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09_ooool2o`00013ooooo00Go0000oooooooooooo
ooooo`00000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo0026ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
0000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Fooooo`00Qoooool01Ol0003ooooooooooooooooo000002Wo
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05_ooool008Oooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo
013ooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04Wooooo00Go0000ooooooooooooooooo`00000Hooooo`00R?ooool00ol0003oooooo`00000Z
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000;?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`00000Hooooo`00R?ooool0
0ol0003oooooo`00000Zooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000;Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`00
000Hooooo`00R?ooool2o`0002_ooooo00?o0000ooooooooool04?ooool3o`0002gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1:ooooo`05o`000?ooooooooooooooool000006?oo
ool00;Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04[ooooo00Go0000ooooooooooooooooo`00000Hooooo`00]Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooooooo
oooo000001Sooooo002eooooo`;o0000@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04[ooooo00Go0000ooooooooooooooooo`00000Hooooo`00]Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooooooo
oooo000001Sooooo002eooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1:ooooo`05o`000?ooooooooooooooool000006?ooool00;Gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo00Go0000
ooooooooooooooooo`00000Hooooo`00]Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool0000Hooooo`00]Oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool0
1?l0003oooooooooool0000Hooooo`00]Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooo`00000Iooooo`00]Oooool00ol0
003oooooooooo`11ooooo`05o`000?ooooooooooooooool00000C_ooool00ol0003oooooo`00000I
ooooo`00]Oooool2o`0004;ooooo00Go0000ooooooooooooooooo`00001>ooooo`?o00006Oooool0
0;Gooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooooooo000004oooooo00?o0000
ooooooooool06?ooool00;Gooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooooooo
000006[ooooo002eooooo`03o`000?oooooooooo047ooooo00Go0000ooooooooooooooooo`00001Z
ooooo`00]Oooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00000J_ooool0
0:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo047ooooo00Go0000oooo
ooooooooooooo`00001Zooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
047ooooo00Go0000ooooooooooooooooo`00001Zooooo`00Z_ooool5o`0000Kooooo00?o0000oooo
ooooool0@Oooool01Ol0003ooooooooooooooooo000006[ooooo002Zooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol00011ooooo`05o`000?ooooooooooooooool00000J_ooool00:[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00000
J_ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`11ooooo`05o`000?oo
ooooooooooooool00000J_ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`11ooooo`05o`000?ooooooooooooooool00000J_ooool00:cooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooo000006_ooooo002eooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooool00000Joooool00;Gooooo00?o0000ooooooooool0@_ooool00ol0
003oooooo`00001[ooooo`00]Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo000006_o
oooo002eooooo`;o0000A?ooool00ol0003oooooooooo`1Zooooo`00]Oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo06[ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zj
ooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Co410@
o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<07cooooo0025ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000_ooooo00?oV9RHoa0@4?oMgMd00oooool01OmEEEGoMgMgoooooonH
V9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Ooo
ool00on7QhOoEEEEooooo`02ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko
0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo0000
00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Oo<
c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@1looooo`00QOooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05ob4Q8On7QhOooooo
oiRHV?l000000oooool01Ol0003oEEEEo`000?l@413oc<c<07cooooo0025ooooo`06o`000?n7QhOo
ZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol@413o0000o`000003o`0001Wooooo00Go0000ooooooooooooooooo`000003oooo
o`03oeEEEOn7QhOooooo07kooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool0
0ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003ooooooooo
o`0Jooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool00ooMgMgo410@oiRHV01nooooo`00Q?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05olc<c?l@413o0000oc8b<_o^
k^h01?ooool01?o<c<coA4A4o`000?l@411looooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(98) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25535 m
.00236 .24189 L
.00488 .22976 L
.00942 .21336 L
.0122 .20628 L
.01483 .20123 L
.01719 .19778 L
.01975 .19489 L
.04057 .17773 L
.06204 .1537 L
.06726 .14896 L
.07288 .14485 L
.07609 .14306 L
.07904 .14179 L
.08045 .1413 L
.082 .14084 L
.08481 .14021 L
.08621 .13998 L
.08694 .13989 L
.08772 .13981 L
.0884 .13976 L
.08914 .13972 L
.09046 .1397 L
.09174 .13973 L
.09311 .13984 L
.0944 .14002 L
.09558 .14023 L
.09705 .14058 L
.0984 .14097 L
.10147 .14215 L
.10418 .14352 L
.10706 .14535 L
.1095 .14726 L
.11213 .14977 L
.11688 .15584 L
.11963 .16045 L
.12253 .16634 L
.12772 .18002 L
.1385 .22491 L
.1438 .2541 L
.14868 .28103 L
.15098 .29215 L
.15312 .3009 L
.15429 .30482 L
.15536 .30778 L
.15655 .31034 L
.15782 .31217 L
.15909 .31299 L
.16026 .31286 L
.16154 .31172 L
Mistroke
.16291 .30938 L
.16421 .30613 L
.16544 .30222 L
.16773 .29298 L
.17846 .23363 L
.18317 .20864 L
.18832 .18584 L
.19347 .16834 L
.1989 .15493 L
.20481 .14464 L
.21032 .13781 L
.2156 .13318 L
.21857 .13121 L
.22132 .12967 L
.22637 .12741 L
.22892 .12652 L
.23029 .12613 L
.23173 .1258 L
.23294 .12557 L
.23426 .12539 L
.23546 .12529 L
.23658 .12524 L
.2379 .12525 L
.2391 .1253 L
.24049 .12543 L
.2418 .12562 L
.24294 .12584 L
.24415 .12613 L
.24633 .12682 L
.24866 .12787 L
.25123 .12948 L
.25386 .13173 L
.25672 .13496 L
.25925 .13856 L
.26193 .14323 L
.267 .15484 L
.27169 .16951 L
.28225 .21615 L
.2878 .24291 L
.29082 .25554 L
.2923 .26075 L
.29364 .26479 L
.29482 .26772 L
.2961 .27018 L
.29745 .2719 L
.29873 .27266 L
.29939 .27271 L
.30013 .2725 L
.3009 .27196 L
.30162 .27118 L
Mistroke
.30291 .26913 L
.30429 .26604 L
.30691 .25801 L
.30939 .24836 L
.31406 .22757 L
.3185 .20789 L
.32324 .19016 L
.32464 .18594 L
.32596 .1825 L
.32725 .17972 L
.32843 .1777 L
.32955 .17629 L
.33074 .17538 L
.33194 .1751 L
.33325 .17555 L
.33462 .17692 L
.33589 .17904 L
.33655 .18048 L
.33728 .18235 L
.33876 .18706 L
.34145 .19903 L
.34397 .21468 L
.34643 .23446 L
.34868 .25671 L
.35375 .31903 L
.35643 .35493 L
.35929 .3902 L
.36068 .40459 L
.362 .41582 L
.36317 .42357 L
.36445 .4292 L
.36581 .43179 L
.3665 .43171 L
.36725 .43056 L
.36858 .42583 L
.36983 .41843 L
.37131 .40627 L
.37267 .39242 L
.37571 .35453 L
.3807 .28627 L
.3854 .2312 L
.388 .20736 L
.39081 .18691 L
.39336 .1725 L
.3957 .16226 L
.39833 .15373 L
.39982 .15011 L
.4012 .14747 L
.40267 .14536 L
.40401 .14401 L
Mistroke
.40475 .14348 L
.40555 .14305 L
.40631 .14279 L
.40701 .14266 L
.40826 .14268 L
.40943 .14295 L
.41071 .14351 L
.41209 .14438 L
.41353 .14555 L
.41491 .1469 L
.41748 .15005 L
.42831 .17056 L
.43362 .18245 L
.43851 .19245 L
.44296 .19985 L
.4452 .20264 L
.44647 .20388 L
.44766 .20479 L
.44895 .20547 L
.45016 .20584 L
.45126 .20592 L
.45244 .20575 L
.45374 .20526 L
.45511 .20442 L
.45628 .20344 L
.45757 .20211 L
.4627 .19475 L
.46822 .18434 L
.47822 .16421 L
.48381 .15504 L
.48686 .15106 L
.4897 .14799 L
.49234 .14569 L
.49473 .14405 L
.4961 .14332 L
.49739 .14277 L
.49876 .14234 L
.49953 .14217 L
.50024 .14206 L
.50155 .14197 L
.5028 .14202 L
.50392 .14217 L
.50514 .14245 L
.50646 .1429 L
.50787 .14352 L
.51041 .14504 L
.51298 .14712 L
.5154 .14964 L
.51993 .15601 L
.52257 .16089 L
Mistroke
.52536 .16711 L
.53034 .18125 L
.53571 .20149 L
.5416 .23039 L
.54665 .25984 L
.55214 .29264 L
.55465 .30608 L
.55732 .31801 L
.5596 .32561 L
.5609 .32868 L
.56211 .33065 L
.56279 .33135 L
.56352 .33179 L
.56429 .33189 L
.565 .33164 L
.56628 .33041 L
.56765 .328 L
.56842 .32617 L
.56926 .32381 L
.57077 .31864 L
.57361 .30638 L
.58408 .24953 L
.58889 .22576 L
.59404 .20466 L
.5997 .18684 L
.60499 .17439 L
.61092 .16377 L
.61654 .15594 L
.62155 .15042 L
.62709 .14551 L
.63195 .14187 L
.6372 .13865 L
.64275 .1361 L
.64524 .1352 L
.64796 .13437 L
.65033 .13376 L
.65287 .13324 L
.65427 .13304 L
.65554 .1329 L
.65683 .13281 L
.65804 .13279 L
.65916 .13281 L
.66035 .13289 L
.66136 .13299 L
.66248 .13315 L
.66367 .13338 L
.66496 .13369 L
.66729 .13441 L
.66995 .13555 L
.67279 .13721 L
Mistroke
.67547 .13933 L
.6779 .14182 L
.68077 .14559 L
.68387 .15082 L
.68655 .15649 L
.68949 .16414 L
.69483 .18272 L
.70048 .21002 L
.71058 .27401 L
.71322 .29058 L
.71609 .30638 L
.7174 .31247 L
.7188 .31797 L
.72 .32183 L
.7213 .32498 L
.72255 .32699 L
.7237 .32794 L
.7248 .32805 L
.72595 .32736 L
.72722 .32572 L
.7284 .32344 L
.73107 .31614 L
.73654 .29744 L
.73784 .29334 L
.73922 .28953 L
.7405 .28663 L
.74169 .28457 L
.74305 .2831 L
.74377 .28273 L
.74455 .28268 L
.74538 .28303 L
.74616 .28377 L
.74687 .28478 L
.74764 .28627 L
.749 .28989 L
.75044 .29515 L
.75304 .30818 L
.75578 .32636 L
.75868 .34876 L
.76119 .36865 L
.76387 .38769 L
.76538 .39628 L
.76676 .40223 L
.76814 .40607 L
.76945 .40752 L
.77019 .40735 L
.77097 .40637 L
.77164 .40488 L
.77238 .40255 L
.77317 .39925 L
Mistroke
.77403 .39483 L
.77557 .38467 L
.77828 .36113 L
.78124 .32991 L
.78663 .26978 L
.7915 .2228 L
.79676 .1847 L
.79966 .16904 L
.80233 .15747 L
.80483 .14875 L
.80758 .14119 L
.81005 .13589 L
.81235 .13197 L
.81479 .12873 L
.8174 .12606 L
.82023 .12396 L
.82183 .1231 L
.82331 .1225 L
.8246 .12213 L
.82533 .12198 L
.82602 .12187 L
.82741 .12178 L
.82819 .12179 L
.82891 .12184 L
.83018 .12202 L
.83135 .12229 L
.83264 .1227 L
.83403 .12326 L
.83685 .12483 L
.83941 .12678 L
.84183 .12914 L
.8445 .13237 L
.84988 .14122 L
.85487 .15244 L
.85954 .16563 L
.87073 .205 L
.8734 .21439 L
.87625 .22337 L
.87871 .22984 L
.88 .23264 L
.88137 .23507 L
.88205 .23608 L
.8828 .23701 L
.88412 .23819 L
.88546 .2388 L
.88671 .2388 L
.88793 .23828 L
.88904 .23737 L
.89033 .23581 L
.89155 .23385 L
Mistroke
.89431 .22785 L
.89687 .22072 L
.90265 .20133 L
.91202 .17031 L
.91728 .15687 L
.91978 .15185 L
.92211 .14803 L
.92446 .14501 L
.92581 .14367 L
.92704 .14269 L
.92833 .1419 L
.92955 .14139 L
.93084 .14111 L
.93156 .14106 L
.93223 .14108 L
.93337 .14129 L
.93443 .14168 L
.93559 .14232 L
.93684 .14328 L
.93815 .14459 L
.9394 .14615 L
.94173 .14997 L
.94433 .15577 L
.9471 .16394 L
.95208 .18463 L
.95514 .20166 L
.95801 .22094 L
.96337 .26487 L
.96818 .30894 L
.97266 .34576 L
.97492 .35968 L
.97619 .36555 L
.97734 .36953 L
.9786 .37231 L
.97997 .37339 L
.98127 .37255 L
.98246 .37022 L
.98347 .36716 L
.98456 .36283 L
.98651 .35259 L
.99098 .32138 L
1 .25535 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo06?ooooo1_l00017
ooooo`00GOooool9o`0004oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04Cooooo001Looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0C?ooool2o`0006;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`00
F_ooool2o`0000_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0]ooooo`Go0000
;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04;ooooo001Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Zooooo`?o00001Ooo
ool3o`0002_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12ooooo`00<Oooool4
o`0002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02Sooooo0_l0000;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`11ooooo`00;_ooool3o`0000Cooooo0ol0000Pooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0:oooool2o`0001_ooooo1?l0000Vooooo`;o00003_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool5o`00
02Oooooo000/ooooo`;o00002_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000Hooooo`;o000000Goooooo`00
0?ooooooooooo`00000Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooooooo0_l0
000Vooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05Oooool01?l0003oooooooooool00003ooooo`;o00008_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool002[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01kooooo0_l0000Booooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool08oooool002Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool2
o`0000Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool08oooool002Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`005Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?ooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`00
0?oooooooooo00_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool00ol0003oooooooooo`09oooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo017ooooo00Go410@okZj^_oooooo0000oc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0<ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool2
o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003o
ooooooooo`0>ooooo`05oa0@4?nj^[[o0000ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0:ooooo`Ko00001Ooo
ool2o`0000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Cooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@ooooool0003ooooooa0@400Cooooo`Ko
00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41001oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooo`000003ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool05_ooool00ol0
003o410@ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0>
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooool0003oooooo`00000@ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool04Oooool00ol0003o410@ooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Kooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00006?ooool00ol@413o0000o`000003ooooo`05o`000?ooooooooooooooool000003?ooool00ol0
003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooool0003oooooo`00000?
ooooo`?o00003?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000oooooo00?o0000ooooooooool02oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001Cooooo00?oMgMgolc<c?l000001?ooool01ol@413ooooooooooooooooo410@ooooool00000
6oooool00onj^[[o0000ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003o
ooooooooo`0Aooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`0>oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool01Ol@413o0000oooooooo
oooo410@00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`;o00002?oo
ool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0000Cooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003o8B4Qooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Iooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooo
ooooool03Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo0000ogMg
M`0>ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`05o`00
0?nHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooooooo
ool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo00?o0000ooooooooool01oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`00
0?oooooooooo00oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05ojVYZOl@413o0000oa0@4?l000000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000004ooooo`05o`000?lb<S;o0000
oc8b<_o^k^h02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo00?o0000ooooooooool01oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo
00oooooo00GoZJVYoa0@4?l0003o410@o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08?ooool001gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0P
ooooo`007?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo000Kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool001[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Oooooo`005_ooooooo`00043o00004oooool001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001Oooool00ol0003oooooo`000007ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Ioooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Noooo
o`006Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool07_ooool001Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01kooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Nooooo`006?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool07_ooool001Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo000Gooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo0_l0000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000Doooo
o`03o`000?oooooooooo01kooooo000Gooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Iooooo`;o000000?oooooo`000?ooool05?ooool00ol0003o
ooooooooo`0Nooooo`005_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06oooool2o`0001Kooooo00?o0000ooooooooool07_ooool001Kooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool07_ooool001Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07Oooool001Kooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool07Oooool001Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool07Oooool001Kooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`00@oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08_ooool2o`0000gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo0013ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo0014
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo017ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Cooooo0ol0000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04_ooool004Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Booooo`00AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0015
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02?ooooo0_l0000>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`;o00003?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool004Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0016oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`00A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04oooool004Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool004Kooooo00Go0000oooooooo
ooooooooo`00000kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool004Ko
oooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06?ooool5o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo0017ooooo`04o`000?ooooooooooo`0003_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
04Oooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01[ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Cooooo`00B?ooool2o`0003cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00oooooo00Go0000oooo
ooooooooooooo`00000^ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Dooooo`00Q_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000;ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo0026ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000002oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Dooooo`00Q_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
013ooooo00Co0000oooooooooooo0000;oooool01?l0003oooooo`000?l00007ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0@ooooo`04o`000?oooooo0000o`00033ooooo0_l00008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Aooooo`;o0000>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`00Q_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l0001?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Cooooo0027ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo
0027ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Gooooo0027ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo0027oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo0027ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo0027ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0??ooool01Ol0003ooooooooooooooooo000001Oo
oooo0027ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool01?l0003ooooo
ooooool0000Hooooo`00Qoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo
0_l0001Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??ooool01?l0003ooooo
ooooool0000Hooooo`00Qoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo
00Co0000oooooooooooo00006?ooool008Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooo000001Sooooo0027ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?Oooool2o`0001Wooooo0028ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Gooooo`00R?ooool01Ol0003ooooooooooooooooo
000002Sooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05Sooooo0028ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`1A
ooooo`05o`000?ooooooooooooooool00000F_ooool008Sooooo00Go0000ooooooooooooooooo`00
000Xooooo`03o`000?oooooooooo057ooooo00Go0000ooooooooooooooooo`00001Jooooo`00R?oo
ool01Ol0003ooooooooooooooooo000002Sooooo0_l0001Booooo`05o`000?ooooooooooooooool0
0000F_ooool008Sooooo00Go0000ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo057o
oooo00Co0000oooooooooooo0000Foooool008Sooooo00Go0000ooooooooooooooooo`00000Xoooo
o`03o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Foooool008Sooooo00Go0000oooo
ooooooooooooo`00000Xooooo`03o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Fooo
ool008Wooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`1Aooooo`04o`000?oo
ooooooooo`0005_ooooo0029ooooo`04o`000?ooooooooooo`0001oooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooool00000Foooool008Wooooo00Co
0000oooooooooooo00008?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo
0_l0001Looooo`00ROooool01?l0003oooooooooool0000Mooooo`Go00001_ooool00ol0003ooooo
ooooo`2`ooooo`00ROooool01?l0003oooooooooool0000Mooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0002`ooooo`00ROooool00ol0003oooooo`00000Nooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0/?ooool008Wooooo00?o0000ooooool000007oooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;3ooooo0029ooooo`03o`000?oooooo000001oooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00ROooool00ol0003oooooo`00000P
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool008[ooooo0_l0000Yoooo
o`03o`000?oooooooooo0;3ooooo002:ooooo`;o0000:Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo
00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wo
oooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2
oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Co410@o`000?m4A4Coc<c<1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00_ooooo00?oV9RHoa0@4?oMgMd00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q07cooooo0025oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103
ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00on7QhOoEEEEooooo`02
ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000oooooom4A4CoA4A4oooo
ool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Oo<c<co8B4Qo`000?mEEEGo0000
00?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGo
gMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`0Jooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01Oo<
c<co0000o`000?l0003oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000
o`000003o`0001Wooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?nj^[[ooooookZj
^_l@4100O?ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go
8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool01Oo<c<co410@o`000?lb<S;ok^k^
00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1looooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .34959 m
.00942 .29577 L
.01975 .22598 L
.02496 .19961 L
.02782 .18804 L
.03053 .17884 L
.03305 .17167 L
.03578 .16526 L
.04057 .15688 L
.04331 .15333 L
.04588 .15063 L
.04894 .14804 L
.05173 .14619 L
.05466 .14472 L
.05744 .1437 L
.06037 .14294 L
.06203 .14261 L
.06357 .14235 L
.06635 .14197 L
.06896 .14168 L
.07131 .14149 L
.07263 .14141 L
.07385 .14135 L
.07516 .14132 L
.07639 .1413 L
.07774 .14131 L
.07849 .14132 L
.07918 .14134 L
.08056 .14138 L
.08207 .14144 L
.08481 .14155 L
.08726 .14167 L
.08854 .14174 L
.0899 .14183 L
.09109 .14194 L
.09239 .14207 L
.09468 .14241 L
.09611 .14269 L
.09741 .14301 L
.10032 .14392 L
.10302 .14508 L
.10557 .14648 L
.10825 .14839 L
.11108 .15105 L
.1135 .154 L
.11616 .15816 L
.11901 .1639 L
.12208 .17179 L
.12763 .1914 L
.13315 .21874 L
Mistroke
.13827 .25042 L
.14435 .28979 L
.147 .30426 L
.14839 .31054 L
.14986 .31593 L
.15117 .31952 L
.15192 .321 L
.15261 .32201 L
.15383 .32289 L
.15513 .32253 L
.15646 .32079 L
.15772 .31789 L
.15886 .3143 L
.16009 .30943 L
.16283 .2954 L
.16574 .27705 L
.17097 .24064 L
.17578 .20915 L
.18084 .18185 L
.18638 .15942 L
.18884 .15174 L
.19146 .14489 L
.19395 .1395 L
.19621 .13543 L
.20064 .12933 L
.20311 .12674 L
.2058 .12448 L
.20833 .12279 L
.21066 .12161 L
.21198 .12108 L
.21324 .12069 L
.21436 .12041 L
.21559 .12019 L
.21692 .12005 L
.21759 .12002 L
.21833 .12001 L
.21964 .12007 L
.22087 .1202 L
.22203 .12041 L
.22326 .12071 L
.22546 .12146 L
.22668 .12202 L
.22782 .12263 L
.2304 .1244 L
.23323 .12702 L
.23589 .13026 L
.24089 .13869 L
.24368 .14496 L
.24626 .15186 L
.25209 .17188 L
Mistroke
.26157 .21632 L
.2668 .24215 L
.26938 .25314 L
.27177 .26143 L
.27312 .2651 L
.27456 .26807 L
.27539 .2693 L
.27616 .27014 L
.27686 .27062 L
.27761 .27085 L
.27897 .27049 L
.27965 .26994 L
.2804 .26905 L
.28172 .26677 L
.28296 .26387 L
.2856 .25543 L
.28801 .2456 L
.29343 .2195 L
.30316 .17499 L
.30807 .15844 L
.31086 .15115 L
.31349 .1457 L
.31487 .14335 L
.31633 .14126 L
.31759 .13975 L
.31894 .13845 L
.3197 .13785 L
.32039 .13738 L
.32174 .13669 L
.3225 .13643 L
.32332 .13624 L
.3241 .13617 L
.32481 .13618 L
.32607 .13639 L
.32724 .13682 L
.32852 .13754 L
.3299 .13864 L
.33135 .14017 L
.33272 .14199 L
.33529 .14649 L
.33802 .15298 L
.34059 .16092 L
.34539 .18125 L
.34809 .19632 L
.35056 .21277 L
.35614 .25928 L
.36094 .30683 L
.36548 .35059 L
.36799 .37046 L
.36931 .37889 L
Mistroke
.37071 .38599 L
.37189 .39035 L
.37318 .39335 L
.37436 .3944 L
.37547 .39394 L
.37679 .39162 L
.37805 .38772 L
.37918 .38296 L
.38041 .37654 L
.38573 .33955 L
.39074 .3021 L
.39529 .2743 L
.39809 .26115 L
.40074 .25137 L
.40353 .24336 L
.40655 .23679 L
.4092 .23236 L
.41199 .22854 L
.41701 .22243 L
.43785 .18513 L
.44696 .16782 L
.4521 .16015 L
.45686 .15482 L
.46196 .15074 L
.46453 .14925 L
.46602 .14857 L
.46738 .14806 L
.46858 .1477 L
.46985 .14742 L
.47112 .14723 L
.47184 .14717 L
.47251 .14713 L
.47374 .14712 L
.47485 .14717 L
.47613 .14729 L
.47734 .14744 L
.48 .14793 L
.48282 .1486 L
.48787 .15018 L
.4993 .15521 L
.5092 .15936 L
.51466 .162 L
.51984 .16505 L
.52464 .16879 L
.52736 .17168 L
.52988 .17511 L
.53433 .18353 L
.53681 .18981 L
.53906 .19665 L
.54974 .24701 L
Mistroke
.55557 .28557 L
.55842 .30444 L
.56101 .31983 L
.56215 .3257 L
.56339 .33128 L
.56447 .33532 L
.56565 .33884 L
.56691 .34143 L
.56824 .34281 L
.56947 .34279 L
.57063 .34164 L
.57192 .33906 L
.57328 .33494 L
.57444 .33036 L
.57571 .32434 L
.58118 .28949 L
.59133 .21849 L
.59702 .18882 L
.60218 .16919 L
.607 .15616 L
.60972 .15071 L
.61222 .14666 L
.61683 .14101 L
.6217 .13666 L
.62436 .13481 L
.62689 .13339 L
.62915 .13238 L
.63162 .13151 L
.63716 .13014 L
.6398 .12961 L
.64228 .12918 L
.64332 .12903 L
.64441 .12891 L
.64561 .12881 L
.64671 .12877 L
.64792 .12878 L
.64905 .12884 L
.65028 .12897 L
.6516 .12918 L
.65288 .12944 L
.65427 .12979 L
.6568 .13061 L
.65925 .13164 L
.66152 .13287 L
.66407 .13471 L
.66641 .13695 L
.66911 .14037 L
.67167 .14459 L
.67622 .15466 L
.68119 .17002 L
Mistroke
.68662 .19337 L
.69242 .2259 L
.69749 .25712 L
.70026 .27285 L
.70285 .28528 L
.70425 .29077 L
.70553 .29484 L
.70695 .29823 L
.70773 .29954 L
.70847 .30041 L
.70976 .30103 L
.71095 .30057 L
.71226 .29893 L
.71292 .29765 L
.71365 .2959 L
.71516 .29118 L
.71655 .28567 L
.71968 .26986 L
.72533 .23526 L
.73068 .20422 L
.73565 .18137 L
.73816 .17244 L
.74084 .16505 L
.74237 .16195 L
.74312 .16076 L
.74381 .15987 L
.74511 .15875 L
.74579 .15846 L
.74651 .15838 L
.74779 .15885 L
.74917 .16027 L
.75048 .1625 L
.75169 .16536 L
.75399 .17299 L
.75527 .1786 L
.75643 .1846 L
.75906 .2019 L
.76191 .22727 L
.7646 .25851 L
.76707 .29342 L
.77192 .37281 L
.77428 .41072 L
.77643 .44024 L
.77752 .45236 L
.77871 .46283 L
.77996 .47045 L
.78114 .47415 L
.78244 .47412 L
.78383 .4694 L
.785 .46172 L
Mistroke
.7863 .44968 L
.79171 .37174 L
.79762 .2764 L
.80031 .24106 L
.80319 .21123 L
.80591 .18994 L
.80838 .17545 L
.80964 .16952 L
.81098 .16421 L
.81337 .15699 L
.8147 .15412 L
.81595 .15214 L
.81731 .1507 L
.81808 .15021 L
.81878 .14995 L
.82003 .1499 L
.82119 .1503 L
.82246 .15118 L
.82381 .15257 L
.82608 .15576 L
.82858 .16034 L
.83891 .18847 L
.84455 .20752 L
.8473 .21612 L
.8498 .22288 L
.85195 .22765 L
.85429 .23154 L
.85557 .23305 L
.85676 .23405 L
.85789 .23463 L
.85909 .23483 L
.8603 .23461 L
.86159 .23389 L
.86282 .23275 L
.86394 .23134 L
.86667 .22645 L
.86927 .22018 L
.87979 .18788 L
.88492 .17335 L
.88956 .16233 L
.89463 .15314 L
.89741 .14953 L
.90003 .14706 L
.90142 .14607 L
.90289 .14526 L
.90414 .14474 L
.90552 .14432 L
.9063 .14416 L
.907 .14405 L
.90782 .14398 L
Mistroke
.90859 .14395 L
.90996 .14402 L
.91074 .14413 L
.91145 .14426 L
.91269 .14459 L
.914 .14507 L
.91633 .14627 L
.91883 .14801 L
.92157 .1504 L
.93107 .16115 L
.94241 .17747 L
.95271 .19434 L
.9578 .20429 L
.96332 .21806 L
.96853 .23525 L
.97332 .25587 L
.98381 .3153 L
.98668 .33131 L
.98826 .33906 L
.98976 .3454 L
.99115 .3502 L
.99189 .35227 L
.99267 .35409 L
.99405 .35626 L
.99533 .35706 L
.99659 .35664 L
.99778 .35515 L
.99885 .35292 L
1 .34959 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Iooooo`Go0000Eoooool00ol0003oooooooooo`2`ooooo`00Eoooool2o`0000Gooooo0_l0001E
ooooo`03o`000?oooooooooo0;3ooooo001Fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`2`ooooo`00E_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo057ooooo0_l0000Yooooo`So0000P?ooool005Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Gooooo0ol00008ooooo`03o`00
0?oooooooooo07gooooo001Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05ooo
ool3o`0003Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`;o0000OOoo
ool005?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;o0000=Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0N_ooool002Wooooo3Ol0000Mooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07[ooooo000Vooooo`?o
00003Oooool2o`0001_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0A_ooool5o`0002kooooo000Uooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`Oo0000
1?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
:oooool2o`0001Oooooo0_l00005ooooo`03o`000?oooooooooo02_ooooo000Tooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`;o00001ooo
ool3o`000003ooooool0003ooooo027ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Yooooo`Co00005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo000S
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00[ooooo1?l0000Oooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0:Oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Yooooo`008oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;o00007Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo0_l0000D
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02Sooooo000Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool4
o`0001?ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09oooool001Gooooo0_l000002ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^k_oooooo000001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0>ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`;o00006Oooool5o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`03o`000?oooooooooo00cooooo1_l00002ooooo`05o`000?lb<S;o0000oc8b
<_o^k^h03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_l000003?ooool00ol0003ooooooooo
o`0>ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000006?ooool0
1Ol@413o^[Zjo`000?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`00
0?oooooooooo00kooooo00GoV9RHob4Q8Oo^k^koooooo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03?ooool01_nHV9So8B4Q
onk^k_ooooooA4A4o`0000;ooooo00Go0000oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?oooooo0000ogMgM`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo
00Ko410@oooooooooooooooooa0@4?l0000Aooooo`Ko00001Oooool2o`0000?ooooo00Go410@oooo
oooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l00003ooooo`04oiRHV?lQ8B7o
k^k^o`0000?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00Sooooo
1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool000001?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool03?ooool01?nHV9So8B4Qonk^k_l00003ooooo`05oa0@4?l0003oooooooooool@4100
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
oooooa0@4002ooooo`03o`000?l@413ooooo00gooooo00?o0000ooooooooool02_ooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004oooo
o`04o`000?ooooooooooooooo`;o00007?ooool00ol0003o410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`0Aooooo`03oiRHV?lQ8B7o000000?ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo
oooo00gooooo00?oV9RHob4Q8Ol000000oooool2o`0000;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMoooo
ool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04_ooool00omgMgOo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000003?ooool00ol0
003oooooooooo`0>ooooo`03ogMgMol0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooool0003oooooo`00000@ooooo`03o`000?oooooooooo00Sooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@ooooooooooooooooo`00000Mooooo`03o`000?lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`05
oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000
ooooooooool04?ooool2o`0000Sooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00kooooo
0_l00003ooooo`05oa0@4?l0003oooooooooool@41003Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413oooooo`000?oooooo410@
013ooooo00?o0000ooooooooool02Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
000001[ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`0@ooooo`06o`000?nj^[[ooooooiRHV?l@413o00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo
00?o0000ooooooooool02_ooool01Ol0003o^[Zjooooool0003o410@00?ooooo00GoMgMgo`000?oo
ooooV9RHogMgM`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Aooooo`03o`000?oo
oooooooo00Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05ojVY
ZOl@413o0000oa0@4?l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool04?ooool01_nHV9So410@o`000?lQ8B7oc<c<o`0000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool01_l0003ooooooooooomEEEGoIVIV
o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00[ooooo00Go
V9RHoa0@4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_l0003o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`09ooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo027ooooo000Oooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool08Oooool001kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool07oooool001Koooooool00010o`0001?ooooo000Foooo
o`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`;o00001Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`05ooooo`;o00001Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
0_l00006ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo000Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07Oooool001gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`007Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01gooooo000Looooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07?ooool001cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`00
7?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
00007oooool00ol0003oooooooooo`0Looooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`;o0000
3Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool3o`00027ooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06ooo
ool001cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01_ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Jooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool06_ooool001_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo01[ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Iooooo`006oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07_ooool2o`0000oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00Go0000oooooooo
ooooooooo`00000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000005oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Hooooo`006_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08Oooool2o`0001Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool001[ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06?ooool001[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool001[ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool06?ooool001[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`;o
00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`006Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo0000
4?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
5oooool001Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`04o`000?oo
ooooooooo`00013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo01Oooooo000Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Gooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Gooooo0ol0000@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Gooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Gooooo1Ol00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo000Iooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo000Hoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00onHV9So8B4Qonk^kP07oooo
o`?o00003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Kooooo000Hooooo`03
o`000?oooooooooo02[ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Fooooo`006?ooool00ol0003o
ooooooooo`0Zooooo`04o`000?ooooooooooo`00043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Iooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Kooooo000Hooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooool00000@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool05_ooool001Sooooo00?o0000ooooooooool0:oooool3o`00043ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool05_ooool001Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Gooooo000Gooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Eooooo`005oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Aooooo`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool05Oooool001Oooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo0_l0000Booooo`04
o`000?ooooooooooo`0003kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo01Gooooo000Gooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo0000?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool05Oooool001Oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00000nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Eooooo`00
5_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Gooooo000Fooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01Cooooo000Fooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0001?ooooo002:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0??ooool2o`000003ooooool0003ooooo01;ooooo002:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool2o`0001Cooooo002:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool008_ooooo00Go0000oooooooooooo
ooooo`00000Uooooo`;o0000E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?o
oooo002;ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool008_ooooo00Go0000oooooooooooo
ooooo`00000Uooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Cooooo`00Roooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo002;ooooo`05o`00
0?ooooooooooooooool000009Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Doooool008_ooooo00Go0000ooooooooooooooooo`00000Uooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`00
Roooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05?ooooo002<ooooo`03o`000?oooooo000002Kooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo
002<ooooo`03o`000?oooooo000002Kooooo0_l0001Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Doooool008cooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool008gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0E?ooool00;Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05Cooooo002eooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Dooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Cooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Cooooo002Zooooo`Go00001_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool00:[ooooo00CoA4A4omgMgOoo
oooo00001oooool3o`0005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Doooo
o`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Dooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`00
Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Dooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`00]Oooool0
0ol0003oooooooooo`1Eooooo`05o`000?ooooooooooooooool00000E_ooool00;Gooooo00?o0000
ooooooooool0EOooool01Ol0003ooooooooooooooooo000005Kooooo002eooooo`03o`000?oooooo
oooo05Gooooo00Co0000oooooooooooo0000Eoooool00;Gooooo0_l0001Fooooo`04o`000?oooooo
ooooo`0005Oooooo002eooooo`03o`000?oooooooooo05Gooooo00Co0000oooooooooooo0000Eooo
ool00;Gooooo00?o0000ooooooooool0EOooool01?l0003oooooooooool0001Gooooo`00]Oooool0
0ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0005Oooooo002eooooo`03o`000?oooooo
oooo05Gooooo00Co0000oooooooooooo0000Eoooool00;Gooooo00?o0000ooooooooool0EOooool0
1?l0003oooooooooool0001Gooooo`00]Oooool00ol0003oooooooooo`1Eooooo`04o`000?oooooo
ooooo`0005Oooooo002eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooool00000Eoooool0
0;Gooooo0_l0001Gooooo`03o`000?oooooo000005Oooooo002eooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooool00000Eoooool00;Gooooo00?o0000ooooooooool0E_ooool2o`0005Sooooo
002eooooo`03o`000?oooooooooo05Kooooo0_l0001Hooooo`00]Oooool00ol0003oooooooooo`1F
ooooo`;o0000F?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000go
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o
<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(102) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .37187 m
.01975 .27103 L
.02492 .23102 L
.02981 .20195 L
.03251 .18949 L
.03544 .17849 L
.04057 .16446 L
.04333 .15903 L
.04625 .15445 L
.0515 .14837 L
.05634 .14438 L
.06168 .14108 L
.06743 .13826 L
.07362 .13572 L
.07946 .13379 L
.08227 .13305 L
.08481 .13251 L
.08605 .1323 L
.08739 .13213 L
.08865 .13201 L
.08981 .13195 L
.09105 .13195 L
.09241 .13203 L
.09309 .1321 L
.09382 .13221 L
.09515 .13248 L
.09638 .13284 L
.09772 .13334 L
.09891 .1339 L
.10017 .13462 L
.10254 .13641 L
.10474 .13864 L
.10731 .14209 L
.11008 .14708 L
.11269 .15324 L
.11509 .16035 L
.12065 .18326 L
.12344 .1986 L
.1265 .21838 L
.13159 .2568 L
.13709 .29938 L
.13962 .31552 L
.141 .32264 L
.1423 .32794 L
.1434 .33131 L
.14458 .33366 L
.14589 .33466 L
.14709 .33407 L
.1478 .33304 L
.14856 .33141 L
Mistroke
.14992 .32711 L
.15154 .3199 L
.15301 .31163 L
.15862 .26997 L
.16362 .22939 L
.16909 .19103 L
.17423 .16396 L
.17703 .15272 L
.17964 .14422 L
.18205 .13791 L
.18433 .13309 L
.18695 .12873 L
.18934 .12571 L
.19199 .12324 L
.19332 .1223 L
.19479 .12148 L
.19604 .12095 L
.19739 .12055 L
.19866 .12033 L
.19983 .12026 L
.2012 .12034 L
.20248 .12057 L
.20321 .12077 L
.20388 .12099 L
.20538 .12164 L
.20682 .12246 L
.20838 .12357 L
.21122 .12618 L
.2137 .12916 L
.21637 .13317 L
.22118 .14285 L
.2269 .15917 L
.23213 .17894 L
.23769 .20429 L
.24361 .23275 L
.24604 .24341 L
.24866 .25327 L
.25016 .25787 L
.25153 .2613 L
.25285 .2638 L
.25424 .26554 L
.25549 .26631 L
.25663 .26634 L
.25794 .26557 L
.25918 .26407 L
.26033 .26206 L
.26139 .25969 L
.26379 .25274 L
.26887 .23269 L
.27425 .20834 L
Mistroke
.27925 .18728 L
.28462 .16903 L
.2877 .16102 L
.29052 .15525 L
.29335 .15086 L
.29604 .1479 L
.29735 .14686 L
.29804 .14642 L
.29876 .14602 L
.3001 .14548 L
.30133 .14519 L
.30251 .14509 L
.30361 .14515 L
.30482 .14539 L
.30612 .14583 L
.3075 .1465 L
.309 .14745 L
.31173 .14973 L
.31685 .1557 L
.32688 .17214 L
.33616 .18913 L
.34115 .19705 L
.34641 .20363 L
.34916 .20629 L
.35217 .20863 L
.35744 .21186 L
.36002 .2135 L
.36245 .21544 L
.36379 .21679 L
.36525 .21855 L
.36779 .22257 L
.37022 .22783 L
.3728 .23525 L
.375 .24336 L
.37741 .2544 L
.38258 .28589 L
.3873 .32236 L
.39238 .36218 L
.39377 .37149 L
.39525 .37998 L
.39664 .38637 L
.39791 .39058 L
.39918 .39314 L
.40035 .39395 L
.40163 .39309 L
.40298 .3902 L
.40415 .38607 L
.40525 .38096 L
.40774 .36536 L
.41707 .28312 L
Mistroke
.42235 .24056 L
.42514 .22241 L
.42809 .20649 L
.43066 .19519 L
.4335 .18523 L
.43608 .17817 L
.4385 .17303 L
.44101 .16893 L
.44341 .16599 L
.44555 .16397 L
.44789 .16229 L
.45043 .16094 L
.45185 .16037 L
.45314 .15994 L
.45434 .15961 L
.45564 .15932 L
.458 .15895 L
.46322 .15854 L
.4661 .15835 L
.46882 .15808 L
.47135 .15776 L
.47411 .15732 L
.47893 .15637 L
.4844 .15495 L
.48947 .15323 L
.49504 .15114 L
.50104 .1491 L
.50361 .14834 L
.50631 .14764 L
.50862 .14715 L
.50993 .14693 L
.51114 .14678 L
.51238 .14669 L
.51355 .14667 L
.51459 .1467 L
.51573 .14681 L
.51697 .14702 L
.51828 .14735 L
.5194 .14772 L
.52063 .14824 L
.52207 .149 L
.52344 .1499 L
.52602 .15208 L
.52879 .15532 L
.5318 .16021 L
.53443 .16592 L
.53723 .17379 L
.54226 .19349 L
.545 .20765 L
.5479 .22542 L
Mistroke
.55308 .26373 L
.55913 .31241 L
.56208 .33277 L
.56337 .34002 L
.56477 .34645 L
.56608 .35088 L
.56728 .35353 L
.56843 .3547 L
.56965 .35444 L
.57094 .35252 L
.57214 .34923 L
.57346 .34406 L
.57488 .33682 L
.5777 .3183 L
.58066 .29483 L
.58596 .2504 L
.59113 .21203 L
.59601 .1838 L
.5987 .17151 L
.60162 .16057 L
.60405 .15311 L
.60672 .14636 L
.6116 .13714 L
.61427 .13339 L
.61677 .13051 L
.62123 .12658 L
.62373 .12494 L
.62602 .12374 L
.62841 .12275 L
.63105 .12195 L
.63238 .12167 L
.63308 .12154 L
.63381 .12144 L
.63516 .12131 L
.6364 .12127 L
.63755 .1213 L
.63878 .12141 L
.63994 .12159 L
.641 .12182 L
.64224 .12219 L
.64358 .12271 L
.64602 .12398 L
.64864 .12591 L
.65152 .12882 L
.65453 .13294 L
.65735 .13802 L
.66239 .15079 L
.66522 .16045 L
.66781 .17104 L
.67815 .22984 L
Mistroke
.68309 .26252 L
.68552 .27706 L
.68775 .2884 L
.68902 .29367 L
.6904 .29829 L
.69108 .30006 L
.6918 .30159 L
.69256 .30278 L
.69328 .30349 L
.69462 .30377 L
.6959 .30273 L
.69704 .30075 L
.69828 .2975 L
.69963 .29282 L
.70111 .28637 L
.70412 .27006 L
.70951 .23501 L
.71468 .20212 L
.72011 .1738 L
.72476 .15595 L
.72739 .14831 L
.72983 .14266 L
.7312 .14006 L
.73269 .13768 L
.734 .13593 L
.73538 .13443 L
.73663 .13335 L
.738 .13248 L
.73925 .13194 L
.74042 .13166 L
.74112 .13159 L
.74188 .1316 L
.74327 .13183 L
.74462 .13234 L
.74588 .13305 L
.74736 .1342 L
.74871 .13555 L
.75173 .13965 L
.75418 .14419 L
.75687 .15058 L
.75949 .1584 L
.76229 .16874 L
.76731 .19316 L
.77199 .22362 L
.78336 .32282 L
.78836 .36384 L
.78973 .3728 L
.7912 .38094 L
.79259 .38705 L
.79387 .39121 L
Mistroke
.79514 .39397 L
.79586 .39491 L
.79653 .39539 L
.79776 .39531 L
.79906 .39394 L
.79978 .39268 L
.80055 .39093 L
.80196 .38687 L
.80458 .37688 L
.81622 .32587 L
.83736 .25916 L
.84725 .22037 L
.8527 .20057 L
.85786 .18495 L
.86078 .17771 L
.86395 .17114 L
.86659 .16672 L
.86951 .16291 L
.87225 .1603 L
.87375 .15924 L
.87516 .15845 L
.87647 .1579 L
.87767 .15753 L
.87899 .15726 L
.87966 .15718 L
.88038 .15712 L
.88172 .15713 L
.88248 .15719 L
.88318 .15727 L
.88446 .15751 L
.88582 .15786 L
.88817 .15872 L
.89076 .15997 L
.90184 .16707 L
.90682 .17006 L
.90956 .17147 L
.91216 .1726 L
.91457 .17341 L
.91594 .17376 L
.91721 .174 L
.91838 .17415 L
.91944 .17422 L
.92067 .17424 L
.92182 .17419 L
.92304 .17406 L
.92435 .17386 L
.92559 .1736 L
.92672 .17331 L
.93209 .17142 L
.93728 .16903 L
Mistroke
.94292 .16622 L
.94544 .16511 L
.94681 .16459 L
.9481 .16418 L
.94929 .16387 L
.95038 .16366 L
.95159 .16352 L
.95289 .16347 L
.95403 .16354 L
.95509 .16369 L
.95625 .16397 L
.95749 .16441 L
.9588 .16504 L
.96003 .16582 L
.96233 .16782 L
.96346 .1691 L
.96467 .17073 L
.96687 .17442 L
.96947 .18023 L
.97186 .18712 L
.97433 .1961 L
.97703 .20822 L
.98193 .23719 L
1 .37187 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Dooooo`Co0000GOooool00ol0003oooooooooo`0Wooooo`?o0000Q_ooool005?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02Gooooo0ol00002
ooooo`;o0000Q?ooool005;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo02?ooooo0_l00007ooooo`03o`000?oooooooooo087ooooo001Aooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool2o`0002?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`20ooooo`00;_ooool8o`0001[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Gooooo`Go0000Hoooool002cooooo0_l00008ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`;o00000ooo
ool00ol0003oooooooooo`1Qooooo`00:_ooool2o`0000_ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`03o`000?oooooo
oooo063ooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Pooooo`009oooool2o`0000oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo1?l0000looooo`03o`000?oooooooooo00?o
00007?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Oooooo`009_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`04o`00
0?ooooooooooooooo`;o0000>_ooool5o`000004ooooool0003o0000o`0001[ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Goooool002Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05kooooo000Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0aooooo`Co00000_ooool2o`0000Oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Nooooo`008oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:Oooool8o`0000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo1Ol0000gooooo`008oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool3
o`0000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00oooool2o`0003Gooooo000Eooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Dooooo`05o`00
0?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool03_ooool01?l0003oooooooooooooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000000?o000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool04?ooool6o`0000?ooooo
00Gok^k^oc8b<_l0003o0000onk^kP0Kooooo`0>oiRHV?l@413o0000oc8b<_o<c<coooooo`000?oo
ooook^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000kooooo1Ol00007ooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool05?ooool01Ol0003o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00oooooo00So0000ooooooooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00OoMgMgoiRHV?oooooo
V9RHogMgMooooooo000000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo00kooooo00Oo
0000oooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Koooo
o`06oa0@4?nj^[[oooooogMgMolb<S;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00?o0000ooooooooool02Oooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0=ooooo`Ko00000oooool01?l0003o
ooooooooool00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0:
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`07oa0@4?ooooooooooooooool@413ooooo
o`00000<ooooo`03o`000?oooooooooo00;ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool03_ooool01_l0
003ooooooooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooo0000oa0@400Oooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`02ooooo`;o00001_ooool3o`0000Oo
oooo0_l00003ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo01Kooooo00Co0000oooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00kooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00?ooooo00?o0000oooooooo
ool00_l0000Nooooo`03ojVYZOl0003ooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`Ko00003?ooool01ol0003ooooooooooom4A4CogMgMooooool000001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo01Kooooo00Co0000oa0@4?l0003o^[Zj0oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`03ogMgMomVIVKooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool000006?ooool01ol0003ooooooooooooMgMgoEEEEooooool0
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Co
oooo00Oo410@oooooooooooooooooa0@4?oooooo000001[ooooo00?o0000okZj^_lQ8B400oooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o0000ooooo`0>ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[o
oooo00?o0000ooooooooool04Oooool2o`0000[ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o0000ooooooooool07?ooool00ol0003o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41006?ooool01ol0003oooooooooooooooooMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00OoMgMgoiRHV?oo
ooooV9RHogMgMooooooo000001Sooooo00Go410@oiRHV?l0003o^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Aooooo`07o`000?oooooo0000okZj^_oo
ooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool03?ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0ooo
ool01OmgMgOoV9RHoooooonHV9So000001_ooooo00Go410@oiRHV?l0003o^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06?ooool01ol0003oooooooooooooooook^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Ko
k^k^oc8b<_l0003o<S8bonk^k_l0000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool04Oooool01ol0003ooooooiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`00013ooooo00?o0000oooo
ooooool02?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool0
1ol0003oooooooooooooooooEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool03?ooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7oc<c<0ooo
ool01Oo^k^ko<S8bo`000?lb<S;o000001_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06Oooool01_l0003oooooooooooooooooMgMgo`0000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool06_ooool0023ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo000Pooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`007oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06Oooool001oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo
000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo017ooooo000Ooooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool2o`0001Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo000Nooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Hooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
6?ooool001kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01Oooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Gooooo`007_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool2o`0000go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05oooool001gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo000Mooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`00
7Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5_ooool001gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Kooooo000Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000009?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Oooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo000M
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0J
ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool001cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo0ol0000U
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Kooooo000Looooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05_ooool001cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool001cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
5Oooool001cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool05Oooool001cooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool0
01_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`;o00004?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Eooooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oo
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Eooooo`006oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`006oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00006Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05Oooool001_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Cooooo000Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool2o`000003
ooooool0003ooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3Oooool5o`0000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo023ooooo0ol0000Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`0Uooooo`05o`000?ooooooooooooooool00000BOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00oooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00013ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Uooooo`05o`000?oo
ooooooooooooool00000BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool05?ooool001Wooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooo
oooooooo000004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01Cooooo000Iooooo`03o`000?oooooooooo02Kooooo00Go0000oooooooooooooooo
o`00001:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Cooooo`006Oooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0004[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool04oooool001Wooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0001:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
01?ooooo000Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooool00000Boooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooool00000Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo0000047ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`00
0?oooooooooo02Wooooo0_l0001<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6Oooool2o`0001;ooooo00Go0000ooooooooooooooooo`000011ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`006?ooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Aooooo`05o`000?ooooooooooooooool00000@_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool04oooool001Sooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
4Oooool01Ol0003ooooooooooooooooo000004;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo01;ooooo000Hooooo`03o`000?oooooooooo07Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo
00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool04_ooool001Sooooo00?o0000ooooooooool0Moooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04Oooool01?l0003ooooo
ooooool00013ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Booooo`005oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000004?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo
000Gooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01;ooooo0_l00014ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Booooo`005oooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo000Gooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`;o
0000F_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool04Oooool001Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04Ooo
ool001Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool04Oooool009?ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1?
ooooo`00U?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo05[ooooo00Go0000
ooooooooooooooooo`00001Aooooo`00U?ooool01?l0003oooooooooool0000Mooooo`03o`000?oo
oooooooo05[ooooo00Go0000ooooooooooooooooo`00001Aooooo`00U?ooool01?l0003ooooooooo
ool0000Mooooo`03o`000?oooooooooo05[ooooo00Co0000oooooooooooo0000D_ooool009Cooooo
00?o0000ooooool000007_ooool2o`0005_ooooo00Co0000oooooooooooo0000D_ooool009Cooooo
00?o0000ooooool000007_ooool00ol0003oooooooooo`1Jooooo`04o`000?ooooooooooo`0005;o
oooo002Eooooo`;o00007_ooool00ol0003oooooooooo`1Kooooo`;o0000Doooool00;Gooooo00?o
0000ooooooooool0Foooool2o`0005?ooooo002eooooo`03o`000?oooooooooo0;3ooooo002/oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool00:[ooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00Zoooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0/?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Go
c<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo
002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b
<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^0oooool5o`0007Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Cooooo
00?oV9RHob4Q8Oo^k^h0NOooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko
00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00onHV9So8B4Qonk^kP1hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGo
gMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03ogMgMomVIVKooooo07Oooooo0021ooooo`06o`000?n7QhOoZJVYokZj
^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Oooooo00?o0000ooooooooool0M_ooool0087ooooo00Ko0000oc8b<_oooooooooo
oc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Boooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@401hooooo`00P?ooool00ol@413o0000ohN7Q`02
ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(104) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .32361 m
.00236 .34472 L
.00488 .36404 L
.0061 .37161 L
.00726 .37742 L
.0083 .38139 L
.00942 .38426 L
.01066 .38561 L
.01203 .38484 L
.01272 .38356 L
.01346 .38154 L
.01479 .37622 L
.01612 .36897 L
.01738 .36048 L
.01975 .34112 L
.02982 .2442 L
.03546 .2014 L
.04057 .17354 L
.04328 .16241 L
.04622 .15276 L
.0488 .14597 L
.05154 .1402 L
.05406 .13585 L
.05684 .13192 L
.06172 .12664 L
.06473 .12426 L
.06748 .12258 L
.07066 .12113 L
.07211 .12061 L
.07366 .12015 L
.07498 .11982 L
.07643 .11953 L
.07776 .11934 L
.079 .11923 L
.07971 .1192 L
.08046 .1192 L
.0818 .11928 L
.08254 .11937 L
.08323 .11949 L
.084 .11966 L
.08481 .11988 L
.0861 .12034 L
.08753 .121 L
.0904 .12286 L
.09307 .1253 L
.09556 .12834 L
.0985 .13313 L
.10118 .13894 L
.10428 .14777 L
.10722 .15865 L
Mistroke
.11248 .18518 L
.11735 .21857 L
.1231 .26644 L
.12838 .30916 L
.13098 .32517 L
.13229 .33115 L
.13303 .33381 L
.13373 .33583 L
.13448 .33744 L
.13517 .33839 L
.13591 .33883 L
.13672 .33863 L
.13742 .33788 L
.13817 .33651 L
.13951 .33261 L
.14074 .32745 L
.14208 .32039 L
.14448 .30436 L
.14997 .25914 L
.15488 .2188 L
.16011 .18366 L
.16265 .17027 L
.16504 .15978 L
.16722 .15191 L
.16952 .14517 L
.17204 .13944 L
.17436 .13551 L
.17556 .13392 L
.17686 .13253 L
.17827 .13135 L
.1796 .13056 L
.18033 .13024 L
.18101 .13002 L
.18176 .12986 L
.18255 .12978 L
.18388 .12986 L
.18464 .13001 L
.18535 .13022 L
.18667 .13081 L
.18788 .13155 L
.18921 .13259 L
.19061 .13394 L
.19325 .13722 L
.19609 .14178 L
.20119 .15286 L
.20726 .17102 L
.21277 .19177 L
.22254 .23149 L
.22492 .23973 L
.22747 .24706 L
Mistroke
.22893 .25038 L
.23027 .25278 L
.23162 .25453 L
.23289 .25555 L
.23426 .25595 L
.23502 .25585 L
.23571 .25557 L
.23706 .2545 L
.23832 .2529 L
.23981 .25033 L
.24117 .24737 L
.24425 .23896 L
.25472 .20292 L
.25966 .18772 L
.26238 .18081 L
.26495 .17537 L
.26735 .17127 L
.26995 .16785 L
.2711 .16667 L
.27232 .16563 L
.27338 .16489 L
.2745 .16428 L
.27584 .16376 L
.27706 .16348 L
.27838 .16339 L
.27913 .16342 L
.27983 .16351 L
.28109 .1638 L
.28224 .1642 L
.28357 .16483 L
.28482 .16556 L
.29028 .17008 L
.2962 .17646 L
.30141 .18234 L
.30428 .18537 L
.307 .18793 L
.30952 .18994 L
.31085 .19082 L
.31227 .1916 L
.31358 .19218 L
.31477 .19259 L
.31597 .19288 L
.31709 .19304 L
.31837 .1931 L
.31973 .19301 L
.32088 .19283 L
.32215 .19251 L
.32352 .19204 L
.32498 .1914 L
.32762 .1899 L
Mistroke
.33368 .18516 L
.33919 .18007 L
.34426 .17562 L
.34964 .1717 L
.35185 .17042 L
.35423 .16929 L
.35559 .16878 L
.35684 .16841 L
.35809 .16815 L
.35928 .16799 L
.36066 .16794 L
.3619 .16803 L
.36259 .16812 L
.36334 .16828 L
.36469 .16867 L
.36596 .16919 L
.36731 .16989 L
.36971 .17159 L
.37252 .17439 L
.37514 .17795 L
.37802 .18317 L
.3811 .19067 L
.38379 .19912 L
.38665 .2104 L
.39178 .2376 L
.3973 .27796 L
.4034 .33237 L
.40595 .35486 L
.40864 .37554 L
.41004 .38438 L
.41079 .38837 L
.41158 .39205 L
.41232 .39486 L
.41299 .39692 L
.41429 .3995 L
.4156 .40012 L
.41681 .39889 L
.41814 .3956 L
.41881 .3932 L
.41955 .39002 L
.42212 .37493 L
.42452 .35633 L
.42974 .30874 L
.43544 .25905 L
.44082 .22225 L
.44339 .20847 L
.44581 .19751 L
.44819 .18844 L
.45076 .18028 L
.45524 .16941 L
Mistroke
.45778 .16471 L
.46046 .16059 L
.46527 .15478 L
.47049 .15008 L
.47524 .14686 L
.48592 .14151 L
.49582 .13781 L
.50065 .13642 L
.50518 .13531 L
.50751 .13486 L
.50882 .13467 L
.51001 .13454 L
.51125 .13446 L
.51261 .13443 L
.51329 .13445 L
.51403 .1345 L
.51534 .13464 L
.51607 .13476 L
.51674 .13489 L
.51825 .13529 L
.51958 .13577 L
.52099 .1364 L
.52344 .13791 L
.52482 .13903 L
.52612 .1403 L
.52863 .14344 L
.531 .14746 L
.53313 .15213 L
.53545 .15854 L
.53797 .16731 L
.54065 .17904 L
.54547 .20734 L
.55529 .29315 L
.56045 .33936 L
.5617 .34827 L
.56304 .35622 L
.56381 .35994 L
.56451 .36275 L
.56588 .36654 L
.56716 .36795 L
.56835 .36737 L
.56965 .36466 L
.57102 .35953 L
.57222 .35331 L
.57334 .34615 L
.57588 .32589 L
.58506 .23677 L
.59028 .19475 L
.59303 .17728 L
.59597 .16205 L
Mistroke
.59879 .15033 L
.60134 .14188 L
.60394 .1351 L
.60633 .13023 L
.60867 .12652 L
.61114 .12351 L
.61362 .12124 L
.61505 .12023 L
.61635 .11948 L
.61747 .11895 L
.6187 .11851 L
.62 .11819 L
.62123 .11803 L
.62237 .11801 L
.62359 .11812 L
.62463 .11831 L
.62578 .11864 L
.62706 .11915 L
.62825 .11975 L
.63095 .12159 L
.63358 .12405 L
.63638 .12753 L
.639 .13174 L
.64148 .13673 L
.6461 .14924 L
.65157 .17018 L
.65661 .19582 L
.6621 .2296 L
.668 .26681 L
.67073 .28121 L
.67208 .28704 L
.67332 .29154 L
.67445 .29477 L
.67565 .29728 L
.67698 .29888 L
.67819 .29923 L
.67942 .2985 L
.68054 .29689 L
.68179 .29413 L
.68309 .29016 L
.6853 .2813 L
.68771 .2691 L
.69354 .23425 L
.69906 .20236 L
.70401 .17945 L
.7068 .16941 L
.70938 .16195 L
.71183 .15639 L
.71412 .15243 L
.71544 .15067 L
Mistroke
.71664 .14938 L
.71803 .14824 L
.71935 .14749 L
.72061 .14707 L
.72197 .14693 L
.72324 .14707 L
.7244 .14741 L
.72576 .14805 L
.72724 .14904 L
.72992 .15154 L
.73257 .15485 L
.73548 .15939 L
.74136 .17113 L
.75189 .19661 L
.75739 .20879 L
.76009 .21373 L
.76259 .21744 L
.76486 .21993 L
.76601 .22084 L
.76727 .22158 L
.76853 .22203 L
.76989 .22219 L
.77118 .22205 L
.77236 .2217 L
.77364 .22108 L
.775 .22019 L
.77746 .2181 L
.78305 .21208 L
.78608 .20884 L
.78757 .20743 L
.78895 .20633 L
.7902 .20553 L
.79152 .20495 L
.79285 .2047 L
.7936 .20472 L
.79431 .20487 L
.79562 .20548 L
.79636 .20604 L
.79702 .20668 L
.79831 .20834 L
.79953 .21043 L
.80096 .21358 L
.80227 .2172 L
.80523 .22811 L
.80763 .24009 L
.81027 .25675 L
.81559 .30188 L
.82038 .35186 L
.82291 .3781 L
.82559 .40248 L
Mistroke
.82671 .41092 L
.82793 .41849 L
.82926 .42473 L
.83051 .42842 L
.83166 .42987 L
.83288 .42929 L
.83392 .42712 L
.83505 .42304 L
.83578 .41954 L
.83646 .41564 L
.83774 .40693 L
.84061 .38197 L
.84578 .32802 L
.85053 .28138 L
.85556 .24324 L
.85817 .22831 L
.86105 .21529 L
.86366 .2061 L
.8661 .19941 L
.86898 .19347 L
.87161 .18946 L
.87465 .18604 L
.87753 .18358 L
.88283 .18009 L
.88763 .1775 L
.89839 .17169 L
.91771 .15979 L
.92286 .15703 L
.92828 .1546 L
.93297 .15292 L
.93798 .15154 L
.94081 .15097 L
.94339 .15058 L
.94463 .15045 L
.94598 .15034 L
.94725 .15028 L
.94843 .15025 L
.94979 .15026 L
.95107 .15031 L
.9518 .15036 L
.95247 .15042 L
.95398 .1506 L
.95542 .15084 L
.957 .1512 L
.95848 .15164 L
.95987 .15215 L
.96258 .15347 L
.96507 .15513 L
.96781 .15757 L
.9707 .16107 L
Mistroke
.97322 .1651 L
.97557 .16991 L
.97815 .17662 L
.98091 .18582 L
.98337 .19604 L
.98604 .20966 L
.9909 .24192 L
1 .32361 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02?ooooo
0ol0002:ooooo`00;?ooool7o`0008;ooooo00?o0000ooooooooool08Oooool2o`0000;ooooo0ol0
0028ooooo`00:_ooool2o`0000Kooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q_ooool002Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`25ooooo`00:Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Sooooo0ol0001Sooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08Gooooo000Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5_ooool01Ol0003ooooooooooooooooo000006;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo08Cooooo000Wooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo
2?l0000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Poooool002Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0G?ooool4o`0000Kooooo0_l0000Hooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Poooool002Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool3o`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Poooool002Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo08;ooooo000Uooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo0_l00007ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Cooooo1?l0001Zooooo`009?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03gooooo2_l0000Pooooo`009?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`08ooooo`;o00007_ooool002?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0hooooo`;o00003Oooool00ol0003oooooooooo`0Kooooo`008oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l0000@ooooo`03o`000?oooooooooo
01[ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool00ol0003oooooooooo`0Booooo`07o`000?ooooooV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Sooooo1Ol00003ooooo`03onk^k_lb<S;o000000Co00006_ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`Co000000[o410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^k_oooooo00004oooool00ol0003oooooooooo`02ooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0001?ooooo00?o0000ooooooooool00_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0Booooo`07
o`000?oooooo410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9So0000oiRHV?mgMgL00_ooool00ol0003oooooooooo`0Cooooo`Co
00000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_oo
oooo000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0000Eooooo`05o`000?oooooooooo
ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00cooooo1ol0
0005ooooo`05o`000?ooooooooooooooool@41000oooool01?l@413oooooooooool0000>ooooo`03
o`000?oooooo000000Go00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?l0003ooooooooo
ool@41000oooool00ol0003oooooooooo`0=ooooo`Ko00000_ooool2o`000003ooooool0003ooooo
00?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`04ooooo`05oiRHV?lQ8B7ok^k^ooooool000000_ooool01Ol@413ooooo
oooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`04oa0@4?oooooo0000
o`0001Oooooo1_l00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4
omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
4oooool01_l0003oooooooooooooooooZJVYoa0@40?ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP03
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`04oiRHV?lQ8B7ok^k^o`0000;o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Co0000oooo
oooooooooooo0_l0000Iooooo`05o`000?m4A4CogMgMooooool000001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo01?ooooo00Ko0000oooooooooooo410@o`000?nj^[X3
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`07ooooo`06ogMgMomVIVKoooooo`000?oooooo00000oooool00ol0003ooooooooo
o`0Kooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000ooooooooool00_l0000Kooooo`04o`000?mE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Cooooo`06
o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooo`000?l@4100
0oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`0=ooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`08ooooo`05o`000?oooooo0000ooooool@41000oooool0
0ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@o`000?l0003ooooooa0@
400Kooooo`04o`000?mgMgOoc<c<o`0000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`00
5?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003o
ooooooooo`0Dooooo`06o`000?l@413oV9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`05o`000?nj
^[[ooooooiRHV?l@41000_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00go
0000okZj^_ooooooV9RHoa0@4?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nHV9SooooooiRHV?mgMgL07?ooool00ol0003o
A4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?oo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool05?ooool01_l0
003oZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01_ooool03OnHV9So410@o`000?lQ8B7oc<c<oooo
ool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`05ooooo`;o0000
2_ooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`02ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hKooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQcooooo00?o0000ogMgMol000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool2o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Gooooo`008_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo1Ol0000A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01Kooooo000Rooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Fooooo`008Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool05_ooool0027ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo000Foooooooo0000@?l0
000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo0_l00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`;o00001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01Gooooo000Pooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool05Oooool0023ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01?ooooo1?l00008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Eooooo`008?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool05Oooool0023ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Gooooo000Pooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Dooooo`008?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0@ooooo`;o00003Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Dooooo`007oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool001oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo000O
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0D
ooooo`007oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool0
01oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Kooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Dooooo`007oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool01?l0
003oooooooooool0000`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo000Oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`?o0000<Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Dooooo`007oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;o
oooo0_l0000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo
000Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo000Noooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04_ooool2o`0000oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04oooool0
01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0002Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01;ooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool0000Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Booooo`007Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Kooooo`?o0000:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Looooo`;o0000:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`Go00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo000Mooooo`03o`000?oooooooooo
01oooooo00Go0000ooooooooooooooooo`00001Aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`007Oooool00ol0003oooooooooo`0Ooooo
o`05o`000?ooooooooooooooool00000DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool04Oooool001gooooo00?o0000ooooooooool07oooool01Ol0
003ooooooooooooooooo000005;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000D_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`005_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo0000
Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`12ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooool00000Doooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`12ooooo`005_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool00000Doooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0_l0000Aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04;ooooo000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool3o`00
05?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0@_ooool001Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00001=oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@_ooool001Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000C_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0001>ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0@oooool001Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Aooooo`04o`000?ooooooooooo`0004kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`13ooooo`005_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017o
oooo00Co0000oooooooooooo0000C_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04?ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool01?l0003o
ooooooooool0001>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool001Oo
oooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000004oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`13ooooo`005oooool01Ol0003ooooooooooooooooo0000
07_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`;o00004_ooool00ol0
003oooooo`00001?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool001Oo
oooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Booooo`;o0000Coooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04?ooooo000Gooooo`05o`000?ooooooooooooooool00000O?ooool01Ol0
003ooooooooooooooooo000001Sooooo00?o0000ooooooooool04_ooool2o`00053ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`13ooooo`006?ooool01?l0003oooooooooool0001l
ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0A?ooool001Sooooo00?o0000ooooool00000OOooool0
1Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04Cooooo000Hooooo`03o`000?oooooo000007gooooo00Go0000
ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`14ooooo`006?ooool00ol0003oooooo`00001mooooo`05o`000?oooooo
ooooooooool000006?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0A?ooool001Wooooo0_l0001mooooo`04o`000?ooooooooooo`0001Wooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Cooooo000I
ooooo`03o`000?oooooooooo07cooooo00Co0000oooooooooooo00006Oooool2o`0006Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`00V?ooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`14ooooo`00VOooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo06Gooooo00Go0000
ooooooooooooooooo`000016ooooo`00VOooool00ol0003oooooo`00000Iooooo`03o`000?oooooo
oooo06Gooooo00Co0000oooooooooooo0000Aoooool009[ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo002/ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0
0017ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0
0017ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000IOooool01?l0003ooooooooo
ool00017ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06Gooooo
00Co0000oooooooooooo0000Aoooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo002[ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0IOooool01?l0003oooooooooool00017ooooo`00[?ooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000Aoooool00;Gooooo00?o
0000ooooooooool0I_ooool2o`0004Sooooo002eooooo`03o`000?oooooooooo06Kooooo00?o0000
ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`
ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj
^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zoooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oooooo00?o0000okZj^_oo
ool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o
410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_l000000ol@413oooooooooo`1foooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo07Oooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool5o`0007Sooooo0021ooooo`06o`000?ooooooA4A4odA4
A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo0000NOooool0087ooooo
00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01?oMgMgoEEEEooooool0001iooooo`00
POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03ogMgMoo<c<co000007Wooooo0021
ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03onk^k_m4A4Co000007Wooooo0020ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool0N?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26963 m
.00488 .32833 L
.00722 .35544 L
.00942 .37762 L
.01068 .38792 L
.01204 .39675 L
.01327 .40238 L
.01441 .40537 L
.01565 .40611 L
.017 .40392 L
.01769 .40163 L
.01842 .39833 L
.01975 .39024 L
.02113 .3792 L
.02241 .36692 L
.02532 .33393 L
.03062 .26823 L
.0354 .21703 L
.04057 .17662 L
.04358 .15956 L
.04635 .14729 L
.049 .13816 L
.0518 .13087 L
.05431 .12603 L
.05665 .12267 L
.05922 .11996 L
.06198 .11787 L
.06351 .11702 L
.06492 .11639 L
.06572 .11611 L
.06647 .11589 L
.06725 .11571 L
.06811 .11558 L
.06882 .11552 L
.06957 .11551 L
.07091 .11561 L
.07165 .11574 L
.07235 .11591 L
.07311 .11614 L
.07392 .11645 L
.07533 .11713 L
.07686 .11807 L
.07963 .1203 L
.08232 .12316 L
.08481 .12655 L
.08737 .13101 L
.08972 .13616 L
.09224 .14306 L
.09499 .15243 L
.09987 .17444 L
Mistroke
.10451 .20229 L
.11037 .24642 L
.11588 .2905 L
.11829 .30712 L
.12083 .32081 L
.12216 .32595 L
.12292 .32816 L
.12362 .32975 L
.12486 .33139 L
.12618 .33148 L
.12757 .32975 L
.12885 .32656 L
.12952 .32431 L
.13026 .3214 L
.13175 .31423 L
.13702 .27916 L
.14216 .23979 L
.14688 .20769 L
.15236 .17979 L
.15523 .16943 L
.15669 .1652 L
.15825 .16141 L
.15964 .15865 L
.16089 .15659 L
.16217 .15492 L
.16335 .15374 L
.16472 .15277 L
.16545 .15243 L
.16621 .15219 L
.1675 .15207 L
.16823 .15216 L
.16891 .15233 L
.17023 .15291 L
.1709 .15333 L
.17164 .15388 L
.17416 .15648 L
.17558 .15839 L
.1771 .16079 L
.17987 .16598 L
.19026 .1932 L
.19513 .20818 L
.20034 .22314 L
.20287 .22924 L
.20526 .23397 L
.20741 .2372 L
.20862 .23857 L
.20973 .23952 L
.21093 .2402 L
.21205 .24052 L
.21328 .24053 L
Mistroke
.21461 .24013 L
.21599 .23929 L
.2173 .2381 L
.21977 .23498 L
.22249 .23038 L
.22502 .22535 L
.23075 .21283 L
.23627 .20153 L
.24147 .1931 L
.24435 .18959 L
.24587 .18809 L
.24747 .18677 L
.24882 .18585 L
.2503 .18505 L
.25164 .18451 L
.2529 .18415 L
.25422 .18391 L
.25489 .18384 L
.25563 .1838 L
.25694 .18382 L
.25816 .18394 L
.25886 .18405 L
.2596 .18419 L
.26091 .18449 L
.26388 .18542 L
.26927 .18756 L
.27428 .18956 L
.2766 .19033 L
.27879 .19092 L
.28 .19116 L
.28131 .19136 L
.2825 .19148 L
.28359 .19154 L
.28481 .19154 L
.28595 .19147 L
.2872 .19134 L
.28854 .19113 L
.28994 .19083 L
.29127 .19047 L
.29377 .18964 L
.29908 .18726 L
.30388 .18459 L
.31463 .1782 L
.32403 .17363 L
.33395 .17007 L
.33899 .16874 L
.34451 .16742 L
.35422 .16509 L
.3601 .16381 L
.36567 .16262 L
Mistroke
.3681 .16213 L
.37067 .16169 L
.37201 .16152 L
.37272 .16144 L
.37349 .16138 L
.37484 .16132 L
.3761 .16132 L
.37746 .16139 L
.37872 .16153 L
.38011 .16176 L
.38089 .16193 L
.38159 .16212 L
.38289 .16253 L
.38429 .1631 L
.38549 .16371 L
.38682 .16453 L
.38931 .16658 L
.39066 .16805 L
.39193 .16969 L
.3942 .1734 L
.39664 .17865 L
.39946 .18678 L
.40254 .19858 L
.40544 .21313 L
.40813 .23006 L
.41322 .27226 L
.41862 .32912 L
.42341 .37896 L
.42581 .39848 L
.42718 .40676 L
.42845 .4123 L
.42917 .41443 L
.42985 .41575 L
.43112 .41635 L
.43249 .41425 L
.43327 .41184 L
.43398 .40884 L
.43515 .40241 L
.43644 .39333 L
.43905 .36976 L
.44376 .31741 L
.4489 .26116 L
.45375 .21859 L
.45824 .18944 L
.46095 .17594 L
.46341 .16591 L
.46605 .15714 L
.46891 .14965 L
.47393 .14023 L
.47865 .13397 L
Mistroke
.48421 .12842 L
.48701 .12628 L
.49008 .12441 L
.49552 .12193 L
.50059 .12007 L
.50192 .11967 L
.50333 .1193 L
.50453 .11904 L
.50586 .11884 L
.5066 .11877 L
.50728 .11873 L
.50803 .11872 L
.50881 .11874 L
.51014 .11887 L
.51089 .11898 L
.51158 .11912 L
.51294 .11947 L
.51422 .1199 L
.51662 .12098 L
.5192 .12262 L
.52065 .12383 L
.52199 .12517 L
.52432 .12817 L
.5265 .1319 L
.52889 .13726 L
.53146 .14475 L
.53415 .15479 L
.5367 .16671 L
.54148 .19659 L
.5516 .29352 L
.55426 .32154 L
.55714 .34779 L
.55846 .35749 L
.55986 .36562 L
.56105 .37064 L
.56235 .37393 L
.56355 .37483 L
.56465 .37384 L
.56591 .37059 L
.56711 .36554 L
.56821 .35928 L
.56923 .35228 L
.57153 .33282 L
.58168 .22848 L
.58657 .18908 L
.58932 .17219 L
.59184 .15972 L
.59417 .1504 L
.59671 .14238 L
.59912 .13662 L
Mistroke
.60135 .13266 L
.60271 .13084 L
.60418 .12932 L
.60486 .12877 L
.60557 .12828 L
.60685 .12762 L
.60808 .12724 L
.60923 .12709 L
.61048 .12714 L
.61183 .12743 L
.61258 .12769 L
.61327 .128 L
.61484 .12893 L
.61621 .13001 L
.61768 .13145 L
.62021 .13468 L
.62301 .13943 L
.62817 .15171 L
.63361 .16986 L
.64333 .2155 L
.64839 .24281 L
.65117 .25676 L
.65379 .2681 L
.65528 .27344 L
.65689 .27814 L
.65761 .27982 L
.65836 .28132 L
.65972 .28327 L
.66107 .28424 L
.66234 .28426 L
.66307 .28389 L
.66373 .2833 L
.6645 .28234 L
.66523 .28116 L
.66654 .2784 L
.66796 .27457 L
.67053 .26572 L
.67533 .24496 L
.68056 .22103 L
.68607 .19955 L
.69088 .18592 L
.6936 .18039 L
.69491 .17828 L
.69614 .17661 L
.69726 .17536 L
.69848 .17427 L
.69959 .17352 L
.70061 .17303 L
.70172 .17271 L
.70293 .17259 L
Mistroke
.7042 .17271 L
.70539 .17305 L
.7067 .17364 L
.70809 .17451 L
.7106 .17659 L
.71628 .18321 L
.72663 .19834 L
.72915 .20178 L
.73188 .20502 L
.73429 .20733 L
.7356 .20835 L
.73683 .20915 L
.73803 .20978 L
.73912 .21022 L
.74034 .21057 L
.74165 .21077 L
.74274 .21081 L
.74392 .21071 L
.74504 .2105 L
.74608 .21019 L
.74731 .20969 L
.74861 .20902 L
.75094 .20745 L
.75617 .20258 L
.76566 .19233 L
.77065 .18767 L
.77598 .18366 L
.77905 .18193 L
.78183 .18081 L
.78318 .18043 L
.78389 .18027 L
.78464 .18013 L
.78601 .17994 L
.78728 .17984 L
.78855 .1798 L
.78993 .17981 L
.79124 .17987 L
.79245 .17997 L
.79365 .18011 L
.79474 .18026 L
.79718 .18071 L
.79855 .18106 L
.79981 .18143 L
.80266 .18253 L
.80517 .18379 L
.80782 .18541 L
.81011 .18707 L
.81256 .18916 L
.81698 .19416 L
.81969 .19845 L
Mistroke
.82224 .20379 L
.82454 .20989 L
.82704 .21819 L
.83182 .23997 L
.83422 .25442 L
.83685 .27328 L
.84236 .32308 L
.84741 .37464 L
.85032 .40103 L
.85192 .41283 L
.8527 .41768 L
.85342 .42153 L
.85409 .42454 L
.85483 .42719 L
.85557 .42913 L
.85635 .43036 L
.85773 .43043 L
.85901 .4281 L
.85968 .42596 L
.86042 .42295 L
.86175 .41573 L
.86426 .39692 L
.86989 .33938 L
.87524 .28312 L
.88027 .24043 L
.88305 .22201 L
.88606 .20593 L
.88856 .19514 L
.89131 .18561 L
.89374 .17885 L
.89634 .1731 L
.89909 .16835 L
.90165 .16489 L
.90662 .15997 L
.91115 .15677 L
.91622 .15407 L
.9216 .15185 L
.93125 .14805 L
.94176 .14339 L
.94756 .14081 L
.95307 .1383 L
.95555 .13725 L
.95819 .1363 L
.95971 .13586 L
.96109 .13555 L
.96247 .13532 L
.96378 .13519 L
.96497 .13514 L
.96623 .13517 L
.9673 .13527 L
Mistroke
.96848 .13547 L
.96976 .13579 L
.97112 .13629 L
.9724 .13693 L
.97358 .13769 L
.97477 .13866 L
.97603 .13993 L
.9783 .143 L
.98075 .14763 L
.98344 .1547 L
.98576 .16273 L
.98826 .17375 L
.99279 .20131 L
.9963 .23076 L
1 .26963 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool002Wooooo1_l0001kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08;ooooo1ol0
002]ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo0_l00000
0ooooooo0000ooooo`04ooooo`03o`000?oooooooooo0:[ooooo000Wooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool06?ooool3o`0008kooooo000Vooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0N_ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00_l0002=ooooo`009_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2;ooooo`009Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Xooooo`Ko00007?ooool002Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool2o`0000Kooooo00?o
0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool3o`0000Wooooo00?o0000
ooooooooool06?ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Goooool2o`0000cooooo00?o0000oooo
ooooool06?ooool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOooool2o`0000oooooo00?o0000oooooooo
ool05oooool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`?o0000
G_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Wooooo0ol0000Aooooo`03o`00
0?oooooooooo01Oooooo000Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_oo
ool2o`000003ooooool0003ooooo05cooooo00?o0000ooooooooool02?ooool2o`0000Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`009?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0_l0001Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0E_ooool2o`0001Kooooo00?o0000ooooooooool05_oo
ool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0>_ooool6o`0001Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool0
01Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Gooooo00?o0000ooooooooool04Oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Fooooo`[o000000So410@o`000?l0003ok^k^
oc8b<_l0003o<S8bonk^kQ;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool4o`000004oa0@4?oooooooooo
onk^kP;o000000?o<S8bonk^k_ooool06Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00?o0000ooooooooool05oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000Kooooo00?o0000oooo
ooooool04?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Booooo`Co00002?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?oooooo
V9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol0003oooooooooo`0<ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@o`000?ooool01_ooool00ol0003oooooooooo`08ooooo`Ko00000oooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004?ooool2o`000003ooooool0003o
000000Co00001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41004_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@o`000?oooooooooo
oa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05
o`000?ooooooooooooooool@41000oooool01?l@413oooooooooool0000Hooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1Oooool00onYZJWo410@ooooo`02ooooo`04o`000?ooooooooooooooo`;o00002?ooool00ol0003o
ooooooooo`0Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`?o00003_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooo
ooooool03oooool4o`0000Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001kooooo00?oZJVYoa0@4?ooool00_ooool01ol0003ooooooooooooooooo0000ooooool00000
6Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01;ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000[ooooo0ol0000Aooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`;o00000oooool00ol0003ooooo
ooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03
oa0@4?l0003o^[Zj00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000001Wooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol@
413oooooo`000?oooooo410@017ooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@
ooooool0003ooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool6o`0001?ooooo
00?o^[Zjob4Q8Oooool00_ooool01_l@413ooooooooooooooooo410@o`0001_ooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo013ooooo00Wo0000
oooooooooooooooooa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So0000
00[ooooo00?o0000ooooooooool03_ooool01?l0003o^[ZjoooooonHV9P4o`000005ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?l0003oV9RHogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg013ooooo00?o0000ooooooooool01?ooool02?l0003o
ooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo
0ol00005ooooo`?o00003_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol0000Kooooo`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00ol0003oooooooooo`0@ooooo`09o`000?oooooooooooooooonYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000:ooooo`03o`000?oooooooooo00kooooo00Go
V9RHoa0@4?l0003o0000olc<c003ooooo`?o000000?o<S8bonk^k_ooool01?ooool3o`0001Cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?l0003ok^k^017ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0
003oooooooooo`05ooooo`08o`000?oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`07onk^
k_lb<S;o0000oc8b<_o^k^koooooo`00000;ooooo`;o00003?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Mooooo`03ogMgMol0003o000000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Dooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Sooooo1Ol0000Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Dooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Cooooo000Rooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool002;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`005_ooooooo`00043o00004ooo
ool001Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooooooo
o`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00000ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooooooool4o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000Cooooo`008Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04oooool0
027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01;ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Booooo`008?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`;o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Booooo`008?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool04_ooool0023ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01;ooooo1?l0000looooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;o
oooo000Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo01;ooooo000Pooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo000P
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01;ooooo000Pooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo017ooooo000Pooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3Oooool2o`0000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Ooo
ool001oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool001Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Go
oooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo0000
03Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`005_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool01?l0003o
ooooooooool0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool001Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooool00000=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wo
oooo000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0>ooooo`;o00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo
0_l0000fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool001Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`005_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Wooooo000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0>Oooool001Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`00
5_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`Go00001_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000G
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0ioooo
o`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0>_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`05o`00
0?ooooooooooooooool00000F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[o
oooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool01?l0003ooooo
ooooool0001Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0joooo
o`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo0000Foooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo0000
05_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Looooo`;o0000G?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`005oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0@ooooo`;o00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo000Hoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0joooo
o`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooo
ooooooooo`00001Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool001So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooooooo
ool00000E_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo000Hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo0000
05Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`006?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00001Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>oooool001Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000Eoooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo000Hooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017o
oooo0_l0000@ooooo`05o`000?ooooooooooooooool00000Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03_ooooo000Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooo`00001Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>oooool001Wooooo00Go0000ooooooooooooooooo`00001nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000005So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`006Oooool01Ol0003ooooo
oooooooooooo000007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo00?o0000ooooool00000F?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03_ooooo000Iooooo`04o`000?ooooooooooo`0007oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo000Iooooo`04o`00
0?ooooooooooo`0007oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`00
6Oooool01?l0003oooooooooool0001oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>oooool001Wooooo00Co0000oooooooooooo0000Ooooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03cooooo000Iooooo`04o`000?ooooooooooo`0007oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Aooooo`;o0000K?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03cooooo000Iooooo`04o`000?ooooooooooo`00083ooooo00Go0000oooooooo
ooooooooo`00000Cooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0looooo`006_ooool00ol0003oooooo`000020ooooo`05o`000?oooooooooooooo
ool000004oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0??ooool001[ooooo00?o0000ooooool00000P?ooool01Ol0003ooooooooooooooooo0000
01?ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03cooooo000Jooooo`03o`000?oooooo0000083ooooo00Co0000oooooooooooo00005?ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??ooool001[o
oooo0_l00021ooooo`04o`000?ooooooooooo`0000_ooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0loooo
o`006_ooool2o`0008;ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`00
W_ooool00ol0003oooooo`000009ooooo`Go00001_ooool00ol0003oooooooooo`1]ooooo`04o`00
0?ooooooooooo`0003oooooo002Nooooo`03o`000?oooooo000000Wooooo00CoA4A4omgMgOoooooo
00001oooool3o`0006gooooo00Co0000oooooooooooo0000?oooool009kooooo0_l0000:ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0KOooool01?l0003oooooooooool0000o
ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo06gooooo00Co0000oooo
oooooooo0000?oooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1]oooo
o`04o`000?ooooooooooo`0003oooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0K_ooool2o`00043ooooo002eooooo`03o`000?oooooooooo06kooooo0_l00010ooooo`00
]Oooool00ol0003oooooooooo`1^ooooo`;o0000@?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o410@olc<c01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009
ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003oV9RHoooooonHV9So8B4Q07Sooooo0021ooooo`06o`00
0?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oeEEEOl0003o410@olc<c01hooooo`00
POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo07[ooooo0021
ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH07[ooooo0020ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Coc<c<odA4A?l0003o410@N?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(108) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24234 m
.00488 .30296 L
.00942 .36071 L
.01077 .37544 L
.01204 .38756 L
.01319 .39673 L
.01441 .40423 L
.01574 .40953 L
.01697 .4116 L
.01829 .4107 L
.01904 .40876 L
.01975 .40602 L
.02103 .39884 L
.02243 .38805 L
.02499 .36197 L
.02978 .30114 L
.03533 .23397 L
.04057 .18753 L
.04336 .16959 L
.04639 .15463 L
.04914 .14444 L
.05167 .13753 L
.05309 .13458 L
.05442 .13236 L
.05587 .13046 L
.05743 .12897 L
.05821 .12841 L
.05906 .12793 L
.05987 .12758 L
.06061 .12735 L
.06128 .12722 L
.06202 .12714 L
.06279 .12713 L
.06351 .12719 L
.06475 .12744 L
.06611 .12794 L
.0668 .12828 L
.06753 .12871 L
.06886 .12968 L
.07143 .13232 L
.07376 .13565 L
.07649 .14076 L
.07944 .1478 L
.08481 .16473 L
.09467 .21271 L
.10011 .24708 L
.10527 .27861 L
.10818 .29306 L
.10971 .29914 L
.11055 .30194 L
Mistroke
.11134 .3042 L
.11207 .30594 L
.11286 .30745 L
.11422 .30913 L
.1149 .30951 L
.11562 .30957 L
.1169 .30885 L
.11819 .30703 L
.11958 .30394 L
.12089 .30002 L
.12208 .2957 L
.12777 .2684 L
.13272 .24224 L
.13796 .21856 L
.1407 .2088 L
.14372 .20027 L
.14504 .19726 L
.14646 .19453 L
.14779 .19243 L
.14903 .19088 L
.15022 .18974 L
.15148 .18889 L
.1522 .18856 L
.15288 .18836 L
.15415 .18822 L
.1555 .1884 L
.15674 .18884 L
.1581 .18958 L
.15953 .19063 L
.16411 .19531 L
.16915 .20211 L
.17418 .20975 L
.17683 .21367 L
.17965 .21739 L
.18211 .22008 L
.18341 .22127 L
.18482 .22236 L
.18611 .22318 L
.18729 .22379 L
.18842 .22425 L
.18961 .2246 L
.19098 .22486 L
.19175 .22493 L
.19244 .22495 L
.1938 .22488 L
.19509 .22466 L
.19581 .22448 L
.19658 .22423 L
.19796 .22367 L
.19945 .2229 L
Mistroke
.20108 .22187 L
.21156 .21303 L
.21656 .20914 L
.22202 .20546 L
.22451 .20398 L
.22717 .20261 L
.22947 .20163 L
.23195 .20079 L
.23505 .20001 L
.23796 .19941 L
.24341 .19821 L
.25388 .19588 L
.26387 .19294 L
.27483 .18875 L
.29696 .17943 L
.33942 .16354 L
.35901 .15538 L
.3803 .14398 L
.3832 .14233 L
.38592 .14096 L
.3874 .14036 L
.38876 .13992 L
.39027 .13955 L
.39106 .13941 L
.39189 .1393 L
.39318 .13921 L
.39455 .1392 L
.39584 .13928 L
.39701 .13944 L
.3984 .13975 L
.39918 .13999 L
.3999 .14027 L
.40122 .14094 L
.40262 .14193 L
.40393 .14317 L
.40512 .14464 L
.40641 .14663 L
.40782 .14933 L
.41031 .15571 L
.41268 .16391 L
.41546 .17665 L
.41842 .19461 L
.42122 .21667 L
.42375 .24164 L
.43361 .37423 L
.43601 .40435 L
.43733 .41802 L
.43857 .42844 L
.43928 .43313 L
.44005 .43713 L
Mistroke
.44139 .44125 L
.44275 .44155 L
.44401 .43833 L
.44537 .43121 L
.44665 .42137 L
.44955 .38953 L
.45542 .3053 L
.46085 .23377 L
.46589 .18625 L
.46841 .16899 L
.4711 .15438 L
.47408 .14191 L
.47678 .13339 L
.47935 .12733 L
.48212 .12255 L
.48473 .11929 L
.48714 .11707 L
.48947 .11542 L
.49165 .11422 L
.49404 .11325 L
.49538 .11285 L
.4966 .11259 L
.49787 .11242 L
.49905 .11236 L
.50035 .1124 L
.50173 .11255 L
.50292 .11278 L
.50404 .11307 L
.50659 .11399 L
.50914 .11528 L
.51152 .11685 L
.51412 .11912 L
.51691 .12237 L
.51983 .127 L
.5226 .13282 L
.52508 .13949 L
.52777 .14856 L
.53268 .17109 L
.53515 .18598 L
.53788 .20547 L
.5472 .29272 L
.54982 .31808 L
.55267 .34184 L
.55397 .35055 L
.55536 .35792 L
.55667 .36286 L
.55786 .36552 L
.55912 .36636 L
.56028 .36533 L
.56154 .36226 L
Mistroke
.56288 .35692 L
.56405 .35066 L
.56514 .34361 L
.56761 .32412 L
.57301 .27327 L
.57888 .22216 L
.58157 .2035 L
.58442 .18737 L
.58686 .17643 L
.58954 .16713 L
.5909 .16347 L
.59232 .1603 L
.59355 .15809 L
.59486 .15624 L
.5956 .15542 L
.59628 .15481 L
.5976 .15397 L
.59834 .15369 L
.59914 .15353 L
.59989 .15352 L
.60059 .15362 L
.60183 .15406 L
.60298 .15474 L
.60426 .15578 L
.60562 .15721 L
.6084 .16114 L
.61094 .16585 L
.61573 .17756 L
.62095 .19391 L
.63044 .22814 L
.63517 .24373 L
.63766 .25047 L
.64029 .256 L
.64168 .25818 L
.64242 .25911 L
.64321 .25992 L
.64394 .26049 L
.6446 .26088 L
.64589 .26125 L
.64719 .26113 L
.64793 .26084 L
.64861 .26044 L
.64985 .25939 L
.65117 .25787 L
.65378 .25374 L
.65658 .24802 L
.66166 .23584 L
.66765 .2215 L
.67057 .2155 L
.67321 .21092 L
Mistroke
.67568 .20742 L
.67835 .2045 L
.67982 .20325 L
.68117 .20232 L
.68246 .20161 L
.68383 .20105 L
.68521 .20066 L
.68598 .20052 L
.68668 .20043 L
.68805 .20038 L
.68935 .20046 L
.69008 .20056 L
.69086 .20069 L
.69225 .20102 L
.69541 .20207 L
.70024 .20403 L
.70277 .20501 L
.70544 .2059 L
.70686 .20629 L
.70842 .20664 L
.7091 .20677 L
.70983 .20689 L
.71115 .20704 L
.71184 .2071 L
.71259 .20713 L
.71396 .20713 L
.71528 .20705 L
.71651 .2069 L
.71782 .20666 L
.71907 .20636 L
.72142 .20562 L
.72669 .20328 L
.73621 .19818 L
.74124 .19558 L
.74658 .19325 L
.75245 .19143 L
.75789 .19021 L
.76872 .18803 L
.77169 .18739 L
.77482 .18658 L
.78042 .1846 L
.79065 .17987 L
.80161 .174 L
.80717 .17127 L
.81243 .16928 L
.81715 .16785 L
.81844 .16752 L
.81982 .16721 L
.8211 .16698 L
.82228 .16683 L
Mistroke
.82345 .16674 L
.82456 .16671 L
.82573 .16676 L
.82701 .16691 L
.82812 .16711 L
.82931 .16741 L
.83144 .16816 L
.83275 .16876 L
.83417 .16954 L
.83674 .17138 L
.83924 .17387 L
.84154 .177 L
.84412 .18179 L
.84647 .18765 L
.84918 .19654 L
.85175 .20746 L
.85632 .23421 L
.8589 .25437 L
.86129 .2767 L
.86667 .3384 L
.8695 .37367 L
.87248 .4079 L
.87374 .42027 L
.87509 .43141 L
.87587 .43668 L
.87657 .44068 L
.87795 .44614 L
.87919 .44823 L
.88054 .4474 L
.88181 .44365 L
.88298 .43775 L
.88411 .43003 L
.88532 .4197 L
.88751 .3967 L
.89249 .33321 L
.89731 .27347 L
.90256 .22256 L
.90557 .20072 L
.90835 .18444 L
.91124 .17093 L
.91386 .16114 L
.91886 .14749 L
.9216 .14209 L
.92418 .13792 L
.92908 .13162 L
.93445 .12636 L
.94006 .12237 L
.94529 .11963 L
.9501 .1176 L
.95247 .11677 L
Mistroke
.95466 .11612 L
.95585 .11583 L
.95717 .11557 L
.9585 .11536 L
.95923 .11528 L
.95991 .11523 L
.96111 .11518 L
.96221 .11519 L
.96342 .11527 L
.96469 .11543 L
.96584 .11564 L
.96708 .11594 L
.96817 .11629 L
.96933 .11673 L
.97152 .11782 L
.97354 .11921 L
.97587 .12139 L
.97804 .12416 L
.98043 .12823 L
.98299 .1341 L
.98517 .14059 L
.98755 .1495 L
.98965 .15922 L
.99188 .1718 L
.9961 .20316 L
1 .24233 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo1ol0002>ooooo`?o0000
7_ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`28ooooo`?o00000_ooool3o`0001cooooo002`ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000028ooooo`;o00002?ooool00ol0003o
ooooooooo`0Iooooo`00[oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Poooool2o`0000_ooooo00?o0000ooooooooool06?ooool002Sooooo1?l0
0022ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool002Oooooo0_l00002
ooooo`;o0000POooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`20
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool002Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool002Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1nooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Qooooo`Go00005oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Kooooo000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Gooo
ool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_oo
ool002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`;o00001oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool0
02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`?o00002_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool002Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`;o00003Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`;o00003oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooooooo01;ooooo
1?l0001Sooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool002Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`;o00004Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`05o`000?ooooooooooooooool00000HOooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo000Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D?oo
ool2o`0001Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`005Oooool2
o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool2o`0000Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000
ooooooooool04oooool3o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0?ooooo`?o00003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo0_l0
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`Oo00001Oooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Gooooo0_l0
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool02oooool7o`0000Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`?o00001?ooool6o`00
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`04ooooo`;o00001?ooool01Ol@413ooooooooooooo
oooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00cooooo
0ol00006ooooo`;o00002?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000002Oooool3o`0001;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00002oooool00ol0003oooooooooo`04
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo01;ooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00005Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000002?ooool2o`0000kooooo00?o0000ooooooooool00_ooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Boooo
o`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
0_ooool2o`0001Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`05oa0@4?oooooooooooooo
ool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool2
o`00013ooooo00?o0000ooooooooool00oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`0Dooooo`05ogMgMoo<c<co0000ooooool00000
0_ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`?o
00006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo013ooooo00So0000oooooooooooo410@oiRHV?oooooo^[Zj
o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01Cooooo00Go
k^k^odA4A?l0003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo
00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`04onk^k_lb
<S;o0000oc8b<P;o00006oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00GoEEEEofIVI_l0
003oooooo`000002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool4o`0001Cooooo00Oo0000oooooonY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo01Gooooo00CoMgMgo`000?oooooo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool3o`0002?ooooo
0_l0000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Xooooo`Go00006?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0?ooooo`05o`000?ooooooooooooooool000007oooool3o`0002oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo0ol0000Nooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Cooooo`008ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Hooooo`Co0000<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08oooool2o`00027ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo000Sooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01?ooooo1?l0000fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Qooooo`;o00008oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool3o`00
03[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00oooooo1ol00007ooooo`?o00009Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04_ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?o00000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0000C
ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`;o0000@_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Boooo
o`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool04_ooool002;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0<ooooo`Go0000A_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`008Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Aooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`008Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017o
oooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo017ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0<Oooool001Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01;ooooo00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool01?l0003oooooooooool00011ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo0ol00012ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0b
ooooo`005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000Fooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool001Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0booooo`005oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03;ooooo000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool0
01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo0_l0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0<_ooool001Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0booooo`005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000G
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool001Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`00067ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<_ooool001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Goooo
o`04o`000?ooooooooooo`00067ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`005oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000HOooool0
0ol0003oooooooooo`06ooooo`08o`000?oooooooooooiRHV?lQ8B7ok^k^oooooom4A4@6ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool001Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Hooooo`;o0000H_ooool00ol0003oooooooooo`06ooooo`07o`00
0?oooooooooooooooonHV9So8B4Qonk^kP07ooooo`?o00003Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0coooo
o`005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0cooooo`005oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`005ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0cooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool01Oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So
410@1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?ooooo000Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`08o`00
0?oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0<oooool001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03?ooooo000Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0cooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`;o0000
3oooool01Ol0003ooooooooooooooooo000005oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo
00Go0000ooooooooooooooooo`00001Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<oooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool00000Goooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?o
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool01Ol0003ooooo
oooooooooooo000005oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`00001Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool001Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`00063o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`006Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000H?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Cooooo000Iooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03oooool00ol0003oooooo`00001Pooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0=?ooool001Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooo0000067ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0dooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool2o`0006;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0dooooo`006Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00oooooo0_l0001Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0=?ooool001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool001Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=?ooool001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=?ooool001Wooooo00Go0000ooooooooooooooooo`00
0022ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool001Wooooo00Go0000
ooooooooooooooooo`000022ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?oo
ool001[ooooo00Co0000oooooooooooo0000P_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Gooooo000Jooooo`04o`000?ooooooooooo`0008;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`;o0000M?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Gooooo000Jooooo`04o`000?ooooooooooo`0008?ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`006_ooool01?l0003oooooooooool00023ooooo`05o`000?ooooooooooooooool0
00003oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0=Oooool001[ooooo00?o0000ooooool00000Q?ooool01Ol0003ooooooooooooooooo000000oo
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Go
oooo000Jooooo`03o`000?oooooo000008Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`00
6_ooool00ol0003oooooo`000024ooooo`05o`000?ooooooooooooooool000001_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Gooooo000Jooooo`03o`000?oooooo000008Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Gooooo000Kooooo`;o0000Q?ooool01?l0003ooooo
ooooool00005ooooo`Go00001_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0=Oooool001_ooooo0_l00024ooooo`04o`000?ooooooooooo`0000Go
oooo00CoA4A4omgMgOoooooo00001oooool3o`0007?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0eooooo`00XOooool01?l0003oooooooooool00005ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03Gooooo002Qooooo`04o`000?ooooooooooo`0000Kooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`1dooooo`05o`000?ooooooooooooooool00000=oooool00:7ooooo00Co0000
oooooooooooo00001_ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo07Cooooo00Go
0000ooooooooooooooooo`00000gooooo`00XOooool01?l0003oooooooooool00007ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0M?ooool01Ol0003ooooooooooooooooo000003Oo
oooo002Qooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0M?ooool01?l0003ooooo
ooooool0000hooooo`00XOooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo07Cooooo
00Co0000oooooooooooo0000>?ooool00:;ooooo0_l0000Aooooo`03o`000?oooooooooo07Cooooo
00Co0000oooooooooooo0000>?ooool00:;ooooo0_l0000Aooooo`;o0000M_ooool00ol0003ooooo
o`00000hooooo`00X_ooool2o`00017ooooo00?o0000ooooooooool0MOooool00ol0003oooooo`00
000hooooo`00]Oooool00ol0003oooooooooo`1eooooo`;o0000>Oooool00;Gooooo00?o0000oooo
ooooool0MOooool2o`0003Wooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000go
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000ooooooooooooooooo`00
001hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S80N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Oo<c<co0000o`000?l0003oc<c<07Sooooo0021ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@okZj^_oooooo^[Zjoa0@401hooooo`00POooool01_l0003o
<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o000007Sooooo0020ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1hooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .22836 m
.00488 .28093 L
.00942 .33413 L
.01199 .36114 L
.01441 .38144 L
.01575 .38964 L
.01651 .39317 L
.01721 .39567 L
.01844 .39824 L
.01975 .39833 L
.02104 .39578 L
.02221 .39123 L
.02357 .38354 L
.02486 .37407 L
.02966 .32641 L
.03538 .26357 L
.04057 .21795 L
.0433 .2 L
.04588 .18669 L
.0486 .17605 L
.05013 .17146 L
.05154 .16807 L
.05268 .16587 L
.0539 .16402 L
.05524 .16255 L
.05649 .16168 L
.05716 .1614 L
.05789 .16122 L
.05922 .16125 L
.06052 .16166 L
.06172 .16235 L
.06304 .16343 L
.06446 .16494 L
.06704 .16851 L
.07011 .17414 L
.07292 .18063 L
.08481 .219 L
.09442 .25287 L
.09718 .26101 L
.09979 .26732 L
.10214 .27157 L
.10346 .27332 L
.10468 .27449 L
.10602 .27531 L
.10728 .27562 L
.10866 .27548 L
.10944 .2752 L
.11015 .27481 L
.11089 .27429 L
.11157 .27371 L
Mistroke
.11312 .27204 L
.11594 .26797 L
.12641 .24691 L
.13176 .23667 L
.13457 .23227 L
.13754 .22847 L
.14014 .22582 L
.14299 .22354 L
.14559 .22197 L
.148 .22091 L
.14922 .2205 L
.15054 .22016 L
.15179 .21993 L
.15295 .21978 L
.15399 .2197 L
.15513 .21966 L
.15633 .21966 L
.15745 .2197 L
.15869 .21977 L
.15999 .21987 L
.16231 .22004 L
.16482 .22021 L
.16624 .22028 L
.16756 .22032 L
.1689 .22035 L
.16958 .22036 L
.17032 .22037 L
.17164 .22037 L
.17287 .22036 L
.17362 .22035 L
.17433 .22033 L
.17565 .22029 L
.17639 .22025 L
.17708 .22021 L
.17863 .22009 L
.17987 .21996 L
.18104 .2198 L
.1837 .21933 L
.18628 .21872 L
.18908 .21793 L
.20861 .2114 L
.25177 .1946 L
.29334 .17588 L
.33332 .15375 L
.35561 .13403 L
.36615 .12634 L
.37078 .12325 L
.37588 .12039 L
.38078 .11831 L
.38598 .11644 L
Mistroke
.38871 .11555 L
.39021 .11513 L
.39164 .11481 L
.39296 .11458 L
.39371 .11449 L
.39441 .11443 L
.39563 .11439 L
.39694 .11445 L
.39829 .11461 L
.39952 .11484 L
.40088 .11518 L
.40232 .11565 L
.40473 .11669 L
.4061 .11746 L
.40738 .11832 L
.40977 .12045 L
.41195 .12321 L
.41446 .12769 L
.41684 .13355 L
.41933 .1417 L
.42166 .15156 L
.42423 .1653 L
.42699 .18433 L
.42973 .20855 L
.43261 .2407 L
.43776 .31405 L
.44223 .38301 L
.44469 .41512 L
.44589 .42776 L
.447 .4371 L
.44832 .44492 L
.44901 .44751 L
.44975 .44906 L
.45093 .44893 L
.45224 .44504 L
.45345 .43805 L
.45475 .42719 L
.45711 .40022 L
.46227 .32287 L
.46776 .24411 L
.47092 .20918 L
.47378 .18464 L
.47665 .16569 L
.47936 .15205 L
.48193 .14214 L
.48334 .13784 L
.48465 .13448 L
.48697 .1299 L
.48819 .1281 L
.48951 .12659 L
Mistroke
.49092 .12537 L
.49167 .12487 L
.49246 .12443 L
.49315 .12412 L
.49391 .12384 L
.49525 .1235 L
.49655 .12332 L
.49727 .12329 L
.49794 .12329 L
.49924 .1234 L
.50047 .12364 L
.50177 .12404 L
.50251 .12435 L
.50318 .12469 L
.5044 .12543 L
.50574 .12646 L
.50807 .1288 L
.51053 .13202 L
.5132 .13637 L
.51607 .14201 L
.52126 .15543 L
.52374 .16389 L
.52644 .17498 L
.53135 .20062 L
.54056 .2644 L
.5453 .299 L
.5478 .31475 L
.55042 .32779 L
.55182 .33281 L
.55261 .33498 L
.55335 .33654 L
.55465 .33817 L
.55604 .33831 L
.55672 .33778 L
.55746 .33677 L
.5588 .33383 L
.56011 .32969 L
.56131 .32488 L
.5727 .25818 L
.57556 .24232 L
.57828 .22927 L
.58092 .21876 L
.58337 .21105 L
.58557 .2058 L
.58669 .2037 L
.58791 .20186 L
.58925 .20031 L
.59051 .19928 L
.59173 .19863 L
.59286 .19832 L
Mistroke
.59408 .19827 L
.59523 .19846 L
.59648 .1989 L
.59782 .19964 L
.59923 .20066 L
.60056 .20186 L
.60306 .20464 L
.61357 .22088 L
.61933 .22913 L
.62215 .23234 L
.62473 .23478 L
.62706 .23655 L
.62952 .23795 L
.6308 .23846 L
.63199 .2388 L
.63329 .23902 L
.63402 .23908 L
.63468 .23908 L
.63537 .23904 L
.6361 .23895 L
.6374 .23869 L
.63812 .23849 L
.6388 .23827 L
.64033 .23767 L
.64566 .235 L
.66502 .22403 L
.68455 .21429 L
.69486 .20955 L
.70051 .20696 L
.70328 .20589 L
.70582 .20513 L
.70846 .20454 L
.71131 .20404 L
.71738 .20293 L
.72249 .2019 L
.72809 .201 L
.73066 .20054 L
.73341 .19985 L
.73601 .19895 L
.73837 .19794 L
.7492 .19248 L
.79114 .17281 L
.83148 .14934 L
.83666 .14473 L
.83952 .14221 L
.84224 .14017 L
.84476 .13873 L
.84618 .13812 L
.8475 .13767 L
.8487 .13733 L
Mistroke
.84983 .13708 L
.85114 .13686 L
.85232 .13673 L
.8536 .13668 L
.85495 .13677 L
.8561 .13701 L
.85737 .13748 L
.85873 .13833 L
.85949 .13899 L
.86019 .13972 L
.86154 .14154 L
.86283 .1438 L
.86422 .14691 L
.86571 .15105 L
.86837 .1608 L
.87124 .17516 L
.8744 .19691 L
.87687 .21941 L
.87956 .25078 L
.885 .33513 L
.88762 .38116 L
.89009 .42215 L
.89231 .45269 L
.89357 .46591 L
.89472 .47496 L
.89599 .48107 L
.89671 .48264 L
.89738 .48284 L
.89875 .47951 L
.89951 .47549 L
.90021 .47054 L
.90164 .45671 L
.90321 .43681 L
.90607 .39142 L
.91114 .30204 L
.91662 .22321 L
.91954 .19318 L
.92222 .17196 L
.92478 .15619 L
.92749 .14332 L
.92992 .13446 L
.93218 .12815 L
.93466 .12304 L
.93606 .12085 L
.93732 .11921 L
.94015 .11641 L
.94275 .11454 L
.94561 .11296 L
.94708 .11231 L
.94865 .11173 L
Mistroke
.95002 .11135 L
.95128 .11109 L
.95254 .11093 L
.95374 .11087 L
.95442 .11087 L
.95514 .1109 L
.95643 .11101 L
.95722 .11111 L
.95797 .11122 L
.95936 .11149 L
.96172 .11204 L
.96424 .11278 L
.96701 .11387 L
.9696 .11526 L
.97251 .11746 L
.97526 .12031 L
.97773 .12363 L
.98042 .12823 L
.98274 .13323 L
.9853 .14017 L
.98798 .1494 L
.99049 .16034 L
.99498 .18664 L
.99981 .22657 L
1 .22836 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2<ooooo`Go00007oooool009;ooooo1?l0000Dooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2:ooooo`;o00001Oooool2o`0001gooooo002>ooooo`Co00001?oo
ool2o`0001;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`00SOooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Wooooo002;ooooo`;o00003?ooool00ol0003oooooooooo`0F
ooooo`Go0000R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo0029oooo
o`;o00003oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o0000Qoooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo0028ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool3o`0008Kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Gooooo`00Qoooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`00Q_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000006[ooooo0ol0000Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05_ooool008Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Xooooo`?o00000_ooool2o`00
01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`00Q?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool008?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`;o00001oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool008;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Oooooo`;o00002_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool0087ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo001ooooo
o`;o00006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo0_l00005oooo
o`03o`000?oooooooooo05_ooooo0_l0000=ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Eooooo`00OOooool2o`0001gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Dooooo`00:?ooool2o`00057ooooo0_l0000Pooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05Sooooo0_l0000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo00003oooool01OnHV9So410@o`000?lb
<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00[ooooo0_l0000@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kPKooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000
ooooooooool03?ooool01_nHV9So410@o`000?lb<S;oc<c<o`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP09ooooo`03o`000?oooooooooo017ooooo0ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000oooooo
00Ko410@okZj^_ooooooMgMgoc8b<_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool0
0ol0003oooooooooo`0Booooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;
ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool6o`0000Kooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4007ooooo`;o00002_ooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003oooooooooo`0Cooooo`05o`000?oo
oooo0000ooooool@41000oooool00ol@413oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00005ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00005Oooool01_nY
ZJWo410@ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`03odA4A?oMgMgooooo00;o00000oooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool2o`0001Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool3o`0001Kooooo00Oo410@o`000?nj^[[oooooo`000?oooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`06omgMgOmEEEGoooooo`000?oooooo0000
0_ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0
003ooooooooooooooooo410@00?ooooo00Co410@ooooool0003o00006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00;o00006_ooool01_nj^[[o8B4Qooooool0003ooooooa0@40?ooooo00?o
410@ooooooooool01oooool00ol0003oooooooooo`0@ooooo`05ogMgMoo<c<co0000ooooool00000
0_ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01?mgMgOoV9RHoooooonHV9P2o`0001gooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0001Wooooo00go
410@oiRHV?oooooo^[Zjo`000?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool04Oooool01Oo^k^koA4A4o`000?oooooo000000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^o`000?l0003o0000onk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`03onk^k_lb<S;o000000;o00006oooool03OnYZJWo410@o`000?l@413oZJVYooooool0003o
ooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Booooo`04ogMgMol0003o
ooooo`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`009?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Sooooo0_l0000cooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo0_l0
000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Cooooo`009?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo0_l0000e
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04;ooooo0_l0000Wooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03?ooooo0_l0000gooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04oooool002?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`?o
0000>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0@ooooo`?o0000:_ooool3o`0002[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo000Sooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool3o`0003gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02o`0002?ooooo1_l0000]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Booooo`005_ooooooo`00043o00004ooo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooooooo`?o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo1?l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool2o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`008oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo0ol00018ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`;o0000??ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool002?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`?o0000Boooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool3o`0003ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;o
oooo000Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool=o`0004kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo
0_l00011ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Aooooo`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool2o`0004?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o0000G?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0A
ooooo`005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`07ooooo`;o0000A_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02_ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo0_l00006ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0[ooooo`005_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`;o0000
BOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Fooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`Co0000C?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02_ooooo000Fooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0:oooool001Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0/ooooo`005_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02co
oooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool001Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`005oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool2o`0000_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0;?ooool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/oooo
o`005oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo000Gooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool001Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000IOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0/ooooo`005oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0ol0
001Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02cooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo000Goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/oooo
o`005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`00
5oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
;Oooool001Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02gooooo000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02gooooo000Hooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`06ooooo`Go00001_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02gooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`06o`000?nHV9So8B4Qonk^k_oooooo
A4A41_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo000Hooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooV9RHob4Q8Oo^k^h01oooool3o`0000cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool001Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo
00Ko0000ooooooooooooV9RHob4Q8Oo^k^h6ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;Oooool001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooogMgMomVIVH6ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00001V
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo0_l000001?nj
^[[ooooooiRHV?l@4106ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00
001Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool001Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00Ko0000
oiRHV?l@413o0000ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
0000I_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo000Iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0001Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0006Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0^ooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`;o0000
3_ooool2o`000003ooooool0003ooooo06Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0^ooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo0_l0
001Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;_ooool001Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0;_ooool001[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001[ooooo00Go0000oooooooooooooooo
o`000023ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001[ooooo00Go
0000ooooooooooooooooo`000023ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
;_ooool001[ooooo00Go0000ooooooooooooooooo`000023ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;_ooool001[ooooo00Go0000ooooooooooooooooo`000023ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool2o`0007Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0^ooooo`006_ooool01Ol0003ooooooooooooooooo000008?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`006_ooool01Ol0003ooooooooo
oooooooo000008?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`006_oo
ool01Ol0003ooooooooooooooooo000008?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0_ooooo`006_ooool01Ol0003ooooooooooooooooo000008?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0_ooooo`006_ooool01Ol0003ooooooooooooooooo000008?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`006_ooool01?l0003ooooooooo
ool00024ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;oooool001[ooooo00Co
0000oooooooooooo0000Q?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo
000Kooooo`03o`000?oooooo000008Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`;o0000NOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo000K
ooooo`03o`000?oooooo000008Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_
ooooo`006oooool00ol0003oooooo`000024ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;oooool001_ooooo0_l00025ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;oooool001cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02oooooo002Sooooo`05o`000?ooooooooooooooool000001?ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02oooooo002Sooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0_ooooo`00Xoooool01Ol0003ooooooooooooooooo000000;ooooo1Ol00006ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`00Xooo
ool01Ol0003ooooooooooooooooo000000;ooooo00CoA4A4omgMgOoooooo00001oooool3o`0007Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`00Xoooool01?l0003ooooo
ooooool00003ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0NOooool01Ol0
003ooooooooooooooooo000003;ooooo002Sooooo`04o`000?ooooooooooo`0000Cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`1iooooo`05o`000?ooooooooooooooool00000<_oo
ool00:?ooooo00Co0000oooooooooooo00001?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo07Wooooo00Go0000ooooooooooooooooo`00000booooo`00Y?ooool00ol0003oooooo`00
0005ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0NOooool01Ol0003ooooooooo
oooooooo000003;ooooo002Tooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0NOoo
ool01Ol0003ooooooooooooooooo000003;ooooo002Tooooo`03o`000?oooooo000000kooooo00?o
0000ooooooooool0NOooool01Ol0003ooooooooooooooooo000003;ooooo002Tooooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool0NOooool01Ol0003ooooooooooooooooo000003;ooooo
002Tooooo`03o`000?oooooo000000kooooo0_l0001jooooo`05o`000?ooooooooooooooool00000
<_ooool00:Cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`1jooooo`04o`000?oo
ooooooooo`0003;ooooo002Tooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0N_oo
ool01?l0003oooooooooool0000booooo`00YOooool2o`0000kooooo00?o0000ooooooooool0N_oo
ool01?l0003oooooooooool0000booooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo07[ooooo00Co0000oooooooooooo0000<_ooool00;Gooooo00?o0000ooooooooool0N_oo
ool01?l0003oooooooooool0000booooo`00]Oooool00ol0003oooooooooo`1jooooo`04o`000?oo
ooooooooo`0003;ooooo002eooooo`03o`000?oooooooooo07[ooooo00Co0000oooooooooooo0000
<_ooool00;Gooooo0_l0001kooooo`04o`000?ooooooooooo`0003;ooooo002eooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooool00000<oooool00;Gooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooo`00000cooooo`00]Oooool00ol0003oooooooooo`1kooooo`;o0000<oooool00;Go
oooo00?o0000ooooooooool0Noooool2o`0003?ooooo002eooooo`03o`000?oooooooooo07_ooooo
0_l0000cooooo`00]Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03;ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zooo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo
002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zj
oa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@
413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool0
0:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000Co410@oooooooo
oooooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^N?ooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj
^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4
ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0
003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06
o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko
0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21919 m
.00942 .28862 L
.0122 .31042 L
.01483 .32913 L
.01739 .34404 L
.01851 .34922 L
.01975 .35382 L
.02096 .35711 L
.02225 .35923 L
.02292 .35978 L
.02364 .35993 L
.02496 .35906 L
.02567 .358 L
.02645 .35637 L
.02786 .35225 L
.02924 .34691 L
.03053 .34093 L
.04057 .27835 L
.04334 .26189 L
.04635 .24664 L
.049 .2357 L
.0518 .22666 L
.05433 .2205 L
.05567 .21794 L
.0571 .21569 L
.05842 .21405 L
.05962 .21289 L
.06083 .21204 L
.06198 .2115 L
.06329 .21121 L
.06403 .21118 L
.06473 .21125 L
.06547 .21141 L
.06614 .21164 L
.06688 .21197 L
.06766 .21241 L
.07017 .21436 L
.07291 .21724 L
.08481 .23393 L
.08989 .24157 L
.09257 .24523 L
.0954 .24857 L
.09788 .25095 L
.1006 .25296 L
.1018 .25365 L
.10308 .25427 L
.10428 .25475 L
.1054 .2551 L
.10618 .25529 L
.10688 .25543 L
Mistroke
.10766 .25555 L
.10849 .25564 L
.10922 .25567 L
.11 .25567 L
.11074 .25563 L
.11142 .25556 L
.1127 .25534 L
.11342 .25517 L
.1141 .25498 L
.11693 .25387 L
.11957 .25246 L
.12198 .25099 L
.1274 .24748 L
.14917 .23346 L
.15874 .22819 L
.16382 .22561 L
.16929 .22352 L
.17456 .22207 L
.17938 .22098 L
.18177 .22053 L
.18399 .22022 L
.18631 .21998 L
.18884 .21978 L
.19015 .21969 L
.19155 .21957 L
.19279 .21945 L
.19411 .21928 L
.19659 .21883 L
.19888 .21827 L
.20399 .21657 L
.20959 .21411 L
.252 .19064 L
.26147 .18883 L
.26626 .18761 L
.26899 .18673 L
.27155 .18566 L
.27432 .18416 L
.27686 .18243 L
.28259 .17743 L
.29282 .1661 L
.30367 .15176 L
.3151 .13809 L
.32531 .12787 L
.33622 .12018 L
.34179 .11699 L
.34706 .11477 L
.35219 .11317 L
.35692 .11181 L
.36141 .11069 L
.36367 .11029 L
Mistroke
.36496 .11012 L
.36617 .10999 L
.36746 .10989 L
.36869 .10982 L
.371 .1097 L
.3762 .1094 L
.37751 .10931 L
.37819 .10927 L
.37892 .10923 L
.38026 .10919 L
.38148 .10917 L
.38267 .10919 L
.38377 .10925 L
.38498 .10934 L
.38627 .10949 L
.39179 .11033 L
.3945 .11076 L
.39701 .11116 L
.39936 .11161 L
.40185 .1123 L
.40314 .11277 L
.40435 .11329 L
.40711 .11478 L
.41155 .11799 L
.41632 .12276 L
.41884 .12625 L
.42153 .13122 L
.42407 .13748 L
.42638 .14481 L
.4291 .15578 L
.43204 .17105 L
.43738 .21038 L
.44793 .34011 L
.45083 .37898 L
.45242 .39772 L
.45393 .41271 L
.45533 .42354 L
.45613 .42818 L
.45686 .43145 L
.45816 .4347 L
.45954 .43453 L
.46023 .43304 L
.46096 .43049 L
.46226 .4235 L
.46298 .41835 L
.46366 .4128 L
.46519 .39784 L
.4705 .33058 L
.4756 .26535 L
.48042 .21823 L
Mistroke
.4831 .19914 L
.48601 .18336 L
.48866 .17277 L
.4911 .16566 L
.49246 .16267 L
.49374 .16046 L
.49514 .15864 L
.49593 .15787 L
.49665 .15732 L
.49739 .15689 L
.49809 .15662 L
.49885 .15645 L
.49966 .15641 L
.50043 .1565 L
.50116 .15669 L
.50252 .15729 L
.50374 .15808 L
.50505 .15916 L
.50741 .16167 L
.51021 .16557 L
.51277 .17001 L
.51833 .18271 L
.5236 .19834 L
.53281 .23181 L
.53806 .25274 L
.54299 .27131 L
.54536 .27907 L
.54786 .28598 L
.54917 .28899 L
.55061 .29178 L
.5519 .29381 L
.55312 .29531 L
.5538 .29596 L
.55453 .29652 L
.55582 .29714 L
.55654 .29728 L
.55731 .29728 L
.5587 .29689 L
.55997 .2961 L
.56117 .29501 L
.56248 .29344 L
.56389 .29136 L
.56907 .28103 L
.57399 .26926 L
.58322 .24906 L
.58852 .24038 L
.59331 .23463 L
.59597 .23235 L
.59737 .2314 L
.59884 .23059 L
Mistroke
.60014 .23002 L
.60156 .22955 L
.60285 .22923 L
.60405 .22904 L
.60525 .22892 L
.60656 .22888 L
.60779 .22891 L
.60893 .22901 L
.60996 .22914 L
.61109 .22933 L
.61338 .22988 L
.61586 .23068 L
.61853 .23174 L
.62337 .23387 L
.62589 .23491 L
.62859 .23583 L
.6299 .23619 L
.63113 .23647 L
.63224 .23667 L
.63344 .23684 L
.63476 .23696 L
.63552 .23699 L
.63622 .237 L
.63696 .23699 L
.63764 .23696 L
.63842 .23691 L
.63917 .23683 L
.64048 .23663 L
.64169 .23638 L
.64302 .23602 L
.64444 .23555 L
.64705 .23442 L
.64987 .23289 L
.65497 .22958 L
.661 .22562 L
.66661 .22241 L
.67145 .22011 L
.67394 .21917 L
.67663 .21837 L
.67817 .21801 L
.67959 .21774 L
.68238 .21732 L
.68508 .21698 L
.68761 .21663 L
.69273 .21562 L
.69544 .21489 L
.69836 .21396 L
.70141 .21278 L
.70431 .21141 L
.70976 .20807 L
Mistroke
.74987 .18818 L
.75498 .18716 L
.75767 .18652 L
.76051 .18572 L
.763 .18482 L
.76573 .18354 L
.76821 .18202 L
.77053 .1803 L
.78208 .16877 L
.79255 .15535 L
.80204 .14335 L
.81213 .13223 L
.82319 .12322 L
.82811 .12015 L
.83341 .11708 L
.83627 .11577 L
.83889 .11486 L
.84139 .11422 L
.84402 .11365 L
.84695 .11301 L
.85008 .11228 L
.8516 .11196 L
.85235 .11183 L
.85304 .11173 L
.85433 .1116 L
.855 .11157 L
.85572 .11157 L
.85692 .11163 L
.85821 .11181 L
.85942 .11207 L
.86053 .11239 L
.86324 .11339 L
.86581 .1146 L
.86856 .11623 L
.8711 .11835 L
.87256 .12002 L
.87388 .12191 L
.87542 .12464 L
.87685 .12781 L
.8793 .13484 L
.88199 .14518 L
.88461 .1584 L
.88741 .17685 L
.89002 .19925 L
.89249 .22623 L
.89711 .29377 L
.9022 .38536 L
.90498 .43234 L
.90635 .45159 L
.90759 .46608 L
Mistroke
.90895 .47778 L
.9097 .48224 L
.91041 .48507 L
.91118 .48656 L
.91189 .48646 L
.91268 .4847 L
.91351 .48095 L
.91422 .47632 L
.91499 .46987 L
.91638 .45469 L
.91898 .41661 L
.9242 .32344 L
.92708 .27524 L
.9298 .23674 L
.93233 .20805 L
.93508 .18384 L
.93758 .16697 L
.9399 .15475 L
.94233 .1448 L
.94501 .13669 L
.94636 .13363 L
.94781 .13101 L
.94918 .12913 L
.95044 .12783 L
.95111 .12728 L
.95183 .12679 L
.95313 .12613 L
.95392 .12584 L
.95467 .12563 L
.95534 .12549 L
.95607 .12537 L
.95679 .1253 L
.95757 .12525 L
.95839 .12523 L
.95916 .12524 L
.96054 .12535 L
.96131 .12546 L
.96201 .12559 L
.96325 .12592 L
.96441 .12635 L
.96545 .12684 L
.96658 .1275 L
.96911 .12949 L
.97144 .13187 L
.97596 .13769 L
.98018 .14437 L
.98478 .15401 L
.98721 .16068 L
.98982 .16932 L
.99515 .1921 L
Mistroke
1 .21919 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool008Oooooo3ol0000Hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0K?ooool4o`00043ooooo0024ooooo`?o00003oooool3o`00017ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Wooooo0ol00004ooooo`;o0000
?_ooool008;ooooo0_l0000Eooooo`03o`000?oooooooooo00kooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo06Kooooo0ol00009ooooo`;o0000??ooool0083ooooo0_l0
000Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03[ooooo001nooooo`;o00006_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo06?ooooo0_l0000?ooooo`03o`000?oooooooooo03Wooooo001moooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool6o`0001kooooo001mooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool05oooool2o`0006;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Cooooo`;o00001Oooool00ol0003oooooooooo`0Kooooo`00
O?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`00Noooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`00N_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`00NOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`00N?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Gooooo`00Moooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`00M_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Fooooo`00M_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Cooooo0_l0001K
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Kooooo001eooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04_ooool4o`0005_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool007Cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Booooo`05o`000?oooooo0000ooooool00000FOooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Eooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
01Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2?ooool00ol0003ooooo
ooooo`0@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07?ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool04_ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00cooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0@ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01?ooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL03_ooool00ol0003oooooooooo`0=ooooo`;o
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool03Oooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool@41000_ooool00ol0003o410@ooooo`0=ooooo`03o`000?oooooooooo00[ooooo1Ol0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo01Sooooo00?oZJVYoa0@4?ooool00_ooool00ol0003oooooooooo`02o`00
00kooooo00?o0000ooooooooool02_ooool00om4A4CogMgMooooo`02o`0000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000
7_ooool00omgMgOoIVIVooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`00000Loooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06?ooool00ol@413o
0000okZj^P03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`0;ooooo`03
omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03
ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo
00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413o0000ooooo`0Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool2o`0000?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool000007?ooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41003Oooool00ol0003oooooooooo`0<
ooooo`05ogMgMoo<c<co0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@00kooooo
000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`03ogMgMonHV9Sooooo00;o00007_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01?mgMgOoV9RHoooooonHV9P2o`0001[ooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9Soooooo`000?mgMgL03Oooool00ol0003oooooooooo`0<ooooo`05onk^k_m4
A4Co0000ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`?o000000?o<S8bonk^k_ooool06oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool5o`00
01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000o`000?o^k^h03Ooo
ool00ol0003oooooooooo`0=ooooo`04ogMgMol0003oooooo`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`00IOooool5o`0003Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool2o`0002cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
001Sooooo`;o0000>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`;o0000;_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool006;ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`10ooooo`;o0000<?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool0063ooooo0_l0000noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03kooooo0_l0000booooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`00G_ooool2o`00043ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool2o`0003Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o00000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Xooooo`;o0000
0_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<_ooool3o`0003gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo000Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool4o`0004Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;?ooool5o`00043ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`Oo0000COooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Zooooo`;o0000AOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo0_l0001Dooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Sooooo0_l00017ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool001Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Go
oooo1?l0001Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Kooooo0_l00019ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool09oooool001Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Booooo`Oo00002oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool09oooool001Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo0_l0001Kooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`05ooooo`;o00001oooool2o`0004cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Wooooo`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02?ooool7o`0004kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0W
ooooo`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool2o`0005oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool001Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Wooooo`005oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Oooooo000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09ooo
ool001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`;o00001Oooool2
o`0006Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09oooool001Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`Ko0000I_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`006?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`05ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`006?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool001Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo000H
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0X
ooooo`006?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:?ooool001Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1looooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Sooooo000Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Xooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:?ooool001Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2
o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:?ooool001Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo000Iooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`006Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00001Yooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool001Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0>ooooo`?o0000J_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Sooooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`04ooooo`Go00001_ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
00Cooooo00GoV9RHob4Q8Ol0003oooooodA4A006ooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool01Oooool00onHV9So0000onk^kP07oooo
o`?o0000Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`06ooooo`03
o`000?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Wooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`06ooooo`03o`000?mgMgOoIVIV00Kooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo000Jooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Wooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`03ooooo`;o000000?ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool001[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00?ooooo00GoV9RH
o`000?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Yooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`006_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Yooooo`006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`;o0000OOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo
000Kooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Wooooo000Kooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo000Kooooo`05o`000?ooooooooooooooool00000
Q?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
O?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Looooo`04o`000?oo
ooooooooo`0008Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`007?oo
ool01?l0003oooooooooool00024ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
:_ooool001cooooo00?o0000ooooool00000QOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02[ooooo000Mooooo`;o0000QOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02[ooooo002Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool2o`00
07gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`00YOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02[ooooo002Uooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:_ooool00:Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Zooooo`00YOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0OOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo002Uoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00:Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Zooooo`00YOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02[ooooo002Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool2o`0007kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02[ooooo002Vooooo`05o`000?ooooooooooooooool000002_oo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_oo
ool00:Kooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo07gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02_ooooo002Vooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0[ooooo`00Y_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0OOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo
002Vooooo`03o`000?oooooooooo00Ko00001_ooool00ol0003oooooooooo`1nooooo`05o`000?oo
ooooooooooooool00000;Oooool00:Kooooo00So0000oooooooooooo0000odA4A?oMgMgoooooo`00
00Oooooo0ol0001nooooo`05o`000?ooooooooooooooool00000;Oooool00:Kooooo00So0000oooo
oooooooo0000omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0O_ooool01Ol0003ooooo
oooooooooooo000002gooooo002Vooooo`08o`000?ooooooooooo`000?ooooooMgMgolc<c?l00007
ooooo`03o`000?oooooooooo07kooooo00Go0000ooooooooooooooooo`00000]ooooo`00Yoooool0
1ol0003oooooo`000?ooooook^k^odA4A?l000001oooool00ol0003oooooooooo`1nooooo`05o`00
0?ooooooooooooooool00000;Oooool00:Oooooo00?o0000ooooool000000_ooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo07kooooo00Go0000ooooooooooooooooo`00000]ooooo`00
Yoooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo07kooooo00Go0000oooooooooooo
ooooo`00000]ooooo`00Yoooool2o`0000cooooo00?o0000ooooooooool0O_ooool01Ol0003ooooo
oooooooooooo000002gooooo002Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
O_ooool01Ol0003ooooooooooooooooo000002gooooo002eooooo`;o0000Ooooool01?l0003ooooo
ooooool0000^ooooo`00]Oooool00ol0003oooooooooo`1nooooo`04o`000?ooooooooooo`0002ko
oooo002eooooo`03o`000?oooooooooo07kooooo00Co0000oooooooooooo0000;_ooool00;Gooooo
00?o0000ooooooooool0O_ooool01?l0003oooooooooool0000^ooooo`00]Oooool00ol0003ooooo
ooooo`1nooooo`04o`000?ooooooooooo`0002kooooo002eooooo`03o`000?oooooooooo07kooooo
00Co0000oooooooooooo0000;_ooool00;Gooooo00?o0000ooooooooool0O_ooool01?l0003ooooo
ooooool0000^ooooo`00]Oooool00ol0003oooooooooo`1nooooo`04o`000?ooooooooooo`0002ko
oooo002eooooo`;o0000P?ooool00ol0003oooooo`00000^ooooo`00]Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooo000002kooooo002eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooool00000;_ooool00;Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooo`00000^oooo
o`00]Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo000002kooooo002eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooool00000;_ooool00;Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooo`00000^ooooo`00]Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo02gooooo002eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0;Oooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000
/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooo
oonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2f
ooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410H
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001?l@413o
ooooooooooooool4o`000003oa0@4?oooooooooo00Go0000N?ooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^07Wooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03oiRHV?lQ8B7ok^k^07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
ogMgMomVIVKooooo07Oooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003
o`0001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo07Kooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@07So
oooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l0
00001Oooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(114) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20899 m
.00942 .24451 L
.01975 .28871 L
.02496 .30738 L
.02646 .31165 L
.02787 .31508 L
.02916 .31764 L
.03053 .31973 L
.03172 .32102 L
.03303 .32186 L
.03422 .32208 L
.03534 .32185 L
.03666 .32104 L
.03786 .31984 L
.03925 .31794 L
.04057 .31568 L
.05167 .28672 L
.05777 .26972 L
.06351 .25686 L
.06888 .24838 L
.0719 .24497 L
.07468 .24261 L
.07703 .2412 L
.07836 .24064 L
.07961 .24026 L
.08092 .24002 L
.08212 .23994 L
.0835 .24 L
.08481 .2402 L
.08599 .24048 L
.08711 .24083 L
.08965 .24188 L
.09479 .24475 L
.10402 .25101 L
.10657 .25255 L
.10797 .25327 L
.10926 .25383 L
.11047 .25426 L
.11156 .25456 L
.11277 .25478 L
.11407 .25491 L
.11475 .25492 L
.11546 .25489 L
.11675 .25476 L
.11813 .25449 L
.11891 .25428 L
.11965 .25405 L
.12219 .253 L
.12491 .2515 L
.13555 .24334 L
Mistroke
.14117 .23934 L
.1443 .23774 L
.14578 .23715 L
.14714 .23671 L
.14844 .23637 L
.14986 .23608 L
.15128 .23586 L
.15206 .23578 L
.15279 .23571 L
.15413 .23564 L
.15535 .23562 L
.15603 .23563 L
.15676 .23564 L
.1581 .23571 L
.16062 .23589 L
.16195 .236 L
.16267 .23605 L
.16334 .2361 L
.16456 .23616 L
.1659 .23618 L
.16704 .23615 L
.16825 .23605 L
.16953 .23586 L
.17092 .23556 L
.17223 .23516 L
.17344 .2347 L
.17573 .23358 L
.17815 .23207 L
.18335 .22786 L
.18906 .22213 L
.19498 .21582 L
.1979 .21301 L
.2006 .21076 L
.20299 .20913 L
.20564 .20774 L
.20701 .20719 L
.2083 .20678 L
.20966 .20645 L
.21043 .20631 L
.21113 .20621 L
.21232 .2061 L
.21359 .20607 L
.21479 .20611 L
.21588 .20621 L
.21717 .20639 L
.21856 .20666 L
.22109 .2073 L
.2235 .208 L
.22609 .2087 L
.22757 .20902 L
Mistroke
.22893 .20923 L
.23029 .20934 L
.23159 .20934 L
.23296 .20922 L
.23424 .20898 L
.23497 .20878 L
.23564 .20856 L
.23713 .20794 L
.23858 .20715 L
.24016 .20608 L
.243 .20358 L
.24567 .20054 L
.24849 .19664 L
.25354 .18812 L
.26426 .16703 L
.27441 .14807 L
.28352 .13458 L
.29343 .1241 L
.2986 .12011 L
.30408 .11693 L
.30876 .11483 L
.31393 .11297 L
.31659 .11222 L
.31939 .1116 L
.32245 .11108 L
.32526 .11072 L
.33034 .11023 L
.33174 .11013 L
.33322 .11003 L
.33394 .10999 L
.33462 .10996 L
.3359 .10991 L
.33711 .10989 L
.33841 .10989 L
.33964 .1099 L
.34076 .10993 L
.34208 .10998 L
.34351 .11005 L
.34611 .1102 L
.35135 .11052 L
.35423 .11074 L
.35693 .111 L
.36221 .11172 L
.36699 .1125 L
.37631 .11417 L
.38122 .11538 L
.3866 .11695 L
.39184 .1186 L
.39745 .12075 L
.40271 .12333 L
Mistroke
.4075 .12612 L
.41195 .12916 L
.41686 .13342 L
.42193 .13932 L
.42731 .14776 L
.43229 .15859 L
.43696 .17289 L
.43977 .18413 L
.44244 .197 L
.44747 .22779 L
.45287 .27126 L
.45877 .3269 L
.46145 .35124 L
.46435 .37361 L
.46568 .38178 L
.46708 .38861 L
.46828 .39282 L
.4696 .39561 L
.47088 .39642 L
.47205 .39552 L
.4734 .39261 L
.47468 .38808 L
.47586 .38253 L
.47695 .37633 L
.47942 .35932 L
.48489 .31434 L
.49078 .26889 L
.49349 .25198 L
.49634 .23732 L
.4988 .22717 L
.50144 .21867 L
.50398 .21254 L
.50628 .20852 L
.5074 .20705 L
.5086 .20577 L
.50974 .20484 L
.51079 .20422 L
.51202 .20376 L
.51316 .20356 L
.51441 .20358 L
.51576 .20388 L
.51644 .20413 L
.51717 .20448 L
.51851 .20529 L
.52103 .20744 L
.52388 .21077 L
.52646 .21456 L
.53225 .22532 L
.54266 .24964 L
.54779 .2615 L
Mistroke
.55059 .26716 L
.5532 .27164 L
.55544 .27474 L
.55783 .27722 L
.55919 .27822 L
.56048 .2789 L
.56164 .27929 L
.5629 .27947 L
.56425 .27939 L
.56552 .27908 L
.56625 .27881 L
.56691 .2785 L
.56841 .27761 L
.57126 .27531 L
.57426 .27227 L
.57977 .26612 L
.58477 .26095 L
.58994 .25667 L
.59481 .25374 L
.59996 .25154 L
.60553 .24945 L
.61557 .24454 L
.62482 .23883 L
.62974 .23603 L
.63245 .23477 L
.63379 .23426 L
.63502 .23386 L
.63616 .23356 L
.63741 .23329 L
.63867 .23309 L
.64001 .23296 L
.64113 .23291 L
.64235 .23291 L
.6435 .23296 L
.64456 .23303 L
.64582 .23316 L
.64716 .23334 L
.64959 .23371 L
.65224 .23414 L
.65363 .23435 L
.65511 .23455 L
.65585 .23462 L
.65667 .23469 L
.65741 .23474 L
.65811 .23476 L
.65947 .23475 L
.66024 .2347 L
.66094 .23463 L
.66224 .23443 L
.66297 .23427 L
Mistroke
.66366 .23409 L
.66624 .23314 L
.66759 .23246 L
.66902 .23161 L
.67157 .22977 L
.67734 .22448 L
.68779 .21344 L
.69229 .20941 L
.69481 .20764 L
.69711 .20639 L
.69841 .20584 L
.69983 .20537 L
.70116 .20505 L
.7024 .20485 L
.70354 .20474 L
.70479 .2047 L
.7061 .20474 L
.70733 .20484 L
.71268 .20589 L
.71766 .20721 L
.71895 .2075 L
.72017 .20771 L
.72085 .2078 L
.72158 .20788 L
.72285 .20792 L
.72354 .2079 L
.72429 .20785 L
.72507 .20774 L
.72581 .20759 L
.72712 .20721 L
.72853 .20664 L
.72982 .20596 L
.73102 .20519 L
.73374 .20296 L
.73869 .19725 L
.74318 .19037 L
.74796 .18167 L
.75819 .16169 L
.76898 .14302 L
.77463 .13514 L
.78082 .12827 L
.78651 .12318 L
.79169 .11941 L
.7971 .11645 L
.80222 .11435 L
.80808 .11236 L
.81065 .11163 L
.81349 .111 L
.81593 .11059 L
.81822 .11031 L
Mistroke
.82324 .10981 L
.82585 .10957 L
.82833 .10936 L
.8297 .10927 L
.83048 .10923 L
.8312 .1092 L
.83247 .10918 L
.83382 .1092 L
.83512 .10924 L
.83586 .10928 L
.83655 .10932 L
.83944 .10954 L
.84461 .10993 L
.8475 .11013 L
.84892 .11025 L
.85024 .1104 L
.85175 .1106 L
.8534 .11089 L
.85628 .11154 L
.86654 .11437 L
.86904 .11522 L
.87173 .1164 L
.87468 .11813 L
.87745 .12018 L
.87997 .12238 L
.88265 .12513 L
.88497 .12795 L
.88749 .13176 L
.89045 .13771 L
.89325 .14535 L
.89597 .15518 L
.89848 .16676 L
.9036 .19987 L
.90651 .22611 L
.90923 .2566 L
.91468 .33352 L
.91756 .37785 L
.92063 .42064 L
.92216 .438 L
.9236 .45087 L
.92489 .45905 L
.92562 .46213 L
.92629 .46395 L
.92751 .4647 L
.92884 .46176 L
.92952 .45881 L
.93024 .45462 L
.93154 .44451 L
.93288 .43114 L
.93433 .41375 L
Mistroke
.93696 .37712 L
.94191 .30511 L
.94681 .24665 L
.94929 .22443 L
.95202 .20513 L
.95434 .19235 L
.95684 .18169 L
.9592 .17415 L
.96137 .16909 L
.96261 .1669 L
.96379 .16526 L
.96485 .16412 L
.96599 .1632 L
.96724 .16252 L
.96856 .16213 L
.96969 .16201 L
.97093 .16208 L
.97209 .16231 L
.97315 .16264 L
.97437 .16315 L
.97553 .16377 L
.97758 .16517 L
.97982 .16717 L
.98249 .17026 L
.9849 .17376 L
.9903 .1838 L
1 .20899 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool007[ooooo4Ol0000Sooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0H?oooolAo`0003oooooo001gooooo`Co00004?ooool6o`0001Wooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05cooooo1?l0000Aooooo`;o0000
?Oooool007Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Gooooo
0_l0000kooooo`00M?ooool2o`0001cooooo1?l0000Oooooo`03o`000?oooooooooo05Wooooo0_l0
000Jooooo`03o`000?oooooooooo03Sooooo001cooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0=oooool007?ooooo00?o0000ooooooooool08Oooool2o`0001cooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Kooooo001booooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool06Oooool2o`0005Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0fooooo`00LOooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo03Gooooo001`ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=Ooo
ool0073ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0dooooo`00Koooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03Cooooo001^ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0<oooool006gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0cooooo`00KOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03;ooooo001/
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool2o`0005;ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0booooo`00K?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo03;ooooo001[ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool05?ooool2o`0001cooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Kooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^01cooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`02o`000004ooooool0003o0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01Ol0003oV9RHoooooonHV9SoMgMg01kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo0000oooooonHV9SoMgMg01_ooooo
00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooo
oooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4009ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?l0003oooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00Co
410@oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00003ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool01?m4A4CogMgMo`000?l00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001ko
oooo00CoMgMgofIVI_oooooooooo0_l00003ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00oooool01?oMgMgoEEEEo`000?l00004ooooo`05o`000?oooooooooo
ooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go
0000ooooool0003ooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool04?ooool2o`0002;o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooo
ooooooooooooo`000003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`05ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`06o`000?nj^[[ooooo
oiRHV?l@413o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Joooo
o`05o`000?nj^[[ooooooiRHV?l@41000_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgMa_ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00Cok^k^odA4A?l0003o00000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01_ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l00002ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00goV9RHoa0@4?l0003o8B4Qolc<c?oooooo
0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?oMgMgo`000?l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo001V
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01?ooooo001Vooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo001Uooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01?ooooo001Uooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`18ooooo`;o0000<oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04_ooool006Cooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_oo
ool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool4o`0000;ooooo2?l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`03ooooo`Go00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool2o`0000Go
oooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0kooooo`;o0000C_ooool00ol0003o
ooooooooo`0>ooooo`;o00001_ooool00ol0003oooooooooo`0`ooooo`;o0000A?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo023ooooo000Gooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Qooooo`005oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool03Oooool2o`0000Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool001Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00gooooo0_l00009oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo027ooooo000Hooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool00ol0003oooooooooo`0Xooooo`;o
0000BOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo000Hooooo`03o`00
0?oooooooooo03;ooooo0_l0001Eooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`03o`00
0?oooooooooo01cooooo3?l0001;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8Oooool001Sooooo00?o0000ooooooooool0:Oooool:o`0005Kooooo00?o0000ooooooooool03Ooo
ool2o`0000[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08_ooool001Sooooo00?o0000ooooooooool05?ooool3
o`00013ooooo0_l0001Qooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`03o`000?oooooo
oooo01Sooooo0_l0001Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool0
01Wooooo00?o0000ooooooooool04Oooool2o`0000?ooooo0_l0000<ooooo`;o0000Hoooool00ol0
003oooooooooo`0<ooooo`;o00002oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`006Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo01Co
oooo0ol0001Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool001Wooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool04Oooool2o`0005oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Rooooo`006Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo0_l0
0004ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00
000<ooooo`03o`000?oooooooooo00oooooo0_l0001Qooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool001[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`Go0000J?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000gooooo00?o0000
ooooooooool03?ooool2o`0006?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0R
ooooo`006_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool02oooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo000Joooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02?ooool2o`0006Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`006_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02;ooooo000Jooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08_ooool001_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0R
ooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool02Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo000Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`00017ooooo0_l000000ooooooo0000o`00001/ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08oooool001_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00004_ooool3
o`0006gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`006oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooooooool2o`00087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0S
ooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000008;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Sooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000008;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Sooooo`007?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000008;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000008;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0S
ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000008;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Sooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool01Ol00002ooooo`05o`000?ooooooooooooooool00000P_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0P?ooool02_l0003ooooooooooonHV9So8B4Qonk^k_ooooooA4A4
ooooool00004ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo
00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00;ooooo00?o0000ooooooooool00_ooool3o`00
083ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool00_ooool01OnHV9So
8B4Qonk^k_oooooo000000Cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02?ooooo000Oooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0
003oooooooooo`02ooooo`04ogMgMomVIVKoooooo`0000Cooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo000Oooooo`04o`000?oooooooooo
o`0008Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`007oooool4o`00
08Gooooo00Wo0000ooooool0003o^[ZjoooooonHV9So410@ooooool000001?ooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00:Sooooo00Wo
0000oooooonHV9So410@o`000?lQ8B7oc<c<ooooool000001?ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00:Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Tooooo`00Z?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Cooooo002Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool2o`0008;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`00Z?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo002Xooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09?ooool00:Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Tooooo`00ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo
002Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00:Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`00ZOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Cooooo002Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09?ooool00:Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`;o0000
Poooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo002Zooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09Oooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`00Z_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Gooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9Oooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Gooooo002Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo002Zooooo`04o`000?oo
ooooooooo`0000Oooooo0_l00023ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9Oooool00:[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00:_ooooo0_l00008ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`00Zoooool2
o`0000Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Kooooo002eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Vooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0Poooool01Ol0003ooooooooooooooooo000002Sooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Poooool01Ol0003ooooooooooooooooo000002Sooooo002Zooooo`Go
00001_ooool00ol0003oooooooooo`23ooooo`05o`000?ooooooooooooooool00000:?ooool00:[o
oooo00CoA4A4omgMgOoooooo00001oooool3o`0008?ooooo00Go0000ooooooooooooooooo`00000X
ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo08?ooooo00Go0000
ooooooooooooooooo`00000Xooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo08?ooooo00Go0000ooooooooooooooooo`00000Xooooo`00Zoooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00000Xooooo`00[?ooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00
000Xooooo`00]Oooool00ol0003oooooooooo`23ooooo`05o`000?ooooooooooooooool00000:?oo
ool00;Gooooo00?o0000ooooooooool0Poooool01Ol0003ooooooooooooooooo000002Sooooo002e
ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00000Xooooo`00]Oooool2
o`0008Cooooo00Go0000ooooooooooooooooo`00000Xooooo`00]Oooool00ol0003oooooooooo`23
ooooo`04o`000?ooooooooooo`0002Wooooo002eooooo`03o`000?oooooooooo08?ooooo00Co0000
oooooooooooo0000:Oooool00;Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooo`00000Y
ooooo`00]Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooo000002Wooooo002eooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooool00000:Oooool00;Gooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooo`00000Yooooo`00]Oooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooo000002Wooooo002eooooo`;o0000QOooool2o`0002[ooooo002eooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool0:?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`00
0?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zoooo
o`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2i
ooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo
0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b
<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001?l@413oooooooooooooool4o`000003oa0@
4?oooooooooo00;ooooo0_l000000ol@413oooooooooo`1fooooo`00POooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1gooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`Go0000N?ooool0
087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo
0000NOooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo0000
NOooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l00000NOooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000007Wooooo0020ooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`00
0006ooooo`03ogMgMol0003ooooo07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(116) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20641 m
.00236 .20856 L
.00488 .21155 L
.00942 .21872 L
.01483 .23011 L
.01975 .24299 L
.03057 .27599 L
.03533 .28878 L
.03803 .29453 L
.04057 .29861 L
.0419 .30021 L
.04312 .30133 L
.04379 .30181 L
.04452 .30221 L
.04586 .30264 L
.0466 .30271 L
.04727 .30267 L
.04804 .30252 L
.04877 .30227 L
.05007 .30157 L
.0508 .30105 L
.05147 .30049 L
.05422 .2976 L
.05723 .29359 L
.06331 .28494 L
.06868 .27869 L
.07168 .27611 L
.07443 .27432 L
.07698 .27304 L
.07976 .27196 L
.08481 .27025 L
.08726 .26926 L
.0899 .2679 L
.09468 .26442 L
.10036 .25879 L
.10557 .25313 L
.1107 .24826 L
.11211 .2472 L
.11361 .24624 L
.11503 .24551 L
.11632 .24503 L
.11702 .24483 L
.11777 .24468 L
.11911 .24457 L
.11985 .24458 L
.12055 .24466 L
.12132 .24479 L
.12214 .24501 L
.12284 .24525 L
.12361 .24556 L
Mistroke
.12501 .24628 L
.12763 .24804 L
.13276 .25243 L
.13545 .2548 L
.13829 .25695 L
.1395 .25769 L
.14079 .25833 L
.14153 .25861 L
.1422 .25882 L
.14352 .25905 L
.14471 .25907 L
.14599 .25885 L
.14721 .25842 L
.14833 .25783 L
.1497 .25684 L
.151 .25566 L
.15394 .25211 L
.15989 .24225 L
.1649 .23298 L
.16754 .2284 L
.17036 .22409 L
.17318 .22065 L
.1745 .21937 L
.17573 .21842 L
.17696 .21768 L
.17829 .21713 L
.17947 .21688 L
.18071 .21685 L
.18201 .21706 L
.18339 .21756 L
.1847 .21828 L
.1859 .21913 L
.18882 .2219 L
.1916 .2252 L
.19611 .23116 L
.19858 .23427 L
.2009 .23675 L
.20221 .23787 L
.2034 .23868 L
.20473 .23931 L
.20543 .23952 L
.20617 .23963 L
.20737 .23958 L
.20849 .23926 L
.20972 .2386 L
.21104 .23752 L
.21233 .23608 L
.21375 .23408 L
.21662 .22877 L
.22178 .21573 L
Mistroke
.23343 .17913 L
.23909 .16263 L
.24447 .14942 L
.24971 .13907 L
.25458 .13149 L
.2593 .12578 L
.26433 .12118 L
.26991 .11747 L
.27497 .11505 L
.2778 .11403 L
.2804 .11326 L
.2832 .1126 L
.28627 .11204 L
.28894 .11166 L
.29144 .11138 L
.29408 .11117 L
.29555 .11108 L
.2969 .11102 L
.29814 .11099 L
.2993 .11097 L
.30058 .11096 L
.30195 .11097 L
.30332 .11099 L
.304 .11101 L
.30475 .11103 L
.30732 .11113 L
.30973 .11126 L
.31231 .11143 L
.31696 .11182 L
.32283 .11251 L
.32838 .11332 L
.33876 .1152 L
.34898 .11769 L
.35979 .1211 L
.36902 .12484 L
.37917 .12987 L
.40132 .1438 L
.42155 .15749 L
.43156 .16505 L
.43723 .17065 L
.44248 .17766 L
.44753 .18699 L
.4521 .19861 L
.45737 .21702 L
.46233 .24012 L
.47262 .30339 L
.47534 .32081 L
.47824 .3377 L
.48098 .3507 L
.48228 .35554 L
Mistroke
.48347 .35913 L
.48458 .36166 L
.48576 .36347 L
.48694 .36438 L
.48824 .36432 L
.48935 .36339 L
.49056 .36153 L
.4917 .35902 L
.49274 .35612 L
.49522 .34724 L
.49794 .33525 L
.50289 .31099 L
.50846 .28579 L
.5112 .27559 L
.51371 .26767 L
.51843 .2565 L
.52091 .25231 L
.52353 .24893 L
.52615 .24643 L
.5276 .24536 L
.52896 .24452 L
.53023 .24387 L
.53161 .24328 L
.53286 .24286 L
.53403 .24254 L
.53541 .24226 L
.53614 .24215 L
.53693 .24207 L
.53771 .24201 L
.53854 .24199 L
.53924 .242 L
.54001 .24204 L
.5414 .24218 L
.54218 .24231 L
.54288 .24245 L
.54426 .2428 L
.54555 .24323 L
.54806 .24435 L
.55041 .24575 L
.55299 .24771 L
.55575 .25031 L
.56656 .26402 L
.56904 .2673 L
.57175 .27052 L
.57414 .27287 L
.57545 .27392 L
.57668 .27472 L
.57789 .27533 L
.5792 .27576 L
.58039 .27594 L
Mistroke
.58148 .27593 L
.58251 .27576 L
.58364 .2754 L
.58483 .27483 L
.58593 .27413 L
.62682 .25361 L
.62812 .25437 L
.6295 .25509 L
.63082 .25564 L
.63202 .256 L
.63329 .25623 L
.63464 .25627 L
.63602 .25609 L
.6368 .25587 L
.63753 .2556 L
.63906 .2548 L
.64045 .2538 L
.64357 .25065 L
.64645 .24676 L
.64916 .24243 L
.65943 .22506 L
.66193 .22169 L
.66461 .21883 L
.66614 .21759 L
.66755 .21673 L
.66822 .21642 L
.66896 .21614 L
.6703 .21584 L
.67159 .21579 L
.67281 .21596 L
.67415 .21638 L
.6749 .21672 L
.67559 .21709 L
.67833 .21913 L
.68122 .22207 L
.68646 .22843 L
.68902 .23147 L
.69134 .23386 L
.69244 .23481 L
.69364 .23567 L
.69477 .2363 L
.69581 .23671 L
.69692 .23693 L
.69813 .23693 L
.6994 .23663 L
.70059 .23605 L
.7019 .23508 L
.70314 .23383 L
.70548 .23062 L
.70799 .226 L
Mistroke
.71073 .21974 L
.72226 .18594 L
.73312 .15561 L
.74287 .13623 L
.74836 .12852 L
.75341 .1231 L
.75834 .11911 L
.76294 .11631 L
.76799 .11398 L
.7734 .11219 L
.77611 .11154 L
.77907 .111 L
.78186 .11061 L
.78444 .11034 L
.78676 .11015 L
.78808 .11007 L
.78932 .11001 L
.79062 .10996 L
.79182 .10994 L
.79313 .10994 L
.79451 .10996 L
.7958 .11 L
.79654 .11003 L
.79721 .11006 L
.79976 .11022 L
.80453 .11066 L
.80974 .11128 L
.81524 .1122 L
.82443 .11426 L
.83453 .11703 L
.85495 .12427 L
.87689 .13382 L
.88754 .13972 L
.89355 .14416 L
.89913 .14985 L
.9019 .15344 L
.9045 .15746 L
.90936 .16738 L
.91209 .17492 L
.91459 .18349 L
.91755 .19604 L
.92024 .21015 L
.92519 .24405 L
.9305 .29295 L
.93546 .34714 L
.94005 .39412 L
.94265 .41408 L
.94396 .42134 L
.9447 .42451 L
.9454 .4268 L
Mistroke
.94615 .42852 L
.94686 .42943 L
.9482 .4292 L
.94895 .42799 L
.94964 .42618 L
.9504 .42347 L
.95121 .41978 L
.95258 .41184 L
.95406 .40112 L
.95675 .37749 L
.96177 .32755 L
.96604 .28847 L
.97062 .25558 L
.97325 .24119 L
.97565 .23063 L
.97793 .22262 L
.98035 .21599 L
.98286 .21092 L
.98518 .2076 L
.98647 .20626 L
.98768 .20528 L
.98901 .20448 L
.98975 .20415 L
.99044 .20392 L
.99159 .20367 L
.99266 .20359 L
.99384 .20365 L
.99509 .20388 L
.99642 .20431 L
.99766 .20489 L
1 .20641 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool0077ooooo2ol0000booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0DooooolAo`0004cooooo001]ooooo`Co00002oooool9o`0002Gooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
3oooool3o`0004Wooooo001[ooooo`;o00006?ooool3o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo053ooooo0_l0000Eooooo`?o0000A_ooool006[ooooo00?o
0000ooooooooool06oooool3o`0002[ooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Hooooo`?o0000@oooool006Wooooo00?o0000ooooooooool07oooool2o`0002Sooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Looooo`?o0000@?ooool006Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool08?ooool3o`0003gooooo001Xooooo`03o`000?oooooooooo02?ooooo0_l0000Uooooo`;o
0000COooool00ol0003oooooooooo`0Tooooo`;o0000>oooool006Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
9oooool2o`0003Wooooo001Vooooo`03o`000?oooooooooo02Sooooo0_l0000Rooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0fooooo`00IOooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Gooooo001Uooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0=?ooool006Cooooo00?o0000ooooooooool0;_ooool2o`0001ko
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0^ooooo`;o0000=?ooool006Cooooo
00?o0000ooooooooool0<?ooool2o`0001cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo037ooooo001Tooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0<Oooool006?ooooo00?o0000ooooooooool0=?ooool2o`0001Wooooo0_l00018
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<?ooool006?ooooo00?o0000oooo
ooooool0=_ooool2o`0001Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02oooooo001Sooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0;oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0J
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h8ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Eooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01Ol0003o8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So0000onk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`Ko000000Koooooo`000?ooooooV9RHob4Q8Oo^k^h4oooo
o`05oa0@4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03o`00
0?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo1Ol00003oooo
o`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000001[ooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001[ooooo00Go0000oooooonHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Booooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`00
0?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000006_ooool01_l0003oooooooooooooooooMgMgofIVIP?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000<ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooomgMgOoIVIV00?ooooo00Go0000
ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo01;ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
oooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400I
ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool03oooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001ooo
ool00ol0003oooooooooo`0Booooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Ioooo
o`07o`000?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01Wooooo0_l000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`03o`000?oooooooooo01;ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Sooooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<
c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04oooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool005oooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0/ooooo`00Goooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo02_ooooo001Nooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:oooool0
05kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0[ooooo`00G_ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo02_ooooo000Foooooooo0000@?l0000Cooooo`005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0Aooooo`005_ooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
017ooooo000Hooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo0_l0000<ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`006Oooool00ol0003ooooo
ooooo`0booooo`?o00002oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<Oooool5o`0000_ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Oooooo000Iooooo`03o`000?oooooooooo037ooooo00Co
0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`006Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo000Jooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06?ooool001[ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[o
oooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000015oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0004oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo1?l00016oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0:ooooo`?o0000D?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Wooooo000Looooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo1Ol0000Pooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`007?oo
ool00ol0003oooooooooo`0Jooooo`Go00002oooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0000Nooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`007?ooool0
0ol0003oooooooooo`0Iooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool2
o`0001cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool2o`00
00Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01[ooooo000Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool2o`0000;o
oooo1Ol0001Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool001gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`Co0000I?ooool00ol0003ooooo
ooooo`08ooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
0_l0001Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l0
001Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000
ooooooooool04_ooool2o`0007Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000oooo
ooooool04?ooool2o`0007Oooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
0000017ooooo00?o0000ooooooooool01Oooool2o`0006Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`0>ooooo`?o0000N?ooool00ol0
003oooooooooo`08ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`02
ooooo`;o0000J_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo000Ooooo
o`03o`000?oooooooooo00_ooooo0_l0001looooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00004oooool3o`000003ooooool0003ooooo06_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Kooooo`007oooool00ol0003oooooooooo`0:ooooo`;o0000OOooool00ol0
003oooooooooo`07ooooo`04o`000?ooooooooooo`0001Gooooo0_l0001]ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06oooool001oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000Q?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo000Pooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`00
0?ooool0Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo000Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooo`0008Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooool00025ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000QOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01cooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000008Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Looooo`008oooool01?l0003oooooooooool00025ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool00000Q_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo000Sooooo`Co0000Poooool5o`0000Kooooo00?o0000ooooool00000
Q_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo002Zooooo`05oiRHV?lQ
8B7o0000oooooom4A4@01_ooool00ol0003oooooo`000026ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07?ooool00:_ooooo00?oV9RHo`000?o^k^h01oooool3o`0008Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`00[?ooool00ol0003o8B4Qonk^kP06
ooooo`;o0000R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo002]oooo
o`03o`000?mVIVKooooo00Gooooo0_l00028ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07Oooool00:gooooo0_l00006ooooo`;o0000R?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01gooooo002Zooooo`05o`000?nj^[[oooooo`000?l@41001_ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00:[ooooo
00GoV9RHoa0@4?l0003o0000olc<c006ooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Mooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`00[_oo
ool00ol0003oooooooooo`03ooooo`;o0000ROooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01gooooo002^ooooo`03o`000?oooooooooo00?ooooo0ol00028ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07Oooool00:kooooo00?o0000ooooooooool00oooool2o`00
08[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`00[_ooool00ol0003o
ooooooooo`03ooooo`;o0000R_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01go
oooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000R_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01kooooo002_ooooo`07o`000?ooooooooooooooool0003o
ooooo`00002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00:oooooo
00Oo0000ooooooooooooooooo`000?oooooo000008[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Nooooo`00[oooool01ol0003ooooooooooooooooo0000ooooool00000R_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo002_ooooo`07o`000?oooooooooo
ooooool0003oooooo`00002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_oo
ool00;3ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07_ooool00;3ooooo0ol00002ooooo`;o0000ROooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo002aooooo`05o`000?oooooooooooooo
ool00000R_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo002eooooo`03
o`000?oooooooooo08Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`00
]Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7oooool00;Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01oooooo002eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Oooooo`00]Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool07oooool00;Gooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01oooooo002eooooo`;o0000R_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01oooooo002eooooo`03o`000?oooooooooo08Wooooo00Go
0000ooooooooooooooooo`00000Rooooo`00]Oooool00ol0003oooooooooo`29ooooo`05o`000?oo
ooooooooooooool000008_ooool00;Gooooo00?o0000ooooooooool0ROooool01Ol0003ooooooooo
oooooooo000002;ooooo002eooooo`03o`000?oooooooooo08Wooooo00Go0000oooooooooooooooo
o`00000Rooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0ROoo
ool01Ol0003ooooooooooooooooo000002;ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0R_ooool01?l0003oooooooooool0000Rooooo`00Z_ooool5o`0000Kooooo00?o
0000ooooooooool0R_ooool01?l0003oooooooooool0000Rooooo`00Z_ooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000R_ooool01?l0003oooooooooool0000Rooooo`00Z_ooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo08[ooooo00Co0000oooooooooooo00008_ooool00:_o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2:ooooo`04o`000?ooooooooooo`00
02;ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0R_ooool01?l0003o
ooooooooool0000Rooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooool000008oooool00;Gooooo00?o0000ooooooooool0Roooool2o`0002?ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Z
ooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00
002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_oooo
o`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6Oooool4o`000004oa0@4?ooooooooooooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
410@olc<c7Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6
o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co
0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRH
V?lQ8B40N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0003o
410@olc<c01hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00omEEEGoQhN7ooooo`1j
ooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0N_ooool0083ooooo00?o
410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000005ooooo`03oeEE
EOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@N?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(118) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26446 m
.00236 .2593 L
.00365 .25707 L
.00488 .25532 L
.00602 .25397 L
.00726 .25275 L
.00942 .25117 L
.01066 .2505 L
.01203 .24992 L
.01479 .24904 L
.01975 .24778 L
.02493 .2463 L
.02778 .24551 L
.02919 .24519 L
.0305 .24496 L
.03171 .24482 L
.03301 .24479 L
.03375 .24482 L
.03445 .24489 L
.03576 .24516 L
.03696 .24556 L
.03807 .24608 L
.03928 .24683 L
.04057 .24785 L
.04328 .25082 L
.04624 .2554 L
.05161 .26717 L
.0578 .28406 L
.06049 .29121 L
.06345 .29804 L
.06478 .30057 L
.06622 .30281 L
.06758 .3044 L
.06883 .30538 L
.07016 .30589 L
.07091 .30593 L
.07161 .30581 L
.07235 .3055 L
.07303 .30507 L
.07381 .3044 L
.07454 .3036 L
.07711 .29962 L
.07947 .29457 L
.08481 .28048 L
.08925 .26888 L
.0917 .26357 L
.09403 .25964 L
.09534 .25797 L
.09603 .25726 L
.09677 .25664 L
Mistroke
.09807 .25588 L
.09927 .25557 L
.1006 .25566 L
.10185 .25615 L
.10297 .25691 L
.10418 .25806 L
.10666 .26136 L
.10937 .26611 L
.11486 .27708 L
.11731 .28144 L
.11866 .28343 L
.11994 .28497 L
.12113 .28604 L
.12242 .28677 L
.12359 .28702 L
.12468 .28687 L
.12592 .28624 L
.12723 .28506 L
.12834 .28363 L
.12956 .28164 L
.13228 .27572 L
.13481 .26874 L
.14432 .23823 L
.14714 .23052 L
.14981 .22475 L
.15097 .22277 L
.1522 .22106 L
.15355 .21967 L
.15479 .21885 L
.15612 .21846 L
.15686 .21847 L
.15754 .21862 L
.15886 .21931 L
.16011 .22044 L
.16082 .22127 L
.16157 .22231 L
.16291 .22455 L
.16596 .23133 L
.17579 .26186 L
.17848 .2695 L
.17994 .27295 L
.18131 .27556 L
.18248 .27727 L
.18373 .2785 L
.18512 .27909 L
.18638 .27889 L
.18758 .27804 L
.18884 .27642 L
.18992 .27447 L
.19111 .27174 L
Mistroke
.19377 .26362 L
.19625 .25388 L
.20557 .2086 L
.21079 .18422 L
.21648 .1622 L
.22185 .14635 L
.22684 .13554 L
.23178 .12783 L
.23626 .1228 L
.23875 .12064 L
.24143 .11873 L
.2463 .11616 L
.24879 .11521 L
.25147 .1144 L
.25378 .11384 L
.25629 .11337 L
.25782 .11313 L
.25924 .11296 L
.26056 .11282 L
.26202 .1127 L
.26333 .11261 L
.26456 .11256 L
.26585 .11252 L
.26658 .1125 L
.26725 .11249 L
.26854 .11249 L
.26992 .1125 L
.27122 .11253 L
.2724 .11256 L
.27379 .11262 L
.2753 .11269 L
.27803 .11285 L
.2809 .11307 L
.28393 .11337 L
.28937 .11405 L
.29929 .11567 L
.30994 .11813 L
.32 .1212 L
.32918 .12478 L
.35086 .13557 L
.3614 .14106 L
.37095 .14534 L
.37577 .1471 L
.38098 .14866 L
.39041 .15086 L
.39559 .15191 L
.40113 .15321 L
.40636 .15484 L
.41112 .15684 L
.41627 .15974 L
Mistroke
.42114 .1633 L
.43212 .17429 L
.45425 .20147 L
.46443 .21269 L
.47 .21995 L
.47522 .22918 L
.47965 .24001 L
.48443 .2556 L
.49458 .301 L
.49971 .32468 L
.50252 .33524 L
.50391 .33939 L
.50518 .3425 L
.5059 .34393 L
.50669 .34521 L
.50749 .34618 L
.50833 .34687 L
.50904 .34717 L
.5098 .3472 L
.51118 .34652 L
.5119 .34579 L
.51268 .34473 L
.5141 .3421 L
.51548 .33876 L
.51676 .33508 L
.52199 .31614 L
.52763 .29476 L
.53023 .28646 L
.53296 .27938 L
.53529 .27485 L
.53662 .2729 L
.53785 .27149 L
.53907 .27045 L
.5404 .26971 L
.54165 .26935 L
.54281 .26929 L
.54385 .26942 L
.545 .26974 L
.5462 .27025 L
.54732 .27085 L
.5498 .27242 L
.55251 .27416 L
.55375 .27485 L
.55506 .27545 L
.55631 .27586 L
.55744 .27608 L
.55878 .27611 L
.55954 .27602 L
.56024 .27585 L
.56153 .27536 L
Mistroke
.56288 .27456 L
.56411 .27361 L
.56526 .27252 L
.56786 .26942 L
.57323 .26121 L
.57606 .25668 L
.57906 .25237 L
.58178 .24935 L
.58253 .24871 L
.58333 .24813 L
.58402 .24772 L
.58478 .24738 L
.58612 .24703 L
.58685 .247 L
.58754 .24706 L
.58876 .24742 L
.59006 .24814 L
.59141 .24925 L
.59287 .25086 L
.59552 .25478 L
.60047 .26472 L
.6054 .27566 L
.60809 .2808 L
.60941 .28286 L
.61061 .2844 L
.61172 .28549 L
.61276 .28621 L
.61387 .28663 L
.61507 .28666 L
.6163 .28621 L
.61761 .28521 L
.61873 .28393 L
.61996 .28208 L
.62242 .27713 L
.62511 .2701 L
.63053 .25301 L
.63562 .23713 L
.63783 .23122 L
.64024 .22591 L
.6417 .22333 L
.64306 .22144 L
.64435 .22009 L
.64572 .21917 L
.64641 .2189 L
.64716 .21876 L
.6485 .21892 L
.64932 .21927 L
.65011 .21978 L
.65081 .22039 L
.65157 .2212 L
Mistroke
.65296 .22307 L
.65422 .2252 L
.65705 .23132 L
.66213 .24571 L
.66725 .26122 L
.67005 .26829 L
.67141 .27103 L
.67266 .27301 L
.6738 .27435 L
.67489 .27516 L
.67603 .27549 L
.67727 .27523 L
.67855 .27426 L
.67991 .27246 L
.68106 .27031 L
.68234 .2673 L
.68517 .25848 L
.68777 .24824 L
.69362 .22084 L
.69874 .19619 L
.7042 .17284 L
.7096 .1543 L
.7145 .1414 L
.71943 .13175 L
.72408 .12512 L
.72672 .12221 L
.72951 .11968 L
.73451 .11628 L
.73729 .11491 L
.7399 .11391 L
.74275 .11308 L
.74436 .11271 L
.74582 .11243 L
.74849 .11204 L
.74996 .11188 L
.75134 .11177 L
.75262 .1117 L
.7538 .11166 L
.7551 .11163 L
.75646 .11164 L
.75784 .11167 L
.75862 .1117 L
.75932 .11173 L
.7607 .11181 L
.76199 .11191 L
.7649 .1122 L
.76806 .1126 L
.77903 .11456 L
.78917 .11704 L
.83046 .12904 L
Mistroke
.84108 .13214 L
.85119 .13548 L
.87016 .14429 L
.87989 .15051 L
.89052 .15822 L
.90201 .16642 L
.91244 .17288 L
.91754 .17601 L
.92306 .18014 L
.92559 .18252 L
.92827 .18557 L
.93307 .19314 L
.93569 .19887 L
.9385 .20668 L
.94356 .22621 L
.94666 .24222 L
.94959 .26056 L
.95509 .30276 L
.96031 .34752 L
.96287 .36789 L
.96521 .38377 L
.96639 .3903 L
.96767 .39616 L
.96896 .40055 L
.97033 .40344 L
.97107 .40423 L
.97174 .40448 L
.97252 .4042 L
.97325 .40339 L
.97456 .40069 L
.97529 .39849 L
.97597 .39605 L
.97828 .38518 L
.98044 .37218 L
.98536 .33782 L
.99056 .30361 L
.99299 .29041 L
.99531 .2799 L
1 .26446 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1<ooooo`Ko0000G_ooool006Gooooo4?l0000eooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`18ooooo`Co00001_ooool7o`0005Oooooo001Tooooo`03o`000?oo
oooooooo00kooooo1_l0000_ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`17ooooo`;o00004?ooool3o`0005Cooooo001Rooooo`;o00005oooool3o`0003Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`?o0000DOooool0063ooooo0_l0000L
ooooo`;o0000=Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Oooooo0ol0001>
ooooo`00Goooool00ol0003oooooooooo`0Nooooo`;o0000<oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo01_ooooo0ol0001;ooooo`00Goooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo033ooooo0_l00015ooooo`03o`000?oooooooooo01kooooo1?l00017ooooo`00
G_ooool00ol0003oooooooooo`0Rooooo`;o0000<?ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo02?ooooo0ol00014ooooo`00G_ooool00ol0003oooooooooo`0Tooooo`;o0000;_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Kooooo0ol00011ooooo`00G_ooool0
0ol0003oooooooooo`0Vooooo`;o0000;?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo02[ooooo0_l0000oooooo`00GOooool00ol0003oooooooooo`0Yooooo`?o0000:Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo02gooooo0_l0000mooooo`00G?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0_ooooo`;o0000>oooool005cooooo00?o0000ooooooooool0;_ooool5o`0002?ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Sooooo
001Looooo`03o`000?oooooooooo03?ooooo0ol0000Pooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0<oooool2o`0003Sooooo001Kooooo`03o`000?oooooooooo03Oooooo1?l0000L
ooooo`;o0000@Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo001Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo03Kooooo0_l0000eooooo`00Foooool00ol0003oooooooooo`0looooo`;o
00006Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0<_ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0J
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo
00?o0000ooooooooool01?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kQCooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0K
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00?o0000ooooooooool06?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo
00?o0000ooooooooool01?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0001Wooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004oooool0
0ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo01?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?o
oooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2
o`0001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Looooo`03
oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo
00Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Cooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
00Sooooo0_l0000Aooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo
01;ooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400C
ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool03oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[o
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool0
0ol0003oooooooooo`06ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Gooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo00oo
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03
ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool01_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h04_ooool00ol0003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0?ooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00FOooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo02Oooooo001Hooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool09_ooool005Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Vooooo`00F?oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Gooooo001Hooooo`03o`000?oooooo
oooo04_ooooo0_l0000=ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Uooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool005Oooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Tooooo`00Aoooool2o`0000gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo0_l0000>ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool09?ooool004Kooooo1?l0000<ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`Co00003Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo02Cooooo0015ooooo`;o00000_ooool2o`0000_ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool08oooool004Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02?o
oooo0015ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0Sooooo`00AOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`05ooooo`;o0000:_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0Sooooo`00A?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool08_ooool004Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02;ooooo0014ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Rooooo`007Oooool6o`00023ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Hooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Rooooo`006_oo
ool3o`0000Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Oooooo1?l0000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02;ooooo000Hooooo`;o00002Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool08_ooool001Oooooo0_l0000;
ooooo`03o`000?oooooooooo00gooooo0ol0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool08Oooool001Kooooo0_l0000<ooooo`03o`000?oooooooooo00gooooo00Co0000oooo
ool0003o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`02ooooo`;o00005_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool08Oooool001Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo027ooooo000Fooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05_ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo000Voooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00001Mooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
E?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo000Vooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00001Mooooo`05o`000?ooooooooooooooool0
00002oooool5o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00_l0001Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04Oooool002Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool01?l0003ooooo
ooooool0001Nooooo`05o`000?ooooooooooooooool000002_ooool2o`0000Cooooo00?o0000oooo
ool000000_l0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`00
05Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`?o0000G_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool01?ooool2o`0000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool002Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000004Oooool00ol0
003oooooooooo`1Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Booooo`00:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo0_l00002ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool00_l00008oooo
o`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000JOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01;ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool3o`0007?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0F
ooooo`?o0000J_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo000Yoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0C
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04oooool002[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo000Zooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Dooooo`00:oooool00ol0003oooooo`00001looooo`Go00001?ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Dooooo`00:oooool3o`0007cooooo00GoV9RHob4Q8Oo^k^koooooodA4A004ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Cooooo002[ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooool00000
0_l00005ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Dooooo`00[?ooool00onHV9So8B4Qonk^kP05ooooo`;o00001_ooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00:gooooo00?oMgMg
ofIVI_ooool01?ooool2o`0000Kooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Gooooo002^ooooo`03o`000?oooooooooo00?ooooo0_l00006oooo
o`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool00:[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo002eooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo002eooooo`;o00000oooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00;Gooooo0_l00003ooooo`03o`000?oo
oooooooo08[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`00]Oooool2
o`0000?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Kooooo002eooooo`;o00000oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05_ooool00;Gooooo00Go0000ooooool0003oooooo`00002=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00;Gooooo00?o0000ooooool0
00000_l0002=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00;Gooooo
00?o0000ooooooooool0Soooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo
002eooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Fooooo`00]Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05oooool00;Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo002eooooo`;o0000TOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05oooool00;Gooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooooooo
093ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003o
ooooooooo`2Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00;Gooooo
00?o0000ooooooooool0TOooool01Ol0003ooooooooooooooooo000001[ooooo002eooooo`03o`00
0?oooooooooo097ooooo00Go0000ooooooooooooooooo`00000Jooooo`00]Oooool2o`0009;ooooo
00Go0000ooooooooooooooooo`00000Jooooo`00]Oooool00ol0003oooooooooo`2Aooooo`05o`00
0?ooooooooooooooool000006_ooool00;Gooooo00?o0000ooooooooool0TOooool01?l0003ooooo
ooooool0000Kooooo`00]Oooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000001_ooooo
002eooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000006oooool00:cooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo0_l0000Kooooo`00[Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool06_ooool00:[o
oooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3o
oooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@
4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00
Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj
^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o
0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`00
0004oa0@4?ooooooooooooooo`Co000000So410@ooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c7So
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40N?ooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80N?oo
ool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c01h
ooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@07So
oooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zjoooooonj^[[o000007Sooooo0020
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Ooo
ool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0N?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .39394 m
.00123 .39574 L
.00236 .39609 L
.00365 .39495 L
.00488 .3924 L
.00601 .38881 L
.00706 .38455 L
.00942 .372 L
.01434 .33814 L
.01975 .30079 L
.02226 .28676 L
.02365 .2803 L
.02497 .27505 L
.02619 .27099 L
.02752 .26743 L
.02873 .26498 L
.02985 .26334 L
.03053 .26266 L
.03125 .26215 L
.03257 .26184 L
.03386 .26223 L
.03504 .26316 L
.03632 .26471 L
.03773 .26699 L
.04057 .27297 L
.04328 .27963 L
.04624 .28676 L
.04759 .28967 L
.04903 .29234 L
.05027 .29422 L
.05161 .29573 L
.0524 .29636 L
.05313 .29674 L
.05382 .29693 L
.05455 .29694 L
.05536 .29673 L
.0561 .29633 L
.05693 .29565 L
.0578 .29467 L
.05932 .29234 L
.06076 .28949 L
.06345 .28271 L
.06843 .26736 L
.0737 .25205 L
.07502 .24904 L
.07645 .24635 L
.07727 .2451 L
.07801 .24415 L
.07877 .24339 L
.07948 .24286 L
Mistroke
.0808 .24238 L
.08203 .24254 L
.08338 .2434 L
.08413 .2442 L
.08481 .24513 L
.08608 .24733 L
.08726 .24996 L
.08994 .25789 L
.09536 .28052 L
.10034 .30419 L
.10279 .31438 L
.10506 .32174 L
.10634 .32476 L
.10771 .3269 L
.10908 .32787 L
.10986 .32786 L
.11059 .32749 L
.11185 .32601 L
.11301 .32374 L
.11428 .32029 L
.11562 .31567 L
.12103 .28928 L
.12693 .2555 L
.12961 .2418 L
.1325 .22947 L
.13383 .22488 L
.13523 .22083 L
.13643 .21806 L
.13775 .21577 L
.13903 .2143 L
.1402 .21364 L
.14155 .21368 L
.14282 .21451 L
.144 .21595 L
.14509 .21787 L
.14629 .2206 L
.14757 .22421 L
.15016 .23368 L
.15296 .24672 L
.15802 .27504 L
.16091 .29148 L
.1625 .29976 L
.16401 .3067 L
.16541 .31217 L
.16614 .31459 L
.16692 .31679 L
.1683 .31962 L
.16958 .321 L
.17077 .32114 L
.17204 .32004 L
Mistroke
.17325 .31783 L
.17435 .31484 L
.17564 .31022 L
.17705 .30393 L
.17961 .28966 L
.19059 .21334 L
.19616 .18085 L
.19921 .16664 L
.20208 .15553 L
.20477 .14695 L
.20767 .13942 L
.21274 .12982 L
.21524 .1264 L
.21791 .12346 L
.22022 .12142 L
.22273 .11963 L
.22568 .118 L
.22847 .11686 L
.23118 .11605 L
.23369 .11551 L
.23496 .1153 L
.23632 .11511 L
.2375 .11498 L
.23879 .11487 L
.24022 .11478 L
.241 .11474 L
.24173 .11472 L
.24303 .11469 L
.24376 .11469 L
.24442 .11469 L
.24513 .1147 L
.24589 .11472 L
.24723 .11477 L
.24799 .11481 L
.24869 .11485 L
.25028 .11497 L
.25295 .11524 L
.25581 .1156 L
.26134 .1165 L
.26646 .11757 L
.27806 .12098 L
.28829 .12495 L
.29918 .13 L
.31001 .13518 L
.31571 .1377 L
.32172 .14 L
.32699 .1416 L
.32978 .1423 L
.33277 .14291 L
.33552 .14337 L
Mistroke
.33802 .14369 L
.34053 .14393 L
.34291 .14409 L
.34817 .14431 L
.35309 .14447 L
.35556 .14458 L
.35822 .14475 L
.35973 .14488 L
.36117 .14503 L
.36388 .14539 L
.3662 .14583 L
.36867 .14643 L
.37313 .14794 L
.37586 .14915 L
.37843 .15052 L
.38323 .15365 L
.40252 .17235 L
.40781 .17764 L
.41072 .18019 L
.41347 .18226 L
.41603 .18382 L
.41739 .18448 L
.41882 .18506 L
.42003 .18543 L
.42136 .18574 L
.42256 .18592 L
.4237 .18601 L
.42492 .18601 L
.42626 .18591 L
.42693 .18582 L
.42765 .18571 L
.42895 .18543 L
.43148 .18467 L
.43377 .1838 L
.43942 .18128 L
.4419 .18022 L
.44331 .1797 L
.44463 .17927 L
.4459 .17895 L
.44728 .1787 L
.44803 .17862 L
.44874 .17857 L
.45008 .1786 L
.45079 .17868 L
.45155 .17881 L
.45291 .17917 L
.45375 .17948 L
.45453 .17984 L
.456 .18069 L
.45869 .18287 L
Mistroke
.46116 .18564 L
.46388 .18959 L
.46674 .1948 L
.50665 .2636 L
.52889 .30401 L
.53399 .32649 L
.53679 .33698 L
.53816 .34108 L
.53941 .34406 L
.5405 .34598 L
.54164 .34727 L
.54279 .34777 L
.54404 .34738 L
.54532 .34596 L
.54668 .34335 L
.54797 .33988 L
.54914 .33596 L
.55432 .31198 L
.55921 .28547 L
.56176 .27268 L
.56446 .26116 L
.56587 .2562 L
.56742 .25168 L
.56883 .24848 L
.57015 .2463 L
.57138 .24498 L
.57273 .24434 L
.57399 .24449 L
.57517 .24527 L
.57622 .24649 L
.57738 .24838 L
.5786 .25093 L
.57974 .25384 L
.58469 .27094 L
.59004 .29287 L
.59254 .30198 L
.59392 .30616 L
.59523 .30939 L
.59644 .31168 L
.59776 .3133 L
.59896 .31394 L
.60006 .31379 L
.60137 .3127 L
.6026 .31078 L
.60395 .30772 L
.60539 .3034 L
.60834 .29179 L
.61104 .27884 L
.61647 .25085 L
.61934 .23738 L
Mistroke
.6224 .22548 L
.62391 .22078 L
.62533 .21715 L
.62661 .21461 L
.62799 .21263 L
.62931 .21153 L
.62997 .21127 L
.6307 .2112 L
.63198 .21167 L
.63319 .21279 L
.63433 .21447 L
.63554 .21688 L
.63687 .22026 L
.63808 .22403 L
.64268 .24346 L
.64747 .26986 L
.65021 .28554 L
.65276 .29888 L
.65531 .30969 L
.65674 .31416 L
.65804 .31705 L
.65878 .31815 L
.65947 .3188 L
.66022 .31911 L
.66101 .31894 L
.66235 .31754 L
.66311 .31613 L
.66382 .3144 L
.66514 .3102 L
.6664 .30509 L
.66875 .29296 L
.67405 .25775 L
.67922 .22095 L
.68472 .18687 L
.68789 .17092 L
.69076 .15887 L
.69368 .14877 L
.69636 .14123 L
.70159 .13046 L
.70434 .12647 L
.70724 .12321 L
.70977 .12102 L
.71213 .11942 L
.71472 .11808 L
.71603 .11755 L
.71749 .11707 L
.71879 .11672 L
.72019 .11642 L
.72167 .11618 L
.72305 .11602 L
Mistroke
.72443 .11591 L
.72574 .11585 L
.72692 .11583 L
.7282 .11583 L
.72899 .11585 L
.72973 .11588 L
.73112 .11595 L
.7319 .11601 L
.73261 .11607 L
.73423 .11623 L
.73696 .11658 L
.73984 .11704 L
.76098 .12149 L
.78181 .12579 L
.80082 .12944 L
.80585 .13062 L
.81133 .13211 L
.82129 .13572 L
.83269 .14152 L
.84324 .14838 L
.85266 .1548 L
.85761 .15787 L
.86282 .16055 L
.8656 .16168 L
.86864 .16264 L
.86997 .16297 L
.8714 .16326 L
.87275 .16347 L
.87397 .16362 L
.87531 .16373 L
.87655 .16378 L
.87792 .16379 L
.8786 .16377 L
.87936 .16374 L
.88062 .16366 L
.88198 .16353 L
.88444 .16321 L
.88959 .16237 L
.89241 .16192 L
.8938 .16174 L
.89507 .1616 L
.89579 .16153 L
.89658 .16148 L
.89738 .16144 L
.89822 .16142 L
.89894 .16142 L
.8997 .16143 L
.90108 .16152 L
.9018 .16159 L
.90258 .1617 L
Mistroke
.904 .16197 L
.90538 .16232 L
.90666 .16275 L
.90917 .16386 L
.91153 .16526 L
.91411 .16724 L
.91689 .16989 L
.92256 .17694 L
.92776 .18513 L
.93819 .20401 L
.94393 .21333 L
.94674 .21711 L
.94933 .22003 L
.95174 .22224 L
.95438 .22417 L
.95704 .2257 L
.95985 .22711 L
.96223 .2284 L
.96354 .22924 L
.96478 .2302 L
.96719 .23262 L
.96939 .23573 L
.97133 .23937 L
.97308 .24355 L
.97496 .24912 L
.977 .25652 L
.98063 .27364 L
.98404 .29435 L
1 .39394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00H?ooool7o`0004?ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0;3ooooo001Nooooo`?o00001_ooool7o`0003cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo047ooooo3Ol0001Rooooo`00G?ooool2o`00013ooooo0_l0
0015ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02oooool5o`0005gooooo001K
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo017ooooo0ol0001Jooooo`00F_ooool00ol0003oooooooooo`0Doooo
o`?o0000@Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Gooooo1Ol0001Eoooo
o`00FOooool00ol0003oooooooooo`0Hooooo`?o0000?_ooool2o`0003kooooo00?o0000oooooooo
ool06oooool5o`00053ooooo001Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo0ol0001=ooooo`00F?oo
ool00ol0003oooooooooo`0Mooooo`;o0000>oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo02Cooooo0_l0001;ooooo`00F?ooool00ol0003oooooooooo`0Oooooo`Co0000=oooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo02Kooooo0_l00019ooooo`00F?ooool00ol0
003oooooooooo`0Sooooo`Co0000<oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02Wooooo0_l00017ooooo`00Eoooool00ol0003oooooooooo`0Xooooo`[o0000:Oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0A?ooool005Oooooo
00?o0000ooooooooool0<_ooool2o`0002Oooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0/ooooo`;o0000A?ooool005Oooooo00?o0000ooooooooool0=?ooool2o`0002Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo047ooooo001F
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool2o`0003_ooooo00?o0000
ooooooooool0<?ooool2o`00047ooooo001Fooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0?_ooool005Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0<oooool2o`0000Kooooo1ol0000aooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool00ol0003ooooo
ooooo`0:ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000001?l@413o
ooooooooooo^k^h2o`000003oc8b<_o^k^kooooo01gooooo00?o0000ooooooooool07oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h?ooooo`03o`000?oooooooooo00Sooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;oc<c<
00Ko000000?o<S8bonk^k_ooool00oooool3o`0001Kooooo0_l000002Ol@413ooooooooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9So0000oiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko0000
0_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo013ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001gooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00007Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
4?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03_oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`00000Looooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`0?ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0?
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo000000Sooooo1ol0000=ooooo`;o
00008_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0L
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oo
oooooooo013ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo
000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000oooo
ooooool02oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`?o0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2_ooool00ol0003oooooooooo`0?ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool5o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo
00[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03
o`000?oooooooooo00oooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo001Dooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:?ooool005?ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Wooooo`00Doooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo02Oooooo001Cooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool09_ooool005?ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Voooo
o`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool3o`0000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo0012oooo
o`;o00003_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09Oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool08oooool0047ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0
000=ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool08_ooool0047ooooo00Co0000
oooooooooooo00003Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`0Qooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Cooooo0_l0000Qooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo05Gooooo0ol0000Oooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05Oooooo0_l0000Nooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool01?l0003oooooooooooooool2o`0002Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool06oooool0043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
01_ooooo000oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Nooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06_ooool002oo
oooo0_l0000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooo000002Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06_ooool002kooooo
00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Goooool00ol0003oooooo`00000Eooooo`?o00003?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Jooooo`00;_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Pooooo`;o00005Oooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01Wooooo000]ooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0H?ooool2o`0001Cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo01Wooooo000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0H
ooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;ooooo0_l0000Coooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`007oooool2o`00
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Rooooo`;o00004_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06?ooool001oo
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooool000004Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool06?ooool001kooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool00ol0003oooooo`00000Aooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Gooooo`00
7_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Rooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;o
oooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo01Oooooo000Mooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Sooooo`;o00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool05_ooool001gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo01Kooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Kooooo000Looooo`03o`000?oooooooooo00Oooooo0ol0000<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Fooooo`007?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0F
ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo1Ol00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000003oooool01Ol0003ooooooooooooooooo000006Cooooo00?o
0000ooooooooool05_ooool001cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00001Kooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0000?ooooo`05o`000?oooooooooooooo
ool00000IOooool00ol0003oooooooooo`0Eooooo`007?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
05cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000oooooo00Go0000ooooooooooooooooo`00
001Uooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool00000GOooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`?o00003oooool01?l0003oooooooooool0001Vooooo`03o`000?oooooooooo01Go
oooo000Kooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000@ooooo`03
o`000?oooooo000005oooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool2o`00017ooooo00?o0000ooooool0
0000I_ooool00ol0003oooooooooo`0Eooooo`006oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool000004?ooool00ol0003oooooo`00001Pooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01ko
oooo0ol0001Vooooo`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo01Wooooo
00Co0000oooooooooooo00004?ooool2o`0005gooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27oooo
o`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool0
0000Koooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool05Oooool001_o
oooo00?o0000ooooooooool06_ooool2o`0007_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool05?ooool001[ooooo
00?o0000ooooooooool0V?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`2Hooooo`;o00002_ooool01Ol0003ooooooooooooooooo000008_ooooo00?o0000ooooooooool0
5?ooool001[ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool00000Roooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000S?ooool00ol0003ooooo
ooooo`0Dooooo`006_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo0000S?ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00[ooooo0_l0002>ooooo`03o`000?oooooooooo01?ooooo000J
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0C
ooooo`006_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool04oooool001Wooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`0Cooooo`006Oooool00ol0003oooooooooo`2Iooooo`;o0000Vooo
ool00ol0003oooooooooo`0Cooooo`006Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooo
oooo09_ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool0VOooool00ol0
003oooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`006Oooool00ol0003ooooo
ooooo`2Iooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool04_ooool001Wooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000H
ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0B
ooooo`006?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo09_ooooo00?o0000oooo
ooooool04_ooool001Sooooo00?o0000ooooooooool0V_ooool2o`0009gooooo00?o0000oooooooo
ool04Oooool001Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`2Looooo`03o`00
0?oooooooooo017ooooo000Fooooo`;o0000WOooool00ol0003oooooooooo`2Looooo`03o`000?oo
oooooooo017ooooo000Fooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/?ooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool0
0:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Z
ooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00
002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_oooo
o`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6Oooool4o`000003oa0@4?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07So
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool00oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087o
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool0M_ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo
1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(122) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2923 m
.00488 .28509 L
.00942 .27663 L
.01077 .2746 L
.01204 .27308 L
.01318 .27213 L
.01441 .27162 L
.01576 .27176 L
.01644 .27214 L
.01719 .27281 L
.01851 .27467 L
.01975 .27726 L
.02103 .28085 L
.02243 .28583 L
.02499 .29777 L
.02978 .32866 L
.03245 .34841 L
.03533 .36885 L
.03666 .37709 L
.03806 .38454 L
.03925 .38965 L
.04057 .39371 L
.04133 .39526 L
.04202 .39612 L
.04282 .39646 L
.04358 .39611 L
.04493 .39387 L
.04569 .39172 L
.04639 .38917 L
.04761 .38356 L
.04895 .37575 L
.05167 .35575 L
.05737 .30527 L
.06036 .28 L
.06351 .2577 L
.06625 .24304 L
.0678 .23687 L
.06854 .23448 L
.06924 .23255 L
.07057 .22979 L
.07178 .22829 L
.07308 .22773 L
.07382 .2279 L
.0745 .22836 L
.07573 .22994 L
.07688 .23227 L
.07815 .23575 L
.0795 .24054 L
.08228 .25339 L
.08481 .26822 L
Mistroke
.08983 .30236 L
.09258 .32059 L
.09517 .33501 L
.09635 .34021 L
.0976 .34456 L
.09896 .34784 L
.10022 .34938 L
.10134 .3495 L
.1024 .34854 L
.10355 .3463 L
.10478 .34258 L
.10624 .33656 L
.10759 .32961 L
.11064 .31007 L
.11618 .26885 L
.12118 .23572 L
.12399 .22166 L
.12532 .21639 L
.12656 .21235 L
.1277 .20937 L
.12892 .207 L
.13027 .20536 L
.1315 .20477 L
.13278 .2051 L
.13351 .2057 L
.13417 .20653 L
.1354 .20874 L
.13669 .21204 L
.13782 .21572 L
.13903 .22051 L
.14122 .23129 L
.14619 .26494 L
.15201 .31278 L
.15487 .33436 L
.15612 .34241 L
.15751 .34987 L
.15875 .35503 L
.15991 .35846 L
.16114 .36048 L
.16246 .36071 L
.16383 .35881 L
.16451 .35704 L
.16527 .3545 L
.1666 .34851 L
.16784 .34136 L
.17738 .25856 L
.1826 .21377 L
.18749 .18113 L
.19277 .15611 L
.19557 .14651 L
Mistroke
.19858 .13856 L
.20132 .13309 L
.20392 .12915 L
.20626 .12642 L
.20881 .12412 L
.21032 .12302 L
.21175 .12215 L
.21443 .1209 L
.21593 .1204 L
.21731 .12006 L
.21803 .11992 L
.21882 .1198 L
.21965 .11971 L
.22042 .11966 L
.22109 .11963 L
.22182 .11962 L
.22314 .11965 L
.22443 .11973 L
.22562 .11985 L
.22832 .1202 L
.23119 .12069 L
.23638 .12195 L
.24125 .1236 L
.25234 .12812 L
.26173 .13226 L
.27176 .13628 L
.27752 .13804 L
.28276 .13934 L
.28528 .13981 L
.28671 .14001 L
.28802 .14016 L
.28917 .14026 L
.29043 .14034 L
.29175 .14039 L
.29299 .14042 L
.29429 .14043 L
.29503 .14042 L
.29571 .14041 L
.29696 .14039 L
.29829 .14036 L
.29961 .14031 L
.30084 .14025 L
.30314 .14012 L
.30587 .13991 L
.30838 .13967 L
.31131 .13936 L
.31274 .13922 L
.31405 .1391 L
.31524 .13902 L
.31653 .13894 L
Mistroke
.3179 .13889 L
.31919 .13888 L
.31987 .13888 L
.32061 .1389 L
.32139 .13892 L
.32212 .13895 L
.32343 .13904 L
.32483 .13916 L
.32629 .13933 L
.32788 .13956 L
.33077 .14013 L
.33359 .14092 L
.33621 .1419 L
.34153 .14472 L
.34729 .14893 L
.35774 .15919 L
.36784 .17073 L
.37278 .1756 L
.37728 .17905 L
.37846 .17976 L
.37975 .18043 L
.38086 .1809 L
.38209 .18132 L
.38339 .18162 L
.38477 .18179 L
.38605 .18181 L
.38725 .18169 L
.38859 .18143 L
.38926 .18124 L
.39 .18099 L
.39252 .17986 L
.39547 .17803 L
.3982 .17596 L
.40366 .17118 L
.40958 .1658 L
.41229 .16361 L
.41517 .16169 L
.41635 .16105 L
.41762 .16048 L
.41835 .16021 L
.41901 .16 L
.42032 .1597 L
.42164 .15955 L
.42238 .15953 L
.42305 .15956 L
.42436 .15975 L
.42559 .16008 L
.42629 .16034 L
.42703 .16067 L
.42835 .16141 L
Mistroke
.42977 .16243 L
.43133 .16383 L
.43394 .16686 L
.43674 .1711 L
.44179 .18129 L
.45193 .20859 L
.45639 .22086 L
.45875 .22663 L
.4613 .23183 L
.4627 .23413 L
.46398 .23584 L
.46521 .23708 L
.4665 .23797 L
.46786 .23841 L
.46913 .23836 L
.46986 .23814 L
.47052 .23781 L
.47129 .23729 L
.47201 .23666 L
.47342 .23506 L
.47491 .23289 L
.47759 .22792 L
.48364 .21356 L
.4885 .20155 L
.49117 .19578 L
.49371 .19132 L
.49514 .18935 L
.49589 .18849 L
.4967 .18772 L
.49737 .1872 L
.49812 .18676 L
.49943 .18633 L
.50075 .18638 L
.5015 .18664 L
.50218 .18701 L
.50345 .18808 L
.50477 .18974 L
.50607 .1919 L
.50747 .19488 L
.51001 .20203 L
.51249 .21122 L
.51477 .22163 L
.52547 .28707 L
.5278 .30123 L
.5303 .31429 L
.53151 .31948 L
.53266 .3236 L
.5337 .32656 L
.53482 .32894 L
.53601 .33044 L
Mistroke
.53727 .3309 L
.53846 .33024 L
.53954 .32876 L
.54083 .32597 L
.54222 .32179 L
.54474 .31171 L
.54997 .2854 L
.55285 .27131 L
.55557 .26026 L
.5568 .25632 L
.55811 .25295 L
.55879 .25155 L
.55954 .2503 L
.56086 .24889 L
.56206 .2485 L
.56335 .24905 L
.56457 .2505 L
.56568 .25264 L
.56695 .256 L
.56814 .26 L
.57082 .27203 L
.57623 .30583 L
.58178 .34258 L
.5833 .35055 L
.58414 .35424 L
.58492 .35719 L
.58629 .3611 L
.58702 .36246 L
.5878 .36334 L
.58854 .3636 L
.58922 .36335 L
.58997 .36252 L
.59077 .36101 L
.59153 .35898 L
.59224 .35656 L
.59358 .35079 L
.59612 .33593 L
.59886 .31566 L
.60393 .27388 L
.6067 .25245 L
.60929 .23505 L
.61183 .22108 L
.61414 .21139 L
.61546 .20722 L
.61671 .20419 L
.61803 .20198 L
.61877 .20117 L
.61946 .20071 L
.62058 .20054 L
.62162 .20103 L
Mistroke
.62276 .20229 L
.624 .20449 L
.62528 .20772 L
.62651 .21167 L
.62881 .22137 L
.63152 .23647 L
.63408 .25388 L
.63886 .29166 L
.64158 .31327 L
.64444 .33324 L
.64563 .33997 L
.64689 .34593 L
.64762 .34869 L
.64828 .35075 L
.64958 .35347 L
.65077 .35437 L
.65186 .35381 L
.65306 .35168 L
.65434 .34771 L
.65545 .34294 L
.65649 .33742 L
.65885 .32161 L
.66888 .23479 L
.67422 .19565 L
.6792 .16888 L
.6817 .15865 L
.68438 .14979 L
.68735 .14215 L
.69006 .13688 L
.69255 .13316 L
.69485 .1305 L
.69737 .12824 L
.70005 .12644 L
.70236 .12526 L
.70454 .12444 L
.70578 .12408 L
.70692 .12381 L
.70823 .12357 L
.70948 .12339 L
.71079 .12327 L
.71153 .12322 L
.7122 .12318 L
.71345 .12314 L
.71477 .12313 L
.71595 .12313 L
.71705 .12315 L
.71826 .12317 L
.71956 .12321 L
.72245 .12332 L
.72518 .12347 L
Mistroke
.72763 .12365 L
.7303 .12388 L
.74026 .12476 L
.74961 .12552 L
.75437 .12607 L
.7595 .12674 L
.76227 .12716 L
.76518 .12768 L
.7704 .12891 L
.77586 .13065 L
.78094 .13265 L
.79246 .1389 L
.81216 .1527 L
.81755 .15597 L
.8205 .1574 L
.82326 .15846 L
.82561 .15915 L
.82693 .15945 L
.82813 .15966 L
.82945 .15984 L
.83019 .15991 L
.83088 .15995 L
.83214 .15999 L
.83349 .15996 L
.83423 .15991 L
.83501 .15983 L
.83568 .15975 L
.83641 .15964 L
.83804 .15933 L
.83956 .15895 L
.84527 .15697 L
.85085 .15462 L
.85592 .15256 L
.85844 .15166 L
.86118 .15085 L
.86243 .15055 L
.86376 .1503 L
.8649 .15015 L
.86615 .15005 L
.86688 .15003 L
.86757 .15004 L
.86887 .15013 L
.8696 .15021 L
.87027 .15033 L
.8718 .15068 L
.87314 .15111 L
.87436 .1516 L
.87709 .15304 L
.87953 .15476 L
.88221 .15712 L
Mistroke
.88761 .16351 L
.8973 .17957 L
.90317 .19039 L
.90873 .19956 L
.91115 .20278 L
.91372 .20546 L
.91506 .20651 L
.91578 .20695 L
.91654 .20735 L
.91789 .20783 L
.91916 .20802 L
.92044 .20795 L
.92164 .20766 L
.92295 .20709 L
.92369 .20667 L
.92436 .20621 L
.92718 .20368 L
.92984 .20051 L
.93964 .1855 L
.94475 .17821 L
.94733 .17537 L
.9488 .17411 L
.95017 .17319 L
.95094 .17279 L
.95167 .17249 L
.95304 .17215 L
.9538 .17209 L
.95451 .17213 L
.95529 .17226 L
.95612 .17252 L
.95683 .17284 L
.9576 .17329 L
.95899 .17439 L
.96035 .17583 L
.9616 .17748 L
.96399 .18161 L
.96617 .18648 L
.97108 .2014 L
.97992 .23931 L
.98486 .26214 L
.98747 .27287 L
.99024 .28232 L
.9914 .28552 L
.99265 .2884 L
.99402 .29082 L
.99531 .29237 L
.9965 .29318 L
.99776 .2934 L
.99883 .2931 L
1 .2923 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Jooooo`Oo0000E?ooool00ol0003oooooooooo`2`ooooo`00F?ooool2o`0000Oooooo0ol0001A
ooooo`03o`000?oooooooooo03kooooo3_l0001Tooooo`00Eoooool00ol0003oooooooooo`0:oooo
o`;o0000Coooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00cooooo1ol0001Moooo
o`00Eoooool00ol0003oooooooooo`0<ooooo`?o0000C?ooool2o`0003cooooo0_l0000Fooooo`?o
0000F_ooool005Kooooo00?o0000ooooooooool04?ooool3o`0004Wooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Iooooo`;o0000F?ooool005Kooooo00?o0000ooooooooool04ooo
ool2o`0004Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Looooo`;o0000E_oo
ool005Gooooo00?o0000ooooooooool05_oooolBo`0003Gooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Nooooo`;o0000E?ooool005Gooooo00?o0000ooooooooool0:?ooool2o`00
03?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
057ooooo001Dooooo`03o`000?oooooooooo02_ooooo0_l0000aooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool08Oooool2o`00057ooooo001Dooooo`03o`000?oooooooooo02gooooo
0_l0000_ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1>ooooo`00Doooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`;o00003?ooool8o`0003[ooooo001C
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool2o`0003Sooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`;o00002?ooool00ol0003oooooooooo`0g
ooooo`00Doooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Yooooo`?o00000oooool3o`0000_ooooo00?o0000oooo
ooooool0=_ooool005?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`Ko
00005Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02_ooooo1?l0000>ooooo`03
o`000?oooooooooo03Kooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`03o`000?oooooooooo00gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06_ooool00ol0003oooooo`000003o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h2ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00?o0000oooo
ooooool02oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o
0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01?l0003oooooooooool00004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00007ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ol0003oooooooooo`0<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
ooooo`000?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo
1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@400Cooooo`Ko00000oooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool03Ooo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o0000ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0?ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_l0000:ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0>ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Co0000oooo
oooooooooooo0_l0000Aooooo`Co00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oo
ooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool04Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000007Oooool2o`0000Cooooo00Go0000ooooool0003oooooo`00000;ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Co0000oooooooo
oooooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@
oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo01cooooo0ol00002ooooo`;o00000_ooool00ol@413oooooooooo`09ooooo`03
o`000?oooooooooo013ooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01ol@413ooooooooooooo
oooo410@ooooool000003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03_ooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`00
0?oooooooooo00;o000000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02_ooool00ol0003oooooooooo`0=ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`07ogMg
MonHV9SooooooiRHV?mgMgOoooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
01Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003ooooo
ooooo`0>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000
ooooooooool03_ooool3o`00023ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00[ooooo00?o0000ooooooooool03Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo001Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03Oooool4
o`0003Kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07?ooool0057ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0<ooooo`05o`000?oooooo0000ooooool00000=?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0K
ooooo`00DOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00_ooooo00Ko0000oooo
oooooooo0000ooooool0000dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo001@ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool02oooool01_l0003oooooooooool0003oooooo`0003Cooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06oooool0053ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Oooooo`?o0000
3oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Jooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`Go00000oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo1?l00007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo
017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000;o
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool2o`0000Kooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool003kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0I
ooooo`00?_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool06Oooool003gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0Hooooo`00;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool06?ooool002cooooo00?o0000ooooool000003Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo01Sooooo000/ooooo`03o`000?oooooo000000gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Oooooo00Go0000
ooooooooooooooooo`000007ooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo01Sooooo000[ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Eoooool4o`0000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Oooooo000[
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0F?ooool2o`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Oooooo000[ooooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool05oooool002_ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Gooooo`00:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Gooooo`00:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`Co00003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Fooooo`00:_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05_ooool002[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`;o00001Oooool00ol0003o
ooooooooo`08ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05_ooool002[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool05_ooool002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool05_ooool002[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05_ooool001[ooooo
0_l0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo01Gooooo000Iooooo`Co00003?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Eooooo`006Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo000I
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05?ooool001Sooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOoo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool05?ooool001Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Cooooo000Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`005_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo06Sooooo0_l0000Cooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1mooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1mooooo`007_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool5o`0000Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0OOooool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07gooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Looooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`007_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07gooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Nooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_ooool001oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0O_ooool001oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1n
ooooo`007oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Foooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo0000083ooooo000Oooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Sooooo0ol0
000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooo
oooooooo0000083ooooo000Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00001Yooooo`03
o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03Oooool01Ol0003ooooooooooooooooo0000083ooooo000Oooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooo
ooooooooooooo`00001Yooooo`;o00005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00gooooo00Go0000ooooooooooooooooo`000020ooooo`007oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?oo
ooooooooooooool00000JOooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool0
00003oooool01Ol0003ooooooooooooooooo0000083ooooo000Pooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooo
ooooooooooooo`00001Yooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00
000?ooooo`05o`000?ooooooooooooooool00000P?ooool0023ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000oooooo00Go0000oooooooooooooooo
o`00001Yooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000?ooooo`04
o`000?ooooooooooo`00087ooooo000Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooo`00000?ooooo`05o`000?ooooooooooooooool00000JOooool00ol0
003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooo`000021
ooooo`008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooool0001Yooooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`00000@ooooo`03o`000?oooooo0000087ooooo000Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0001Yooooo`03o`000?oo
oooooooo01Oooooo00Go0000ooooooooooooooooo`00000Aooooo`;o0000POooool0023ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000006[ooooo00?o
0000ooooooooool06?ooool00ol0003oooooo`00000Booooo`03o`000?oooooooooo083ooooo000P
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0006[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`00002Eooooo`008Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0JOooool2o`0001Wooooo0ol0002Eoooo
o`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`2Dooooo`008Oooool01Ol0003ooooooooooooooooo000008oo
oooo00?o0000ooooooooool0/?ooool0027ooooo00Go0000ooooooooooooooooo`00002?ooooo`03
o`000?oooooooooo0;3ooooo000Qooooo`05o`000?ooooooooooooooool00000Soooool00ol0003o
ooooooooo`2`ooooo`008Oooool01Ol0003ooooooooooooooooo000008oooooo00?o0000oooooooo
ool0/?ooool0027ooooo00Go0000ooooooooooooooooo`00002?ooooo`03o`000?oooooooooo0;3o
oooo000Rooooo`04o`000?ooooooooooo`0008oooooo00?o0000ooooooooool0/?ooool002;ooooo
00Co0000oooooooooooo0000Soooool2o`000;7ooooo000Rooooo`03o`000?oooooo0000093ooooo
00?o0000ooooooooool0/?ooool002?ooooo0_l0002@ooooo`03o`000?oooooooooo0;3ooooo000S
ooooo`;o0000T?ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool00:gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo002Z
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Z
ooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@
402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o
0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oo
oooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool0
1Ol00003ooooo`Go0000N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool0
0ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OnHV9So8B4Qonk^
k_ooooooA4A407Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0
NOooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q
8Oo^k^h0N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMgofIVI_ooool0
Moooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M_ooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@401hooooo`00
P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(124) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18863 m
.00236 .18277 L
.00365 .1802 L
.00488 .17823 L
.00602 .17682 L
.00726 .17576 L
.00839 .17525 L
.00942 .17518 L
.01066 .1756 L
.01181 .1765 L
.01307 .17809 L
.01444 .18052 L
.01586 .18388 L
.01721 .1879 L
.01975 .19773 L
.02225 .21047 L
.02491 .22752 L
.0297 .26654 L
.03536 .31981 L
.03784 .34151 L
.04057 .36102 L
.04201 .36874 L
.04336 .374 L
.0441 .37603 L
.04478 .37732 L
.04556 .37813 L
.04631 .37823 L
.04706 .37767 L
.04785 .37636 L
.04853 .37468 L
.04928 .37224 L
.05095 .36482 L
.05251 .35569 L
.05839 .31171 L
.06096 .29264 L
.06377 .27521 L
.06501 .26911 L
.06633 .26381 L
.06757 .26001 L
.0687 .25762 L
.06998 .25616 L
.07071 .25593 L
.07137 .2561 L
.0726 .25737 L
.07389 .26008 L
.07519 .26416 L
.07658 .27006 L
.07909 .28449 L
.08481 .33082 L
.08746 .35431 L
Mistroke
.08996 .37399 L
.09134 .3829 L
.09207 .38684 L
.09284 .39037 L
.0942 .39487 L
.09545 .39691 L
.09616 .39712 L
.09693 .39656 L
.09832 .39352 L
.09916 .3904 L
.09996 .38661 L
.10146 .37748 L
.10414 .35577 L
.10704 .32701 L
.11237 .27199 L
.11528 .24566 L
.11801 .22531 L
.12033 .21173 L
.12283 .20105 L
.12419 .19697 L
.12487 .19537 L
.12561 .19396 L
.12693 .19232 L
.12815 .19179 L
.1295 .19231 L
.13017 .193 L
.13092 .19411 L
.13224 .19693 L
.13347 .20057 L
.13492 .20613 L
.13625 .2124 L
.13923 .23066 L
.14459 .27667 L
.14967 .32867 L
.15202 .35115 L
.15331 .362 L
.15453 .37085 L
.15564 .37762 L
.15666 .38253 L
.1578 .38638 L
.15902 .38853 L
.16025 .38853 L
.16139 .38658 L
.16264 .38233 L
.16398 .3755 L
.16539 .36601 L
.16671 .35519 L
.1692 .3313 L
.17939 .2271 L
.18453 .18985 L
Mistroke
.18745 .17425 L
.19019 .1628 L
.19269 .15465 L
.19506 .14868 L
.1972 .14456 L
.19952 .14119 L
.20204 .13858 L
.20345 .13748 L
.20473 .13667 L
.20592 .13604 L
.20722 .13549 L
.20842 .13508 L
.20956 .13478 L
.21086 .13453 L
.21205 .13438 L
.21333 .13431 L
.21406 .13431 L
.21473 .13432 L
.21584 .13439 L
.21706 .13453 L
.21835 .13472 L
.21955 .13494 L
.23051 .13709 L
.2357 .1379 L
.23853 .13831 L
.23991 .13847 L
.24116 .1386 L
.24254 .13871 L
.2433 .13875 L
.24402 .13877 L
.2448 .13879 L
.24552 .13879 L
.24631 .13877 L
.24714 .13875 L
.2485 .13867 L
.24976 .13858 L
.25263 .13829 L
.25751 .13769 L
.26209 .13701 L
.26737 .13598 L
.27215 .13501 L
.27492 .13455 L
.27746 .13424 L
.27879 .13413 L
.28025 .13403 L
.28098 .13399 L
.28177 .13396 L
.28251 .13394 L
.28319 .13393 L
.2845 .13393 L
Mistroke
.28571 .13395 L
.28704 .134 L
.28771 .13404 L
.28845 .1341 L
.28968 .13423 L
.29101 .13443 L
.29227 .13467 L
.29342 .13494 L
.29624 .13582 L
.29887 .13692 L
.30482 .14036 L
.31007 .14443 L
.31567 .15002 L
.32666 .16355 L
.33148 .16947 L
.33678 .17523 L
.33931 .17747 L
.34203 .17935 L
.34353 .18011 L
.34489 .18063 L
.34627 .18096 L
.34757 .18111 L
.34824 .18113 L
.34898 .18109 L
.34975 .181 L
.35048 .18087 L
.35177 .18051 L
.35317 .17996 L
.35471 .17917 L
.35634 .17814 L
.35925 .17581 L
.36949 .16415 L
.37511 .15728 L
.38043 .15173 L
.38296 .14956 L
.38563 .14768 L
.38703 .14689 L
.38857 .14619 L
.38925 .14595 L
.38997 .14573 L
.39128 .14547 L
.39255 .14537 L
.39392 .14544 L
.39523 .1457 L
.39644 .1461 L
.39763 .14666 L
.39872 .1473 L
.40115 .14924 L
.40363 .15193 L
.40592 .15507 L
Mistroke
.41108 .16468 L
.41563 .17606 L
.42043 .19048 L
.42555 .20704 L
.4304 .22162 L
.43308 .2283 L
.43449 .23124 L
.43599 .23382 L
.43725 .23551 L
.43863 .23685 L
.4399 .23755 L
.44108 .23774 L
.44221 .23751 L
.44344 .23679 L
.44472 .23554 L
.44592 .23393 L
.44806 .23007 L
.45035 .22475 L
.46034 .19421 L
.46558 .17845 L
.46844 .17108 L
.47112 .16531 L
.47401 .1605 L
.47554 .15858 L
.47633 .15778 L
.47719 .15704 L
.47797 .1565 L
.47869 .15611 L
.47938 .15583 L
.48012 .15564 L
.48138 .15559 L
.48211 .15571 L
.48279 .15593 L
.48402 .15659 L
.48537 .15771 L
.48678 .15935 L
.48809 .16133 L
.49045 .16603 L
.49297 .17276 L
.49593 .18302 L
.49872 .19502 L
.50396 .22279 L
.50921 .25475 L
.51414 .28269 L
.51661 .29363 L
.518 .29837 L
.51928 .30167 L
.52066 .30404 L
.52145 .30479 L
.52218 .3051 L
Mistroke
.52351 .30468 L
.52426 .3039 L
.52493 .30286 L
.52615 .30025 L
.52743 .29651 L
.52972 .28761 L
.53491 .26084 L
.53973 .23402 L
.5443 .21234 L
.54679 .20326 L
.54811 .19944 L
.54951 .19619 L
.55068 .19413 L
.55197 .19259 L
.55315 .19189 L
.55425 .19185 L
.55556 .1926 L
.55693 .19433 L
.55811 .19658 L
.55939 .19989 L
.56078 .20446 L
.56226 .21052 L
.56492 .22455 L
.57011 .26307 L
.57501 .30933 L
.57729 .33132 L
.57975 .35281 L
.58093 .36179 L
.58206 .36918 L
.58309 .37478 L
.58418 .37943 L
.58538 .3829 L
.5865 .38445 L
.58783 .38416 L
.58904 .38191 L
.59036 .37736 L
.59111 .37389 L
.5918 .37017 L
.59439 .35216 L
.59954 .30543 L
.6052 .25533 L
.60755 .2386 L
.61008 .2244 L
.6113 .21896 L
.61246 .21471 L
.61349 .21166 L
.61463 .20909 L
.61583 .20728 L
.6171 .20638 L
.61829 .20648 L
Mistroke
.61939 .20738 L
.6207 .20944 L
.62189 .21227 L
.62326 .21667 L
.62457 .22196 L
.62729 .23633 L
.62984 .25382 L
.63463 .29444 L
.63734 .31948 L
.64021 .34436 L
.64266 .36193 L
.64405 .36962 L
.64535 .37496 L
.64655 .37814 L
.64769 .37951 L
.64871 .37934 L
.64982 .37763 L
.65103 .37402 L
.65231 .36828 L
.65341 .36196 L
.65462 .35361 L
.66465 .25884 L
.6698 .21503 L
.67262 .19591 L
.67523 .18111 L
.67987 .16109 L
.68232 .15324 L
.68495 .14658 L
.68777 .14103 L
.69084 .13651 L
.69374 .13328 L
.69641 .13095 L
.69903 .12914 L
.70147 .12783 L
.70403 .1268 L
.70538 .12638 L
.70684 .12602 L
.70821 .12574 L
.70951 .12554 L
.711 .12535 L
.71235 .12522 L
.71363 .12513 L
.71481 .12506 L
.7161 .12502 L
.71746 .125 L
.71884 .12502 L
.71962 .12504 L
.72032 .12508 L
.72169 .12518 L
.72299 .12532 L
Mistroke
.7245 .12554 L
.72589 .12578 L
.72905 .12651 L
.73392 .12797 L
.73929 .13004 L
.74489 .13287 L
.75015 .13616 L
.76957 .15046 L
.77489 .15393 L
.77782 .15548 L
.78057 .15666 L
.78315 .15751 L
.7846 .15787 L
.78594 .15813 L
.78706 .15829 L
.7883 .1584 L
.78959 .15844 L
.7908 .15841 L
.79211 .15829 L
.79284 .15819 L
.79353 .15807 L
.79478 .1578 L
.79611 .15744 L
.79866 .15655 L
.80096 .15556 L
.81187 .14947 L
.81736 .14617 L
.82025 .1446 L
.82329 .14319 L
.82596 .14221 L
.82748 .14178 L
.82889 .14147 L
.83019 .14127 L
.83137 .14115 L
.83274 .14109 L
.83403 .14113 L
.83523 .14124 L
.83653 .14145 L
.83775 .14175 L
.83887 .1421 L
.84018 .14261 L
.84161 .14331 L
.84421 .14496 L
.84691 .14723 L
.8498 .15025 L
.855 .15725 L
.86508 .17572 L
.87436 .19431 L
.87707 .19883 L
.87961 .20231 L
Mistroke
.88099 .20385 L
.88225 .20501 L
.88365 .20601 L
.88443 .20642 L
.88516 .20672 L
.88583 .20691 L
.88656 .20704 L
.88734 .20707 L
.88806 .207 L
.88936 .20665 L
.89008 .20632 L
.89075 .20595 L
.89217 .20491 L
.89372 .2034 L
.89684 .19932 L
.90793 .17843 L
.91318 .16834 L
.91802 .16052 L
.92043 .15741 L
.9231 .15472 L
.92448 .15365 L
.92577 .15288 L
.92714 .1523 L
.9279 .15209 L
.9286 .15196 L
.92988 .15191 L
.93106 .15208 L
.93235 .1525 L
.93373 .15323 L
.93505 .15421 L
.93629 .15539 L
.9386 .15829 L
.94128 .16287 L
.94411 .16917 L
.94918 .18428 L
.9606 .23147 L
.96302 .2417 L
.96566 .25171 L
.96798 .25904 L
.96925 .26228 L
.97045 .26476 L
.97181 .26687 L
.97253 .26765 L
.97331 .26823 L
.9747 .26856 L
.97596 .26809 L
.97713 .267 L
.97841 .26512 L
.97975 .26243 L
.98099 .25932 L
Mistroke
.98581 .24291 L
.99019 .22484 L
1 .18863 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo03gooooo3?l0001Wooooo`00]Oooool2o`0003cooooo0_l0000<ooooo`;o
0000IOooool006kooooo1Ol00012ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3Oooool2o`0006?ooooo001Gooooo`[o00002?ooool5o`0000Cooooo1Ol0000nooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool04?ooool2o`00067ooooo001Fooooo`03o`000?oooooo
oooo00Sooooo2?l0000>ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo05kooooo001Eooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04Oooool7o`0004Gooooo001Dooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05_ooool4o`00023ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00gooooo0ol00006ooooo`03o`000?oooooooooo04?o
oooo001Dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05?ooool2o`0000?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000ooooooooool0@_ooool005Cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo1?l0
000Xooooo`00Doooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool2o`0003Sooooo00?o0000
ooooooooool06_ooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00;o00009oooool005?ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool2o`00
0003ooooool0003o000000?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Loooo
o`Oo00004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09?ooool005;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`005Oooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0=ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00?o0000ooooooooool02_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h2ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000027ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0<ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo
00gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000Sooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03o`000?oooooooooo00cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol@413o^[Zjo`000?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Ko00000_ooool01?l0003oooooooooool00004ooooo`05oa0@4?ooooooooooooooool@
41000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00008oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0ol0003oooooooooo`0=ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400Nooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Moooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooo
oooo013ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000017ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo00oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001kooooo00?o0000oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`004oooool00ooMgMgoEEEEooooo`06o`0000?ooooo
00?o0000ooooooooool06_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`0Aooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Booooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooo000002?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool04?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000007Oooool00ol@413o0000o`000003ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`04ogMgMoo<c<co0000
o`0000;ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0Kooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo01;ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01;ooooo1Ol00005ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool3o`0002;ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00[ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o0000ooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4
A4Co000000Cooooo00Go0000oiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool03oooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01oooool2o`0002?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03Oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`04oa0@4?nHV9SooooookZj^P;o00000_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
5Oooool00omgMgOo0000ooooo`03ooooo`05o`000?lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooo
oooo00oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0_l0000Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooooooo00gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01_nYZJWo410@o`00
0?l@413oZJVYo`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`;o0000=_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo000Kooooo`03
o`000?oooooooooo023ooooo0_l0000@ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`;o00003oooool3o`0002Cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0Nooooo`Co0000
3oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool2o`0000oooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo017ooooo000Looooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo0000
3oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool2o`0000kooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool07_ooool01?l0003ooooo
ooooool0000?ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`;o00003_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Booooo`005_ooooooo`00043o00004oooool001Kooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004ooo
ool001Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000001?ooooo000Mooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?o
oooo000Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool001kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0_l0000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo000Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`;o00002oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool2
o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C_ooool01Ol0
003ooooooooooooooooo0000013ooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo000Noooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo04kooooo00Go0000ooooooooooooooooo`00000@ooooo`?o00002_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`?o00004Oooool00ol0
003oooooo`00000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool001kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0I?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo000O
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo06Cooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Fooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05_ooool001oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1T
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool001oooooo00?o0000
ooooooooool02_ooool2o`0000cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0G_ooool01Ol0003ooooooooooooooooo000001Wooooo000O
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0I?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G_ooool01Ol0003ooooooooo
oooooooo000001Wooooo000Oooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
I?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Goooool00ol0003oooooo`00000Jooooo`007oooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0I?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Goooool3o`0001[ooooo000Oooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooo
oooo00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo000Oooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Uooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo
000Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Uooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0OOooool0023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0OOooool0023ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0OOooool0023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0OOoo
ool0023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0OOooool0023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07gooooo000Pooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Jooooo`Go00001_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0OOooool0023ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0ol0000?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07gooooo000Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07ko
oooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1nooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0G_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0O_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Kooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0O_ooool0027ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1nooooo`008_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool2o`0001Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
O_ooool002;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`008_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo0000087ooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000POoo
ool002;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go
0000ooooooooooooooooo`000021ooooo`008_ooool01Ol0003ooooooooooooooooo000000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000087ooooo000Sooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
087ooooo000Sooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo0000087ooooo000Sooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000003_oo
ool01Ol0003ooooooooooooooooo0000087ooooo000Sooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool0
0000J_ooool2o`0001Sooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?oooooooooo
ooooool00000POooool002?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00001Zooooo`03o`000?oo
oooooooo01Oooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000087o
oooo000Sooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000@oooo
o`04o`000?ooooooooooo`0006[ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000@ooooo`03o`000?oooooo000008;ooooo000Sooooo`03o`000?oooooo000000cooooo00Go0000
ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0006[ooooo00?o0000ooooooooool0
5oooool01?l0003oooooooooool0000@ooooo`03o`000?oooooo000008;ooooo000Sooooo`?o0000
3?ooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo0000J_ooool00ol0
003oooooooooo`0Gooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooool00000P_ooool0
02Cooooo0_l0000<ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0
001Zooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00004Oooool2o`0008;ooooo
000cooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooool00000Joooool00ol0003ooooo
ooooo`0Hooooo`;o00004_ooool00ol0003oooooooooo`21ooooo`00<oooool01?l0003ooooooooo
ool0000Aooooo`;o0000Joooool00ol0003oooooooooo`0Hooooo`;o0000U_ooool003?ooooo00Co
0000oooooooooooo00004Oooool2o`0006_ooooo0_l0002aooooo`00<oooool00ol0003oooooo`00
001oooooo`03o`000?oooooooooo0;3ooooo000dooooo`;o0000Ooooool00ol0003oooooooooo`2`
ooooo`00=?ooool2o`0007oooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo
002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:[ooooo1Ol00006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`
ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool0
0:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`
ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnY
ZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Ko
oooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41So
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
0on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oo
oooooooo00Go00001Oooool2o`000003oa0@4?oooooooooo07Kooooo0021ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0Moooool0087ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool5
o`0007Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2oooool6o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`04odA4
A?oMgMgoooooo`0007Wooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmE
EEGoooooo`0007Wooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003o`00
01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03ogMgMoo<c<co0000
07Wooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03onk^k_m4A4Co000007Wooooo
0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l00000
1?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?oMgMgo`000?ooool0N?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14859 m
.01975 .22477 L
.02492 .26468 L
.02981 .30269 L
.03251 .32007 L
.03403 .32779 L
.03476 .33082 L
.03544 .33325 L
.03663 .33647 L
.03793 .33847 L
.0392 .33882 L
.04057 .33743 L
.04129 .33597 L
.04197 .33419 L
.04349 .32871 L
.04484 .32238 L
.04628 .31435 L
.0515 .27831 L
.05639 .24356 L
.05896 .22776 L
.06168 .21403 L
.06323 .20778 L
.06493 .20238 L
.06568 .20051 L
.06648 .19885 L
.06724 .19763 L
.06793 .19679 L
.06868 .1962 L
.06937 .19595 L
.07014 .19601 L
.07095 .19646 L
.07231 .19811 L
.07308 .19957 L
.07381 .20127 L
.07516 .20532 L
.07657 .21086 L
.0791 .22417 L
.08183 .24358 L
.08481 .27081 L
.08989 .32852 L
.09257 .36055 L
.0954 .39101 L
.09659 .40173 L
.09788 .41133 L
.09861 .41582 L
.09929 .41921 L
.1006 .42378 L
.10178 .42544 L
.10306 .42457 L
.10428 .42122 L
Mistroke
.1054 .41603 L
.10691 .40618 L
.10833 .39431 L
.11098 .36714 L
.11693 .29892 L
.12196 .25152 L
.12334 .24161 L
.12479 .23269 L
.12615 .22581 L
.1274 .22065 L
.12868 .21651 L
.12935 .21483 L
.13008 .21333 L
.13131 .21165 L
.13262 .21099 L
.1338 .21139 L
.13508 .21287 L
.13628 .21525 L
.13738 .21828 L
.13867 .22285 L
.13986 .22807 L
.14258 .24332 L
.14806 .28672 L
.15286 .3328 L
.15738 .37234 L
.1586 .38065 L
.15988 .38786 L
.16055 .3909 L
.16129 .39363 L
.16259 .39676 L
.16377 .39769 L
.16504 .39662 L
.16623 .39366 L
.16732 .38938 L
.16856 .38284 L
.16972 .3752 L
.17236 .35345 L
.17771 .30009 L
.1824 .25522 L
.18734 .21726 L
.18995 .20146 L
.1928 .1872 L
.19782 .16877 L
.20065 .16139 L
.20367 .15531 L
.20913 .14744 L
.21471 .14176 L
.21986 .13804 L
.22552 .13515 L
.23151 .13263 L
Mistroke
.23402 .13171 L
.23671 .1309 L
.23802 .13058 L
.23926 .13033 L
.24048 .13013 L
.24158 .12998 L
.24291 .12984 L
.24364 .12979 L
.24433 .12974 L
.24556 .12969 L
.24688 .12966 L
.24758 .12966 L
.24835 .12966 L
.24915 .12968 L
.24989 .12971 L
.25123 .1298 L
.25198 .12987 L
.25267 .12995 L
.2539 .13013 L
.25507 .13036 L
.25645 .1307 L
.25772 .13109 L
.2603 .13211 L
.26308 .13353 L
.26778 .1366 L
.27272 .14068 L
.28314 .1528 L
.29452 .16846 L
.30008 .1752 L
.30281 .17788 L
.30401 .17887 L
.30532 .17981 L
.30643 .18046 L
.30761 .18102 L
.30886 .18145 L
.31003 .18169 L
.3114 .18178 L
.3127 .18169 L
.31386 .18145 L
.31513 .18104 L
.31663 .18035 L
.31803 .17952 L
.32066 .17751 L
.32349 .17471 L
.32655 .17106 L
.33713 .15595 L
.34715 .14336 L
.3499 .14065 L
.35283 .13825 L
.35426 .1373 L
Mistroke
.3556 .13654 L
.35691 .13595 L
.35813 .13551 L
.3594 .13519 L
.36008 .13508 L
.3608 .135 L
.36156 .13496 L
.36229 .13497 L
.36364 .13511 L
.36491 .13537 L
.36608 .13574 L
.36737 .13628 L
.36874 .13703 L
.37023 .13806 L
.37185 .13944 L
.37478 .14269 L
.37764 .14689 L
.38026 .15168 L
.39061 .17868 L
.3963 .19772 L
.4017 .21586 L
.40413 .22307 L
.40671 .2295 L
.40806 .23221 L
.40954 .23462 L
.41089 .23624 L
.41216 .23725 L
.41333 .23772 L
.41456 .23774 L
.41561 .23737 L
.41676 .23657 L
.418 .23525 L
.41932 .23333 L
.42171 .22866 L
.431 .20057 L
.44083 .16921 L
.44597 .15681 L
.44889 .15131 L
.45162 .14725 L
.45291 .14572 L
.45413 .1445 L
.45524 .14359 L
.45642 .14282 L
.4577 .14223 L
.45888 .1419 L
.45961 .14181 L
.46029 .14179 L
.46157 .14195 L
.46287 .14237 L
.46361 .14272 L
Mistroke
.4643 .14312 L
.46569 .14417 L
.46718 .14564 L
.46988 .14928 L
.47234 .15382 L
.4752 .16073 L
.47831 .17037 L
.48397 .19366 L
.49403 .24878 L
.49938 .27682 L
.50084 .28295 L
.50238 .28833 L
.50369 .29192 L
.50443 .2935 L
.50513 .29468 L
.50581 .29554 L
.50654 .29615 L
.50782 .29638 L
.50855 .29604 L
.50931 .29532 L
.51069 .29313 L
.51196 .29012 L
.51315 .28653 L
.51586 .27593 L
.52592 .22281 L
.53139 .1964 L
.53408 .1859 L
.53657 .17789 L
.53943 .17077 L
.54094 .16789 L
.54254 .16548 L
.54388 .16398 L
.54513 .16299 L
.54651 .16238 L
.54728 .16226 L
.54799 .1623 L
.54933 .16276 L
.55059 .16367 L
.55172 .16491 L
.55295 .16672 L
.55429 .16927 L
.55571 .17266 L
.55826 .18061 L
.56061 .19021 L
.56281 .20128 L
.56783 .23429 L
.57315 .27987 L
.57597 .30599 L
.57897 .33238 L
.58045 .34388 L
Mistroke
.58184 .35328 L
.5832 .3608 L
.58446 .36606 L
.58565 .36946 L
.5869 .37124 L
.58817 .37112 L
.58955 .36879 L
.59023 .36683 L
.59098 .3641 L
.59233 .35769 L
.59486 .34133 L
.60055 .2929 L
.60553 .25063 L
.60826 .23125 L
.61082 .21643 L
.61313 .20613 L
.61443 .20168 L
.61562 .19846 L
.61685 .196 L
.6182 .19434 L
.61888 .19392 L
.61961 .19377 L
.62092 .1943 L
.62213 .19572 L
.62344 .19826 L
.62468 .20165 L
.62582 .20563 L
.62798 .21549 L
.63027 .22934 L
.63545 .27354 L
.64018 .3254 L
.64265 .35291 L
.64528 .37889 L
.64679 .39104 L
.64816 .39966 L
.64953 .4057 L
.65083 .40872 L
.65203 .40912 L
.6533 .40698 L
.65438 .40314 L
.65557 .39689 L
.65685 .38796 L
.65822 .37621 L
.66069 .35064 L
.67006 .24341 L
.67276 .2186 L
.67563 .19687 L
.67811 .18164 L
.68077 .16848 L
.68363 .15758 L
Mistroke
.68631 .14994 L
.68794 .14633 L
.68949 .14354 L
.69102 .14134 L
.69241 .13973 L
.69363 .1386 L
.69494 .13762 L
.69634 .13682 L
.69765 .13626 L
.69888 .13589 L
.70018 .13564 L
.70129 .13553 L
.70251 .13552 L
.70325 .13557 L
.70395 .13565 L
.70527 .13589 L
.706 .13608 L
.70668 .13628 L
.70822 .13685 L
.7108 .13809 L
.71355 .13971 L
.72361 .1466 L
.7291 .1505 L
.73421 .15383 L
.73646 .15505 L
.73858 .156 L
.73976 .15644 L
.74103 .15684 L
.74218 .15714 L
.74326 .15737 L
.74445 .15756 L
.74576 .1577 L
.74704 .15777 L
.74841 .15777 L
.74968 .1577 L
.75089 .15757 L
.75198 .15739 L
.75316 .15714 L
.75454 .15676 L
.75584 .15632 L
.75826 .15529 L
.76369 .15217 L
.77346 .14536 L
.78411 .13821 L
.7867 .13685 L
.78947 .13567 L
.79106 .13514 L
.79251 .13474 L
.79397 .13443 L
.79535 .13422 L
Mistroke
.79656 .1341 L
.7979 .13404 L
.79857 .13404 L
.79929 .13407 L
.8006 .13418 L
.80184 .13437 L
.80314 .13467 L
.80425 .135 L
.80546 .13546 L
.80822 .13687 L
.81116 .13897 L
.81645 .14429 L
.82169 .15148 L
.82662 .16005 L
.83586 .17953 L
.84114 .19073 L
.84608 .19953 L
.84856 .20293 L
.84984 .20434 L
.85123 .20558 L
.85202 .20614 L
.85275 .20656 L
.85345 .20687 L
.85419 .2071 L
.85492 .20723 L
.85561 .20726 L
.85689 .20708 L
.85802 .20667 L
.85926 .20595 L
.86055 .20491 L
.86175 .20369 L
.86621 .19733 L
.87108 .18805 L
.87628 .17683 L
.887 .1552 L
.88994 .1506 L
.89305 .14653 L
.89571 .14375 L
.89722 .14247 L
.89864 .14144 L
.89996 .14068 L
.90065 .14034 L
.90139 .14004 L
.90269 .13965 L
.9039 .13945 L
.90464 .13941 L
.90543 .13944 L
.90618 .13954 L
.90687 .13969 L
.90818 .14014 L
Mistroke
.90956 .14086 L
.91078 .1417 L
.91208 .14283 L
.91444 .14546 L
.91724 .14966 L
.91979 .15456 L
.93032 .1871 L
.93564 .21031 L
.94152 .23721 L
.94395 .24729 L
.94651 .25635 L
.94785 .26025 L
.94931 .26372 L
.95065 .26608 L
.95189 .26754 L
.95315 .26827 L
.95435 .26823 L
.95543 .26759 L
.95659 .26625 L
.95786 .26407 L
.95921 .26097 L
.96162 .25365 L
1 .14859 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001Qooooo`So0000C?ooool2o`000;7ooooo001Nooooo`?o0000
2?ooool2o`0004[ooooo00?o0000ooooooooool0Foooool3o`0005;ooooo001Mooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06?ooool6o`0002Wooooo00?o0000ooooooooool0>ooo
ool5o`0001Sooooo0ol00002ooooo`?o0000D?ooool005_ooooo0_l0000?ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03[ooooo0_l00004ooooo`?o00004oooool2o`0000Sooooo00?o0000ooooooooool06Oooool4
o`00033ooooo001Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool2o`00
00Oooooo00?o0000ooooooooool05oooool4o`0000[ooooo00?o0000ooooooooool0>Oooool2o`00
00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Oooooo0_l00002ooooo`;o0000;oooool005Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooooooo01Gooooo0_l00005oooo
o`03o`000?oooooooooo02cooooo000Fooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`;o0000
4Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`;o0000>?oo
ool00ol0003oooooooooo`0=ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01;ooooo000Gooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0?ooooo`Ko00005Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`005oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo000Eooooo`?o00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03oooool00ol0003oooooooooo`09ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`Co0000
00So410@o`000?ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0@
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000oooooooo
ool03?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo
00Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool00ol0003oooooooooo`0@ooooo`;o000000Wo410@o`000?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h03_ooool001Kooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00[o0000oooooooo
ooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooo
ooooool03?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Dooooo`03o`000?oooooooooo00Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
Mol0003ooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool00_ooool6o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool02?oo
ool01?l0003oooooooooooooool6o`0000Gooooo00Ko0000ooooooooooooooooo`000?l@4103oooo
o`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooo
oooo00gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01Cooooo00?o
0000ooooooooool02?ooool01_l0003ooooooooooooooooo410@o`0000;ooooo00?o410@oooooooo
ool02?ooool00ol0003oooooooooo`0>ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00kooooo000Cooooo`06odA4A?oMgMgoooooo`000?oooooo00000_ooool01Ol0003ooooooooooooo
oooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000gooooo
00?o0000ooooooooool03Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooo
oooooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo00kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000001Gooooo00?o0000ooooooooool01_ooool00onYZJWo410@ooooo`02ooooo`;o00000_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?oA4A4omgMgOooool00_l0
0003ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00KogMgMoeEEEOoooooo0000
ooooool00002ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00Gooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03Oooool0
0ooMgMgoEEEEooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool0
1OmgMgOoc<c<o`000?oooooo000000;ooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo00oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Gooooo0ol000000ooo
oooo0000o`00000Aooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@400:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Q
ooooo`02ooooo`05o`000?ooooooooooooooool@41002oooool00ol0003oooooooooo`0>ooooo`04
ogMgMoo<c<co0000o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^
k^koA4A4o`000002ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09
ooooo`?o00004_ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03?ooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo
00;ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg
3?ooool00ol0003oooooooooo`0=ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`005Oooool02omgMgOo0000oooooooooooo0000ooooooo^k^ko<S8bo`000?lb
<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool00ol0003oooooooooo`0<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000o`000?lb
<S;ok^k^00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool02Ol0
003oooooooooooooooooZJVYoa0@4?l0003o410@ojVYZ@02ooooo`06o`000?o^k^ko<S8bo`000?lb
<S;ok^k^3?ooool00ol0003oooooooooo`0>ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`006Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`006Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooooooo00kooooo
0_l0000Uooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00oooooo0ol0000@ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05_ooool001[ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`00
000Tooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool000004?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooooooo00gooooo0_l00000
0ooooooo0000ooooo`0Sooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool001Koooooool00010
o`0001?ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`;o00001_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool4o`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`005_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01?l0003ooooo
o`000?l00004ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00006ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`006oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
o`00000?ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Iooooo`007?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Iooooo`007?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`007?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Jooooo`007?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Jooooo`007?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0000Fooooo`03o`00
0?oooooooooo00;o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`007Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool3o`0001Kooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`007Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Goooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01_ooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06oooool001gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0L
ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo000Mooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool001gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0HOooool3o`0000Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Ooo
ool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo067ooooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool0
1Ol0003ooooooooooooooooo0000023ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1Qooooo`;o00001Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooooooo00008?ooool001kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06;ooooo0_l00005
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F?ooool2o`00027ooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Roooo
o`;o00001?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`00
7_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Noooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07_ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Sooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07_ooooo000Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Sooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1k
ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0I?ooool2o`0000;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1koooo
o`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0I?ooool2o`000003ooooool0003ooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Noooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo
00Co0000ooooool0003o00005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1kooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`Go00001_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0ol0000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1looooo`008?ooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O?ooool0023ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Pooooo`05o`000?oooooooooooooo
ool000003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Iooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Pooooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Qooooo`04o`000?oooooo
ooooo`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07cooooo000Qooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Qooooo`03o`000?oooooo
000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0IOooool2o`0001Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0OOooool0
027ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0OOooool002;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0OOooool003;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo
000cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1mooooo`00<oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0OOoo
ool003?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Gooooo`04o`000?oooooo
ooooo`0000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`00<oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00003ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo000cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0OOooool003?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool2
o`0001Sooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07gooooo000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000006Sooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00
000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_ooool003?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000J?oo
ool00ol0003oooooooooo`0Hooooo`?o00004?ooool01Ol0003ooooooooooooooooo0000083ooooo
000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooo
oooooooo000006Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool00000P?ooool003?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool00000J?ooool00ol0003oooooooooo`0[ooooo`05
o`000?ooooooooooooooool00000P?ooool003Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`05o`000?ooooooooooooooool00000J?ooool00ol0003oooooooooo`0[oooo
o`05o`000?ooooooooooooooool00000P?ooool003Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`04o`000?ooooooooooo`0006Wooooo00?o0000ooooooooool0:oooool0
1Ol0003ooooooooooooooooo0000083ooooo000dooooo`05o`000?ooooooooooooooool000003ooo
ool01?l0003oooooooooool0001Yooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooooooo
ooooo`000020ooooo`00=?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooool0
0000JOooool2o`0002gooooo00Co0000oooooooooooo0000P?ooool003Cooooo00Go0000oooooooo
ooooooooo`00000@ooooo`03o`000?oooooo000006Wooooo00?o0000ooooooooool0;?ooool01?l0
003oooooooooool00020ooooo`00=?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooool00000JOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo0000087ooooo000doooo
o`05o`000?ooooooooooooooool000004?ooool2o`0006[ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooo`000021ooooo`00=?ooool01Ol0003ooooooooooooooooo000007cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooo`000021ooooo`00=?ooool01Ol0003ooooooooooooooooo
000007?ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooool00000POooool003Cooooo00Go0000ooooooooooooooooo`00001dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`000021ooooo`00=Oooool01?l0
003oooooooooool0001aooooo`Go00001_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo083ooooo000eooooo`03o`000?oooooo000007;ooooo00CoA4A4omgMgOoooooo00001oooool3
o`000;3ooooo000eooooo`03o`000?oooooo000007;ooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2`ooooo`00=Oooool00ol0003oooooo`00001cooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0/?ooool003Gooooo00?o0000ooooool00000Loooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo07?ooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_oo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02i
ooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooo
okZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYoooo
o`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko
410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o410@
olc<c01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0
000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000007So
oooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6
o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?nHV9So
oooooiRHV?lQ8B40N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oeEE
EOl0003o410@olc<c01hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l00000
0ol0000Looooo`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooooooooeEEEOn7QhMkoooo
o`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00ooMgMgo410@oiRHV01jooooo`00P?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`04olc<c?m4A4Co0000oa0@47Sooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(128) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16863 m
.00942 .21373 L
.01975 .28149 L
.02243 .29737 L
.02496 .30953 L
.02635 .31466 L
.02709 .31685 L
.02787 .31875 L
.02925 .321 L
.03053 .3218 L
.03171 .32142 L
.03299 .31982 L
.0342 .31723 L
.0353 .314 L
.038 .30307 L
.04057 .28962 L
.05081 .22808 L
.05375 .21289 L
.05653 .20071 L
.05905 .19159 L
.06172 .18399 L
.06315 .18074 L
.06472 .17781 L
.06614 .1757 L
.06747 .1742 L
.06828 .17349 L
.06904 .17297 L
.06973 .17263 L
.07047 .17239 L
.07128 .17227 L
.07215 .17234 L
.07288 .17254 L
.07369 .17293 L
.07439 .17341 L
.07513 .17406 L
.07645 .17562 L
.07787 .17788 L
.07943 .18111 L
.08221 .18899 L
.08481 .19895 L
.12581 .31626 L
.13105 .26759 L
.13362 .24812 L
.13596 .2337 L
.13843 .22226 L
.13979 .21765 L
.14108 .2144 L
.14176 .21314 L
.14248 .21214 L
.14378 .2112 L
Mistroke
.14457 .21119 L
.14532 .21157 L
.14599 .21223 L
.14671 .2133 L
.14745 .21476 L
.14814 .21646 L
.1497 .2216 L
.15123 .22834 L
.15286 .2375 L
.15582 .25934 L
.15851 .28493 L
.16416 .35091 L
.16664 .38028 L
.16796 .39447 L
.16938 .40794 L
.17073 .41851 L
.17197 .42588 L
.17315 .43061 L
.1744 .43295 L
.17571 .43237 L
.17694 .429 L
.17828 .42228 L
.17904 .41722 L
.17972 .41189 L
.18249 .38403 L
.1855 .34642 L
.19095 .27547 L
.19612 .2209 L
.19872 .19987 L
.20158 .18129 L
.20402 .16866 L
.20663 .15797 L
.20911 .15022 L
.21136 .14487 L
.21375 .14071 L
.21512 .13892 L
.2164 .13755 L
.21765 .13647 L
.21897 .13557 L
.22042 .13483 L
.22175 .13435 L
.2229 .13408 L
.22413 .13392 L
.22529 .13391 L
.22635 .13401 L
.22759 .13426 L
.22893 .1347 L
.2302 .13527 L
.23137 .13593 L
.23398 .1378 L
Mistroke
.23641 .13998 L
.24195 .14599 L
.25316 .16157 L
.25838 .16936 L
.26114 .17302 L
.26407 .17639 L
.26689 .17902 L
.26945 .18083 L
.27068 .1815 L
.27202 .18205 L
.27328 .18239 L
.27444 .18256 L
.27557 .18257 L
.27677 .18241 L
.27791 .1821 L
.27895 .18168 L
.28017 .18103 L
.28149 .18012 L
.2839 .17801 L
.28909 .17189 L
.2939 .16509 L
.30334 .15061 L
.30829 .14363 L
.31351 .13759 L
.31629 .13494 L
.31933 .13249 L
.32213 .13065 L
.32467 .12937 L
.32602 .12886 L
.3273 .12849 L
.32864 .12823 L
.3294 .12814 L
.3301 .12809 L
.33127 .1281 L
.33255 .12822 L
.33389 .12847 L
.33515 .12883 L
.33646 .12932 L
.33786 .12998 L
.34038 .13153 L
.34337 .13406 L
.34608 .13708 L
.35143 .14541 L
.35646 .15624 L
.36582 .18336 L
.37106 .20106 L
.37593 .21679 L
.37842 .22365 L
.38077 .22897 L
.38207 .23134 L
Mistroke
.38348 .23339 L
.38476 .23477 L
.38595 .23561 L
.38726 .23604 L
.38848 .23597 L
.38983 .23537 L
.39058 .23479 L
.39128 .23412 L
.39266 .23236 L
.39417 .22986 L
.39692 .22388 L
.40853 .18827 L
.41402 .17196 L
.41906 .15944 L
.42417 .14961 L
.42685 .14566 L
.42969 .14237 L
.43216 .14022 L
.43447 .13874 L
.43579 .13812 L
.437 .13769 L
.43766 .13751 L
.43839 .13735 L
.43971 .13719 L
.44107 .13718 L
.44234 .13733 L
.44307 .13749 L
.44374 .13768 L
.44525 .13827 L
.44662 .13902 L
.44812 .14008 L
.45114 .14301 L
.45379 .14652 L
.45662 .15131 L
.46173 .1631 L
.47188 .20137 L
.48262 .25778 L
.48533 .27077 L
.48824 .28218 L
.4899 .28711 L
.49143 .29038 L
.49216 .29149 L
.49296 .29236 L
.49371 .29283 L
.49441 .29297 L
.4951 .29282 L
.49584 .29234 L
.49718 .29066 L
.49848 .28804 L
.49968 .28483 L
Mistroke
.50241 .27502 L
.50529 .26174 L
.51495 .21038 L
.52027 .18582 L
.5253 .16777 L
.52815 .15997 L
.53125 .1534 L
.53261 .15109 L
.53406 .14902 L
.53531 .14752 L
.53666 .14621 L
.53802 .1452 L
.53926 .14455 L
.54045 .14417 L
.5417 .14404 L
.54307 .14423 L
.54435 .14475 L
.54509 .14519 L
.54576 .1457 L
.54725 .1472 L
.54851 .14886 L
.54969 .15078 L
.55236 .15652 L
.55496 .16414 L
.55776 .17479 L
.56281 .20169 L
.56743 .23575 L
.57292 .28566 L
.57594 .31363 L
.57877 .33694 L
.58117 .35233 L
.58252 .35862 L
.58376 .36267 L
.58504 .365 L
.58577 .36545 L
.58645 .3653 L
.58781 .36332 L
.58858 .36126 L
.58928 .35882 L
.59052 .35316 L
.59184 .34553 L
.59421 .32836 L
.59956 .28081 L
.60424 .24031 L
.60928 .20636 L
.61208 .19268 L
.61464 .1833 L
.61586 .17982 L
.61721 .17678 L
.61847 .17462 L
Mistroke
.61965 .17325 L
.62037 .17271 L
.62114 .17239 L
.62187 .17232 L
.62255 .17248 L
.62383 .17333 L
.62518 .17503 L
.62588 .17623 L
.62663 .17778 L
.62799 .18122 L
.63107 .19225 L
.63376 .20567 L
.63662 .22406 L
.64175 .26814 L
.64775 .33235 L
.65068 .36289 L
.65197 .37473 L
.65338 .38607 L
.65451 .39376 L
.65573 .40026 L
.65701 .40504 L
.65821 .40743 L
.65888 .40788 L
.65961 .40764 L
.66094 .40527 L
.66223 .40068 L
.66342 .39459 L
.66598 .37632 L
.6688 .35043 L
.6745 .29264 L
.67998 .24533 L
.68268 .22729 L
.68518 .2136 L
.68984 .19469 L
.69231 .18751 L
.69493 .18152 L
.69778 .17651 L
.70086 .17238 L
.70644 .16683 L
.71687 .1582 L
.73744 .14063 L
.74308 .13646 L
.74911 .13283 L
.75203 .13143 L
.7548 .13037 L
.75729 .12965 L
.75869 .12935 L
.75999 .12915 L
.76123 .12903 L
.76237 .12897 L
Mistroke
.76368 .12898 L
.76493 .12905 L
.76608 .12918 L
.76715 .12936 L
.76832 .12962 L
.76957 .12996 L
.77242 .13104 L
.77511 .13246 L
.77752 .13411 L
.78014 .13631 L
.78555 .14235 L
.79126 .15094 L
.80151 .1714 L
.81145 .19317 L
.81431 .1984 L
.81702 .20247 L
.81946 .20521 L
.82084 .20634 L
.82211 .20708 L
.82321 .20749 L
.8244 .20767 L
.82552 .20761 L
.82654 .20734 L
.82768 .20681 L
.82893 .20595 L
.83023 .20477 L
.83144 .20341 L
.83623 .19592 L
.84135 .18533 L
.8521 .16122 L
.85775 .1502 L
.86375 .14105 L
.86899 .13535 L
.87196 .13306 L
.87339 .1322 L
.87475 .13153 L
.87597 .13106 L
.87731 .13069 L
.87852 .13049 L
.87964 .13042 L
.88098 .13049 L
.88219 .13069 L
.88286 .13087 L
.88359 .13111 L
.8849 .13167 L
.88621 .13241 L
.8874 .13324 L
.89007 .13567 L
.89255 .13869 L
.8949 .14229 L
Mistroke
.90015 .15344 L
.90312 .16182 L
.90586 .17097 L
.91727 .22073 L
.92286 .246 L
.92531 .25511 L
.9266 .25914 L
.92798 .26271 L
.92923 .26523 L
.93037 .26689 L
.93151 .26793 L
.93259 .26832 L
.9338 .26806 L
.93491 .26718 L
.93613 .26552 L
.93743 .26301 L
.93993 .25618 L
.94227 .24783 L
.9476 .22446 L
.95292 .19969 L
.95871 .17594 L
.96136 .16697 L
.96418 .15888 L
.96661 .15305 L
.96924 .14792 L
.97151 .14441 L
.97359 .14189 L
.97558 .14009 L
.97659 .13941 L
.97768 .13884 L
.97868 .13847 L
.97959 .13827 L
.98064 .13818 L
.98164 .13824 L
.98255 .13843 L
.9834 .13871 L
.98433 .13914 L
.98532 .13974 L
.98706 .14115 L
.98893 .14318 L
.99231 .14832 L
.99436 .15248 L
.99632 .15726 L
1 .16863 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001looooo`Ko0000<oooool2o`0004oooooo1ol0000Pooooo`?o
0000>?ooool005gooooo0_l0000Looooo`03o`000?oooooooooo00Cooooo0_l0000aooooo`03o`00
0?oooooooooo04_ooooo0ol00006ooooo`;o00007Oooool2o`0000;ooooo0_l0000gooooo`00Fooo
ool2o`0000;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01[ooooo0ol0000Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?oo
ool005[ooooo0_l00004ooooo`;o00005oooool2o`0000Wooooo00?o0000ooooooooool06?ooool3
o`000003ooooool0003o0000013ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0G
ooooo`Co00006?ooool005[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Aoooool2o`0000oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00Co0000oooo
oooooooooooo0_l0000Fooooo`00FOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`?o0000>_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo001Hooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`00
F?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2oooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`00Eooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_oo
ool005Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01;ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
6_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@oooo
o`03o`000?oooooooooo00Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPCooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQGooooo00?o0000ooooooooool00_oo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooooooo00kooooo
00Go0000oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo0_l000002Ol@413oooooooooool0003o
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00Sooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l0
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003ooooooooo
o`0=ooooo`06o`000?l@413o^[ZjoooooomgMgOo<S8b0oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`0:o`000?oooooooooo
ooooool0003oMgMgoiRHV?ooooooV9RHogMgM`kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`06o`0000?ooooo00?oV9RHob4Q
8Oo^k^h00_ooool00ol0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000003oooool6
o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Gooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000002oooool4o`0000kooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02_ooool00onHV9So8B4Q
onk^kP02ooooo`;o00000oooool01?l0003oooooooooool0000Gooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooo000000?o00000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool03?ooool01_l0003oooooooooooooooooZJVYoa0@40?o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001?ooooo00?ogMgMoeEEEOooool00_l00003ooooo`05o`000?ooooooooooooooool000002_oo
ool2o`0000;ooooo00?o0000ooooooooool02oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00;ooooo
00Oo0000ooooooooooooooooo`000?oooooo000001Sooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool02_ooool01ol0003ooooooooooooooooo410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?oo
ool01?mgMgOoc<c<o`000?l00003ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool03Oooool01_l0003ooooooooooooooooo
410@o`0000;ooooo00?o410@o`000?ooool06Oooool01?l0003oooooooooool00004ooooo`05oa0@
4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00So
oooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool2o`0000?o
oooo00Go0000oooooooooooooooooa0@400Aooooo`03o`000?oooooooooo00[ooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00Cok^k^odA4A?l0003o0000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00oooooo00?o0000ooooooooool02Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00?o
MgMgoiRHV?l000000_l0000Kooooo`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL04?ooool00ol0003oooooooooo`07oooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o
0000ooooooooool02Oooool01ol0003ooooooa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omg
MgOo0000o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`09ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Co0000oeEEEOmVIVKo00001?ooool0
1oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000004_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03oeEE
EOmVIVKo000000Cooooo00Go0000oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00So
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0ol0003oooooooooo`08ooooo`08o`000?ooooooooooojVYZOl@413o0000oa0@4?nYZJT3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Kooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Goooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool001Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Oooooo`006?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo023ooooo000Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool001Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`005_ooooooo`00
043o00004oooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`?o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0
0007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00gooooo0ol0000>ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`006Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Q
ooooo`006Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`006Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`006_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo0000013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02;ooooo000Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0hooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool001[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00Co0000ooooool0003o
00006_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`00
6_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
>oooool2o`0001_ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000013o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;o
oooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00004Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool001[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`006_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02?ooooo000Kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool08oooool001_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Sooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000001?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo
000Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo00?ooooo0ol0000Cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04cooooo00Go
0000ooooooooooooooooo`00000Vooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000001?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0COooool01?l0003oooooooooool0000Wooooo`006ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooo`00000Wooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000001?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0C_ooool2o`0002Sooooo000Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
00;ooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00;o
oooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07Sooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00;ooooo
0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07Sooooo000Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Looooo`05o`000?ooooooooooooooool00000
5_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1hooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooooooool2o`0001Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0NOooool001cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Eooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05gooooo00Co0000ooooool0003o00005_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`00
7Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOooool01?l0003o
ooooo`000?l0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000Mooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0GOooool4o`0001Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0NOooool001go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0NOooool001gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0NOooool001gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo000000[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`Go00001_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07Wooooo000Nooooo`05o`000?ooooooooooooooool000006_oo
ool2o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo
000Nooooo`05o`000?ooooooooooooooool000006_ooool2o`0000[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Fooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo07Wooooo000Nooooo`04o`000?ooooooooooo`0001_ooooo0_l0000:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00onHV9So8B4Qonk^kP06ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0NOooool001kooooo00Co0000oooooooooooo0000
7?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
FOooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
NOooool001kooooo0_l000000ooooooo0000ooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0NOooool001oooooo0_l0000Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0E_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1iooooo`00BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0N_ooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool004Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0N_ooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`;o
00005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1jooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`00B_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05_oo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1jooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool05_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1jooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool004[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000
4_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo001:ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Gooooo`04o`000?oo
ooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1jooooo`00B_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05ooo
ool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
N_ooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07[ooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool2
o`0001Wooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N_ooool0
04[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
07_ooooo001;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool004_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`00Boooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07_ooooo001;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Noooool004_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1koooo
o`00Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0;_ooool01Ol0003ooooooooooooooooo000007gooooo001;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0H_ooool2o`0002oooooo00Co0000oooooooooooo0000O_ooool004_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02ko
oooo00Co0000oooooooooooo0000O_ooool004_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo0000O_ooool004_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02ko
oooo00Co0000oooooooooooo0000O_ooool004_ooooo00Go0000ooooooooooooooooo`00001Uoooo
o`03o`000?oooooooooo02kooooo00Co0000oooooooooooo0000O_ooool004cooooo00Co0000oooo
oooooooo0000G?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool0
1?l0003oooooooooool0001nooooo`00C?ooool01?l0003oooooooooool0001Mooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0007oooooo001<ooooo`04o`000?oooooo
ooooo`0005[ooooo1Ol00006ooooo`03o`000?oooooooooo02oooooo0_l0001oooooo`00C?ooool0
1?l0003oooooooooool0001Jooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00C?oo
ool01?l0003oooooooooool0001Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool004cooooo00Co0000oooooooooooo0000Foooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo0;3ooooo001<ooooo`03o`000?oooooo000005cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`2`ooooo`00C?ooool00ol0003oooooo`00001Mooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0/?ooool004cooooo00?o0000ooooool00000I_ooool0
0ol0003oooooooooo`2`ooooo`00COooool2o`0006Kooooo00?o0000ooooooooool0/?ooool004go
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
0ol@413oooooooooo`05o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01hooooo`00POooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40N?ooool0087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oo
ooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooo
ooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80N?ooool0
087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c01hoooo
o`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oo
oooooooo00Kooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@4100N?ooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo^[Zjo`00001hooooo`00
P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0N?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(130) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20021 m
.00942 .24713 L
.01483 .27707 L
.01719 .28887 L
.01975 .29968 L
.02114 .3044 L
.02243 .30789 L
.02365 .3104 L
.02496 .31209 L
.02632 .31278 L
.02761 .31238 L
.02834 .31171 L
.02901 .3108 L
.02979 .30943 L
.03053 .3078 L
.03302 .30019 L
.03533 .29056 L
.04057 .26284 L
.04586 .23244 L
.05159 .20315 L
.057 .18132 L
.06198 .16638 L
.06476 .1601 L
.0678 .15482 L
.06934 .15277 L
.07098 .15101 L
.07178 .15031 L
.07254 .14975 L
.07321 .14933 L
.07395 .14895 L
.07526 .14851 L
.07598 .14839 L
.07665 .14836 L
.07786 .14852 L
.07915 .14901 L
.07984 .14941 L
.08059 .14996 L
.0821 .15149 L
.0835 .15343 L
.08481 .15575 L
.08757 .16243 L
.09011 .17105 L
.0929 .18366 L
.09586 .20115 L
.10082 .24137 L
.10629 .30005 L
.11115 .35514 L
.11255 .36901 L
.11388 .38055 L
.11509 .38931 L
Mistroke
.11637 .39655 L
.1176 .40123 L
.11871 .40345 L
.11983 .40368 L
.12089 .40205 L
.12212 .39794 L
.12325 .39217 L
.12449 .38384 L
.12581 .37308 L
.13578 .2652 L
.13866 .23817 L
.14138 .21721 L
.14382 .20236 L
.14518 .19565 L
.14647 .1904 L
.14767 .18637 L
.14878 .18344 L
.15001 .18104 L
.15133 .17947 L
.15253 .17894 L
.15384 .17936 L
.15521 .18091 L
.15648 .18336 L
.15769 .18659 L
.15883 .19046 L
.16096 .19987 L
.16325 .21329 L
.16573 .23189 L
.17654 .35731 L
.17925 .39109 L
.18059 .40571 L
.18182 .41749 L
.18292 .42621 L
.18413 .43371 L
.18535 .43877 L
.18664 .44126 L
.1879 .44076 L
.18926 .43705 L
.19055 .43068 L
.19172 .42261 L
.19438 .39809 L
.19718 .3661 L
.20324 .29502 L
.20588 .26919 L
.20875 .24638 L
.21143 .22988 L
.2139 .21825 L
.21626 .20986 L
.21876 .20339 L
.22002 .20092 L
Mistroke
.22139 .19876 L
.22256 .19727 L
.22385 .19598 L
.22535 .19483 L
.22678 .19402 L
.22817 .19341 L
.22945 .19295 L
.23176 .19221 L
.23426 .19133 L
.23662 .19026 L
.23879 .189 L
.244 .18475 L
.24873 .17932 L
.25909 .16315 L
.27019 .1456 L
.27557 .13849 L
.28067 .13302 L
.28524 .12933 L
.28782 .12774 L
.29021 .12655 L
.2925 .12567 L
.2937 .1253 L
.29496 .12498 L
.29607 .12477 L
.29728 .12461 L
.29839 .12453 L
.29941 .12452 L
.30074 .12459 L
.30198 .12474 L
.30311 .12496 L
.30432 .12528 L
.30565 .12573 L
.30705 .12632 L
.30956 .12765 L
.312 .12931 L
.31462 .13151 L
.31935 .13678 L
.32497 .14557 L
.33011 .15618 L
.34061 .18487 L
.34637 .2027 L
.35178 .21787 L
.35425 .22344 L
.35686 .22801 L
.35822 .22978 L
.35894 .23054 L
.35971 .2312 L
.36107 .23199 L
.36233 .23229 L
.36356 .23217 L
Mistroke
.3649 .2316 L
.36616 .23062 L
.36733 .22937 L
.36953 .22614 L
.37187 .22161 L
.38187 .19486 L
.38738 .17934 L
.39262 .16627 L
.39747 .1562 L
.40276 .14761 L
.40758 .14183 L
.41205 .13793 L
.41455 .13629 L
.41586 .13558 L
.41724 .13494 L
.41846 .13447 L
.41979 .13405 L
.421 .13376 L
.42213 .13358 L
.42332 .13347 L
.42444 .13344 L
.42545 .13348 L
.42654 .1336 L
.42773 .13383 L
.429 .13417 L
.43008 .13454 L
.43127 .13506 L
.43392 .13663 L
.43636 .13862 L
.43903 .14154 L
.44184 .14558 L
.44658 .15513 L
.44927 .16231 L
.45177 .1703 L
.45706 .19171 L
.46281 .22143 L
.46787 .25058 L
.47064 .26577 L
.47324 .2782 L
.47557 .28707 L
.47687 .29085 L
.47807 .29344 L
.47938 .29528 L
.48011 .29584 L
.4808 .29605 L
.48205 .29563 L
.48339 .29408 L
.48461 .2917 L
.48592 .28814 L
.4883 .27937 L
Mistroke
.49275 .25704 L
.49799 .22651 L
.5036 .19589 L
.5089 .1727 L
.51372 .15707 L
.51632 .15069 L
.51914 .14523 L
.52181 .14137 L
.52427 .13881 L
.52565 .13777 L
.52694 .13703 L
.52768 .1367 L
.52836 .13647 L
.52911 .13628 L
.52989 .13616 L
.5306 .13611 L
.53136 .13613 L
.53274 .13635 L
.53357 .1366 L
.53437 .13692 L
.53585 .13773 L
.53706 .13861 L
.53837 .13978 L
.54072 .14253 L
.54352 .14694 L
.54608 .15215 L
.54873 .15893 L
.55163 .16806 L
.55689 .19006 L
.56177 .21731 L
.56696 .25285 L
.5715 .28628 L
.57628 .3177 L
.57872 .32978 L
.58011 .33494 L
.5814 .33849 L
.58259 .34063 L
.58367 .3416 L
.58491 .34155 L
.58609 .34037 L
.58738 .33788 L
.58874 .33395 L
.59117 .32401 L
.59669 .2926 L
.60182 .26072 L
.60671 .23441 L
.61109 .21587 L
.61587 .20113 L
.61835 .19554 L
.621 .19096 L
Mistroke
.62349 .18781 L
.62576 .18579 L
.62713 .18492 L
.62839 .18433 L
.62977 .18392 L
.63047 .1838 L
.63123 .18375 L
.63252 .18385 L
.6339 .18422 L
.6352 .18485 L
.63639 .18569 L
.63758 .18681 L
.63884 .18834 L
.64111 .19206 L
.64356 .19765 L
.64626 .20603 L
.64858 .21538 L
.65108 .228 L
.6556 .25854 L
.66088 .30672 L
.66651 .36433 L
.66924 .38814 L
.67059 .39746 L
.67182 .40427 L
.67295 .40877 L
.67414 .41165 L
.67534 .41248 L
.67665 .41096 L
.67803 .40668 L
.67929 .40047 L
.68074 .39081 L
.68212 .37948 L
.68724 .32567 L
.69331 .25833 L
.69595 .23324 L
.69881 .21013 L
.70152 .19191 L
.70401 .17807 L
.70891 .15766 L
.7114 .15013 L
.71414 .14368 L
.71699 .13858 L
.71965 .13498 L
.72216 .13237 L
.72454 .13047 L
.72667 .12917 L
.72787 .1286 L
.72899 .12816 L
.73018 .1278 L
.73151 .12754 L
Mistroke
.73279 .1274 L
.73418 .12739 L
.73546 .12749 L
.73668 .12769 L
.73778 .12794 L
.73897 .12829 L
.74165 .12935 L
.74454 .13092 L
.74728 .13285 L
.7498 .13506 L
.75457 .14055 L
.75961 .14819 L
.77023 .16951 L
.77608 .18315 L
.78163 .19526 L
.78413 .19983 L
.78678 .2038 L
.78817 .20544 L
.7897 .20687 L
.79037 .20737 L
.79109 .20781 L
.7924 .20837 L
.79359 .2086 L
.79489 .20854 L
.79626 .20811 L
.79752 .20739 L
.79871 .20644 L
.7998 .20535 L
.80223 .20215 L
.80697 .19347 L
.81212 .18184 L
.82147 .16002 L
.82625 .15016 L
.8314 .14131 L
.83704 .13393 L
.84232 .12906 L
.84515 .12718 L
.84665 .12639 L
.84824 .12572 L
.84903 .12545 L
.84977 .12523 L
.85115 .12492 L
.85245 .12476 L
.85319 .12471 L
.85386 .12471 L
.85513 .12478 L
.85631 .12495 L
.8576 .12524 L
.85899 .12569 L
.86045 .1263 L
Mistroke
.86183 .12703 L
.86441 .1288 L
.8669 .13107 L
.86924 .13378 L
.87201 .13781 L
.87456 .14236 L
.87975 .15446 L
.88534 .17204 L
.89469 .21121 L
.89984 .23426 L
.90236 .24438 L
.90468 .25233 L
.90728 .25911 L
.90864 .26165 L
.90933 .26263 L
.91009 .26347 L
.91131 .2643 L
.91262 .26444 L
.91386 .26386 L
.91499 .26274 L
.91621 .26091 L
.91735 .25867 L
.91991 .25188 L
.92458 .23488 L
.92997 .21198 L
.93578 .1886 L
.94081 .17194 L
.94366 .16425 L
.94632 .15825 L
.94919 .15298 L
.9518 .14921 L
.9546 .14616 L
.95613 .14487 L
.95759 .14387 L
.95884 .14317 L
.96017 .14258 L
.9613 .1422 L
.96255 .14191 L
.96389 .14173 L
.96464 .14169 L
.96533 .14169 L
.96666 .14181 L
.96793 .14205 L
.96916 .1424 L
.97028 .14282 L
.97278 .14411 L
.9751 .14573 L
.97728 .14763 L
.98218 .15333 L
.98495 .15756 L
Mistroke
.98749 .16225 L
.99345 .17696 L
.99684 .18799 L
1 .20021 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo001dooooo`?o0000?_ooool00ol0003oooooooooo`1]
ooooo`;o0000@Oooool0077ooooo1?l000001?oooooo0000o`000?l0000looooo`03o`000?oooooo
oooo04Kooooo1?l0000Qooooo`Ko0000?oooool0073ooooo0_l00007ooooo`03o`000?oooooooooo
03Wooooo0_l00015ooooo`?o00000_ooool3o`0001gooooo0_l00006ooooo`;o0000?Oooool006oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`Co00005_ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03_ooooo001^ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07?ooool2o`0000?ooooo0_l0000Dooooo`03o`000?oooooooooo00Gooooo
1?l0000jooooo`03o`000?oooooooooo00Kooooo0_l0000Jooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>oooool006gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Jooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_l0000hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo001]ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool06?ooool5o`0001cooooo001/ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05oooool2o`0000?ooooo0_l0000Kooooo`00;Oooool3o`0003co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06?ooool002cooooo0_l00002ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06?ooool002_ooooo00?o0000ooooooooool00_ooool2o`0003Sooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03_ooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_oo
ool002[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo000E
ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`000008ooooool0003oooooonk^k_lb<S;o0000
oc8b<_o^k^hAooooo`03o`000?oooooooooo00Sooooo1?l000001?l@413oooooooooooo^k^h2o`00
0003oc8b<_o^k^kooooo00gooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool03oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^hDooooo`03o`000?oooooooooo00?ooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b
<_o^k^ko00004?ooool00ol0003oooooooooo`07ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo00?o0000ooooooooool02_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Kooooo`0=oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000?ooooooMgMgoiRHV?ooooooV9RH
ogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01OmgMgOo0000
oooooonHV9SoMgMg00oooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg01Cooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Ko
MgMgoiRHV?ooooooV9RHogMgMol0000?ooooo`03o`000?oooooooooo00Sooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL04?ooool00ol0003oooooooooo`0;
ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Kooooo1_l0
0006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko0000
0oooool01OnHV9So8B4Qonk^k_oooooo000000;ooooo00Go410@oooooooooooooooooa0@400Aoooo
o`03o`000?oooooo000000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003ooooo
ooooool@41003oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
4oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Oo410@oooooooooooo
oooooa0@4?oooooo000000kooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo
410@00;ooooo00?o0000oa0@4?ooool03_ooool00ol0003oooooooooo`09ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So
8B4Qo`000003ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h00oooool01ol0003ooooooooooooooooo0000ooooool000003Oooool00ol0
003oooooooooo`0<ooooo`03ojVYZOl@413ooooo00;ooooo00?o0000ooooooooool00_l0000?oooo
o`03o`000?oooooooooo00Wooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`000?oooooooooo
ooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03oa0@4?l0
003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMol0003ooooo00;ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool03?ooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01oooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o410@o`000?nj^[X00oooool00ol0003oooooooooo`02o`0000oooooo
00?o0000ooooooooool02Oooool01_oMgMgoEEEEooooool0003oooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o^[Zj
ob4Q8Oooool00_ooool00ol@413oooooooooo`03o`0001gooooo0_l00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool00ol0003oooooooooo`09ooooo`06o`000?ooooooooooooooool0003o
410@0oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo
0000ooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00Co410@oooooooooooo00003?ooool00ol0003oooooooooo`0<ooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo00[ooooo
00GoMgMgolc<c?l0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Co
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1omgMgOoV9RHooooool0003oMgMgooooool000006Oooool01Ol0003o^[Zjo`000?nHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo00Sooooo00[o0000oooo
ooooooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg4?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`?o
000000?oV9RHogMgMoooool04_ooool00ol0003oooooooooo`04ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9So000000kooooo00?o0000ooooooooool02oooool01Oo^k^koA4A4o`000?oooooo000000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`07onk^k_lb<S;o0000o`000?o^k^kooooo
o`00000Iooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000002ooooo`07o`000?ooooook^k^
oc8b<_l0003o<S8bonk^kP0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003ooo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000?ooooo00?o0000onk^k_lb<S800_l0
00000oo^k^koooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_l000003_ooool00ol0003oooooooooo`0<ooooo`0;ogMgMol0003oooooooooool0003ooooo
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000006?ooool2o`0001oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04_ooool002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool000005Oooool3o`0002;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo0_l0000@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`009oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Aooooo`;o00009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool2o`00013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04?ooool2o`0002Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00_ooooo0_l0000Aooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool2o`00017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`005_ooooooo`00043o00004oooool0
01Kooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`005_ooool2o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Gooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo000Goooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Oooooo000Gooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`08ooooo`;o00004oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool001Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0_l0000Cooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Xooooo`006?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:ooo
ool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool02?ooool2o`0001?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo
000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0/ooooo`04o`000?oooooo0000o`0001kooooo00?o0000ooooooooool01oooool2o`0001?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo
000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool3o`0001;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`006Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`07oooo
o`;o00005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:Oooool001Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool01oooool2o`0001Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo000Iooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool001Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Zooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000001Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02[ooooo000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000005?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool001Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l0000Cooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
04;ooooo00Co0000oooooooooooo0000;Oooool001Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`00000Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooool00000;_ooool001[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04;o
oooo0ol0000^ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Loooool001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo07?ooooo000Jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1cooooo`006_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`00
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
D_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1dooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0E?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0000Eooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07Cooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0EOooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool001_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo000Looooo`05o`000?oooooo
ooooooooool000005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`;o00001Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07Cooooo000Looooo`05o`000?ooooooooooooooool000005ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M?oo
ool001cooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo057ooooo1Ol0
0006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M?ooool001cooooo00Co0000
oooooooooooo00006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Aooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Cooooo000Mooooo`03o`000?oo
oooo000001Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D_ooool00onHV9So8B4Qonk^kP07ooooo`?o00005Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1dooooo`007Oooool3o`0001Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Doooool0
0onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0MOooool0
03Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0EOooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0MOooool003Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0MOooool003Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0D_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1eooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Go
oooo000hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool05_ooool01Ol0003ooooo
oooooooooooo000001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1eooooo`00
>Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
00005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo000iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05gooooo0_l0000Gooooo`04o`000?ooooooooooo`0001Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1eooooo`00>Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo01Kooooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo07Gooooo000iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
5oooool2o`0001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1eooooo`00>Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo000iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07Gooooo000iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo000iooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Go
oooo000iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07Kooooo000iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Kooooo000i
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05kooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0M_ooool003[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0M_ooool003[ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool003[ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool0
03[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0M_ooool003[ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000N?ooool003[ooooo00Co0000oooooooooooo00004Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooo
oooooooo000007Sooooo000jooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooooooo
ooooo`00001hooooo`00>_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0G_ooool2o`0003Cooooo00Co0000oooooooooooo0000NOooool003[o
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0001iooooo`00>_ooool01?l0
003oooooooooool0000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0007Wooooo000kooooo`03o`000?oooooo
0000017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo03?ooooo00Co0000oooooooooooo0000NOooool003_ooooo00?o0000ooooool000004Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<oooool0
1?l0003oooooooooool0001iooooo`00>oooool2o`0001;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Eooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooo000007Wooooo001?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ool00000NOooool004oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Cooooo`Go
00001_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo000007Wooooo001?ooooo`05o`00
0?ooooooooooooooool00000E_ooool01?m4A4CogMgMooooool00007ooooo`?o0000=?ooool2o`00
07[ooooo001@ooooo`04o`000?ooooooooooo`0005Kooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2`ooooo`00D?ooool01?l0003oooooooooool0001Gooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0/?ooool0053ooooo00Co0000oooooooooooo0000Eoooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo001@ooooo`04o`000?oooooooooo
o`0005Sooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00D?ooool00ol0
003oooooo`00001Rooooo`03o`000?oooooooooo0;3ooooo001@ooooo`03o`000?oooooo000006;o
oooo00?o0000ooooooooool0/?ooool0053ooooo00?o0000ooooool00000H_ooool00ol0003ooooo
ooooo`2`ooooo`00DOooool2o`0006;ooooo0_l0002aooooo`00DOooool2o`0006;ooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00
Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@
4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@
o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_
ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?oooooooooo
oiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8b
ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`1fooooo`00POooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oo
oooooooo00Gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo
0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000N?oo
ool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003o
ooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@401hoooo
o`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg07So
oooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l0
00001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1h
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(132) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21745 m
.00488 .24905 L
.00942 .28055 L
.01199 .29694 L
.01441 .31004 L
.01575 .31587 L
.01646 .31846 L
.01721 .32082 L
.01853 .32394 L
.01975 .32556 L
.02104 .32593 L
.02221 .32502 L
.02357 .32254 L
.02486 .31879 L
.02605 .31424 L
.02715 .30915 L
.02966 .29498 L
.04057 .21787 L
.04635 .18422 L
.04919 .17127 L
.0518 .16135 L
.05413 .15399 L
.05669 .14744 L
.05926 .14232 L
.06198 .13833 L
.06351 .13666 L
.06496 .13543 L
.06626 .13458 L
.06699 .13422 L
.06768 .13394 L
.06841 .13371 L
.06922 .13354 L
.07 .13346 L
.07085 .13347 L
.0716 .13355 L
.07238 .13371 L
.07305 .13392 L
.07379 .13422 L
.07523 .13504 L
.07655 .13604 L
.07806 .13754 L
.0795 .1393 L
.08205 .14334 L
.08481 .14912 L
.08728 .15569 L
.08994 .1644 L
.09475 .18519 L
.10046 .21992 L
.10568 .26089 L
.1111 .30752 L
Mistroke
.11396 .33013 L
.11554 .34095 L
.11701 .34972 L
.11842 .35656 L
.11916 .3595 L
.11994 .36209 L
.12133 .3653 L
.1226 .36666 L
.12387 .3665 L
.12507 .36498 L
.12637 .36189 L
.12711 .35954 L
.12777 .35705 L
.13834 .2936 L
.14112 .27667 L
.14412 .26086 L
.14677 .24924 L
.14955 .23928 L
.15193 .23241 L
.15454 .22651 L
.15691 .22242 L
.15912 .21954 L
.16179 .217 L
.16422 .21536 L
.16557 .21464 L
.16702 .21399 L
.1683 .21352 L
.16967 .21312 L
.17098 .21286 L
.17218 .21275 L
.17338 .21281 L
.17453 .21303 L
.17585 .21356 L
.17708 .21435 L
.17843 .2156 L
.17986 .21742 L
.18113 .21952 L
.18251 .22234 L
.18499 .22914 L
.18794 .24055 L
.19065 .25488 L
.19514 .28842 L
.20005 .33877 L
.20481 .39218 L
.20731 .41614 L
.20868 .42656 L
.20997 .43407 L
.21134 .43934 L
.21207 .4409 L
.21285 .44157 L
Mistroke
.21424 .44015 L
.21551 .43596 L
.21679 .42902 L
.21819 .41858 L
.22074 .39319 L
.23053 .26889 L
.23605 .21378 L
.23914 .19102 L
.24194 .17466 L
.24456 .16243 L
.24739 .15203 L
.25006 .1445 L
.25252 .13921 L
.25511 .135 L
.25746 .1321 L
.26018 .12958 L
.26275 .12782 L
.26391 .1272 L
.26513 .12665 L
.26619 .12627 L
.26733 .12594 L
.26855 .12569 L
.26969 .12556 L
.27106 .12551 L
.2723 .12558 L
.27357 .12574 L
.27492 .12601 L
.2762 .12635 L
.27735 .12672 L
.28288 .12923 L
.28563 .13096 L
.2886 .13329 L
.294 .139 L
.29915 .14628 L
.30395 .15473 L
.31489 .18055 L
.32032 .19575 L
.32623 .21157 L
.32894 .21783 L
.33181 .22336 L
.33322 .22553 L
.33453 .22721 L
.33571 .2284 L
.33699 .22932 L
.33833 .22987 L
.33957 .22999 L
.34094 .22969 L
.3417 .22931 L
.3424 .22885 L
.3438 .22758 L
Mistroke
.34533 .2257 L
.3481 .2211 L
.35341 .2091 L
.35831 .19593 L
.36769 .17065 L
.37778 .14966 L
.38307 .14169 L
.38792 .136 L
.39025 .1338 L
.3928 .13176 L
.39743 .12896 L
.40028 .12773 L
.40286 .12692 L
.40429 .1266 L
.4051 .12647 L
.40584 .12637 L
.40721 .12627 L
.4079 .12626 L
.40866 .12627 L
.41002 .1264 L
.41126 .12661 L
.41194 .12678 L
.41269 .12699 L
.41405 .12749 L
.41666 .12883 L
.41908 .13056 L
.42162 .13294 L
.42394 .13571 L
.42645 .13944 L
.42918 .14457 L
.4338 .15624 L
.43867 .17319 L
.44409 .19801 L
.44987 .23023 L
.45494 .25938 L
.45771 .27339 L
.4603 .2839 L
.46158 .28789 L
.46296 .29114 L
.46375 .29248 L
.46449 .2934 L
.46516 .29393 L
.46589 .29418 L
.46719 .29379 L
.46857 .29223 L
.46987 .2897 L
.47105 .28658 L
.47393 .27609 L
.47705 .26128 L
.4827 .23042 L
Mistroke
.48807 .20267 L
.49373 .17957 L
.49856 .16568 L
.5013 .15998 L
.50386 .15591 L
.50519 .15423 L
.5066 .15275 L
.50782 .1517 L
.50913 .15081 L
.50986 .1504 L
.51053 .15009 L
.51185 .14964 L
.51255 .14948 L
.51331 .14936 L
.51411 .1493 L
.51485 .1493 L
.51621 .14942 L
.51749 .14967 L
.51864 .14999 L
.51989 .15043 L
.52268 .15174 L
.52526 .15329 L
.53473 .16125 L
.53997 .16688 L
.54475 .1727 L
.54951 .1796 L
.55468 .18937 L
.56015 .20347 L
.56534 .22173 L
.57018 .24401 L
.57533 .27278 L
.57983 .29929 L
.58229 .31254 L
.58458 .32307 L
.58586 .3279 L
.58702 .33152 L
.58831 .33458 L
.5897 .33663 L
.59085 .33732 L
.59211 .33699 L
.5933 .33562 L
.59439 .33347 L
.59566 .32995 L
.59684 .3257 L
.59954 .31297 L
.60499 .27848 L
.61416 .21773 L
.61935 .19069 L
.62417 .17136 L
.62689 .16282 L
Mistroke
.62945 .1563 L
.6324 .1505 L
.6337 .14848 L
.63507 .14667 L
.63631 .14531 L
.63767 .14409 L
.6389 .14322 L
.64005 .14263 L
.64141 .14219 L
.64265 .14207 L
.64333 .14213 L
.64408 .1423 L
.64543 .1429 L
.64664 .1438 L
.64776 .14499 L
.649 .14671 L
.65034 .14909 L
.65305 .15581 L
.65554 .16446 L
.65772 .17424 L
.66009 .18768 L
.66489 .22535 L
.66997 .28288 L
.67548 .35799 L
.67801 .38987 L
.67939 .40475 L
.68069 .41638 L
.68179 .42421 L
.68297 .43024 L
.68429 .43384 L
.68548 .43417 L
.6862 .43303 L
.68695 .43072 L
.68831 .42388 L
.68915 .41808 L
.68993 .4116 L
.6914 .39716 L
.69701 .32511 L
.70201 .26083 L
.70465 .23285 L
.70748 .20861 L
.71027 .19013 L
.71281 .17733 L
.71536 .16773 L
.71777 .16129 L
.71908 .15876 L
.7198 .15763 L
.72047 .15674 L
.72166 .15554 L
.72297 .15472 L
Mistroke
.72369 .15448 L
.72439 .15438 L
.72569 .15451 L
.72641 .15475 L
.72709 .15506 L
.72783 .15551 L
.72861 .1561 L
.73113 .15861 L
.73385 .16225 L
.73879 .17088 L
.74803 .19112 L
.75283 .20057 L
.75553 .20465 L
.75799 .2074 L
.75939 .2085 L
.76017 .20898 L
.7609 .20931 L
.76223 .20968 L
.76291 .20974 L
.76365 .2097 L
.76497 .20936 L
.7657 .20903 L
.76638 .20863 L
.76763 .20765 L
.76894 .20629 L
.77158 .20261 L
.77441 .19746 L
.7795 .18611 L
.79105 .15872 L
.79627 .148 L
.80179 .13882 L
.80468 .13501 L
.80786 .13151 L
.81078 .12883 L
.81345 .12679 L
.81596 .12523 L
.81871 .12395 L
.82022 .12344 L
.82095 .12323 L
.82161 .12308 L
.82295 .12284 L
.82368 .12275 L
.82437 .12269 L
.82562 .12264 L
.82693 .12268 L
.82806 .12276 L
.82929 .12292 L
.83061 .12317 L
.83204 .12352 L
.8346 .1244 L
Mistroke
.83588 .12497 L
.8373 .12572 L
.84016 .12763 L
.84281 .12992 L
.8453 .13256 L
.85089 .14035 L
.85692 .15209 L
.8623 .1662 L
.86795 .18482 L
.87806 .2232 L
.88054 .23212 L
.88322 .24075 L
.88559 .24706 L
.88688 .24987 L
.88809 .25204 L
.88949 .25393 L
.89022 .25467 L
.89102 .25525 L
.89174 .25559 L
.89242 .25574 L
.89371 .25557 L
.89498 .25484 L
.89615 .2537 L
.89744 .25194 L
.89881 .24953 L
.90132 .24389 L
.90403 .23636 L
.90894 .22049 L
.9181 .19087 L
.92294 .17826 L
.92812 .1678 L
.9311 .16306 L
.9338 .15945 L
.9391 .15403 L
.94194 .15189 L
.94456 .1503 L
.94737 .1489 L
.95048 .14764 L
.95299 .14679 L
.9557 .14603 L
.95719 .14569 L
.95856 .14543 L
.95993 .14522 L
.96124 .14507 L
.9625 .14499 L
.96386 .14495 L
.96515 .14498 L
.96634 .14507 L
.96741 .14519 L
.96859 .14538 L
Mistroke
.96982 .14566 L
.97097 .14598 L
.97231 .14646 L
.97358 .14702 L
.97597 .14843 L
.97854 .15058 L
.98134 .15385 L
.98357 .15732 L
.98604 .16218 L
.98844 .1681 L
.99103 .17597 L
.99566 .19445 L
1 .21745 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo06;ooooo1_l00018
ooooo`00JOooool7o`0002Gooooo1_l0000Jooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool01?ooool2o`0004Kooooo001Yooooo`03o`000?oooooooooo00Cooooo0_l0000Rooooo`03
o`000?oooooooooo00?ooooo0_l0000Iooooo`;o0000HOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04?ooooo000[ooooo`?o0000>_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01gooooo0_l00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04;ooooo000Zooooo`;o00000_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo000Yooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`10ooooo`00:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Yooooo`?o0000<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
043ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Sooooo0_l00002ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`Oo00007?ooool002Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo
00Co0000oooooooooooooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`03
o`000?oooooooooo01Wooooo000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo0000o`0000;ooooo0_l0000Rooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`00
9oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4_ooool3o`0000Gooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool4o`0001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05oooool002Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0_l00008ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`04o`000?oo
ooooooooo`0001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Ooo
ool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool04Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h9ooooo`03o`000?oooooooooo017ooooo0_l0000;ooooo`03o`000?oooooooooo
01?ooooo1?l000002?l@413oooooo`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool04Oooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00kooooo0_l000002Ol@413ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Go
oooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
1OnHV9So8B4Qo`000?ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`00
0?oooooooooo017ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003o
ooooooooo`0@ooooo`;o00003?ooool00ol0003oooooooooo`0Dooooo`0:o`000?oooooooooooooo
ool0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00?o0000ooooooooool04?ooool02Ol0003ooooo
ooooooooooooV9RHob4Q8Oo^k^ko0000odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?nj^[[oooooo`000?lb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool02_ooool6o`0000Kooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03o`000?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l0
0003ooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo013ooooo0_l0000<ooooo`03o`000?oooooooooo01Cooooo00Ko0000oooooooooooo
0000ooooool@4103ooooo`03oa0@4?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`04oiRHV?lQ8B7ok^k^o`0000?ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`0=ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00onYZJWo410@ooooo`02oooo
o`05o`000?ooooooooooooooool000007?ooool01?l0003oV9RHob4Q8Oo^k^h3ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000Cooooo
00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool0
00003Oooool00ol0003oooooooooo`0Cooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
0onHV9So8B4Qo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Eooooo`03ojVYZOl0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00gooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`00000Looooo`04o`000?ooooooMgMgofIVIP?ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo
00001?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool03oooool00ol0
003oooooo`00000>ooooo`03o`000?oooooooooo01;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`04ooooo`03ogMgMomVIVKo000000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo01Cooooo00?o410@o`000?l000000oooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool03_ooool00ooMgMgoEEEEooooo`02o`0000?ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00Co0000oooooooooooo00000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool03Oooool01?l0003ooooo
ooooool00004ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooo0000o`0000kooooo00?o0000ooooooooool04Oooool01_l0003oooooooooool0
003ooooooa0@40?ooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Gooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`0Fooooo`03okZj^_l0003ooooo00;ooooo00Go410@oooooooooooooooooa0@400:oooo
o`03o`000?oooooooooo00oooooo00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooo
oooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`;o000000?ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0>ooooo`0Ao`00
0?ooooooooooooooool0003o^[ZjoooooonHV9So410@ooooool0003oooooogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`0Cooooo`04oa0@4?nHV9SooooookZj^P;o00000_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03oooool01Oo^k^koA4A4o`00
0?oooooo000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06oooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooomEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
013ooooo00?o0000ooooooooool03_ooool01OmEEEGoIVIVo`000?oooooo000000;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool03OnHV9So410@o`000?lQ8B7oc<c<ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool00ol0003oooooooooo`0Dooooo`06ojVYZOl@413o0000oa0@4?nYZJWo00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool04Oooool01?mgMgOo0000ooooool00002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00004?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04ooo
ool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00004Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_oo
ool002Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Booooo`008oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo0000017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01;ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`04
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?oo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000000Gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo1Ol0000Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`005_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo000Fooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0;_ooool001Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01cooooo0_l000000ooooooo0000o`00000Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`00
5_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
7_ooool3o`00027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02oooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool2o`0001Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02oooooo000Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0_ooooo`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0;oooool001Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo033ooooo000Gooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`005oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0hooooo`05o`000?ooooooooooooooool00000<oooool001Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?oo
ool01?l0003oooooooooool0000dooooo`005oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`?o0000=?oo
ool001Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00005Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1`ooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1`ooooo`006?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1`ooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1`ooooo`006?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1`ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1`ooooo`006Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1`oooo
o`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1`ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo000000So
oooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo073ooooo000Iooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1`ooooo`006_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool001[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo0ol0
0009ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool001[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1aooooo`006_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo077ooooo000Jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`19ooooo`Go00001_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo077ooooo000Jooooo`05o`000?ooooooooooooooool000006_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`19ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo077ooooo000Jooooo`05o`000?ooooooooooooooool000006_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
077ooooo000Jooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aoooo
o`006oooool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04cooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo000Kooooo`04
o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0LOooool001_ooooo00?o0000ooooool0
00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`19ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo077ooooo000Looooo`;o00007?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`19oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo000L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo077ooooo000jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0LOooool0
03[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0EOooool2o`0001[ooooo00?o0000ooooool000006?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo000jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool06Oooool3o`0001Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1aooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`00>_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`00>oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`00>oooool01?l0003oooooooooool0000Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool003_ooooo00Co0000oooooooooooo00005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo000kooooo`04o`000?oooooo
ooooo`0001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`00??ooool0
0ol0003oooooo`00000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool0
03cooooo00?o0000ooooool000005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Gooooo0_l0000fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool003co
oooo0ol0000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool005Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`00E_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo001Fooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool005Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1boooo
o`00E_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool0=_ooool01Ol0003ooooooooooooooooo000007Gooooo001Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool00000MOooool005Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`;o
0000=oooool01Ol0003ooooooooooooooooo000007Gooooo001Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool00000MOooool005Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00001eooooo`00Eoooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0=_ooool01Ol0003o
oooooooooooooooo000007Gooooo001Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool00000MOooool005Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool00000MOooool005So
oooo00Go0000ooooooooooooooooo`00001@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=_ooool01?l0003oooooooooool0001fooooo`00F?ooool01?l0003oooooooooool0001>
ooooo`Go00001_ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0007Kooooo001H
ooooo`04o`000?ooooooooooo`0004kooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Kooooo
00Co0000oooooooooooo0000M_ooool005Sooooo00Co0000oooooooooooo0000C_ooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000M_ooool0
05Sooooo00Co0000oooooooooooo0000Coooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo03Kooooo00Co0000oooooooooooo0000M_ooool005Sooooo00Co0000oooooooooooo0000Cooo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000M_oo
ool005Sooooo00Co0000oooooooooooo0000D?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooool00000M_ooool005Sooooo00Co0000oooooooooooo0000FOoo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooo000007Kooooo001Hooooo`04o`000?oooooo
ooooo`0005Wooooo00?o0000ooooooooool0=oooool2o`0007Oooooo001Iooooo`;o0000F_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo07Gooooo001Iooooo`;o0000F_ooool2o`00
0;7ooooo001Iooooo`;o0000F_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Ooo
ool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj
^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool0
0:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@
4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Iooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8bolc<c0?ooooo1Ol0001h
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@4100
3?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;o
oooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP1iooooo`00POooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00Gooooo00?oZJVYoa0@4?ooool01?ooool00onHV9So8B4Qonk^kP1hooooo`00POoo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Cooooo00?o410@o`000?nj^[X01_ooool00omgMgOoIVIVooooo`1gooooo`00POooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00Gooooo
00?o^[Zjob4Q8Oooool01_ooool00ol0003oooooooooo`1fooooo`00POooool01_l0003o<S8boooo
oooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01Ol0003o^[ZjoooooonHV9So410@07Sooooo0020ooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(134) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .27862 m
.00236 .29548 L
.00488 .31086 L
.0061 .31692 L
.00726 .32164 L
.0083 .32495 L
.00942 .32748 L
.01066 .32894 L
.01203 .32891 L
.01272 .32824 L
.01346 .32704 L
.01479 .32367 L
.01612 .31886 L
.01738 .31308 L
.01975 .29958 L
.02982 .22752 L
.03248 .21051 L
.03536 .19465 L
.03789 .18302 L
.04057 .17308 L
.04356 .16459 L
.04499 .16144 L
.04632 .15898 L
.04762 .15699 L
.04881 .15552 L
.05012 .15424 L
.05081 .15372 L
.05154 .15326 L
.05284 .1527 L
.05404 .15244 L
.05534 .15244 L
.05607 .15255 L
.05677 .15273 L
.05801 .15321 L
.05915 .15383 L
.06172 .15576 L
.0645 .15856 L
.06709 .16168 L
.07297 .17003 L
.07865 .17882 L
.08481 .18762 L
.09586 .19893 L
.10092 .2033 L
.1037 .20613 L
.10629 .20944 L
.10862 .21328 L
.11112 .21865 L
.1139 .22653 L
.11644 .23586 L
.12125 .25976 L
Mistroke
.12581 .28955 L
.13101 .32748 L
.13356 .34462 L
.1359 .35765 L
.13722 .36333 L
.13789 .36568 L
.13861 .36774 L
.13933 .36933 L
.14001 .37035 L
.14081 .37097 L
.14154 .37095 L
.1428 .36961 L
.14416 .36628 L
.14545 .36142 L
.14664 .35554 L
.14895 .34091 L
.1511 .32416 L
.15602 .28083 L
.16117 .23698 L
.16596 .20333 L
.17091 .17715 L
.17352 .16681 L
.17631 .15827 L
.17772 .15484 L
.17925 .15174 L
.1806 .14948 L
.18202 .14753 L
.1833 .14614 L
.18398 .14554 L
.18472 .145 L
.186 .14431 L
.1872 .14397 L
.18849 .14398 L
.1897 .14437 L
.19101 .14524 L
.19168 .14588 L
.19242 .14675 L
.19364 .14861 L
.19497 .15122 L
.19736 .1577 L
.19972 .1665 L
.2022 .17872 L
.20432 .19194 L
.20664 .2099 L
.21218 .27066 L
.21741 .34962 L
.22217 .42195 L
.22332 .43633 L
.22457 .44941 L
.22593 .46038 L
Mistroke
.22721 .46703 L
.22791 .4691 L
.22868 .47002 L
.2294 .4696 L
.23007 .46811 L
.23134 .46243 L
.23269 .45251 L
.23406 .43886 L
.23535 .42321 L
.23775 .38874 L
.24321 .30356 L
.2461 .26388 L
.2492 .22926 L
.25197 .20517 L
.2545 .18819 L
.25705 .17505 L
.25946 .16564 L
.26077 .16162 L
.26215 .1581 L
.26336 .15566 L
.26465 .15358 L
.26603 .15196 L
.26733 .15094 L
.26809 .15055 L
.26888 .15028 L
.26955 .15016 L
.27029 .15013 L
.2716 .15032 L
.27284 .15074 L
.27395 .15131 L
.27515 .1521 L
.27786 .15451 L
.28035 .15753 L
.28489 .16519 L
.28969 .1761 L
.29961 .20283 L
.30508 .21704 L
.30777 .22299 L
.30908 .22546 L
.31026 .22739 L
.31138 .22894 L
.31259 .23026 L
.31387 .23126 L
.31507 .23179 L
.3164 .23193 L
.31707 .23181 L
.31781 .23155 L
.31911 .23075 L
.32032 .22963 L
.32151 .22819 L
Mistroke
.32264 .22653 L
.32475 .22274 L
.3295 .21153 L
.33874 .18396 L
.34868 .15715 L
.35438 .14548 L
.35959 .13706 L
.3621 .13383 L
.36483 .13089 L
.36982 .12685 L
.37256 .12518 L
.37504 .12395 L
.37642 .12339 L
.37791 .12287 L
.37932 .12249 L
.38061 .12223 L
.38181 .12207 L
.38294 .122 L
.38417 .12199 L
.38549 .12207 L
.38687 .12224 L
.38818 .12249 L
.38936 .12278 L
.39064 .12316 L
.39328 .12416 L
.3962 .12567 L
.39924 .12781 L
.4021 .13046 L
.40721 .13702 L
.41272 .147 L
.41792 .1598 L
.42276 .17534 L
.43375 .22217 L
.43926 .24706 L
.44196 .25787 L
.44446 .26624 L
.44583 .27 L
.44733 .27334 L
.44806 .27463 L
.44885 .27578 L
.44968 .27671 L
.45045 .27732 L
.45115 .27764 L
.45191 .27776 L
.4533 .27733 L
.45465 .27616 L
.4559 .27444 L
.45725 .27195 L
.45868 .26869 L
.46124 .26151 L
Mistroke
.46702 .24155 L
.47243 .22208 L
.47748 .2062 L
.48198 .195 L
.4868 .18613 L
.48955 .18226 L
.49215 .17921 L
.49703 .17477 L
.50186 .17152 L
.50718 .16854 L
.51796 .16195 L
.5274 .15567 L
.53254 .15235 L
.53504 .15096 L
.53732 .14993 L
.53858 .14948 L
.53977 .14916 L
.54103 .14893 L
.54239 .14882 L
.54306 .14883 L
.54379 .14889 L
.54456 .149 L
.54528 .14916 L
.54656 .14958 L
.54793 .15025 L
.54918 .15108 L
.55054 .15225 L
.55174 .15354 L
.55302 .15522 L
.55543 .15936 L
.55766 .16453 L
.56024 .17234 L
.56303 .18331 L
.56807 .21081 L
.57407 .25676 L
.57957 .30632 L
.58212 .32775 L
.58453 .34464 L
.58587 .35195 L
.58657 .3551 L
.58731 .35788 L
.58863 .36127 L
.58984 .3626 L
.59097 .36225 L
.59219 .36015 L
.59334 .35659 L
.59439 .35206 L
.59696 .33647 L
.59941 .31705 L
.60992 .22222 L
Mistroke
.61295 .20005 L
.6158 .1826 L
.61839 .16955 L
.62113 .15843 L
.62361 .15047 L
.62633 .14375 L
.62881 .13919 L
.63112 .13608 L
.63252 .13466 L
.63385 .13361 L
.63504 .1329 L
.63634 .13236 L
.63701 .13218 L
.63775 .13205 L
.63852 .132 L
.63924 .13203 L
.64054 .13225 L
.64126 .13248 L
.64193 .13276 L
.64306 .13336 L
.64426 .1342 L
.64642 .13622 L
.649 .13952 L
.65134 .14342 L
.65378 .14851 L
.65643 .15536 L
.66124 .17206 L
.68171 .31365 L
.68458 .33592 L
.68731 .35359 L
.68882 .36133 L
.68961 .36476 L
.69046 .36786 L
.69124 .37023 L
.69195 .37194 L
.69333 .37409 L
.69402 .37458 L
.69474 .37468 L
.69603 .37386 L
.69742 .37164 L
.69821 .36981 L
.69894 .36777 L
.70149 .35859 L
.70421 .34627 L
.74559 .20761 L
.75631 .17315 L
.76195 .15825 L
.76794 .14583 L
.77317 .13765 L
.77595 .13421 L
Mistroke
.77893 .13117 L
.78167 .12893 L
.78417 .12731 L
.78669 .12604 L
.78909 .12513 L
.79039 .12474 L
.7918 .1244 L
.79313 .12415 L
.79436 .12399 L
.79546 .1239 L
.79668 .12386 L
.79795 .12389 L
.79914 .12397 L
.80053 .12414 L
.80184 .12437 L
.80431 .12499 L
.80697 .12591 L
.80986 .12717 L
.81472 .12997 L
.81988 .13402 L
.82429 .13852 L
.82916 .14465 L
.83975 .16299 L
.84946 .1868 L
.8608 .21923 L
.86364 .22683 L
.86632 .23323 L
.86894 .23843 L
.87009 .24034 L
.87135 .24214 L
.87243 .24341 L
.87358 .2445 L
.87481 .24534 L
.87595 .24582 L
.87729 .246 L
.87856 .24581 L
.8797 .24533 L
.88094 .24449 L
.8823 .24321 L
.88352 .24173 L
.88627 .23741 L
.8912 .22682 L
.90252 .19715 L
.91293 .17265 L
.92277 .15527 L
.93316 .14219 L
.93856 .13714 L
.94359 .1335 L
.94643 .13184 L
.94911 .13053 L
Mistroke
.9506 .12992 L
.95221 .12937 L
.95292 .12917 L
.95367 .12899 L
.95503 .12874 L
.95623 .12861 L
.95753 .12858 L
.9589 .12868 L
.96017 .1289 L
.96136 .12921 L
.96245 .1296 L
.9637 .13017 L
.96488 .13084 L
.96753 .13285 L
.96998 .13543 L
.97266 .13927 L
.97549 .14474 L
.97777 .1504 L
.98022 .15789 L
.98464 .17563 L
.9899 .20451 L
.9947 .23796 L
1 .27862 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002=ooooo`Oo00008Oooool00ol0003oooooooooo`1I
ooooo`Go0000D_ooool008_ooooo0_l00007ooooo`;o00007oooool00ol0003oooooooooo`1Goooo
o`?o00001?ooool3o`0004oooooo002:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool07?ooool2o`0005Sooooo00?o0000ooooooooool01oooool2o`0002Wooooo1_l0000Nooooo`00
ROooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9oooool5o`0002Wooooo0_l0000<ooooo`03o`000?oooooooooo02Cooooo0_l00006ooooo`03o`00
0?oooooooooo01_ooooo0028ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Jooooo`00R?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06_ooool008Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01[ooooo001@ooooo`Co0000<oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool004oooooo0_l00002ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Wooooo1?l0000Hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`Co00006?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01oooool2o`0000?ooooo0_l0000Fooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`009Ooo
ool2o`000003ooooool0003o000002Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Sooooo0_l00006ooooo`;o00001_ooool2o`0001Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo000Tooooo`;o00001?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool2o`0000_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool0
01Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool5o`00000:ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^koooooo`0001?o
oooo00?o0000ooooooooool01?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h4ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oo
oooooooo00gooooo1Ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003ooooo
ooooo`0Cooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00Wo0000oooooooo
oooooooooiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool04Oooool3o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool03onHV9So8B4Qonk^k_ooooooA4A4ooooool0003oooooogMgMonH
V9SooooooiRHV?mgMgOoooooo`00000Cooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool05oooool3o`00
00oooooo00?o0000ooooooooool03oooool00ol0003oooooo`000002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`0Booooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHo`000?nHV9SoMgMg01Oooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooo`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l0
0002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00?o0000ooooool@41000oooool01?l@413o
ooooooooool0000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03_ooool00ol0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`0Cooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@ooooool0003ooooo
oa0@400Hooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Gooooo00?o0000ooooooooool04Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0<ooooo`07oiRHV?lQ8B7ok^k^ooooool0003oooooo`000003ooooo`04
o`000?ooooooooooo`00017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Eooooo`;o00004_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01;ooooo00CoA4A4omgMgOl0003o
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00KoMgMgofIVI_oooooo0000
ooooool00003ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Gooooo00?o
MgMgofIVI_ooool00_ooool2o`0000;ooooo00?o0000ooooooooool05oooool01ol0003ooooooooo
oooooooo410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool04_ooool01?oMgMgoEEEEo`000?l00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3Oooool01Ol0003oooooo`000?oooooo410@00?ooooo00Go410@ooooooooooooooooo`00000@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02o`0001;ooooo00?o0000
ooooooooool03Oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
oooooooo01Kooooo00Ko0000oooooooooooooooooa0@4?l00002ooooo`03oa0@4?oooooooooo01Oo
oooo00?o0000ooooooooool00_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`0Dooooo`03ogMgMol0003o000000Cooooo00Go410@oooo
oooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00Ko0000okZj^_ooooooV9RHoa0@4?l00002oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool04oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00gooooo
0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Booooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003oV9RHoooooonHV9SoMgMg01Wooooo00Oo0000
ooooool@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo01Cooooo00?ok^k^o`000?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool01_nHV9So410@o`000?lQ8B7oc<c<o`0000;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0A
ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`0;ooooo`04oeEEEOmV
IVKo0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo017o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05o`000?lb<S;o0000oc8b<_o^k^h06_ooool0
1_l0003oZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo01Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool01Ol0003o
oooooooooooooooo000001?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool0027ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Eooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Gooooo000Qooooo`03o`000?oooooooooo013ooooo0_l0000Eooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`008Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo000Foooooooo0000@?l0000Coooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o
00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0023ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Dooooo`008?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Cooooo000Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?oo
ool001oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`007oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000S
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01?ooooo000Oooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04Oooool4o`0002Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool001oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Booooo`;o00009Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000Oooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`007ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09ooo
ool2o`0000Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool0
1Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool04oooool001kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Wooooo0ol0000S
ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo01;ooooo000Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01;ooooo000Nooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo0_l0000Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool04_oo
ool001kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool04_ooool001go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0mooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo017ooooo000Mooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0?Oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_ooool2o`0000kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo017ooooo
000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool001Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04kooooo0_l0000F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo06Wooooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0JOooool001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Zooooo`00
5_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06[ooooo000Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0J_ooool001Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Zooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0A?ooool5o`0000Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1[ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0A?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1[ooooo`005oooool01Ol0003ooooooooooooooooo0000
02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0AOooool00onHV9So8B4Qonk^kP07ooooo`?o00005_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1[ooooo`005oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0A_ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0K?ooool001Oooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Oooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06cooooo000Hooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K?ooool001So
oooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`14ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06cooooo000Hoooo
o`03o`000?oooooo000002Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1]ooooo`006Oooool2o`00
02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
06gooooo000oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1]ooooo`00?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`;o00006?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1^ooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
K_ooool0043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Hooooo`05o`000?oo
ooooooooooooool000006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo
0010ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1_ooooo`00@?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000
7Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06oooooo0010ooooo`05o`000?oo
ooooooooooooool000005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Koooool0047ooooo00Co0000oooooooooooo00005_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool06?ooool01?l0003o
ooooooooool0000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Koooool0047o
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`05o`000?oooooo
ooooooooool00000L_ooool0047ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool06Oooool2o`0001kooooo00Go
0000ooooooooooooooooo`00001booooo`00@Oooool01?l0003oooooooooool0000Fooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool2o`0001[ooooo0_l0000Nooooo`05o`00
0?ooooooooooooooool00000L_ooool004;ooooo00?o0000ooooool000005_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0>Oooool01?l0003ooooo
ooooool0001cooooo`00@_ooool2o`0001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool00000Loooool004;ooooo0_l0
000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooo000007?ooooo001Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`0jooooo`;o0000M?ooool005_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0;3ooooo001Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2`ooooo`00
Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
/?ooool005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`;o0000/Ooo
ool005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`2`ooooo`00G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool0/?ooool005cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0B?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?oo
ool005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool005cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`16ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00G?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Kooooo00CoA4A4omgMgOoooooo00001oooool3o`00
0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo001Looooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Aoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3o
oooo001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0B?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo001L
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2`
ooooo`00GOooool01?l0003oooooooooool0001Dooooo`03o`000?oooooooooo0;3ooooo001Moooo
o`04o`000?ooooooooooo`0005Cooooo00?o0000ooooooooool0/?ooool005gooooo00Co0000oooo
oooooooo0000E?ooool2o`000;7ooooo001Mooooo`04o`000?ooooooooooo`0005Cooooo00?o0000
ooooooooool0/?ooool005gooooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`2`
ooooo`00GOooool01?l0003oooooooooool0001Dooooo`03o`000?oooooooooo0;3ooooo001Moooo
o`04o`000?ooooooooooo`0005Cooooo00?o0000ooooooooool0/?ooool005gooooo00Co0000oooo
oooooooo0000E?ooool00ol0003oooooooooo`2`ooooo`00G_ooool00ol0003oooooo`00001Doooo
o`03o`000?oooooooooo0;3ooooo001Nooooo`;o0000EOooool00ol0003oooooooooo`2`ooooo`00
G_ooool2o`0005Gooooo0_l0002aooooo`00G_ooool2o`0005Gooooo00?o0000ooooooooool0/?oo
ool005kooooo0_l0001Eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Iooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8bolc<c0Gooooo0_l0
00000ol@413oooooooooo`1fooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<oooo
o`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooo
oooo07Oooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`Go0000N?ooool0087ooooo00Ko0000
oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003o
ooooooooo`05ooooo`03ojVYZOl@413ooooo00;ooooo00CoA4A4omgMgOoooooo0000NOooool0087o
oooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`04ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000NOooool0087ooooo
00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`05
ooooo`03okZj^_lQ8B7ooooo00?ooooo00?oMgMgolc<c?l00000NOooool0087ooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413oV9RH
oooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000NOooool0083ooooo00?o410@o`000?n7QhL0
0_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;o
oooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01Oooool00omgMgOo0000ooooo`1hooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(136) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30285 m
.01975 .24501 L
.02492 .22682 L
.02746 .21976 L
.02981 .21442 L
.03251 .20964 L
.0339 .20769 L
.03544 .20591 L
.03793 .2037 L
.04057 .20203 L
.04329 .20075 L
.04621 .19959 L
.0515 .19735 L
.05422 .19586 L
.05682 .19411 L
.06168 .1896 L
.06742 .18225 L
.07274 .17433 L
.07854 .16564 L
.08481 .15687 L
.08762 .15346 L
.09059 .15047 L
.09312 .14855 L
.09456 .14773 L
.0959 .14716 L
.09726 .14678 L
.09854 .14659 L
.0997 .14659 L
.10095 .14676 L
.10231 .14719 L
.103 .14751 L
.10376 .14794 L
.1051 .14896 L
.10636 .15024 L
.10875 .15364 L
.10995 .15591 L
.11126 .15886 L
.11359 .16546 L
.11576 .17332 L
.12066 .1982 L
.1234 .21707 L
.12589 .23759 L
.13568 .33954 L
.13806 .36249 L
.13937 .37322 L
.14061 .38173 L
.14131 .38571 L
.14208 .38933 L
.14342 .39371 L
.14478 .3955 L
Mistroke
.14604 .39468 L
.14675 .39318 L
.14753 .39072 L
.14826 .38763 L
.14893 .38418 L
.15154 .36561 L
.15439 .33843 L
.1574 .30579 L
.16288 .24784 L
.16788 .20593 L
.17033 .18996 L
.173 .1758 L
.17531 .16593 L
.17785 .15725 L
.18055 .15019 L
.18193 .14731 L
.18341 .14471 L
.18479 .14269 L
.18605 .14116 L
.18726 .13996 L
.18854 .13895 L
.18976 .13821 L
.19086 .13772 L
.19198 .1374 L
.19303 .13725 L
.19425 .13724 L
.19538 .13741 L
.19662 .13777 L
.19793 .13837 L
.1991 .13909 L
.20036 .14008 L
.20263 .14248 L
.20534 .14652 L
.2078 .15154 L
.21019 .15788 L
.21284 .16688 L
.2156 .17891 L
.21819 .19309 L
.22282 .22659 L
.22782 .27575 L
.23335 .34139 L
.23637 .37621 L
.23784 .39123 L
.23918 .40316 L
.24033 .41184 L
.24158 .41934 L
.24291 .42488 L
.24416 .42773 L
.24553 .42814 L
.24623 .42727 L
Mistroke
.24699 .4255 L
.24834 .42041 L
.2496 .41357 L
.29034 .25304 L
.31254 .19003 L
.32276 .15796 L
.32847 .14523 L
.33116 .14043 L
.33364 .13665 L
.33879 .13066 L
.3415 .12843 L
.34436 .12664 L
.34685 .12549 L
.34917 .12469 L
.35051 .12435 L
.35172 .12411 L
.3524 .12401 L
.35313 .12392 L
.35445 .12382 L
.35565 .12381 L
.35677 .12386 L
.358 .12398 L
.35932 .12419 L
.36063 .12448 L
.36202 .12485 L
.36449 .1257 L
.36892 .12773 L
.37377 .13072 L
.37932 .13536 L
.38457 .14097 L
.39437 .1546 L
.40493 .17471 L
.41638 .20194 L
.42717 .22979 L
.43244 .24188 L
.43726 .25087 L
.43987 .25458 L
.44234 .25718 L
.44369 .25819 L
.44495 .25884 L
.44632 .25925 L
.44709 .25933 L
.44779 .25931 L
.44852 .2592 L
.44928 .25898 L
.45066 .25835 L
.45142 .25785 L
.45213 .2573 L
.45375 .25576 L
.45646 .25228 L
Mistroke
.45936 .24744 L
.48022 .19507 L
.49121 .16898 L
.49723 .15742 L
.50287 .14838 L
.50828 .14113 L
.51323 .13575 L
.51874 .1312 L
.52181 .12922 L
.52466 .12771 L
.52704 .12671 L
.52838 .12628 L
.52959 .12598 L
.53092 .12575 L
.53167 .12567 L
.53236 .12563 L
.53363 .12565 L
.53497 .12579 L
.53614 .12604 L
.53739 .12641 L
.53857 .12689 L
.53965 .12743 L
.54091 .1282 L
.54228 .12923 L
.54478 .13169 L
.54723 .13498 L
.54987 .13978 L
.55236 .14576 L
.55464 .1527 L
.55995 .17527 L
.56261 .19058 L
.56553 .21072 L
.57148 .262 L
.57709 .3152 L
.57953 .33528 L
.58087 .34447 L
.58213 .3516 L
.58348 .35747 L
.5842 .35975 L
.58497 .36153 L
.58634 .3629 L
.58759 .36215 L
.58886 .35945 L
.59021 .35455 L
.59148 .34816 L
.59264 .34105 L
.59814 .2957 L
.60337 .24849 L
.60817 .21224 L
.61082 .19661 L
Mistroke
.61362 .18352 L
.61642 .17363 L
.61802 .16935 L
.6195 .16614 L
.62089 .1638 L
.6222 .16213 L
.62337 .16104 L
.62465 .16029 L
.62531 .16006 L
.62604 .15994 L
.6268 .15994 L
.62752 .16006 L
.62879 .16054 L
.63016 .16141 L
.63149 .16257 L
.63269 .16387 L
.63538 .16753 L
.64023 .17617 L
.65124 .19975 L
.6539 .20476 L
.65671 .20912 L
.65819 .21094 L
.6598 .21252 L
.66051 .21308 L
.66127 .21358 L
.66265 .21424 L
.66403 .21458 L
.66481 .21463 L
.66553 .21459 L
.66686 .21431 L
.66753 .21408 L
.66827 .21374 L
.66954 .21299 L
.67092 .21197 L
.6734 .20965 L
.67825 .20425 L
.68091 .20154 L
.68222 .20048 L
.68343 .19973 L
.68412 .19943 L
.68486 .19922 L
.6856 .19913 L
.68641 .1992 L
.68708 .19939 L
.68781 .19976 L
.68912 .20084 L
.68979 .20163 L
.69053 .20269 L
.69188 .20517 L
.69319 .20833 L
Mistroke
.69441 .21197 L
.69731 .22368 L
.70003 .2391 L
.70248 .25694 L
.70513 .28048 L
.71104 .344 L
.71392 .3748 L
.71518 .38672 L
.71655 .39802 L
.71784 .40667 L
.71903 .41269 L
.72017 .41649 L
.72137 .41828 L
.72264 .4176 L
.72383 .41457 L
.72513 .40867 L
.72587 .40424 L
.72654 .39952 L
.72909 .37665 L
.73188 .34522 L
.73749 .27678 L
.74304 .22043 L
.74614 .19659 L
.74895 .17939 L
.75159 .16663 L
.75444 .1559 L
.75713 .14828 L
.75961 .14308 L
.76218 .13918 L
.76452 .13663 L
.76582 .13555 L
.76723 .13458 L
.76858 .13383 L
.7698 .13328 L
.77103 .13285 L
.77219 .13254 L
.77342 .13231 L
.77474 .13219 L
.7759 .13217 L
.77713 .13225 L
.77817 .13239 L
.77932 .13261 L
.78078 .13298 L
.78216 .13341 L
.78474 .13436 L
.79054 .13684 L
.801 .14282 L
.81116 .15044 L
.81629 .1552 L
.82195 .16194 L
Mistroke
.82676 .1691 L
.83194 .17857 L
.8413 .20163 L
.8519 .23219 L
.8548 .23944 L
.8564 .24288 L
.8579 .24569 L
.85931 .24787 L
.86004 .24883 L
.86082 .24968 L
.8622 .25079 L
.86348 .25133 L
.86479 .25138 L
.86598 .25097 L
.86736 .24996 L
.86867 .24848 L
.86988 .24669 L
.871 .24468 L
.87353 .23903 L
.87888 .22324 L
.88456 .2035 L
.89439 .1708 L
.89955 .15706 L
.90499 .14546 L
.90977 .1374 L
.915 .13069 L
.91975 .12629 L
.92418 .12332 L
.92693 .12192 L
.92947 .12093 L
.9308 .12052 L
.93226 .12018 L
.93299 .12005 L
.93378 .11994 L
.93453 .11987 L
.93521 .11983 L
.93654 .11981 L
.93777 .11989 L
.93912 .12005 L
.93987 .12018 L
.94056 .12033 L
.94182 .12065 L
.94317 .1211 L
.94564 .12215 L
.948 .1235 L
.95058 .12545 L
.95328 .12811 L
.9558 .13127 L
.96031 .13878 L
.96515 .14996 L
Mistroke
.96961 .16378 L
.97373 .18013 L
.98305 .22923 L
1 .30285 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo08Kooooo1Ol0000Uooooo`00QOooool5o`0002_ooooo00?o0000
ooooooooool0Q?ooool2o`0000Gooooo0_l0000Sooooo`00Poooool2o`0000Gooooo0ol0000Xoooo
o`03o`000?oooooooooo00Gooooo1_l0001gooooo`;o00002?ooool00ol0003oooooooooo`0Qoooo
o`00P_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo0_l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo023ooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`14ooooo`Ko0000
:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo001Cooooo`;o0000:ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00Go0000oooooooooooooooo
o`00000:ooooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`?o00009?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01oooooo001Aooooo`;o000000?oooooo`000?l00000:Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02?ooool2o`0002;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`00DOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Rooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Nooooo`00=Oooool2o`0001Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00
000>ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool003?ooooo0_l00000
0ooooooo0000o`00000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo0_l0000?ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool07?ooool003?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo0_l0000?ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03_ooool2o`0001_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`03ooooo`;o00005Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Oooooo`;o00003oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01co
oooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Nooooo`;o00004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo
000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Mooooo`;o00004Oooool00ol0003oooooooooo`0Booooo`?o00009oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Kooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00oo
oooo00?o0000ooooooooool02?ooool01Ol0003o410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00cooooo1?l0
00001Ol@413oooooooooooo^k^ko<S8b00;o000000?ok^k^ooooooooool06_ooool00ol0003ooooo
o`00000Aooooo`03o`000?oooooooooo00gooooo1Ol00002ooooo`05onk^k_l0003o0000oc8b<_o^
k^h06_ooool5o`0000?ooooo00Go0000oc8b<_l0003o<S8bonk^kP0Aooooo`03o`000?oooooooooo
00Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`07onk^k_lb<S;o0000oc8b<_o^k^kooooo
o`00000Fooooo`03o`000?oooooooooo00;ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05o`000?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
o`000?mgMgL07?ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000000_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05o`000?nHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`06ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000005_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool01?l0003oooooooooooooool6o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol@
413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool02?ooool7o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01?oo
ool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo000001_ooooo
00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool01Ol@413o
ooooo`000?oooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo
410@01?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@o`000?ooool05oooool00ol0003oooooo`000004o`0000?ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooZJVYoa0@40?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0000Jooooo`04o`00
0?ooooooooooo`0001;ooooo00?o0000ooooooooool03_ooool2o`0000?ooooo00?o0000oooooooo
ool00_l0000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Coooo
o`03o`000?oooooooooo00Sooooo00?oZJVYoa0@4?ooool00_ooool01?l0003oooooooooooooool2
o`0001Sooooo00Ko0000oooooom4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool02oooool01?l0003o410@o`000?nj^[X3ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00006Oooool01Ol0003o
oooooooooooooooo000001;ooooo00?o0000ooooooooool03_ooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`00000Mooooo`04ogMgMomVIVKoooooooooo`;o00000oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo00?o410@o`000?nj^[X00oooool01?l0003ooooooooo
ooooool2o`0001Sooooo00Ko0000oooooooMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool03?ooool01?l0003ooooookZj^_lQ8B43ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Wooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000H
ooooo`04o`000?ooooooooooooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00Go410@ooooooooooooooooo`00000Nooooo`05o`000?ooooooooooo`000?l@
41000oooool00ol@413oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo000001[ooooo00Go0000oooooomgMgOoc<c<o`000004
ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03?ooool01Ol@413o0000oooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
1omgMgOoV9RHoooooonHV9SoMgMgooooool000006?ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRH
V?mgMgOo00006Oooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo00Ko0000ogMgMonHV9Sooooo
oiRHV?mgMgLEooooo`03o`000?oooooooooo00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003oooo
o`05ogMgMonHV9SooooooiRHV?l000006_ooool01Ol0003oooooonk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0=ooooo`05ojVYZOl0003o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00[ooooo00?o0000ooooooooool03oooool00omEEEGoIVIVo`000004ooooo`07onk^k_lb
<S;o0000oc8b<_o^k^koooooo`00000Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0;ooooo`03oeEEEOmVIVKo000000Cooooo00Kok^k^oc8b<_l0
003o<S8bonk^k_l0000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool01_l0003ok^k^oc8b
<_l0003o<S8bonk^kQKooooo00?o0000ooooooooool00_ooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05o`000?ooooooooooogMgMol000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Yooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`00:Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool002Oooooo0_l0000Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool002Cooooo0ol0000Eooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo0ol0000Aooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo000Sooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o0000013ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000004ooooo`;o00001?ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000oooo
ool000001Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo1?l00007oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool001oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`007_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_oo
ool001kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01Kooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00005?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool05_ooool001gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`007?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo
000002Cooooo00?o0000ooooooooool05Oooool001cooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo0_l000000ooooooo0000ooooo`0Toooo
o`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Tooooo`;o00009_ooool00ol0003oooooooooo`0Eooooo`00
6oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0Dooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02kooooo
1?l0000>ooooo`;o00005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Cooooo
000Jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05?ooool001[ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool04oooool001Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Cooooo`006Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool04oooool001Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`12ooooo`;o00005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
01;ooooo000Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool04_ooool001Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Booooo`005oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool04_ooool001Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Wooooo1Ol00006ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Aooooo`00
@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06Gooooo0010ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0001Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0IOooool0043ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0??ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0IOooool0043ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool0043ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0I_ooool0043ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool01Ol0003o^[ZjoooooonHV9So410@
00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Vooooo`00@Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06Kooooo0011ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Vooooo`00@Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0I_ooool0047ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool2o`0001Oooooo
00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0I_ooool0047ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`05o`00
0?ooooooooooooooool000009Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Ko
oooo0011ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05oooool01?l0003ooooo
ooooool0000Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool0047ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0002Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`00@Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00009Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo06Kooooo0011ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool05oooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0I_ooool004;ooooo00Go0000ooooooooooooooooo`00000Iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Gooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Voooo
o`00@_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00009Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo0012ooooo`05o`000?oooooooooo
ooooool000006Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool05oooool3o`0002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1V
ooooo`00@_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`19ooooo`;o00006Oooool2o`0002Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Vooooo`00@_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@_ooool01Ol0003ooooooooooooooooo
000001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@_ooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1W
ooooo`00@_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Wooooo`00@_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Ioooool004;ooooo00Co0000oooooooooooo00006oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo0012ooooo`04o`000?oooooooooo
o`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@oooool00ol0
003oooooo`00000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool2o`00
04;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@oooool00ol0003o
ooooo`00000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`11ooooo`05o`000?ooooooooooooooool00000J_ooool004?ooooo0_l0000Looooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`12ooooo`04
o`000?ooooooooooo`0006[ooooo0014ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooo
oooo0000J_ooool006;ooooo00Go0000ooooooooooooooooo`00001>ooooo`03o`000?oooooooooo
04;ooooo00Co0000oooooooooooo0000J_ooool006;ooooo00Go0000ooooooooooooooooo`000015
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`12ooooo`04o`000?oooooo
ooooo`0006[ooooo001Rooooo`05o`000?ooooooooooooooool00000A_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooooooo0000J_ooool006;ooooo00Co
0000oooooooooooo0000A?ooool5o`0000Kooooo00?o0000ooooooooool0@_ooool01?l0003ooooo
ooooool0001Zooooo`00H_ooool01?l0003oooooooooool00014ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol00013ooooo`03o`000?oooooo000006[ooooo001Rooooo`04o`000?ooooooooooo`00
04Cooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`13ooooo`;o0000Joooool0
06?ooooo00?o0000ooooool00000AOooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
04?ooooo0_l0001[ooooo`00Hoooool00ol0003oooooo`000015ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0/?ooool006?ooooo0_l00017ooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool0/?ooool006?ooooo0_l0001@ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zoooo
o`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002i
ooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03
o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooooooo
ool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Ooo
ool4o`000008oa0@4?oooooooooooiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<
c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmEEEGoMgMgoooooonHV9So
8B4Q07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`1fooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
V9RHoooooonHV9So8B4Q07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P03ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`0N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Ioooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o
000000?o00007?ooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00?oEEEE
ohN7Qoooool0N_ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00?ogMgMoa0@4?nH
V9P0N_ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGo
IVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`000?l@411h
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(138) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26436 m
.04057 .20716 L
.05077 .17438 L
.05648 .16081 L
.06168 .15133 L
.06463 .14696 L
.06784 .14296 L
.07066 .14003 L
.07365 .13747 L
.07641 .13557 L
.07945 .13388 L
.08201 .13272 L
.08481 .13171 L
.08624 .13129 L
.08758 .13097 L
.08885 .13073 L
.09021 .13055 L
.09154 .13046 L
.0928 .13045 L
.09392 .13051 L
.09514 .13065 L
.09649 .13089 L
.09725 .13108 L
.09796 .13128 L
.09952 .13182 L
.10093 .13244 L
.10351 .13395 L
.10626 .13623 L
.10883 .13922 L
.11121 .14295 L
.11381 .1484 L
.11658 .15609 L
.11898 .16462 L
.12123 .17448 L
.12389 .18881 L
.12636 .20513 L
.13129 .24722 L
.13668 .30525 L
.13961 .33763 L
.14238 .36464 L
.14358 .37445 L
.14486 .38309 L
.14553 .38681 L
.14626 .39021 L
.14755 .39436 L
.14877 .39602 L
.14989 .39555 L
.15118 .39268 L
.1524 .38773 L
.15353 .38137 L
Mistroke
.15458 .37409 L
.15695 .35349 L
.16698 .24679 L
.17233 .20391 L
.17534 .18657 L
.17811 .17447 L
.18054 .16652 L
.18191 .16303 L
.1832 .16041 L
.18456 .15826 L
.18579 .15684 L
.18648 .15626 L
.18722 .1558 L
.18857 .15535 L
.18978 .15538 L
.19092 .15573 L
.19216 .15645 L
.1935 .1576 L
.19483 .15908 L
.19623 .16099 L
.19873 .16524 L
.20322 .17545 L
.20812 .19007 L
.21322 .20755 L
.21874 .22562 L
.22128 .23261 L
.22395 .23868 L
.22624 .24261 L
.22754 .24427 L
.22875 .24543 L
.22947 .24592 L
.23025 .24631 L
.23098 .24652 L
.23166 .24658 L
.23295 .24637 L
.23432 .24568 L
.23502 .24516 L
.23578 .24447 L
.23716 .24295 L
.24029 .23858 L
.24295 .23467 L
.2444 .23279 L
.24575 .23136 L
.24691 .23047 L
.24815 .22991 L
.24952 .22988 L
.25077 .23044 L
.25201 .23165 L
.25318 .23343 L
.25447 .23617 L
Mistroke
.25585 .24012 L
.25729 .24548 L
.25866 .25184 L
.26123 .26747 L
.26362 .28661 L
.26585 .30822 L
.27089 .36641 L
.27374 .39929 L
.27514 .4135 L
.27643 .42475 L
.27758 .43298 L
.27884 .43969 L
.28011 .44372 L
.28145 .44482 L
.28221 .44398 L
.28292 .4422 L
.28426 .43638 L
.28501 .43175 L
.28571 .42666 L
.28728 .41249 L
.29271 .34456 L
.29731 .28227 L
.30215 .22808 L
.30469 .20606 L
.30746 .18664 L
.31001 .17245 L
.31233 .16214 L
.31512 .15247 L
.31656 .14855 L
.31811 .145 L
.31955 .1423 L
.32088 .14025 L
.32223 .13855 L
.32349 .13725 L
.32591 .13543 L
.3272 .13475 L
.32858 .1342 L
.32927 .13399 L
.33002 .1338 L
.33139 .13356 L
.33273 .13345 L
.33396 .13347 L
.33532 .13361 L
.33601 .13373 L
.33675 .1339 L
.33808 .13429 L
.33932 .13476 L
.34211 .13612 L
.3451 .13794 L
.35557 .14546 L
Mistroke
.37513 .1609 L
.38585 .16731 L
.3915 .17028 L
.39459 .17206 L
.39749 .17405 L
.40272 .17903 L
.40549 .1826 L
.40848 .18732 L
.41378 .19843 L
.41863 .21214 L
.42827 .24698 L
.43082 .25614 L
.43357 .265 L
.43483 .26851 L
.43616 .27174 L
.43732 .27409 L
.43856 .2761 L
.43932 .27705 L
.44001 .27772 L
.44138 .27847 L
.44214 .27854 L
.44296 .27834 L
.44375 .27787 L
.44447 .27721 L
.44571 .27555 L
.44707 .27297 L
.4485 .2695 L
.44984 .26555 L
.45488 .24611 L
.46031 .22096 L
.46558 .19691 L
.47121 .17444 L
.47642 .15771 L
.48134 .14563 L
.48689 .13564 L
.49192 .12905 L
.49481 .12614 L
.49747 .12396 L
.5004 .12207 L
.5035 .12057 L
.50615 .11962 L
.50746 .11924 L
.50867 .11895 L
.50986 .11871 L
.51093 .11853 L
.51213 .11839 L
.5134 .11829 L
.51477 .11827 L
.51603 .11831 L
.51742 .11845 L
Mistroke
.51811 .11855 L
.51888 .11869 L
.52017 .11899 L
.52155 .1194 L
.52404 .1204 L
.52652 .12171 L
.52921 .12355 L
.53158 .12558 L
.5341 .12826 L
.53636 .13123 L
.53886 .13523 L
.54326 .14447 L
.54844 .15966 L
.55388 .18185 L
.55853 .20655 L
.56361 .23885 L
.5691 .27579 L
.57212 .29414 L
.57497 .30834 L
.57626 .31346 L
.57762 .31782 L
.57833 .31964 L
.57912 .32126 L
.5805 .32315 L
.58175 .32378 L
.58309 .32332 L
.58436 .32185 L
.58552 .3197 L
.62731 .23228 L
.64641 .20075 L
.65729 .1721 L
.66262 .16056 L
.66751 .15205 L
.67236 .14567 L
.6748 .14336 L
.67619 .14234 L
.67748 .14159 L
.67815 .14127 L
.67888 .14099 L
.6802 .14062 L
.68149 .14045 L
.68268 .14046 L
.68396 .14063 L
.68469 .14081 L
.68538 .14103 L
.68676 .14164 L
.68824 .14257 L
.6897 .14379 L
.69106 .14524 L
.69268 .14741 L
Mistroke
.69414 .14986 L
.69686 .15583 L
.69975 .16459 L
.70236 .17494 L
.70518 .18919 L
.71028 .22484 L
.72112 .3438 L
.72383 .37508 L
.72517 .38864 L
.7264 .39961 L
.7275 .40781 L
.72871 .41495 L
.72993 .41988 L
.73123 .42252 L
.73249 .42242 L
.73385 .41936 L
.73514 .41379 L
.73632 .40656 L
.73897 .384 L
.74177 .35372 L
.74784 .28299 L
.75048 .25573 L
.75335 .23054 L
.75603 .21115 L
.7585 .19655 L
.76337 .17538 L
.76585 .16772 L
.76857 .16121 L
.77142 .15615 L
.77408 .15264 L
.77657 .15013 L
.77894 .14826 L
.78109 .14689 L
.78338 .14574 L
.78468 .14523 L
.78586 .14486 L
.78704 .14457 L
.78816 .14438 L
.78946 .14426 L
.79066 .14425 L
.79198 .14433 L
.79337 .14454 L
.79465 .14483 L
.79605 .14527 L
.79859 .14637 L
.80107 .14788 L
.80335 .14974 L
.80582 .15235 L
.80853 .15607 L
.81403 .1667 L
Mistroke
.81882 .1796 L
.82398 .19718 L
.8333 .23457 L
.83596 .24442 L
.83879 .25323 L
.84017 .25664 L
.84147 .25925 L
.84264 .26104 L
.8439 .26235 L
.84462 .2628 L
.84529 .26301 L
.84603 .26302 L
.84683 .26276 L
.84766 .2622 L
.84845 .2614 L
.84915 .26045 L
.84992 .25919 L
.85132 .25629 L
.8528 .25243 L
.85547 .24372 L
.86562 .19997 L
.87095 .17769 L
.87656 .15836 L
.88165 .14493 L
.88434 .1393 L
.88721 .13431 L
.88986 .13057 L
.89227 .1278 L
.89456 .12567 L
.89699 .12388 L
.89945 .12249 L
.90172 .12155 L
.90298 .12117 L
.90416 .12089 L
.90546 .12068 L
.90619 .1206 L
.90685 .12056 L
.90804 .12054 L
.90914 .12059 L
.91035 .12071 L
.91163 .12093 L
.91286 .12121 L
.91401 .12154 L
.91617 .12233 L
.91871 .12353 L
.92107 .1249 L
.92644 .12903 L
.93167 .13452 L
.93728 .14208 L
.94743 .16007 L
Mistroke
.95668 .18054 L
.99855 .26189 L
1 .26436 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Co0000
[?ooool00;Gooooo1?l00002ooooo`?o0000Moooool5o`0002kooooo002dooooo`;o00002?ooool0
0ol0003oooooooooo`1booooo`;o00001?ooool2o`0002gooooo002cooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`;o0000:oooool003;o
oooo1?l0001looooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool002oooooo0ol00003ooooo`?o0000
A_ooool4o`00033ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool002kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`12ooooo`;o00000_ooool3o`0002gooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Wooooo`00;?ooool2o`0000[ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`05ooooo`;o0000:oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool09_ooool002_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool5o`0003gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Uooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool02Oooool2o`0002Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo1_l0000Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09Ooo
ool002[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`;o00006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Tooooo`00:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05_ooool2o`0000Sooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo000Yooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04oooool2o`0002Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02?o
oooo000Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool2o`000003oooo
ool0003o000002Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`00:?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooooooo
o`00000Tooooo`03o`000?oooooooooo017ooooo0_l0000Nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`005Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool03oooool01OnH
V9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0:ooooo`03o`000?oooooooooo00oooooo1_l000001_ooooook^k^oc8b<_l0003o<S8bonk^
kQKooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
013ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00003Oooool00ol0003oooooooooo`0:ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool0
1_l0003ok^k^oc8b<_l0003o<S8bonk^kQ7ooooo00?o0000ooooooooool02Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo013ooooo00Go410@
okZj^_l0003oMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`0:o`000?oooooooooo
ooooool0003oMgMgoiRHV?ooooooV9RHogMgMaGooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000kooooo
00?o0000ooooooooool02Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00;ooooo00Ko0000ogMgMonH
V9SooooooiRHV?mgMgLBooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Sooooo1_l00004ooooo`03o`000?oo
oooo000000?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Wooooo00?o0000ooooooooool01oooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo410@01Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooooooooooooa0@4?l0000>ooooo`03o`00
0?oooooooooo00gooooo00Go0000oooooooooooo0000oa0@4003ooooo`03oa0@4?oooooooooo013o
oooo00?o0000ooooooooool01_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>oooo
o`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?nYZJWo410@00?ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003oooool00ol0
003oooooooooo`0<ooooo`06ojVYZOl@413oooooo`000?oooooo00000oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo0_l000001Onj^[[ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00005Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo0000013ooooo00?o0000ooooooooool02_ooool01ol@413o0000okZj^_oooooo0000
ooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo01?ooooo
00?o0000okZj^_lQ8B400oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo000001Gooooo00?o0000ooooooooool01_ooool2o`0000oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool01_nj^[[o8B4Q
ooooool0003ooooooa0@40?ooooo00?o410@ooooooooool04_ooool00ol0003oooooooooo`05oooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0B
ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mg
MgL04?ooool00ol0003oooooooooo`08ooooo`0=oa0@4?nHV9SooooookZj^_l0003oooooo`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@
4?l0003o0000ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0@ooooo`03oeEEEOmVIVKo000000Co
oooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?l0003ok^k^017o
oooo00?o0000ooooooooool01oooool01_nYZJWo410@o`000?l@413oZJVYo`0000;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Eooooo`03o`000?oooooooooo00Gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Uooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`009?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool002Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo000Tooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`00
9?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
6oooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`00
0?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
4Oooool002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Iooooo`008?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool06?ooool0023ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo000Oooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`06ooooo`?o00003oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo000N
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00003oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool2o`0001;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool05_ooool001gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Fooooo`007?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01Cooooo000Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`Co00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool0
0000;?ooool00ol0003oooooooooo`0Cooooo`006Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000002go
oooo00?o0000ooooooooool04_ooool001Sooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool2o`0001?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooo`00000^ooooo`03o`000?oooooooooo01;ooooo
000Gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Jooooo`?o0000;oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0A
ooooo`00@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo0010ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02[ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo067ooooo0010ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooo
oooo00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo0010ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02[ooooo0ol0000Aooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0HOooool0043ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo067ooooo0010ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo0_l0000Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo067ooooo0010ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Qooooo`00@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0HOooool0047ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo067ooooo0011ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Qooooo`00@Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0HOooool0047ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<oooool5o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1R
ooooo`00@Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;ooooo0011ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0001Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool0047o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0H_ooool0047ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Xooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool0047ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
0000:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;ooooo0011ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03Cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;o
oooo0012ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06;ooooo0012ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo0012ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06;ooooo0012ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo0_l00014ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0H_ooool004;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Hoooool004;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Hoooool004;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Hoooool004?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Hoooool004?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0@?ooool2o`0004Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Sooooo`00@oooool01Ol0003ooooooooooooooooo000002Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00@oooool01Ol0003ooooooooooooo
oooo000002Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00@oooool0
1Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Tooooo`00@oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Tooooo`00@oooool01Ol0003ooooooooooooooooo000002Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Tooooo`00A?ooool01?l0003oooooooooool0
000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool004Cooooo00Co0000
oooooooooooo00009Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0AOooool01Ol0003ooooooooooooooooo000006Kooooo0014ooooo`03o`000?oo
oooo000002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`;o0000A_oo
ool01Ol0003ooooooooooooooooo000006Kooooo0014ooooo`03o`000?oooooo000002Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Gooooo00Go
0000ooooooooooooooooo`00001Vooooo`00AOooool2o`0002Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Gooooo00Go0000oooooooooooooooo
o`00001Vooooo`00AOooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000
@oooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`0006Oooooo001]ooooo`05o`00
0?ooooooooooooooool00000@oooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`00
06Oooooo001]ooooo`05o`000?ooooooooooooooool00000>_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool0001Wooooo`00KOooool01Ol0
003ooooooooooooooooo000003_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15
ooooo`04o`000?ooooooooooo`0006Oooooo001]ooooo`05o`000?ooooooooooooooool00000>?oo
ool5o`0000Kooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool0001Wooooo`00KOoo
ool01Ol0003ooooooooooooooooo000003Sooooo00CoA4A4omgMgOoooooo00001oooool3o`0004Go
oooo00Co0000oooooooooooo0000Ioooool006gooooo00Go0000ooooooooooooooooo`00000hoooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooo`00001W
ooooo`00KOooool01Ol0003ooooooooooooooooo000003Wooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`16ooooo`;o0000J?ooool006kooooo00Co0000oooooooooooo0000>Oooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04Kooooo0_l0001Xooooo`00K_ooool01?l0
003oooooooooool0000jooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool0
06kooooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`2`ooooo`00K_ooool00ol0
003oooooo`000014ooooo`03o`000?oooooooooo0;3ooooo001^ooooo`03o`000?oooooo000004Co
oooo00?o0000ooooooooool0/?ooool006kooooo00?o0000ooooool00000A?ooool2o`000;7ooooo
001^ooooo`03o`000?oooooo000004Cooooo00?o0000ooooooooool0/?ooool006oooooo0_l00014
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0
003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05
o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2ioooo
o`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020
ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413ooooooooooonHV9So410@o`000?lb<S;o
c<c<0oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07Sooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@1hooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool0M_ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool0
0009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1hooooo`00POooool01_l0003ogMgM
oc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o
410@o`000?nj^[X00oooool01Oo<c<co0000o`000?l0003oc<c<07Sooooo0021ooooo`06o`000?n7
QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool01Oooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100N?ooool0087ooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00Go0000okZj^_oooooo^[Zjo`00001hooooo`00P?ooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0N?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .29087 m
.00123 .29562 L
.00236 .29942 L
.00357 .30287 L
.00488 .30577 L
.00609 .30762 L
.00722 .30857 L
.00829 .30876 L
.00942 .30821 L
.01065 .30674 L
.01196 .30417 L
.0132 .30086 L
.01434 .29713 L
.01975 .27216 L
.03054 .2114 L
.0358 .18682 L
.04057 .16932 L
.04582 .15493 L
.05141 .144 L
.05434 .13966 L
.05751 .13579 L
.06024 .13303 L
.06325 .13052 L
.06871 .12701 L
.07149 .12562 L
.07448 .12438 L
.07727 .12344 L
.07982 .12278 L
.08105 .12253 L
.08238 .12231 L
.08364 .12215 L
.08481 .12204 L
.08604 .12196 L
.08735 .12194 L
.08846 .12196 L
.08967 .12202 L
.09099 .12215 L
.09172 .12226 L
.09239 .12237 L
.09369 .12265 L
.09492 .12299 L
.09729 .12388 L
.09947 .12503 L
.10187 .12671 L
.10441 .12906 L
.10697 .13214 L
.10973 .13642 L
.11233 .14158 L
.11471 .14747 L
.11749 .15606 L
Mistroke
.12052 .16789 L
.12604 .19728 L
.13164 .23839 L
.1369 .28481 L
.14169 .32592 L
.1441 .34279 L
.14548 .35056 L
.14674 .35618 L
.14812 .36061 L
.14887 .36222 L
.14959 .3632 L
.15087 .36362 L
.15226 .36218 L
.15354 .3592 L
.15489 .35444 L
.15733 .34242 L
.1633 .30275 L
.16592 .28512 L
.16877 .26805 L
.1711 .25651 L
.17358 .24686 L
.17495 .24272 L
.1762 .23969 L
.17745 .23732 L
.17864 .23569 L
.17993 .23452 L
.18129 .23395 L
.18246 .23396 L
.18374 .23443 L
.18511 .23542 L
.18589 .23616 L
.18659 .23694 L
.18926 .24048 L
.19398 .24735 L
.19527 .24895 L
.19665 .25038 L
.19782 .25132 L
.19912 .25202 L
.20033 .25233 L
.20143 .25229 L
.20265 .25187 L
.20394 .251 L
.20506 .24988 L
.2061 .24852 L
.20846 .24435 L
.22811 .18065 L
.23349 .16572 L
.23644 .15904 L
.2392 .15386 L
.24154 .15034 L
Mistroke
.24407 .1475 L
.2455 .14631 L
.24687 .14545 L
.24809 .14491 L
.24943 .14454 L
.25016 .14445 L
.25095 .14442 L
.25169 .14448 L
.25238 .1446 L
.25368 .14502 L
.25505 .14576 L
.25576 .14627 L
.25653 .14693 L
.25791 .14843 L
.25955 .1508 L
.26104 .15357 L
.26369 .16016 L
.26657 .1701 L
.2693 .18258 L
.27181 .19725 L
.27669 .23619 L
.27947 .26555 L
.28207 .29773 L
.28728 .36943 L
.29003 .40502 L
.29154 .42173 L
.29297 .4348 L
.29431 .44423 L
.29507 .44816 L
.29577 .45084 L
.29701 .45331 L
.29832 .45269 L
.29955 .44914 L
.30069 .44335 L
.30195 .43446 L
.3033 .42232 L
.30888 .35469 L
.31417 .28838 L
.31904 .24166 L
.32178 .22216 L
.32433 .20788 L
.32665 .19752 L
.32883 .18971 L
.33134 .18265 L
.33361 .17777 L
.33615 .17366 L
.33852 .17076 L
.3439 .16593 L
.35475 .15837 L
.36406 .15297 L
Mistroke
.36896 .15021 L
.37144 .14909 L
.37284 .1486 L
.37416 .14825 L
.3749 .1481 L
.3756 .14799 L
.37692 .14788 L
.37766 .14787 L
.37834 .1479 L
.37909 .14796 L
.37989 .14808 L
.38057 .14822 L
.38132 .14841 L
.38266 .14887 L
.38397 .14948 L
.38518 .1502 L
.38759 .15215 L
.38896 .15361 L
.39024 .15525 L
.39282 .15945 L
.39559 .16541 L
.40083 .18121 L
.40579 .20178 L
.41509 .25159 L
.41761 .26514 L
.42032 .27802 L
.42156 .28302 L
.42288 .28749 L
.42401 .29061 L
.42522 .29312 L
.42649 .29478 L
.42767 .29541 L
.42839 .29534 L
.42907 .29498 L
.43034 .29349 L
.43102 .29227 L
.43175 .29067 L
.43305 .28703 L
.43599 .2756 L
.44609 .21831 L
.45051 .19357 L
.45533 .17104 L
.4604 .15287 L
.46523 .14025 L
.4679 .13492 L
.47075 .13036 L
.47344 .12701 L
.47587 .12464 L
.47835 .12277 L
.48063 .12144 L
Mistroke
.48313 .12036 L
.48439 .11995 L
.48577 .1196 L
.48699 .11937 L
.4881 .11924 L
.48938 .11917 L
.4906 .11918 L
.49172 .11927 L
.49275 .11941 L
.49389 .11963 L
.49509 .11994 L
.4976 .1208 L
.50024 .12202 L
.50495 .12498 L
.50758 .12713 L
.51003 .12952 L
.51557 .13652 L
.52044 .14451 L
.52486 .15322 L
.53477 .1777 L
.54458 .20447 L
.54994 .21683 L
.55495 .22548 L
.55756 .22867 L
.55903 .23006 L
.56037 .23108 L
.56183 .23197 L
.56342 .23269 L
.56493 .2332 L
.56632 .23359 L
.56894 .23426 L
.5714 .23511 L
.57263 .23572 L
.57396 .23657 L
.57544 .23778 L
.5768 .23919 L
.57936 .24273 L
.58214 .24804 L
.58477 .25456 L
.58719 .26187 L
.59302 .28329 L
.59575 .29392 L
.59831 .30306 L
.60055 .30966 L
.60169 .31236 L
.60294 .31467 L
.60431 .31635 L
.60561 .31707 L
.60687 .3169 L
.60804 .31596 L
Mistroke
.60939 .31395 L
.61066 .31117 L
.61304 .30379 L
.61559 .29309 L
.61836 .27905 L
.62848 .22119 L
.63401 .19473 L
.63917 .17592 L
.64358 .164 L
.6483 .15487 L
.651 .15113 L
.65355 .14841 L
.65583 .14654 L
.65832 .14497 L
.66077 .14379 L
.66206 .14329 L
.66342 .14284 L
.66461 .1425 L
.66591 .1422 L
.66709 .14199 L
.6682 .14185 L
.66888 .14178 L
.66962 .14173 L
.67096 .14169 L
.67226 .1417 L
.67346 .14175 L
.67477 .14184 L
.6762 .14196 L
.67909 .14222 L
.68191 .14245 L
.68459 .14266 L
.68606 .14281 L
.68767 .14301 L
.68913 .14326 L
.69049 .14355 L
.6932 .14433 L
.69565 .14526 L
.69849 .14663 L
.70115 .1483 L
.70369 .15045 L
.70606 .1532 L
.70866 .15741 L
.71144 .16374 L
.71435 .17293 L
.71711 .1845 L
.71959 .19775 L
.72228 .21579 L
.72718 .26007 L
.73237 .3219 L
.73466 .35097 L
Mistroke
.73715 .38078 L
.73935 .40291 L
.74056 .41261 L
.74169 .4198 L
.74237 .42307 L
.74309 .42574 L
.74436 .42817 L
.74566 .42763 L
.74685 .42447 L
.74794 .41939 L
.74914 .41158 L
.75156 .38964 L
.75669 .32695 L
.76219 .25895 L
.76485 .23168 L
.76738 .21022 L
.76984 .19326 L
.77212 .18068 L
.77427 .17124 L
.77656 .16355 L
.77886 .15802 L
.78017 .15577 L
.78139 .15423 L
.78263 .15319 L
.78394 .15262 L
.78519 .15257 L
.78632 .15289 L
.78765 .15371 L
.7884 .15438 L
.78909 .15511 L
.7917 .1589 L
.79422 .164 L
.79698 .17127 L
.80257 .19112 L
.81253 .23665 L
.8149 .24683 L
.81744 .25617 L
.81867 .25998 L
.81983 .26303 L
.82088 .26532 L
.82199 .2672 L
.82327 .26864 L
.82444 .26925 L
.8257 .26912 L
.82709 .26805 L
.82848 .26601 L
.82925 .26446 L
.82996 .26281 L
.83265 .25464 L
.83765 .23349 L
Mistroke
.84239 .21052 L
.84749 .18696 L
.8529 .16593 L
.85572 .15697 L
.85883 .14875 L
.86146 .14313 L
.86432 .13824 L
.867 .13469 L
.86949 .13215 L
.87212 .13017 L
.8736 .12934 L
.87493 .12875 L
.87618 .12833 L
.87734 .12806 L
.8786 .12789 L
.87994 .12784 L
.8811 .1279 L
.88219 .12805 L
.88338 .1283 L
.88466 .12867 L
.88747 .12981 L
.89053 .1315 L
.89611 .13565 L
.90153 .141 L
.90656 .14695 L
.9162 .15954 L
.92636 .1721 L
.93168 .177 L
.93469 .17898 L
.93614 .17972 L
.9375 .1803 L
.93874 .18072 L
.94009 .18107 L
.94131 .1813 L
.94245 .18143 L
.94367 .1815 L
.94501 .18148 L
.94569 .18144 L
.94642 .18137 L
.94773 .18119 L
.94923 .18091 L
.95062 .18059 L
.95377 .17977 L
.95532 .17938 L
.95678 .17905 L
.95809 .17882 L
.95883 .17872 L
.95951 .17865 L
.96072 .1786 L
.96204 .17866 L
Mistroke
.96343 .17886 L
.96472 .17921 L
.96544 .17948 L
.96612 .17979 L
.9674 .1805 L
.96878 .1815 L
.97028 .18289 L
.97282 .18604 L
.97562 .19086 L
.97854 .1976 L
.98129 .20566 L
.98619 .22428 L
.99148 .24941 L
1 .29087 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002_ooooo`Oo0000/_ooool002gooooo2Ol0001gooooo`;o00001_ooool00ol0003oooooooooo`2`
ooooo`00:oooool2o`0000Sooooo0_l0001eooooo`03o`000?oooooooooo00Kooooo0ol0001eoooo
o`;o0000>Oooool002[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`1aooooo`?o000000?oooooo`000?l0
0000=oooool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00001aooooo`03o`000?oooooooooo00?o
oooo0_l0000eooooo`00:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`009oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0aooooo`009oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo2ol0000e
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool002Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Xooooo`Co0000@Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool3o`0000Wooooo0ol0000coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool002Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooooooo`;o00008oooool5o`00
01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0;oooool002Gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool3o`0000Co
oooo0_l0000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool2o`0001Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`009?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0:ooooo`;o00001_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05Oooool4o`0001Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0^ooooo`009?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`;o00002_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooo
oooooooo000001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`009?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooooooooooo
o`00000Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool001Gooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo
01Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Ooo
ool00ol0003oooooo`000004o`0000?ooooo00Go0000oc8b<_l0003o<S8bonk^kP0Eooooo`03o`00
0?oooooooooo00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool4
o`000009oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko000001Cooooo00?o0000oooooooo
ool00_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03oooool01Ol0003o410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo01;ooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0Dooooo`05oa0@4?nj^[[o0000
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Oo0000oooooonHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Cooooo`;o00002Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9So0000oiRHV?mgMgL04?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02
ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00005?ooool00ol0003oooooooooo`02ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool03?ooool6o`0000Cooooo
00?o0000ooooool000000oooool01Ol@413ooooooooooooooooo410@01?ooooo1ol00002ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@o`000?oooooooooooa0@400Booooo`Oo00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?oooooo0000ooooool@41004?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool000005_ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`03o`000?oooooooooo00kooooo1Ol00003ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool05_ooool00ol0003oZJVYoa0@4003ooooo`05o`000?oo
ooooooooooooool000006?ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
0_l00002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;o00004?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000005_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03oooool01Ol0003ooooooooooonYZJWo410@00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`03o`000?oooooooooo00gooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo01Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00omgMgOoIVIVooooo`02
ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02o`00013ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02o`0001Kooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00oooooo00Go0000ooooool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00003?ooool00ol0003oooooooooo`0<ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41000_ooool00ol0003oooooooooo`0Hooooo`03o`000?lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@400Gooooo`03o`000?oooooooooo00Gooooo00Ko0000oooooooooooooooo
oa0@4?l00002ooooo`03oa0@4?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41003oooool00ol0003oooooooooo`0<oooo
o`;o00002Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooo0000oa0@400Gooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooooa0@
4003ooooo`04oa0@4?ooooooooooo`0000Oooooo00?o0000ooooooooool03Oooool01_l0003ooooo
oooooooooooo^[Zjob4Q8@?ooooo00Go410@oooooooooooooooooa0@400=ooooo`?o000000?ooooo
o`000?l000001_l00003ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@
400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
ool00ol0003oooooooooo`0Eooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Oooooo00Wo0000ooooooooooooooooo`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOo0000oooooonHV9SoMgMg013ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL03oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9Soooooo`000?mgMgL05oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0=ooooo`06o`000?l@413oV9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9So
MgMg013ooooo0_l00006ooooo`;o00000_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01oo^k^ko<S8bo`000?lb
<S;ok^k^ooooool000006?ooool01OnYZJWo410@o`000?l0003oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Gooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^o`000?l0003o<S8bonk^kP0@ooooo`03o`000?oooooooooo00Wooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?l0003ok^k^00oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?l0003ok^k^01Oooooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool01_l0003oZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Iooooo`06o`000?oooooooooooooooomgMgOo00001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01Wooooo000Pooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Hooooo`008?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06?ooool001Koooooool00010o`00
01?ooooo000Fooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04Oooool001Kooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo017o
oooo000Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Fooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool05_ooool001oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool001kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0?ooooo`;o00005Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool05Oooool001kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0<ooooo`;o00002?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo0_l0000Booooo`?o00004Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool001kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0;ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool2o`0000oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo000Noooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool05?ooool001gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Dooooo`007Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Co
oooo000Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`007Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool3o`0001Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo000M
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0D
ooooo`007Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Aooooo`;o00006Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Coooo
o`007Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03oooool2o`0000;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Cooooo`00
7?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool01?l0003oooooo`000?l0000cooooo`03o`000?oooooooooo01?ooooo000Looooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`?o0000
=?ooool00ol0003oooooooooo`0Cooooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00
000Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0Booooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Go0000
ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0Booooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01oooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0Booooo`006oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00000Dooooo`;o00006ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01;ooooo000Kooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000001Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo017ooooo000Fooooo`05o`000?ooooooooooooooool000009_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Mooooo`005_ooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08?ooool2o`0001Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1N
ooooo`005_ooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo000Gooooo`04o`000?oooooooooo
o`0002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0;Oooool5o`0000Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Nooooo`005oooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0G_ooool001Sooooo0_l0000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00?oV9RHob4Q
8Oo^k^h01oooool3o`0001gooooo00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05kooooo0012ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0002Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Nooooo`00@_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aoooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool07_ooool3o`0002Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Nooooo`00@oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0G_ooool004?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05kooooo0013ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02kooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Nooooo`00@oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Nooooo`00@ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Nooooo`00@oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`;o0000B?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05kooooo0014ooooo`05o`000?oooooooooo
ooooool000009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05kooooo0014oooo
o`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05kooooo0014ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05kooooo0014ooooo`05o`000?ooooooooooooooool000009oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo0014ooooo`05o`000?oooooooooo
ooooool000009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo0014oooo
o`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1O
ooooo`00A?ooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Goooool004Cooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05oooooo0015ooooo`;o0000:_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03[ooooo0_l00019ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Goooool004Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05oooooo001aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Goooool0077ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Oooooo`00LOooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo001aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0H?ooool0077ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Pooooo`00LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo
001aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool2o`0004Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`00L_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo063ooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`19ooooo`05o`000?ooooooooooooooool00000H_ooool0
07;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
04Wooooo00Go0000ooooooooooooooooo`00001Rooooo`00L_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooooooo
000006;ooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool0001S
ooooo`00L_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0006?ooooo001boooo
o`05o`000?ooooooooooooooool00000<oooool5o`0000Kooooo00?o0000ooooooooool0BOooool0
1?l0003oooooooooool0001Sooooo`00L_ooool01Ol0003ooooooooooooooooo000003?ooooo00Co
A4A4omgMgOoooooo00001oooool3o`0004Wooooo00Co0000oooooooooooo0000Hoooool007?ooooo
00Co0000oooooooooooo0000<oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
04Wooooo00Co0000oooooooooooo0000Hoooool007?ooooo00Co0000oooooooooooo0000=?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooool00000Hoooool0
07?ooooo00Co0000oooooooooooo0000=?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooool00000Hoooool007?ooooo00Co0000oooooooooooo0000=Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04[ooooo0_l0001Tooooo`00Loooool01?l0
003oooooooooool0000nooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0H_ooool0
07?ooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`2`ooooo`00Loooool01?l0
003oooooooooool0000nooooo`03o`000?oooooooooo0;3ooooo001cooooo`04o`000?oooooooooo
o`0003kooooo0_l0002aooooo`00Loooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo
0;3ooooo001cooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool0/?ooool007Cooooo
0_l0000oooooo`03o`000?oooooooooo0;3ooooo001dooooo`;o0000?oooool00ol0003ooooooooo
o`2`ooooo`00M?ooool2o`0003oooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00
0;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`00
0?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go
0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo
003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083o
oooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooooooooooo
oooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[o
EEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb
<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7
o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oo
oooooooo01_ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(142) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .32332 m
.01975 .22765 L
.02492 .1953 L
.02981 .17123 L
.03251 .16069 L
.03544 .15122 L
.04057 .13878 L
.04333 .13386 L
.04625 .12972 L
.04875 .12692 L
.0515 .12451 L
.05403 .12279 L
.05676 .12138 L
.05807 .12084 L
.05933 .12041 L
.06054 .12006 L
.06168 .1198 L
.06238 .11966 L
.06314 .11954 L
.06446 .11939 L
.06521 .11934 L
.066 .11932 L
.06667 .11932 L
.06742 .11934 L
.06874 .11945 L
.06949 .11954 L
.07017 .11964 L
.07149 .11991 L
.07274 .12022 L
.07574 .12126 L
.07852 .12256 L
.08157 .12444 L
.08481 .12702 L
.08994 .13267 L
.09465 .13985 L
.09981 .15022 L
.10525 .16441 L
.11531 .19939 L
.12445 .23384 L
.12692 .24178 L
.1296 .24909 L
.13083 .25189 L
.13213 .25445 L
.13335 .25644 L
.13447 .25792 L
.13574 .2592 L
.1371 .26012 L
.13837 .26056 L
.13957 .26065 L
.14024 .26058 L
Mistroke
.14096 .26041 L
.14225 .2599 L
.14304 .25949 L
.14379 .25904 L
.14518 .25811 L
.14753 .25649 L
.14881 .2557 L
.15001 .25511 L
.15103 .25476 L
.15212 .25457 L
.15334 .25464 L
.15445 .25499 L
.15573 .25578 L
.15691 .25692 L
.15821 .25866 L
.15959 .2611 L
.16191 .26664 L
.16446 .27487 L
.17438 .3204 L
.1768 .33074 L
.17812 .33548 L
.17937 .33915 L
.18008 .34085 L
.18085 .34234 L
.18219 .344 L
.18356 .34439 L
.18482 .34356 L
.18619 .34132 L
.18746 .33801 L
.18887 .33307 L
.19038 .32638 L
.19625 .29012 L
.20673 .21858 L
.20941 .20402 L
.21227 .19085 L
.21739 .1728 L
.22024 .16554 L
.22291 .16029 L
.22584 .1561 L
.22749 .15437 L
.229 .15314 L
.23023 .15235 L
.23155 .15169 L
.23279 .15123 L
.23391 .15092 L
.23524 .15068 L
.23599 .1506 L
.23668 .15056 L
.23795 .15055 L
.23929 .15065 L
Mistroke
.24057 .15083 L
.24195 .15112 L
.24325 .15149 L
.24445 .15189 L
.25012 .15455 L
.25978 .15932 L
.27007 .16405 L
.27312 .16564 L
.276 .16728 L
.27858 .16908 L
.2799 .17024 L
.28136 .17177 L
.28402 .17551 L
.28547 .17822 L
.28682 .18126 L
.28924 .18811 L
.29184 .19781 L
.29453 .21102 L
.29739 .22936 L
.29984 .24927 L
.30253 .27631 L
.30813 .34745 L
.31107 .38768 L
.31416 .42495 L
.31547 .43754 L
.31687 .44804 L
.31768 .4525 L
.31841 .45548 L
.31915 .45741 L
.31985 .45822 L
.32115 .45705 L
.32235 .45292 L
.32367 .44514 L
.32506 .43353 L
.32758 .40532 L
.32993 .37319 L
.33529 .29565 L
.34052 .23295 L
.34348 .20634 L
.34623 .18685 L
.34882 .17226 L
.35126 .16139 L
.35406 .15183 L
.35528 .14858 L
.35661 .14557 L
.35898 .14148 L
.36028 .13987 L
.36149 .13871 L
.36262 .13789 L
.36365 .13735 L
Mistroke
.36484 .13695 L
.36597 .13678 L
.36719 .13682 L
.36849 .1371 L
.36959 .13755 L
.37081 .13828 L
.37212 .13935 L
.37353 .14087 L
.37608 .14464 L
.37874 .15013 L
.38157 .15781 L
.38668 .1765 L
.39275 .20707 L
.39826 .24121 L
.40347 .27334 L
.4049 .2809 L
.40641 .28788 L
.40772 .29292 L
.40843 .29525 L
.40912 .29716 L
.41043 .29995 L
.41164 .30142 L
.41277 .30184 L
.41399 .30123 L
.41534 .2993 L
.41602 .29785 L
.41677 .29587 L
.41935 .28648 L
.43007 .22253 L
.43592 .18834 L
.44136 .16398 L
.44602 .1489 L
.44863 .14249 L
.451 .13778 L
.4536 .13373 L
.45497 .13203 L
.45643 .13053 L
.45769 .12944 L
.45909 .12846 L
.46037 .12776 L
.46155 .12726 L
.46284 .12685 L
.46353 .1267 L
.46426 .12657 L
.46561 .12645 L
.46683 .12646 L
.46803 .12658 L
.46932 .12682 L
.47054 .12716 L
.47166 .12757 L
Mistroke
.47418 .12884 L
.47695 .13077 L
.48253 .13623 L
.48743 .14253 L
.49268 .15079 L
.50216 .16908 L
.51286 .18959 L
.51579 .19407 L
.5189 .19788 L
.52018 .19911 L
.52156 .20019 L
.52235 .20068 L
.52307 .20106 L
.52382 .20137 L
.52449 .20159 L
.52573 .20181 L
.52704 .2018 L
.52826 .20159 L
.52941 .20121 L
.53076 .20056 L
.532 .19978 L
.53479 .19746 L
.54006 .19161 L
.54563 .18449 L
.54807 .18151 L
.55072 .17862 L
.55323 .17641 L
.55443 .17558 L
.55556 .17494 L
.55684 .1744 L
.55752 .1742 L
.55826 .17406 L
.55899 .174 L
.55975 .17401 L
.56113 .17426 L
.56238 .17475 L
.56355 .17545 L
.56484 .17651 L
.56621 .178 L
.5687 .18171 L
.57139 .18739 L
.57394 .19449 L
.57629 .20267 L
.58074 .22255 L
.58545 .24943 L
.59052 .28238 L
.59534 .31217 L
.59799 .3252 L
.5995 .33087 L
.60021 .33306 L
Mistroke
.60089 .3348 L
.60218 .33719 L
.60335 .33827 L
.60461 .33825 L
.60597 .33685 L
.60717 .33446 L
.60829 .33129 L
.61084 .32113 L
.61332 .30802 L
.61598 .29167 L
.62519 .23286 L
.63037 .20609 L
.63587 .18474 L
.63874 .17623 L
.64191 .16853 L
.64749 .15811 L
.65274 .15082 L
.65839 .14477 L
.66862 .13632 L
.67868 .12975 L
.68437 .12699 L
.68692 .12593 L
.68967 .12496 L
.69117 .12452 L
.69256 .12421 L
.69388 .12398 L
.69455 .12391 L
.69529 .12385 L
.69656 .12382 L
.69792 .12391 L
.69921 .12409 L
.70039 .12436 L
.70184 .12482 L
.70319 .12539 L
.70468 .12618 L
.70626 .12724 L
.70776 .1285 L
.70918 .12994 L
.71183 .13343 L
.71437 .13803 L
.71673 .14369 L
.71933 .15169 L
.72211 .16269 L
.72503 .17742 L
.72779 .19484 L
.73296 .23787 L
.74219 .3392 L
.74472 .36459 L
.74612 .37641 L
.74745 .38575 L
Mistroke
.74867 .39251 L
.75002 .3976 L
.75124 .40005 L
.75237 .40042 L
.7537 .39855 L
.75495 .39461 L
.75607 .38943 L
.75729 .38224 L
.76254 .33889 L
.76778 .2923 L
.77065 .27178 L
.77205 .26363 L
.77332 .25734 L
.77443 .25276 L
.77564 .24871 L
.77692 .24544 L
.77813 .24327 L
.77945 .24187 L
.78012 .24153 L
.78086 .24143 L
.78217 .24193 L
.7834 .24311 L
.78453 .24476 L
.78573 .24702 L
.78786 .25213 L
.79268 .26641 L
.79537 .27415 L
.7967 .27742 L
.79792 .27997 L
.79903 .28184 L
.80021 .28328 L
.80139 .28412 L
.80269 .2843 L
.8034 .28407 L
.80408 .28361 L
.80535 .28217 L
.80672 .27977 L
.80821 .2762 L
.8109 .26752 L
.81339 .25734 L
.82265 .21167 L
.82752 .18945 L
.83267 .17074 L
.83543 .16286 L
.83846 .15585 L
.84121 .15081 L
.84378 .14718 L
.84513 .14565 L
.84642 .14443 L
.84759 .14352 L
Mistroke
.84883 .14273 L
.85017 .14208 L
.85142 .14165 L
.85276 .14137 L
.85352 .14128 L
.85424 .14125 L
.85538 .14127 L
.85663 .14142 L
.85793 .14168 L
.85915 .14202 L
.86132 .14285 L
.86365 .14404 L
.86896 .14777 L
.87378 .15212 L
.88358 .1618 L
.88894 .16677 L
.89395 .17075 L
.89656 .17239 L
.89936 .17373 L
.90096 .17428 L
.90175 .17449 L
.90247 .17466 L
.90383 .17489 L
.90455 .17497 L
.90532 .17502 L
.90668 .17504 L
.90745 .17501 L
.90815 .17495 L
.90945 .17478 L
.91082 .17451 L
.91204 .17418 L
.91319 .17381 L
.91579 .17273 L
.93542 .15893 L
.9408 .15539 L
.94374 .15381 L
.94518 .15319 L
.9465 .15272 L
.9477 .15239 L
.94884 .15217 L
.95005 .15203 L
.95137 .15201 L
.95271 .15213 L
.95347 .15226 L
.95415 .15242 L
.95548 .15287 L
.95673 .15345 L
.95802 .15423 L
.95943 .15531 L
.96081 .15662 L
Mistroke
.96229 .15834 L
.96494 .16234 L
.96741 .16733 L
.97052 .17555 L
.97346 .18559 L
.97897 .21079 L
1 .32332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
000Xooooo`Oo0000Q_ooool00ol0003oooooooooo`2`ooooo`009_ooool2o`0000Oooooo0_l00024
ooooo`03o`000?oooooooooo03[ooooo1?l0001booooo`009Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo07Cooooo1Ol00008ooooo`03o`000?oooooooooo03Oooooo0ol00004oooo
o`;o0000L?ooool002Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1cooooo`;o
00001?ooool2o`0000Kooooo0_l0000fooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`00
8oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo077ooooo0_l00006ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo06gooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Dooo
ool3o`0001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03;ooooo0_l0000<ooooo`03o`000?oooooooooo06gooooo000Sooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0DOooool2o`000003ooooool0003o000001Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1/ooooo`008oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09oooool5o`0003oooooo000Rooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0??ooool002;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Gooooo0_l0000looooo`008Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Oooooo1_l0000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo0000033ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05?ooool4o`00027ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool09_ooool2o`0000Gooooo0ol0000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0002kooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04Oooool3o`0000;ooooo0_l0000Pooooo`008?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool2o`0001cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo0_l0000^ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00kooooo0_l00007ooooo`03o`000?oooooooooo01gooooo000Pooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`;o0000
6_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool2o`0002kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01cooooo000Eooooo`;o000000[o410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^ko00005_ooool02?l0003ooooooooooonHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Gooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o0000onk^kP0Gooooo`03o`000?oooooooooo00;ooooo1?l000002?l@413o0000ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oo
oooo1?l000002Ol@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^o`00000Hooooo`Ko00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo00?o0000ooooooooool00_ooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0:ooooo`;o00002oooool00ol0
003oooooooooo`03ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
3_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So000001Oooooo
00So0000oooooooooooo410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Eooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?l000005oooool00ol0003oooooooooo`04ooooo`0:o`000?ooooooooooo`00
0?ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Iooooo`06
o`000?nHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o
0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHo`000009ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go
00000oooool01Ol@413ooooooooooooooooo000001;ooooo1_l00006ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`04oa0@4?ooooooooooooooo`;o00004_ooool6o`0000Gooooo00Ko0000oooooooooooo0000
ooooool@4103ooooo`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool04?ooool2o`0002;o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo000001Wooooo00Go0000oooo
oonHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41005Oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o0000ooooo`06ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01Sooooo00?o0000ooooooooool00_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000005?ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000
oooooooooooooooo0_l0000Eooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo
0_l00003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool2o`00013ooooo
0ol0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l0000Jooooo`05o`00
0?ooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooo
ooooool01_ooool00onYZJWo410@ooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo1ol0
000Aooooo`06o`000?ooooooA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000H
ooooo`07o`000?ooooooooooooooool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00005?ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00;ooooo00Ko0000oooooooo
ooooooooo`000?ooool2o`0001?ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_l0000Jooooo`05o`000?ooooooooooogMgMomVIVH00oooool01Ol0003ooooo
oooooooooooo000001Cooooo00?o0000ooooooooool01_ooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000006Oooool01_l0003oooooomgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool000006?ooool00ol0003oooooooooo`02ooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
oooooooooa0@4003ooooo`04oa0@4?ooooooooooo`0001?ooooo00?o0000ooooooooool01Oooool0
1_l0003ooooooooooooooooo0000oa0@40?ooooo00?o410@ooooooooool02?ooool00ol0003ooooo
ooooo`0Aooooo`?o00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@01[ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41005?ooool00ol0003oooooooooo`07
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Iooooo`06o`000?oo
ooooooooogMgMoo<c<co00001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHo`00000Iooooo`06o`000?l@413oV9RH
oooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00?o0000ooooooooool0
1Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool02_l0003ooooooooooooooooo
0000ogMgMonHV9SooooooiRHV?mgMgL:ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo00002_ooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9So0000oiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003oooooonk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000o`000?o^k^h06Oooool01_l0003oZJVYoa0@4?l0003o410@ojVYZ@?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001?ooool01Ol0003o<S8bo`00
0?lb<S;ok^k^00Wooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo00Gooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003ooooooooooomgMgOo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo0_l00002ooooo`;o00002oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1?ooool4o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Hooooo`005_oo
ooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo017ooooo000Mooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo000Moooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Oooooo000Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Oooooo000Looooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Oooooo000Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo0_l0000Hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool05oooool001cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05oooool001_ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05_ooool001_ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0;ooooo`?o00002_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Kooooo000K
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool01?l0003oooooo`000?l0
0009ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05_ooool001_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Fooooo`006oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05_ooool001[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`02ooooo`?o00003_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Eoooo
o`006_ooool00ol0003oooooooooo`0Sooooo`;o000000?oooooo`000?l000000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool2o`0001Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool05Oooool001[ooooo00?o0000ooooooooool09?ooool3o`0000Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05Oooool001[ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Gooooo000Ioooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Doooo
o`006Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool05?ooool001Wo
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo01Cooooo000Iooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooooooo
o`0003Wooooo00?o0000ooooooooool05?ooool001Wooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000006Oooool2o`0001_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool3o`0003[ooooo00?o0000ooooooooool05?ooool001Sooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000006Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04oooool0
01Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`05o`000?oooooooooo
ooooool000006Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool04oooool001Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Cooooo`006?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool04oooool001Oooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo1Ol00006ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`005ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Booooo`005oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo00?o
V9RHob4Q8Oo^k^h01oooool3o`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Booooo`005oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool04_ooool001Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zoooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Oooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01co
oooo00Go0000ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
01cooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0Aooooo`00C_ooool01Ol0003ooooooooooooooooo
000002Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05cooooo001>ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00
000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOooool004kooooo00Go0000
ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_oo
ool2o`0001kooooo00?o0000ooooool00000:_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05gooooo001>ooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo0ol0000Zooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0GOooool004oooooo00?o0000ooooool000009_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo001?ooooo`?o00009_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo001hooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0GOooool007Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Mooooo`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo001h
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool007Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Mooooo`00N?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03?ooooo0_l0001<ooooo`05o`000?ooooooooooooooool00000H?ooool007So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04_o
oooo00Go0000ooooooooooooooooo`00001Pooooo`00NOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo0000
063ooooo001iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`1;ooooo`05o`000?ooooooooooooooool00000H?ooool007Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04_ooooo00Go0000oooooooo
ooooooooo`00001Pooooo`00NOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo0000063ooooo001iooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1;ooooo`05
o`000?ooooooooooooooool00000H?ooool007Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo04cooooo00Co0000oooooooooooo0000H?ooool007Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`;o0000COooool00ol0003o
ooooo`00001Qooooo`00NOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooo`00001Qooooo`00NOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooo`00
001Qooooo`00NOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0C?ooool00ol0003oooooo`00001Qooooo`00NOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0COooool2o`00067ooooo001iooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0:oooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0/?ooool007Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool007[ooooo00Go
0000ooooooooooooooooo`00000[ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00N_oo
ool01Ol0003ooooooooooooooooo000002_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3o
oooo001jooooo`05o`000?ooooooooooooooool00000:oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo0;3ooooo001jooooo`05o`000?ooooooooooooooool00000;?ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo001jooooo`04o`000?ooooooooooo`00
02gooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00N_ooool01?l0003o
ooooooooool0000^ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool007[o
oooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`2`ooooo`00N_ooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo0;3ooooo001jooooo`04o`000?ooooooooooo`00
03Oooooo00?o0000ooooooooool0/?ooool007[ooooo00Co0000oooooooooooo0000=oooool2o`00
0;7ooooo001jooooo`04o`000?ooooooooooo`0003Oooooo00?o0000ooooooooool0/?ooool007_o
oooo00?o0000ooooool00000=oooool00ol0003oooooooooo`2`ooooo`00Noooool00ol0003ooooo
o`00000gooooo`03o`000?oooooooooo0;3ooooo001kooooo`;o0000>?ooool00ol0003ooooooooo
o`2`ooooo`00Noooool2o`0003Sooooo00?o0000ooooooooool0/?ooool007_ooooo0_l0000hoooo
o`03o`000?oooooooooo0;3ooooo001looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj
^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_oo
ool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj^[[o
oooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003
oa0@4?oooooooooo00;ooooo0_l000001?l@413oooooooooooooool5o`0007Sooooo0021ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0N?ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00004ooooo`03
oiRHV?lQ8B7ok^k^07Wooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool0
0006ooooo`03oiRHV?lQ8B7ok^k^07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo0000
6Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00007
ooooo`03ogMgMomVIVKooooo07Oooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000
o`000003o`0001cooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000008ooooo`03o`00
0?oooooooooo07Kooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[ZjoooooonHV9So
410@07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEE
ofIVI_l000001_ooool00omgMgOo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(144) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30858 m
.00942 .23648 L
.01483 .19819 L
.01975 .17129 L
.02496 .15112 L
.02782 .14319 L
.03053 .13739 L
.03303 .13325 L
.03534 .13029 L
.03788 .12782 L
.03916 .12686 L
.04057 .12599 L
.04198 .12532 L
.04272 .12504 L
.04351 .12479 L
.04427 .12462 L
.04497 .1245 L
.04631 .12438 L
.04761 .12441 L
.04835 .12448 L
.04902 .12458 L
.05026 .12485 L
.05157 .12525 L
.05298 .1258 L
.05449 .12652 L
.05722 .12818 L
.06046 .13078 L
.06341 .13382 L
.06867 .14101 L
.0744 .15147 L
.08481 .17715 L
.08996 .19212 L
.09552 .20765 L
.09807 .21386 L
.10076 .2194 L
.10306 .22312 L
.10436 .22477 L
.10557 .22598 L
.10694 .22695 L
.10823 .22748 L
.10939 .22763 L
.11064 .22743 L
.11201 .22681 L
.1127 .22634 L
.11346 .22571 L
.11606 .22266 L
.11894 .21796 L
.12204 .21186 L
.12763 .19984 L
.13278 .18968 L
Mistroke
.13561 .18512 L
.13827 .18178 L
.13979 .18038 L
.14064 .17976 L
.14143 .17932 L
.14209 .17904 L
.14282 .17883 L
.14358 .17873 L
.14428 .17875 L
.14501 .17889 L
.14569 .17913 L
.14698 .17987 L
.14836 .18111 L
.14986 .18301 L
.15117 .18515 L
.1524 .18757 L
.15519 .19474 L
.15791 .20407 L
.16083 .21695 L
.16613 .2479 L
.17097 .28328 L
.17596 .32119 L
.17871 .33937 L
.18005 .34691 L
.18129 .35283 L
.18244 .35731 L
.1837 .36102 L
.18498 .36337 L
.18632 .3643 L
.18746 .3638 L
.18868 .36199 L
.18983 .3591 L
.19088 .35552 L
.19366 .34231 L
.19623 .32638 L
.20205 .28508 L
.20714 .25159 L
.21263 .22308 L
.21519 .21256 L
.21789 .20323 L
.22272 .19045 L
.22725 .18192 L
.2322 .17462 L
.25383 .14987 L
.2644 .13913 L
.27439 .13126 L
.27707 .12945 L
.27854 .12861 L
.27992 .12796 L
.2814 .12742 L
Mistroke
.28219 .1272 L
.28303 .12702 L
.2838 .1269 L
.28454 .12682 L
.28591 .12678 L
.28717 .12685 L
.28851 .12703 L
.28977 .1273 L
.29092 .12765 L
.29227 .12822 L
.29373 .12905 L
.29511 .13013 L
.29638 .13142 L
.29771 .13314 L
.29897 .13519 L
.30132 .1403 L
.30386 .14796 L
.30661 .15927 L
.30902 .17211 L
.31158 .18943 L
.31616 .2328 L
.32661 .38858 L
.32947 .42899 L
.33091 .44496 L
.33173 .45238 L
.33248 .45791 L
.33383 .46472 L
.33457 .46666 L
.33527 .46729 L
.33652 .46549 L
.33786 .45947 L
.33914 .45013 L
.34033 .43854 L
.34304 .40414 L
.34851 .32066 L
.35114 .28368 L
.35364 .25408 L
.35607 .23116 L
.35832 .215 L
.36047 .20372 L
.36167 .19901 L
.36276 .19565 L
.36395 .1929 L
.36524 .19098 L
.36646 .19014 L
.36758 .19016 L
.36878 .19101 L
.36989 .19254 L
.37111 .195 L
.37242 .1985 L
Mistroke
.37509 .20813 L
.37752 .21934 L
.38728 .27371 L
.38965 .28536 L
.3922 .29532 L
.39295 .2976 L
.39366 .29945 L
.395 .30204 L
.39625 .30337 L
.39762 .30353 L
.39839 .30302 L
.39911 .30215 L
.40046 .29953 L
.40122 .29751 L
.40192 .29531 L
.4035 .28929 L
.40896 .26004 L
.41402 .22867 L
.41944 .19801 L
.42478 .17416 L
.42965 .15876 L
.432 .15346 L
.43455 .14909 L
.43572 .14751 L
.43696 .14611 L
.43919 .14419 L
.44053 .14338 L
.44175 .14283 L
.44309 .14245 L
.44377 .14233 L
.44451 .14227 L
.44576 .1423 L
.4471 .14253 L
.44836 .14293 L
.4495 .14345 L
.45096 .1443 L
.45231 .14527 L
.45536 .14805 L
.46089 .15459 L
.47118 .16984 L
.47686 .17879 L
.48225 .18604 L
.48467 .18863 L
.48725 .19086 L
.48873 .19189 L
.49008 .19267 L
.49143 .19328 L
.4927 .19371 L
.49386 .19396 L
.49509 .19409 L
Mistroke
.49614 .19408 L
.49729 .19395 L
.49853 .19365 L
.49985 .19317 L
.50111 .19258 L
.50225 .19192 L
.51227 .18316 L
.52291 .17244 L
.52729 .16857 L
.532 .16525 L
.5347 .16377 L
.53717 .16263 L
.53968 .16166 L
.54201 .16091 L
.54428 .16035 L
.54554 .16012 L
.54669 .15996 L
.54795 .15985 L
.54932 .15981 L
.55061 .15986 L
.5518 .15997 L
.55303 .16016 L
.55418 .1604 L
.55544 .16075 L
.5568 .16121 L
.55956 .16249 L
.56208 .16411 L
.56487 .16659 L
.56744 .16972 L
.57027 .17436 L
.57328 .18097 L
.57588 .18832 L
.57832 .1968 L
.58389 .22273 L
.59419 .29327 L
.59691 .31284 L
.59981 .33092 L
.60122 .33798 L
.60256 .34334 L
.60375 .34692 L
.60505 .34937 L
.60616 .35023 L
.60739 .34982 L
.60867 .34786 L
.60987 .34464 L
.61099 .34049 L
.61201 .33579 L
.61432 .32243 L
.62447 .24253 L
.62947 .20655 L
Mistroke
.63481 .1768 L
.63985 .15643 L
.64441 .14328 L
.64721 .13721 L
.64979 .13271 L
.65257 .12879 L
.65562 .12536 L
.65809 .12312 L
.66075 .12117 L
.66355 .11958 L
.66617 .11851 L
.66745 .11811 L
.66886 .11776 L
.66957 .11762 L
.67034 .11749 L
.67172 .11732 L
.67303 .11722 L
.6744 .11719 L
.67557 .11722 L
.67686 .1173 L
.67764 .11739 L
.67838 .11749 L
.67977 .11774 L
.68126 .11812 L
.68288 .11865 L
.68579 .11997 L
.68848 .12164 L
.69337 .12594 L
.69615 .12921 L
.69874 .13292 L
.70398 .1428 L
.70961 .15777 L
.75296 .26855 L
.75556 .2633 L
.75692 .26083 L
.75837 .2586 L
.75963 .25708 L
.76102 .25598 L
.76228 .25556 L
.76345 .25573 L
.76422 .25616 L
.76494 .2568 L
.76629 .25865 L
.76704 .26008 L
.76774 .26164 L
.76932 .26609 L
.77189 .27608 L
.77463 .2902 L
.77962 .32289 L
.78237 .34214 L
Mistroke
.78499 .35882 L
.78742 .37106 L
.78879 .37603 L
.79007 .37915 L
.79125 .38061 L
.79232 .38072 L
.79355 .37935 L
.79471 .37662 L
.79582 .37276 L
.79704 .36719 L
.79949 .3522 L
.80389 .31684 L
.81382 .23504 L
.81907 .20452 L
.82202 .19193 L
.82471 .18299 L
.82721 .17661 L
.82853 .17391 L
.82993 .17148 L
.83115 .16972 L
.8325 .1681 L
.83365 .16697 L
.83488 .16599 L
.83615 .1652 L
.83734 .16464 L
.83807 .16438 L
.83875 .16418 L
.84003 .16394 L
.84139 .16384 L
.84264 .16389 L
.84401 .16407 L
.8447 .16421 L
.84546 .16441 L
.84788 .16522 L
.85048 .16638 L
.85517 .16881 L
.86104 .17175 L
.86393 .17298 L
.86661 .17394 L
.86903 .17461 L
.87039 .17488 L
.87161 .17506 L
.87296 .17518 L
.87372 .1752 L
.87442 .1752 L
.87571 .17512 L
.87707 .17495 L
.87835 .17469 L
.87975 .17432 L
.88228 .1734 L
Mistroke
.88703 .17097 L
.89258 .1671 L
.89771 .16267 L
.91697 .14452 L
.92184 .14052 L
.92709 .13695 L
.9295 .13561 L
.93204 .13442 L
.93421 .1336 L
.93535 .13325 L
.93658 .13294 L
.93735 .13279 L
.93805 .13268 L
.93943 .13254 L
.94068 .13253 L
.94201 .13264 L
.9427 .13275 L
.94343 .13292 L
.94477 .13334 L
.94558 .13367 L
.94635 .13405 L
.9478 .13493 L
.95039 .13712 L
.95279 .13995 L
.95542 .14411 L
.95822 .15003 L
.96085 .15723 L
.96362 .16685 L
.96858 .19006 L
.97391 .22409 L
.97976 .26915 L
.98482 .30644 L
.98628 .31519 L
.98766 .32215 L
.98889 .32715 L
.99024 .33106 L
.99141 .33309 L
.9927 .33378 L
.99405 .33274 L
.99531 .33016 L
.99649 .32641 L
.99757 .32192 L
1 .30858 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03;ooooo
1_l0001hooooo`00]Oooool00ol0003oooooooooo`0`ooooo`;o00001Oooool3o`0007Kooooo000T
ooooo`?o0000S_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0M?ooool002;ooooo0_l00002ooooo`;o0000Aoooool4o`0004;ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07?ooooo000Qooooo`03
o`000?oooooooooo00Cooooo0_l00014ooooo`03o`000?oooooooooo00;ooooo0_l00010ooooo`;o
0000;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07;ooooo000Pooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0?oooool2o`0000Kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
B?ooool5o`0002Cooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo0ol00004ooooo`;o00008ooo
ool001oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo023ooooo000Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo1?l0000?ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08?ooool001oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool2o`0000;o
oooo0_l0000>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`10ooooo`;o00002oooool00ol0003oooooooooo`0Oooooo`007_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07_ooool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo0_l0000[ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo000Moooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool001gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool7o`0001Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool001Gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo017ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool3o`0000Oooooo00?o0000ooooooooool02ooo
ool4o`000005oa0@4?ooooooooooonk^k_lb<S800_l000000oo^k^koooooooooo`0Dooooo`04o`00
0?ooooooooooooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo1Ol000001OnH
V9So410@o`000?lb<S;oc<c<00?ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001Cooooo
00?o0000ooooooooool01?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0?
ooooo`03o`000?oooooooooo00Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01Ol0003o8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Fooooo`09o`000?oo
oooooooooooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0E
ooooo`03o`000?oooooooooo00;ooooo1?l000000omgMgOo<S8booooo`02ooooo`04ogMgMonHV9So
oooooiRHV0;o00005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?l0
003oooooooooool@41004?ooool00ol0003oooooo`000005o`0000Kooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l000001_oooooo0000oooooonHV9So8B4Q
onk^kPCooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?oooooo0000ooooool@41005_ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@400Dooooo`03o`000?oooooooooo00Oooooo0_l00003oooo
o`05oa0@4?ooooooooooo`000?l@41005_ooool00ol0003oooooooooo`02ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo0_l0
0002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00onYZJWo410@oooo
o`02ooooo`05o`000?ooooooooooooooool000006Oooool01ol0003oooooooooooooooooV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`00
0?oooooo000001Oooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`05ojVYZOl0003o0000o`00
0?ooool00ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGo
ooooo`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooo
ooooo`02ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooool0003oooooo`00000Gooooo`03o`000?oooooooooo00?ooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01ooo
ool00ol@413o0000okZj^P02ooooo`;o00000oooool00ol0003oooooooooo`0Eooooo`08o`000?oo
oooooooooooooooMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01Cooooo00?oMgMgolc<c?l000001?ooool01Ol0003ooooooooooooooooo410@017ooooo00?o0000
ooooooooool02Oooool00onj^[[o8B4Qooooo`02ooooo`Co000000?o410@ooooooooool05_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`;o0000
0oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool01Ol@413oooooo`000?oooooo410@01Oooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Gooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00Go0000oiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oo
oooooooo00Kooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nHV9Soooooo`000?mg
MgL05oooool02Ol0003ooooooooooooooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9So0000oiRHV?mgMgL06?ooool01ol0003oooooo`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooooooo
ool01_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0G
ooooo`03o`000?oooooooooo00;ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Go0000oc8b<_l0003o<S8bonk^
kP0Booooo`03o`000?oooooooooo00Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`06o`00
0?o^k^ko<S8bo`000?lb<S;o00005oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0?ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooo
oooo00Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000o`000?lb<S;ok^k^01Sooooo00Oo
0000oooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Boooo
o`03o`000?oooooooooo00Kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06?ooool00ol0003oooooooooo`02ooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03_ooool2o`00013ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Kooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool03_ooool2o`00013ooooo00?o0000ooooooooool04_ooool6
o`0001Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool0000>ooooo`03o`000?oooooooooo01Gooooo0ol0000Hooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00003_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01[ooooo000Foooooooo0000@?l0000Cooooo`005_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`0Aooooo`005_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`006_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_oo
ool001[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01Wooooo000Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Iooooo`006Oooool00ol0003oooooooooo`0Jooooo`;o00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Iooooo`006Oooool00ol0003oooooooooo`0Kooooo`Co00003oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06Oooool001Wooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool06Oooool001Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool2o`0001Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Iooooo`006Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hoooo
o`006Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`006Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`006?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Hooooo`006?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;o
oooo0_l0000>ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06?ooool001Sooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool2o`0001[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Co00003Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
5oooool001Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Gooooo`006?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
01Oooooo000Gooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo
000Gooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo0_l0000L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool001Oooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000007_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool0
01Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool05_ooool001Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo01Kooooo000Gooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool01?l0003oooooo`000?l0000Nooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Fooooo`005_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooool000007oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05_ooool001Kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`?o00005?ooool5o`0000Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Kooooo000Fooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Ko
oooo000Fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00onHV9So8B4Q
onk^kP07ooooo`?o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool004gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooo
oooooooo000001?ooooo001>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00Go0000oooooooooooooooo
o`00000Cooooo`00C_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0001Cooooo
001>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02;ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=oooool01?l0003oooooooooool0000Dooooo`00
C_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`0Mooooo`05o`000?ooooooooooooooool00000=?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Oooooo00Co0000oooooooooooo00005?ooool004kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool00000=?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000005?ooool0
04kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooo
ooooool00000=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooool000005?ooool004oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool2o`0001kooooo00Go0000oooo
ooooooooooooo`00000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool2
o`0001Gooooo001?ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooo
oooo000003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@ooooo`00Coooool0
1Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo0000=_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo053ooooo001?ooooo`05o`000?ooooooooooooooool00000
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooo`00000fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
D?ooool004oooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000003Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`00Coooool01Ol0003ooooooooo
oooooooo000002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01kooooo0_l0000gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
DOooool004oooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooooooooooooo000005?o
oooo001?ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo05Sooooo00Go0000ooooooooooooooooo`00001Coooo
o`00D?ooool00ol0003oooooo`00000Zooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1Hooooo`05o`000?ooooooooooooooool00000Doooool0053o
oooo0ol0000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool2o`0005Wo
oooo00Co0000oooooooooooo0000E?ooool0057ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0F?ooool01?l0003o
ooooooooool0001Dooooo`00OOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0F?ooool01?l0003oooooooooool0001Dooooo`00O_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0F?ooool01?l0003o
ooooooooool0001Dooooo`00O_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0FOooool00ol0003oooooo`00001Dooooo`00O_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0FOooool00ol0003ooooo
o`00001Dooooo`00O_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`1Cooooo`00O_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/?ooool007kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0_ooooo`;o0000/Oooool007kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0;3ooooo001nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2`ooooo`00O_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/?oo
ool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo0;3ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool007kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/?ooool007oooooo00Go0000ooooooooooooooooo`00000Vooooo`Go00001_ooool00ol0003o
ooooooooo`2`ooooo`00Ooooool01Ol0003ooooooooooooooooo000002Kooooo00CoA4A4omgMgOoo
oooo00001oooool3o`000;3ooooo001oooooo`05o`000?ooooooooooooooool000009_ooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo001oooooo`05o`000?oooooooooo
ooooool000009oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo001ooooo
o`04o`000?ooooooooooo`0002Sooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`
ooooo`00Ooooool01?l0003oooooooooool0000Yooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0/?ooool007oooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`2`
ooooo`00Ooooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo0;3ooooo001ooooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0/?ooool007oooooo00Co0000oooo
oooooooo0000<_ooool2o`000;7ooooo001oooooo`04o`000?ooooooooooo`0003;ooooo00?o0000
ooooooooool0/?ooool007oooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`2`
ooooo`00Ooooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo0;3ooooo001ooooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0/?ooool007oooooo00Co0000oooo
oooooooo0000<_ooool00ol0003oooooooooo`2`ooooo`00Ooooool00ol0003oooooo`00000coooo
o`03o`000?oooooooooo0;3ooooo0020ooooo`;o0000<oooool00ol0003oooooooooo`2`ooooo`00
P?ooool2o`0003?ooooo0_l0002aooooo`00P?ooool2o`0003?ooooo00?o0000ooooooooool0/?oo
ool0083ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00
0;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`00
0?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go
0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo
003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083o
oooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@413o
ooooooooo`03ooooo`;o000000?o410@ooooooooool0M_ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Moooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0K
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`Go0000N?ooool0087ooooo00Ko0000
oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003o
ooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4omgMgOoooooo0000NOooool0
087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo0000NOooool0
087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003ooooo
ooooo`03ooooo`03ogMgMoo<c<co000000Gooooo00?oMgMgolc<c?l00000NOooool0087ooooo00Ko
0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00oo^
k^koA4A4o`000005ooooo`03onk^k_m4A4Co000007Wooooo0020ooooo`03oa0@4?l0003oQhN700;o
oooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Boooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`05oooo
o`03ogMgMol0003ooooo07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(146) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23782 m
.00488 .20386 L
.00942 .17911 L
.01199 .16822 L
.01441 .15984 L
.01721 .15226 L
.01975 .1471 L
.02227 .1434 L
.02354 .14201 L
.02494 .1408 L
.02613 .14003 L
.02741 .13945 L
.02862 .13911 L
.02973 .13898 L
.03111 .13903 L
.03239 .13928 L
.03312 .13952 L
.03379 .13978 L
.03529 .14056 L
.03659 .14144 L
.03801 .1426 L
.04057 .14521 L
.04591 .1526 L
.05177 .16333 L
.06361 .19013 L
.0689 .20168 L
.07181 .20707 L
.07457 .21126 L
.07714 .21419 L
.07859 .21539 L
.07993 .2162 L
.08105 .21665 L
.08229 .21689 L
.08359 .21688 L
.08481 .21661 L
.08604 .21611 L
.08736 .21531 L
.08974 .21328 L
.09256 .21002 L
.09513 .20646 L
.106 .18938 L
.1108 .18286 L
.11332 .18 L
.116 .17746 L
.11833 .17567 L
.1209 .17415 L
.12203 .17363 L
.12324 .17317 L
.12437 .17282 L
.12543 .17256 L
Mistroke
.1261 .17243 L
.12683 .17233 L
.1281 .17221 L
.12883 .17218 L
.12959 .17217 L
.13095 .17223 L
.13221 .17236 L
.13339 .17254 L
.13468 .1728 L
.13607 .17313 L
.13919 .1741 L
.14214 .17525 L
.14766 .178 L
.15292 .18153 L
.15778 .18614 L
.16032 .18942 L
.16311 .19404 L
.16603 .20033 L
.16877 .20796 L
.18821 .32562 L
.19095 .34541 L
.19354 .3606 L
.19497 .3669 L
.19577 .36966 L
.19652 .37166 L
.19783 .37384 L
.19849 .37426 L
.19922 .37418 L
.20055 .37257 L
.20177 .36946 L
.20244 .36708 L
.20317 .364 L
.20451 .35711 L
.20707 .33988 L
.20945 .32047 L
.21946 .23228 L
.22517 .19337 L
.22797 .17847 L
.23053 .167 L
.2357 .14939 L
.23841 .14254 L
.24128 .1367 L
.24673 .12844 L
.24982 .12501 L
.2527 .12246 L
.25527 .12064 L
.25799 .1191 L
.26098 .11779 L
.26373 .11685 L
.26629 .11617 L
Mistroke
.26752 .11592 L
.26869 .11572 L
.27007 .11555 L
.27132 .11544 L
.27268 .11539 L
.27344 .11539 L
.27415 .11541 L
.27538 .11548 L
.27671 .11563 L
.27796 .11582 L
.27911 .11605 L
.28129 .11662 L
.2836 .11744 L
.28608 .1186 L
.2884 .12001 L
.29094 .12199 L
.29366 .12474 L
.29636 .12821 L
.29922 .13287 L
.30436 .14443 L
.30721 .1531 L
.30988 .16304 L
.31598 .19342 L
.32608 .26672 L
.33179 .31121 L
.33458 .32897 L
.33711 .34106 L
.33835 .34529 L
.33968 .34855 L
.34095 .35035 L
.34211 .35092 L
.34335 .35045 L
.3447 .34875 L
.34539 .34747 L
.34612 .34583 L
.34745 .34224 L
.35303 .32289 L
.35436 .31845 L
.35577 .31424 L
.357 .3112 L
.35832 .30865 L
.35964 .30697 L
.36087 .30624 L
.36208 .30636 L
.36318 .30722 L
.36441 .309 L
.36576 .31193 L
.36717 .31602 L
.36848 .32067 L
.3733 .3425 L
Mistroke
.37542 .3527 L
.37776 .36274 L
.37899 .36709 L
.38032 .37076 L
.38105 .37226 L
.38172 .37328 L
.38304 .37423 L
.38376 .37412 L
.38444 .37361 L
.38518 .37257 L
.38597 .37093 L
.38673 .36886 L
.38744 .36645 L
.38877 .36084 L
.39137 .34609 L
.39377 .3291 L
.39918 .28532 L
.40409 .24759 L
.40867 .21902 L
.41344 .19742 L
.41597 .18917 L
.41869 .18248 L
.42137 .17775 L
.42273 .17599 L
.42423 .17446 L
.4255 .17348 L
.42688 .17272 L
.42817 .17225 L
.42936 .17201 L
.43004 .17195 L
.43076 .17194 L
.43206 .17205 L
.43286 .1722 L
.43361 .1724 L
.43502 .17287 L
.43788 .17421 L
.44098 .17606 L
.45103 .18252 L
.45379 .18402 L
.45675 .18538 L
.45819 .18592 L
.45955 .18637 L
.46089 .18673 L
.4621 .18699 L
.46339 .1872 L
.46461 .18734 L
.46589 .18741 L
.46728 .18742 L
.4685 .18737 L
.46978 .18727 L
Mistroke
.47088 .18714 L
.47208 .18696 L
.4748 .18643 L
.47771 .18568 L
.48296 .18389 L
.49452 .17859 L
.50505 .17253 L
.52682 .15496 L
.53638 .14643 L
.54146 .14236 L
.54413 .14043 L
.54693 .13867 L
.54945 .13741 L
.55087 .13686 L
.5522 .13648 L
.55342 .13623 L
.55453 .1361 L
.55581 .13608 L
.55702 .13619 L
.55817 .13641 L
.55938 .1368 L
.56042 .13725 L
.56156 .13791 L
.56279 .13881 L
.5641 .14005 L
.56648 .14307 L
.56786 .14538 L
.56914 .14793 L
.57204 .15538 L
.5746 .16416 L
.57732 .1761 L
.58202 .2041 L
.58722 .24672 L
.59237 .29746 L
.59518 .32459 L
.59779 .34625 L
.59895 .354 L
.60003 .36007 L
.60129 .36539 L
.60243 .36853 L
.60369 .37001 L
.60486 .36948 L
.60614 .3668 L
.6075 .36166 L
.60885 .35436 L
.61009 .346 L
.61288 .32252 L
.61792 .27196 L
.62347 .21939 L
.62652 .1958 L
Mistroke
.62939 .17749 L
.63199 .16394 L
.63481 .1522 L
.63737 .14384 L
.63973 .13781 L
.64195 .13336 L
.6444 .12965 L
.64563 .12817 L
.64695 .12683 L
.64933 .125 L
.65078 .12419 L
.65213 .12363 L
.65283 .1234 L
.65361 .1232 L
.65441 .12305 L
.65517 .12296 L
.65585 .12292 L
.65656 .12291 L
.65784 .123 L
.65921 .12324 L
.65999 .12343 L
.66071 .12365 L
.66334 .12475 L
.66573 .12613 L
.66828 .128 L
.67109 .13053 L
.67618 .13654 L
.68157 .14522 L
.68657 .15569 L
.69124 .16771 L
.70244 .20409 L
.70796 .22291 L
.71065 .23109 L
.71308 .2375 L
.71562 .24289 L
.71679 .24483 L
.71802 .24649 L
.71933 .2478 L
.72054 .24857 L
.72185 .24892 L
.72259 .24891 L
.72327 .24875 L
.72397 .24846 L
.72472 .248 L
.72608 .24677 L
.72741 .24512 L
.72864 .24324 L
.73439 .2309 L
.74376 .20653 L
.74646 .20034 L
Mistroke
.74903 .19525 L
.75136 .19143 L
.75385 .18832 L
.75517 .1871 L
.75636 .18627 L
.75757 .1857 L
.7587 .18542 L
.76002 .18543 L
.76124 .18575 L
.76258 .18649 L
.76325 .18701 L
.76399 .18771 L
.76636 .19087 L
.76769 .19328 L
.7689 .19591 L
.77349 .20993 L
.77626 .22173 L
.77882 .23509 L
.78461 .27383 L
.78968 .31472 L
.79234 .33639 L
.79514 .35712 L
.79766 .37219 L
.79908 .3787 L
.80041 .38322 L
.80163 .38595 L
.80274 .3872 L
.80403 .38714 L
.80524 .38564 L
.80639 .38296 L
.80761 .37886 L
.80979 .36866 L
.81472 .33624 L
.82514 .2635 L
.82815 .24742 L
.831 .2346 L
.83635 .2162 L
.84144 .2038 L
.84617 .19501 L
.85688 .17881 L
.8761 .15238 L
.88721 .13954 L
.89266 .13434 L
.89767 .13031 L
.90215 .12728 L
.90707 .12455 L
.912 .12245 L
.9147 .12159 L
.91722 .12099 L
.91855 .12074 L
Mistroke
.91995 .12055 L
.92116 .12043 L
.92248 .12035 L
.92323 .12034 L
.92391 .12034 L
.92465 .12037 L
.92544 .12042 L
.92676 .12057 L
.92751 .12069 L
.92821 .12083 L
.92956 .12118 L
.93084 .1216 L
.93324 .12268 L
.93582 .12432 L
.93861 .12677 L
.94096 .12946 L
.94354 .13325 L
.94624 .13834 L
.94875 .14437 L
.95326 .15891 L
.9581 .18103 L
.96344 .21428 L
.96839 .25215 L
.97143 .27656 L
.97428 .29809 L
.97705 .31563 L
.97827 .32174 L
.9796 .32708 L
.9808 .33054 L
.98192 .33256 L
.98309 .33338 L
.98435 .33274 L
.98574 .33026 L
.98704 .32629 L
.98821 .32148 L
.98949 .31505 L
.99495 .2774 L
1 .23782 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00KOooool00ol0003oooooooooo`0jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2`ooooo`00JOooool8o`0003Wooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`;o00002?ooool2o`0004;ooooo00?o
0000ooooooooool0POooool6o`0002Wooooo001Vooooo`03o`000?oooooooooo00Wooooo0_l00011
ooooo`03o`000?oooooooooo02gooooo1Ol0001<ooooo`?o00001_ooool2o`0002Oooooo001Uoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool2o`0000_ooooo00?o0000oooo
ooooool09?ooool006Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0nooooo`;o
0000;?ooool00ol0003oooooooooo`04ooooo`;o0000Aoooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Cooooo001Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo001Sooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`Co00006Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo0_l0000?ooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`?o0000@_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l0000Gooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02;ooooo000Mooooo`;o00000_ooool2o`0003oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Wooooo0_l00007ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08_ooool001gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Qooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo
000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08Oooool001_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0>oooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool08?ooool001[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Poooo
o`006_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo023ooooo000Eooooo`;o0000
00Wo410@oooooooooooo0000onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0A
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Sooooo
00?o0000ooooooooool01Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003o
ooooooooo`0@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00Go
0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Oooooo1?l000001?l@413ooooo
ooooooo^k^h2o`000003oc8b<_o^k^kooooo00gooooo00?o0000ooooooooool02Oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`0=oiRHV?l@413o0000oc8b<_o<c<coooooo`00
0?ooooook^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo00Oooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool02_l0003ooooooooo
oooooooo0000ogMgMonHV9SooooooiRHV?mgMgL6ooooo`03o`000?oooooooooo017ooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06?ooool02?l0003ooooo
oooooonHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool01OmgMgOo0000oooooonHV9SoMgMg00oooooo00?o0000ooooooooool02?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`06oa0@4?nj
^[[oooooogMgMolb<S;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
00_ooooo1_l00002ooooo`Go00000_ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooool000005Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00Go410@o`000?oooooooooooa0@400?ooooo`03o`000?oooooooooo00Wooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01;ooooo00?o0000ooooooooool01?ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00003ooooo`;o00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo1ol00003ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`Go00004oooool2o`0001Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool00ol0
003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03ojVYZOl0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oo
oooooooo00Cooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`04omgMgOmEEEGoooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo00Co0000oa0@4?l0003o^[Zj0oooool5o`00
01Oooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o00005ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000@ooooo`03o`000?oooooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool00oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000000_ooool00ol0003ooooooa0@4003
ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooonj
^[[o8B4Q00?ooooo00Go410@oooooooooooo0000oa0@400Gooooo`03o`000?oooooooooo00Gooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0ol000000ooooooo0000o`00000Foooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
410@013ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool06oooool00ol0003o^[Zjob4Q8@03ooooo`05oa0@4?ooooooooooooooool@4100
5Oooool00ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000002ooooo`07o`000?ooooooMgMgoiRHV?oo
ooooV9RHogMgM`09ooooo`03o`000?oooooooooo00gooooo00Ko0000oa0@4?nHV9SooooookZj^_l0
0003ooooo`04ogMgMonHV9SooooooiRHV0;o00005_ooool02Ol0003ooooooooooooooooo0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooooooo00Oooooo0_l00008ooooo`;o00001?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonHV9SoMgMg013o
oooo00?o0000ooooooooool01oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Kooooo`05oa0@4?nHV9So0000okZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Gooooo00?o0000ooooooooool01?ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00_oMgMgo`000?ooooooooooo`000?ooooook^k^
oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00cooooo00Oo0000oooooonYZJWo410@
o`000?l@413oZJVY00?ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001Gooooo00Wo0000
oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00[ooooo00?o0000ooooooooool03oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool00ol0003oooooooooo`09ooooo`So00001_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?oEEEEofIVI_l000001?ooool01Ol0003o<S8bo`000?lb
<S;ok^k^013ooooo00?o0000ooooooooool01oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00?ok^k^o`000?l000000_l0000Kooooo`05ojVYZOl0003o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Gooooo00?o0000ooooooooool01Oooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Nooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07_ooool001Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01kooooo000Hooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`005oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Oooool001Koooooool00010
o`0001?ooooo000Fooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo000Gooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01go
oooo000Gooooo`03o`000?oooooooooo01Gooooo0ol0000Iooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`005oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Mooooo`005_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`005_ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Loooo
o`005_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Looooo`005_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01_ooooo0_l0000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01cooooo000Fooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool004gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool0
04gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04Oooool004gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo001=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo001>ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool004kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`00C_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Looooo`;o00006_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04_ooool004kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`00C_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo001?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool004oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`00Coooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01?ooooo001?ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool004oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`00Coooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Mooooo`;o00006oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool0053ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Cooooo`00D?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01?ooooo001@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool0
053ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00D?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Cooooo001Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
1Ol00006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo001Aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`;o00002_ooool00ol0003ooooooooo
o`0Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`00DOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_oo
ool3o`0000Wooooo00?o0000ooooooooool05?ooool00onHV9So8B4Qonk^kP07ooooo`?o00006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool000005_ooool0057ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`0Eooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
00005_ooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033o
oooo00Go0000ooooooooooooooooo`00000Fooooo`00D_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000001Kooooo001Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Dooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo00Co
0000oooooooooooo00005oooool005;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000Gooooo`00
D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool00000
5oooool005;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooo000001Oooooo001Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`;o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`;o00006?ooool0
05;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000003Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`00D_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool01Ol0003ooooo
oooooooooooo000003Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`00
D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07?ooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1<ooooo`00D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02So
oooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Looooo`05o`000?ooooooooooooooool00000>_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04cooooo001Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07?ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1<ooooo`00Doooool01Ol0003ooooooooooooooooo000003Gooooo00Go0000oooo
ooooooooooooo`00000Sooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00
000jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool005?ooooo00Go0000
ooooooooooooooooo`00000fooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
7Oooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0COooool005?ooooo00Co0000oooooooooooo0000=oooool01?l0003oooooooooool0000Soooo
o`;o00007_ooool00ol0003oooooo`00000kooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0COooool005?ooooo00Co0000oooooooooooo0000=oooool01?l0003oooooooooool0000S
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool00000??ooool01Ol0003ooooooooooooo
oooo000004oooooo001Dooooo`03o`000?oooooo000003Oooooo00Co0000oooooooooooo00008ooo
ool00ol0003oooooooooo`0Mooooo`?o0000??ooool01Ol0003ooooooooooooooooo000004oooooo
001Dooooo`03o`000?oooooo000003Sooooo0ol0000Sooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000004oooooo001Eooooo`03o`000?oo
oooooooo03Oooooo0_l0000Tooooo`03o`000?oooooooooo05cooooo00Co0000oooooooooooo0000
D?ooool00;Gooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool0001@ooooo`00]Ooo
ool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`00053ooooo002eooooo`03o`000?oo
oooooooo05gooooo0_l0001Aooooo`00]Oooool2o`0005kooooo0_l0001Aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool0
0:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<
c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zj
oooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?oooooo
JOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`00
0006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0
003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?l@413oc<c<07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B40N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0K
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`05o`000?ooooooooooooooool00000
N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
oiRHV?ooooooV9RHob4Q8@1hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003oEEEEo`000?l@413oc<c<07Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
6Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o
0000o`000003o`0001cooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`03
oeEEEOn7QhOooooo07[ooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool00ooMgMgo410@oiRHV01j
ooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo
000000Kooooo00?oMgMgo`000?ooool01?ooool01?o<c<coA4A4o`000?l@411hooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(148) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19483 m
.00236 .18688 L
.00488 .18015 L
.00726 .17539 L
.00942 .17229 L
.01075 .17093 L
.01197 .17001 L
.01331 .16934 L
.01399 .16913 L
.01473 .16899 L
.01598 .16897 L
.01732 .16921 L
.01859 .16966 L
.01975 .17025 L
.02239 .17215 L
.02485 .17448 L
.03042 .18127 L
.04057 .19497 L
.04334 .19805 L
.04635 .20078 L
.04773 .2018 L
.04919 .20272 L
.05045 .20338 L
.0518 .20394 L
.05311 .20434 L
.05431 .20457 L
.05551 .20469 L
.05665 .20469 L
.05798 .20455 L
.0592 .20431 L
.06055 .20391 L
.06198 .20337 L
.08481 .19116 L
.09488 .18922 L
.09754 .18895 L
.099 .18877 L
.10038 .18856 L
.10305 .18802 L
.10549 .18735 L
.10983 .18569 L
.11228 .18445 L
.11454 .18305 L
.11935 .17915 L
.12445 .17373 L
.13494 .16075 L
.14476 .14879 L
.14734 .1462 L
.14979 .14417 L
.15114 .14324 L
.15261 .14239 L
Mistroke
.15394 .14178 L
.15519 .14134 L
.15592 .14115 L
.1567 .14101 L
.15807 .1409 L
.15885 .14093 L
.15967 .14105 L
.16037 .14122 L
.16114 .14149 L
.16252 .14222 L
.16329 .14278 L
.164 .1434 L
.16537 .14492 L
.16666 .14677 L
.16916 .15169 L
.17149 .15813 L
.17406 .16754 L
.17682 .18086 L
.17957 .19789 L
.18245 .22047 L
.18761 .27313 L
.19208 .32702 L
.19454 .3555 L
.19686 .37852 L
.19818 .38903 L
.19887 .39364 L
.1996 .39775 L
.2009 .40297 L
.20209 .40531 L
.20329 .40521 L
.20441 .4029 L
.20564 .39796 L
.20696 .39005 L
.21703 .2787 L
.22255 .21865 L
.22774 .17813 L
.23042 .16283 L
.23332 .14987 L
.23653 .1391 L
.23948 .13196 L
.24201 .12753 L
.24478 .12406 L
.24617 .12273 L
.24767 .12157 L
.25036 .12001 L
.25172 .11944 L
.25247 .1192 L
.25316 .119 L
.2544 .11874 L
.25576 .11858 L
Mistroke
.25651 .11855 L
.25723 .11856 L
.25858 .11866 L
.25933 .11878 L
.26003 .11892 L
.26161 .11934 L
.26301 .11984 L
.26432 .1204 L
.26676 .12167 L
.26943 .12338 L
.27225 .12558 L
.27723 .1307 L
.28182 .13719 L
.28675 .14637 L
.29216 .15939 L
.30357 .19859 L
.30919 .22218 L
.31438 .24335 L
.31908 .25918 L
.32146 .26511 L
.32281 .26772 L
.32408 .26962 L
.32537 .27099 L
.32673 .27181 L
.32789 .272 L
.32916 .27169 L
.33053 .27076 L
.33129 .26999 L
.33199 .26914 L
.33463 .26481 L
.34472 .23957 L
.35003 .22721 L
.35271 .22251 L
.35423 .22045 L
.35492 .21968 L
.35566 .21896 L
.35699 .21799 L
.35826 .21747 L
.35949 .21737 L
.36064 .21764 L
.362 .21845 L
.36323 .21965 L
.36391 .22052 L
.36465 .22163 L
.36598 .22409 L
.3684 .23009 L
.37095 .23872 L
.3755 .26061 L
.38073 .29627 L
.38549 .33619 L
Mistroke
.39061 .3789 L
.39202 .38883 L
.39351 .39788 L
.39479 .40423 L
.39618 .40932 L
.39745 .41226 L
.39861 .41341 L
.39978 .41306 L
.40089 .41133 L
.40218 .40767 L
.40337 .40277 L
.40608 .38701 L
.41061 .35091 L
.41545 .3088 L
.4207 .26892 L
.42624 .23784 L
.42914 .22599 L
.43232 .216 L
.43522 .20927 L
.43792 .20466 L
.44066 .2013 L
.44326 .19903 L
.4456 .19755 L
.44814 .19636 L
.4509 .19541 L
.45383 .19464 L
.45639 .19404 L
.4591 .19334 L
.46154 .19255 L
.46422 .19139 L
.46666 .19003 L
.46893 .18847 L
.47405 .18396 L
.47953 .17779 L
.49872 .15045 L
.50947 .13676 L
.51513 .13097 L
.52112 .12603 L
.52636 .12265 L
.52914 .12122 L
.53213 .11998 L
.53354 .11951 L
.53487 .11913 L
.53617 .11881 L
.53737 .11858 L
.53851 .1184 L
.53972 .11827 L
.54106 .1182 L
.54228 .11819 L
.54355 .11826 L
Mistroke
.54473 .11839 L
.54602 .11862 L
.54741 .11898 L
.54887 .11949 L
.55025 .1201 L
.55283 .12166 L
.55524 .12366 L
.55747 .12607 L
.55992 .12948 L
.56252 .13416 L
.5651 .14015 L
.56789 .14845 L
.57292 .16951 L
.57584 .18603 L
.57891 .20729 L
.58439 .25488 L
.58956 .30563 L
.5921 .32871 L
.59443 .34649 L
.59575 .35438 L
.59713 .36076 L
.59785 .36319 L
.59852 .3649 L
.59926 .36613 L
.60005 .36667 L
.60142 .36573 L
.60272 .36267 L
.60388 .3582 L
.60515 .35164 L
.60746 .33582 L
.61001 .3141 L
.61517 .26508 L
.6196 .22652 L
.62445 .19335 L
.62711 .17941 L
.6296 .16893 L
.63222 .16022 L
.63502 .15327 L
.63628 .15087 L
.63764 .1487 L
.63883 .14712 L
.6401 .14576 L
.64125 .14479 L
.64251 .14397 L
.64365 .14343 L
.64473 .14308 L
.64608 .14285 L
.64684 .14281 L
.64755 .14284 L
.64885 .14303 L
Mistroke
.65024 .14344 L
.6516 .14404 L
.65288 .14479 L
.65527 .14663 L
.65811 .14955 L
.66072 .15287 L
.66661 .16235 L
.67697 .18546 L
.68267 .2007 L
.68806 .21476 L
.69308 .22594 L
.69592 .23086 L
.69727 .23276 L
.69854 .23423 L
.69969 .23529 L
.70074 .23602 L
.70191 .23657 L
.70317 .23684 L
.70431 .23679 L
.70556 .23644 L
.70687 .23574 L
.70808 .23481 L
.71058 .23214 L
.71328 .22831 L
.71819 .2197 L
.72737 .20227 L
.73257 .19422 L
.7352 .19112 L
.73808 .18847 L
.74054 .1868 L
.74193 .18609 L
.74319 .18557 L
.74436 .18519 L
.74564 .1849 L
.74684 .18474 L
.74796 .18467 L
.74932 .18472 L
.75 .18479 L
.75075 .1849 L
.75208 .18518 L
.75331 .18553 L
.7561 .18657 L
.75909 .18793 L
.76956 .19269 L
.77449 .19476 L
.77972 .19708 L
.78187 .1982 L
.78419 .19969 L
.78673 .20191 L
.78911 .20485 L
Mistroke
.79048 .20703 L
.79198 .20991 L
.79471 .21672 L
.79736 .22564 L
.79983 .23629 L
.80546 .27069 L
.81146 .3224 L
.8142 .34833 L
.81717 .37441 L
.81853 .38469 L
.81997 .39383 L
.8212 .39996 L
.82255 .40466 L
.82386 .40698 L
.82506 .40709 L
.82644 .40478 L
.82775 .40024 L
.82895 .39411 L
.83007 .38693 L
.8326 .36611 L
.84282 .25842 L
.84857 .20913 L
.85131 .19104 L
.85385 .17703 L
.85849 .15744 L
.86094 .14966 L
.86357 .14292 L
.86633 .13725 L
.86893 .13295 L
.87125 .12978 L
.87381 .12688 L
.87861 .12276 L
.88123 .12109 L
.88369 .11982 L
.88809 .11809 L
.89055 .11734 L
.89281 .11679 L
.89408 .11653 L
.89543 .11629 L
.8966 .11611 L
.89786 .11596 L
.89864 .11589 L
.89935 .11584 L
.90004 .11579 L
.90076 .11576 L
.90201 .11573 L
.90338 .11574 L
.90469 .11578 L
.90589 .11586 L
.90727 .11598 L
Mistroke
.90857 .11613 L
.9109 .11651 L
.91221 .1168 L
.91342 .11711 L
.91596 .11794 L
.91829 .11895 L
.92085 .12038 L
.92354 .1223 L
.92808 .12672 L
.93065 .13009 L
.93304 .13392 L
.93586 .13952 L
.93852 .14608 L
.9435 .16232 L
.94887 .18675 L
.95468 .2219 L
.95989 .25866 L
.96275 .27869 L
.96548 .29572 L
.968 .30847 L
.96943 .31395 L
.97075 .31773 L
.97198 .32005 L
.97309 .32111 L
.97437 .32111 L
.97557 .31991 L
.97685 .31739 L
.97821 .31342 L
.98063 .3034 L
.9861 .27156 L
.99209 .23348 L
.99767 .20431 L
1 .19483 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool006Oooooo0_l00011ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`09ooooo`?o0000K?ooool:o`0002kooooo001Uooooo`Oo0000BOooool00ol0003ooooooooo
o`06ooooo`Co00000_ooool3o`0006Oooooo0_l0000:ooooo`;o0000;?ooool006Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:Oooool006?ooooo00?o0000ooooooooool01_ooool2o`0004Oooooo00?o0000oooo
ooooool00oooool2o`0000[ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02Sooooo001Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0A?ooool2o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool006;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool006;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`00013o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Ko
oooo001Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool01?l0003ooooo
ooooool0000Aooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Uooooo`00A_ooool5o`0001Kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool05_ooool3o`0004?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`00AOooool00ol0003ooooooooo
o`02ooooo`;o00005?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo047ooooo0_l0
000Cooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`;o0000@_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Gooooo0014ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo0014oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03oooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool09?ooool004?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0?oooool3o`0001?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Tooooo`00@_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooo000001Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`00@Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Sooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^01[ooooo00goV9RHoa0@4?l0003o<S8bolc<c?oooooo0000ooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo01Gooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool02Oooool4o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8b
onk^k_ooool01_ooool00ol0003oooooooooo`0@ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h04?ooool00ol0003oooooooooo`0:ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01[ooooo00Ko410@okZj^_ooooooMgMgoc8b<_l00002ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0?ooooo`08o`000?oooooooooooiRHV?lQ8B7ok^k^oooo
oom4A4@3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?oooooooooo
ooooool000005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Go0000
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[Zjo`000?mgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`000003ooooool0003o000000;o00000_ooool00ol@413oooooooooo`0@ooooo`Ko00001_ooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`0@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400Looooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooooooo
oa0@400Aooooo`03o`000?oooooooooo00Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00CoA4A4omgMgOoooooo00000_ooool01?l0003oooooo`000?ooool3o`00
01gooooo00?o0000oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool04Oooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000007?ooool01?l0003oooooojVYZOl@4103ooooo`05o`000?oooooo
ooooooooool000004Oooool00ol0003oooooooooo`07ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`004oooool01_oMgMgoEEEEooooool0003oooooo`00
00;ooooo00?o0000ooooooooool00_l0000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00Co0000oa0@
4?l0003o^[Zj0oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool01ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo
00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooooooo000001_ooooo0_l000000onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41005oooool00ol0003oooooooooo`04ooooo`;o00005_ooool00ol0003ooooo
ooooo`09ooooo`06o`000?ooooooooooooooool0003o410@0oooool00ol@413oooooooooo`07oooo
o`03o`000?oooooooooo01;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo01[ooooo00Co0000oooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooooooo410@017ooooo
00?o0000ooooooooool02?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001Cooooo00Cok^k^odA4A?l0003o00000oooool01OmgMgOoV9RHoooooonHV9So0000
01Wooooo0_l000001?nHV9SooooookZj^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00ol0003oooooooooo`0=ooooo`09o`000?ooooooooooooooool0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00[o0000oooooooooooooooo
o`000?mgMgOoV9RHoooooonHV9SoMgMg2Oooool00ol0003oooooooooo`0>ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@o`000?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`07oooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omg
MgOo0000ooooo`03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00005_ooool3o`000005ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000oooooooo
ool03Oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Cooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`07ooooo`03oeEEEOmVIVKo000000?ooooo00Ko0000onk^k_lb
<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo00gooooo00CoV9RHoa0@4?l0003o8B4Q1ol0
00000olb<S;ok^k^ooooo`0Jooooo`05o`000?l@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool02?ooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0?ooooo`Co00005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0<_ooool2o`0000Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`03ooooo`?o00006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo027o
oooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool3o`0001cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo033ooooo
0_l0000;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool2o`0001Wooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`005_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Oooooo0ol0000Oooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`Co00003Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00[ooooo0ol0000Fooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`04
ooooo`?o00008_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0:_ooool2o`00013ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo000Tooooo`;o00000oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01;ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000
4oooool0053ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04_ooool0053ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo0ol0000Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01;ooooo001@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0;ooooo`;o000000?oooooo`000?l000005?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Coooo
o`00D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool0053o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo001@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Cooooo`00D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05Oooool2o`0001Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`00D?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_oo
ool4o`0001cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04oooool0053ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool0
053ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04oooool0053ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool0057ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05?ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool0057ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Kooooo0_l0000Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`00DOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`00
DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Eooooo`00DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo
00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05Oooool0057ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Oooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool0057ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Eooooo`00DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo001Aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool0057ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05oooool2o`0001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Kooooo001Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5_ooool005;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`00D_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool005;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Gooooo`00D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`Go00001_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`00D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00Go0000oooooooooooo
ooooo`00000Iooooo`00D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
0ol0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000Iooooo`00
D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0?ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0001[ooooo001Booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo013ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Oooooo00Co0000oooooooooooo00006_ooool005?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooo`00000Jooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo
0_l0000Kooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo001Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15ooooo`00Doooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool0
05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06Oooool2o`0001_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool005?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Go
oooo001Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool01Ol0003ooooo
oooooooooooo0000047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`00
E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00Go0000oooooooooooo
ooooo`000011ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool005Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0004;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`00E?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000@_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04Kooooo001Dooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool00012ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0A_ooool005Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Kooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`16ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo0000@_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Ko
oooo001Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01[ooooo0_l0000Mooooo`03o`000?oooooo000004;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00E?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01cooooo0_l00014ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0A_ooool005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool005Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0A_ooool005Cooooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0A_ooool005Cooooo00Go0000ooooooooooooooooo`00000ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Roooo
o`05o`000?ooooooooooooooool00000BOooool005Cooooo00Go0000ooooooooooooooooo`00000i
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1R
ooooo`05o`000?ooooooooooooooool00000BOooool005Cooooo00Go0000ooooooooooooooooo`00
000iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Rooooo`05o`000?ooooooooooooooool00000BOooool005Gooooo00Co0000oooooooooooo0000
>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo0_l0001Sooooo`05o`00
0?ooooooooooooooool00000BOooool005Gooooo00Co0000oooooooooooo0000>Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Hoooool01?l0003o
ooooooooool00019ooooo`00EOooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`04o`000?oooooooooo
o`0004Wooooo001Eooooo`03o`000?oooooo000003_ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`0004Wooooo001Eooooo`03o`000?oooooo
000003_ooooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooo000004[ooooo001Fooooo`;o0000>oooool01?l0003oooooooooool0000Eooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo000004[ooooo001F
ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06Cooooo0_l0001:ooooo`00U?ooool00ol0003oooooo`00000C
ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00U?ooool2o`0001Cooooo00CoA4A4omgM
gOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`oooo
o`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oo
oooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2o`000009oa0@4?ooooooooooooooooo<c<co
8B4Qo`000?lQ8B7oc<c<07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00ooo
ool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B40N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00;ooooo1Ol00003ooooo`05o`000?ooooooooooooooool00000N?ooool0087o
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P1hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000
o`000?l0003oc<c<07Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003
o`0001cooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?nj^[[o
oooookZj^_l@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooookZj
^_l00000N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omE
EEGoIVIVo`000006ooooo`03ogMgMol0003ooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1h
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21522 m
.00488 .21009 L
.00942 .20647 L
.01975 .20031 L
.02492 .19743 L
.02981 .19516 L
.03251 .19427 L
.03403 .1939 L
.03544 .19365 L
.03663 .1935 L
.03793 .19339 L
.03929 .19336 L
.04057 .1934 L
.04125 .19345 L
.04198 .19353 L
.0433 .19374 L
.0441 .19391 L
.04486 .1941 L
.04627 .19454 L
.04888 .19562 L
.0517 .19719 L
.05655 .20046 L
.06188 .20397 L
.06333 .20477 L
.06488 .20552 L
.06623 .20605 L
.06769 .20651 L
.06854 .20671 L
.06934 .20685 L
.07009 .20694 L
.0709 .20698 L
.07161 .20697 L
.07229 .20691 L
.07303 .2068 L
.07382 .20663 L
.07516 .20618 L
.07591 .20584 L
.07661 .20546 L
.07815 .20443 L
.07955 .20326 L
.08209 .20056 L
.08481 .19694 L
.10665 .15603 L
.11624 .1405 L
.12133 .13393 L
.12679 .12806 L
.13209 .1238 L
.13693 .12101 L
.13925 .11992 L
.14179 .11889 L
Mistroke
.14295 .11849 L
.14419 .11812 L
.14527 .11785 L
.14641 .11763 L
.14708 .11753 L
.14782 .11746 L
.14911 .1174 L
.14984 .11742 L
.15062 .11747 L
.15135 .11756 L
.15203 .11767 L
.15333 .11797 L
.15474 .11843 L
.15731 .11959 L
.1598 .12119 L
.16244 .12355 L
.16469 .1263 L
.16718 .13039 L
.16965 .13587 L
.17236 .14381 L
.17518 .15469 L
.1778 .16757 L
.18251 .19893 L
.18753 .24633 L
.19345 .31707 L
.19635 .35161 L
.19902 .37842 L
.20028 .38834 L
.20146 .39566 L
.20268 .40107 L
.20403 .40419 L
.2054 .40424 L
.20664 .40154 L
.20733 .39896 L
.20808 .3953 L
.20945 .38656 L
.21923 .28022 L
.22436 .22673 L
.22717 .20398 L
.22978 .18692 L
.23266 .17219 L
.23582 .16023 L
.23849 .15296 L
.23999 .14989 L
.24136 .14764 L
.24275 .14584 L
.24404 .14456 L
.24545 .14355 L
.24616 .14317 L
.24695 .14285 L
Mistroke
.24826 .14252 L
.249 .14243 L
.24968 .1424 L
.25099 .14249 L
.25223 .14273 L
.25357 .14313 L
.25483 .14364 L
.25718 .14494 L
.25972 .1468 L
.26245 .14935 L
.27194 .16152 L
.28313 .18123 L
.29343 .20483 L
.30298 .22874 L
.30824 .24078 L
.31082 .24572 L
.31321 .24947 L
.31455 .25118 L
.31603 .25271 L
.31751 .25385 L
.31832 .25431 L
.31909 .25463 L
.32043 .25492 L
.32166 .2549 L
.32301 .25455 L
.32369 .25424 L
.32444 .25381 L
.32581 .25276 L
.32706 .25151 L
.32987 .24782 L
.33491 .23864 L
.34471 .21755 L
.35006 .20745 L
.35507 .20019 L
.35768 .19747 L
.35915 .1963 L
.36049 .19546 L
.3612 .1951 L
.36195 .19479 L
.36278 .19454 L
.36354 .19438 L
.36433 .19428 L
.36506 .19427 L
.36644 .19441 L
.36772 .19474 L
.36907 .1953 L
.37022 .19593 L
.37148 .19679 L
.37429 .19935 L
.37692 .2025 L
Mistroke
.3822 .21105 L
.38793 .22344 L
.39298 .23705 L
.39834 .2549 L
.40317 .27511 L
.40848 .30306 L
.41785 .36411 L
.42045 .3805 L
.42183 .38821 L
.4233 .39538 L
.42471 .40099 L
.42598 .40482 L
.42727 .40732 L
.42848 .40832 L
.42966 .40797 L
.43092 .40614 L
.43198 .4034 L
.43316 .39916 L
.43442 .39322 L
.43577 .38541 L
.43822 .36807 L
.4496 .26658 L
.45461 .22782 L
.46013 .1943 L
.46531 .17119 L
.47081 .15359 L
.47369 .14653 L
.4768 .14018 L
.47949 .13559 L
.48243 .13142 L
.48779 .12567 L
.49072 .12332 L
.49344 .1215 L
.49833 .11895 L
.50106 .11789 L
.50355 .11717 L
.50597 .11666 L
.50735 .11644 L
.50864 .11628 L
.50997 .11614 L
.51123 .11605 L
.51193 .116 L
.51269 .11596 L
.51402 .11591 L
.5153 .11588 L
.51645 .11588 L
.51778 .1159 L
.51904 .11595 L
.5202 .11603 L
.52127 .11613 L
Mistroke
.52245 .11627 L
.52369 .11645 L
.52629 .11694 L
.52907 .11761 L
.5341 .11912 L
.53717 .12026 L
.54008 .1216 L
.54288 .12323 L
.54552 .12512 L
.55035 .12962 L
.55313 .13297 L
.55568 .13666 L
.56087 .14691 L
.56359 .15425 L
.56646 .16381 L
.57125 .18476 L
.5757 .2106 L
.58581 .28913 L
.58839 .30959 L
.59112 .32831 L
.59255 .33626 L
.59331 .33985 L
.59412 .34317 L
.59486 .3457 L
.59554 .34757 L
.59688 .34993 L
.59821 .35056 L
.59944 .34957 L
.6008 .34681 L
.60148 .34477 L
.60224 .34205 L
.60486 .32918 L
.60732 .31326 L
.61664 .24351 L
.61919 .22696 L
.62192 .2118 L
.62428 .2009 L
.62685 .19132 L
.62962 .18338 L
.63089 .18052 L
.63224 .17799 L
.63345 .17612 L
.63479 .1745 L
.63601 .17339 L
.63715 .17266 L
.63782 .17236 L
.63855 .17213 L
.63988 .172 L
.64117 .17218 L
.64238 .17261 L
Mistroke
.64311 .17299 L
.6438 .17341 L
.6451 .1744 L
.648 .17736 L
.65286 .18418 L
.65733 .19187 L
.66742 .21018 L
.66996 .21401 L
.67236 .21707 L
.67368 .21848 L
.67512 .21978 L
.67632 .22068 L
.67765 .22146 L
.67889 .22201 L
.68005 .22235 L
.68128 .22254 L
.68261 .22256 L
.68377 .22241 L
.685 .22209 L
.68605 .2217 L
.68719 .22116 L
.69004 .21933 L
.69263 .21721 L
.69843 .21187 L
.70341 .20787 L
.70624 .20616 L
.70763 .20549 L
.70889 .20497 L
.71007 .20457 L
.71135 .20422 L
.7127 .20396 L
.71398 .20381 L
.71534 .20376 L
.7161 .20377 L
.71678 .20381 L
.71812 .20396 L
.71938 .20418 L
.7218 .20479 L
.72402 .20547 L
.72645 .20623 L
.72778 .2066 L
.72904 .20689 L
.73041 .20713 L
.73166 .20725 L
.73284 .20727 L
.73411 .20719 L
.73478 .20711 L
.73551 .20698 L
.73628 .2068 L
.737 .20659 L
Mistroke
.73829 .20612 L
.73967 .20547 L
.74267 .20352 L
.74552 .20095 L
.75088 .1941 L
.7617 .17515 L
.77189 .15726 L
.77634 .15042 L
.78105 .14478 L
.78351 .14264 L
.78481 .14172 L
.78621 .14091 L
.78749 .14031 L
.78866 .1399 L
.78984 .13963 L
.79096 .13951 L
.79214 .13957 L
.79344 .13987 L
.79481 .1405 L
.79609 .14145 L
.79728 .14268 L
.79837 .14413 L
.80084 .14874 L
.80213 .15198 L
.80334 .15555 L
.80608 .16587 L
.80874 .17933 L
.81159 .19822 L
.81444 .22267 L
.81752 .25628 L
.82312 .33306 L
.82573 .3706 L
.82854 .40614 L
.8299 .41997 L
.83119 .43035 L
.83235 .43705 L
.83361 .44128 L
.83492 .44211 L
.8361 .4397 L
.83747 .4333 L
.83876 .42394 L
.84105 .40045 L
.84353 .36788 L
.84874 .29162 L
.8517 .25218 L
.85446 .22103 L
.85739 .19434 L
.86006 .17515 L
.86291 .15911 L
.86597 .14607 L
Mistroke
.86857 .13777 L
.86994 .13429 L
.8714 .13119 L
.87267 .12894 L
.87408 .12686 L
.87655 .12407 L
.87902 .12208 L
.88172 .1205 L
.88308 .11988 L
.88454 .11934 L
.88591 .11895 L
.88716 .11869 L
.88841 .11854 L
.88956 .1185 L
.89083 .11855 L
.89216 .11871 L
.89332 .11895 L
.89441 .11923 L
.89688 .12005 L
.90241 .12251 L
.90745 .12566 L
.91023 .12805 L
.91327 .13133 L
.91879 .13914 L
.9244 .14969 L
.92967 .16299 L
.9344 .17851 L
.93951 .19887 L
.95003 .2476 L
.95559 .27109 L
.9572 .27653 L
.95871 .28091 L
.96009 .28417 L
.96155 .28684 L
.9627 .28834 L
.96397 .28938 L
.96512 .28977 L
.9662 .28967 L
.96746 .289 L
.96863 .2879 L
.96997 .28608 L
.97124 .28387 L
.97556 .27364 L
.98027 .25965 L
1 .21522 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool004?ooooo1Ol0001Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool;o`00077ooooo
00?o0000ooooooooool0=?ooool0047ooooo0ol00004ooooo`;o0000JOooool3o`0000[ooooo0ol0
001[ooooo`?o000000Coooooo`000?l0003o0000<oooool0043ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
Ioooool2o`0000Kooooo0_l0000aooooo`00?oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06Cooooo00Go0000ooooooooooooooooo`00000=ooooo`;o0000Ioooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02kooooo000mooooo`;o00003?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`00??ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]
ooooo`00??ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0/ooooo`00>oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Kooooo1?l0000Fooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0:oooool003_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`Co0000
AOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
AOooool2o`0000;ooooo0_l0000Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:oooool003[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`00>Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:Oooool003Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Yooooo`00>?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Ko
oooo0_l0000Booooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool003Sooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`00=oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02Sooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h05oooool02?l0003ooooooooooonHV9So410@o`000?lb<S;oc<c<0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?ooool6o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`00
00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000;ooooo`03o`000?oooooooooo00cooooo00Go
V9RHoa0@4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003o
ooooooooo`0>ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00Wo
0000oooooooooooooooooa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Oooooo00?o0000ooooooooool04?ooool01_l0003oV9RHob4Q8Oo^k^koooooodA4A0?ooooo
00GoMgMgoiRHV?oooooo0000ogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000_o
oooo00?o0000ooooooooool03?ooool01Ol@413o^[Zjooooool0003o<S8b00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool01Oooool00ol0003oooooooooo`09ooooo`Oo00000_ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool000004oooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo000000cooooo00?o0000ooooooooool03oooool2o`0000?ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00cooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooonHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00?o00006oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?l@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo00_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Dooooo`03o`000?oooooooooo00Gooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`03ogMgMomVIVKooooo00;ooooo00Co0000oooooooooooooooo0_l0000Mooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`03o`000?oooooo000001_ooooo00?oMgMgofIVI_ooool00_ooool00ol0003ooooo
ooooo`02o`0000gooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`0;ooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41005?ooool00ol0003oooooooooo`06ooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool00000
7?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003o
ooooooooo`09ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00Go410@o`000?oooooooooooa0@4002ooooo`03o`000?oooooooooo01Wooooo00Go0000oooo
oooooooooooooa0@4002ooooo`03o`000?l@413ooooo00cooooo00?o0000ooooooooool03_ooool0
0ol0003o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003ooooooooo
o`0<ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool03Oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@
0oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000007?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9So
oooooiRHV?mgMgL00oooool00ol0003oooooooooo`0Dooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00gooooo00?o0000ooooooooool02oooool00ol@413o
V9RHooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo
00cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eoooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooo
oooo00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`0=ooooo`08o`000?oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`3
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0Gooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03oeEEEOmVIVKo000000Cooooo
00Go0000oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo01Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0003oooooooooo`0;
ooooo`05ojVYZOl@413o0000o`000?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
00?o0000ooooooooool03?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool003;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool09Oooool0027ooooo1?l0000=ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Gooooo000Oooooo`;o00000oooool2o`0000_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool5
o`0001_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02Cooooo000Mooooo`;o00001oooool2o`0000Wooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool2o`00
00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool09?ooool001_ooooo0_l0000;ooooo`03o`000?oooooooooo00Co
oooo0_l0000Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool001Kooooo
ool00010o`0001?ooooo000Fooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`?o00001oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo1?l00003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Kooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo017ooooo001@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Aooooo`00D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o000002Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04_ooool0057ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo0_l0000Yooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo001Aooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01?ooooo001Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo001Aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`;o00005ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04ooo
ool0057ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05?ooool0057ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool0057o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05Oooool0057ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool0057ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05_ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00;o00005_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05_ooool0057ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Looooo`?o00005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05_ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0001So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oo
oooo001Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool0057ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`00D_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Sooooo001Booooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06?ooool005;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`00
D_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo001Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`05o`000?oo
ooooooooooooool000007?ooool005;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool2o`0001Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000001cooooo001Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`04o`000?oo
oooo0000o`0001cooooo001Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Qooooo`?o00007Oooool005;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo001Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`00D_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool005?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool5o`0000Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`11ooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo001Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0001Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Ooo
ool005?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0@Oooool005?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool005?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0@_ooool005?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01Ol0003o^[Zj
oooooonHV9So410@00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00
Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`0Jooooo`05o`000?ooooooooooooooool00000AOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04;ooooo001Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06_ooool01Ol0003ooooooooooooooooo000004Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`12ooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`000015ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0@_ooool005?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool2o`0001_ooooo00Go0000oooooooo
ooooooooo`000015ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool005Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool00000AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo001Dooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooo`000016ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool005Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo000004Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`12ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooool00000A_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04;ooooo001Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool2
o`0004Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00E?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`13ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13ooooo`00E?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`13ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o0000I_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04?ooooo001Dooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo001Eoooo
o`05o`000?ooooooooooooooool00000@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04?ooooo001Eooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`13ooooo`00EOooool01?l0003oooooooooool00013ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@oooool005Gooooo00Co0000oooooooooooo0000@oooool0
1Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04?ooooo001Eooooo`04o`000?ooooooooooo`0004?ooooo00Go
0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`13ooooo`00EOooool01?l0003oooooooooool00013ooooo`05o`00
0?ooooooooooooooool000005?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0@oooool005Gooooo00Co0000oooooooooooo0000@oooool01Ol0003o
oooooooooooooooo000001Cooooo0_l0001Vooooo`05o`000?ooooooooooooooool00000A_ooool0
05Gooooo00Co0000oooooooooooo0000@oooool01Ol0003ooooooooooooooooo000001Cooooo00?o
0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000004Kooooo001Fooooo`03o`000?oo
oooo000004?ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo06Gooooo
00Go0000ooooooooooooooooo`000016ooooo`00E_ooool00ol0003oooooo`000013ooooo`05o`00
0?ooooooooooooooool000005?ooool00ol0003oooooooooo`1Uooooo`05o`000?oooooooooooooo
ool00000A_ooool005Kooooo00?o0000ooooool00000A?ooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000016ooooo`00Eoooool00ol0
003oooooooooo`13ooooo`03o`000?oooooo000000cooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000016ooooo`00WOooool3o`00
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`05o`000?oooooooooo
ooooool00000A_ooool009kooooo00?o0000ooooooooool02Oooool5o`0000Kooooo00?o0000oooo
ooooool0IOooool01Ol0003ooooooooooooooooo000004Kooooo002Zooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol0001Uooooo`05o`000?ooooooooooooooool00000A_ooool00:[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0004Kooooo
002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0I_ooool01?l0003ooooooooo
ool00016ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo06Kooooo00Co
0000oooooooooooo0000A_ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`1Vooooo`04o`000?ooooooooooo`0004Kooooo002eooooo`03o`000?oooooooooo06Kooooo00Co
0000oooooooooooo0000A_ooool00;Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00
0017ooooo`00]Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000004Oooooo002eoooo
o`;o0000J?ooool2o`0004Oooooo002eooooo`03o`000?oooooooooo06Oooooo0_l00017ooooo`00
]Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo04Gooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?oo
ool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj
^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2foooo
o`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hoooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o
QhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001Ol@413ooooo
ooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0M_ooool0087ooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`1fooooo`00POooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000N?oo
ool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@401hoooo
o`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Gooooo
1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}]
}, Closed]],

Cell["Fig. 7.7 (animation)  A solution of the KdV equation", "Caption",
  CellTags->"Fig. 7.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 -1.11022e-16 1.16608 [
[.5 1.098 -41.125 0 ]
[.5 1.098 41.125 24.5 ]
[.09072 .22988 -5.91576 -9 ]
[.09072 .22988 .08424 0 ]
[.22151 .17463 -5.64878 -9 ]
[.22151 .17463 .35122 0 ]
[.35968 .11629 -5.38181 -9 ]
[.35968 .11629 .61819 0 ]
[.50588 .0546 -5.11483 -9 ]
[.50588 .0546 .88517 0 ]
[.66081 -0.01073 -4.84785 -9 ]
[.66081 -0.01073 1.15215 0 ]
[.30907 .06148 -8.98592 -12 ]
[.30907 .06148 1.01408 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.12079 .90442 -6.71106 0 ]
[.12079 .90442 5.28894 9 ]
[.22056 .97437 -6.52538 0 ]
[.22056 .97437 5.47462 9 ]
[.31055 1.03745 -6.36418 0 ]
[.31055 1.03745 5.63582 9 ]
[.39213 1.09464 -6.2229 0 ]
[.39213 1.09464 5.7771 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.0469 .42724 -18 -2.76445 ]
[.0469 .42724 0 6.23555 ]
[.01721 .61309 -18 -2.93177 ]
[.01721 .61309 0 6.06823 ]
[-0.03373 .52941 -45.25 -3.77786 ]
[-0.03373 .52941 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -102.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(spectrum) show
69.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.23115 .18555 m
.23598 .19102 L
s
[(1)] .22151 .17463 .88293 1 Mshowa
.36874 .1277 m
.37327 .13341 L
s
[(2)] .35968 .11629 .79394 1 Mshowa
.51427 .06651 m
.51847 .07247 L
s
[(3)] .50588 .0546 .70494 1 Mshowa
.66846 .00168 m
.67228 .00789 L
s
[(4)] .66081 -0.01073 .61595 1 Mshowa
.125 Mabswid
.12637 .22961 m
.12939 .23277 L
s
.15215 .21877 m
.15514 .22196 L
s
.1782 .20782 m
.18116 .21104 L
s
.20453 .19675 m
.20746 .19999 L
s
.25807 .17424 m
.26093 .17754 L
s
.28528 .16279 m
.28811 .16613 L
s
.31279 .15123 m
.31558 .15459 L
s
.34061 .13953 m
.34337 .14292 L
s
.39719 .11574 m
.39987 .11919 L
s
.42596 .10364 m
.42861 .10713 L
s
.45507 .09141 m
.45767 .09492 L
s
.4845 .07903 m
.48706 .08257 L
s
.54439 .05385 m
.54687 .05745 L
s
.57487 .04103 m
.5773 .04467 L
s
.6057 .02807 m
.60808 .03173 L
s
.63689 .01495 m
.63923 .01865 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(10)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(20)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(30)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(40)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.0605 .42199 m
.0673 .41937 L
s
[(0.1)] .0469 .42724 1 -0.38568 Mshowa
.03097 .60829 m
.03785 .60589 L
s
[(0.2)] .01721 .61309 1 -0.3485 Mshowa
.125 Mabswid
.0817 .28822 m
.08574 .28655 L
s
.07658 .32051 m
.08063 .31886 L
s
.07134 .35355 m
.0754 .35193 L
s
.06598 .38737 m
.07005 .38577 L
s
.05488 .45746 m
.05897 .45591 L
s
.04912 .49378 m
.05322 .49226 L
s
.04322 .53101 m
.04733 .52951 L
s
.03717 .56917 m
.04129 .5677 L
s
.02461 .64842 m
.02875 .64701 L
s
.01809 .6896 m
.02224 .68822 L
s
.01139 .73186 m
.01555 .73051 L
s
.00452 .77524 m
.00869 .77393 L
s
gsave
-0.03373 .52941 -106.25 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
75.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.250 13.000 moveto
(H) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
(\\310) show
104.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4186 .578 m
.42216 .58164 L
s
.41502 .57434 m
.4186 .578 L
s
.41143 .57067 m
.41502 .57434 L
s
.40782 .56698 m
.41143 .57067 L
s
.40419 .56327 m
.40782 .56698 L
s
.40055 .55955 m
.40419 .56327 L
s
.39689 .55581 m
.40055 .55955 L
s
.39322 .55206 m
.39689 .55581 L
s
.38953 .54829 m
.39322 .55206 L
s
.49063 .58498 m
.49428 .57325 L
s
.38583 .5445 m
.38953 .54829 L
s
.3821 .54069 m
.38583 .5445 L
s
.37836 .53687 m
.3821 .54069 L
s
.49981 .59432 m
.50342 .58113 L
s
.48648 .63203 m
.49063 .58498 L
s
.37461 .53303 m
.37836 .53687 L
s
.37084 .52917 m
.37461 .53303 L
s
.51839 .65405 m
.52202 .58017 L
s
.50899 .62234 m
.51265 .59042 L
s
.36705 .5253 m
.37084 .52917 L
s
.49595 .62742 m
.49981 .59432 L
s
.36324 .52141 m
.36705 .5253 L
s
.35941 .5175 m
.36324 .52141 L
s
.35557 .51357 m
.35941 .5175 L
s
.35171 .50962 m
.35557 .51357 L
s
.34784 .50566 m
.35171 .50962 L
s
.58494 .55129 m
.59004 .64304 L
s
.58314 .63365 m
.58494 .55129 L
s
.50521 .65711 m
.50899 .62234 L
s
.34394 .50168 m
.34784 .50566 L
s
.54712 .60891 m
.55047 .60111 L
s
.48216 .68228 m
.48648 .63203 L
s
.55672 .60375 m
.56 .59442 L
s
.49194 .66516 m
.49595 .62742 L
s
.34003 .49768 m
.34394 .50168 L
s
.64246 .51401 m
.64644 .53742 L
s
.64055 .54553 m
.64246 .51401 L
s
.3361 .49366 m
.34003 .49768 L
s
.47389 .53374 m
.47658 .59536 L
s
.46998 .54544 m
.47389 .53374 L
s
.5439 .64832 m
.54712 .60891 L
s
.33215 .48963 m
.3361 .49366 L
s
.55359 .63611 m
.55672 .60375 L
s
.5357 .53821 m
.53922 .5549 L
s
.53231 .58621 m
.5357 .53821 L
s
.60484 .56987 m
.60809 .57098 L
s
.44159 .71848 m
.44528 .72261 L
s
.43189 .73081 m
.43565 .73295 L
s
.64918 .51081 m
.65279 .52424 L
s
.64611 .51104 m
.64918 .51081 L
s
.53922 .5549 m
.54293 .60368 L
s
.32819 .48557 m
.33215 .48963 L
s
.66262 .52072 m
.66584 .52518 L
s
.61458 .56613 m
.61788 .56949 L
s
.60383 .52568 m
.60783 .55481 L
s
.60071 .53061 m
.60383 .52568 L
s
.4796 .71049 m
.48353 .69307 L
s
.65279 .52424 m
.65629 .53505 L
s
.43794 .71273 m
.44159 .71848 L
s
.60188 .58184 m
.60484 .56987 L
s
.67234 .51401 m
.67559 .51949 L
s
.48324 .53991 m
.48602 .60762 L
s
.47922 .5616 m
.48324 .53991 L
s
.42812 .72801 m
.43189 .73081 L
s
.3242 .4815 m
.32819 .48557 L
s
.6595 .51863 m
.66262 .52072 L
s
.59531 .58241 m
.59904 .60215 L
s
.5918 .57177 m
.59531 .58241 L
s
.43429 .70606 m
.43794 .71273 L
s
.58891 .592 m
.5918 .57177 L
s
.46395 .56137 m
.46657 .61963 L
s
.46015 .56319 m
.46395 .56137 L
s
.68216 .50909 m
.68543 .51512 L
s
.51452 .7385 m
.51839 .65405 L
s
.56664 .62217 m
.57001 .6212 L
s
.61148 .57027 m
.61458 .56613 L
s
.70123 .48786 m
.70472 .49834 L
s
.66911 .50914 m
.67234 .51401 L
s
.6987 .49435 m
.70123 .48786 L
s
.69193 .50263 m
.69517 .50845 L
s
.64414 .5404 m
.64611 .51104 L
s
.43064 .69931 m
.43429 .70606 L
s
.46515 .60075 m
.46998 .54544 L
s
.6792 .50917 m
.68216 .50909 L
s
.5013 .69627 m
.50521 .65711 L
s
.42435 .72485 m
.42812 .72801 L
s
.3202 .4774 m
.3242 .4815 L
s
.71148 .4893 m
.71463 .49416 L
s
.66577 .50215 m
.66911 .50914 L
s
.68928 .50796 m
.69193 .50263 L
s
.42696 .69321 m
.43064 .69931 L
s
.65633 .5161 m
.6595 .51863 L
s
.59815 .56123 m
.60071 .53061 L
s
.62458 .56913 m
.62803 .57747 L
s
.72141 .48466 m
.72453 .48932 L
s
.60783 .55481 m
.61148 .57027 L
s
.66288 .50538 m
.66577 .50215 L
s
.70824 .48315 m
.71148 .4893 L
s
.56369 .66116 m
.56664 .62217 L
s
.62158 .5755 m
.62458 .56913 L
s
.42323 .68832 m
.42696 .69321 L
s
.45477 .63365 m
.46015 .56319 L
s
.31617 .47329 m
.3202 .4774 L
s
.49266 .54796 m
.49493 .68846 L
s
.48849 .58932 m
.49266 .54796 L
s
.42056 .72164 m
.42435 .72485 L
s
.73128 .4787 m
.73445 .48444 L
s
.6343 .56213 m
.63786 .57386 L
s
.63183 .58247 m
.6343 .56213 L
s
.48786 .69932 m
.49194 .66516 L
s
.71842 .48216 m
.72141 .48466 L
s
.67636 .51219 m
.6792 .50917 L
s
.65306 .51142 m
.65633 .5161 L
s
.70503 .47761 m
.70824 .48315 L
s
.63861 .57851 m
.64055 .54553 L
s
.41943 .68495 m
.42323 .68832 L
s
.59875 .5885 m
.60188 .58184 L
s
.59646 .48736 m
.60068 .52616 L
s
.59344 .4999 m
.59646 .48736 L
s
.74133 .47507 m
.74449 .48072 L
s
.72846 .47831 m
.73128 .4787 L
s
.6964 .50528 m
.6987 .49435 L
s
.31213 .46916 m
.31617 .47329 L
s
.41674 .71866 m
.42056 .72164 L
s
.47479 .78074 m
.4796 .71049 L
s
.70275 .48807 m
.70503 .47761 L
s
.6495 .50017 m
.65306 .51142 L
s
.64664 .50615 m
.6495 .50017 L
s
.47769 .73258 m
.48216 .68228 L
s
.75146 .47187 m
.75452 .4765 L
s
.68675 .51621 m
.68928 .50796 L
s
.54906 .57933 m
.55282 .61511 L
s
.5456 .58207 m
.54906 .57933 L
s
.61433 .54836 m
.61798 .56293 L
s
.61132 .55656 m
.61433 .54836 L
s
.73875 .4776 m
.74133 .47507 L
s
.71557 .48211 m
.71842 .48216 L
s
.41556 .68308 m
.41943 .68495 L
s
.66019 .51383 m
.66288 .50538 L
s
.30807 .46501 m
.31213 .46916 L
s
.55023 .65043 m
.55359 .63611 L
s
.61798 .56293 m
.62158 .5755 L
s
.41289 .71609 m
.41674 .71866 L
s
.54293 .60368 m
.54664 .63854 L
s
.47463 .61348 m
.47922 .5616 L
s
.76147 .46672 m
.76467 .47333 L
s
.72565 .47846 m
.72846 .47831 L
s
.58671 .65212 m
.58891 .592 L
s
.7488 .47286 m
.75146 .47187 L
s
.67358 .51705 m
.67636 .51219 L
s
.54057 .68854 m
.5439 .64832 L
s
.47658 .59536 m
.47943 .65399 L
s
.77174 .46447 m
.77466 .46782 L
s
.53777 .67641 m
.54131 .68201 L
s
.59159 .56432 m
.59531 .58277 L
s
.58809 .55628 m
.59159 .56432 L
s
.304 .46084 m
.30807 .46501 L
s
.75865 .46507 m
.76147 .46672 L
s
.41163 .68224 m
.41556 .68308 L
s
.59531 .58277 m
.59875 .5885 L
s
.409 .71405 m
.41289 .71609 L
s
.71246 .47839 m
.71557 .48211 L
s
.58533 .58727 m
.58809 .55628 L
s
.54221 .60525 m
.5456 .58207 L
s
.54108 .52867 m
.5449 .58355 L
s
.53759 .53761 m
.54108 .52867 L
s
.73613 .47997 m
.73875 .4776 L
s
.53432 .71217 m
.53777 .67641 L
s
.78186 .45985 m
.78488 .46457 L
s
.57675 .64162 m
.58072 .67671 L
s
.57436 .70948 m
.57675 .64162 L
s
.64439 .52912 m
.64664 .50615 L
s
.76878 .46076 m
.77174 .46447 L
s
.2999 .45665 m
.304 .46084 L
s
.72269 .47655 m
.72565 .47846 L
s
.69404 .51605 m
.6964 .50528 L
s
.43573 .71603 m
.43923 .72968 L
s
.43213 .7059 m
.43573 .71603 L
s
.74628 .47593 m
.7488 .47286 L
s
.59036 .51185 m
.59344 .4999 L
s
.64216 .57175 m
.64414 .5404 L
s
.4284 .69998 m
.43213 .7059 L
s
.68401 .52107 m
.68675 .51621 L
s
.60828 .56542 m
.61132 .55656 L
s
.70898 .46861 m
.71246 .47839 L
s
.75605 .46663 m
.75865 .46507 L
s
.40767 .68156 m
.41163 .68224 L
s
.52878 .63195 m
.53231 .58621 L
s
.70056 .5008 m
.70275 .48807 L
s
.40506 .71252 m
.409 .71405 L
s
.66276 .48151 m
.66653 .497 L
s
.65988 .48596 m
.66276 .48151 L
s
.43923 .72968 m
.44269 .74551 L
s
.79214 .45662 m
.79515 .46154 L
s
.62876 .58633 m
.63183 .58247 L
s
.70629 .47213 m
.70898 .46861 L
s
.77909 .45813 m
.78186 .45985 L
s
.65731 .51875 m
.66019 .51383 L
s
.46657 .61963 m
.46943 .67107 L
s
.67033 .51275 m
.67358 .51705 L
s
.60068 .52616 m
.60472 .55557 L
s
.55089 .52934 m
.55511 .60996 L
s
.54746 .53803 m
.55089 .52934 L
s
.42454 .69797 m
.4284 .69998 L
s
.29578 .45244 m
.2999 .45665 L
s
.55282 .61511 m
.55667 .65583 L
s
.7656 .4545 m
.76878 .46076 L
s
.66653 .497 m
.67033 .51275 L
s
.44269 .74551 m
.44614 .76163 L
s
.80243 .4532 m
.80538 .45762 L
s
.59529 .58242 m
.59815 .56123 L
s
.71984 .47666 m
.72269 .47655 L
s
.58177 .75246 m
.58314 .63365 L
s
.78943 .45529 m
.79214 .45662 L
s
.54664 .63854 m
.55023 .65043 L
s
.48602 .60762 m
.48872 .69428 L
s
.73308 .47644 m
.73613 .47997 L
s
.60703 .51214 m
.61066 .5249 L
s
.60378 .51394 m
.60703 .51214 L
s
.49729 .73244 m
.5013 .69627 L
s
.44614 .76163 m
.44966 .77551 L
s
.40109 .71137 m
.40506 .71252 L
s
.76303 .45597 m
.7656 .4545 L
s
.52324 .48877 m
.52683 .55262 L
s
.51957 .5143 m
.52324 .48877 L
s
.40372 .67994 m
.40767 .68156 L
s
.44966 .77551 m
.45329 .78467 L
s
.61066 .5249 m
.61485 .55719 L
s
.77626 .45589 m
.77909 .45813 L
s
.81275 .4496 m
.81567 .4539 L
s
.29165 .44822 m
.29578 .45244 L
s
.64631 .47947 m
.65001 .49341 L
s
.64313 .4787 m
.64631 .47947 L
s
.42056 .69849 m
.42454 .69797 L
s
.75353 .46939 m
.75605 .46663 L
s
.79978 .45211 m
.80243 .4532 L
s
.74337 .47409 m
.74628 .47593 L
s
.53413 .57696 m
.53759 .53761 L
s
.48381 .72336 m
.48786 .69932 L
s
.65001 .49341 m
.6539 .51194 L
s
.68065 .51432 m
.68401 .52107 L
s
.62523 .57709 m
.62876 .58633 L
s
.72969 .46824 m
.73308 .47644 L
s
.70387 .48063 m
.70629 .47213 L
s
.65691 .48907 m
.65988 .48596 L
s
.56037 .67509 m
.56369 .66116 L
s
.45358 .51591 m
.4558 .58752 L
s
.44997 .50571 m
.45358 .51591 L
s
.63598 .59452 m
.63861 .57851 L
s
.78657 .45242 m
.78943 .45529 L
s
.67693 .50055 m
.68065 .51432 L
s
.67367 .49611 m
.67693 .50055 L
s
.82311 .446 m
.82608 .45099 L
s
.62205 .57904 m
.62523 .57709 L
s
.6539 .51194 m
.65731 .51875 L
s
.4443 .57269 m
.44997 .50571 L
s
.56705 .51456 m
.57088 .54238 L
s
.56468 .60301 m
.56705 .51456 L
s
.71681 .47425 m
.71984 .47666 L
s
.81 .44715 m
.81275 .4496 L
s
.28749 .44397 m
.29165 .44822 L
s
.72641 .46162 m
.72969 .46824 L
s
.39709 .71028 m
.40109 .71137 L
s
.39982 .67656 m
.40372 .67994 L
s
.53138 .5631 m
.53504 .59836 L
s
.52779 .56371 m
.53138 .5631 L
s
.60472 .55557 m
.60828 .56542 L
s
.52445 .70037 m
.52807 .75832 L
s
.52055 .86616 m
.52445 .70037 L
s
.69117 .51804 m
.69404 .51605 L
s
.60996 .49157 m
.61394 .51644 L
s
.60666 .49156 m
.60996 .49157 L
s
.77323 .45147 m
.77626 .45589 L
s
.63944 .46514 m
.64313 .4787 L
s
.63622 .4641 m
.63944 .46514 L
s
.48371 .6665 m
.48849 .58932 L
s
.60018 .50252 m
.60378 .51394 L
s
.59679 .50012 m
.60018 .50252 L
s
.58687 .50602 m
.59036 .51185 L
s
.66277 .46011 m
.66678 .48028 L
s
.65936 .45309 m
.66277 .46011 L
s
.83355 .44277 m
.83639 .44673 L
s
.76055 .45904 m
.76303 .45597 L
s
.74024 .46943 m
.74337 .47409 L
s
.58415 .53308 m
.58805 .55968 L
s
.58059 .52429 m
.58415 .53308 L
s
.79701 .44999 m
.79978 .45211 L
s
.54414 .57621 m
.54746 .53803 L
s
.72352 .46107 m
.72641 .46162 L
s
.41655 .69923 m
.42056 .69849 L
s
.82024 .44203 m
.82311 .446 L
s
.67049 .49367 m
.67367 .49611 L
s
.69793 .50665 m
.70056 .5008 L
s
.61994 .4879 m
.62428 .52209 L
s
.61657 .48436 m
.61994 .4879 L
s
.4603 .64966 m
.46515 .60075 L
s
.5774 .53755 m
.58059 .52429 L
s
.28331 .4397 m
.28749 .44397 L
s
.78366 .44917 m
.78657 .45242 L
s
.65613 .45039 m
.65936 .45309 L
s
.39596 .67152 m
.39982 .67656 L
s
.75074 .46894 m
.75353 .46939 L
s
.76993 .44392 m
.77323 .45147 L
s
.71327 .46413 m
.71681 .47425 L
s
.5834 .50189 m
.58687 .50602 L
s
.80732 .44567 m
.81 .44715 L
s
.53869 .61509 m
.54221 .60525 L
s
.84397 .43903 m
.84684 .44345 L
s
.70969 .4532 m
.71327 .46413 L
s
.39308 .7088 m
.39709 .71028 L
s
.7068 .45373 m
.70969 .4532 L
s
.67293 .45797 m
.67679 .47413 L
s
.66965 .45344 m
.67293 .45797 L
s
.73723 .46658 m
.74024 .46943 L
s
.8307 .43891 m
.83355 .44277 L
s
.64175 .54341 m
.64439 .52912 L
s
.62996 .48412 m
.63441 .51903 L
s
.62651 .47737 m
.62996 .48412 L
s
.59386 .51947 m
.59679 .50012 L
s
.61876 .57848 m
.62205 .57904 L
s
.63386 .48759 m
.63622 .4641 L
s
.65342 .48056 m
.65691 .48907 L
s
.52414 .61583 m
.52779 .56371 L
s
.76725 .44406 m
.76993 .44392 L
s
.60353 .4991 m
.60666 .49156 L
s
.66678 .48028 m
.67049 .49367 L
s
.61485 .55719 m
.61876 .57848 L
s
.81752 .43985 m
.82024 .44203 L
s
.64975 .46782 m
.65342 .48056 L
s
.64638 .46243 m
.64975 .46782 L
s
.39212 .66582 m
.39596 .67152 L
s
.56099 .54955 m
.56583 .65966 L
s
.55741 .54054 m
.56099 .54955 L
s
.79405 .4459 m
.79701 .44999 L
s
.55667 .65583 m
.56037 .67509 L
s
.68777 .51073 m
.69117 .51804 L
s
.27912 .43541 m
.28331 .4397 L
s
.61346 .49023 m
.61657 .48436 L
s
.47943 .65399 m
.48252 .70351 L
s
.59589 .46003 m
.59974 .48128 L
s
.59312 .48652 m
.59589 .46003 L
s
.61394 .51644 m
.61763 .5303 L
s
.67679 .47413 m
.68083 .4938 L
s
.78083 .447 m
.78366 .44917 L
s
.85448 .43574 m
.85733 .44011 L
s
.58272 .63193 m
.58533 .58727 L
s
.57088 .54238 m
.57564 .62666 L
s
.58024 .51611 m
.5834 .50189 L
s
.72055 .45959 m
.72352 .46107 L
s
.55442 .59844 m
.55741 .54054 L
s
.62378 .49332 m
.62651 .47737 L
s
.65267 .4427 m
.65613 .45039 L
s
.4126 .69766 m
.41655 .69923 L
s
.84121 .43572 m
.84397 .43903 L
s
.46301 .52547 m
.46532 .60343 L
s
.45933 .51729 m
.46301 .52547 L
s
.61763 .5303 m
.62148 .54926 L
s
.66645 .45097 m
.66965 .45344 L
s
.53708 .71462 m
.54057 .68854 L
s
.70106 .48326 m
.70387 .48063 L
s
.55936 .62779 m
.56342 .67762 L
s
.55581 .62324 m
.55936 .62779 L
s
.68439 .5039 m
.68777 .51073 L
s
.47315 .77895 m
.47769 .73258 L
s
.5449 .58355 m
.54873 .62492 L
s
.75783 .45923 m
.76055 .45904 L
s
.80455 .44329 m
.80732 .44567 L
s
.82774 .43404 m
.8307 .43891 L
s
.38824 .66063 m
.39212 .66582 L
s
.38908 .70661 m
.39308 .7088 L
s
.73396 .46018 m
.73723 .46658 L
s
.74769 .4653 m
.75074 .46894 L
s
.58805 .55968 m
.59191 .58225 L
s
.64346 .46891 m
.64638 .46243 L
s
.59191 .58225 m
.59529 .58242 L
s
.45423 .56953 m
.45933 .51729 L
s
.64955 .44339 m
.65267 .4427 L
s
.53083 .7938 m
.53432 .71217 L
s
.86499 .43204 m
.86779 .43623 L
s
.79099 .44079 m
.79405 .4459 L
s
.2749 .4311 m
.27912 .43541 L
s
.49813 .6006 m
.50126 .67428 L
s
.49307 .73031 m
.49813 .6006 L
s
.46943 .67107 m
.47262 .70781 L
s
.8149 .43879 m
.81752 .43985 L
s
.70358 .44913 m
.7068 .45373 L
s
.63976 .59394 m
.64216 .57175 L
s
.85174 .43236 m
.85448 .43574 L
s
.68083 .4938 m
.68439 .5039 L
s
.43948 .53845 m
.44292 .55622 L
s
.43289 .62696 m
.43948 .53845 L
s
.67982 .45003 m
.68348 .46203 L
s
.6766 .44669 m
.67982 .45003 L
s
.6948 .50424 m
.69793 .50665 L
s
.41884 .84723 m
.42284 .84686 L
s
.68348 .46203 m
.68737 .47832 L
s
.76467 .44568 m
.76725 .44406 L
s
.53504 .59836 m
.53869 .61509 L
s
.55238 .63536 m
.55581 .62324 L
s
.73036 .44929 m
.73396 .46018 L
s
.72692 .44063 m
.73036 .44929 L
s
.77773 .44185 m
.78083 .447 L
s
.59974 .48128 m
.60353 .4991 L
s
.63302 .60279 m
.63598 .59452 L
s
.62148 .54926 m
.62579 .58183 L
s
.83842 .43226 m
.84121 .43572 L
s
.38428 .65677 m
.38824 .66063 L
s
.82495 .43096 m
.82774 .43404 L
s
.40876 .69212 m
.4126 .69766 L
s
.71714 .45163 m
.72055 .45959 L
s
.66357 .45562 m
.66645 .45097 L
s
.87555 .42843 m
.87836 .43287 L
s
.68992 .44471 m
.6938 .46062 L
s
.68662 .43947 m
.68992 .44471 L
s
.74431 .45737 m
.74769 .4653 L
s
.72377 .43635 m
.72692 .44063 L
s
.47005 .65607 m
.47463 .61348 L
s
.78802 .4369 m
.79099 .44079 L
s
.38508 .70385 m
.38908 .70661 L
s
.80168 .44011 m
.80455 .44329 L
s
.51052 .80636 m
.51452 .7385 L
s
.86227 .42866 m
.86499 .43204 L
s
.51569 .57854 m
.51957 .5143 L
s
.27067 .42677 m
.2749 .4311 L
s
.47988 .73363 m
.48381 .72336 L
s
.68737 .47832 m
.69128 .49495 L
s
.7 .43856 m
.70358 .44913 L
s
.44292 .55622 m
.44507 .62482 L
s
.71353 .44061 m
.71714 .45163 L
s
.62428 .52209 m
.62842 .54866 L
s
.44899 .71235 m
.45477 .63365 L
s
.52611 .65626 m
.52977 .68973 L
s
.52247 .65731 m
.52611 .65626 L
s
.7101 .43243 m
.71353 .44061 L
s
.69679 .43454 m
.7 .43856 L
s
.53312 .51832 m
.53679 .54169 L
s
.52952 .53978 m
.53312 .51832 L
s
.75479 .4556 m
.75783 .45923 L
s
.74091 .44922 m
.74431 .45737 L
s
.84894 .42864 m
.85174 .43236 L
s
.77433 .43325 m
.77773 .44185 L
s
.57457 .5777 m
.5774 .53755 L
s
.40505 .68301 m
.40876 .69212 L
s
.67343 .44461 m
.6766 .44669 L
s
.69766 .47596 m
.70106 .48326 L
s
.60996 .4835 m
.61346 .49023 L
s
.6938 .46062 m
.69766 .47596 L
s
.38023 .65446 m
.38428 .65677 L
s
.69128 .49495 m
.6948 .50424 L
s
.64678 .45323 m
.64955 .44339 L
s
.88616 .42494 m
.88896 .42946 L
s
.81212 .43626 m
.8149 .43879 L
s
.70693 .42863 m
.7101 .43243 L
s
.83553 .42803 m
.83842 .43226 L
s
.68367 .44081 m
.68662 .43947 L
s
.40138 .67253 m
.40505 .68301 L
s
.46927 .88161 m
.47479 .78074 L
s
.87279 .42454 m
.87555 .42843 L
s
.77132 .42932 m
.77433 .43325 L
s
.73768 .44347 m
.74091 .44922 L
s
.82234 .42977 m
.82495 .43096 L
s
.41482 .84767 m
.41884 .84723 L
s
.39766 .66324 m
.40138 .67253 L
s
.72049 .43048 m
.72377 .43635 L
s
.49332 .75458 m
.49729 .73244 L
s
.78518 .43465 m
.78802 .4369 L
s
.63441 .51903 m
.6384 .54004 L
s
.38106 .70105 m
.38508 .70385 L
s
.26641 .42242 m
.27067 .42677 L
s
.39382 .65688 m
.39766 .66324 L
s
.60684 .49154 m
.60996 .4835 L
s
.79862 .43506 m
.80168 .44011 L
s
.85954 .4253 m
.86227 .42866 L
s
.58437 .71245 m
.58671 .65212 L
s
.52513 .65936 m
.52878 .63195 L
s
.6384 .54004 m
.64175 .54341 L
s
.76174 .44317 m
.76467 .44568 L
s
.5792 .46875 m
.58298 .48803 L
s
.5758 .47203 m
.5792 .46875 L
s
.69414 .44059 m
.69679 .43454 L
s
.64083 .48395 m
.64346 .46891 L
s
.89682 .42145 m
.89958 .4258 L
s
.75154 .44936 m
.75479 .4556 L
s
.84615 .42503 m
.84894 .42864 L
s
.88338 .42062 m
.88616 .42494 L
s
.7342 .43444 m
.73768 .44347 L
s
.83243 .42187 m
.83553 .42803 L
s
.71725 .42519 m
.72049 .43048 L
s
.67001 .43783 m
.67343 .44461 L
s
.37611 .65319 m
.38023 .65446 L
s
.70431 .43418 m
.70693 .42863 L
s
.38982 .65377 m
.39382 .65688 L
s
.87012 .4214 m
.87279 .42454 L
s
.5187 .70164 m
.52247 .65731 L
s
.5772 .54094 m
.58024 .51611 L
s
.52852 .47522 m
.53217 .48805 L
s
.52485 .51937 m
.52852 .47522 L
s
.76848 .42779 m
.77132 .42932 L
s
.80913 .43171 m
.81212 .43626 L
s
.53679 .54169 m
.54053 .57526 L
s
.73074 .42563 m
.7342 .43444 L
s
.53848 .46677 m
.54216 .48457 L
s
.53497 .50166 m
.53848 .46677 L
s
.59063 .52757 m
.59386 .51947 L
s
.66044 .45576 m
.66357 .45562 L
s
.79541 .42844 m
.79862 .43506 L
s
.53217 .48805 m
.53594 .54049 L
s
.26214 .41805 m
.26641 .42242 L
s
.7481 .44071 m
.75154 .44936 L
s
.52683 .55262 m
.53051 .58515 L
s
.62069 .49966 m
.62378 .49332 L
s
.90751 .41789 m
.91025 .42226 L
s
.37699 .69879 m
.38106 .70105 L
s
.62975 .60269 m
.63302 .60279 L
s
.52807 .75832 m
.53196 .92289 L
s
.81962 .42764 m
.82234 .42977 L
s
.62842 .54866 m
.63256 .57444 L
s
.85673 .42138 m
.85954 .4253 L
s
.41075 .84835 m
.41482 .84767 L
s
.78205 .42913 m
.78518 .43465 L
s
.72752 .42055 m
.73074 .42563 L
s
.59561 .44643 m
.59982 .48084 L
s
.59226 .44848 m
.59561 .44643 L
s
.53051 .58515 m
.53413 .57696 L
s
.89408 .4173 m
.89682 .42145 L
s
.58298 .48803 m
.58693 .51444 L
s
.66698 .43935 m
.67001 .43783 L
s
.74442 .42881 m
.7481 .44071 L
s
.74101 .42073 m
.74442 .42881 L
s
.82973 .41964 m
.83243 .42187 L
s
.62579 .58183 m
.62975 .60269 L
s
.47262 .70781 m
.47612 .72863 L
s
.68089 .4461 m
.68367 .44081 L
s
.75844 .43627 m
.76174 .44317 L
s
.71423 .4237 m
.71725 .42519 L
s
.84332 .4213 m
.84615 .42503 L
s
.54873 .62492 m
.55238 .63536 L
s
.88066 .41688 m
.88338 .42062 L
s
.46869 .53565 m
.47221 .55465 L
s
.46366 .59313 m
.46869 .53565 L
s
.63118 .50416 m
.63386 .48759 L
s
.79228 .42279 m
.79541 .42844 L
s
.54216 .48457 m
.54618 .55277 L
s
.80612 .427 m
.80913 .43171 L
s
.38571 .65271 m
.38982 .65377 L
s
.47612 .72863 m
.47988 .73363 L
s
.738 .4182 m
.74101 .42073 L
s
.54849 .46477 m
.55231 .49542 L
s
.54515 .50345 m
.54849 .46477 L
s
.86741 .41814 m
.87012 .4214 L
s
.25784 .41366 m
.26214 .41805 L
s
.37197 .65183 m
.37611 .65319 L
s
.52977 .68973 m
.53345 .71557 L
s
.48252 .70351 m
.48588 .73908 L
s
.77865 .42071 m
.78205 .42913 L
s
.75493 .4267 m
.75844 .43627 L
s
.90481 .41385 m
.90751 .41789 L
s
.72437 .41654 m
.72752 .42055 L
s
.4367 .48038 m
.43981 .51097 L
s
.43096 .53598 m
.4367 .48038 L
s
.76529 .42211 m
.76848 .42779 L
s
.57143 .75071 m
.57436 .70948 L
s
.57246 .48092 m
.5758 .47203 L
s
.85383 .41674 m
.85673 .42138 L
s
.37285 .69742 m
.37699 .69879 L
s
.53345 .71557 m
.53708 .71462 L
s
.8913 .41291 m
.89408 .4173 L
s
.75151 .41838 m
.75493 .4267 L
s
.55511 .60996 m
.55932 .67534 L
s
.59007 .50385 m
.59312 .48652 L
s
.54053 .57526 m
.54414 .57621 L
s
.78929 .41881 m
.79228 .42279 L
s
.77539 .41403 m
.77865 .42071 L
s
.8167 .42374 m
.81962 .42764 L
s
.64395 .4628 m
.64678 .45323 L
s
.56342 .67762 m
.56765 .73387 L
s
.65695 .44806 m
.66044 .45576 L
s
.84034 .41613 m
.84332 .4213 L
s
.47221 .55465 m
.47414 .67186 L
s
.87799 .41375 m
.88066 .41688 L
s
.4266 .49305 m
.42888 .54791 L
s
.41926 .58832 m
.4266 .49305 L
s
.82702 .41746 m
.82973 .41964 L
s
.69143 .44612 m
.69414 .44059 L
s
.63655 .59506 m
.63976 .59394 L
s
.40665 .84944 m
.41075 .84835 L
s
.80303 .42167 m
.80612 .427 L
s
.60363 .49766 m
.60684 .49154 L
s
.65319 .43436 m
.65695 .44806 L
s
.64953 .42305 m
.65319 .43436 L
s
.64637 .42387 m
.64953 .42305 L
s
.7484 .41415 m
.75151 .41838 L
s
.71144 .42618 m
.71423 .4237 L
s
.25352 .40924 m
.25784 .41366 L
s
.76191 .41409 m
.76529 .42211 L
s
.4558 .58752 m
.4585 .64389 L
s
.70163 .43948 m
.70431 .43418 L
s
.73512 .41771 m
.738 .4182 L
s
.8646 .41409 m
.86741 .41814 L
s
.58905 .45862 m
.59226 .44848 L
s
.60593 .45081 m
.60972 .46663 L
s
.60252 .44903 m
.60593 .45081 L
s
.63256 .57444 m
.63655 .59506 L
s
.66398 .44224 m
.66698 .43935 L
s
.38159 .65133 m
.38571 .65271 L
s
.7723 .40943 m
.77539 .41403 L
s
.9021 .40988 m
.90481 .41385 L
s
.72107 .41059 m
.72437 .41654 L
s
.85104 .41312 m
.85383 .41674 L
s
.36786 .64927 m
.37197 .65183 L
s
.8885 .40848 m
.8913 .41291 L
s
.58693 .51444 m
.59063 .52757 L
s
.83719 .4096 m
.84034 .41613 L
s
.75876 .40922 m
.76191 .41409 L
s
.78613 .41301 m
.78929 .41881 L
s
.48872 .69428 m
.49159 .78196 L
s
.43593 .77253 m
.43956 .78554 L
s
.43178 .77822 m
.43593 .77253 L
s
.51852 .50432 m
.52217 .52753 L
s
.51461 .55509 m
.51852 .50432 L
s
.61751 .50454 m
.62069 .49966 L
s
.81358 .41784 m
.8167 .42374 L
s
.79977 .41453 m
.80303 .42167 L
s
.36864 .69692 m
.37285 .69742 L
s
.52585 .55216 m
.52952 .53978 L
s
.43956 .78554 m
.44254 .82441 L
s
.60972 .46663 m
.61387 .49471 L
s
.67779 .44574 m
.68089 .4461 L
s
.87526 .41016 m
.87799 .41375 L
s
.74539 .4116 m
.7484 .41415 L
s
.63807 .49703 m
.64083 .48395 L
s
.71814 .41044 m
.72107 .41059 L
s
.45564 .68286 m
.4603 .64966 L
s
.82412 .41363 m
.82702 .41746 L
s
.24919 .40481 m
.25352 .40924 L
s
.59877 .43448 m
.60252 .44903 L
s
.59569 .44857 m
.59877 .43448 L
s
.76929 .40581 m
.7723 .40943 L
s
.86168 .40918 m
.8646 .41409 L
s
.83443 .40679 m
.83719 .4096 L
s
.48949 .75692 m
.49332 .75458 L
s
.79649 .40737 m
.79977 .41453 L
s
.89933 .40548 m
.9021 .40988 L
s
.40249 .8511 m
.40665 .84944 L
s
.78288 .40646 m
.78613 .41301 L
s
.84816 .40893 m
.85104 .41312 L
s
.88587 .40548 m
.8885 .40848 L
s
.81038 .41125 m
.81358 .41784 L
s
.75599 .40926 m
.75876 .40922 L
s
.61255 .43943 m
.61654 .4614 L
s
.60891 .42922 m
.61255 .43943 L
s
.59982 .48084 m
.60363 .49766 L
s
.37755 .64745 m
.38159 .65133 L
s
.36379 .64542 m
.36786 .64927 L
s
.64299 .41986 m
.64637 .42387 L
s
.55231 .49542 m
.55665 .57438 L
s
.60588 .44187 m
.60891 .42922 L
s
.73209 .41552 m
.73512 .41771 L
s
.57962 .65482 m
.58272 .63193 L
s
.62266 .4323 m
.62697 .46266 L
s
.61904 .42252 m
.62266 .4323 L
s
.43981 .51097 m
.44209 .57394 L
s
.67024 .41899 m
.67412 .43462 L
s
.66689 .41443 m
.67024 .41899 L
s
.7934 .40226 m
.79649 .40737 L
s
.70866 .42914 m
.71144 .42618 L
s
.51751 .47032 m
.52112 .51965 L
s
.51381 .46391 m
.51751 .47032 L
s
.87246 .40606 m
.87526 .41016 L
s
.5587 .47731 m
.56251 .49968 L
s
.55546 .51122 m
.5587 .47731 L
s
.46862 .8166 m
.47315 .77895 L
s
.61587 .42798 m
.61904 .42252 L
s
.24483 .40035 m
.24919 .40481 L
s
.77978 .40163 m
.78288 .40646 L
s
.36439 .69689 m
.36864 .69692 L
s
.80723 .40526 m
.81038 .41125 L
s
.82106 .40822 m
.82412 .41363 L
s
.68812 .4414 m
.69143 .44612 L
s
.74235 .40865 m
.74539 .4116 L
s
.56917 .49738 m
.57246 .48092 L
s
.85872 .40401 m
.86168 .40918 L
s
.48588 .73908 m
.48949 .75692 L
s
.52217 .52753 m
.52585 .55216 L
s
.66067 .43895 m
.66398 .44224 L
s
.89644 .40019 m
.89933 .40548 L
s
.76654 .40568 m
.76929 .40581 L
s
.52142 .6627 m
.52513 .65936 L
s
.52035 .66291 m
.52414 .61583 L
s
.67412 .43462 m
.67779 .44574 L
s
.84509 .40304 m
.84816 .40893 L
s
.83155 .40295 m
.83443 .40679 L
s
.69858 .43872 m
.70163 .43948 L
s
.49493 .68846 m
.49708 .87833 L
s
.62811 .51086 m
.63118 .50416 L
s
.63289 .42821 m
.63704 .4521 L
s
.62927 .41836 m
.63289 .42821 L
s
.64075 .46389 m
.64395 .4628 L
s
.37363 .64088 m
.37755 .64745 L
s
.35972 .64126 m
.36379 .64542 L
s
.88316 .40196 m
.88587 .40548 L
s
.7153 .41203 m
.71814 .41044 L
s
.63971 .41867 m
.64299 .41986 L
s
.50971 .52794 m
.51381 .46391 L
s
.43886 .62425 m
.4443 .57269 L
s
.62628 .42731 m
.62927 .41836 L
s
.5433 .55682 m
.54704 .57709 L
s
.53966 .55786 m
.5433 .55682 L
s
.42735 .79127 m
.43178 .77822 L
s
.79037 .398 m
.7934 .40226 L
s
.57412 .5685 m
.5772 .54094 L
s
.52658 .42357 m
.5303 .46257 L
s
.52284 .45861 m
.52658 .42357 L
s
.41748 .44914 m
.41993 .49573 L
s
.40914 .56001 m
.41748 .44914 L
s
.6637 .41352 m
.66689 .41443 L
s
.61387 .49471 m
.61751 .50454 L
s
.80405 .39915 m
.80723 .40526 L
s
.39828 .85345 m
.40249 .8511 L
s
.61654 .4614 m
.62039 .47806 L
s
.81784 .40146 m
.82106 .40822 L
s
.86958 .40143 m
.87246 .40606 L
s
.72884 .41036 m
.73209 .41552 L
s
.77694 .39993 m
.77978 .40163 L
s
.85587 .39992 m
.85872 .40401 L
s
.24045 .39588 m
.24483 .40035 L
s
.4657 .67919 m
.47005 .65607 L
s
.68452 .4316 m
.68812 .4414 L
s
.75316 .40881 m
.75599 .40926 L
s
.89375 .3966 m
.89644 .40019 L
s
.36973 .63353 m
.37363 .64088 L
s
.5854 .44904 m
.58905 .45862 L
s
.84197 .39677 m
.84509 .40304 L
s
.6812 .42721 m
.68452 .4316 L
s
.50126 .67428 m
.50354 .89681 L
s
.73933 .40644 m
.74235 .40865 L
s
.65705 .42895 m
.66067 .43895 L
s
.5817 .43692 m
.5854 .44904 L
s
.57832 .44368 m
.5817 .43692 L
s
.57163 .61786 m
.57457 .5777 L
s
.58655 .50088 m
.59007 .50385 L
s
.52757 .47172 m
.53127 .4926 L
s
.52385 .48901 m
.52757 .47172 L
s
.46532 .60343 m
.46783 .67934 L
s
.56251 .49968 m
.56681 .55684 L
s
.44936 .60572 m
.45423 .56953 L
s
.44585 .50262 m
.44915 .52964 L
s
.44121 .52497 m
.44585 .50262 L
s
.35559 .63779 m
.35972 .64126 L
s
.82847 .39729 m
.83155 .40295 L
s
.36011 .69666 m
.36439 .69689 L
s
.65342 .41896 m
.65705 .42895 L
s
.80098 .39423 m
.80405 .39915 L
s
.81464 .39489 m
.81784 .40146 L
s
.53594 .54049 m
.53966 .55786 L
s
.62039 .47806 m
.62443 .50028 L
s
.55087 .60596 m
.55442 .59844 L
s
.36575 .62756 m
.36973 .63353 L
s
.88033 .3975 m
.88316 .40196 L
s
.44507 .62482 m
.44786 .6732 L
s
.65012 .41679 m
.65342 .41896 L
s
.78734 .39387 m
.79037 .398 L
s
.76366 .40425 m
.76654 .40568 L
s
.72538 .40226 m
.72884 .41036 L
s
.54704 .57709 m
.55087 .60596 L
s
.70562 .42837 m
.70866 .42914 L
s
.83907 .39265 m
.84197 .39677 L
s
.86659 .39596 m
.86958 .40143 L
s
.69531 .43461 m
.69858 .43872 L
s
.40191 .69574 m
.40554 .70916 L
s
.3979 .69204 m
.40191 .69574 L
s
.23604 .39138 m
.24045 .39588 L
s
.58277 .48559 m
.58655 .50088 L
s
.5792 .48083 m
.58277 .48559 L
s
.57564 .62666 m
.57962 .65482 L
s
.5983 .4117 m
.60211 .42787 L
s
.59535 .43205 m
.5983 .4117 L
s
.63673 .42629 m
.63971 .41867 L
s
.8529 .39489 m
.85587 .39992 L
s
.47904 .72177 m
.48371 .6665 L
s
.44254 .82441 m
.44501 .88764 L
s
.63704 .4521 m
.64075 .46389 L
s
.5177 .66005 m
.52142 .6627 L
s
.40554 .70916 m
.40882 .73238 L
s
.89106 .39311 m
.89375 .3966 L
s
.67764 .41831 m
.6812 .42721 L
s
.66024 .40712 m
.6637 .41352 L
s
.53127 .4926 m
.53497 .50166 L
s
.81169 .39099 m
.81464 .39489 L
s
.82536 .39149 m
.82847 .39729 L
s
.63478 .49699 m
.63807 .49703 L
s
.72187 .39348 m
.72538 .40226 L
s
.67383 .40467 m
.67764 .41831 L
s
.67062 .40299 m
.67383 .40467 L
s
.77412 .39878 m
.77694 .39993 L
s
.61248 .42698 m
.61587 .42798 L
s
.62697 .46266 m
.631 .48356 L
s
.36165 .62375 m
.36575 .62756 L
s
.7122 .4099 m
.7153 .41203 L
s
.35138 .63531 m
.35559 .63779 L
s
.79804 .39074 m
.80098 .39423 L
s
.394 .8565 m
.39828 .85345 L
s
.73625 .40347 m
.73933 .40644 L
s
.74999 .40424 m
.75316 .40881 L
s
.59256 .46282 m
.59569 .44857 L
s
.60211 .42787 m
.60588 .44187 L
s
.87743 .39261 m
.88033 .3975 L
s
.68778 .40941 m
.69177 .426 L
s
.68413 .39879 m
.68778 .40941 L
s
.71879 .39135 m
.72187 .39348 L
s
.86358 .39036 m
.86659 .39596 L
s
.78445 .39151 m
.78734 .39387 L
s
.68072 .39292 m
.68413 .39879 L
s
.62443 .50028 m
.62811 .51086 L
s
.57587 .49209 m
.5792 .48083 L
s
.35584 .69565 m
.36011 .69666 L
s
.39365 .69354 m
.3979 .69204 L
s
.84984 .38912 m
.8529 .39489 L
s
.83607 .38766 m
.83907 .39265 L
s
.69177 .426 m
.69531 .43461 L
s
.23162 .38685 m
.23604 .39138 L
s
.65689 .40369 m
.66024 .40712 L
s
.51479 .74669 m
.5187 .70164 L
s
.64703 .42022 m
.65012 .41679 L
s
.82238 .38709 m
.82536 .39149 L
s
.76058 .40045 m
.76366 .40425 L
s
.56765 .73387 m
.57143 .75071 L
s
.51381 .69316 m
.5177 .66005 L
s
.47788 .57681 m
.48088 .63737 L
s
.47293 .63844 m
.47788 .57681 L
s
.88825 .38877 m
.89106 .39311 L
s
.80881 .38792 m
.81169 .39099 L
s
.70212 .4204 m
.70562 .42837 L
s
.35745 .62119 m
.36165 .62375 L
s
.51644 .45209 m
.52009 .49107 L
s
.51261 .46548 m
.51644 .45209 L
s
.52112 .51965 m
.52485 .51937 L
s
.56152 .64068 m
.56468 .60301 L
s
.42888 .54791 m
.43084 .6171 L
s
.44915 .52964 m
.45176 .58729 L
s
.62317 .43434 m
.62628 .42731 L
s
.7466 .39681 m
.74999 .40424 L
s
.87448 .3874 m
.87743 .39261 L
s
.67767 .39396 m
.68072 .39292 L
s
.86064 .38544 m
.86358 .39036 L
s
.631 .48356 m
.63478 .49699 L
s
.40882 .73238 m
.41195 .7606 L
s
.79497 .38612 m
.79804 .39074 L
s
.34712 .63328 m
.35138 .63531 L
s
.66734 .40049 m
.67062 .40299 L
s
.70876 .40276 m
.7122 .4099 L
s
.42297 .80123 m
.42735 .79127 L
s
.84685 .38403 m
.84984 .38912 L
s
.69836 .40801 m
.70212 .4204 L
s
.6947 .39721 m
.69836 .40801 L
s
.54151 .50636 m
.54515 .50345 L
s
.73295 .39781 m
.73625 .40347 L
s
.77125 .39724 m
.77412 .39878 L
s
.60932 .43507 m
.61248 .42698 L
s
.57498 .4549 m
.57832 .44368 L
s
.51543 .41129 m
.51906 .45836 L
s
.51148 .44691 m
.51543 .41129 L
s
.83311 .3832 m
.83607 .38766 L
s
.69126 .39049 m
.6947 .39721 L
s
.56588 .51841 m
.56917 .49738 L
s
.4585 .64389 m
.46181 .67577 L
s
.50638 .86645 m
.51052 .80636 L
s
.22718 .38231 m
.23162 .38685 L
s
.71549 .38618 m
.71879 .39135 L
s
.78162 .39 m
.78445 .39151 L
s
.81949 .38362 m
.82238 .38709 L
s
.65375 .40526 m
.65689 .40369 L
s
.74325 .39022 m
.7466 .39681 L
s
.51176 .61145 m
.51569 .57854 L
s
.35159 .69387 m
.35584 .69565 L
s
.56675 .69772 m
.57074 .72906 L
s
.56316 .69749 m
.56675 .69772 L
s
.53674 .44003 m
.54052 .46467 L
s
.53306 .44445 m
.53674 .44003 L
s
.38966 .8602 m
.394 .8565 L
s
.70505 .3913 m
.70876 .40276 L
s
.75746 .39635 m
.76058 .40045 L
s
.70173 .38615 m
.70505 .3913 L
s
.88532 .38349 m
.88825 .38877 L
s
.58144 .74812 m
.58437 .71245 L
s
.55932 .67534 m
.56316 .69749 L
s
.54618 .55277 m
.55009 .58999 L
s
.87148 .3818 m
.87448 .3874 L
s
.5303 .46257 m
.53407 .49248 L
s
.85766 .38036 m
.86064 .38544 L
s
.80588 .38449 m
.80881 .38792 L
s
.35325 .61828 m
.35745 .62119 L
s
.68825 .39171 m
.69126 .39049 L
s
.38943 .69364 m
.39365 .69354 L
s
.60148 .39793 m
.60565 .42608 L
s
.59831 .40843 m
.60148 .39793 L
s
.72951 .39016 m
.73295 .39781 L
s
.79183 .38088 m
.79497 .38612 L
s
.52714 .92588 m
.53083 .7938 L
s
.84391 .37959 m
.84685 .38403 L
s
.63365 .43243 m
.63673 .42629 L
s
.45142 .69237 m
.45564 .68286 L
s
.74007 .38588 m
.74325 .39022 L
s
.8303 .38032 m
.83311 .3832 L
s
.34286 .63097 m
.34712 .63328 L
s
.71224 .38199 m
.71549 .38618 L
s
.22271 .37774 m
.22718 .38231 L
s
.66377 .39214 m
.66734 .40049 L
s
.56583 .65966 m
.57049 .74007 L
s
.64392 .42384 m
.64703 .42022 L
s
.72611 .38323 m
.72951 .39016 L
s
.76812 .39269 m
.77125 .39724 L
s
.88235 .37804 m
.88532 .38349 L
s
.81657 .38006 m
.81949 .38362 L
s
.6986 .38461 m
.70173 .38615 L
s
.52009 .49107 m
.52385 .48901 L
s
.57912 .80919 m
.58177 .75246 L
s
.86852 .37663 m
.87148 .3818 L
s
.67468 .39692 m
.67767 .39396 L
s
.75414 .39 m
.75746 .39635 L
s
.66018 .38341 m
.66377 .39214 L
s
.46181 .67577 m
.4657 .67919 L
s
.85473 .37573 m
.85766 .38036 L
s
.77862 .3867 m
.78162 .39 L
s
.34732 .69182 m
.35159 .69387 L
s
.78896 .37871 m
.79183 .38088 L
s
.41993 .49573 m
.42183 .56121 L
s
.84108 .37619 m
.84391 .37959 L
s
.34908 .61431 m
.35325 .61828 L
s
.80283 .38 m
.80588 .38449 L
s
.41195 .7606 m
.41522 .78587 L
s
.53779 .49854 m
.54151 .50636 L
s
.45889 .62965 m
.46366 .59313 L
s
.44313 .78508 m
.44899 .71235 L
s
.43005 .48859 m
.43317 .52029 L
s
.42584 .49123 m
.43005 .48859 L
s
.72288 .37904 m
.72611 .38323 L
s
.657 .38398 m
.66018 .38341 L
s
.73676 .38013 m
.74007 .38588 L
s
.57073 .58086 m
.57412 .5685 L
s
.21822 .37316 m
.22271 .37774 L
s
.45516 .5268 m
.45825 .56779 L
s
.45098 .53338 m
.45516 .5268 L
s
.65055 .40627 m
.65375 .40526 L
s
.70929 .38274 m
.71224 .38199 L
s
.46423 .84022 m
.46862 .8166 L
s
.5725 .50437 m
.57587 .49209 L
s
.43676 .53788 m
.44121 .52497 L
s
.61569 .41056 m
.61969 .43046 L
s
.61212 .40437 m
.61569 .41056 L
s
.55193 .52407 m
.55546 .51122 L
s
.38546 .68737 m
.38943 .69364 L
s
.54052 .46467 m
.5444 .50071 L
s
.41131 .43219 m
.4144 .46121 L
s
.40347 .52207 m
.41131 .43219 L
s
.44993 .75903 m
.45313 .79485 L
s
.4459 .75939 m
.44993 .75903 L
s
.82745 .37717 m
.8303 .38032 L
s
.61969 .43046 m
.62317 .43434 L
s
.33859 .6282 m
.34286 .63097 L
s
.87942 .37296 m
.88235 .37804 L
s
.75062 .38114 m
.75414 .39 L
s
.58898 .45834 m
.59256 .46282 L
s
.38527 .86439 m
.38966 .8602 L
s
.76471 .38502 m
.76812 .39269 L
s
.42563 .57298 m
.43096 .53598 L
s
.53407 .49248 m
.53779 .49854 L
s
.86561 .37202 m
.86852 .37663 L
s
.37816 .66001 m
.38176 .67467 L
s
.37442 .64844 m
.37816 .66001 L
s
.37043 .64192 m
.37442 .64844 L
s
.68477 .3847 m
.68825 .39171 L
s
.81361 .37623 m
.81657 .38006 L
s
.41888 .80045 m
.42297 .80123 L
s
.58513 .44122 m
.58898 .45834 L
s
.58141 .43042 m
.58513 .44122 L
s
.52932 .43212 m
.53306 .44445 L
s
.52558 .43466 m
.52932 .43212 L
s
.59195 .43566 m
.59535 .43205 L
s
.85185 .37169 m
.85473 .37573 L
s
.44786 .6732 m
.45142 .69237 L
s
.57801 .43863 m
.58141 .43042 L
s
.42554 .73168 m
.43289 .62696 L
s
.60565 .42608 m
.60932 .43507 L
s
.74722 .37386 m
.75062 .38114 L
s
.44209 .57394 m
.44522 .60878 L
s
.38176 .67467 m
.38546 .68737 L
s
.77546 .38176 m
.77862 .3867 L
s
.6956 .38574 m
.6986 .38461 L
s
.34491 .60995 m
.34908 .61431 L
s
.79962 .37392 m
.80283 .38 L
s
.73349 .37494 m
.73676 .38013 L
s
.34302 .69 m
.34732 .69182 L
s
.76135 .37807 m
.76471 .38502 L
s
.57074 .72906 m
.57517 .78752 L
s
.6186 .38329 m
.62262 .40355 L
s
.61545 .39103 m
.6186 .38329 L
s
.60855 .39877 m
.61212 .40437 L
s
.50848 .52072 m
.51261 .46548 L
s
.83823 .37282 m
.84108 .37619 L
s
.78596 .37532 m
.78896 .37871 L
s
.71988 .37847 m
.72288 .37904 L
s
.54704 .44977 m
.5509 .47652 L
s
.54332 .44371 m
.54704 .44977 L
s
.51055 .60791 m
.51461 .55509 L
s
.36627 .63849 m
.37043 .64192 L
s
.21371 .36855 m
.21822 .37316 L
s
.57149 .45988 m
.57498 .4549 L
s
.6814 .38009 m
.68477 .3847 L
s
.87653 .36832 m
.87942 .37296 L
s
.60468 .38275 m
.60855 .39877 L
s
.60169 .40019 m
.60468 .38275 L
s
.63013 .42698 m
.63365 .43243 L
s
.74409 .37027 m
.74722 .37386 L
s
.51906 .45836 m
.52284 .45861 L
s
.64054 .42173 m
.64392 .42384 L
s
.8627 .3675 m
.86561 .37202 L
s
.33429 .62553 m
.33859 .6282 L
s
.82445 .37262 m
.82745 .37717 L
s
.41522 .78587 m
.41888 .80045 L
s
.67133 .3931 m
.67468 .39692 L
s
.75801 .37143 m
.76135 .37807 L
s
.56681 .55684 m
.57073 .58086 L
s
.81059 .3719 m
.81361 .37623 L
s
.79638 .36763 m
.79962 .37392 L
s
.84905 .3684 m
.85185 .37169 L
s
.65377 .38409 m
.657 .38398 L
s
.43984 .83727 m
.4459 .75939 L
s
.77209 .37454 m
.77546 .38176 L
s
.73037 .37216 m
.73349 .37494 L
s
.34069 .6062 m
.34491 .60995 L
s
.59499 .41505 m
.59831 .40843 L
s
.53962 .44313 m
.54332 .44371 L
s
.44522 .60878 m
.44936 .60572 L
s
.64715 .40297 m
.65055 .40627 L
s
.70626 .38264 m
.70929 .38274 L
s
.42082 .51595 m
.42584 .49123 L
s
.55009 .58999 m
.55388 .60591 L
s
.51651 .67866 m
.52035 .66291 L
s
.20918 .36391 m
.21371 .36855 L
s
.33867 .68852 m
.34302 .69 L
s
.62638 .41544 m
.63013 .42698 L
s
.62262 .40355 m
.62638 .41544 L
s
.36211 .63451 m
.36627 .63849 L
s
.67828 .38038 m
.6814 .38009 L
s
.83534 .36913 m
.83823 .37282 L
s
.78271 .36918 m
.78596 .37532 L
s
.87369 .36415 m
.87653 .36832 L
s
.49159 .78196 m
.49476 .85588 L
s
.38082 .86883 m
.38527 .86439 L
s
.56827 .6361 m
.57163 .61786 L
s
.75479 .36651 m
.75801 .37143 L
s
.50908 .63007 m
.51275 .66086 L
s
.50527 .62693 m
.50908 .63007 L
s
.76858 .36578 m
.77209 .37454 L
s
.85982 .36328 m
.8627 .3675 L
s
.79333 .36354 m
.79638 .36763 L
s
.74076 .36428 m
.74409 .37027 L
s
.56242 .53103 m
.56588 .51841 L
s
.82133 .36717 m
.82445 .37262 L
s
.44501 .88764 m
.44725 .96614 L
s
.55388 .60591 m
.55775 .62838 L
s
.52178 .44551 m
.52558 .43466 L
s
.44667 .54274 m
.45098 .53338 L
s
.58817 .42292 m
.59195 .43566 L
s
.58447 .41427 m
.58817 .42292 L
s
.32992 .62358 m
.33429 .62553 L
s
.71679 .37686 m
.71988 .37847 L
s
.4144 .46121 m
.41676 .51153 L
s
.69236 .38297 m
.6956 .38574 L
s
.46316 1.00133 m
.46927 .88161 L
s
.66769 .38383 m
.67133 .3931 L
s
.43317 .52029 m
.43676 .53788 L
s
.80745 .36653 m
.81059 .3719 L
s
.55665 .57438 m
.5608 .6222 L
s
.63692 .41371 m
.64054 .42173 L
s
.62928 .38695 m
.63304 .39871 L
s
.62581 .38343 m
.62928 .38695 L
s
.63304 .39871 m
.63692 .41371 L
s
.76544 .36146 m
.76858 .36578 L
s
.3364 .60329 m
.34069 .6062 L
s
.8462 .36488 m
.84905 .3684 L
s
.77943 .36296 m
.78271 .36918 L
s
.58106 .42146 m
.58447 .41427 L
s
.66407 .37508 m
.66769 .38383 L
s
.51429 .403 m
.51804 .41893 L
s
.51019 .45361 m
.51429 .403 L
s
.72728 .37016 m
.73037 .37216 L
s
.64351 .39408 m
.64715 .40297 L
s
.43421 .64293 m
.43886 .62425 L
s
.20463 .35926 m
.20918 .36391 L
s
.5509 .47652 m
.55488 .51096 L
s
.35806 .62811 m
.36211 .63451 L
s
.50961 .76737 m
.51381 .69316 L
s
.51704 .37141 m
.52076 .40859 L
s
.51301 .41922 m
.51704 .37141 L
s
.45313 .79485 m
.45643 .82871 L
s
.52833 .40672 m
.53211 .42649 L
s
.52455 .41924 m
.52833 .40672 L
s
.75173 .36366 m
.75479 .36651 L
s
.73762 .36101 m
.74076 .36428 L
s
.8708 .35971 m
.87369 .36415 L
s
.83233 .36451 m
.83534 .36913 L
s
.81824 .36204 m
.82133 .36717 L
s
.6504 .38155 m
.65377 .38409 L
s
.5359 .44287 m
.53962 .44313 L
s
.56898 .51013 m
.5725 .50437 L
s
.50108 .6684 m
.50527 .62693 L
s
.57462 .44966 m
.57801 .43863 L
s
.5679 .4603 m
.57149 .45988 L
s
.66079 .37372 m
.66407 .37508 L
s
.33428 .68715 m
.33867 .68852 L
s
.63988 .38588 m
.64351 .39408 L
s
.85698 .35957 m
.85982 .36328 L
s
.79018 .35843 m
.79333 .36354 L
s
.54821 .51888 m
.55193 .52407 L
s
.7028 .37579 m
.70626 .38264 L
s
.5444 .50071 m
.54821 .51888 L
s
.80422 .36035 m
.80745 .36653 L
s
.6079 .36694 m
.61188 .38575 L
s
.60489 .3832 m
.6079 .36694 L
s
.51804 .41893 m
.52178 .44551 L
s
.61188 .38575 m
.61545 .39103 L
s
.55746 .4595 m
.56134 .48091 L
s
.55374 .45247 m
.55746 .4595 L
s
.77625 .35789 m
.77943 .36296 L
s
.45176 .58729 m
.45488 .62734 L
s
.46783 .67934 m
.47092 .73103 L
s
.35407 .62033 m
.35806 .62811 L
s
.48088 .63737 m
.48263 .80292 L
s
.67486 .37537 m
.67828 .38038 L
s
.76236 .35811 m
.76544 .36146 L
s
.32547 .62253 m
.32992 .62358 L
s
.68861 .37159 m
.69236 .38297 L
s
.55775 .62838 m
.56152 .64068 L
s
.50423 .58616 m
.50797 .60291 L
s
.50021 .60501 m
.50423 .58616 L
s
.62224 .37771 m
.62581 .38343 L
s
.68502 .36304 m
.68861 .37159 L
s
.63635 .38041 m
.63988 .38588 L
s
.33206 .60067 m
.3364 .60329 L
s
.45825 .56779 m
.46083 .637 L
s
.84321 .36017 m
.8462 .36488 L
s
.71356 .37342 m
.71679 .37686 L
s
.40923 .41503 m
.41187 .45622 L
s
.40294 .46408 m
.40923 .41503 L
s
.20005 .35458 m
.20463 .35926 L
s
.50797 .60291 m
.51176 .61145 L
s
.37633 .87321 m
.38082 .86883 L
s
.6994 .37026 m
.7028 .37579 L
s
.51089 .76083 m
.51479 .74669 L
s
.81514 .35696 m
.81824 .36204 L
s
.86781 .35451 m
.8708 .35971 L
s
.82919 .35866 m
.83233 .36451 L
s
.53211 .42649 m
.5359 .44287 L
s
.55006 .45255 m
.55374 .45247 L
s
.35004 .61327 m
.35407 .62033 L
s
.80106 .35492 m
.80422 .36035 L
s
.59123 .40408 m
.59499 .41505 L
s
.68191 .36345 m
.68502 .36304 L
s
.43553 .5003 m
.43927 .51354 L
s
.43165 .49201 m
.43553 .5003 L
s
.72413 .36742 m
.72728 .37016 L
s
.78708 .3541 m
.79018 .35843 L
s
.46013 .84499 m
.46423 .84022 L
s
.73451 .3584 m
.73762 .36101 L
s
.57811 .76433 m
.58144 .74812 L
s
.7485 .3589 m
.75173 .36366 L
s
.58748 .39357 m
.59123 .40408 L
s
.50735 .49204 m
.51148 .44691 L
s
.43927 .51354 m
.44283 .53311 L
s
.85411 .35575 m
.85698 .35957 L
s
.64701 .37913 m
.6504 .38155 L
s
.47469 .74583 m
.47904 .72177 L
s
.77326 .35528 m
.77625 .35789 L
s
.58407 .39991 m
.58748 .39357 L
s
.51275 .66086 m
.51651 .67866 L
s
.32987 .68563 m
.33428 .68715 L
s
.61896 .38144 m
.62224 .37771 L
s
.67125 .36689 m
.67486 .37537 L
s
.42789 .47964 m
.43165 .49201 L
s
.42391 .47373 m
.42789 .47964 L
s
.633 .38017 m
.63635 .38041 L
s
.65755 .37377 m
.66079 .37372 L
s
.50567 .55466 m
.50971 .52794 L
s
.34589 .60777 m
.35004 .61327 L
s
.56134 .48091 m
.56525 .5026 L
s
.84014 .35488 m
.84321 .36017 L
s
.75938 .3561 m
.76236 .35811 L
s
.69594 .36383 m
.6994 .37026 L
s
.56427 .46049 m
.5679 .4603 L
s
.19545 .34987 m
.20005 .35458 L
s
.82597 .35223 m
.82919 .35866 L
s
.3277 .5978 m
.33206 .60067 L
s
.43084 .6171 m
.43421 .64293 L
s
.71013 .36708 m
.71356 .37342 L
s
.86494 .35035 m
.86781 .35451 L
s
.81198 .35138 m
.81514 .35696 L
s
.32094 .62207 m
.32547 .62253 L
s
.66786 .36307 m
.67125 .36689 L
s
.79794 .35012 m
.80106 .35492 L
s
.59829 .40402 m
.60169 .40019 L
s
.44283 .53311 m
.44667 .54274 L
s
.48779 .84905 m
.49307 .73031 L
s
.78404 .35059 m
.78708 .3541 L
s
.74512 .35248 m
.7485 .3589 L
s
.47414 .67186 m
.47619 .79813 L
s
.41936 .48336 m
.42391 .47373 L
s
.57762 .42932 m
.58106 .42146 L
s
.72072 .36121 m
.72413 .36742 L
s
.55874 .52982 m
.56242 .53103 L
s
.85111 .35085 m
.85411 .35575 L
s
.73131 .35479 m
.73451 .3584 L
s
.56525 .5026 m
.56898 .51013 L
s
.51976 .35644 m
.52352 .39421 L
s
.51578 .3962 m
.51976 .35644 L
s
.34168 .60309 m
.34589 .60777 L
s
.6922 .35287 m
.69594 .36383 L
s
.82287 .3471 m
.82597 .35223 L
s
.45643 .82871 m
.46013 .84499 L
s
.83702 .34925 m
.84014 .35488 L
s
.68917 .35436 m
.6922 .35287 L
s
.5463 .4455 m
.55006 .45255 L
s
.70641 .35633 m
.71013 .36708 L
s
.64361 .37675 m
.64701 .37913 L
s
.77007 .35054 m
.77326 .35528 L
s
.41099 .70177 m
.41926 .58832 L
s
.32544 .68404 m
.32987 .68563 L
s
.54249 .42963 m
.5463 .4455 L
s
.5387 .4188 m
.54249 .42963 L
s
.19082 .34515 m
.19545 .34987 L
s
.80887 .34647 m
.81198 .35138 L
s
.67841 .35725 m
.68191 .36345 L
s
.70312 .35273 m
.70641 .35633 L
s
.37182 .87728 m
.37633 .87321 L
s
.56464 .63715 m
.56827 .6361 L
s
.53112 .39466 m
.53491 .40763 L
s
.52734 .40278 m
.53112 .39466 L
s
.55488 .51096 m
.55874 .52982 L
s
.45488 .62734 m
.45889 .62965 L
s
.53491 .40763 m
.5387 .4188 L
s
.74178 .34657 m
.74512 .35248 L
s
.79498 .34713 m
.79794 .35012 L
s
.86202 .34596 m
.86494 .35035 L
s
.32335 .59465 m
.3277 .5978 L
s
.66462 .36276 m
.66786 .36307 L
s
.7562 .35195 m
.75938 .3561 L
s
.51695 1.0359 m
.52055 .86616 L
s
.62938 .37328 m
.633 .38017 L
s
.71728 .35468 m
.72072 .36121 L
s
.57107 .45417 m
.57462 .44966 L
s
.6542 .37188 m
.65755 .37377 L
s
.52076 .40859 m
.52455 .41924 L
s
.78107 .348 m
.78404 .35059 L
s
.57517 .78752 m
.57912 .80919 L
s
.84797 .34488 m
.85111 .35085 L
s
.31637 .62182 m
.32094 .62207 L
s
.33746 .59826 m
.34168 .60309 L
s
.5606 .45905 m
.56427 .46049 L
s
.50224 .90305 m
.50638 .86645 L
s
.83387 .34337 m
.83702 .34925 L
s
.41676 .51153 m
.42082 .51595 L
s
.42183 .56121 m
.42563 .57298 L
s
.81982 .34244 m
.82287 .3471 L
s
.61134 .35708 m
.61518 .37019 L
s
.60825 .36996 m
.61134 .35708 L
s
.72797 .34949 m
.73131 .35479 L
s
.67486 .35011 m
.67841 .35725 L
s
.61518 .37019 m
.61896 .38144 L
s
.76688 .34583 m
.77007 .35054 L
s
.468 .6886 m
.47293 .63844 L
s
.80586 .34264 m
.80887 .34647 L
s
.73864 .34354 m
.74178 .34657 L
s
.18618 .3404 m
.19082 .34515 L
s
.62568 .36424 m
.62938 .37328 L
s
.4415 .49945 m
.44523 .51375 L
s
.43754 .49294 m
.4415 .49945 L
s
.58065 .40862 m
.58407 .39991 L
s
.71373 .34664 m
.71728 .35468 L
s
.69956 .34476 m
.70312 .35273 L
s
.64004 .3709 m
.64361 .37675 L
s
.32095 .68279 m
.32544 .68404 L
s
.85902 .34098 m
.86202 .34596 L
s
.5608 .6222 m
.56464 .63715 L
s
.59448 .3918 m
.59829 .40402 L
s
.59072 .3816 m
.59448 .3918 L
s
.31896 .59151 m
.32335 .59465 L
s
.44523 .51375 m
.44871 .53833 L
s
.50702 .76085 m
.51089 .76083 L
s
.79194 .34351 m
.79498 .34713 L
s
.75285 .34573 m
.7562 .35195 L
s
.60143 .38454 m
.60489 .3832 L
s
.84489 .33943 m
.84797 .34488 L
s
.62224 .36342 m
.62568 .36424 L
s
.6716 .349 m
.67486 .35011 L
s
.46423 .57392 m
.46711 .635 L
s
.46036 .565 m
.46423 .57392 L
s
.33324 .59313 m
.33746 .59826 L
s
.58729 .38761 m
.59072 .3816 L
s
.83082 .33861 m
.83387 .34337 L
s
.71053 .34406 m
.71373 .34664 L
s
.54534 .40895 m
.54916 .42231 L
s
.54157 .40377 m
.54534 .40895 L
s
.6964 .34367 m
.69956 .34476 L
s
.72459 .34379 m
.72797 .34949 L
s
.68584 .35106 m
.68917 .35436 L
s
.57049 .74007 m
.57454 .76837 L
s
.81675 .33781 m
.81982 .34244 L
s
.43355 .48718 m
.43754 .49294 L
s
.49592 .6427 m
.50021 .60501 L
s
.57454 .76837 m
.57811 .76433 L
s
.65074 .36808 m
.6542 .37188 L
s
.45612 .57212 m
.46036 .565 L
s
.7779 .34331 m
.78107 .348 L
s
.76372 .34181 m
.76688 .34583 L
s
.54916 .42231 m
.553 .43781 L
s
.66128 .36076 m
.66462 .36276 L
s
.36728 .88101 m
.37182 .87728 L
s
.41187 .45622 m
.41505 .485 L
s
.18151 .33562 m
.18618 .3404 L
s
.55683 .45129 m
.5606 .45905 L
s
.63647 .36513 m
.64004 .3709 L
s
.31176 .6216 m
.31637 .62182 L
s
.80284 .3389 m
.80586 .34264 L
s
.57403 .43074 m
.57762 .42932 L
s
.74945 .3391 m
.75285 .34573 L
s
.85594 .33544 m
.85902 .34098 L
s
.73543 .33987 m
.73864 .34354 L
s
.84186 .33462 m
.84489 .33943 L
s
.553 .43781 m
.55683 .45129 L
s
.41505 .485 m
.41936 .48336 L
s
.32899 .58812 m
.33324 .59313 L
s
.42596 .46203 m
.42969 .47664 L
s
.42197 .45517 m
.42596 .46203 L
s
.61831 .3479 m
.62224 .36342 L
s
.61496 .35095 m
.61831 .3479 L
s
.31453 .58863 m
.31896 .59151 L
s
.82777 .33384 m
.83082 .33861 L
s
.78878 .33869 m
.79194 .34351 L
s
.31639 .68235 m
.32095 .68279 L
s
.42969 .47664 m
.43355 .48718 L
s
.7213 .33949 m
.72459 .34379 L
s
.53777 .39472 m
.54157 .40377 L
s
.56738 .45095 m
.57107 .45417 L
s
.47092 .73103 m
.47469 .74583 L
s
.81374 .3339 m
.81675 .33781 L
s
.52352 .39421 m
.52734 .40278 L
s
.50273 .81547 m
.50702 .76085 L
s
.53395 .38174 m
.53777 .39472 L
s
.53015 .38517 m
.53395 .38174 L
s
.7745 .33619 m
.7779 .34331 L
s
.63267 .35368 m
.63647 .36513 L
s
.68222 .3429 m
.68584 .35106 L
s
.74622 .33485 m
.74945 .3391 L
s
.62918 .35084 m
.63267 .35368 L
s
.7072 .33985 m
.71053 .34406 L
s
.64712 .36082 m
.65074 .36808 L
s
.66833 .348 m
.6716 .349 L
s
.76044 .33641 m
.76372 .34181 L
s
.17682 .33083 m
.18151 .33562 L
s
.44871 .53833 m
.45223 .56291 L
s
.41755 .45979 m
.42197 .45517 L
s
.85294 .33064 m
.85594 .33544 L
s
.5225 .3481 m
.52632 .37461 L
s
.51856 .38051 m
.5225 .3481 L
s
.5976 .37221 m
.60143 .38454 L
s
.59394 .36681 m
.5976 .37221 L
s
.69321 .34263 m
.6964 .34367 L
s
.79978 .33487 m
.80284 .3389 L
s
.6578 .35626 m
.66128 .36076 L
s
.32469 .58352 m
.32899 .58812 L
s
.49806 .52586 m
.50187 .53916 L
s
.49382 .55419 m
.49806 .52586 L
s
.8389 .33056 m
.84186 .33462 L
s
.40661 .40946 m
.41006 .43087 L
s
.40063 .44869 m
.40661 .40946 L
s
.73216 .33559 m
.73543 .33987 L
s
.50657 .62024 m
.51055 .60791 L
s
.67874 .33724 m
.68222 .3429 L
s
.50187 .53916 m
.50567 .55466 L
s
.77126 .33102 m
.7745 .33619 L
s
.82468 .32891 m
.82777 .33384 L
s
.7856 .33382 m
.78878 .33869 L
s
.30713 .62128 m
.31176 .6216 L
s
.64348 .35339 m
.64712 .36082 L
s
.49476 .85588 m
.49832 .90001 L
s
.31005 .58609 m
.31453 .58863 L
s
.71799 .33523 m
.7213 .33949 L
s
.36271 .88455 m
.36728 .88101 L
s
.56357 .44082 m
.56738 .45095 L
s
.55973 .42706 m
.56357 .44082 L
s
.5559 .41531 m
.55973 .42706 L
s
.5521 .40583 m
.5559 .41531 L
s
.50444 .53857 m
.50848 .52072 L
s
.81068 .32959 m
.81374 .3339 L
s
.75709 .33033 m
.76044 .33641 L
s
.57708 .41174 m
.58065 .40862 L
s
.58383 .39452 m
.58729 .38761 L
s
.1721 .32601 m
.17682 .33083 L
s
.57031 .42607 m
.57403 .43074 L
s
.31172 .68295 m
.31639 .68235 L
s
.74305 .33152 m
.74622 .33485 L
s
.7036 .33153 m
.7072 .33985 L
s
.49903 .57734 m
.50281 .59579 L
s
.49482 .6036 m
.49903 .57734 L
s
.4966 .72787 m
.50108 .6684 L
s
.59053 .37371 m
.59394 .36681 L
s
.84996 .32612 m
.85294 .33064 L
s
.54828 .39609 m
.5521 .40583 L
s
.44725 .96614 m
.44963 1.04552 L
s
.60465 .36665 m
.60825 .36996 L
s
.6256 .34621 m
.62918 .35084 L
s
.32035 .57926 m
.32469 .58352 L
s
.63986 .34676 m
.64348 .35339 L
s
.43748 .84186 m
.44313 .78508 L
s
.65423 .35031 m
.6578 .35626 L
s
.45223 .56291 m
.45612 .57212 L
s
.67549 .3365 m
.67874 .33724 L
s
.79652 .32893 m
.79978 .33487 L
s
.37721 .70701 m
.38075 .72562 L
s
.37315 .6999 m
.37721 .70701 L
s
.83589 .32609 m
.8389 .33056 L
s
.72895 .33233 m
.73216 .33559 L
s
.76808 .32676 m
.77126 .33102 L
s
.66492 .34484 m
.66833 .348 L
s
.54448 .38845 m
.54828 .39609 L
s
.8216 .32421 m
.82468 .32891 L
s
.70048 .33133 m
.7036 .33153 L
s
.78225 .32718 m
.7856 .33382 L
s
.61166 .35694 m
.61496 .35095 L
s
.41006 .43087 m
.41338 .45658 L
s
.75387 .32606 m
.75709 .33033 L
s
.71475 .33229 m
.71799 .33523 L
s
.68969 .33604 m
.69321 .34263 L
s
.62166 .33117 m
.6256 .34621 L
s
.61855 .34161 m
.62166 .33117 L
s
.30552 .5839 m
.31005 .58609 L
s
.50281 .59579 m
.50657 .62024 L
s
.80756 .32485 m
.81068 .32959 L
s
.52632 .37461 m
.53015 .38517 L
s
.6362 .33933 m
.63986 .34676 L
s
.56653 .41841 m
.57031 .42607 L
s
.16736 .32116 m
.1721 .32601 L
s
.36901 .69404 m
.37315 .6999 L
s
.30247 .62074 m
.30713 .62128 L
s
.54064 .37688 m
.54448 .38845 L
s
.43576 .47275 m
.43957 .48572 L
s
.43183 .46394 m
.43576 .47275 L
s
.35776 .6528 m
.36146 .66747 L
s
.35387 .6417 m
.35776 .6528 L
s
.65062 .34346 m
.65423 .35031 L
s
.53682 .36782 m
.54064 .37688 L
s
.84702 .32208 m
.84996 .32612 L
s
.79329 .32343 m
.79652 .32893 L
s
.31597 .57517 m
.32035 .57926 L
s
.7398 .32746 m
.74305 .33152 L
s
.38075 .72562 m
.38366 .75897 L
s
.40099 .65711 m
.40914 .56001 L
s
.34984 .63316 m
.35387 .6417 L
s
.43957 .48572 m
.44334 .50049 L
s
.46083 .637 m
.46392 .6871 L
s
.77899 .32179 m
.78225 .32718 L
s
.41338 .45658 m
.41755 .45979 L
s
.6008 .35411 m
.60465 .36665 L
s
.59725 .35397 m
.6008 .35411 L
s
.50896 .44275 m
.51301 .41922 L
s
.36146 .66747 m
.36513 .68284 L
s
.50615 .47172 m
.51019 .45361 L
s
.83278 .32085 m
.83589 .32609 L
s
.68608 .32819 m
.68969 .33604 L
s
.42792 .45397 m
.43183 .46394 L
s
.533 .3692 m
.53682 .36782 L
s
.81854 .31982 m
.8216 .32421 L
s
.3581 .88805 m
.36271 .88455 L
s
.76476 .32095 m
.76808 .32676 L
s
.44719 .51217 m
.45103 .52432 L
s
.44334 .50049 m
.44719 .51217 L
s
.30694 .68465 m
.31172 .68295 L
s
.56273 .40969 m
.56653 .41841 L
s
.45103 .52432 m
.45463 .54658 L
s
.63277 .33848 m
.6362 .33933 L
s
.34578 .62488 m
.34984 .63316 L
s
.72552 .32626 m
.72895 .33233 L
s
.66144 .3405 m
.66492 .34484 L
s
.36513 .68284 m
.36901 .69404 L
s
.7507 .32254 m
.75387 .32606 L
s
.42404 .44284 m
.42792 .45397 L
s
.64708 .33883 m
.65062 .34346 L
s
.67216 .33457 m
.67549 .3365 L
s
.41992 .43833 m
.42404 .44284 L
s
.57338 .40896 m
.57708 .41174 L
s
.80433 .31919 m
.80756 .32485 L
s
.71112 .32349 m
.71475 .33229 L
s
.1626 .31629 m
.16736 .32116 L
s
.55891 .40024 m
.56273 .40969 L
s
.68277 .32592 m
.68608 .32819 L
s
.50339 .49499 m
.50735 .49204 L
s
.79004 .31786 m
.79329 .32343 L
s
.30093 .58208 m
.30552 .5839 L
s
.34175 .616 m
.34578 .62488 L
s
.6971 .32698 m
.70048 .33133 L
s
.39582 .52834 m
.40294 .46408 L
s
.77587 .318 m
.77899 .32179 L
s
.31156 .57125 m
.31597 .57517 L
s
.844 .31747 m
.84702 .32208 L
s
.73653 .32324 m
.7398 .32746 L
s
.49832 .90001 m
.50224 .90305 L
s
.55507 .38931 m
.55891 .40024 L
s
.76153 .31643 m
.76476 .32095 L
s
.82961 .31524 m
.83278 .32085 L
s
.70781 .31997 m
.71112 .32349 L
s
.72222 .32221 m
.72552 .32626 L
s
.29781 .61985 m
.30247 .62074 L
s
.43143 .99377 m
.43984 .83727 L
s
.55123 .37894 m
.55507 .38931 L
s
.3377 .60721 m
.34175 .616 L
s
.58022 .39522 m
.58383 .39452 L
s
.81542 .31494 m
.81854 .31982 L
s
.58702 .37829 m
.59053 .37371 L
s
.50064 .51843 m
.50444 .53857 L
s
.49677 .50791 m
.50064 .51843 L
s
.40332 .81021 m
.40657 .83911 L
s
.39868 .81853 m
.40332 .81021 L
s
.54741 .37075 m
.55123 .37894 L
s
.65788 .33483 m
.66144 .3405 L
s
.51177 .41714 m
.51578 .3962 L
s
.80114 .31394 m
.80433 .31919 L
s
.52914 .35337 m
.533 .3692 L
s
.52528 .3426 m
.52914 .35337 L
s
.64339 .33078 m
.64708 .33883 L
s
.49242 .54073 m
.49677 .50791 L
s
.45463 .54658 m
.45802 .57992 L
s
.41566 .43723 m
.41992 .43833 L
s
.33359 .59926 m
.3377 .60721 L
s
.59383 .36061 m
.59725 .35397 L
s
.74745 .31829 m
.7507 .32254 L
s
.49959 .47481 m
.50339 .49499 L
s
.49548 .48724 m
.49959 .47481 L
s
.15781 .31139 m
.1626 .31629 L
s
.78686 .3131 m
.79004 .31786 L
s
.52136 .36743 m
.52528 .3426 L
s
.60789 .3481 m
.61166 .35694 L
s
.4083 .4036 m
.41179 .42516 L
s
.40364 .41074 m
.4083 .4036 L
s
.62891 .32628 m
.63277 .33848 L
s
.62542 .325 m
.62891 .32628 L
s
.5696 .40175 m
.57338 .40896 L
s
.69349 .31917 m
.6971 .32698 L
s
.30711 .56751 m
.31156 .57125 L
s
.30204 .68741 m
.30694 .68465 L
s
.54355 .35964 m
.54741 .37075 L
s
.66872 .33093 m
.67216 .33457 L
s
.84089 .31215 m
.844 .31747 L
s
.82653 .31049 m
.82961 .31524 L
s
.77257 .31243 m
.77587 .318 L
s
.35345 .8916 m
.3581 .88805 L
s
.53973 .35498 m
.54355 .35964 L
s
.73311 .31713 m
.73653 .32324 L
s
.29628 .58057 m
.30093 .58208 L
s
.63987 .32728 m
.64339 .33078 L
s
.67947 .32428 m
.68277 .32592 L
s
.32942 .59207 m
.33359 .59926 L
s
.75835 .31273 m
.76153 .31643 L
s
.60411 .33875 m
.60789 .3481 L
s
.48645 .6935 m
.49009 .72529 L
s
.48197 .72715 m
.48645 .6935 L
s
.71871 .3154 m
.72222 .32221 L
s
.81227 .30991 m
.81542 .31494 L
s
.70455 .31755 m
.70781 .31997 L
s
.65432 .32953 m
.65788 .33483 L
s
.5052 .84341 m
.50961 .76737 L
s
.46711 .635 m
.46971 .71958 L
s
.39597 .59689 m
.40347 .52207 L
s
.38366 .75897 m
.38639 .79791 L
s
.79797 .30914 m
.80114 .31394 L
s
.69009 .31519 m
.69349 .31917 L
s
.60067 .34319 m
.60411 .33875 L
s
.56576 .39181 m
.5696 .40175 L
s
.29314 .61862 m
.29781 .61985 L
s
.61501 .34001 m
.61855 .34161 L
s
.15299 .30647 m
.15781 .31139 L
s
.78376 .30948 m
.78686 .3131 L
s
.74412 .31326 m
.74745 .31829 L
s
.32521 .58523 m
.32942 .59207 L
s
.4916 .67249 m
.49592 .6427 L
s
.43791 .46176 m
.44174 .47489 L
s
.43398 .4515 m
.43791 .46176 L
s
.56191 .3813 m
.56576 .39181 L
s
.72972 .31177 m
.73311 .31713 L
s
.83774 .30657 m
.84089 .31215 L
s
.44174 .47489 m
.44552 .49023 L
s
.76925 .3067 m
.77257 .31243 L
s
.57647 .39039 m
.58022 .39522 L
s
.30262 .56393 m
.30711 .56751 L
s
.71526 .30959 m
.71871 .3154 L
s
.82344 .30584 m
.82653 .31049 L
s
.43005 .4412 m
.43398 .4515 L
s
.55806 .37081 m
.56191 .3813 L
s
.41179 .42516 m
.41566 .43723 L
s
.53588 .35101 m
.53973 .35498 L
s
.53199 .33098 m
.53588 .35101 L
s
.52813 .33891 m
.53199 .33098 L
s
.66519 .32569 m
.66872 .33093 L
s
.48928 .59814 m
.49382 .55419 L
s
.80914 .30524 m
.81227 .30991 L
s
.55422 .36206 m
.55806 .37081 L
s
.65067 .32258 m
.65432 .32953 L
s
.42616 .42979 m
.43005 .4412 L
s
.63622 .32075 m
.63987 .32728 L
s
.62209 .32903 m
.62542 .325 L
s
.75512 .30853 m
.75835 .31273 L
s
.46392 .6871 m
.468 .6886 L
s
.44552 .49023 m
.44925 .50799 L
s
.42212 .42223 m
.42616 .42979 L
s
.40657 .83911 m
.40816 .91766 L
s
.32098 .57858 m
.32521 .58523 L
s
.2916 .57922 m
.29628 .58057 L
s
.50231 .45473 m
.50615 .47172 L
s
.49835 .45149 m
.50231 .45473 L
s
.79477 .30408 m
.79797 .30914 L
s
.67605 .32082 m
.67947 .32428 L
s
.49027 .65028 m
.49482 .6036 L
s
.70099 .3105 m
.70455 .31755 L
s
.58336 .3771 m
.58702 .37829 L
s
.68681 .31355 m
.69009 .31519 L
s
.14816 .30153 m
.15299 .30647 L
s
.74075 .30776 m
.74412 .31326 L
s
.55037 .35297 m
.55422 .36206 L
s
.29703 .6912 m
.30204 .68741 L
s
.3938 .83186 m
.39868 .81853 L
s
.83465 .30168 m
.83774 .30657 L
s
.76608 .30296 m
.76925 .3067 L
s
.34876 .89513 m
.35345 .8916 L
s
.72634 .30673 m
.72972 .31177 L
s
.41842 .81983 m
.42554 .73168 L
s
.78049 .30412 m
.78376 .30948 L
s
.71208 .30808 m
.71526 .30959 L
s
.51458 .3933 m
.51856 .38051 L
s
.28844 .61728 m
.29314 .61862 L
s
.57265 .382 m
.57647 .39039 L
s
.41793 .41869 m
.42212 .42223 L
s
.64704 .31616 m
.65067 .32258 L
s
.39107 .32563 m
.39298 .38054 L
s
.38239 .41129 m
.39107 .32563 L
s
.61115 .3285 m
.61501 .34001 L
s
.82034 .3012 m
.82344 .30584 L
s
.63239 .31015 m
.63622 .32075 L
s
.6616 .31964 m
.66519 .32569 L
s
.2981 .5605 m
.30262 .56393 L
s
.44925 .50799 m
.45295 .52769 L
s
.3167 .57223 m
.32098 .57858 L
s
.60757 .32692 m
.61115 .3285 L
s
.5465 .34363 m
.55037 .35297 L
s
.59027 .36268 m
.59383 .36061 L
s
.62918 .31636 m
.63239 .31015 L
s
.45802 .57992 m
.46151 .61107 L
s
.80602 .30077 m
.80914 .30524 L
s
.69749 .30465 m
.70099 .3105 L
s
.39786 .44217 m
.40364 .41074 L
s
.7518 .30348 m
.75512 .30853 L
s
.56881 .37245 m
.57265 .382 L
s
.52459 1.03074 m
.52714 .92588 L
s
.79167 .30032 m
.79477 .30408 L
s
.54267 .34046 m
.5465 .34363 L
s
.49009 .72529 m
.49335 .80018 L
s
.73735 .30213 m
.74075 .30776 L
s
.49394 .48815 m
.49835 .45149 L
s
.1433 .29656 m
.14816 .30153 L
s
.67253 .31583 m
.67605 .32082 L
s
.50507 .4305 m
.50896 .44275 L
s
.50115 .4223 m
.50507 .4305 L
s
.6435 .31243 m
.64704 .31616 L
s
.28687 .57787 m
.2916 .57922 L
s
.59719 .34745 m
.60067 .34319 L
s
.56495 .36257 m
.56881 .37245 L
s
.77714 .29798 m
.78049 .30412 L
s
.83157 .29703 m
.83465 .30168 L
s
.7228 .29956 m
.72634 .30673 L
s
.31239 .56629 m
.3167 .57223 L
s
.49889 1.02164 m
.49708 .87833 L
s
.49097 .52933 m
.49548 .48724 L
s
.39436 .49065 m
.40063 .44869 L
s
.65799 .31354 m
.6616 .31964 L
s
.76288 .29894 m
.76608 .30296 L
s
.41017 .39382 m
.41391 .40973 L
s
.4058 .39328 m
.41017 .39382 L
s
.45295 .52769 m
.45668 .54682 L
s
.68342 .3104 m
.68681 .31355 L
s
.81722 .29646 m
.82034 .3012 L
s
.57958 .3712 m
.58336 .3771 L
s
.41391 .40973 m
.41793 .41869 L
s
.56109 .35291 m
.56495 .36257 L
s
.29353 .55724 m
.2981 .5605 L
s
.69421 .30286 m
.69749 .30465 L
s
.38779 .36866 m
.39011 .41476 L
s
.37888 .45784 m
.38779 .36866 L
s
.49681 .45522 m
.50115 .4223 L
s
.28369 .6162 m
.28844 .61728 L
s
.70858 .30193 m
.71208 .30808 L
s
.80274 .29493 m
.80602 .30077 L
s
.74848 .29857 m
.7518 .30348 L
s
.55723 .34436 m
.56109 .35291 L
s
.49775 .93529 m
.50273 .81547 L
s
.71965 .29824 m
.7228 .29956 L
s
.61832 .32047 m
.62209 .32903 L
s
.73404 .29796 m
.73735 .30213 L
s
.60414 .33202 m
.60757 .32692 L
s
.44013 .44897 m
.44396 .4633 L
s
.43622 .43729 m
.44013 .44897 L
s
.30802 .56075 m
.31239 .56629 L
s
.78842 .29512 m
.79167 .30032 L
s
.34403 .89844 m
.34876 .89513 L
s
.77393 .29365 m
.77714 .29798 L
s
.43229 .42588 m
.43622 .43729 L
s
.13841 .29156 m
.1433 .29656 L
s
.38639 .79791 m
.38962 .82625 L
s
.2919 .69595 m
.29703 .6912 L
s
.66894 .30979 m
.67253 .31583 L
s
.53878 .32922 m
.54267 .34046 L
s
.42836 .4148 m
.43229 .42588 L
s
.65431 .30624 m
.65799 .31354 L
s
.82849 .29247 m
.83157 .29703 L
s
.52421 .35211 m
.52813 .33891 L
s
.44396 .4633 m
.44775 .47956 L
s
.53488 .3183 m
.53878 .32922 L
s
.50787 .40484 m
.51177 .41714 L
s
.50393 .39775 m
.50787 .40484 L
s
.42431 .40712 m
.42836 .4148 L
s
.6396 .30027 m
.6435 .31243 L
s
.63629 .30332 m
.6396 .30027 L
s
.55336 .33475 m
.55723 .34436 L
s
.45668 .54682 m
.46039 .56786 L
s
.57575 .36282 m
.57958 .3712 L
s
.61456 .31294 m
.61832 .32047 L
s
.53103 .33196 m
.53488 .3183 L
s
.75959 .29415 m
.76288 .29894 L
s
.81409 .29187 m
.81722 .29646 L
s
.4694 .631 m
.47314 .65269 L
s
.46535 .62651 m
.4694 .631 L
s
.58655 .3593 m
.59027 .36268 L
s
.28213 .57638 m
.28687 .57787 L
s
.705 .29496 m
.70858 .30193 L
s
.79962 .29074 m
.80274 .29493 L
s
.54951 .32882 m
.55336 .33475 L
s
.28892 .55424 m
.29353 .55724 L
s
.67993 .30579 m
.68342 .3104 L
s
.46094 1.0469 m
.46316 1.00133 L
s
.45028 1.05975 m
.44963 1.04552 L
s
.74509 .29293 m
.74848 .29857 L
s
.44775 .47956 m
.45151 .49748 L
s
.6508 .30281 m
.65431 .30624 L
s
.30362 .55546 m
.30802 .56075 L
s
.57189 .35339 m
.57575 .36282 L
s
.42017 .40134 m
.42431 .40712 L
s
.49962 .43063 m
.50393 .39775 L
s
.66535 .30405 m
.66894 .30979 L
s
.40058 .41174 m
.4058 .39328 L
s
.78508 .28906 m
.78842 .29512 L
s
.69085 .30003 m
.69421 .30286 L
s
.73046 .29024 m
.73404 .29796 L
s
.1335 .28654 m
.13841 .29156 L
s
.61114 .31703 m
.61456 .31294 L
s
.27886 .61575 m
.28369 .6162 L
s
.46151 .61107 m
.46535 .62651 L
s
.77074 .28964 m
.77393 .29365 L
s
.51741 .36865 m
.52136 .36743 L
s
.38962 .82625 m
.3938 .83186 L
s
.62553 .31173 m
.62918 .31636 L
s
.51069 .37763 m
.51458 .3933 L
s
.50669 .37784 m
.51069 .37763 L
s
.56802 .3436 m
.57189 .35339 L
s
.70171 .29251 m
.705 .29496 L
s
.82534 .2873 m
.82849 .29247 L
s
.71621 .29294 m
.71965 .29824 L
s
.59354 .34638 m
.59719 .34745 L
s
.46039 .56786 m
.46393 .59864 L
s
.43233 .87423 m
.43748 .84186 L
s
.45151 .49748 m
.45521 .51867 L
s
.75629 .28944 m
.75959 .29415 L
s
.54563 .32213 m
.54951 .32882 L
s
.8108 .28577 m
.81409 .29187 L
s
.56415 .33491 m
.56802 .3436 L
s
.72728 .2882 m
.73046 .29024 L
s
.47314 .65269 m
.47635 .71038 L
s
.74179 .28877 m
.74509 .29293 L
s
.58274 .35225 m
.58655 .3593 L
s
.29918 .55029 m
.30362 .55546 L
s
.41616 .39167 m
.42017 .40134 L
s
.7964 .28576 m
.79962 .29074 L
s
.48784 .58243 m
.49242 .54073 L
s
.67636 .30007 m
.67993 .30579 L
s
.33929 .90131 m
.34403 .89844 L
s
.78186 .28444 m
.78508 .28906 L
s
.66168 .2969 m
.66535 .30405 L
s
.28425 .55156 m
.28892 .55424 L
s
.27736 .5748 m
.28213 .57638 L
s
.49196 .78526 m
.4966 .72787 L
s
.64699 .29303 m
.6508 .30281 L
s
.12856 .28149 m
.1335 .28654 L
s
.56027 .32588 m
.56415 .33491 L
s
.41223 .37977 m
.41616 .39167 L
s
.54171 .30834 m
.54563 .32213 L
s
.53786 .31357 m
.54171 .30834 L
s
.47717 .77379 m
.48197 .72715 L
s
.40779 .3803 m
.41223 .37977 L
s
.28666 .70147 m
.2919 .69595 L
s
.51351 .35075 m
.51741 .36865 L
s
.50944 .36479 m
.51351 .35075 L
s
.62168 .3015 m
.62553 .31173 L
s
.76747 .28491 m
.77074 .28964 L
s
.8222 .28249 m
.82534 .2873 L
s
.48731 .6911 m
.4916 .67249 L
s
.68739 .29568 m
.69085 .30003 L
s
.60056 .33288 m
.60414 .33202 L
s
.64349 .29095 m
.64699 .29303 L
s
.71262 .28563 m
.71621 .29294 L
s
.47619 .79813 m
.47904 .88772 L
s
.80766 .28125 m
.8108 .28577 L
s
.57888 .3434 m
.58274 .35225 L
s
.43853 .42117 m
.44244 .43394 L
s
.4346 .40934 m
.43853 .42117 L
s
.63278 .30171 m
.63629 .30332 L
s
.43061 .39907 m
.4346 .40934 L
s
.5564 .31818 m
.56027 .32588 L
s
.44244 .43394 m
.44629 .44864 L
s
.61821 .30289 m
.62168 .3015 L
s
.27391 .61628 m
.27886 .61575 L
s
.65814 .29274 m
.66168 .2969 L
s
.7529 .28369 m
.75629 .28944 L
s
.29471 .5453 m
.29918 .55029 L
s
.69837 .28977 m
.70171 .29251 L
s
.67278 .29439 m
.67636 .30007 L
s
.45521 .51867 m
.45885 .54396 L
s
.42655 .39102 m
.43061 .39907 L
s
.79308 .27983 m
.7964 .28576 L
s
.73824 .28139 m
.74179 .28877 L
s
.44629 .44864 m
.4501 .46554 L
s
.50239 .41243 m
.50669 .37784 L
s
.575 .33399 m
.57888 .3434 L
s
.77867 .2803 m
.78186 .28444 L
s
.58976 .34084 m
.59354 .34638 L
s
.1236 .27642 m
.12856 .28149 L
s
.70928 .28238 m
.71262 .28563 L
s
.72389 .28358 m
.72728 .2882 L
s
.27953 .54911 m
.28425 .55156 L
s
.55254 .31248 m
.5564 .31818 L
s
.39228 .32639 m
.39601 .34302 L
s
.38431 .39698 m
.39228 .32639 L
s
.27254 .57329 m
.27736 .5748 L
s
.57113 .32515 m
.575 .33399 L
s
.60763 .3193 m
.61114 .31703 L
s
.76417 .2801 m
.76747 .28491 L
s
.42246 .38317 m
.42655 .39102 L
s
.38753 .44268 m
.38984 .49076 L
s
.38315 .43978 m
.38753 .44268 L
s
.81893 .27648 m
.8222 .28249 L
s
.68384 .29017 m
.68739 .29568 L
s
.4501 .46554 m
.45385 .48507 L
s
.33302 .62058 m
.33693 .63313 L
s
.32905 .60889 m
.33302 .62058 L
s
.33693 .63313 m
.34078 .64694 L
s
.74959 .27926 m
.7529 .28369 L
s
.80447 .27642 m
.80766 .28125 L
s
.73499 .27829 m
.73824 .28139 L
s
.32504 .59795 m
.32905 .60889 L
s
.33455 .90354 m
.33929 .90131 L
s
.29019 .54065 m
.29471 .5453 L
s
.66912 .28752 m
.67278 .29439 L
s
.78986 .27509 m
.79308 .27983 L
s
.34078 .64694 m
.34452 .66256 L
s
.32097 .58772 m
.32504 .59795 L
s
.65441 .28483 m
.65814 .29274 L
s
.52028 .34064 m
.52421 .35211 L
s
.56725 .31638 m
.57113 .32515 L
s
.64005 .29095 m
.64349 .29095 L
s
.39601 .34302 m
.39879 .38137 L
s
.46393 .59864 m
.46734 .63884 L
s
.51633 .33076 m
.52028 .34064 L
s
.40296 .3892 m
.40779 .3803 L
s
.58592 .33287 m
.58976 .34084 L
s
.50495 1.01509 m
.50354 .89681 L
s
.41844 .37301 m
.42246 .38317 L
s
.62892 .29156 m
.63278 .30171 L
s
.31684 .57822 m
.32097 .58772 L
s
.69492 .28558 m
.69837 .28977 L
s
.52709 .33007 m
.53103 .33196 L
s
.54861 .30107 m
.55254 .31248 L
s
.7754 .27552 m
.77867 .2803 L
s
.48296 .9076 m
.48779 .84905 L
s
.11861 .27132 m
.1236 .27642 L
s
.34452 .66256 m
.34818 .67983 L
s
.26882 .61799 m
.27391 .61628 L
s
.59683 .32889 m
.60056 .33288 L
s
.72031 .27633 m
.72389 .28358 L
s
.54474 .29883 m
.54861 .30107 L
s
.5122 .35757 m
.51633 .33076 L
s
.39011 .41476 m
.39296 .45122 L
s
.41433 .36533 m
.41844 .37301 L
s
.8158 .27195 m
.81893 .27648 L
s
.62535 .2897 m
.62892 .29156 L
s
.39298 .38054 m
.39593 .41507 L
s
.56336 .30817 m
.56725 .31638 L
s
.31266 .5694 m
.31684 .57822 L
s
.65079 .27967 m
.65441 .28483 L
s
.28133 .70746 m
.28666 .70147 L
s
.70595 .27961 m
.70928 .28238 L
s
.66555 .28264 m
.66912 .28752 L
s
.27478 .54673 m
.27953 .54911 L
s
.45885 .54396 m
.46248 .57118 L
s
.76078 .27431 m
.76417 .2801 L
s
.68026 .28443 m
.68384 .29017 L
s
.45385 .48507 m
.45757 .50713 L
s
.61475 .30588 m
.61821 .30289 L
s
.58205 .32393 m
.58592 .33287 L
s
.53396 .31655 m
.53786 .31357 L
s
.28561 .53641 m
.29019 .54065 L
s
.80116 .27054 m
.80447 .27642 L
s
.39296 .45122 m
.39786 .44217 L
s
.3724 .56385 m
.38315 .43978 L
s
.74608 .27236 m
.74959 .27926 L
s
.26767 .57214 m
.27254 .57329 L
s
.52315 .31184 m
.52709 .33007 L
s
.51915 .32406 m
.52315 .31184 L
s
.48475 .63015 m
.48928 .59814 L
s
.40368 .7799 m
.41099 .70177 L
s
.44091 .40358 m
.44484 .41663 L
s
.43695 .3919 m
.44091 .40358 L
s
.34818 .67983 m
.35183 .6975 L
s
.78667 .27083 m
.78986 .27509 L
s
.30843 .56114 m
.31266 .5694 L
s
.43293 .38192 m
.43695 .3919 L
s
.44484 .41663 m
.44871 .43141 L
s
.73164 .27404 m
.73499 .27829 L
s
.55949 .30215 m
.56336 .30817 L
s
.39855 .31605 m
.40171 .34636 L
s
.39286 .34111 m
.39855 .31605 L
s
.40983 .3667 m
.41433 .36533 L
s
.71694 .2724 m
.72031 .27633 L
s
.57816 .31505 m
.58205 .32393 L
s
.11359 .2662 m
.11861 .27132 L
s
.42887 .37317 m
.43293 .38192 L
s
.39593 .41507 m
.40058 .41174 L
s
.77211 .27057 m
.7754 .27552 L
s
.44871 .43141 m
.45254 .44875 L
s
.69138 .2802 m
.69492 .28558 L
s
.384 .49088 m
.38723 .51898 L
s
.37459 .59056 m
.384 .49088 L
s
.3903 .55165 m
.39582 .52834 L
s
.3298 .90516 m
.33455 .90354 L
s
.30416 .55335 m
.30843 .56114 L
s
.75747 .26966 m
.76078 .27431 L
s
.59301 .32187 m
.59683 .32889 L
s
.67662 .27785 m
.68026 .28443 L
s
.81262 .2671 m
.8158 .27195 L
s
.64739 .28001 m
.65079 .27967 L
s
.60395 .31664 m
.60763 .3193 L
s
.48574 .68392 m
.49027 .65028 L
s
.74279 .26853 m
.74608 .27236 L
s
.35183 .6975 m
.35549 .71521 L
s
.66186 .27569 m
.66555 .28264 L
s
.4088 1.01836 m
.40816 .91766 L
s
.57428 .30643 m
.57816 .31505 L
s
.48939 .52504 m
.49394 .48815 L
s
.79794 .26565 m
.80116 .27054 L
s
.63623 .28194 m
.64005 .29095 L
s
.54087 .30227 m
.54474 .29883 L
s
.4248 .36405 m
.42887 .37317 L
s
.28098 .53249 m
.28561 .53641 L
s
.48263 .80292 m
.48475 .96877 L
s
.26999 .54436 m
.27478 .54673 L
s
.45757 .50713 m
.46126 .53169 L
s
.4923 .49222 m
.49681 .45522 L
s
.46971 .71958 m
.47295 .77587 L
s
.70252 .27548 m
.70595 .27961 L
s
.62192 .29282 m
.62535 .2897 L
s
.55557 .29263 m
.55949 .30215 L
s
.45254 .44875 m
.45632 .46831 L
s
.50516 .39815 m
.50944 .36479 L
s
.78341 .26599 m
.78667 .27083 L
s
.29983 .54602 m
.30416 .55335 L
s
.26359 .62083 m
.26882 .61799 L
s
.72807 .26698 m
.73164 .27404 L
s
.57039 .29822 m
.57428 .30643 L
s
.63258 .27743 m
.63623 .28194 L
s
.35549 .71521 m
.35902 .73588 L
s
.42072 .35503 m
.4248 .36405 L
s
.58914 .31337 m
.59301 .32187 L
s
.2627 .57165 m
.26767 .57214 L
s
.71362 .26952 m
.71694 .2724 L
s
.55167 .28703 m
.55557 .29263 L
s
.10855 .26104 m
.11359 .2662 L
s
.68781 .27446 m
.69138 .2802 L
s
.48304 .7018 m
.48731 .6911 L
s
.67303 .27257 m
.67662 .27785 L
s
.76873 .26485 m
.77211 .27057 L
s
.65819 .26927 m
.66186 .27569 L
s
.52999 .30072 m
.53396 .31655 L
s
.52603 .29821 m
.52999 .30072 L
s
.46248 .57118 m
.46617 .59761 L
s
.48642 .56272 m
.49097 .52933 L
s
.80932 .26122 m
.81262 .2671 L
s
.75398 .26311 m
.75747 .26966 L
s
.38984 .49076 m
.39436 .49065 L
s
.49335 .80018 m
.49686 .86482 L
s
.41644 .35101 m
.42072 .35503 L
s
.29545 .53916 m
.29983 .54602 L
s
.79475 .26129 m
.79794 .26565 L
s
.56651 .29169 m
.57039 .29822 L
s
.73946 .26439 m
.74279 .26853 L
s
.27593 .71357 m
.28133 .70746 L
s
.61111 .30423 m
.61475 .30588 L
s
.58525 .30466 m
.58914 .31337 L
s
.27631 .52873 m
.28098 .53249 L
s
.60014 .31043 m
.60395 .31664 L
s
.72468 .26255 m
.72807 .26698 L
s
.42792 .87723 m
.43233 .87423 L
s
.4054 .36557 m
.40983 .3667 L
s
.45632 .46831 m
.46006 .49079 L
s
.39879 .38137 m
.40296 .3892 L
s
.44336 .38446 m
.44731 .39738 L
s
.43937 .37313 m
.44336 .38446 L
s
.32504 .90634 m
.3298 .90516 L
s
.69899 .27019 m
.70252 .27548 L
s
.44731 .39738 m
.45122 .41206 L
s
.78012 .26098 m
.78341 .26599 L
s
.26516 .54215 m
.26999 .54436 L
s
.43532 .3632 m
.43937 .37313 L
s
.65478 .26904 m
.65819 .26927 L
s
.49516 .46501 m
.49962 .43063 L
s
.35902 .73588 m
.3622 .76394 L
s
.54782 .28867 m
.55167 .28703 L
s
.68418 .2681 m
.68781 .27446 L
s
.58136 .29617 m
.58525 .30466 L
s
.62917 .28021 m
.63258 .27743 L
s
.76542 .26005 m
.76873 .26485 L
s
.6436 .27201 m
.64739 .28001 L
s
.66937 .2661 m
.67303 .27257 L
s
.50085 .88234 m
.5052 .84341 L
s
.45122 .41206 m
.45508 .42884 L
s
.38723 .51898 m
.3903 .55165 L
s
.75067 .25885 m
.75398 .26311 L
s
.29103 .53273 m
.29545 .53916 L
s
.46126 .53169 m
.46492 .55953 L
s
.43125 .35385 m
.43532 .3632 L
s
.47635 .71038 m
.47949 .78112 L
s
.8061 .2562 m
.80932 .26122 L
s
.46734 .63884 m
.47089 .67563 L
s
.40171 .34636 m
.4054 .36557 L
s
.56259 .28311 m
.56651 .29169 L
s
.71019 .26539 m
.71362 .26952 L
s
.59628 .30244 m
.60014 .31043 L
s
.52201 .3218 m
.52603 .29821 L
s
.25762 .57198 m
.2627 .57165 L
s
.41207 .34862 m
.41644 .35101 L
s
.57747 .28805 m
.58136 .29617 L
s
.7915 .25642 m
.79475 .26129 L
s
.2078 .26967 m
.21171 .28257 L
s
.20346 .26039 m
.2078 .26967 L
s
.42717 .34454 m
.43125 .35385 L
s
.42415 .85806 m
.42792 .87723 L
s
.41988 .85502 m
.42415 .85806 L
s
.19689 .28005 m
.20035 .2969 L
s
.1929 .26777 m
.19689 .28005 L
s
.7359 .25749 m
.73946 .26439 L
s
.21171 .28257 m
.21511 .30022 L
s
.63989 .26591 m
.6436 .27201 L
s
.1885 .2589 m
.1929 .26777 L
s
.45508 .42884 m
.45889 .44834 L
s
.22256 .27274 m
.22631 .28719 L
s
.21835 .26242 m
.22256 .27274 L
s
.53689 .29024 m
.54087 .30227 L
s
.27161 .52504 m
.27631 .52873 L
s
.25825 .6245 m
.26359 .62083 L
s
.72136 .25951 m
.72468 .26255 L
s
.53292 .27848 m
.53689 .29024 L
s
.69543 .26449 m
.69899 .27019 L
s
.61832 .29187 m
.62192 .29282 L
s
.55868 .27659 m
.56259 .28311 L
s
.68059 .26263 m
.68418 .2681 L
s
.52898 .29793 m
.53292 .27848 L
s
.39053 .61827 m
.39597 .59689 L
s
.40442 .31612 m
.40807 .33661 L
s
.39977 .31889 m
.40442 .31612 L
s
.66568 .25936 m
.66937 .2661 L
s
.77676 .25532 m
.78012 .26098 L
s
.17786 .26699 m
.18178 .27984 L
s
.17347 .25782 m
.17786 .26699 L
s
.28655 .5267 m
.29103 .53273 L
s
.39467 .70208 m
.40099 .65711 L
s
.22631 .28719 m
.22954 .30671 L
s
.51502 .35063 m
.51915 .32406 L
s
.18178 .27984 m
.18513 .29743 L
s
.21383 .25485 m
.21835 .26242 L
s
.46617 .59761 m
.46989 .62431 L
s
.23716 .27738 m
.24068 .29428 L
s
.23315 .26528 m
.23716 .27738 L
s
.46006 .49079 m
.46377 .51614 L
s
.60733 .29877 m
.61111 .30423 L
s
.22877 .25665 m
.23315 .26528 L
s
.42298 .33814 m
.42717 .34454 L
s
.19884 .25341 m
.20346 .26039 L
s
.5924 .294 m
.59628 .30244 L
s
.76195 .25369 m
.76542 .26005 L
s
.57358 .28113 m
.57747 .28805 L
s
.26026 .54036 m
.26516 .54215 L
s
.18381 .25217 m
.1885 .2589 L
s
.80291 .25173 m
.8061 .2562 L
s
.20035 .2969 m
.20323 .31893 L
s
.24782 .26951 m
.25156 .2843 L
s
.24363 .25913 m
.24782 .26951 L
s
.74735 .25463 m
.75067 .25885 L
s
.32026 .90727 m
.32504 .90634 L
s
.16876 .25102 m
.17347 .25782 L
s
.21511 .30022 m
.21796 .32303 L
s
.16255 .26815 m
.16612 .2838 L
s
.15836 .25728 m
.16255 .26815 L
s
.7325 .2528 m
.7359 .25749 L
s
.70668 .26015 m
.71019 .26539 L
s
.63648 .26809 m
.63989 .26591 L
s
.22415 .25006 m
.22877 .25665 L
s
.23913 .25162 m
.24363 .25913 L
s
.48337 .60559 m
.48784 .58243 L
s
.25156 .2843 m
.25481 .30443 L
s
.24068 .29428 m
.2437 .31641 L
s
.45889 .44834 m
.46267 .4704 L
s
.55482 .27603 m
.55868 .27659 L
s
.44587 .36389 m
.44985 .3764 L
s
.44184 .35293 m
.44587 .36389 L
s
.1537 .24989 m
.15836 .25728 L
s
.58851 .28561 m
.5924 .294 L
s
.65103 .26176 m
.65478 .26904 L
s
.44985 .3764 m
.45379 .39054 L
s
.78821 .25134 m
.7915 .25642 L
s
.20912 .24877 m
.21383 .25485 L
s
.66226 .25833 m
.66568 .25936 L
s
.18513 .29743 m
.18787 .32035 L
s
.12857 .25273 m
.12401 .32561 L
s
.69181 .25825 m
.69543 .26449 L
s
.41294 .93246 m
.41988 .85502 L
s
.28202 .52097 m
.28655 .5267 L
s
.25837 .26283 m
.2623 .27591 L
s
.25406 .25374 m
.25837 .26283 L
s
.2705 .7195 m
.27593 .71357 L
s
.53984 .26277 m
.54385 .27888 L
s
.53595 .27857 m
.53984 .26277 L
s
.67694 .25625 m
.68059 .26263 L
s
.19406 .2476 m
.19884 .25341 L
s
.2623 .27591 m
.26573 .29432 L
s
.3622 .76394 m
.36509 .79894 L
s
.43778 .34288 m
.44184 .35293 L
s
.26686 .52151 m
.27161 .52504 L
s
.77344 .2504 m
.77676 .25532 L
s
.4187 .33338 m
.42298 .33814 L
s
.47883 .70487 m
.48304 .7018 L
s
.16612 .2838 m
.16899 .30502 L
s
.45379 .39054 m
.45769 .40675 L
s
.40807 .33661 m
.41207 .34862 L
s
.56967 .27299 m
.57358 .28113 L
s
.54385 .27888 m
.54782 .28867 L
s
.22954 .30671 m
.23229 .33117 L
s
.75864 .24921 m
.76195 .25369 L
s
.60348 .29125 m
.60733 .29877 L
s
.17898 .24649 m
.18381 .25217 L
s
.71794 .25532 m
.72136 .25951 L
s
.14306 .25797 m
.14634 .27565 L
s
.13865 .24854 m
.14306 .25797 L
s
.25243 .57308 m
.25762 .57198 L
s
.47295 .77587 m
.47717 .77379 L
s
.46492 .55953 m
.46859 .58907 L
s
.498 .44136 m
.50239 .41243 L
s
.6256 .27962 m
.62917 .28021 L
s
.16388 .24541 m
.16876 .25102 L
s
.4337 .33328 m
.43778 .34288 L
s
.27294 .2686 m
.27654 .2855 L
s
.26888 .25692 m
.27294 .2686 L
s
.58461 .27761 m
.58851 .28561 L
s
.2495 .24696 m
.25406 .25374 L
s
.23447 .24558 m
.23913 .25162 L
s
.26448 .24878 m
.26888 .25692 L
s
.14876 .24434 m
.1537 .24989 L
s
.64729 .25491 m
.65103 .26176 L
s
.45769 .40675 m
.46155 .42528 L
s
.61457 .28698 m
.61832 .29187 L
s
.2194 .2444 m
.22415 .25006 L
s
.79967 .2468 m
.80291 .25173 L
s
.7438 .24785 m
.74735 .25463 L
s
.38746 .5847 m
.39053 .61827 L
s
.38324 .57705 m
.38746 .5847 L
s
.50797 .38374 m
.5122 .35757 L
s
.70312 .25447 m
.70668 .26015 L
s
.25526 .53915 m
.26026 .54036 L
s
.56576 .26651 m
.56967 .27299 L
s
.72918 .24957 m
.7325 .2528 L
s
.20431 .24329 m
.20912 .24877 L
s
.42954 .32585 m
.4337 .33328 L
s
.68822 .25268 m
.69181 .25825 L
s
.20323 .31893 m
.2056 .3459 L
s
.27746 .51544 m
.28202 .52097 L
s
.5996 .28304 m
.60348 .29125 L
s
.67326 .24975 m
.67694 .25625 L
s
.46377 .51614 m
.46749 .54289 L
s
.26573 .29432 m
.26869 .31818 L
s
.25481 .30443 m
.25762 .32941 L
s
.28354 .26204 m
.28727 .2776 L
s
.27937 .25152 m
.28354 .26204 L
s
.78486 .24572 m
.78821 .25134 L
s
.1892 .24222 m
.19406 .2476 L
s
.25282 .62849 m
.25825 .6245 L
s
.46989 .62431 m
.47362 .6525 L
s
.14634 .27565 m
.14858 .30116 L
s
.21796 .32303 m
.22039 .35024 L
s
.27654 .2855 m
.27963 .30835 L
s
.58072 .27045 m
.58461 .27761 L
s
.31544 .90805 m
.32026 .90727 L
s
.46267 .4704 m
.46643 .4948 L
s
.76999 .24409 m
.77344 .2504 L
s
.41462 .32324 m
.4187 .33338 L
s
.25989 .2425 m
.26448 .24878 L
s
.17407 .24117 m
.17898 .24649 L
s
.38595 .38892 m
.39286 .34111 L
s
.2437 .31641 m
.24635 .34266 L
s
.27492 .24409 m
.27937 .25152 L
s
.39397 .34541 m
.39977 .31889 L
s
.26206 .51825 m
.26686 .52151 L
s
.41068 .30908 m
.41462 .32324 L
s
.40623 .30731 m
.41068 .30908 L
s
.24481 .24124 m
.2495 .24696 L
s
.54681 .2494 m
.55085 .26699 L
s
.54297 .26277 m
.54681 .2494 L
s
.37283 .69888 m
.38324 .57705 L
s
.16899 .30502 m
.17118 .33201 L
s
.75531 .24478 m
.75864 .24921 L
s
.28727 .2776 m
.29048 .29948 L
s
.15892 .24012 m
.16388 .24541 L
s
.18787 .32035 m
.19003 .34846 L
s
.41235 .86885 m
.41842 .81983 L
s
.64388 .25639 m
.64729 .25491 L
s
.22971 .24011 m
.23447 .24558 L
s
.48039 .64263 m
.48475 .63015 L
s
.46155 .42528 m
.46537 .4464 L
s
.48735 .8252 m
.49196 .78526 L
s
.71444 .25009 m
.71794 .25532 L
s
.47089 .67563 m
.47474 .69773 L
s
.59571 .2748 m
.5996 .28304 L
s
.7404 .24309 m
.7438 .24785 L
s
.29412 .25601 m
.29797 .27035 L
s
.28987 .24645 m
.29412 .25601 L
s
.42533 .31914 m
.42954 .32585 L
s
.65852 .25138 m
.66226 .25833 L
s
.55085 .26699 m
.55482 .27603 L
s
.31251 .57897 m
.31647 .59196 L
s
.30847 .56704 m
.31251 .57897 L
s
.45245 .35383 m
.45643 .36728 L
s
.44843 .3421 m
.45245 .35383 L
s
.21459 .23904 m
.2194 .2444 L
s
.56189 .26408 m
.56576 .26651 L
s
.31647 .59196 m
.32037 .60611 L
s
.30436 .55608 m
.30847 .56704 L
s
.44438 .33134 m
.44843 .3421 L
s
.61073 .27984 m
.61457 .28698 L
s
.45643 .36728 m
.46037 .38255 L
s
.79638 .24163 m
.79967 .2468 L
s
.69951 .24829 m
.70312 .25447 L
s
.27286 .51008 m
.27746 .51544 L
s
.66981 .24787 m
.67326 .24975 L
s
.29797 .27035 m
.3013 .29128 L
s
.19945 .23798 m
.20431 .24329 L
s
.68457 .24624 m
.68822 .25268 L
s
.5768 .26257 m
.58072 .27045 L
s
.30018 .54596 m
.30436 .55608 L
s
.32037 .60611 m
.32417 .62168 L
s
.23229 .33117 m
.23475 .35889 L
s
.63294 .26745 m
.63648 .26809 L
s
.28538 .23956 m
.28987 .24645 L
s
.78155 .24068 m
.78486 .24572 L
s
.44029 .32155 m
.44438 .33134 L
s
.27031 .23812 m
.27492 .24409 L
s
.18429 .23693 m
.1892 .24222 L
s
.47474 .69773 m
.47883 .70487 L
s
.76668 .23958 m
.76999 .24409 L
s
.2552 .23694 m
.25989 .2425 L
s
.62187 .27505 m
.6256 .27962 L
s
.24716 .57457 m
.25243 .57308 L
s
.46037 .38255 m
.46427 .40003 L
s
.72577 .24525 m
.72918 .24957 L
s
.59181 .26695 m
.59571 .2748 L
s
.3047 .25038 m
.30865 .26359 L
s
.30039 .24161 m
.3047 .25038 L
s
.29594 .53654 m
.30018 .54596 L
s
.48145 .69224 m
.48574 .68392 L
s
.16912 .23588 m
.17407 .24117 L
s
.30865 .26359 m
.31209 .28351 L
s
.32417 .62168 m
.32788 .63893 L
s
.2502 .53839 m
.25526 .53915 L
s
.26505 .72493 m
.2705 .7195 L
s
.24007 .23585 m
.24481 .24124 L
s
.43615 .31337 m
.44029 .32155 L
s
.42123 .30926 m
.42533 .31914 L
s
.65476 .24428 m
.65852 .25138 L
s
.22492 .23479 m
.22971 .24011 L
s
.25721 .51528 m
.26206 .51825 L
s
.60685 .27186 m
.61073 .27984 L
s
.5729 .25639 m
.5768 .26257 L
s
.75177 .23806 m
.75531 .24478 L
s
.26869 .31818 m
.27136 .34577 L
s
.27963 .30835 m
.28234 .33608 L
s
.71088 .24437 m
.71444 .25009 L
s
.29164 .52769 m
.29594 .53654 L
s
.46859 .58907 m
.47234 .61655 L
s
.46537 .4464 m
.46917 .46981 L
s
.73709 .23964 m
.7404 .24309 L
s
.47904 .88772 m
.48296 .9076 L
s
.3106 .90873 m
.31544 .90805 L
s
.69593 .24268 m
.69951 .24829 L
s
.20975 .23373 m
.21459 .23904 L
s
.25762 .32941 m
.26024 .35696 L
s
.29587 .23511 m
.30039 .24161 L
s
.41714 .29877 m
.42123 .30926 L
s
.26822 .50487 m
.27286 .51008 L
s
.68092 .24024 m
.68457 .24624 L
s
.29048 .29948 m
.29324 .32739 L
s
.46643 .4948 m
.47019 .52072 L
s
.28076 .2338 m
.28538 .23956 L
s
.31933 .25719 m
.32288 .276 L
s
.31529 .24503 m
.31933 .25719 L
s
.46749 .54289 m
.47125 .56945 L
s
.40116 .31884 m
.40623 .30731 L
s
.46427 .40003 m
.46813 .41987 L
s
.58791 .25966 m
.59181 .26695 L
s
.36509 .79894 m
.36809 .83288 L
s
.79304 .23604 m
.79638 .24163 L
s
.31093 .23692 m
.31529 .24503 L
s
.32788 .63893 m
.33149 .65805 L
s
.19457 .23268 m
.19945 .23798 L
s
.2056 .3459 m
.20764 .37641 L
s
.26562 .23266 m
.27031 .23812 L
s
.14858 .30116 m
.14994 .33383 L
s
.43199 .30512 m
.43615 .31337 L
s
.37269 .51083 m
.38239 .41129 L
s
.3013 .29128 m
.3041 .31929 L
s
.41273 .29591 m
.41714 .29877 L
s
.47362 .6525 m
.47743 .67825 L
s
.7781 .23437 m
.78155 .24068 L
s
.28731 .51927 m
.29164 .52769 L
s
.48499 .54097 m
.48939 .52504 L
s
.17937 .23162 m
.18429 .23693 L
s
.55791 .25492 m
.56189 .26408 L
s
.25046 .23159 m
.2552 .23694 L
s
.24736 .63225 m
.25282 .62849 L
s
.55386 .23919 m
.55791 .25492 L
s
.55004 .24952 m
.55386 .23919 L
s
.24635 .34266 m
.24891 .37032 L
s
.60296 .26376 m
.60685 .27186 L
s
.22039 .35024 m
.22263 .37971 L
s
.65136 .24516 m
.65476 .24428 L
s
.76334 .23486 m
.76668 .23958 L
s
.50086 .41849 m
.50516 .39815 L
s
.45911 .343 m
.46309 .35708 L
s
.45509 .3306 m
.45911 .343 L
s
.61804 .26814 m
.62187 .27505 L
s
.45104 .31933 m
.45509 .3306 L
s
.23528 .23052 m
.24007 .23585 L
s
.31209 .28351 m
.31496 .31143 L
s
.72227 .23997 m
.72577 .24525 L
s
.66607 .24084 m
.66981 .24787 L
s
.33001 .25106 m
.33368 .26863 L
s
.32589 .23989 m
.33001 .25106 L
s
.74839 .23339 m
.75177 .23806 L
s
.48791 .50932 m
.4923 .49222 L
s
.17118 .33201 m
.17277 .36435 L
s
.48206 .57388 m
.48642 .56272 L
s
.44695 .30931 m
.45104 .31933 L
s
.56901 .25246 m
.5729 .25639 L
s
.46309 .35708 m
.46704 .37318 L
s
.64034 .25554 m
.64388 .25639 L
s
.3064 .23072 m
.31093 .23692 L
s
.22009 .22947 m
.22492 .23479 L
s
.3215 .23234 m
.32589 .23989 L
s
.70729 .23826 m
.71088 .24437 L
s
.584 .25201 m
.58791 .25966 L
s
.42787 .29531 m
.43199 .30512 L
s
.29126 .22948 m
.29587 .23511 L
s
.19003 .34846 m
.19178 .38073 L
s
.62922 .26304 m
.63294 .26745 L
s
.28292 .51124 m
.28731 .51927 L
s
.52494 .3134 m
.52898 .29793 L
s
.69227 .23618 m
.69593 .24268 L
s
.67744 .23746 m
.68092 .24024 L
s
.32288 .276 m
.32584 .30346 L
s
.33149 .65805 m
.33499 .67936 L
s
.26355 .49984 m
.26822 .50487 L
s
.20488 .22841 m
.20975 .23373 L
s
.2523 .51246 m
.25721 .51528 L
s
.27609 .22838 m
.28076 .2338 L
s
.59907 .25601 m
.60296 .26376 L
s
.46813 .41987 m
.47198 .44198 L
s
.44282 .30026 m
.44695 .30931 L
s
.49686 .86482 m
.50085 .88234 L
s
.24509 .53764 m
.2502 .53839 L
s
.5179 .33814 m
.52201 .3218 L
s
.78973 .23087 m
.79304 .23604 L
s
.24186 .5759 m
.24716 .57457 L
s
.18965 .22735 m
.19457 .23268 L
s
.77481 .22992 m
.7781 .23437 L
s
.46704 .37318 m
.47095 .39152 L
s
.2609 .22731 m
.26562 .23266 L
s
.4237 .28681 m
.42787 .29531 L
s
.34071 .24515 m
.3445 .26132 L
s
.33653 .23491 m
.34071 .24515 L
s
.73367 .23515 m
.73709 .23964 L
s
.23475 .35889 m
.23724 .38687 L
s
.61416 .26033 m
.61804 .26814 L
s
.33368 .26863 m
.33677 .2951 L
s
.46917 .46981 m
.47298 .49454 L
s
.53198 .29169 m
.53595 .27857 L
s
.66233 .23395 m
.66607 .24084 L
s
.2457 .22624 m
.25046 .23159 L
s
.30573 .90936 m
.3106 .90873 L
s
.27849 .50355 m
.28292 .51124 L
s
.5801 .24607 m
.584 .25201 L
s
.31697 .22636 m
.3215 .23234 L
s
.33211 .22783 m
.33653 .23491 L
s
.43869 .29089 m
.44282 .30026 L
s
.23047 .22518 m
.23528 .23052 L
s
.75982 .22818 m
.76334 .23486 L
s
.71872 .23422 m
.72227 .23997 L
s
.40809 .29789 m
.41273 .29591 L
s
.47913 .60691 m
.48337 .60559 L
s
.3018 .22517 m
.3064 .23072 L
s
.38725 .66133 m
.39081 .68486 L
s
.37898 .74254 m
.38725 .66133 L
s
.49081 .47944 m
.49516 .46501 L
s
.3445 .26132 m
.34775 .28616 L
s
.59517 .24863 m
.59907 .25601 L
s
.2596 .72964 m
.26505 .72493 L
s
.70371 .23263 m
.70729 .23826 L
s
.36769 .58542 m
.37888 .45784 L
s
.47019 .52072 m
.47401 .54583 L
s
.47234 .61655 m
.47626 .63656 L
s
.74507 .2297 m
.74839 .23339 L
s
.41936 .28225 m
.4237 .28681 L
s
.68866 .23067 m
.69227 .23618 L
s
.21524 .22412 m
.22009 .22947 L
s
.35143 .23943 m
.35533 .25407 L
s
.34719 .23007 m
.35143 .23943 L
s
.2866 .22408 m
.29126 .22948 L
s
.47125 .56945 m
.47511 .59264 L
s
.47626 .63656 m
.48039 .64263 L
s
.27136 .34577 m
.27401 .37414 L
s
.51084 .36541 m
.51502 .35063 L
s
.47743 .67825 m
.48145 .69224 L
s
.56502 .24288 m
.56901 .25246 L
s
.25883 .49493 m
.26355 .49984 L
s
.28234 .33608 m
.2849 .36619 L
s
.46181 .31835 m
.46583 .3313 L
s
.45775 .30674 m
.46181 .31835 L
s
.47095 .39152 m
.47484 .41218 L
s
.61027 .25242 m
.61416 .26033 L
s
.43456 .28129 m
.43869 .29089 L
s
.46583 .3313 m
.46983 .34589 L
s
.6254 .25635 m
.62922 .26304 L
s
.19999 .22306 m
.20488 .22841 L
s
.33499 .67936 m
.33837 .70315 L
s
.27138 .22301 m
.27609 .22838 L
s
.26024 .35696 m
.26298 .38386 L
s
.27403 .4961 m
.27849 .50355 L
s
.45367 .29628 m
.45775 .30674 L
s
.35533 .25407 m
.35877 .27662 L
s
.29324 .32739 m
.29571 .35943 L
s
.78629 .2246 m
.78973 .23087 L
s
.65892 .23428 m
.66233 .23395 L
s
.25615 .22195 m
.2609 .22731 L
s
.24739 .50945 m
.2523 .51246 L
s
.46983 .34589 m
.47379 .36252 L
s
.34276 .22336 m
.34719 .23007 L
s
.53903 .27273 m
.54297 .26277 L
s
.47198 .44198 m
.47583 .46552 L
s
.32758 .222 m
.33211 .22783 L
s
.67369 .23014 m
.67744 .23746 L
s
.64782 .24391 m
.65136 .24516 L
s
.77145 .22485 m
.77481 .22992 L
s
.561 .23175 m
.56502 .24288 L
s
.73018 .22981 m
.73367 .23515 L
s
.63663 .25118 m
.64034 .25554 L
s
.44956 .28633 m
.45367 .29628 L
s
.3041 .31929 m
.3065 .3533 L
s
.43037 .27324 m
.43456 .28129 L
s
.24191 .63534 m
.24736 .63225 L
s
.2409 .22088 m
.2457 .22624 L
s
.57619 .24081 m
.5801 .24607 L
s
.75646 .22368 m
.75982 .22818 L
s
.59125 .24125 m
.59517 .24863 L
s
.31238 .22086 m
.31697 .22636 L
s
.36217 .23389 m
.36618 .24692 L
s
.35788 .22532 m
.36217 .23389 L
s
.24891 .37032 m
.25171 .39604 L
s
.36618 .24692 m
.36981 .26672 L
s
.55717 .23771 m
.561 .23175 L
s
.23998 .53643 m
.24509 .53764 L
s
.71513 .2282 m
.71872 .23422 L
s
.36809 .83288 m
.37158 .85761 L
s
.20764 .37641 m
.20963 .40794 L
s
.22564 .21981 m
.23047 .22518 L
s
.60638 .24483 m
.61027 .25242 L
s
.29715 .21977 m
.3018 .22517 L
s
.22263 .37971 m
.22503 .40822 L
s
.31496 .31143 m
.31731 .34716 L
s
.70005 .22606 m
.70371 .23263 L
s
.26953 .48886 m
.27403 .4961 L
s
.47949 .78112 m
.48311 .8264 L
s
.44544 .27628 m
.44956 .28633 L
s
.68514 .227 m
.68866 .23067 L
s
.47379 .36252 m
.47772 .38136 L
s
.21036 .21875 m
.21524 .22412 L
s
.62153 .24877 m
.6254 .25635 L
s
.28191 .2187 m
.2866 .22408 L
s
.41501 .27742 m
.41936 .28225 L
s
.47298 .49454 m
.47684 .51811 L
s
.25411 .48985 m
.25883 .49493 L
s
.23657 .57661 m
.24186 .5759 L
s
.3008 .9101 m
.30573 .90936 L
s
.37704 .24 m
.38086 .2569 L
s
.37293 .22852 m
.37704 .24 L
s
.14994 .33383 m
.15058 .37265 L
s
.39081 .68486 m
.39467 .70208 L
s
.32584 .30346 m
.32821 .34026 L
s
.37615 .46614 m
.38431 .39698 L
s
.74165 .22503 m
.74507 .2297 L
s
.78302 .22018 m
.78629 .2246 L
s
.35345 .21893 m
.35788 .22532 L
s
.42613 .26597 m
.43037 .27324 L
s
.47484 .41218 m
.47873 .43453 L
s
.26665 .21763 m
.27138 .22301 L
s
.66998 .22388 m
.67369 .23014 L
s
.44131 .2667 m
.44544 .27628 L
s
.33824 .21765 m
.34276 .22336 L
s
.36862 .22066 m
.37293 .22852 L
s
.47511 .59264 m
.47913 .60691 L
s
.58736 .23539 m
.59125 .24125 L
s
.49372 .4502 m
.498 .44136 L
s
.33677 .2951 m
.33924 .3318 L
s
.25138 .21656 m
.25615 .22195 L
s
.32301 .21653 m
.32758 .222 L
s
.4686 .30525 m
.47263 .31855 L
s
.46454 .29328 m
.4686 .30525 L
s
.50375 .39361 m
.50797 .38374 L
s
.23724 .38687 m
.24009 .41171 L
s
.47401 .54583 m
.47794 .56566 L
s
.60248 .23748 m
.60638 .24483 L
s
.17277 .36435 m
.17393 .40093 L
s
.4305 1.01307 m
.43143 .99377 L
s
.47263 .31855 m
.47664 .33351 L
s
.33837 .70315 m
.34161 .72984 L
s
.46045 .28223 m
.46454 .29328 L
s
.72663 .22401 m
.73018 .22981 L
s
.39621 .32594 m
.40116 .31884 L
s
.34775 .28616 m
.35041 .32117 L
s
.76794 .21822 m
.77145 .22485 L
s
.26501 .48168 m
.26953 .48886 L
s
.23609 .21549 m
.2409 .22088 L
s
.30775 .21545 m
.31238 .22086 L
s
.38791 .23342 m
.39188 .24765 L
s
.38373 .22332 m
.38791 .23342 L
s
.57219 .23103 m
.57619 .24081 L
s
.24248 .50595 m
.24739 .50945 L
s
.35877 .27662 m
.36171 .30824 L
s
.19178 .38073 m
.19335 .41521 L
s
.71155 .22246 m
.71513 .2282 L
s
.36981 .26672 m
.37308 .29373 L
s
.63282 .24465 m
.63663 .25118 L
s
.43714 .25772 m
.44131 .2667 L
s
.61764 .24106 m
.62153 .24877 L
s
.69647 .22097 m
.70005 .22606 L
s
.38086 .2569 m
.38443 .27896 L
s
.45636 .27151 m
.46045 .28223 L
s
.75313 .21973 m
.75646 .22368 L
s
.49485 .99542 m
.49775 .93529 L
s
.54612 .25588 m
.55004 .24952 L
s
.40363 .29472 m
.40809 .29789 L
s
.47772 .38136 m
.48165 .40212 L
s
.22078 .21442 m
.22564 .21981 L
s
.29248 .21437 m
.29715 .21977 L
s
.47794 .56566 m
.48206 .57388 L
s
.47664 .33351 m
.48062 .35042 L
s
.39188 .24765 m
.39569 .26538 L
s
.47583 .46552 m
.47973 .48829 L
s
.42196 .25652 m
.42613 .26597 L
s
.25416 .73349 m
.2596 .72964 L
s
.36418 .21451 m
.36862 .22066 L
s
.37939 .21606 m
.38373 .22332 L
s
.45225 .26106 m
.45636 .27151 L
s
.2772 .2133 m
.28191 .2187 L
s
.56823 .22384 m
.57219 .23103 L
s
.2494 .48427 m
.25411 .48985 L
s
.38833 .366 m
.39397 .34541 L
s
.34894 .21329 m
.35345 .21893 L
s
.64412 .23943 m
.64782 .24391 L
s
.26298 .38386 m
.26604 .40761 L
s
.40286 .23933 m
.40683 .25385 L
s
.39878 .22725 m
.40286 .23933 L
s
.41084 .26777 m
.41501 .27742 L
s
.66656 .22363 m
.66998 .22388 L
s
.37158 .85761 m
.37531 .87754 L
s
.48082 .53604 m
.48499 .54097 L
s
.27401 .37414 m
.27687 .4007 L
s
.65537 .23246 m
.65892 .23428 L
s
.23489 .53467 m
.23998 .53643 L
s
.39455 .2183 m
.39878 .22725 L
s
.43299 .24787 m
.43714 .25772 L
s
.68137 .21929 m
.68514 .227 L
s
.2619 .21222 m
.26665 .21763 L
s
.39846 .79756 m
.40368 .7799 L
s
.59857 .23044 m
.60248 .23748 L
s
.33368 .21219 m
.33824 .21765 L
s
.29638 .5346 m
.30041 .54755 L
s
.29228 .52254 m
.29638 .5346 L
s
.58343 .22907 m
.58736 .23539 L
s
.73816 .2196 m
.74165 .22503 L
s
.26049 .47418 m
.26501 .48168 L
s
.30041 .54755 m
.30437 .56157 L
s
.44812 .251 m
.45225 .26106 L
s
.77963 .21471 m
.78302 .22018 L
s
.28811 .51127 m
.29228 .52254 L
s
.40683 .25385 m
.41084 .26777 L
s
.25171 .39604 m
.25495 .41751 L
s
.41788 .24443 m
.42196 .25652 L
s
.61376 .23364 m
.61764 .24106 L
s
.48062 .35042 m
.48458 .36927 L
s
.76461 .21393 m
.76794 .21822 L
s
.24658 .21115 m
.25138 .21656 L
s
.3184 .2111 m
.32301 .21653 L
s
.2849 .36619 m
.28754 .39614 L
s
.47684 .51811 m
.48082 .53604 L
s
.41382 .23201 m
.41788 .24443 L
s
.47873 .43453 m
.48264 .45663 L
s
.30437 .56157 m
.30824 .57687 L
s
.23649 .63752 m
.24191 .63534 L
s
.40967 .22151 m
.41382 .23201 L
s
.72306 .21806 m
.72663 .22401 L
s
.28389 .50063 m
.28811 .51127 L
s
.62896 .23724 m
.63282 .24465 L
s
.39569 .26538 m
.39953 .28286 L
s
.42888 .23665 m
.43299 .24787 L
s
.47545 .29102 m
.47949 .30456 L
s
.47139 .27866 m
.47545 .29102 L
s
.29582 .9112 m
.3008 .9101 L
s
.48373 .50547 m
.48791 .50932 L
s
.23124 .21007 m
.23609 .21549 L
s
.7079 .21592 m
.71155 .22246 L
s
.3031 .21003 m
.30775 .21545 L
s
.46731 .26703 m
.47139 .27866 L
s
.44399 .24073 m
.44812 .251 L
s
.3902 .21151 m
.39455 .2183 L
s
.47949 .30456 m
.48352 .31966 L
s
.37495 .2101 m
.37939 .21606 L
s
.2313 .57661 m
.23657 .57661 L
s
.27963 .49043 m
.28389 .50063 L
s
.69291 .21642 m
.69647 .22097 L
s
.46321 .25582 m
.46731 .26703 L
s
.42476 .22555 m
.42888 .23665 L
s
.30824 .57687 m
.31201 .59375 L
s
.4054 .21344 m
.40967 .22151 L
s
.23757 .5021 m
.24248 .50595 L
s
.56438 .22632 m
.56823 .22384 L
s
.28779 .20895 m
.29248 .21437 L
s
.48165 .40212 m
.48559 .42339 L
s
.35968 .20893 m
.36418 .21451 L
s
.52085 .31717 m
.52494 .3134 L
s
.29571 .35943 m
.29811 .39333 L
s
.67772 .21406 m
.68137 .21929 L
s
.24473 .47813 m
.2494 .48427 L
s
.37531 .87754 m
.37835 .91388 L
s
.22503 .40822 m
.22792 .4325 L
s
.25603 .46599 m
.26049 .47418 L
s
.74971 .21485 m
.75313 .21973 L
s
.45911 .24504 m
.46321 .25582 L
s
.43987 .22996 m
.44399 .24073 L
s
.42058 .21614 m
.42476 .22555 L
s
.38443 .27896 m
.38797 .30231 L
s
.59468 .22447 m
.59857 .23044 L
s
.49665 .42001 m
.50086 .41849 L
s
.27246 .20787 m
.2772 .2133 L
s
.48352 .31966 m
.48752 .3365 L
s
.52792 .2948 m
.53198 .29169 L
s
.34439 .20783 m
.34894 .21329 L
s
.48311 .8264 m
.48735 .8252 L
s
.24009 .41171 m
.24349 .43131 L
s
.39953 .28286 m
.40363 .29472 L
s
.27533 .48051 m
.27963 .49043 L
s
.60986 .22636 m
.61376 .23364 L
s
.51377 .3409 m
.5179 .33814 L
s
.57944 .21978 m
.58343 .22907 L
s
.47973 .48829 m
.48373 .50547 L
s
.34161 .72984 m
.34468 .76054 L
s
.64031 .23296 m
.64412 .23943 L
s
.48458 .36927 m
.48855 .38925 L
s
.25711 .20679 m
.2619 .21222 L
s
.20963 .40794 m
.21193 .43725 L
s
.32909 .20674 m
.33368 .21219 L
s
.45499 .23443 m
.45911 .24504 L
s
.62508 .22972 m
.62896 .23724 L
s
.43572 .21971 m
.43987 .22996 L
s
.73461 .21373 m
.73816 .2196 L
s
.31201 .59375 m
.31566 .61258 L
s
.55326 .24037 m
.55717 .23771 L
s
.77614 .20824 m
.77963 .21471 L
s
.48665 .47406 m
.49081 .47944 L
s
.3065 .3533 m
.30865 .39154 L
s
.40105 .20701 m
.4054 .21344 L
s
.27103 .47052 m
.27533 .48051 L
s
.71947 .21215 m
.72306 .21806 L
s
.24175 .2057 m
.24658 .21115 L
s
.31376 .20566 m
.3184 .2111 L
s
.4163 .20871 m
.42058 .21614 L
s
.70435 .2111 m
.7079 .21592 L
s
.25495 .41751 m
.25863 .43447 L
s
.38577 .20569 m
.3902 .21151 L
s
.25163 .45678 m
.25603 .46599 L
s
.22977 .53278 m
.23489 .53467 L
s
.45086 .22393 m
.45499 .23443 L
s
.26604 .40761 m
.26947 .42759 L
s
.53501 .27408 m
.53903 .27273 L
s
.76127 .20968 m
.76461 .21393 L
s
.48237 .27544 m
.48642 .28911 L
s
.4783 .26279 m
.48237 .27544 L
s
.48752 .3365 m
.49152 .35479 L
s
.47421 .25083 m
.4783 .26279 L
s
.43151 .21106 m
.43572 .21971 L
s
.37308 .29373 m
.37618 .32478 L
s
.57551 .21521 m
.57944 .21978 L
s
.29842 .20458 m
.3031 .21003 L
s
.65167 .22775 m
.65537 .23246 L
s
.48264 .45663 m
.48665 .47406 L
s
.37048 .20455 m
.37495 .2101 L
s
.47012 .23947 m
.47421 .25083 L
s
.48642 .28911 m
.49046 .30411 L
s
.50668 .36503 m
.51084 .36541 L
s
.12401 .32561 m
.11938 .40068 L
s
.24009 .47133 m
.24473 .47813 L
s
.26678 .45994 m
.27103 .47052 L
s
.4467 .21428 m
.45086 .22393 L
s
.663 .22112 m
.66656 .22363 L
s
.28307 .20349 m
.28779 .20895 L
s
.60596 .21962 m
.60986 .22636 L
s
.35516 .20345 m
.35968 .20893 L
s
.466 .22861 m
.47012 .23947 L
s
.24875 .73649 m
.25416 .73349 L
s
.23264 .49827 m
.23757 .5021 L
s
.68911 .20833 m
.69291 .21642 L
s
.67428 .21308 m
.67772 .21406 L
s
.59074 .2174 m
.59468 .22447 L
s
.31731 .34716 m
.31926 .38965 L
s
.27687 .4007 m
.28003 .42441 L
s
.24349 .43131 m
.2474 .44577 L
s
.40782 .86937 m
.41235 .86885 L
s
.2474 .44577 m
.25163 .45678 L
s
.6212 .22239 m
.62508 .22972 L
s
.48559 .42339 m
.4896 .4416 L
s
.49046 .30411 m
.49449 .32051 L
s
.31566 .61258 m
.31918 .63373 L
s
.2677 .20241 m
.27246 .20787 L
s
.25863 .43447 m
.26262 .44819 L
s
.26262 .44819 m
.26678 .45994 L
s
.74621 .20929 m
.74971 .21485 L
s
.33982 .20236 m
.34439 .20783 L
s
.39494 .77039 m
.39846 .79756 L
s
.39003 .77802 m
.39494 .77039 L
s
.63646 .22569 m
.64031 .23296 L
s
.29075 .91297 m
.29582 .9112 L
s
.46187 .21831 m
.466 .22861 L
s
.4896 .4416 m
.49372 .4502 L
s
.42723 .20407 m
.43151 .21106 L
s
.48855 .38925 m
.49256 .40786 L
s
.41195 .20253 m
.4163 .20871 L
s
.39181 .32009 m
.39621 .32594 L
s
.77284 .20407 m
.77614 .20824 L
s
.36171 .30824 m
.36431 .34709 L
s
.25231 .20132 m
.25711 .20679 L
s
.73105 .20782 m
.73461 .21373 L
s
.32447 .20127 m
.32909 .20674 L
s
.44248 .20617 m
.4467 .21428 L
s
.23109 .63892 m
.23649 .63752 L
s
.22601 .57637 m
.2313 .57661 L
s
.39664 .20128 m
.40105 .20701 L
s
.49152 .35479 m
.49554 .37309 L
s
.71584 .20582 m
.71947 .21215 L
s
.32821 .34026 m
.33006 .38601 L
s
.54211 .2549 m
.54612 .25588 L
s
.4996 .38798 m
.50375 .39361 L
s
.48933 .2586 m
.4934 .27219 L
s
.48525 .24594 m
.48933 .2586 L
s
.48116 .23411 m
.48525 .24594 L
s
.22792 .4325 m
.23146 .4506 L
s
.38797 .30231 m
.39181 .32009 L
s
.30911 .20019 m
.31376 .20566 L
s
.45771 .20911 m
.46187 .21831 L
s
.26947 .42759 m
.27319 .44453 L
s
.38131 .20015 m
.38577 .20569 L
s
.19335 .41521 m
.19506 .44917 L
s
.49449 .32051 m
.49853 .33776 L
s
.2356 .46285 m
.24009 .47133 L
s
.40403 .84833 m
.40782 .86937 L
s
.39818 .88247 m
.40403 .84833 L
s
.4934 .27219 m
.49746 .28689 L
s
.47705 .22308 m
.48116 .23411 L
s
.68555 .20437 m
.68911 .20833 L
s
.35041 .32117 m
.35257 .3657 L
s
.70074 .20568 m
.70435 .2111 L
s
.15058 .37265 m
.15069 .41635 L
s
.33924 .3318 m
.34114 .3786 L
s
.17393 .40093 m
.17488 .43999 L
s
.29372 .1991 m
.29842 .20458 L
s
.36597 .19905 m
.37048 .20455 L
s
.60206 .21333 m
.60596 .21962 L
s
.28754 .39614 m
.29036 .42457 L
s
.6173 .21525 m
.6212 .22239 L
s
.58676 .20933 m
.59074 .2174 L
s
.75784 .20457 m
.76127 .20968 L
s
.64787 .22127 m
.65167 .22775 L
s
.37947 .42426 m
.38595 .38892 L
s
.57164 .21479 m
.57551 .21521 L
s
.47292 .21295 m
.47705 .22308 L
s
.49746 .28689 m
.50151 .30261 L
s
.63258 .21832 m
.63646 .22569 L
s
.49256 .40786 m
.49665 .42001 L
s
.27832 .19801 m
.28307 .20349 L
s
.35061 .19796 m
.35516 .20345 L
s
.22455 .53152 m
.22977 .53278 L
s
.56044 .2256 m
.56438 .22632 L
s
.4382 .19949 m
.44248 .20617 L
s
.45349 .2014 m
.45771 .20911 L
s
.42289 .19806 m
.42723 .20407 L
s
.27319 .44453 m
.27709 .45946 L
s
.22769 .49424 m
.23264 .49827 L
s
.74267 .20338 m
.74621 .20929 L
s
.26291 .19692 m
.2677 .20241 L
s
.49554 .37309 m
.4996 .38798 L
s
.31918 .63373 m
.32255 .65761 L
s
.23146 .4506 m
.2356 .46285 L
s
.33523 .19687 m
.33982 .20236 L
s
.51674 .31065 m
.52085 .31717 L
s
.40755 .19686 m
.41195 .20253 L
s
.49853 .33776 m
.50258 .35392 L
s
.46875 .20411 m
.47292 .21295 L
s
.49634 .24102 m
.50042 .25421 L
s
.49225 .22884 m
.49634 .24102 L
s
.52383 .28877 m
.52792 .2948 L
s
.50151 .30261 m
.50558 .3186 L
s
.50966 .3327 m
.51377 .3409 L
s
.72746 .20173 m
.73105 .20782 L
s
.50042 .25421 m
.50449 .26838 L
s
.48814 .21771 m
.49225 .22884 L
s
.65929 .21608 m
.663 .22112 L
s
.34468 .76054 m
.34751 .79664 L
s
.31983 .19578 m
.32447 .20127 L
s
.7123 .20101 m
.71584 .20582 L
s
.3922 .19574 m
.39664 .20128 L
s
.27709 .45946 m
.2811 .47322 L
s
.50258 .35392 m
.50668 .36503 L
s
.21193 .43725 m
.21484 .46124 L
s
.58287 .20576 m
.58676 .20933 L
s
.28003 .42441 m
.28343 .44555 L
s
.76949 .19952 m
.77284 .20407 L
s
.50449 .26838 m
.50857 .28332 L
s
.2811 .47322 m
.28514 .48662 L
s
.54925 .23696 m
.55326 .24037 L
s
.484 .20776 m
.48814 .21771 L
s
.30442 .19468 m
.30911 .20019 L
s
.37682 .19464 m
.38131 .20015 L
s
.53093 .26765 m
.53501 .27408 L
s
.28514 .48662 m
.28915 .5003 L
s
.61341 .20869 m
.6173 .21525 L
s
.6707 .20983 m
.67428 .21308 L
s
.37992 .98575 m
.37835 .91388 L
s
.6287 .21107 m
.63258 .21832 L
s
.59811 .20592 m
.60206 .21333 L
s
.69693 .19736 m
.70074 .20568 L
s
.28915 .5003 m
.29312 .51471 L
s
.50558 .3186 m
.50966 .3327 L
s
.64402 .2141 m
.64787 .22127 L
s
.40977 .98609 m
.41294 .93246 L
s
.29811 .39333 m
.30055 .42765 L
s
.44922 .19495 m
.45349 .2014 L
s
.289 .19359 m
.29372 .1991 L
s
.36143 .19354 m
.36597 .19905 L
s
.46454 .19672 m
.46875 .20411 L
s
.50857 .28332 m
.51265 .29812 L
s
.24335 .73883 m
.24875 .73649 L
s
.28557 .9157 m
.29075 .91297 L
s
.43387 .19359 m
.4382 .19949 L
s
.68208 .20251 m
.68555 .20437 L
s
.29312 .51471 m
.29701 .53019 L
s
.75434 .1989 m
.75784 .20457 L
s
.22061 .57684 m
.22601 .57637 L
s
.47984 .19922 m
.484 .20776 L
s
.50746 .2359 m
.51155 .24929 L
s
.50337 .22356 m
.50746 .2359 L
s
.27355 .19249 m
.27832 .19801 L
s
.34603 .19245 m
.35061 .19796 L
s
.41851 .19242 m
.42289 .19806 L
s
.49926 .21243 m
.50337 .22356 L
s
.51265 .29812 m
.51674 .31065 L
s
.51155 .24929 m
.51564 .26335 L
s
.22567 .64005 m
.23109 .63892 L
s
.73912 .19747 m
.74267 .20338 L
s
.53804 .24758 m
.54211 .2549 L
s
.36081 .77 m
.37459 .59056 L
s
.37618 .32478 m
.3795 .35278 L
s
.33061 .19135 m
.33523 .19687 L
s
.51974 .27718 m
.52383 .28877 L
s
.40313 .19131 m
.40755 .19686 L
s
.51564 .26335 m
.51974 .27718 L
s
.22289 .48841 m
.22769 .49424 L
s
.72386 .19577 m
.72746 .20173 L
s
.49513 .20267 m
.49926 .21243 L
s
.29701 .53019 m
.3008 .5471 L
s
.69345 .19465 m
.69693 .19736 L
s
.31517 .19025 m
.31983 .19578 L
s
.38773 .19021 m
.3922 .19574 L
s
.21919 .53119 m
.22455 .53152 L
s
.59417 .19936 m
.59811 .20592 L
s
.65549 .20955 m
.65929 .21608 L
s
.62482 .20414 m
.6287 .21107 L
s
.52683 .2565 m
.53093 .26765 L
s
.6095 .20196 m
.61341 .20869 L
s
.70864 .19478 m
.7123 .20101 L
s
.32255 .65761 m
.32575 .68476 L
s
.37997 .90445 m
.39003 .77802 L
s
.64015 .20684 m
.64402 .2141 L
s
.47563 .19208 m
.47984 .19922 L
s
.46028 .19042 m
.46454 .19672 L
s
.28343 .44555 m
.28701 .46487 L
s
.38346 .3687 m
.38833 .366 L
s
.56768 .21123 m
.57164 .21479 L
s
.29971 .18915 m
.30442 .19468 L
s
.37231 .18911 m
.37682 .19464 L
s
.51863 .23044 m
.52273 .2435 L
s
.51453 .21819 m
.51863 .23044 L
s
.76605 .19421 m
.76949 .19952 L
s
.52273 .2435 m
.52683 .2565 L
s
.44491 .18913 m
.44922 .19495 L
s
.55642 .22009 m
.56044 .2256 L
s
.49097 .1944 m
.49513 .20267 L
s
.51042 .20719 m
.51453 .21819 L
s
.3008 .5471 m
.30448 .56577 L
s
.57895 .20281 m
.58287 .20576 L
s
.28424 .18805 m
.289 .19359 L
s
.35688 .18801 m
.36143 .19354 L
s
.54518 .22874 m
.54925 .23696 L
s
.42951 .18797 m
.43387 .19359 L
s
.29036 .42457 m
.29337 .45138 L
s
.53395 .23665 m
.53804 .24758 L
s
.30865 .39154 m
.31068 .4328 L
s
.21484 .46124 m
.21852 .47816 L
s
.75081 .19298 m
.75434 .1989 L
s
.50629 .19766 m
.51042 .20719 L
s
.66698 .20442 m
.6707 .20983 L
s
.34143 .1869 m
.34603 .19245 L
s
.4141 .18686 m
.41851 .19242 L
s
.73553 .1913 m
.73912 .19747 L
s
.21852 .47816 m
.22289 .48841 L
s
.52984 .22452 m
.53395 .23665 L
s
.7203 .19064 m
.72386 .19577 L
s
.32596 .1858 m
.33061 .19135 L
s
.39868 .18575 m
.40313 .19131 L
s
.52573 .21269 m
.52984 .22452 L
s
.62092 .1975 m
.62482 .20414 L
s
.63627 .19973 m
.64015 .20684 L
s
.59027 .19537 m
.59417 .19936 L
s
.65164 .20246 m
.65549 .20955 L
s
.48677 .18747 m
.49097 .1944 L
s
.60556 .19482 m
.6095 .20196 L
s
.19506 .44917 m
.19724 .47951 L
s
.47139 .1859 m
.47563 .19208 L
s
.52162 .20196 m
.52573 .21269 L
s
.28701 .46487 m
.29068 .48327 L
s
.67847 .1985 m
.68208 .20251 L
s
.70487 .18711 m
.70864 .19478 L
s
.50214 .18963 m
.50629 .19766 L
s
.31048 .1847 m
.31517 .19025 L
s
.38323 .18465 m
.38773 .19021 L
s
.54108 .2181 m
.54518 .22874 L
s
.45599 .18465 m
.46028 .19042 L
s
.30448 .56577 m
.30803 .58655 L
s
.28026 .91971 m
.28557 .9157 L
s
.21499 .57899 m
.22061 .57684 L
s
.23792 .74089 m
.24335 .73883 L
s
.29498 .18359 m
.29971 .18915 L
s
.36777 .18354 m
.37231 .18911 L
s
.44057 .18351 m
.44491 .18913 L
s
.5175 .19268 m
.52162 .20196 L
s
.55235 .21126 m
.55642 .22009 L
s
.76256 .18844 m
.76605 .19421 L
s
.68995 .19184 m
.69345 .19465 L
s
.22015 .64181 m
.22567 .64005 L
s
.53698 .20702 m
.54108 .2181 L
s
.36431 .34709 m
.36691 .38752 L
s
.3523 .18244 m
.35688 .18801 L
s
.42513 .18239 m
.42951 .18797 L
s
.56364 .20419 m
.56768 .21123 L
s
.74726 .18701 m
.75081 .19298 L
s
.2138 .53077 m
.21919 .53119 L
s
.31926 .38965 m
.3209 .4381 L
s
.73196 .18566 m
.73553 .1913 L
s
.53287 .19671 m
.53698 .20702 L
s
.66318 .19782 m
.66698 .20442 L
s
.3368 .18133 m
.34143 .1869 L
s
.40967 .18128 m
.4141 .18686 L
s
.34751 .79664 m
.35013 .83793 L
s
.49796 .18287 m
.50214 .18963 L
s
.6324 .19292 m
.63627 .19973 L
s
.29068 .48327 m
.29436 .50172 L
s
.64778 .19532 m
.65164 .20246 L
s
.60164 .18918 m
.60556 .19482 L
s
.61701 .19056 m
.62092 .1975 L
s
.17488 .43999 m
.17591 .47922 L
s
.70144 .18475 m
.70487 .18711 L
s
.48255 .18139 m
.48677 .18747 L
s
.57497 .19713 m
.57895 .20281 L
s
.51336 .18489 m
.5175 .19268 L
s
.32575 .68476 m
.32875 .71591 L
s
.3795 .35278 m
.38346 .3687 L
s
.32129 .18022 m
.32596 .1858 L
s
.3942 .18017 m
.39868 .18575 L
s
.54826 .2012 m
.55235 .21126 L
s
.71661 .18378 m
.7203 .19064 L
s
.46712 .18016 m
.47139 .1859 L
s
.52875 .18774 m
.53287 .19671 L
s
.30576 .17911 m
.31048 .1847 L
s
.37871 .17906 m
.38323 .18465 L
s
.45167 .17902 m
.45599 .18465 L
s
.30803 .58655 m
.31143 .60991 L
s
.58632 .19036 m
.59027 .19537 L
s
.30055 .42765 m
.30305 .46211 L
s
.29337 .45138 m
.2965 .47713 L
s
.54415 .19145 m
.54826 .2012 L
s
.67473 .19274 m
.67847 .1985 L
s
.36321 .17795 m
.36777 .18354 L
s
.4362 .17791 m
.44057 .18351 L
s
.55957 .19527 m
.56364 .20419 L
s
.75903 .18252 m
.76256 .18844 L
s
.15069 .41635 m
.15052 .4633 L
s
.29436 .50172 m
.298 .52107 L
s
.33006 .38601 m
.33146 .44011 L
s
.35944 .72251 m
.3724 .56385 L
s
.74368 .18091 m
.74726 .18701 L
s
.34769 .17684 m
.3523 .18244 L
s
.42072 .17679 m
.42513 .18239 L
s
.5092 .17828 m
.51336 .18489 L
s
.35257 .3657 m
.35447 .41652 L
s
.65934 .1908 m
.66318 .19782 L
s
.52462 .18018 m
.52875 .18774 L
s
.64392 .18835 m
.64778 .19532 L
s
.6285 .18611 m
.6324 .19292 L
s
.49375 .17686 m
.49796 .18287 L
s
.61309 .18402 m
.61701 .19056 L
s
.72838 .18001 m
.73196 .18566 L
s
.33215 .17573 m
.3368 .18133 L
s
.40522 .17568 m
.40967 .18128 L
s
.54005 .18282 m
.54415 .19145 L
s
.47829 .17565 m
.48255 .18139 L
s
.71296 .17781 m
.71661 .18378 L
s
.59772 .18407 m
.60164 .18918 L
s
.57092 .18931 m
.57497 .19713 L
s
.6863 .18713 m
.68995 .19184 L
s
.34114 .3786 m
.34261 .43416 L
s
.55548 .18617 m
.55957 .19527 L
s
.3166 .17461 m
.32129 .18022 L
s
.3897 .17456 m
.3942 .18017 L
s
.46282 .17452 m
.46712 .18016 L
s
.23241 .74326 m
.23792 .74089 L
s
.20912 .58317 m
.21499 .57899 L
s
.27477 .92531 m
.28026 .91971 L
s
.37417 .17345 m
.37871 .17906 L
s
.44732 .1734 m
.45167 .17902 L
s
.20863 .52784 m
.2138 .53077 L
s
.2144 .64532 m
.22015 .64181 L
s
.19724 .47951 m
.20018 .50344 L
s
.298 .52107 m
.30154 .54206 L
s
.69789 .18101 m
.70144 .18475 L
s
.67093 .18608 m
.67473 .19274 L
s
.58231 .18343 m
.58632 .19036 L
s
.52048 .17369 m
.52462 .18018 L
s
.53594 .17548 m
.54005 .18282 L
s
.75548 .17648 m
.75903 .18252 L
s
.35862 .17233 m
.36321 .17795 L
s
.43181 .17228 m
.4362 .17791 L
s
.65549 .18377 m
.65934 .1908 L
s
.31143 .60991 m
.31465 .63638 L
s
.48542 .98784 m
.48475 .96877 L
s
.64004 .18152 m
.64392 .18835 L
s
.50501 .17232 m
.5092 .17828 L
s
.55139 .17792 m
.55548 .18617 L
s
.62459 .17933 m
.6285 .18611 L
s
.74013 .17536 m
.74368 .18091 L
s
.60917 .17835 m
.61309 .18402 L
s
.56686 .18089 m
.57092 .18931 L
s
.34306 .17121 m
.34769 .17684 L
s
.41629 .17116 m
.42072 .17679 L
s
.39263 .96141 m
.39818 .88247 L
s
.48952 .17113 m
.49375 .17686 L
s
.72466 .17281 m
.72838 .18001 L
s
.32747 .17009 m
.33215 .17573 L
s
.40074 .17004 m
.40522 .17568 L
s
.70948 .17458 m
.71296 .17781 L
s
.47401 .17 m
.47829 .17565 L
s
.59375 .17771 m
.59772 .18407 L
s
.2965 .47713 m
.29969 .50276 L
s
.38518 .16892 m
.3897 .17456 L
s
.45849 .16888 m
.46282 .17452 L
s
.68256 .18105 m
.6863 .18713 L
s
.32875 .71591 m
.33152 .7518 L
s
.5473 .17079 m
.55139 .17792 L
s
.53181 .1691 m
.53594 .17548 L
s
.57827 .17565 m
.58231 .18343 L
s
.56278 .17303 m
.56686 .18089 L
s
.3696 .1678 m
.37417 .17345 L
s
.44296 .16775 m
.44732 .1734 L
s
.6671 .17912 m
.67093 .18608 L
s
.31068 .4328 m
.31259 .4769 L
s
.65163 .17687 m
.65549 .18377 L
s
.51631 .16777 m
.52048 .17369 L
s
.63615 .1747 m
.64004 .18152 L
s
.30154 .54206 m
.30494 .56533 L
s
.75193 .17054 m
.75548 .17648 L
s
.62068 .17312 m
.62459 .17933 L
s
.35401 .16668 m
.35862 .17233 L
s
.4274 .16663 m
.43181 .17228 L
s
.50079 .16659 m
.50501 .17232 L
s
.20401 .51944 m
.20863 .52784 L
s
.73652 .16917 m
.74013 .17536 L
s
.72112 .16821 m
.72466 .17281 L
s
.60523 .17221 m
.60917 .17835 L
s
.69422 .17569 m
.69789 .18101 L
s
.3384 .16555 m
.34306 .17121 L
s
.41183 .1655 m
.41629 .17116 L
s
.48526 .16546 m
.48952 .17113 L
s
.20018 .50344 m
.20401 .51944 L
s
.36662 .91721 m
.37898 .74254 L
s
.22676 .74671 m
.23241 .74326 L
s
.39624 .16438 m
.40074 .17004 L
s
.46971 .16433 m
.47401 .17 L
s
.3741 .43507 m
.37947 .42426 L
s
.58973 .17047 m
.59375 .17771 L
s
.55871 .1661 m
.56278 .17303 L
s
.57422 .16816 m
.57827 .17565 L
s
.54319 .1645 m
.5473 .17079 L
s
.67876 .17433 m
.68256 .18105 L
s
.35013 .83793 m
.35265 .88286 L
s
.30305 .46211 m
.30558 .49725 L
s
.38063 .16325 m
.38518 .16892 L
s
.45415 .1632 m
.45849 .16888 L
s
.66326 .17218 m
.6671 .17912 L
s
.31465 .63638 m
.31767 .66663 L
s
.52766 .1632 m
.53181 .1691 L
s
.64775 .17004 m
.65163 .17687 L
s
.36691 .38752 m
.37 .42036 L
s
.70589 .16999 m
.70948 .17458 L
s
.63225 .16819 m
.63615 .1747 L
s
.26909 .93286 m
.27477 .92531 L
s
.17591 .47922 m
.17734 .51592 L
s
.20831 .65159 m
.2144 .64532 L
s
.20306 .58847 m
.20912 .58317 L
s
.36501 .16212 m
.3696 .1678 L
s
.43856 .16207 m
.44296 .16775 L
s
.51212 .16203 m
.51631 .16777 L
s
.61676 .16695 m
.62068 .17312 L
s
.74837 .1648 m
.75193 .17054 L
s
.34937 .16099 m
.35401 .16668 L
s
.42296 .16095 m
.4274 .16663 L
s
.49656 .1609 m
.50079 .16659 L
s
.73285 .16248 m
.73652 .16917 L
s
.60124 .16536 m
.60523 .17221 L
s
.36889 .51298 m
.37615 .46614 L
s
.29969 .50276 m
.30284 .52947 L
s
.30494 .56533 m
.30816 .59161 L
s
.40735 .15981 m
.41183 .1655 L
s
.5857 .16331 m
.58973 .17047 L
s
.48098 .15977 m
.48526 .16546 L
s
.69046 .16936 m
.69422 .17569 L
s
.57016 .16141 m
.57422 .16816 L
s
.7176 .1641 m
.72112 .16821 L
s
.11938 .40068 m
.11485 .47693 L
s
.55462 .15989 m
.55871 .1661 L
s
.67494 .16744 m
.67876 .17433 L
s
.39171 .15868 m
.39624 .16438 L
s
.46539 .15863 m
.46971 .16433 L
s
.53906 .15863 m
.54319 .1645 L
s
.6594 .16533 m
.66326 .17218 L
s
.64387 .16338 m
.64775 .17004 L
s
.37606 .15755 m
.38063 .16325 L
s
.44977 .1575 m
.45415 .1632 L
s
.62834 .16188 m
.63225 .16819 L
s
.52349 .15746 m
.52766 .1632 L
s
.6128 .16034 m
.61676 .16695 L
s
.36039 .15641 m
.36501 .16212 L
s
.3209 .4381 m
.32226 .49252 L
s
.43415 .15637 m
.43856 .16207 L
s
.5079 .15632 m
.51212 .16203 L
s
.7022 .16417 m
.70589 .16999 L
s
.74474 .15828 m
.74837 .1648 L
s
.72934 .15821 m
.73285 .16248 L
s
.59724 .15848 m
.60124 .16536 L
s
.58167 .15672 m
.5857 .16331 L
s
.4185 .15523 m
.42296 .16095 L
s
.4923 .15518 m
.49656 .1609 L
s
.5661 .15527 m
.57016 .16141 L
s
.36348 .59418 m
.37269 .51083 L
s
.68667 .16261 m
.69046 .16936 L
s
.40284 .15409 m
.40735 .15981 L
s
.47667 .15404 m
.48098 .15977 L
s
.67111 .16059 m
.67494 .16744 L
s
.22086 .75213 m
.22676 .74671 L
s
.55051 .15402 m
.55462 .15989 L
s
.33152 .7518 m
.33404 .79331 L
s
.65554 .15862 m
.6594 .16533 L
s
.15052 .4633 m
.15031 .5116 L
s
.63998 .15695 m
.64387 .16338 L
s
.38716 .15295 m
.39171 .15868 L
s
.46104 .15291 m
.46539 .15863 L
s
.53491 .15286 m
.53906 .15863 L
s
.35835 .89828 m
.37283 .69888 L
s
.71397 .1588 m
.7176 .1641 L
s
.62441 .15539 m
.62834 .16188 L
s
.37146 .15181 m
.37606 .15755 L
s
.44538 .15177 m
.44977 .1575 L
s
.5193 .15172 m
.52349 .15746 L
s
.31767 .66663 m
.32045 .7015 L
s
.60882 .15367 m
.6128 .16034 L
s
.30816 .59161 m
.31117 .62168 L
s
.30284 .52947 m
.30587 .55851 L
s
.59323 .15203 m
.59724 .15848 L
s
.74115 .15259 m
.74474 .15828 L
s
.42971 .15063 m
.43415 .15637 L
s
.50366 .15058 m
.5079 .15632 L
s
.69844 .15767 m
.7022 .16417 L
s
.57763 .15064 m
.58167 .15672 L
s
.26317 .94273 m
.26909 .93286 L
s
.19705 .59271 m
.20306 .58847 L
s
.20183 .66109 m
.20831 .65159 L
s
.68286 .1558 m
.68667 .16261 L
s
.41402 .14948 m
.4185 .15523 L
s
.35447 .41652 m
.35651 .46723 L
s
.48801 .14943 m
.4923 .15518 L
s
.56201 .14941 m
.5661 .15527 L
s
.66726 .15385 m
.67111 .16059 L
s
.72577 .1533 m
.72934 .15821 L
s
.65167 .15211 m
.65554 .15862 L
s
.37 .42036 m
.3741 .43507 L
s
.39831 .14834 m
.40284 .15409 L
s
.47235 .14829 m
.47667 .15404 L
s
.54639 .14824 m
.55051 .15402 L
s
.63607 .15051 m
.63998 .15695 L
s
.30558 .49725 m
.30805 .53427 L
s
.33146 .44011 m
.33251 .50202 L
s
.38258 .14719 m
.38716 .15295 L
s
.45666 .14715 m
.46104 .15291 L
s
.53074 .1471 m
.53491 .15286 L
s
.62046 .14888 m
.62441 .15539 L
s
.60484 .14734 m
.60882 .15367 L
s
.71026 .15263 m
.71397 .1588 L
s
.44096 .146 m
.44538 .15177 L
s
.51508 .14595 m
.5193 .15172 L
s
.17734 .51592 m
.17944 .54737 L
s
.58921 .14599 m
.59323 .15203 L
s
.31259 .4769 m
.31437 .52464 L
s
.69466 .15096 m
.69844 .15767 L
s
.73762 .14779 m
.74115 .15259 L
s
.42524 .14485 m
.42971 .15063 L
s
.4994 .1448 m
.50366 .15058 L
s
.57357 .14477 m
.57763 .15064 L
s
.67903 .14907 m
.68286 .1558 L
s
.34261 .43416 m
.34386 .49575 L
s
.66341 .1473 m
.66726 .15385 L
s
.40951 .1437 m
.41402 .14948 L
s
.48371 .14366 m
.48801 .14943 L
s
.35265 .88286 m
.35502 .93255 L
s
.55791 .14361 m
.56201 .14941 L
s
.64778 .14568 m
.65167 .15211 L
s
.63214 .14411 m
.63607 .15051 L
s
.39375 .14255 m
.39831 .14834 L
s
.46799 .14251 m
.47235 .14829 L
s
.54224 .14246 m
.54639 .14824 L
s
.72211 .14747 m
.72577 .1533 L
s
.21464 .7604 m
.22086 .75213 L
s
.61649 .14264 m
.62046 .14888 L
s
.45226 .14136 m
.45666 .14715 L
s
.52655 .14131 m
.53074 .1471 L
s
.60084 .14132 m
.60484 .14734 L
s
.7065 .14606 m
.71026 .15263 L
s
.43652 .1402 m
.44096 .146 L
s
.51084 .14015 m
.51508 .14595 L
s
.69086 .14426 m
.69466 .15096 L
s
.58517 .14012 m
.58921 .14599 L
s
.30587 .55851 m
.30869 .59118 L
s
.31117 .62168 m
.31392 .65647 L
s
.6752 .1425 m
.67903 .14907 L
s
.42075 .13905 m
.42524 .14485 L
s
.49512 .139 m
.4994 .1448 L
s
.56949 .13896 m
.57357 .14477 L
s
.65954 .14088 m
.66341 .1473 L
s
.73401 .14225 m
.73762 .14779 L
s
.64388 .13935 m
.64778 .14568 L
s
.19142 .59294 m
.19705 .59271 L
s
.40497 .13789 m
.40951 .1437 L
s
.47938 .13785 m
.48371 .14366 L
s
.55379 .1378 m
.55791 .14361 L
s
.62821 .13793 m
.63214 .14411 L
s
.32045 .7015 m
.32295 .74194 L
s
.46362 .13669 m
.46799 .14251 L
s
.53807 .13664 m
.54224 .14246 L
s
.7184 .14111 m
.72211 .14747 L
s
.61252 .13664 m
.61649 .14264 L
s
.25698 .95527 m
.26317 .94273 L
s
.70273 .13943 m
.7065 .14606 L
s
.33404 .79331 m
.33626 .84144 L
s
.44784 .13553 m
.45226 .14136 L
s
.52233 .13548 m
.52655 .14131 L
s
.59683 .13544 m
.60084 .14132 L
s
.68705 .1377 m
.69086 .14426 L
s
.19498 .67344 m
.20183 .66109 L
s
.43205 .13437 m
.43652 .1402 L
s
.67136 .13609 m
.6752 .1425 L
s
.50658 .13432 m
.51084 .14015 L
s
.58111 .13428 m
.58517 .14012 L
s
.65567 .13459 m
.65954 .14088 L
s
.41624 .13321 m
.42075 .13905 L
s
.17944 .54737 m
.18246 .57127 L
s
.49081 .13316 m
.49512 .139 L
s
.56538 .13312 m
.56949 .13896 L
s
.63997 .13321 m
.64388 .13935 L
s
.73034 .1361 m
.73401 .14225 L
s
.47502 .132 m
.47938 .13785 L
s
.54964 .13196 m
.55379 .1378 L
s
.62426 .13194 m
.62821 .13793 L
s
.71465 .13456 m
.7184 .14111 L
s
.30805 .53427 m
.31034 .57489 L
s
.45922 .13084 m
.46362 .13669 L
s
.53387 .13079 m
.53807 .13664 L
s
.60853 .13075 m
.61252 .13664 L
s
.69895 .13289 m
.70273 .13943 L
s
.68323 .1313 m
.68705 .1377 L
s
.44339 .12968 m
.44784 .13553 L
s
.51809 .12963 m
.52233 .13548 L
s
.59279 .12958 m
.59683 .13544 L
s
.18647 .58638 m
.19142 .59294 L
s
.66751 .12983 m
.67136 .13609 L
s
.15031 .5116 m
.15033 .55913 L
s
.35665 .70155 m
.36769 .58542 L
s
.42755 .12851 m
.43205 .13437 L
s
.50229 .12846 m
.50658 .13432 L
s
.57703 .12841 m
.58111 .13428 L
s
.20799 .7723 m
.21464 .7604 L
s
.65178 .12848 m
.65567 .13459 L
s
.48648 .1273 m
.49081 .13316 L
s
.56126 .12725 m
.56538 .13312 L
s
.32226 .49252 m
.32331 .55374 L
s
.63604 .12723 m
.63997 .13321 L
s
.72663 .12967 m
.73034 .1361 L
s
.30869 .59118 m
.31124 .62892 L
s
.47064 .12613 m
.47502 .132 L
s
.54546 .12608 m
.54964 .13196 L
s
.62029 .12603 m
.62426 .13194 L
s
.7109 .12806 m
.71465 .13456 L
s
.18246 .57127 m
.18647 .58638 L
s
.31392 .65647 m
.31635 .69719 L
s
.69515 .1265 m
.69895 .13289 L
s
.45479 .12496 m
.45922 .13084 L
s
.52965 .12491 m
.53387 .13079 L
s
.60452 .12486 m
.60853 .13075 L
s
.67941 .12506 m
.68323 .1313 L
s
.43892 .12379 m
.44339 .12968 L
s
.51383 .12374 m
.51809 .12963 L
s
.58874 .12369 m
.59279 .12958 L
s
.66365 .12373 m
.66751 .12983 L
s
.49798 .12257 m
.50229 .12846 L
s
.35651 .46723 m
.35922 .50795 L
s
.57293 .12252 m
.57703 .12841 L
s
.64788 .12249 m
.65178 .12848 L
s
.48212 .12139 m
.48648 .1273 L
s
.55711 .12134 m
.56126 .12725 L
s
.7229 .12322 m
.72663 .12967 L
s
.31437 .52464 m
.31589 .57769 L
s
.6321 .1213 m
.63604 .12723 L
s
.35577 .95616 m
.35502 .93255 L
s
.70713 .1217 m
.7109 .12806 L
s
.46624 .12022 m
.47064 .12613 L
s
.54127 .12017 m
.54546 .12608 L
s
.25518 .95956 m
.25698 .95527 L
s
.6163 .12012 m
.62029 .12603 L
s
.69136 .12028 m
.69515 .1265 L
s
.32295 .74194 m
.32513 .78906 L
s
.45034 .11904 m
.45479 .12496 L
s
.52541 .11899 m
.52965 .12491 L
s
.60049 .11895 m
.60452 .12486 L
s
.67557 .11897 m
.67941 .12506 L
s
.36321 .5265 m
.36889 .51298 L
s
.50954 .11782 m
.51383 .12374 L
s
.58466 .11777 m
.58874 .12369 L
s
.65978 .11774 m
.66365 .12373 L
s
.18787 .68732 m
.19498 .67344 L
s
.49365 .11664 m
.49798 .12257 L
s
.56881 .11659 m
.57293 .12252 L
s
.64397 .11654 m
.64788 .12249 L
s
.71916 .11688 m
.7229 .12322 L
s
.47774 .11546 m
.48212 .12139 L
s
.55294 .11541 m
.55711 .12134 L
s
.62814 .11536 m
.6321 .1213 L
s
.70336 .11548 m
.70713 .1217 L
s
.46181 .11428 m
.46624 .12022 L
s
.53705 .11423 m
.54127 .12017 L
s
.6123 .11418 m
.6163 .12012 L
s
.11485 .47693 m
.11057 .55317 L
s
.68755 .11419 m
.69136 .12028 L
s
.33626 .84144 m
.33819 .89691 L
s
.52115 .11305 m
.52541 .11899 L
s
.59643 .113 m
.60049 .11895 L
s
.33251 .50202 m
.33329 .57091 L
s
.67172 .11296 m
.67557 .11897 L
s
.31034 .57489 m
.31234 .62119 L
s
.50523 .11186 m
.50954 .11782 L
s
.58055 .11181 m
.58466 .11777 L
s
.20085 .78831 m
.20799 .7723 L
s
.65588 .11177 m
.65978 .11774 L
s
.48929 .11068 m
.49365 .11664 L
s
.56466 .11063 m
.56881 .11659 L
s
.64003 .11058 m
.64397 .11654 L
s
.71541 .11067 m
.71916 .11688 L
s
.34386 .49575 m
.34523 .55814 L
s
.31124 .62892 m
.31341 .6735 L
s
.47333 .10949 m
.47774 .11546 L
s
.54874 .10944 m
.55294 .11541 L
s
.62415 .10939 m
.62814 .11536 L
s
.69957 .10939 m
.70336 .11548 L
s
.53281 .10825 m
.53705 .11423 L
s
.60826 .10821 m
.6123 .11418 L
s
.68372 .10816 m
.68755 .11419 L
s
.51686 .10707 m
.52115 .11305 L
s
.59236 .10702 m
.59643 .113 L
s
.66785 .10697 m
.67172 .11296 L
s
.31635 .69719 m
.31839 .74539 L
s
.50089 .10588 m
.50523 .11186 L
s
.57643 .10583 m
.58055 .11181 L
s
.65197 .10578 m
.65588 .11177 L
s
.15033 .55913 m
.15086 .6036 L
s
.48491 .10468 m
.48929 .11068 L
s
.56048 .10463 m
.56466 .11063 L
s
.63607 .10458 m
.64003 .11058 L
s
.71166 .10457 m
.71541 .11067 L
s
.54452 .10344 m
.54874 .10944 L
s
.62015 .10339 m
.62415 .10939 L
s
.69578 .10335 m
.69957 .10939 L
s
.35922 .50795 m
.36321 .5265 L
s
.52854 .10225 m
.53281 .10825 L
s
.60421 .1022 m
.60826 .10821 L
s
.67988 .10215 m
.68372 .10816 L
s
.37776 .93806 m
.37997 .90445 L
s
.51255 .10105 m
.51686 .10707 L
s
.58825 .101 m
.59236 .10702 L
s
.66397 .10095 m
.66785 .10697 L
s
.49653 .09985 m
.50089 .10588 L
s
.57228 .0998 m
.57643 .10583 L
s
.64803 .09975 m
.65197 .10578 L
s
.18073 .70059 m
.18787 .68732 L
s
.55629 .09861 m
.56048 .10463 L
s
.63208 .09856 m
.63607 .10458 L
s
.70788 .09851 m
.71166 .10457 L
s
.54028 .09741 m
.54452 .10344 L
s
.61612 .09736 m
.62015 .10339 L
s
.69196 .09731 m
.69578 .10335 L
s
.32513 .78906 m
.32692 .84433 L
s
.52425 .0962 m
.52854 .10225 L
s
.60013 .09615 m
.60421 .1022 L
s
.67602 .0961 m
.67988 .10215 L
s
.50821 .095 m
.51255 .10105 L
s
.58413 .09495 m
.58825 .101 L
s
.66005 .0949 m
.66397 .10095 L
s
.56811 .09375 m
.57228 .0998 L
s
.64408 .0937 m
.64803 .09975 L
s
.31589 .57769 m
.31705 .63833 L
s
.32331 .55374 m
.324 .62295 L
s
.19319 .80857 m
.20085 .78831 L
s
.55207 .09254 m
.55629 .09861 L
s
.62808 .09249 m
.63208 .09856 L
s
.70409 .09244 m
.70788 .09851 L
s
.53601 .09134 m
.54028 .09741 L
s
.61207 .09129 m
.61612 .09736 L
s
.68812 .09124 m
.69196 .09731 L
s
.51994 .09013 m
.52425 .0962 L
s
.59603 .09008 m
.60013 .09615 L
s
.67213 .09003 m
.67602 .0961 L
s
.31234 .62119 m
.31391 .67565 L
s
.57998 .08887 m
.58413 .09495 L
s
.65612 .08882 m
.66005 .0949 L
s
.31341 .6735 m
.31509 .72709 L
s
.56391 .08766 m
.56811 .09375 L
s
.6401 .08761 m
.64408 .0937 L
s
.35593 .64093 m
.36348 .59418 L
s
.33906 .93177 m
.33819 .89691 L
s
.54783 .08645 m
.55207 .09254 L
s
.62405 .0864 m
.62808 .09249 L
s
.70028 .08634 m
.70409 .09244 L
s
.53172 .08523 m
.53601 .09134 L
s
.60799 .08518 m
.61207 .09129 L
s
.68426 .08513 m
.68812 .09124 L
s
.59191 .08397 m
.59603 .09008 L
s
.66822 .08392 m
.67213 .09003 L
s
.31839 .74539 m
.31994 .80316 L
s
.15086 .6036 m
.15212 .64276 L
s
.57581 .08275 m
.57998 .08887 L
s
.65217 .0827 m
.65612 .08882 L
s
.5597 .08153 m
.56391 .08766 L
s
.63609 .08148 m
.6401 .08761 L
s
.17385 .7106 m
.18073 .70059 L
s
.54356 .08032 m
.54783 .08645 L
s
.62 .08026 m
.62405 .0864 L
s
.69644 .08021 m
.70028 .08634 L
s
.60389 .07904 m
.60799 .08518 L
s
.68038 .07899 m
.68426 .08513 L
s
.58776 .07782 m
.59191 .08397 L
s
.66429 .07777 m
.66822 .08392 L
s
.57162 .0766 m
.57581 .08275 L
s
.64819 .07655 m
.65217 .0827 L
s
.55545 .07537 m
.5597 .08153 L
s
.63207 .07532 m
.63609 .08148 L
s
.34523 .55814 m
.34724 .61216 L
s
.61593 .0741 m
.62 .08026 L
s
.69259 .07405 m
.69644 .08021 L
s
.33329 .57091 m
.33398 .64421 L
s
.59977 .07287 m
.60389 .07904 L
s
.67647 .07282 m
.68038 .07899 L
s
.58359 .07164 m
.58776 .07782 L
s
.66034 .07159 m
.66429 .07777 L
s
.18501 .8328 m
.19319 .80857 L
s
.5674 .07041 m
.57162 .0766 L
s
.64419 .07036 m
.64819 .07655 L
s
.32692 .84433 m
.32826 .90969 L
s
.11057 .55317 m
.10672 .62808 L
s
.62802 .06913 m
.63207 .07532 L
s
.61183 .0679 m
.61593 .0741 L
s
.68871 .06784 m
.69259 .07405 L
s
.59562 .06666 m
.59977 .07287 L
s
.67255 .06661 m
.67647 .07282 L
s
.5794 .06543 m
.58359 .07164 L
s
.65636 .06537 m
.66034 .07159 L
s
.16754 .71474 m
.17385 .7106 L
s
.15212 .64276 m
.15434 .67458 L
s
.64016 .06414 m
.64419 .07036 L
s
.35208 .88059 m
.36081 .77 L
s
.62395 .0629 m
.62802 .06913 L
s
.60771 .06166 m
.61183 .0679 L
s
.68481 .06161 m
.68871 .06784 L
s
.31509 .72709 m
.31616 .79246 L
s
.31391 .67565 m
.3149 .74107 L
s
.34689 .86345 m
.35944 .72251 L
s
.31705 .63833 m
.31771 .70909 L
s
.59145 .06042 m
.59562 .06666 L
s
.6686 .06037 m
.67255 .06661 L
s
.65237 .05912 m
.65636 .06537 L
s
.63612 .05788 m
.64016 .06414 L
s
.61985 .05663 m
.62395 .0629 L
s
.60357 .05539 m
.60771 .06166 L
s
.68089 .05533 m
.68481 .06161 L
s
.324 .62295 m
.32435 .70075 L
s
.31994 .80316 m
.32089 .87327 L
s
.66463 .05408 m
.6686 .06037 L
s
.16207 .71081 m
.16754 .71474 L
s
.64835 .05283 m
.65237 .05912 L
s
.15434 .67458 m
.15765 .69752 L
s
.63205 .05158 m
.63612 .05788 L
s
.61573 .05033 m
.61985 .05663 L
s
.67694 .04902 m
.68089 .05533 L
s
.66063 .04777 m
.66463 .05408 L
s
.15765 .69752 m
.16207 .71081 L
s
.6443 .04651 m
.64835 .05283 L
s
.34724 .61216 m
.35058 .64447 L
s
.17636 .86027 m
.18501 .8328 L
s
.35058 .64447 m
.35593 .64093 L
s
.62796 .04525 m
.63205 .05158 L
s
.67297 .04268 m
.67694 .04902 L
s
.65661 .04142 m
.66063 .04777 L
s
.64024 .04015 m
.6443 .04651 L
s
.34741 .77706 m
.35665 .70155 L
s
.32828 .91153 m
.32826 .90969 L
s
.66898 .0363 m
.67297 .04268 L
s
.65257 .03503 m
.65661 .04142 L
s
.33398 .64421 m
.33498 .71558 L
s
.66497 .02988 m
.66898 .0363 L
s
.31616 .79246 m
.31646 .87293 L
s
.3149 .74107 m
.31518 .82042 L
s
.10672 .62808 m
.10348 .70022 L
s
.31771 .70909 m
.3178 .79191 L
s
.1685 .88604 m
.17636 .86027 L
s
.32093 .8936 m
.32089 .87327 L
s
.32435 .70075 m
.32449 .7853 L
s
.33498 .71558 m
.33698 .77292 L
s
.10348 .70022 m
.10103 .76806 L
s
.31643 .87759 m
.31646 .87293 L
s
.31495 .8637 m
.31518 .82042 L
s
.34087 .79896 m
.34741 .77706 L
s
.31753 .8528 m
.3178 .79191 L
s
.33698 .77292 m
.34087 .79896 L
s
.32475 .84547 m
.32449 .7853 L
s
.10103 .76806 m
.09953 .83008 L
s
.09948 .83614 m
.09953 .83008 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.23115 .18555 m
.23598 .19102 L
s
[(1)] .22151 .17463 .88293 1 Mshowa
.36874 .1277 m
.37327 .13341 L
s
[(2)] .35968 .11629 .79394 1 Mshowa
.51427 .06651 m
.51847 .07247 L
s
[(3)] .50588 .0546 .70494 1 Mshowa
.66846 .00168 m
.67228 .00789 L
s
[(4)] .66081 -0.01073 .61595 1 Mshowa
.125 Mabswid
.12637 .22961 m
.12939 .23277 L
s
.15215 .21877 m
.15514 .22196 L
s
.1782 .20782 m
.18116 .21104 L
s
.20453 .19675 m
.20746 .19999 L
s
.25807 .17424 m
.26093 .17754 L
s
.28528 .16279 m
.28811 .16613 L
s
.31279 .15123 m
.31558 .15459 L
s
.34061 .13953 m
.34337 .14292 L
s
.39719 .11574 m
.39987 .11919 L
s
.42596 .10364 m
.42861 .10713 L
s
.45507 .09141 m
.45767 .09492 L
s
.4845 .07903 m
.48706 .08257 L
s
.54439 .05385 m
.54687 .05745 L
s
.57487 .04103 m
.5773 .04467 L
s
.6057 .02807 m
.60808 .03173 L
s
.63689 .01495 m
.63923 .01865 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(10)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(20)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(30)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(40)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00kOooool2o`000003oa0@4?oooooooooo05Wooooo
003^ooooo`03o`000?oooooooooo05[ooooo003[ooooo`Go0000Foooool00>_ooooo00CoA4A4omgM
gOoooooo0000G?ooool00>_ooooo00CogMgMoeEEEOoooooo0000G?ooool00>cooooo00?oMgMgolc<
c?l00000G?ooool00>cooooo00?ok^k^odA4A?l00000G?ooool00>gooooo00?oMgMgo`000?ooool0
Foooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?;ooooo
0_l0001Gooooo`00koooool5o`0005Oooooo003]ooooo`;o00001?ooool2o`0005Kooooo003[oooo
o`;o00001_ooool00ol0003oooooo`00001Eooooo`00j?ooool3o`0000Sooooo00?o0000ooooool0
0000EOooool00>Kooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
0000E?ooool008_ooooo0_l00002ooooo`03oa0@4?l0003o000002oooooo00GoV9RHoa0@4?l0003o
<S8bolc<c00Mooooo`?o00003Oooool01?l0003oooooooooool0001Dooooo`00S?ooool01Ol0003o
ooooonk^k_lb<S;oc<c<033ooooo00Go410@okZj^_ooooooMgMgoc8b<P0Kooooo`;o00004?ooool0
1Ol0003ooooooooooooooooo000005?ooooo002<ooooo`04o`000?nHV9So<S8bolc<c3Gooooo00?o
0000ooooooooool05oooool2o`000003ooooool0003ooooo00gooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`1@ooooo`00S?ooool00ol0003o410@oiRHV00eooooo`03ojVYZOl@413o
oooo01Gooooo0ol00003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`1@ooooo`00S?ooool01?l0003ok^k^oeEEEOn7QhLcooooo`03oa0@4?l0003o
^[Zj01Cooooo0_l0000Booooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03o`00
0?oooooooooo04oooooo002<ooooo`05o`000?ooooooA4A4o`000?l@4100<oooool00onj^[[o8B4Q
ooooo`0Aooooo`;o00004Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`1?ooooo`00S?ooool00ol0003oooooooooo`0booooo`05oa0@
4?nHV9SooooookZj^_l000003oooool3o`0000;ooooo00?o0000ooooooooool02_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooo
oooo04kooooo002<ooooo`03o`000?oooooooooo03;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0=
ooooo`;o00004oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo04gooooo002;ooooo`;o0000@oooool3o`00017ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
oooo0_l00005ooooo`03o`000?oooooooooo04gooooo003>ooooo`;o000000?oooooo`000?l00000
3_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`1<ooooo`00c?ooool2
o`00013ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000Kooooo00?o0000oooooooo
ool0Boooool00<Wooooo0ol0000Booooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04_ooooo0037ooooo`?o00004Oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1:ooooo`00a?ooool3o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0B_ooool00<;ooooo0_l0000@ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Wooooo0030ooooo`;o00004_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`18ooooo`00V_ooool5o`0001kooooo0ol00002ooooo`03o`000?oo
oooooooo00cooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?oo
ool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Looooo`;o00004Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo002K
ooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0000@ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0A_oo
ool009cooooo00?oV9RHob4Q8Oo^k^h05oooool3o`000003ooooool0003ooooo00cooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`16ooooo`00WOooool00omgMgOoIVIVooooo`0Doooo
o`;o00004_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo002Noooo
o`03o`000?oooooooooo013ooooo0ol0000Aooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`15ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So
410@013ooooo0_l000000ooooooo0000ooooo`0>ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A?oo
ool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`;o00001?ooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04?ooooo002Zooooo`?o00004_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooooooooooooooo0000
ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0@oooool00:Sooooo0ol0000@ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo
002Uooooo`?o00000oooool00ol0003oooooooooo`0:ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooooooool2o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04;ooooo002Sooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`00XOooool3o`0000kooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`10ooooo`00W_ooool3o`0000;ooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0@?ooool009cooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?oooool009[ooooo0_l0000@ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000?ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03ko
oooo001fooooo`Co000000?o410@ooooooooool06_ooool3o`0000;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`00N?ooool00ol0003oooooooooo`0Jooooo`;o00003oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Ooo
ool007Sooooo00?o0000ooooooooool05oooool3o`0000kooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?Oooool007Sooooo00?o0000ooooooooool05Oooool2o`0000?ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0looooo`00N?ooool00ol0003oooooooooo`0Cooooo`;o0000
4Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0kooooo`00N?ooool00ol0003oooooooooo`0@ooooo`?o00004?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`09o`000?oooooooooo
ooooool0003oooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0>oooool007Sooooo00?o0000oooooooo
ool03_ooool2o`0000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0jooooo`00M_ooool00omEEEGoIVIVo`00000=ooooo`?o00003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0>Oooool008Cooooo0_l0000Booooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_oo
ool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool2o`000003ooooool0003ooooo
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>Oooool008;ooooo0_l00002ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool2o`0000;ooooo00Co
0000oooooooooooooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Sooooo001oooooo`?o00004?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Sooooo001mooooo`;o00004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=oooool007_ooooo0_l00002ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool007Sooooo
0ol00005ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`09o`000?ooooooooooooooool0003ooooo
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo001Boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07oooool2o`0000oooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oooooooooo
ooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0eoooo
o`00D_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo0ol00002ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0eooooo`00D_ooool01Ol@413ooooooooooooooooo410@01[ooooo0_l0
000Aooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0=?ooool005;ooooo00Go0000oooooooo
ooooooooo`00000Hooooo`;o00004?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool005;ooooo00Go
0000ooooooooooooooooo`00000Eooooo`?o00000_ooool00ol0003oooooooooo`0:ooooo`;o0000
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02o`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0<oooool0
05;ooooo00Go410@oooooooooooooooooa0@400Cooooo`;o00004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00005
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00004ooooo`?o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo001Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL04?ooool3o`0000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool0<Oooool005;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0<Oooool006?ooooo0_l0000Aooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000001?ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo0_l00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033o
oooo001Pooooo`Co00003oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oo
ooooooooooooool0003oooooo`000004ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
033ooooo001Nooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l00002
ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;oooool005cooooo0_l0
000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooo`000?l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00005ooooo`09o`000?oooooooooooooo
ool0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0;_ooool005Wooooo1?l0000>ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo001Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
oooo0ol00002ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0]ooooo`00F?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0;Oooool005Sooooo0_l00009oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooo`000?ooool00_l000001Ooooooo
0000oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0;?ooool005Sooooo0ol00008ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol00002ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`00
Eoooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0:oooool004gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00003ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:_ooool004gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`06o`000?oooooo
0000o`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooooooo0ol00002ooooo`05o`000?ooooooooooooooool000000ooo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo001=ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo0_l0
0002ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0Yooooo`00COooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool01Oooool01Ol0003oooooo`000?oooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooooooo0ol00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Sooooo001=ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`06oooo
o`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000oooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?oo
ool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04o`00
0?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo001=ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_l000000ooooooo0000ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o00001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool004gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooo000000Wooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o00000_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`00COooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo0_l0000;ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000ooo
ool4o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`04o`000?oooooooooo
o`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool005Ko
oooo00?o0000ooooooooool02Oooool01ol0003oooooo`000?oooooo0000ooooool000001?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000000oooool3o`0000Cooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo001Fooooo`03o`000?oo
oooooooo00Wooooo00Go0000oooooooooooo0000ooooo`02o`0000Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo1?l000000ooooooo0000ooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo001F
ooooo`03o`000?oooooooooo00Wooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?o000000Coooooo`000?oooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Toooo
o`00E_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
oooo1?l00003ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Sooooo`00EOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000oooool2o`0000;ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`00
EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l000001Ooooooo0000
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol00002oooo
o`?o000000Goooooo`000?ooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooooooool3o`0000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Rooooo`00EOooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00EOooool2o`00
00_ooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00EOooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00004oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooo
oooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03
o`000?oooooooooo00;o00001?ooool00ol0003oooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Pooooo`00EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooooooo0ol00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000Cooooo
o`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo0000ooooo`02
o`000005ooooool0003oooooooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool005Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo0ol000001Ooooooo0000oooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0
003oooooooooool00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool2o`00
0007ooooool0003oooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Oooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003oooooo`0000Cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooooooo0_l000000ooooooo0000o`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Nooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00So0000oooooooooooo
0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool3o`000003ooooool0
003o000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool3o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000Go
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0Nooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`Go000000?o
ooooo`000?ooool00_l00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`02o`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_l00002ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Mooooo`00E?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000;o000000Coooooo`000?oooooo00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000003ooooo`Go000000Goooooo`000?ooooooooooo`000002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool2o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Looooo`00E?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`03
o`000003ooooool0003ooooo00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`00
0?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`000005ooooool0003o0000oooo
ool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
ool0003o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`?o0000
0_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool07?ooool005Cooooo0_l0000<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool01?l0003oooooooooooooool2o`000004ooooool0003oooooo`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000;o000000?oooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;o00000oooool0
1_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooooooo0_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000004oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool06oooool005?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o0000
00?oooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool000000_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06oooool005?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`?o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Cooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo
0000ooooool00003ooooo`Oo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooo`000?ooool2o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo01[ooooo001Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool3o`000003
ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000
o`000003o`0000;ooooo00?o0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`00
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05o`000003ooooool0003o0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00;o000000?oooooo`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000Cooooo
00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`00
Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000ooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`00
0?oooooo0000ooooool000000_ooool01?l0003oooooooooooooool4o`000004ooooool0003o0000
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`07o`00
0?ooooooooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o00000_ooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo001C
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`?o000000?oooooo`000?ooool00oooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000004ooooool0003ooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`;o0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06?ooool005?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000ooooo`03ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oo
oooo0000ooooool00002ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`03
o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0G
ooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool3o`000003ooooool0003ooooo00;o00000_ooool0
2?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool2o`000003ooooool0003ooooo00;o000000?oooooo`00
0?l000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o000000Ko
ooooo`000?l0003oooooo`000?ooool2o`0000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000;ooooo00?o0000ooooool000001?ooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool005;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000001?ooool3o`000003ooooool0003ooooo00;o00000_ooool01?l0
003oooooooooool00002ooooo`;o00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo
00000_ooool02Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooo`02o`000004ooooool0
003oooooo`0000;ooooo00Co0000oooooooooooo00001?ooool02_l0003oooooo`000?l0003ooooo
o`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?oo
ool00oooool01Ol0003oooooo`000?l0003ooooo00?o00000oooool00ol0003oooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001Booooo`?o
00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`Co000000Oooooo
o`000?ooooooooooo`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooo`000004ooooo`05o`000?oooooo0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0Fooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Gooooo00Co0000oooooooo
oooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;o000000Goooooo`000?l0003oooooo`000003ooooo`;o0000
0_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0
0002ooooo`;o00000_ooool01?l0003oooooooooool00005ooooo`06o`000?oooooo0000ooooool0
003ooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`0Eooooo`00D_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Co
oooo0ol00003ooooo`?o00000_ooool01?l0003oooooooooool00002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000ol000001_oo
oooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool000000oooool3o`000003ooooool0
003ooooo00;o00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000oooo
ool000001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Cooooo001Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000oooool3o`000004ooooool0003ooooooooo
o`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?oooooo0000o`0000;ooooo00?o
0000ooooool000000_ooool01Ol0003oooooooooool0003ooooo00;o000000?oooooo`000?l00000
0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool2
o`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000?ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Dooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo0ol000000ooooooo
0000ooooo`03o`000005ooooool0003o0000ooooool000000_ooool02Ol0003oooooo`000?oooooo
0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooo`000?ooool00_l000003_oooooo
0000o`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool02Ol0
003ooooooooooooooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Cooooo`00DOooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`Co00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool3o`000003ooooool0003ooooo00;o000000Woooooo`000?ooooooooooo`000?oooooo0000
ooooool000000_ooool2o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`03o`00
0?oooooo000000Go000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00?o0000
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooo
oooooooo0000ooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01?ooooo001Aooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`?o000000?oooooo`000?l000000_l000002Ooooooo0000oooo
oooooooo0000ooooool0003oooooo`000002ooooo`;o000000Ooooooo`000?ooooooooooo`000?oo
oooo000000;ooooo00Co0000ooooool0003ooooo1?l000001?oooooo0000ooooool00002ooooo`;o
00000_ooool00ol0003oooooooooo`03o`0000?ooooo0ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
ooooool0003o00000oooool3o`000003ooooool0003ooooo00;ooooo0_l000000ooooooo0000o`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo001A
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00ol000001Ooooooo0000oooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00Co00000ooo
ool2o`0000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002ooooo`05o`00
0?oooooo0000ooooool000000_ooool5o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000Gooooo00?o0000ooooooooool00ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool2o`0000;ooooo00Co0000ooooool0003ooooo0_l00005ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooooooo
o`?o00004oooool0057ooooo0ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`06o`000?ooooooooooooooool0003ooooo0_l00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`?o0000017o
ooooo`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`000006ooooool0003oooooo`00
0?oooooo00000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool2o`0000Cooooo
00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`02
o`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003ooooooooo
o`0Aooooo`00DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o000000Goooooo`000?oooooo
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Coooooo`000?oooooooooo0_l0
00001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo
00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool0
00000_ooool3o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00004
ooooo`03o`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`05ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003ooooo
ooooo`0Aooooo`00DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooo`000?ooool00ol000001Ooooooo
0000oooooooooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o
000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Coooooo`000?oooooooooo0_l00000
1ooooooo0000oooooooooooo0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Wo0000oooooooooooo0000ooooool0003o
ooooo`000?ooool00ol000000ooooooo0000ooooo`04o`000005ooooool0003o0000ooooool00000
0oooool01ol0003oooooooooool0003oooooo`000?ooool00_l00002ooooo`;o00000oooool00ol0
003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00003ooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`0Aoooo
o`00=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@oooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`Co0000
0oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000001ooooooo0000oooooooo
oooo0000ooooool000000_ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`05o`00
0?oooooo0000ooooool000000oooool3o`000005ooooool0003oooooo`000?ooool02_l00003oooo
o`;o00001?ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00ol000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo017ooooo
000fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo0ol000001?oooooo0000ooooooooool5o`0000;ooooo00?o0000ooooooooool00_l00000
0ooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000009
o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`03o`000?oooooooooo00Ko00000_ooool0
1?l0003oooooooooool00004ooooo`;o00001?ooool00ol0003oooooo`000002ooooo`;o000000?o
ooooo`000?l000000_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o000000?oooooo`000?ooool0
3?ooool00ol0003oooooooooo`0@ooooo`00=_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`08o`000?ooooooooooooooool0003oooooo`000?oo
ool3o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000002ooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`02o`0000;ooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000004o`000008ooooool0003o0000o`000?oo
oooo0000ooooool00002ooooo`03o`000?oooooo000000?ooooo0ol000001Ooooooo0000ooooool0
003ooooo00;o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;ooooo
0_l000001?oooooo0000ooooooooool2o`000003ooooool0003o000000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool3o`000003
ooooool0003ooooo00oooooo00?o0000ooooooooool04?ooool003Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool3o`000005ooooool0003o0000
o`000?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`;o000000Coooooo`000?oooooo
oooo0_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo0_l000000ooo
oooo0000ooooo`03o`0000;ooooo00Go0000ooooool0003oooooo`000003ooooo`?o00000oooool0
1?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool00000
0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00ol00000
0ooooooo0000ooooo`0Booooo`03o`000?oooooooooo013ooooo000fooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000;ooooo0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo1ol000002?oooooo0000
o`000?l0003oooooo`000?oooooo00000_ooool2o`000003ooooool0003ooooo00;o000000Cooooo
o`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?l000001_l0
00001?oooooo0000ooooool00003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Cooooo2?l00002oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`?o000000?ooooo
o`000?ooool00oooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000;o00000_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo000fooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000;ooooo1?l000001?oooooo0000ooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`Go000000?oooooo`000?ooool0
1Ol00002ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`02o`000005ooooool0003ooooo
ooooool000000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00Oo
0000oooooooooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000001?oooooo
0000ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Cooooo00Wo0000
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000_ooool0
1_l0003ooooooooooooooooo0000ooooo`?o00000_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo013ooooo000fooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo
000000?o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Co0000
00Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Goooooo`000?oo
ooooooooo`000002ooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo1?l000001?oo
oooo0000ooooool00002ooooo`Co00000_ooool2o`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`04o`000?oooooo0000oooo
o`;o000000?oooooo`000?ooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00?ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0@ooooo`00=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o
EEEEofIVI_l000001Oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_l00002oooo
o`03o`000?oooooo000000;ooooo0ol000000ooooooo0000o`000003o`000007ooooool0003ooooo
o`000?oooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo0_l000001?oooooo
0000ooooool00003ooooo`;o000000Goooooo`000?l0003oooooo`000004ooooo`03o`000?oooooo
000000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`05o`0000;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`00Coooool2o`0000oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000ol000001?oooooo0000
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooo`000?l00002ooooo`So00000_ooool01Ol0003oooooo`000?l0003ooooo00?o00000_oo
ool00ol0003oooooo`000002ooooo`?o000000?oooooo`000?l000000ol000001_oooooo0000oooo
ool0003oooooo`0000;ooooo1Ol00003ooooo`?o00000_ooool00ol0003oooooo`000002ooooo`04
o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;o00000oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000?ooooo0_l00000
1?oooooo0000ooooooooool4o`0000?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0?ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool01?l0003oooooo`000?ooool2o`000004ooooool0003oooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooooooo1_l0
00001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_l000001?oooooo
0000ooooool00002ooooo`?o000000Coooooo`000?l0003o00000oooool01Ol0003oooooo`000?oo
oooo000000;ooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooooooo00?o00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;o00000ooo
ool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000007ooooo`Co00000_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo001?ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000_ooool5o`000005ooooool0
003oooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l000001?oooooo
0000ooooooooool6o`000006ooooool0003o0000ooooool0003ooooo0_l000000ooooooo0000oooo
o`02o`000006ooooool0003oooooooooool0003ooooo0_l000000ooooooo0000ooooo`02o`0000?o
oooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`08ooooo`;o00000_ooool2o`00
00;ooooo00?o0000ooooooooool01?l00003ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00Go0000:_ooool00ol0003oooooooooo`0?ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooool0003oooooo`000002ooooo`;o000000Goooooo`000?l0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`000005oooo
ool0003oooooo`000?ooool01Ol000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`00
0?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`;o000000?oooooo`000?ooool00_l0
0002ooooo`;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00Co00000oooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`05o`000?oooooo
ooooo`000?ooool01Ol0000]ooooo`03o`000?oooooooooo00oooooo001?ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo
0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`000005
ooooool0003oooooo`000?ooool00_l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l0
00001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooooooo1?l00002ooooo`Co
000000Koooooo`000?l0003oooooo`000?ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooo`00
0?ooool2o`0000Cooooo00?o0000ooooool000000_ooool01ol0003oooooooooool0003oooooo`00
0?ooool00_l00003ooooo`Ko00000oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00oooooo001>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?oooooo
0000ooooo`;o00000_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000?o
000000Coooooo`000?l0003ooooo0ol000001Ooooooo0000o`000?oooooo000000?ooooo0ol00002
ooooo`Co000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooo`000?ooool3o`0000;ooooo
00?o0000ooooool000000oooool00ol0003oooooo`000002ooooo`09o`000?ooooooooooo`000?oo
oooo0000ooooool0003ooooo00Oo00000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00oooooo001>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool2
o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`000005ooooool0003oooooooooool0
00000oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00;o000000?oooooo`00
0?ooool00_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o00000_oo
ool01?l0003oooooooooooooool2o`0000;ooooo1_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;ooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?oooooooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo1ol00002ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000oooooooo
ool03oooool004kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
000000Ooooooo`000?oooooo0000ooooool0003ooooo00Co00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo0ol000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000?o
ooooo`000?ooool01_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Co
0000ooooool0003ooooo2?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool01Ol0003o
ooooo`000?l0003ooooo00?o00000_ooool2o`000003ooooool0003o000000;o000000Koooooo`00
0?l0003oooooo`000?ooool3o`0000;ooooo00?o0000ooooool000000_ooool4o`0000;ooooo00Go
0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo00oooooo001>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o00000_oo
ool01Ol0003oooooooooool0003ooooo00;o000000Woooooo`000?oooooo0000ooooool0003ooooo
o`000?ooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0005o`000003ooooool0003ooooo00;o000000?oooooo`000?l000001?l000001Ooooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?ooool00_ooool01?l0003oooooo`000?ooool8o`000005
ooooool0003o0000o`000?ooool00_l00002ooooo`;o000000?oooooo`000?ooool00ol000000ooo
oooo0000ooooo`03o`00000?ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo1?l00002ooooo`04o`000?ooooooooooo`0003Sooooo00?o
0000ooooooooool03_ooool004kooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`09o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo00;o000000Koooooo`000?oo
oooo0000ooooool00002ooooo`;o000000?oooooo`000?ooool00_ooool01_l0003ooooooooooooo
oooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`000004ooooool0003o0000oooo
o`?o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000001?l000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool01?l0
00001Ooooooo0000ooooool0003ooooo00;o000000?oooooo`000?l000001?l000001?oooooo0000
o`000?l00002ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`00
C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool02?l0003ooooooooooooooooo0000ooooool0003ooooo0ol000001_oooooo0000ooooool0
003oooooo`0000;ooooo1?l00003ooooo`06o`000?ooooooooooooooool0003ooooo0_l00003oooo
o`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000_l000001ooooooo0000ooooool0
003oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool:o`000007ooooool0003o0000o`000?oooooo0000ooooo`04o`000003ooooool0003o
000000So00000_ooool00ol0003oooooooooo`02ooooo`?o000000Goooooo`000?oooooo0000oooo
o`03o`0003gooooo00?o0000ooooooooool03_ooool004kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00Oo0000oooooooooooo0000oooo
ool0003ooooo00?o000000Koooooo`000?oooooo0000ooooool00002ooooo`04o`000?oooooo0000
o`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000000_ooool01?l0
003oooooo`000?l00003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000002o`0000;ooooo1_l000000ooooooo0000ooooo`04o`0000Cooooo00?o0000
ooooool000000ol000001?oooooo0000ooooool00002ooooo`?o0000?_ooool00ol0003ooooooooo
o`0>ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l00005
ooooo`03o`000?oooooooooo00;o000000[oooooo`000?l0003o0000ooooool0003oooooo`000?oo
oooo00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00ol000000ooo
oooo0000ooooo`02ooooo`;o00000_ooool6o`000003ooooool0003o000000?o000000Coooooo`00
0?l0003o00000_ooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000;o000000Co
ooooo`000?oooooooooo1?l000000ooooooo0000o`000002o`0000;ooooo1Ol00002ooooo`03o`00
0?oooooo000000Co00000_ooool3o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00Co
0000?_ooool00ol0003oooooooooo`0>ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?ooool4o`000006
ooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`03o`000004ooooool0003o
ooooooooo`Co000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Go000000?oooooo`000?ooool00_l00002ooooo`Co00000_ooool00ol0003ooooo
o`000002o`000006ooooool0003oooooooooool0003ooooo0_l000001?oooooo0000ooooool00003
ooooo`Go00000oooool01?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`Ko0000
00?oooooo`000?l000000_l0000nooooo`03o`000?oooooooooo00kooooo001=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`05o`000?oo
oooo0000o`000?ooool00_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Go0000oooo
oooooooo0000ooooo`03o`0000;ooooo1?l000001?oooooo0000ooooooooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`0000?ooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002o`000004ooooool0003oooooooooo`Co0000
00?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00?o000000?oooooo`000?oo
ool01?l00002ooooo`?o000000?oooooo`000?ooool02?l000000ooooooo0000ooooo`0mooooo`03
o`000?oooooooooo00kooooo001=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`?o000000Woooooo`000?l0003oooooo`000?oooooo0000
ooooool000000_ooool01?l0003oooooooooool00002ooooo`;o00000_ooool4o`000009ooooool0
003oooooo`000?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000003ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`03o`000004ooooool0
003oooooooooo`Co000000?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00Oo
00000_ooool00ol0003oooooo`000005o`0000;ooooo0ol000001_oooooo0000ooooool0003ooooo
o`0003oooooo00?o0000ooooooooool03Oooool004gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0<ooooo`;o00001?ooool6o`000005ooooool0003o0000ooooool000000_ooool0
1?l0003oooooooooool00003ooooo`?o000000goooooo`000?l0003o0000ooooool0003oooooo`00
0?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000001ol000000ooooooo0000o`00
0003ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`03o`000004ooooool0003o0000oooo
o`Co000000?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00Go00000_ooool0
1?l0003oooooo`000?ooool2o`000003ooooool0003o000000;o00000_ooool01Ol0003oooooo`00
0?oooooo000000;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`001_oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool0
2?ooool00omVIVKoMgMgooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0>ooooo`;o00000_ooool6o`000005ooooool0003o0000ooooool0
00000_ooool01?l0003oooooooooool00004ooooo`Ko000000Woooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l000000ooooooo0000o`000008o`000003ooooool0003o000000?ooooo
00Oo0000ooooool0003o0000ooooool0003ooooo00;o000000Coooooo`000?l0003o00000_ooool6
o`0000?ooooo1_l00002ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00gooooo0006ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001ooo
ool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413ogMgM00Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo
1_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000006ooooool0003o
0000ooooool0003ooooo1Ol000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?ooool0
0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00Co000000Coooooo`000?l0003o
00000_ooool03Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oo
ool00_l000000ooooooo0000ooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool03Oooool000Kooooo00?o0000ooooooooool00oooool01_mVIVKo0000o`000?m4A4Coc<c<o`00
00;ooooo00?o0000ooooooooool01Oooool00omEEEGoV9RHooooo`02ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00on7QhOoIVIVooooo`06ooooo`03o`000?oooooooooo01Oooooo0ol0000?
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`Go00003Oooool00ol0003oooooo`000003o`000003ooooool0003o000000;ooooo00?o0000
ooooool000000oooool00ol0003oooooooooo`03ooooo`0<o`000?oooooo0000o`000?oooooo0000
ooooool0003oooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0
003o000000Go000000Coooooo`000?oooooooooo0ol000001ooooooo0000o`000?l0003oooooo`00
0?ooool01?l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000?ooooo0_l00000
1_oooooo0000ooooool0003oooooo`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0ol00008ooooo`03o`000?oooooooooo00;o
oooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`?o00002oooool5o`000003ooooool0003o0000
00;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`00
0?l000000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?l000001?l000001?oooooo0000o`000?ooool8o`000005ooooool0003oooooo`000?ooool0
0_l000000ooooooo0000o`000002o`000007ooooool0003o0000ooooool0003oooooo`000003oooo
o`;o000000Koooooo`000?oooooo0000ooooool00002ooooo`?o00000_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oc8b<_oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03_ooool4o`0000Oooooo00?o0000ooooool000000_l000000ooooooo0000o`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?l0
003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o0000
00?oooooo`000?l000001?l000000ooooooo0000ooooo`09o`000005ooooool0003oooooo`000?oo
ool01_l00002ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003ooooo
o`0000;ooooo00?o0000ooooool000000_l0000>ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>oooo
o`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool3o`0000Gooooo1?l000000ooo
oooo0000o`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0
003oooooo`000?l0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo
000000;ooooo2_l000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003ooooo
1_l000000ooooooo0000o`000002o`000007ooooool0003o0000ooooool0003oooooo`000003oooo
o`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0000>ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool00_oo
ool01_mVIVKoMgMgooooooooooooQhN7o`0000_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`05ooooo`03onk^k_l0003ooooo00Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`;o00001?ooool6o`0000;ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`03ooooo`?o000000?oooooo`000?l000000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooo000000;ooooo2_l000000ooooooo0000ooooo`02o`000004ooooool0003o0000oooo
o`Go000000Coooooo`000?l0003ooooo1?l000001ooooooo0000o`000?oooooo0000ooooool00000
0oooool3o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`02ooooo`06
onk^k_mVIVKo0000o`000?m4A4Co00002oooool01?mEEEGoMgMgooooool@4105o`0000Cooooo00?o
MgMgoeEEEOooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo0ol0
0002ooooo`Go00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000002ooooo`[o
000000Goooooo`000?l0003oooooo`000002ooooo`Co000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000005o`000003ooooool0003ooooo00;o00000_ooool3o`000006ooooool0003o
ooooo`000?oooooo00000_ooool2o`0000kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0<ooooo`001_ooool00ol0003oooooooooo`0Cooooo`03omgMgOl@413ok^k^00;ooooo00?o
0000ooooooooool01?ooool00oo^k^ko410@omgMg@07ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`03o`000006ooooool0003oooooo`000?oooooo
00000oooool00ol0003oooooooooo`03ooooo`?o00000oooool01Ol0003oooooo`000?oooooo0000
00?ooooo00?o0000ooooool000000_ooool=o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o00000_oo
ool3o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000oooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0Dooooo`05ogMg
MomVIVKoooooooooool000001_ooool00omVIVKoMgMgooooo`07ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02o`000006ooooool0003oooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`Co00001?ooool2o`000003ooooool0003o
oooo00;ooooo0ol00002ooooo`oo00001?ooool2o`0000;ooooo00?o0000ooooool000002ol00000
0ooooooo0000o`000002ooooo`Oo000000Coooooo`000?oooooooooo0_l0000?ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool03?ooool004_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool0
2_l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo1?l00005ooooo`03o`000?oooooo000000?ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000002_l00004ooooo`;o00000_ooool00ol0003oooooo`000004o`000003ooooool0003o0000
00?o00000_ooool2o`0000;ooooo1ol000001Ooooooo0000o`000?oooooo0000013ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`00Boooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Moooo
o`Go000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
0000o`0000Gooooo0ol00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`0<o`0000Cooooo
0_l00002ooooo`Oo000000Koooooo`000?l0003o0000ooooool00002ooooo`?o000000?oooooo`00
0?ooool01Ol00002ooooo`?o00004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00cooooo001;ooooo`;o00004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07_ooool4o`000004ooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000;ooooo00Go0000
ooooool0003o0000ooooo`0=o`000003ooooool0003o000000Cooooo0_l00002ooooo`Oo000000Ko
ooooo`000?l0003o0000ooooool00002ooooo`?o000000Coooooo`000?l0003ooooo0ol000000ooo
oooo0000ooooo`03o`00013ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0<oooo
o`00Boooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`Oo00001oooool4o`000004ooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00005ooooo`07o`000?oooooo
0000o`000?oooooo0000ooooo`02o`000005ooooool0003o0000o`000?ooool02Ol000000ooooooo
0000o`000004ooooo`;o00000_ooool6o`000003ooooool0003o000000Co00000_ooool3o`000004
ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l0000@ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool02oooool004[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool9o`00
00Oooooo0ol00004ooooo`Co000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000;ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o
000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`000003ooooool0003o000000;o
00000oooool2o`0000;ooooo3Ol00002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool7
o`00013ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`;o00004oooool3o`0000;ooooo1Ol000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00ol000000ooooooo0000o`000006
o`000003ooooool0003o000000?o00000_ooool3o`000005ooooool0003o0000o`000?ooool02Ol0
0002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool3o`000004ooooool0003o0000o`00
013ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo1Ol000001?oooooo0000ooooool00003oooo
o`04o`000?ooooooooooooooo`;o000000Coooooo`000?oooooooooo0_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003o000000Ko
000000?oooooo`000?l000000ol000000ooooooo0000ooooo`02o`000005ooooool0003o0000o`00
0?ooool01ol000001?oooooo0000ooooooooool4o`000003ooooool0003ooooo00Cooooo1Ol0000>
ooooo`?o0000@?ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0000Koooo
o`Oo00000oooool01?l0003oooooooooooooool4o`0000;ooooo0_l000001?oooooo0000ooooool0
0003ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`So000000?oooooo`000?l00000
1Ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Go000000Coooooo`000?oo
oooooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002oooool3o`00
00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0001go
oooo1ol00003ooooo`04o`000?ooooooooooooooo`Co00000_ooool2o`000004ooooool0003ooooo
o`0000?ooooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0003o000000Oo000000Go
ooooo`000?l0003o0000ooooo`06o`000005ooooool0003o0000o`000?ooool01ol000001?oooooo
0000ooooooooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool00_l00008oooo
o`?o00001_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo001:ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`?o
000000Coooooo`000?l0003o00000oooool01?l0003oooooooooooooool4o`0000;ooooo0_l00000
1?oooooo0000ooooool00003ooooo`05o`000?ooooooooooo`000?ooool03?l000001Ooooooo0000
o`000?l0003ooooo00Oo000000Coooooo`000?l0003ooooo1ol000001?oooooo0000ooooooooool2
o`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00005ooooo`?o00002_oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo0019ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`?o000000?ooooo
o`000?l000000ol000000ooooooo0000ooooo`02ooooo`Co000000Soooooo`000?oooooo0000oooo
ool0003oooooo`0000?ooooo00Go0000oooooooooooo0000ooooo`0Bo`000004ooooool0003o0000
ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`;o
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo1?l0000>ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo1Ol000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo
00;ooooo00Go0000oooooooooooo0000ooooo`0Bo`000004ooooool0003o0000ooooo`;o000000Ko
ooooo`000?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`Go00004oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00[ooooo0019ooooo`?o00004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oo
oooo1ol000001?oooooo0000ooooool00003ooooo`Co000000Coooooo`000?oooooooooo0_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000003ol00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`Oo000000Coooooo`000?l0003o
oooo0_l00009ooooo`?o00005_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[o
oooo0019ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Wooooo`Ko000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo000000;o0000
00Goooooo`000?ooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2o`00
0003ooooool0003o000000;ooooo1ol000000ooooooo0000o`000006o`000006ooooool0003o0000
ooooool0003ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o0000
1_ooool3o`0001[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0:ooooo`00;ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`Go000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`03o`000005oooo
ool0003oooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol000001?oo
oooo0000ooooooooool7o`000003ooooool0003o000000Go00000_ooool3o`0000;ooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000?o00000oooool3o`0001kooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`00;oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool3o`000003ooooool0
003o000000;o00001?ooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?l000001?l0
00001Ooooooo0000o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`0000;o
oooo0ol000001?oooooo0000ooooooooool7o`000003ooooool0003ooooo00;o000000?oooooo`00
0?l000000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Ko00008_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo000_ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`;o00002?ooool8o`00
0004ooooool0003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003ooooo00Cooooo00?o0000ooooooooool00_l00002ooooo`?o000000Coooooo`000?oooooooooo
1ol000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo0_l00003oooo
o`;o000000?oooooo`000?l000002?l0000Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool02_ooool002oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool7o`0000;ooooo00?o0000ooooool000000_l000001Ooo
oooo0000oooooooooooo000000Gooooo00?o0000ooooooooool00_l00002ooooo`?o000000Cooooo
o`000?oooooooooo1ol000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003o
oooo0_l00004ooooo`03o`000?oooooo000000Wo00009_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00[ooooo000_ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00gooooo1?l00002ooooo`;o000000Coooooo`000?oo
oooooooo1?l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002oooo
o`?o000000Coooooo`000?oooooooooo1ol000000ooooooo0000o`000002o`000006ooooool0003o
0000ooooool0003ooooo0_l00004ooooo`03o`000?oooooo000000Co000000?oooooo`000?l00000
0_l0000Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02Oooool002oooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo0_l0000@ooooo`Go0000
00?oooooo`000?ooool01?l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001?ooool2o`000004ooooool0003oooooooooo`Oo000000?ooooo
o`000?l000000_l000001_oooooo0000o`000?oooooo0000ooooo`;o00000_ooool9o`000003oooo
ool0003o000000;o0000:?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo
000_ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo0ol0000Booooo`Go000000?oooooo`000?ooool00_ooool2o`000004ooooool0003o0000o`00
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000_ooool<o`000006ooooool0003o0000ooooool0003ooooo1?l000000ooooooo
0000o`000006o`000003ooooool0003o000000;o0000:Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Wooooo000_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00oooooo1?l0000Eooooo`Go000000?oooooo`000?ooool00_ooool8o`00
00Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo3ol0
00000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0
000Zooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool004Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05oooool5o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003
o`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000So000000?oooooo`000?ooool0
0_ooool2o`000003ooooool0003o000000;o00000_ooool4o`0002[ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`09ooooo`00Aoooool3o`0001?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo1_l00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003o
ooooooooool00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000;o00001?ooool01?l0003oooooo`000?ooool3o`0000;ooooo1?l0000[
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool004Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06Oooool2o`000003ooooool0003ooooo00?o00001?ooool8o`0000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooooooo0000
o`000009o`000003ooooool0003o000000;o00001?ooool01?l0003oooooo`000?ooool3o`0000;o
oooo1?l0000/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool004Oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06Oooool2o`000003ooooool0003ooooo00?o00001?ooool4o`000003oooo
ool0003o000000?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo0_l000000ooooooo0000ooooo`0;o`000003ooooool0003o000000;o00001?ooool01?l0003o
ooooooooooooool3o`0000;ooooo1?l0000]ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02Oooool004Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool2o`000003ooooool0003ooooo00;o
000000?oooooo`000?ooool00_ooool4o`000004ooooool0003oooooooooo`;o000000?oooooo`00
0?ooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo2_l000000ooooooo0000o`000003
o`000003ooooool0003o000000;o00001?ooool01?l0003oooooooooooooool3o`0000;ooooo00Co
0000ooooool0003o0000;_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo
0017ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0
003ooooo00?ooooo0ol000001_oooooo0000oooooooooooo0000ooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000_l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool4
o`0002kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`00Aoooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Jooooo`;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`03oooo
o`05o`000?oooooo0000ooooool000000_ooool4o`0000?ooooo00Co0000oooooooooooooooo1?l0
00000ooooooo0000o`000008o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool4o`0002oooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`00Aoooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`;o0000
00Ooooooo`000?ooooooooooo`000?oooooo000000Cooooo00Co0000ooooool0003ooooo0_l00000
0ooooooo0000ooooo`02o`0000?ooooo1Ol00004ooooo`go000000?oooooo`000?l000000_ooool3
o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0000`ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool2o`00
0005ooooool0003oooooooooool000000_ooool00ol0003oooooooooo`02o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`03o`000?oo
oooooooo00;ooooo3Ol000000ooooooo0000o`000002ooooo`04o`000?oooooo0000o`0000;ooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0000aooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool2o`000005ooooool0
003oooooooooool000000_ooool00ol0003oooooooooo`04o`000005ooooool0003o0000o`000?oo
ool01?l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo
0000o`000007o`000004ooooool0003oooooooooo`;o000000?oooooo`000?l000000_ooool00ol0
003oooooooooo`02ooooo`?o000000?oooooo`000?ooool00ol0000booooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool5o`0000;o
oooo00Co0000oooooooooooo00000_ooool3o`000004ooooool0003oooooooooo`Co000000?ooooo
o`000?l000000_l00003ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000o`000007
o`000004ooooool0003oooooooooo`?o000000Coooooo`000?oooooooooo0_l00003ooooo`?o0000
00Coooooo`000?oooooooooo0_l0000cooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06oooool2o`000003ooooool0003o000000Go0000
0_ooool00ol0003oooooooooo`08o`000006ooooool0003o0000ooooool0003ooooo0ol00002oooo
o`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`000007o`000004ooooool0003ooooo
ooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`?o000000Goooooo`000?oooooooooo
o`00000dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool004Kooooo0_l0
000Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooooooo`Co00000_ooool3o`000003ooooool0003ooooo00Go0000
0_ooool01?l0003oooooo`000?l00002ooooo`?o000000Coooooo`000?oooooo00001Oooool01?l0
003oooooooooooooool8o`000004ooooool0003oooooooooo`?o000000Goooooo`000?oooooooooo
o`000005ooooo`;o000000Goooooo`000?ooooooooooo`00000eooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01oooool004Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000Ko00000_ooool5o`000004oooo
ool0003o0000o`0000;ooooo0_l00005ooooo`04o`000?ooooooooooooooo`So000000Coooooo`00
0?oooooooooo0ol000001Ooooooo0000oooooooooooo000000Gooooo0_l000001Ooooooo0000oooo
oooooooo000003Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`00AOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1?l00002ooooo`?o000000?o
ooooo`000?l000001Ol00002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`06o`0000Co
oooo00?o0000ooooooooool00_ooool8o`000004ooooool0003oooooooooo`?o000000?oooooo`00
0?ooool00_l00005ooooo`;o000000?oooooo`000?ooool00_l0000gooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool01oooool004Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`04ooooo`So00000_ooool00ol0003oooooo`000002o`000003ooooool0003o000000;o
00000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`[o00000_ooool00ol0003oooooo`000002o`000003ooooool0003o0000
00Kooooo0ol000000ooooooo0000o`00000hooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01oooool004Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`Ko
000000?oooooo`000?l000000_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00;o
00001Oooool3o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo2_l00002ooooo`05
o`000?oooooo0000o`000?ooool00_l00007ooooo`?o000000?oooooo`000?l00000>?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0015ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000001[ooooo0_l00003oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?ooool00ol000000ooooooo0000o`000003ooooo`?o00000_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00?ooooo2Ol00002ooooo`05o`000?oooooo0000o`000?ooool00_l00007
ooooo`?o000000?oooooo`000?l00000>Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Oooooo0015ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool01?l0
003oooooo`000?l0000Jooooo`03o`000?oooooooooo00?o00001?ooool5o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000ooooo`03o`0000?ooooo1_l00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool9o`0000;ooooo00Go0000ooooool0003o0000
ooooo`02o`0000Oooooo0ol000000ooooooo0000o`00000jooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool01_ooool004Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01[ooooo0ol00007ooooo`Go000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003ooooo00?o00001_ooool3o`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o0000
00?oooooo`000?ooool00_l00007ooooo`?o000000?oooooo`000?l00000>oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Kooooo0014ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool09oooool4o`0000[ooooo1Ol000001?oooooo0000ooooool00002ooooo`;o0000
00Koooooo`000?oooooo0000ooooool00006ooooo`Co000000Coooooo`000?oooooooooo0_l00000
0ooooooo0000ooooo`04ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o000000Gooooo
o`000?ooooooooooo`000007ooooo`?o000000?oooooo`000?l00000??ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Kooooo0014ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool09?ooool3o`000003ooooool0003ooooo00_ooooo0_l000001ooooooo0000o`000?oo
oooo0000ooooool000000_ooool2o`000006ooooool0003oooooo`000?oooooo00001_ooool01?l0
003oooooo`000?ooool2o`0000;ooooo00Co0000ooooool0003o00001Oooool9o`0000;ooooo0_l0
00001Ooooooo0000oooooooooooo000000Sooooo0_l000000ooooooo0000o`00000looooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01_ooool004Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`0:ooooo`;o000000Oo
ooooo`000?l0003oooooo`000?oooooo000000;ooooo0_l000000ooooooo0000o`000002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000000_ooool2o`000005ooooool0003ooooooooo
ool000001Oooool9o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000Sooooo0_l00000
0ooooooo0000o`00000mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
04Cooooo0_l0000Fooooo`03o`000?oooooooooo01kooooo0ol00005ooooo`;o00003Oooool2o`00
0007ooooool0003o0000ooooool0003oooooo`000002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0003o00000_ooool00ol0003o
ooooooooo`03ooooo`Wo00000_ooool2o`000005ooooool0003o0000ooooool000002?ooool2o`00
0003ooooool0003o000003kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06oooo
o`00A?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo1?l00007ooooo`03
o`000?oooooooooo00gooooo0_l000001ooooooo0000o`000?oooooo0000ooooool000000_ooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000?ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`Wo000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003ooooo
00Oooooo0_l000000ooooooo0000ooooo`0oooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01_ooool004Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`?o
00002?ooool3o`00013ooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0003ooooooooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool01_l0003oooooooooool0
003oooooo`0000Kooooo2Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool0
1oooool2o`000003ooooool0003ooooo043ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`06ooooo`00A?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo0ol0
0008ooooo`?o00004oooool2o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000
ooooo`02o`000003ooooool0003ooooo00;o00001_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00006ooooo`Wo000000?oooooo`000?l000000_ooool2o`000003ooooool0003ooooo00Oo
oooo0_l000000ooooooo0000ooooo`10ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01Oooool004?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`?o0000
2_ooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?ooool00_l000001Ooooooo0000
ooooool0003ooooo00;o000000Koooooo`000?oooooo0000ooooool00005ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000Kooooo1ol000000ooooooo0000ooooo`02o`0000;ooooo0_l0
00000ooooooo0000ooooo`07ooooo`;o000000?oooooo`000?ooool0@Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Gooooo0013ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool03_ooool3o`0000gooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool01?l000001_oooooo0000ooooool0003oooooo`0000Gooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00001_ooool4o`000006ooooool0003o0000oooo
ool0003ooooo0_l00002ooooo`;o000000?oooooo`000?ooool01oooool2o`000003ooooool0003o
oooo04;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo1?l0000?ooooo`03o`000?oooooooooo
01Gooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Soooooo`00
0?oooooo0000ooooool0003oooooo`0000Gooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00001_ooool4o`000006ooooool0003o0000ooooool0003ooooo0_l00002ooooo`;o000000?ooooo
o`000?ooool01oooool01?l0003oooooooooool00014ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01Oooool004?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07
ooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?ooool00_l00000
0ooooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool00005ooooo`;o
00000_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool4o`000006ooooool0003o0000oooo
ool0003ooooo0_l00002ooooo`?o00002Oooool2o`000003ooooool0003ooooo04Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo0ol0000Dooooo`03o`000?oooooooooo01Oooooo0_l000000ooo
oooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Soooooo`000?oooooo0000ooooool0
003oooooo`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`Co0000
00Coooooo`000?l0003ooooo1?l00002ooooo`?o00002_ooool3o`0004Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003oooooooooo`0Fooooo`04o`00
0?ooooooooooooooo`?o00005oooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?oo
ool00_l000000ooooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool0
0004ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo1?l0
00001?oooooo0000o`000?ooool4o`0000;ooooo0ol0000:ooooo`?o0000A_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Gooooo0012ooooo`03o`000?oooooooooo01Oooooo1?l0
000Iooooo`03o`000?oooooooooo01Sooooo0_l000000ooooooo0000ooooo`02o`00000=ooooool0
003o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`05o`000?oo
oooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool4o`000004oooo
ool0003o0000ooooo`Co00000_ooool3o`0000[ooooo00?o0000ooooool00000Aoooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0012ooooo`;o00005Oooool4o`0001_ooooo
00?o0000ooooooooool06Oooool2o`000003ooooool0003ooooo00;o000000goooooo`000?l0003o
ooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooooooo`Co00001Oooool4o`000004ooooool0003o0000
ooooo`Co00000_ooool3o`0000[ooooo00?o0000ooooool00000B?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Cooooo0012ooooo`03o`000?oooooooooo017ooooo0ol00003oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool4o`0000;ooooo00Oo0000oooo
ool0003o0000ooooool0003ooooo00;o000000Koooooo`000?ooooooooooo`000?ooool2o`000003
ooooool0003ooooo00;o000000Coooooo`000?oooooooooo1Ol00005ooooo`Co000000Coooooo`00
0?l0003ooooo0ol00003ooooo`?o00002_ooool00ol0003oooooo`000019ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool004;ooooo00?o0000ooooooooool03_ooool3o`00
00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`Co00000_ooool01ol0
003oooooooooool0003oooooo`000?ooool00_l000001?oooooo0000ooooooooool2o`000005oooo
ool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Go00001?ooool4o`00
0004ooooool0003o0000ooooo`?o00000oooool3o`0000[ooooo00?o0000ooooool00000BOooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo0012ooooo`03o`000?oooooooooo
00_ooooo0ol00009ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool3o`00
00;ooooo00Oo0000ooooool0003o0000ooooool0003ooooo00;o000000Coooooo`000?oooooooooo
0_l000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooo00000_ooool2o`00
0003ooooool0003ooooo00?ooooo1?l000001?oooooo0000o`000?ooool3o`0000?ooooo0ol0000:
ooooo`03o`000?oooooo000004[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`00@_ooool00ol0003oooooooooo`07ooooo`Co00003?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01cooooo0ol00002ooooo`Co000000?oooooo`000?ooool00_l000001?oo
oooo0000ooooooooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
00000ooooooo0000ooooo`03ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo
00Co0000ooooool0003o00002_ooool00ol0003oooooo`00001;ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool004;ooooo00?o0000ooooooooool01?ooool3o`00013ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`?o00000_ooool4o`000007oooo
ool0003o0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`02o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000ooooo`03ooooo`Co000000?oooooo`00
0?l000001?l00002ooooo`04o`000?oooooo0000o`0000[ooooo00?o0000ooooool00000C?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo0011ooooo`03o`000?oooooooooo
00;ooooo0ol0000Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool3o`00
00;ooooo0_l000002Ooooooo0000o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o0000
0_ooool01Ol0003oooooooooool0003ooooo00?o00000oooool2o`000003ooooool0003ooooo00?o
oooo1?l000000ooooooo0000o`000004o`0000;ooooo00Co0000ooooool0003o00002oooool2o`00
04gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`00@Oooool00ol0003o
ooooo`000002o`0001Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`?o
00000_ooool2o`000009ooooool0003o0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0
0002ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`;o000000?oooooo`000?ooool0
0oooool4o`000003ooooool0003o000000Co00000_ooool01?l0003oooooo`000?l0000;ooooo`;o
0000COooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo0011ooooo`;o0000
6?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`00
0?oooooooooo00;o000000Koooooo`000?oooooo0000ooooool00002ooooo`;o00001Oooool01?l0
003oooooo`000?l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_l0
00000ooooooo0000o`000004o`0000;ooooo00Co0000ooooool0003o00002oooool2o`0004kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00@oooool2o`0001Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`?o00000_ooool00ol0003ooooooooo
o`02o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000Gooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000ooooo`So00000_ooool0
1?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`00A?ooool2o`0001Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Nooooo`?o00000_ooool00ol0003oooooooooo`02o`000006ooooool0003o
ooooo`000?oooooo00000_ooool2o`0000?ooooo00Go0000ooooool0003oooooo`000005ooooo`04
o`000?ooooooooooo`0000?ooooo0ol000000ooooooo0000o`000006o`0000;ooooo00Co0000oooo
ool0003o00003?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00oooool004Cooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01kooooo0ol00002ooooo`03o`000?oooooooooo00;o000000Koooooo`00
0?oooooo0000ooooool00002ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000Cooooo
0_l00003ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000001_l00002ooooo`04o`00
0?oooooo0000o`0005kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00
Aoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
7oooool4o`000003ooooool0003ooooo00;ooooo00Co0000ooooool0003ooooo0ol00002ooooo`;o
00000_ooool2o`000004ooooool0003oooooo`0000Cooooo0_l00003ooooo`03o`000?oooooooooo
00?o000000?oooooo`000?l000001_l00002ooooo`04o`000?oooooo0000o`0005kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00B?ooool2o`00017ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Oooooo`Co000000?oooooo`000?ooool00_ooool01?l0
003oooooo`000?ooool3o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00001?oo
ool2o`0000?ooooo00?o0000ooooooooool00ol000001?oooooo0000o`000?ooool5o`0000;ooooo
00Co0000ooooool0003o0000Goooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Oooooo`Co000000?oooooo`000?ooool00_ooool01Ol0003oooooo`000?l0003ooooo00;o
00000_ooool2o`000008ooooool0003oooooo`000?oooooo0000ooooool00004ooooo`;o00000ooo
ool00ol0003oooooooooo`03o`000004ooooool0003o0000ooooo`Go00000_ooool01?l0003ooooo
o`000?l0001Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool004[ooooo
0ol0000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool4o`000003oooo
ool0003ooooo00;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo0_l000001?oooooo0000
ooooooooool2o`000003ooooool0003ooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00?o
000000Coooooo`000?l0003ooooo1Ol00002ooooo`04o`000?oooooo0000o`00067ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`02ooooo`00COooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool4o`000003ooooool0003ooooo
00;ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo0_l00000
0ooooooo0000ooooo`03ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`000004ooooool0
003o0000ooooo`Go00000_ooool01?l0003oooooo`000?l0001Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00_ooool004kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo023ooooo1?l000000ooooooo0000ooooo`02ooooo`;o0000
00Coooooo`000?oooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Go
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002
ooooo`04o`000?oooooo0000o`0006;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`00@?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000Qooooo`03o`000?oo
oooooooo023ooooo1?l000000ooooooo0000ooooo`02ooooo`;o000000Coooooo`000?oooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0
003o0000Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo0010ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0001oooooo00?o0000ooooooooool08Oooool4o`00
0004ooooool0003oooooooooo`?o000000Coooooo`000?oooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`03o`000?oooooooooo00;o000000Co
ooooo`000?l0003ooooo1?l00003ooooo`04o`000?ooooooooooo`0006Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`00@?ooool01Ol@413ooooooooooooooooo410@00go
oooo0_l0000Mooooo`03o`000?oooooooooo027ooooo0_l000001?oooooo0000ooooool00002oooo
o`?o000000?oooooo`000?ooool00_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00003oooo
o`;o00001oooool00ol0003oooooo`000002o`000003ooooool0003o000000;o00000oooool01?l0
003oooooooooool0001Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
043ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08Oooool2o`000004ooooool0003oooooo`0000;ooooo0ol000000ooooooo0000oooo
o`02o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Cooooo0_l0
0007ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000_l00003ooooo`04o`000?oo
ooooooooo`0006Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00@?oo
ool01Ol0003ooooooooooooooooo0000013ooooo0_l0000Iooooo`03o`000?oooooooooo02;ooooo
0_l000001?oooooo0000ooooool00002ooooo`?o000000?oooooo`000?ooool00_l00002ooooo`03
o`000?oooooo000000Co000000?oooooo`000?l000001?ooool2o`0000Oooooo00?o0000ooooool0
00000_l000000ooooooo0000o`000002o`0000?ooooo00Co0000oooooooooooo0000I_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo0010ooooo`05oa0@4?oooooooooooooo
ool@41004Oooool2o`0001Sooooo00?o0000ooooooooool08_ooool2o`000004ooooool0003ooooo
o`0000;ooooo0ol000000ooooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00000_ooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooooooo00?o0000
00?oooooo`000?l000000_l00003ooooo`04o`000?ooooooooooo`0006Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`01ooooo`00@?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Rooooo`;o000000Coooooo`000?oo
oooo00000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`?o000000?oooooo`000?l000000_ooool01?l0003oooooo`000?l00005ooooo`03o`00
0?oooooooooo00?o000000?oooooo`000?l000000_l00003ooooo`04o`000?oooooo0000o`0006So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01ooooo`00@?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Cooooo0_l0000Eooooo`03o`000?oooooooooo02;ooooo0_l000001?oooooo
0000ooooool00003ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`06o`000?oooooooooo
ooooool0003ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool01?oo
ool00ol0003oooooooooo`03o`000003ooooool0003o000000;o00000oooool01?l0003oooooo`00
0?l0001Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool005_ooooo0_l0
000Booooo`03o`000?oooooooooo02?ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo
0_l000001Ooooooo0000ooooool0003ooooo00?o00000oooool02Ol0003oooooo`000?l0003ooooo
o`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00ol0
00000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0003o0000J_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo001Looooo`;o00004Oooool00ol0003ooooooooo
o`0Sooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`?o00000_ooool01Ol0003ooooo
o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003o`000003
ooooool0003ooooo00Cooooo00?o0000ooooooooool00ol000000ooooooo0000o`000002o`0000?o
oooo00Co0000ooooool0003o0000Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
007ooooo001Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool2o`000005
ooooool0003oooooooooool000000_ooool3o`0000;ooooo1?l00004ooooo`05o`000?oooooo0000
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00?o0000ooooooooool0
0ol000000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0003o0000Joooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001Oooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool09Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?o
000000Coooooo`000?l0003ooooo0_l00004ooooo`05o`000?oooooo0000ooooool000001Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00;o00000oooool3o`0000?ooooo00Co0000
ooooool0003o0000K?ooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1ooooo`00H?ooool3
o`0000_ooooo00?o0000ooooooooool09Oooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?ooool00_l00004ooooo`05o`000?oooooo0000ooooool00000
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;o00000oooool00ol0003ooooo
o`000003ooooo`04o`000?oooooo0000o`0006gooooo00?o0000ooooooooool02Oooool1o`00007o
oooo0Oooool0067ooooo0_l0000cooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
oooo0_l000001?oooooo0000ooooooooool2o`0000Cooooo00Go0000ooooool0003oooooo`000005
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00ol00002ooooo`?o00000oooool0
1?l0003oooooo`000?l0001^ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001S
ooooo`;o0000<Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?o000000Cooooo
o`000?oooooooooo0_l00004ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00?o00000_ooool3o`0000?ooooo00Co0000ooooool0003o
0000Koooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00IOooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00?o000000Goooooo`000?l0003oooooo`000002ooooo`;o
00001?ooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`03o`0000;ooooo0ol00003ooooo`04o`000?oooooo0000o`0006oooooo00?o0000
ooooooooool01oooool1o`00007ooooo0Oooool006Kooooo0_l0000`ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo00Go0000ooooool0003ooooo
o`000005ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooooooo0_l00002ooooo`?o
00000oooool01?l0003oooooo`000?l0001`ooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`7ooooo001Wooooo`;o0000;oooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00Co
0000oooooooooooooooo0_l00002ooooo`?o00000oooool01?l0003oooooo`000?l0001aooooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo02Kooooo
1ol00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000?o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003o0000
L_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00J_ooool2o`0002;ooooo1?l0
0006ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000ooooool0003o
0000Loooool00ol0003oooooooooo`04ooooo`7o00000Oooool006cooooo00?o0000ooooooooool0
7Oooool2o`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
00000oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooo`000?l0
001cooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00F_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`?o00007?ooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool000001Oooool2o`0000?ooooo00?o0000ooooooooool00_l00005oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Co0000ooooool0003o0000M?ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool005cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001Oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`04o`000?oooooo0000o`0007Gooooo00?o0000ooooooooool00_ooool1o`00007o
oooo001Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooo000001Oooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooo`00001gooooo`05o`000?ooooooooooooooool000000Oooool005cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000Fooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_l00005ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`00001hooooo`04o`000?ooooooooooo`00007ooooo001Looooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000<ooooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Go
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000007Sooooo00Co0000oooooooooooo0000
0Oooool005cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo
0_l0000Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000;o00001Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooool00000NOooool00ol0003oooooooooo`01o`000000G?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0000oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l00005
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`00001jooooo`7o00000Oooool1o`000000
F_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo0ol00005ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`00001kooooo`;o0000001hooooo`;o00003?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00001Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool00000N_ooool3o`000000N_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002
ooooo`?o00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ooo
ool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo0000MOooool5o`00
00?ooooo001kooooo`;o00002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`00
0?ooooooooooo`00077ooooo1?l00008ooooo`00O?ooool2o`0000Oooooo00?o0000ooooooooool0
7_ooool01?l0003oooooooooool00002ooooo`?o00001Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co
0000oooooooooooo0000KOooool4o`0000cooooo001nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00oooool3o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooooooo
o`0006Sooooo1Ol0000@ooooo`00Ooooool3o`0002Cooooo00?o0000ooooooooool00oooool3o`00
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Ko0000
ooooool0003o0000ooooool00002ooooo`04o`000?ooooooooooo`0006Cooooo1?l0000Eooooo`00
POooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`06o`000?oooooo0000o`00
0?oooooo00000_ooool01?l0003oooooooooool0001Oooooo`Go00006Oooool008;ooooo0_l0000R
ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01?l0003o
ooooooooool0001Kooooo`Co00007_ooool008Cooooo00?o0000ooooool000007oooool00ol0003o
ooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001Oooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00Co0000oooooooooooo0000
E_ooool5o`0002;ooooo0025ooooo`;o00007oooool00ol0003oooooooooo`03ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01_l0003ooooo
o`000?l0003oooooo`0000;ooooo00?o0000ooooool00000Doooool4o`0002Oooooo0026ooooo`;o
00007_ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00?o
0000ooooool00000Coooool4o`0002_ooooo001dooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Oooooo0_l000001ooooooo0000oooooooooooo0000oooo
ool00000B_ooool5o`0002oooooo001dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Qooooo`;o00001Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001oooool2o`000007ooooool0003oooooooooool0003o
ooooo`000016ooooo`Co0000=?ooool007Gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Wooooo0_l0000Pooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
047ooooo1Ol0000hooooo`00M_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000002oooool2o`0001kooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000?Oooool4
o`0003gooooo001gooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000=
ooooo`;o00007?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000iooooo`Co0000@Ooo
ool007Sooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o
0000ooooooooool06_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000dooooo`Go0000
AOooool007Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03oooool2o`0001[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000<?ooool4o`00
04[ooooo001dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^017ooooo00?o0000ooooool000005oooool2o`0000[ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000:oooool5o`0004kooooo002C
ooooo`;o00005oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000002Oooooo1?l0001Cooooo`00UOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooo000002;ooooo1Ol0001Gooooo`00U_ooool3o`0001?ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000001kooooo1?l0
001Looooo`00V?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00Co0000
oooooooooooo00003_ooool00ol0003oooooo`00000Jooooo`Co0000H?ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003_ooool00ol0003ooooooooo
o`0Eooooo`Go0000I?ooool009[ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo00Co0000
oooooooooooo00008_ooool4o`0006Wooooo002Looooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02_ooool01?l0003oooooooooool0000Mooooo`Go0000KOooool009cooooo0ol0000<
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00006Oooool4o`0007;ooooo002<
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo
1?l0001fooooo`00S?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`;o00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017o
oooo1Ol0001jooooo`00T?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool2o`0000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`Co
0000Ooooool008oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Go0000Poooool007Oooooo
00GoV9RHo`000?l0003oA4A4okZj^P0Booooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`Co0000R?ooool007Oo
oooo00Go410@okZj^_o^k^koMgMgoa0@400Cooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`Go0000S?ooool0
07Oooooo00?o0000ooooooooool04_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`05o`000?oooooo0000ooooool000002_ooool4o`00097ooooo
001gooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03oooool2o`000003ooooool0003ooooo00Gooooo1?l0002Eooooo`00
Moooool00ol0003oooooooooo`0_ooooo`?o000000?oooooo`000?l000000ol0002Iooooo`00MOoo
ool00ol@413o0000o`000003o`00033ooooo0_l0002Nooooo`00Moooool00ol0003oooooooooo`3A
ooooo`00Moooool00ol0003oooooooooo`3Aooooo`00oooooom<ooooo`00oooooom<ooooo`00oooo
oom<ooooo`00Y?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^09co
oooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Looooo`00
X_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@402Looooo`00X_ooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool00000W?ooool00:;ooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000009cooooo002Sooooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@402Looooo`00Xoooool00oo^k^koA4A4o`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0W?ooool00:Cooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^09cooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo
003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0033ooooo`04oa0@
4?l0003o0000o`0008Cooooo0034ooooo`03o`000?oooooooooo08Cooooo0034ooooo`03o`000?oo
oooooooo08Cooooo002Gooooo`05o`000?o<c<cogMgMo`000?o^k^h00_ooool01_nHV9So0000o`00
0?mgMgOo410@o`0000Cooooo00?o8B4Qoc8b<_ooool00oooool01_o^k^koEEEEo`000?l0003oA4A4
okZj^POooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3ooooo`09o`000?mgMgOo0000o`000?mE
EEGok^k^ooooooo^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OmVIVKo0000o`000?m4
A4Coc<c<00?ooooo00OoV9RHo`000?l0003oA4A4okZj^_oooooo410@00Go00001?ooool01_nHV9So
0000o`000?mgMgOo0000oa0@40;o00000_ooool01Ol0003oooooooooool0003o410@053ooooo002F
ooooo`06ojVYZOl0003oQhN7oiRHV?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Co
oooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Oooooo00Ko
0000ojVYZOoooooooooookZj^_l00003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomE
EEGoMgMgooooooo^k^koMgMgoa0@4002ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01Oooool01Ol0003oZJVYoooo
oon7QhOo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1?ooooo`00
U_ooool01_mEEEGoQhN7odA4A?mEEEGoMgMgoeEEE@;ooooo00Go410@ohN7Qoooooook^k^o`000004
ooooo`04oa0@4?nj^[[oV9RHoc8b<P?ooooo00?o0000ooooooooool02oooool01Onj^[[oQhN7ofIV
I_mVIVKo410@00?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
04oooooo002Fooooo`06o`000?oMgMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002
o`0000?ooooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00001oooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`00
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0Coooool009Gooooo00SoZJVYob4Q8OooooooQhN7oeEEEOoooooo<S8bojVYZ@Co
oooo00Ooc<c<o`000?ooooooooooonk^k_l0003ogMgM00;ooooo00[oV9RHoc8b<_oooooooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b1oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00go
0000oeEEEOo^k^koooooogMgMomVIVKooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00;ooooo00Ko
IVIVogMgMoooooooooooohN7Qol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oc8b<_oM
gMd01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoM
gMgo8B4Q057ooooo002Eooooo`?o00000_ooool3o`0000;ooooo00Co<S8bo`000?l0003oV9RH0_oo
ool00ol@413o0000o`000002ooooo`?o000000?oooooonk^k_mEEED00_l000000om4A4Cok^k^oooo
o`06ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool00ol@413o0000ogMgM`02o`000005
ofIVI_o^k^koooooonk^k_mEEED00_l000001_m4A4Cok^k^ooooooooooook^k^ofIVIP;o000000Co
A4A4o`000?oooooo410@1Ol00003ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o
0000ooooooooool2o`000009ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY057ooooo
003Looooo`03o`000?oooooooooo06cooooo003Looooo`03o`000?oooooooooo06cooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.163248, -0.0828824, \
0.00404337, 0.00404337}}],

Cell[TextData[{
  "Fig. 7.8 Spectrum associated with solution shown in Fig. ",
  ButtonBox["7.7",
    ButtonData:>"Fig. 7.7",
    ButtonStyle->"Hyperlink"]
}], "Caption",
  CellTags->"Fig. 7.8"],

Cell[TextData[{
  "\tThis leaves us in a bit of a quandary. By including dispersion in the \
KdV equation, which should make the equation a more accurate descriptor of \
water waves than Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " ,  we have actually lost wavebreaking, one of the main qualitative \
features of such waves.  "
}], "Text"],

Cell[TextData[{
  "\tThe solution to this puzzle lies in the approximate form of dispersion \
in the KdV equation. As already mentioned in connection with the rounded \
peaks of cnoidal waves, Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  "  is a poor approximation for large wavenumbers, yielding a phase velocity \
that can actually be negative for large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". The exact dispersion relation ",
  ButtonBox["(7.2.1)",
    ButtonData:>{"Chapter7.nb", "(7.2.1)"},
    ButtonStyle->"Hyperlink"],
  "  varies much less rapidly at large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", and results in weaker dispersion that allows real water waves to break, \
provided their amplitude is sufficiently large. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2.4 Shock Waves: Burgers' Equation", "Subsubtitle",
  CellTags->{"i:46", "c:23"}],

Cell[CellGroupData[{

Cell["Steady solutions", "Section",
  CellTags->"c:24"],

Cell[TextData[{
  "If we take the dispersive term ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^3 f/\[PartialD]x\^3\)]],
  " in the KdV equation, change the sign,  and lower the order of the \
derivative by one, we obtain ",
  StyleBox["Burgers'",
    FontSlant->"Italic"],
  StyleBox[" equation",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"i:47"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          f \[PartialD]f\/\[PartialD]x - \[Chi]\ \[PartialD]\^2 \
f\/\[PartialD]x\^2 = 0\)]],
  "."
}], "NE2",
  CellTags->"(7.2.26)"],

Cell[TextData[{
  "This nonlinear  equation is a simplified model for the propagation of \
shock waves. Now ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can be thought of as either the perturbed pressure or density of a gas \
due to a compressional wave, as seen in a frame moving with the linear wave \
speed.  The term proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " describes diffusion of these quantities due to viscosity or thermal \
conduction, and the nonlinear term qualitatively describes a nonlinear \
increase in wave speed when the wave pressure is large. The equation also has \
application to other areas, such as the study of nonlinear patterns in \
traffic flow (see the exercises). \t"
}], "Text"],

Cell[TextData[{
  "\tA steady solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can be found using the same techniques as were used for the KdV equation. \
The solution travels to the right with speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ", takes on one value, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f\_\(-\[Infinity]\)\)\)\)]],
  ", at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ \(-\[Infinity]\)\)]],
  ", and takes a lower value, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f\_\[Infinity]\)\)\)]],
  ", at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(+\[Infinity]\)\)]],
  ".  The form of the solution is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x, t)\), "=", 
          RowBox[{"v", " ", "-", " ", 
            RowBox[{
              FractionBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["f",
                      FontSlant->"Italic"]}]], "2"], 
              RowBox[{"tanh", "[", 
                RowBox[{
                  FractionBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["f",
                          FontSlant->"Italic"]}]], \(4\ \[Chi]\)], \((x - 
                      v\ t)\)}], "]"}]}]}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(7.2.27)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["f",
                FontSlant->"Italic"]}]], " ", "=", 
          " ", \(f\_\(-\[Infinity]\) - f\_\[Infinity]\)}], 
        TraditionalForm]]],
  " is the jump in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " across the shock (see the exercises). The speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " of the shock is related to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f\_\(-\[Infinity]\)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\[Infinity]\)]],
  " according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v = \(1\/2\) \((f\_\(-\[Infinity]\) + 
              f\_\[Infinity])\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.28)"],

Cell[TextData[{
  "This relation between shock speed and the amplitude at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Infinity]\)\)]],
  " is called a ",
  StyleBox["Hugoniot relation",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:48"],

Cell[TextData[{
  "\tA typical shock solution is plotted in Cell ",
  ButtonBox["7.52",
    ButtonData:>"Cell 7.52",
    ButtonStyle->"Hyperlink"],
  ", in the co-moving frame. In this example, we assume that ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\[Infinity] = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[1/2\  - \ 1/2\ Tanh[x/4], {x, \(-20\), 20}, 
        AxesLabel \[Rule] {"\<(x- v t)\[CapitalDelta]f/\[Chi]\>", "\<f(x,t)/\
\[CapitalDelta]f\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.52"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.588631 [
[.02381 .00222 -9 -9 ]
[.02381 .00222 9 0 ]
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 76.1875 6 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25017 -18 -4.5 ]
[.4875 .25017 0 4.5 ]
[.4875 .36789 -18 -4.5 ]
[.4875 .36789 0 4.5 ]
[.4875 .48562 -18 -4.5 ]
[.4875 .48562 0 4.5 ]
[.4875 .60335 -6 -4.5 ]
[.4875 .60335 0 4.5 ]
[.5 .64303 -29 0 ]
[.5 .64303 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-20)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-10)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(10)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(H) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
99.000 13.000 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(L) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(\\220) show
129.188 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
135.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25017 m
.50625 .25017 L
s
[(0.4)] .4875 .25017 1 0 Mshowa
.5 .36789 m
.50625 .36789 L
s
[(0.6)] .4875 .36789 1 0 Mshowa
.5 .48562 m
.50625 .48562 L
s
[(0.8)] .4875 .48562 1 0 Mshowa
.5 .60335 m
.50625 .60335 L
s
[(1)] .4875 .60335 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22074 m
.50375 .22074 L
s
.5 .2796 m
.50375 .2796 L
s
.5 .30903 m
.50375 .30903 L
s
.5 .33846 m
.50375 .33846 L
s
.5 .39732 m
.50375 .39732 L
s
.5 .42676 m
.50375 .42676 L
s
.5 .45619 m
.50375 .45619 L
s
.5 .51505 m
.50375 .51505 L
s
.5 .54448 m
.50375 .54448 L
s
.5 .57391 m
.50375 .57391 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
(\\220) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .60331 L
.04262 .60331 L
.06244 .60329 L
.07298 .60327 L
.08426 .60325 L
.10458 .6032 L
.1148 .60317 L
.12589 .60312 L
.13547 .60307 L
.14603 .603 L
.16586 .60282 L
.17672 .60268 L
.18689 .60253 L
.19727 .60233 L
.20714 .60209 L
.22566 .6015 L
.23525 .60109 L
.24547 .60055 L
.26386 .59924 L
.27414 .59826 L
.28527 .59694 L
.29488 .59552 L
.30544 .59361 L
.32538 .58868 L
.33627 .58503 L
.34644 .58083 L
.35689 .57557 L
.36679 .56952 L
.38535 .55473 L
.40526 .53253 L
.42368 .50469 L
.44234 .46822 L
.46295 .41809 L
.50315 .2993 L
.54184 .18746 L
.56148 .14165 L
.58298 .10242 L
.6035 .07484 L
.6226 .05638 L
.63312 .0486 L
.64306 .04252 L
.66165 .03383 L
.67137 .03039 L
.68166 .02741 L
.70011 .02339 L
.70955 .02185 L
.71969 .0205 L
.738 .01866 L
.74813 .01791 L
Mistroke
.75917 .01725 L
.76972 .01675 L
.77928 .01638 L
.79899 .01582 L
.8098 .01559 L
.81997 .01542 L
.82976 .01529 L
.84009 .01518 L
.85858 .01503 L
.86808 .01497 L
.87825 .01492 L
.8966 .01486 L
.9068 .01483 L
.91788 .01481 L
.92746 .01479 L
.93801 .01477 L
.95654 .01476 L
.96668 .01475 L
.97619 .01474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`002?ooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0`ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kVSooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^;oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Wooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0booooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1Zooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0_ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
06Oooooo0006o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
02Oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Z
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400`ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@401Wooooo`002_ooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000J_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000<Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000Ioooool0
00_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000003;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000006[ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000003;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000006Oooooo000<ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Zoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400cooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`1Uooooo`002?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0booooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1Zooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0_ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg06Oooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^033ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06So
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02oooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Ioooool00?oooooo4?ooool0
0omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo01[ooooo00GoEEEEoiRHV?ooooooooooolc<
c002o`000003oiRHV?oooooooooo00;ooooo0023ooooo`03o`000?oooooooooo08Sooooo00?ogMgM
oa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@0Eooooo`03ob4Q8OoMgMgooooo00?ooooo00GoEEEE
oiRHV?ooooooEEEEohN7Q`06ooooo`00Poooool00ol0003oooooooooo`28ooooo`04oeEEEOnHV9So
ooooooooo`;o00000_ooool2o`0001?ooooo00?o8B4Qoc8b<_ooool02oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00?oQhN7ofIVI_ooool00oooool00olb<S;o0000o`000003o`000004oc8b
<_oooooooooooa0@40Co000000Go410@ooooooooooooV9RHoeEEE@04ooooo`05onk^k_lb<S;oc<c<
ob4Q8Oo<c<`01_ooool008?ooooo00?o0000ooooooooool0R?ooool02_l0003ooooooooooooooooo
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMdBooooo`04oiRHV?lb<S;o410@okZj^P_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4002ooooo`03onk^k_l0003ooooo00?ooooo00?oV9RHodA4A?ooool00_ooool0
0om4A4CoV9RHooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000omgMgOooool00oooool0
0oo^k^ko<S8bo`000007ooooo`001Oooooomo`0000cooooo00?o<S8booooooooool00_ooool01?oM
gMgo0000oa0@4?o<c<`3ooooo`Ko00002_ooool01?l@413o^[ZjoiRHV?lb<S8;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool01Ol@413ogMgMoooooooMgMgo410@00Gooooo
00?o0000ooooooooool01?ooool2ogMgM`Gooooo00?oZJVYoa0@4?o^k^h01_ooool000_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo4ol0
0007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o<S8booooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^hBooooo`06oiRHV?lb<S;oooooooooool@413o^[Zj2_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`05ooooo`03o`000?oooooo
oooo00Cooooo00?ok^k^oa0@4?o^k^h01?ooool01?mgMgOoA4A4oc8b<_o^k^h5ooooo`002oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;Oooool:
o`0000;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?o^k^ko
oooo00;ooooo00Co8B4QogMgMomgMgOo<S8b4Oooool00oo^k^ko0000omgMg@02ooooo`03oiRHV?lb
<S;ooooo00Wooooo00?o0000ooooooooool01?ooool00oo^k^ko0000ooooo`04ooooo`05onk^k_l@
413ok^k^oa0@4?o^k^h01Oooool00ol0003oooooooooo`05ooooo`03oeEEEOnHV9Sooooo00?ooooo
00Co<S8bojVYZOnHV9SoEEEE1Oooool008?ooooo00?o0000ooooooooool0:_ooool3o`0005_ooooo
00CoEEEEogMgMooooooooooo0_l00002ooooo`;o00004?ooool00ol@413o0000o`000002ooooo`?o
00001oooool00ol@413o0000o`000003o`0000?ooooo00?oMgMgoeEEEOooool01Oooool00omgMgOo
8B4QoeEEE@04ooooo`03oa0@4?l0003o000000?o00001?ooool02ooMgMgo410@oooooooooooo<S8b
o`000?lQ8B7ok^k^oooooonHV9SoEEEE00Cooooo0023ooooo`03o`000?oooooooooo02Oooooo0ol0
001Nooooo`03omgMgOl@413ok^k^02Sooooo00?o0000ooooooooool00oooool00oo^k^ko410@omgM
g@06ooooo`03omgMgOl0003ogMgM00Kooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHoooo
o`0;ooooo`00Poooool00ol0003oooooooooo`0Uooooo`;o0000H_ooool00omgMgOoIVIVooooo`0W
ooooo`03o`000?oooooooooo00?ooooo00?oIVIVogMgMoooool01oooool00onYZJWoooooooooo`05
ooooo`03oa0@4?nj^[[ooooo00Kooooo00?o^[ZjodA4A?ooool02oooool008?ooooo00?o0000oooo
ooooool08_ooool3o`000:Kooooo00Co^[Zjoa0@4?l0003o410@4oooool008?ooooo00?o0000oooo
ooooool08?ooool2o`000<3ooooo0023ooooo`;o00008?ooool00ol0003oooooooooo`30ooooo`00
Poooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0<7ooooo0023ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0`_ooool008?ooooo00?o0000ooooooooool06oooool2
o`000<Gooooo0023ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0aOooool008?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`36ooooo`00Poooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0<Oooooo0023ooooo`;o00006?ooool00ol0003ooooooooo
o`38ooooo`00Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Sooooo0023oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0bOooool008?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`3:ooooo`00Poooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0<_ooooo0023ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0booo
ool008?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3<ooooo`00Poooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0<gooooo0023ooooo`;o00004oooool00ol0003o
ooooooooo`3=ooooo`00Poooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<kooooo
0023ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0coooool008?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`3?ooooo`00JOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0=3ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0d?oo
ool006Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`3Aooooo`00JOooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000kooooo00?o0000ooooooooool0d_oo
ool006Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`3Booooo`00JOooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0=?ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3Cooooo`00JOoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0e?ooool008?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3Dooooo`00Poooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0=Cooooo0023ooooo`;o00002oooool00ol0003oooooooooo`3Eooooo`00Poooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0=Gooooo0023ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0e_ooool008?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`3Fooooo`00Poooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Oooooo0023
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0eoooool008?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`3Gooooo`00Poooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0=Sooooo0023ooooo`;o00002?ooool00ol0003oooooooooo`3Hooooo`00Pooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Sooooo0023ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0fOooool008?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3Iooooo`00Poooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Wo
oooo0023ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0f_ooool008?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3Jooooo`00Poooool2o`0000Kooooo00?o0000
ooooooooool0f_ooool008?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Koooo
o`00Poooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=_ooooo0023ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0foooool008?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3Looooo`00JOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0=cooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=cooooo001Y
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3Mooooo`00JOooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool2o`0000?ooooo00?o0000ooooooooool0gOooool006Wooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3Mooooo`00JOooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001_ooool01Ol0003ooooooooooooooooo00000>3ooooo001Yooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006ooooo`05o`000?oooooooooo
ooooool00000h?ooool006Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Gooooo00Go0000ooooooooooooooooo`00003Pooooo`00Poooool01?l0003oooooooooool0
003Qooooo`00Poooool01?l0003oooooooooool0003Qooooo`00Poooool2o`000003ooooool0003o
oooo0>3ooooo0023ooooo`03o`000?oooooo00000>;ooooo0023ooooo`03o`000?oooooo00000>;o
oooo0023ooooo`03o`000?oooooo00000>;ooooo0023ooooo`;o0000hoooool008?ooooo0_l0003S
ooooo`00Poooool2o`000>?ooooo0023ooooo`03o`000?oooooooooo0>;ooooo0023ooooo`;o0000
hoooool008?ooooo00?o0000ooooooooool0h_ooool008;ooooo0_l0003Tooooo`00P_ooool2o`00
0>Cooooo0022ooooo`;o0000i?ooool0087ooooo00?o0000ooooool00000i?ooool0087ooooo00?o
0000ooooool00000i?ooool0087ooooo00Co0000ooooool0003o0000hoooool0083ooooo00Co0000
oooooooooooo0000i?ooool0083ooooo00Co0000oooooooooooo0000i?ooool0083ooooo00Co0000
oooooooooooo0000i?ooool007oooooo00Go0000ooooooooooooooooo`00003Tooooo`00JOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`07onk^k_lb<S;o0000oa0@4?o<c<co
ooooo`000003ooooo`03o`000?oooooooooo0>;ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00OoEEEEogMgMoooooooV9RHob4Q8Ooooooo000000?ooooo00?o0000
ooooooooool0h_ooool006Wooooo00Go410@oooooooooooooooooa0@400;ooooo`04o`000?oooooo
ooooooooo`;o00001?ooool2o`000>?ooooo001Yooooo`05o`000?ooooooooooooooool000002ooo
ool01_l0003oV9RHoooooonHV9So8B4Qo`0000Cooooo00?o0000ooooooooool0h_ooool006Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`06o`000?mEEEGo0000oa0@4?o<c<co00001?ooool0
0ol0003oooooooooo`3Rooooo`00JOooool01Ol@413ooooooooooooooooo410@00_ooooo00GoEEEE
ohN7Qoooooooooooo`000005ooooo`03o`000?oooooooooo0>;ooooo001Yooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01OoMgMgo410@oiRHV?oooooo000000Gooooo00?o0000ooooooooool0
h_ooool006Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000o`0000Go
oooo00?o0000ooooooooool0h_ooool007cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3Rooooo`00O?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>;ooooo001l
ooooo`03o`000?oooooooooo00Cooooo0_l0003Sooooo`00Noooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0>;ooooo001kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0h_ooool007_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Rooooo`00N_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>;ooooo001jooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0h_ooool007[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3Rooooo`00NOooool00ol0003oooooooooo`07ooooo`;o0000hoooool007Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3Rooooo`00N?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0>;ooooo001hooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0h_ooool007Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Roooo
o`00Moooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0>;ooooo001gooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0h_ooool007Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`3Rooooo`00M_ooool00ol0003oooooooooo`0:ooooo`;o0000hoooool0
07Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Rooooo`00MOooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0>;ooooo001dooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0h_ooool007Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`3Rooooo`00JOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ob4Q8Oooool00ooo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0h_ooool006Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00?ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@05ooooo`03o`000?oooooooooo0>;ooooo001Yooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool2o`00
0>?ooooo001Yooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3Rooooo`00JOooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool01Oo<c<co0000o`000?l0
003oc<c<00Gooooo00?o0000ooooooooool0h_ooool006Wooooo00Go410@oooooooooooooooooa0@
4003ooooo`03o`000?oooooooooo00Gooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`00
0?oooooooooo0>;ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooo
ooooo`05ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3Rooooo`00
JOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool01_ooool01OnYZJWo
410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0h_ooool0073ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`3Rooooo`00Koooool00ol0003oooooooooo`0Aooooo`;o0000
hoooool006kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3Rooooo`00KOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0>;ooooo001]ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0h_ooool006cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`3Rooooo`00Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>;ooooo
001Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0h_ooool006Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`3Rooooo`00J?ooool00ol0003oooooooooo`0Hoooo
o`;o0000hoooool006Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3Rooooo`00
IOooool2o`0001cooooo00?o0000ooooooooool0h_ooool006Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`3Rooooo`00Hoooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo0>;ooooo001Rooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0h_ooool0067o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3Rooooo`00H?ooool00ol0003ooooo
ooooo`0Pooooo`;o0000hoooool005kooooo0_l0000Sooooo`03o`000?oooooooooo0>;ooooo001K
ooooo`?o00009Oooool00ol0003oooooooooo`3Rooooo`00FOooool2o`0002Sooooo00?o0000oooo
ooooool0h_ooool005Gooooo1?l0000Zooooo`03o`000?oooooooooo0>;ooooo001Aooooo`Co0000
9Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0h_ooool004Wooooo2?l0
000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0h_ooool003Kooooo4ol0000c
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0h_ooool000_ooooo:ol00016oooo
o`03o`000?oooooooooo00Cooooo0_l0003Sooooo`00O?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>;ooooo001looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
h_ooool007cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Rooooo`00N_ooool0
0omEEEGoIVIVo`00003[ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00K_ooool00omgMgOoIVIV
ooooo`09ooooo`03o`000?nj^[[ooooo00_ooooo00?oIVIVogMgMoooool0gOooool006gooooo00?o
gMgMoa0@4?o^k^h02_ooool2oc8b<Pcooooo00?ok^k^oa0@4?oMgMd01Oooool00olQ8B7ogMgMoooo
o`3Eooooo`00H_ooool00ol@413o0000o`000002o`000003oa0@4?oooooooooo00?ooooo00CoEEEE
oiRHV?oooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00on7QhOoIVIVooooo`04ooooo`03oiRHV?mEEEGooooo00?ooooo
00?o<S8bo`000?l000000ol000001?lb<S;oooooooooool@4104o`000003oa0@4?oooooooooo0<7o
oooo001Tooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
0oooool00oo^k^ko0000ooooo`05ooooo`03o`000?oMgMgooooo00;ooooo00?oV9RHodA4A?ooool0
0_ooool00om4A4CoV9RHooooo`03ooooo`03o`000?oooooooooo0<Cooooo001Tooooo`03o`000?oo
oooooooo00Kooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool2ogMgM`Cooooo00Go410@omgMgOoooooo
gMgMoa0@4005ooooo`03o`000?oooooooooo0<Cooooo001Tooooo`03o`000?oooooooooo00Kooooo
00?o<S8booooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool00oo^k^ko410@onk^kP03ooooo`05ohN7QomgMgOoooooofIV
I_n7QhL01Oooool00ol0003oooooooooo`34ooooo`00I?ooool00ol0003oooooooooo`06ooooo`03
o`000?o^k^kooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05oooo
o`03onk^k_l0003ooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool01Oo^k^ko410@onk^k_l@413o
k^k^00Gooooo00?o0000ooooooooool0a?ooool006;ooooo00?o410@o`000?l000000ol00005oooo
o`04oeEEEOmgMgOoooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004
ooooo`03ogMgMomEEEGooooo00Kooooo00?ogMgMoa0@4?ooool00oooool00omgMgOo8B4QoeEEE@04
ooooo`03oa0@4?l0003o000000?o0000`oooool006Cooooo00?o0000ooooooooool01_ooool00ooM
gMgo410@onk^kP0Aooooo`03o`000?oooooooooo00Cooooo00?ok^k^oa0@4?oMgMd02?ooool00omE
EEGoV9RHooooo`02ooooo`03omgMgOl0003ogMgM00Kooooo00?o0000ooooooooool0a?ooool006Co
oooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?oIVIVogMgMoooool02?ooool00onj^[[oA4A4ooooo`03ooooo`03ojVYZOoooooooooo00Go
oooo00?o410@okZj^_ooool0a?ooool006Cooooo00Co^[Zjoa0@4?l0003o410@>Oooool01?nj^[[o
410@o`000?l@4133ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.8736, -0.209845, \
0.208158, 0.00841976}}]
}, Open  ]],

Cell[TextData[{
  "According to Eq. ",
  ButtonBox["(7.2.27)",
    ButtonData:>{"Chapter7.nb", "(7.2.27)"},
    ButtonStyle->"Hyperlink"],
  "  the width of the shock depends on the diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " and on the jump ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["f",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", scaling roughly as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", "/", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["f",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ". The smaller the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ", or the larger the jump, the narrower the shock. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["CTCS/Crank-Nicolson approach", "Section",
  CellTags->"c:25"],

Cell[TextData[{
  "For numerical solutions of Burgers' equation,  the Galerkin method used in \
Sec. ",
  ButtonBox["7.2.3",
    ButtonData:>"c:18",
    ButtonStyle->"Hyperlink"],
  " for the KdV equation can be easily adapted. This is left to the \
exercises. Here, we will instead use a grid method, for practice. We solve \
the problem under periodic boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ x < L\)]],
  " and take ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M - 1\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(L/M\)}], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:75"],

Cell[TextData[{
  "\tThe first two terms of Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  "  are of the form of the wave equation ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " , and hence we expect that the CTCS method will work for these terms. The \
equation is nonlinear, which hinders von Neuman stability analysis, but if we \
replace ",
  Cell[BoxData[
      \(TraditionalForm\`f \[PartialD]f/\[PartialD]x\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`c \[PartialD]f/\[PartialD]x\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is a constant,  then one can show that the CTCS method is stable provided \
that time step that satisfies the Courant condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"c", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], "\[LessEqual]", " ", "1"}], 
        TraditionalForm]]],
  " [see Eq. ",
  ButtonBox["(6.2.44)",
    ButtonData:>{"Chapter6.nb", "(6.2.44)"},
    ButtonStyle->"Hyperlink"],
  " ].  Thus, we might hope that if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "\[LessEqual]", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "/", "max"}]}], "|", "f", "|"}], 
        TraditionalForm]]],
  ", the CTCS method will be stable. Actually, it  turns out that sharp \
gradients in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can also destabilize the method, but for sufficiently small time step \
this method works well. "
}], "Text"],

Cell[TextData[{
  "\tHowever, the last term in Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  "  is diffusive, which (as we saw in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>{"Chapter6.nb", "c:17"},
    ButtonStyle->"Hyperlink"],
  ") causes instability in the CTCS method. For the diffusion term we \
therefore use a variant of  the Crank-Nicolson scheme, taking the average of \
the diffusion operator at two time steps centered around time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". The resulting difference equation is given below: "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(f\_j\%\(n + 1\) - f\_j\%\(n - 1\)\), 
              RowBox[{"2", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]], "+", 
            RowBox[{\(f\_j\%n\), 
              FractionBox[\(f\_\(j + 1\)\%n - f\_\(j - 1\)\%n\), 
                RowBox[{"2", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}]]}], "-", 
            RowBox[{\(\[Chi]\/2\), 
              RowBox[{"(", 
                RowBox[{
                  
                  FractionBox[\(f\_\(j + 1\)\%\(n + 1\) - 
                      2  f\_j\%\(n + 1\) + f\_\(j - 1\)\%\(n + 1\)\), 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"]], "+", 
                  
                  FractionBox[\(f\_\(j + 1\)\%\(n - 1\) - 
                      2  f\_j\%\(n - 1\) + f\_\(j - 1\)\%\(n - 1\)\), 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"]]}], ")"}]}]}], 
          "=", \(S\_j\%n\)}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(7.2.29)"],

Cell[TextData[{
  "For future reference, note that we have added a finite-differenced source \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(S(x, t)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " to the ",
  "right-hand",
  " side of the equation. "
}], "Text"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(7.2.29)",
    ButtonData:>{"Chapter7.nb", "(7.2.29)"},
    ButtonStyle->"Hyperlink"],
  "  is an implicit method. To solve it, we could apply  the Crank-Nicholson \
algorithm that we used in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>{"Chapter6.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ", but instead we will write the procedure in a different way, using a form \
of operator splitting that we haven't seen before.   First, we set up the \
grid and choose values for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\[IndentingNewLine]", 
    \(M = 40; 
    L = 4; \[CapitalDelta]x\  = \ L/M; \[CapitalDelta]t\  = \ 0.03; \[Chi] = 
      0.1;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.53"],

Cell[TextData[{
  "Next, in order to simplify notation, we split the operator, first taking \
the CTCS step and keeping that part of the Crank-Nicolson diffusion operator \
that depends on previous times.  We place the result in an intermediate array \
",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(F\_j\%\(n + 1\)\), "=", 
          RowBox[{\(f\_j\%\(n - 1\)\), "-", 
            RowBox[{"2", "\[CapitalDelta]t", " ", \(f\_j\%n\), 
              FractionBox[\(f\_\(j + 1\)\%n - f\_\(j - 1\)\%n\), 
                RowBox[{"2", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}]]}], "+", 
            RowBox[{"\[Chi]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox[\(d\_2\),
                  FontSlant->"Italic"], 
                StyleBox["(",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Italic"], 
                  StyleBox[",",
                    FontSlant->"Italic"], "j", ",", \(n - 1\)}], 
                StyleBox[")",
                  FontSlant->"Italic"]}]}], "+", " ", 
            RowBox[{"2", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}]}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(7.2.30)"],

Cell[TextData[{
  "where we have introduced a finite-difference operator ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(d\_2\)(f, j, n)\), "=", 
          FractionBox[\(f\_\(j + 1\)\%n - 2  f\_j\%n + f\_\(j - 1\)\%n\), 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]]}], TraditionalForm]]],
  " in order to further simply the notation. Defined as a recursion relation, \
the ",
  "left-hand",
  " side of Eq. ",
  ButtonBox["(7.2.30)",
    ButtonData:>{"Chapter7.nb", "(7.2.30)"},
    ButtonStyle->"Hyperlink"],
  "  must be evaluated at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(F[j_, n_]\  := \ 
      f[j, n - 2]\  - \ \[CapitalDelta]t \( f[j, 
                n - 1]\/\(\(\ \)\(\[CapitalDelta]x\)\)\) \((f[j + 1, n - 1] - 
              f[j - 1, n - 1])\) + \ \[Chi]\ \[CapitalDelta]t\ d2[f, j, 
            n - 2]\  + \ 2\ \[CapitalDelta]t\ S[j, n - 1]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.54"],

Cell[BoxData[
    \(d2[f_, j_, 
        n_]\  := \ \(f[j + 1, n] - 2  f[j, n] + f[j - 1, \
n]\)\/\[CapitalDelta]x\^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.55"],

Cell[TextData[{
  "We then solve coupled equations for ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%\(n + 1\)\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_j\%\(n + 1\)\), "=", 
          RowBox[{\(F\_j\%\(n + 1\)\), "+", 
            RowBox[{"\[Chi]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(\(d\_2\)(f, j, n + 1)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(7.2.31)"],

Cell[TextData[{
  "Equations  ",
  ButtonBox["(7.2.30)",
    ButtonData:>{"Chapter7.nb", "(7.2.30)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  "  are identical to Eq.  ",
  ButtonBox["(7.2.29)",
    ButtonData:>{"Chapter7.nb", "(7.2.29)"},
    ButtonStyle->"Hyperlink"],
  " . Note that this form of operator splitting differs in concept from that \
used previously in Eqs. ",
  ButtonBox["(6.2.31)",
    ButtonData:>{"Chapter6.nb", "(6.2.31)"},
    ButtonStyle->"Hyperlink"],
  " . There, different forms of the ",
  StyleBox["full",
    FontSlant->"Italic"],
  " operator were used in two substeps of size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "/", "2"}], TraditionalForm]]],
  " . Here,  the full ",
  "time step",
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is taken for each substep, but only ",
  StyleBox["pieces",
    FontSlant->"Italic"],
  " of the operator are used in each."
}], "Text",
  CellTags->"i:79"],

Cell[TextData[{
  "\tTo solve Eq. ",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  "  we introduce dummy variables ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_j\%n\)]],
  " to replace ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  ". The reason is that the equations in ",
  StyleBox["Solve ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "must be in terms of unknown quantities, but the ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  "'s are determined recursively by the procedure and so are not unknown \
variables. After the equations are solved for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_j\%n\)]],
  ", we use these values to update ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  "."
}], "Text"],

Cell["\tThe variables used in the equations are ", "Text"],

Cell[BoxData[
    \(\(vars[n_]\  = \ \ Table[\[Rho][j, n], {j, 0, M - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.56"],

Cell[TextData[{
  "In these variables, Eq. ",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  "  becomes a list of equations:"
}], "Text"],

Cell[BoxData[
    \(\(eqns[n_]\  := \ 
        Table[\[Rho][j, 
              n]\  == \ \ F[j, 
                n]\  + \ \[Chi]\ \[CapitalDelta]t\ d2[\[Rho], j, n], {j, 0, 
            M - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.57"],

Cell[TextData[{
  "Now we solve these equations (once) at the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["n",
              FontSlant->"Italic"], "th"}]], TraditionalForm]]],
  " step:"
}], "Text"],

Cell[BoxData[
    \(varsn[
        n_]\  := \(varsn[
          n]\  = \ \ vars[
            n] /. \(Solve[eqns[n], vars[n]]\)[\([1]\)]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.58"],

Cell[TextData[{
  "Then we substitute the results into ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(f[j_, n_]\  := \((f[j, n]\  = \(varsn[n]\)[\([j + 1]\)])\) /; \ 
        n > 1\  && \ 0 \[LessEqual] \ j \[LessEqual] \ M - 1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.59"],

Cell[TextData[{
  "Since we will solve for points on the grid from ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " up to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M - 1\)\(,\)\)\)]],
  " the above equations will require values for points ",
  Cell[BoxData[
      \(TraditionalForm\`j = \(-1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = M\)]],
  ".  According to the periodic boundary conditions, these points are \
equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`j = M - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " respectively. Boundary conditions for both ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and the dummy variable ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " must be specified:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Rho][\(-1\), n_]\  := \ \[Rho][M - 1, n];\)\), "\n", 
    \(\(\[Rho][M, n_]\  := \[Rho][0, n];\)\ \), "\n", 
    \(\(f[\(-1\), n_]\  := \ f[M - 1, n];\)\), "\n", 
    \(\(f[M, n_]\  := f[0, n];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.60"],

Cell[TextData[{
  "Also, the first time step must be treated differently, since in the CTCS \
step ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " calls ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(-1\)\)]],
  ". The simplest approach is to apply FTCS to the equation for this one time \
step. This is only first -order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", but that is sufficient to our needs here. A second-order scheme \
involving the predictor-corrector method is discussed in the exercises. Here \
we take"
}], "Text"],

Cell[BoxData[
    \(f[j_, 
        1]\  := \(f[j, 
          1]\  = \ \ f[j, 
            0] - \ \[CapitalDelta]t\ f[j, 
              0] \(f[j + 1, 0] - f[j - 1, 0]\)\/\(\(\ \
\)\(\[CapitalDelta]x\)\) + \ \[Chi]\ \[CapitalDelta]t\ d2[f, j, 
              0]\  + \ \[CapitalDelta]t\ S[j, 0]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.61"],

Cell[TextData[{
  "For the source, we take ",
  Cell[BoxData[
      \(TraditionalForm\`S = 0\)]],
  ","
}], "Text"],

Cell[BoxData[
    \(\(S[j_, n_]\  = \ 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.62"],

Cell[TextData[{
  " and  for the initial condition, we take a simple sine wave, offset from \
the origin so that it propagates to the right as shown in Cell ",
  ButtonBox["7.63",
    ButtonData:>"Cell 7.63",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f[j_, 0]\  := 1 + Sin[j\ \[CapitalDelta]x\ Pi];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Table[{j\ \[CapitalDelta]x, f[j, n]}, {j, 0, M}], 
          PlotRange \[Rule] {0, 2}, 
          PlotLabel -> "\<t = \>" <> ToString\ [n\ \[CapitalDelta]t]], {n, 0, 
          80, 2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.63"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30902 Mdot
.04762 .40451 Mdot
.07143 .49065 Mdot
.09524 .55902 Mdot
.11905 .60291 Mdot
.14286 .61803 Mdot
.16667 .60291 Mdot
.19048 .55902 Mdot
.21429 .49065 Mdot
.2381 .40451 Mdot
.2619 .30902 Mdot
.28571 .21353 Mdot
.30952 .12738 Mdot
.33333 .05902 Mdot
.35714 .01512 Mdot
.38095 0 Mdot
.40476 .01512 Mdot
.42857 .05902 Mdot
.45238 .12738 Mdot
.47619 .21353 Mdot
.5 .30902 Mdot
.52381 .40451 Mdot
.54762 .49065 Mdot
.57143 .55902 Mdot
.59524 .60291 Mdot
.61905 .61803 Mdot
.64286 .60291 Mdot
.66667 .55902 Mdot
.69048 .49065 Mdot
.71429 .40451 Mdot
.7381 .30902 Mdot
.7619 .21353 Mdot
.78571 .12738 Mdot
.80952 .05902 Mdot
.83333 .01512 Mdot
.85714 0 Mdot
.88095 .01512 Mdot
.90476 .05902 Mdot
.92857 .12738 Mdot
.95238 .21353 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo000`ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`1Qooooo`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000<oooool0
033ooooo0_l0001Rooooo`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000<oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo05[ooooo0_l0000Kooooo`;o0000L_ooool2o`0001[ooooo0_l0
000/ooooo`00<?ooool2o`0005_ooooo0_l0000Kooooo`;o0000L_ooool2o`0001[ooooo0_l0000/
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo
000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000:Oooool2o`0006?o
oooo0_l0000Zooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0Doooool2o`0002Wooooo
0_l0001Sooooo`;o0000:_ooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`005Oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Eoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo04cooooo0_l0000gooooo`;o0000
EOooool2o`0003Sooooo0_l0000Mooooo`00<?ooool2o`0004gooooo0_l0000gooooo`;o0000EOoo
ool2o`0003Sooooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01?ooool4o`00
04Cooooo0_l00017ooooo`;o0000A_ooool2o`0004Kooooo0_l0000Fooooo`00:?ooool00ol0003o
ooooooooo`04ooooo`;o0000A_ooool2o`0004Oooooo0_l00016ooooo`;o0000A_ooool2o`0001Ko
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0000hooooo`;o0000EOooool2
o`0003Sooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000>?ooool2o`00
05Gooooo0_l0000hooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0000Yooooo`;o0000Hooo
ool2o`0002Wooooo0_l0001]ooooo`00<?ooool2o`0000cooooo0_l0000Yooooo`;o0000Hoooool2
o`0002Wooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o00004oooool2o`0001_ooooo0_l0001aooooo`;o00006oooool2o`0007Cooooo000`ooooo`03
o`000?oooooooooo01;ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0001dooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0000Jooooo`;o00003?ooool2o`00083ooooo0_l0000=ooooo`;o0000Noooool0
033ooooo00?o0000ooooooooool06Oooool2o`0000cooooo0_l00020ooooo`;o00003Oooool2o`00
07_ooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l00022ooooo`009ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o00008?ooool2o`0008oooooo0_l00022ooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Fooooo`00/?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0U_ooool00;3ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@09Ko
oooo002`ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool0
0000U_ooool00;3ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000009Ko
oooo002^ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@09Ko
oooo002`ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Fooooo`00
/?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0U_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .27173 Mdot
.04762 .34835 Mdot
.07143 .41817 Mdot
.09524 .47786 Mdot
.11905 .52653 Mdot
.14286 .56351 Mdot
.16667 .58514 Mdot
.19048 .58368 Mdot
.21429 .55035 Mdot
.2381 .48134 Mdot
.2619 .38294 Mdot
.28571 .27126 Mdot
.30952 .16641 Mdot
.33333 .08487 Mdot
.35714 .03507 Mdot
.38095 .01789 Mdot
.40476 .03006 Mdot
.42857 .06702 Mdot
.45238 .12378 Mdot
.47619 .19439 Mdot
.5 .27173 Mdot
.52381 .34835 Mdot
.54762 .41817 Mdot
.57143 .47786 Mdot
.59524 .52653 Mdot
.61905 .56351 Mdot
.64286 .58514 Mdot
.66667 .58368 Mdot
.69048 .55035 Mdot
.71429 .48134 Mdot
.7381 .38294 Mdot
.7619 .27126 Mdot
.78571 .16641 Mdot
.80952 .08487 Mdot
.83333 .03507 Mdot
.85714 .01789 Mdot
.88095 .03006 Mdot
.90476 .06702 Mdot
.92857 .12378 Mdot
.95238 .19439 Mdot
.97619 .27173 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`0006Wooooo0_l0002?ooooo`;o0000>_ooool0033ooooo00?o0000oooooooo
ool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0L?ooool2
o`0008kooooo0_l0000cooooo`00<?ooool2o`0006;ooooo0_l0000=ooooo`;o0000P?ooool2o`00
00cooooo0_l0000cooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047o
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`003Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`003Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`003Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`003Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000T
ooooo`00<?ooool2o`0007oooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfoooo
o`005Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1C
ooooo`;o0000S_ooool2o`00053ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0
01Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`0001gooooo000`ooooo`03o`00
0?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00;oooool2o`0004kooooo0_l0000oooooo`;o0000COoo
ool2o`0003oooooo0_l0000Fooooo`00;oooool2o`0004kooooo0_l0000oooooo`;o0000COooool2
o`0003oooooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oo
oooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0004Co
oooo0_l0002?ooooo`;o0000G_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool0
0ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool04_ooool2
o`0008kooooo0_l0002Aooooo`00<?ooool2o`0001?ooooo0_l0000Yooooo`;o0000Hoooool2o`00
02[ooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Go
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`0001[ooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000oooo
ooooool06Oooool2o`0008kooooo0_l0002:ooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Kooooo0_l0002>ooooo`;o0000KOooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0f
ooooo`;o0000S_ooool2o`0006gooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004oooo
o`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0
0006ooooo`;o0000Qoooool2o`0000Gooooo0_l0001dooooo`00<?ooool2o`0002Sooooo0_l00006
ooooo`;o0000Qoooool2o`0000Gooooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02:oooo
o`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?oooooooooooooo
ool00000R_ooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oV9RHoooooonH
V9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oEEEEo`000?l@413oc<c<08[o
oooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo08cooooo002Tooooo`03
o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00ooMgMgo410@oiRHV02<ooooo`00Y?ooool00ol0003oooooooooo`0Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Co
c<c<odA4A?l0003o410@R_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .2441 Mdot
.04762 .30516 Mdot
.07143 .3608 Mdot
.09524 .41167 Mdot
.11905 .46007 Mdot
.14286 .50602 Mdot
.16667 .54546 Mdot
.19048 .57128 Mdot
.21429 .5737 Mdot
.2381 .53983 Mdot
.2619 .46038 Mdot
.28571 .34423 Mdot
.30952 .22077 Mdot
.33333 .12098 Mdot
.35714 .05973 Mdot
.38095 .03621 Mdot
.40476 .04332 Mdot
.42857 .0739 Mdot
.45238 .12184 Mdot
.47619 .1809 Mdot
.5 .2441 Mdot
.52381 .30516 Mdot
.54762 .3608 Mdot
.57143 .41167 Mdot
.59524 .46007 Mdot
.61905 .50602 Mdot
.64286 .54546 Mdot
.66667 .57128 Mdot
.69048 .5737 Mdot
.71429 .53983 Mdot
.7381 .46038 Mdot
.7619 .34423 Mdot
.78571 .22077 Mdot
.80952 .12098 Mdot
.83333 .05973 Mdot
.85714 .03621 Mdot
.88095 .04332 Mdot
.90476 .0739 Mdot
.92857 .12184 Mdot
.95238 .1809 Mdot
.97619 .2441 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003ooooo
ooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`03o`000?oooooooooo073ooooo0_l0
002>ooooo`;o0000<oooool0033ooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0
002?ooooo`;o0000@Oooool0033ooooo0_l0001Rooooo`;o0000Soooool2o`00047ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1gooooo`;o0000S_ooool2o`0002cooooo000=ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Mooo
ool2o`0008kooooo0_l0000/ooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo05[ooooo0_l0000Rooooo`;o0000Joooool2o`0002;ooooo0_l0000Tooooo`00<?ooool2o`00
05_ooooo0_l0000Rooooo`;o0000Joooool2o`0002;ooooo0_l0000Tooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
ocKooooo000Eooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
QOooool2o`0008oooooo0_l0000Mooooo`00<?ooool2o`0008Kooooo0_l0002?ooooo`;o00007Ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`003Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?oo
ool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`?o0000oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool2o`0008oo
oooo0_l0002>ooooo`;o00005_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Gooooo0ol0002>ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool2o`0008oooooo0_l0002Oooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo0_l0002?ooooo`;o0000Woooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003o
ooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003o
ooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097o
oooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0I
ooooo`;o0000S_ooool2o`0008[ooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Iooooo`;o0000:Oooool2o`0006?ooooo0_l0000Zoooo
o`;o0000G_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000A?ooool2o`0008oooooo0_l0001Nooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo
000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
8?ooool2o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Sooo
ool2o`0008;ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`0003gooooo0_l0002?ooooo`;o0000IOooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool09oooool2o`0001Cooooo0_l0001iooooo`;o00005?ooool2o`0006Gooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo0_l0000`ooooo`;o00001Oooool2o`00
08Oooooo0_l00005ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0=_ooool2o`0008ko
oooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`Co000000?o410@ooooooooool01Ol0002:ooooo`00Y?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A408[ooooo002Tooooo`03
o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h0Roooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q
8Oo^k^h0R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`29ooooo`00X_ooool00ol@413o
0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0R?ooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So
410@08[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .22153 Mdot
.04762 .27033 Mdot
.07143 .3157 Mdot
.09524 .36044 Mdot
.11905 .40725 Mdot
.14286 .45557 Mdot
.16667 .50154 Mdot
.19048 .53953 Mdot
.21429 .56282 Mdot
.2381 .56175 Mdot
.2619 .51986 Mdot
.28571 .42378 Mdot
.30952 .29212 Mdot
.33333 .17101 Mdot
.35714 .09177 Mdot
.38095 .05704 Mdot
.40476 .05675 Mdot
.42857 .08066 Mdot
.45238 .12082 Mdot
.47619 .17007 Mdot
.5 .22153 Mdot
.52381 .27033 Mdot
.54762 .3157 Mdot
.57143 .36044 Mdot
.59524 .40725 Mdot
.61905 .45557 Mdot
.64286 .50154 Mdot
.66667 .53953 Mdot
.69048 .56282 Mdot
.71429 .56175 Mdot
.7381 .51986 Mdot
.7619 .42378 Mdot
.78571 .29212 Mdot
.80952 .17101 Mdot
.83333 .09177 Mdot
.85714 .05704 Mdot
.88095 .05675 Mdot
.90476 .08066 Mdot
.92857 .12082 Mdot
.95238 .17007 Mdot
.97619 .22153 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`1Xooooo`;o00001_ooool2o`0008Oooooo0_l00005ooooo`;o0000
<oooool0033ooooo00?o0000ooooooooool0J?ooool2o`0000Kooooo0_l00027ooooo`;o00001Ooo
ool2o`0003?ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0007Oooooo0_l0
002>ooooo`;o0000;?ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07Oooooo
0_l0002>ooooo`;o0000;?ooool000gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo
000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o0000H_ooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o
0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`;o0000Ooooool2o`00
08oooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000Eooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0QOooool2
o`0008oooooo0_l0000Mooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o0000Foooool2o`0002Wooooo0_l0001Tooooo`;o0000:Oooool2o`0001gooooo000`oooo
o`03o`000?oooooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool000gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool000gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooo
oolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKo
oooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o0000Wooo
ool0033ooooo00?o0000ooooooooool00oooool2o`0008oooooo0_l0002Oooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool2o`0005Cooooo0_l0002>oooo
o`;o0000D?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000
V?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`;o0000S_oo
ool2o`0009Sooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool0033ooooo00?o0000oooooooo
ool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`oooo
o`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`oooo
o`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Pooooo`;o0000Soooool2o`0008;ooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l00022
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003ooooo
ooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000
Soooool2o`0005kooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000;oooool2o`0008kooooo
0_l0001dooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omE
EEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0
=_ooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0006Gooooo000`ooooo`03o`000?oo
oooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co0000
00So410@ooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c8[ooooo002Tooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40R_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`02ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S80R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool00_ooool01Oo<c<co0000o`000?l0003o
c<c<08[ooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@08[ooooo002T
ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`00002:ooooo`00Y?ooool00ol0003ooooooooo
o`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000004ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .20246 Mdot
.04762 .24209 Mdot
.07143 .28053 Mdot
.09524 .32112 Mdot
.11905 .36587 Mdot
.14286 .41346 Mdot
.16667 .46032 Mdot
.19048 .50234 Mdot
.21429 .53523 Mdot
.2381 .55306 Mdot
.2619 .5447 Mdot
.28571 .48855 Mdot
.30952 .37341 Mdot
.33333 .23763 Mdot
.35714 .13513 Mdot
.38095 .08318 Mdot
.40476 .07206 Mdot
.42857 .08802 Mdot
.45238 .1204 Mdot
.47619 .16076 Mdot
.5 .20246 Mdot
.52381 .24209 Mdot
.54762 .28053 Mdot
.57143 .32112 Mdot
.59524 .36587 Mdot
.61905 .41346 Mdot
.64286 .46032 Mdot
.66667 .50234 Mdot
.69048 .53523 Mdot
.71429 .55306 Mdot
.7381 .5447 Mdot
.7619 .48855 Mdot
.78571 .37341 Mdot
.80952 .23763 Mdot
.83333 .13513 Mdot
.85714 .08318 Mdot
.88095 .07206 Mdot
.90476 .08802 Mdot
.92857 .1204 Mdot
.95238 .16076 Mdot
.97619 .20246 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000=
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`003Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
J?ooool2o`0008oooooo0_l0000jooooo`003Oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Sooooo
0_l0002?ooooo`;o0000>_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Oo
oooo0_l0002>ooooo`;o0000;?ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001hooooo`;o0000S_ooool2o`00
02cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?
ooooo`;o00009?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`000?oooooo=_ooool001Gooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo08Gooooo0_l0002?ooooo`;o00007Oooool001Gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000M
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000_ooooo`?o0000S_ooool2o`0008kooooo0_l0
000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Jooooo`;o0000
Soooool2o`0004Sooooo000=ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0005Gooooo
0_l0000hooooo`;o0000EOooool2o`0004Sooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00
<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000V
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0002A
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oo
oooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo0_l0001Dooooo`;o0000S_ooool2
o`00053ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool08?ooool2o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000
Soooool2o`0008;ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001koooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Wooooo`;o
0000Soooool2o`0007_ooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`ooooo`03o`000?oo
oooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008ko
oooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`00
06gooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006go
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`14ooooo`;o0000Sooo
ool2o`0005kooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0
001Nooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`003_ooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0000Kooooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKo
oooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKo
oooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooolfooooo`009ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool00omgMgOoIVIVooooo`3o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Gooooo00Go0000okZj^_oo
ooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooolooooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo
0_l000000ol@413oooooooooo`28ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo08Wooooo002Tooooo`03o`000?oooooooooo01[o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Cooooo1Ol0002:oooo
o`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0002;ooooo`00Y?ooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`02
ooooo`04omgMgOmEEEGoooooo`0008_ooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00omgMgOoc<c<o`00
002;ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000Roooool00:Cooooo00?o
0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c005ooooo`03ogMgMol0003ooooo08[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18647 Mdot
.04762 .21937 Mdot
.07143 .25312 Mdot
.09524 .29067 Mdot
.11905 .33307 Mdot
.14286 .3785 Mdot
.16667 .4238 Mdot
.19048 .46594 Mdot
.21429 .5023 Mdot
.2381 .5294 Mdot
.2619 .54068 Mdot
.28571 .52126 Mdot
.30952 .44552 Mdot
.33333 .31688 Mdot
.35714 .19325 Mdot
.38095 .11819 Mdot
.40476 .09138 Mdot
.42857 .09694 Mdot
.45238 .12078 Mdot
.47619 .15282 Mdot
.5 .18647 Mdot
.52381 .21937 Mdot
.54762 .25312 Mdot
.57143 .29067 Mdot
.59524 .33307 Mdot
.61905 .3785 Mdot
.64286 .4238 Mdot
.66667 .46594 Mdot
.69048 .5023 Mdot
.71429 .5294 Mdot
.7381 .54068 Mdot
.7619 .52126 Mdot
.78571 .44552 Mdot
.80952 .31688 Mdot
.83333 .19325 Mdot
.85714 .11819 Mdot
.88095 .09138 Mdot
.90476 .09694 Mdot
.92857 .12078 Mdot
.95238 .15282 Mdot
.97619 .18647 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03
o`000?oooooooooo073ooooo0_l00005ooooo`;o0000Qoooool2o`0000Gooooo0_l0000/ooooo`00
<?ooool00ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_oo
ool0033ooooo00?o0000ooooooooool0J?ooool2o`0001Cooooo0_l0001iooooo`;o00005?ooool2
o`0002Cooooo000`ooooo`;o0000Ooooool2o`0008oooooo0_l0000Tooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08Gooooo0_l0002?oooo
o`;o00007Oooool001Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00?ooooo0ol00025ooooo`;o0000Soooool2o`0001gooooo000Eooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00;oooool3o`0008kooooo0_l0
002>ooooo`;o00005_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`oooo
o`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000oooooooo
ool0HOooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00001?ooool2o`0008oooooo0_l0
002Oooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000`ooooo`;o00004oooool2o`00
08kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool2o`0008oooooo
0_l00018ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o
0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool08?ooool2o`0008oooooo0_l00022ooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Noooool0
033ooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053o
oooo000`ooooo`;o0000E?ooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0002oooooo0_l0002>ooooo`;o0000M?ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0;oooool2o`0008ko
oooo0_l0001dooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=
ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o
0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000
KOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o
0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool2o`0003kooooo0_l0002?
ooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00014ooooo`;o0000
Soooool2o`0005kooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`0S_ooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80S_ooool00:Sooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0S?ooool00:Sooooo00?o0000ooooooooool02oooool6o`00
00Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo08gooooo002Xoooo
o`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o
^[Zj08kooooo002Vooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo
410@00kooooo00?o^[Zjob4Q8Oooool0SOooool00:Sooooo00?o0000ooooooooool06_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`00002>ooooo`00Z?ooool0
0ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY08kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17345 Mdot
.04762 .20129 Mdot
.07143 .23166 Mdot
.09524 .26669 Mdot
.11905 .30656 Mdot
.14286 .34925 Mdot
.16667 .39201 Mdot
.19048 .43263 Mdot
.21429 .46942 Mdot
.2381 .50045 Mdot
.2619 .52188 Mdot
.28571 .525 Mdot
.30952 .4898 Mdot
.33333 .39386 Mdot
.35714 .26511 Mdot
.38095 .16553 Mdot
.40476 .1175 Mdot
.42857 .10892 Mdot
.45238 .12273 Mdot
.47619 .14659 Mdot
.5 .17345 Mdot
.52381 .20129 Mdot
.54762 .23166 Mdot
.57143 .26669 Mdot
.59524 .30656 Mdot
.61905 .34925 Mdot
.64286 .39201 Mdot
.66667 .43263 Mdot
.69048 .46942 Mdot
.71429 .50045 Mdot
.7381 .52188 Mdot
.7619 .525 Mdot
.78571 .4898 Mdot
.80952 .39386 Mdot
.83333 .26511 Mdot
.85714 .16553 Mdot
.88095 .1175 Mdot
.90476 .10892 Mdot
.92857 .12273 Mdot
.95238 .14659 Mdot
.97619 .17345 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001hoooo
o`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o
0000;?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1`ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo073ooooo0_l0000<
ooooo`;o0000P?ooool2o`0000gooooo0_l0000Tooooo`00<?ooool2o`0007oooooo0_l0002?oooo
o`;o00009?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0QOooool2o`0008oooooo0_l0000Mooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`25oooo
o`;o0000Soooool2o`0001gooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfoooo
o`005Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1X
ooooo`;o0000Soooool2o`0003[ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool0
01Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool3o`0008kooooo0_l0002>
ooooo`;o00005_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`0000Cooooo0_l0002?ooooo`;o0000Wooo
ool0033ooooo00?o0000ooooooooool00oooool2o`0008oooooo0_l0002Oooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o00002oooool2o`0008kooooo0_l0002Hooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool000gooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKo
oooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011ooooo`00
<?ooool00ol0003oooooooooo`0Booooo`;o0000COooool2o`0003oooooo0_l0001>ooooo`;o0000
@Oooool0033ooooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0001Wooooo0_l0002>ooooo`;o0000R_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo023ooooo
0_l0002?ooooo`;o0000P_ooool0033ooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l0
0022ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool09oooool2o`00037ooooo0_l0001Looooo`;o0000
<Oooool2o`0004Sooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l0000aooooo`;o0000G?oo
ool2o`00037ooooo0_l00018ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00033ooooo0_l0002>ooooo`;o0000
M?ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o
0000KOooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0
002>ooooo`;o0000D?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00
<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0
0006ooooo`;o0000Qoooool2o`0000Gooooo0_l0001Gooooo`00<?ooool2o`0004gooooo0_l0002>
ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l@413oc<c<
08[ooooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?oo
ooooooooooooool@41003oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0R?ooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2:oooo
o`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@
413o0000okZj^P03ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0R_ooool00:;ooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`02
ooooo`03oeEEEOn7QhOooooo08cooooo002Tooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRH
V02<ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@R_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16341 Mdot
.04762 .18714 Mdot
.07143 .21476 Mdot
.09524 .24746 Mdot
.11905 .28474 Mdot
.14286 .32452 Mdot
.16667 .36448 Mdot
.19048 .40294 Mdot
.21429 .43881 Mdot
.2381 .47097 Mdot
.2619 .49726 Mdot
.28571 .51253 Mdot
.30952 .50465 Mdot
.33333 .44999 Mdot
.35714 .3409 Mdot
.38095 .22599 Mdot
.40476 .15342 Mdot
.42857 .12616 Mdot
.45238 .12752 Mdot
.47619 .1427 Mdot
.5 .16341 Mdot
.52381 .18714 Mdot
.54762 .21476 Mdot
.57143 .24746 Mdot
.59524 .28474 Mdot
.61905 .32452 Mdot
.64286 .36448 Mdot
.66667 .40294 Mdot
.69048 .43881 Mdot
.71429 .47097 Mdot
.7381 .49726 Mdot
.7619 .51253 Mdot
.78571 .50465 Mdot
.80952 .44999 Mdot
.83333 .3409 Mdot
.85714 .22599 Mdot
.88095 .15342 Mdot
.90476 .12616 Mdot
.92857 .12752 Mdot
.95238 .1427 Mdot
.97619 .16341 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0001hooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03
o`000?oooooooooo07Oooooo0_l00005ooooo`;o0000Qoooool2o`0000Kooooo0_l0000Tooooo`00
<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oo
oooo0_l0000Mooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000Eooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000L?ooool2o`0008kooooo0_l0000coooo
o`005Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o0000Soooool2
o`0008kooooo0_l0000Fooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`03
ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?oooo
o`;o0000Woooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo
000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0J?oo
ool2o`0008oooooo0_l0000jooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Xooooo`;o0000Soooool2o`0003[ooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000Cooooo`;o
0000S_ooool2o`00097ooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000
TOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo01Wooooo
0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0
002:ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`000?oooooo=_ooool002So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`ooooo`;o00008Oooool2o`00
08oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`0006;ooooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0HOooool2o`00
08oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`000?oooooooooo02Oooooo
0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooo
ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0000`ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`03o`000?oooooo
oooo02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033ooooo00?o0000oooo
ooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000Foooool2o`0008oooooo0_l00018ooooo`00<?ooool00ol0003ooooooooo
o`1Jooooo`;o0000Soooool2o`0004Sooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
?Oooool2o`0008oooooo0_l0001Uooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`005_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Noooo
o`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`03o`00
0?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0Dooo
ool2o`0008kooooo0_l0001@ooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o0000Eoooool0
033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000Co410@oooooooooooo
oooo1Ol0002:ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool01OnH
V9So8B4Qonk^k_ooooooA4A408[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001?ooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0
003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001_ooool00onHV9So8B4Qonk^kP2:ooooo`00Y?ooool00ol0003oooooooooo`0J
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03ogMg
MomVIVKooooo08Wooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000002?ooool00ol0003oooooooooo`28ooooo`00Y?oo
ool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@4100R_ooool00:Cooooo00?o0000ooooooooool0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool00oooool01OnHV9So
410@o`000?lQ8B7oc<c<08[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15651 Mdot
.04762 .1764 Mdot
.07143 .20144 Mdot
.09524 .23183 Mdot
.11905 .2665 Mdot
.14286 .30342 Mdot
.16667 .34061 Mdot
.19048 .37675 Mdot
.21429 .41113 Mdot
.2381 .44309 Mdot
.2619 .47135 Mdot
.28571 .4929 Mdot
.30952 .50049 Mdot
.33333 .4781 Mdot
.35714 .40455 Mdot
.38095 .29425 Mdot
.40476 .20084 Mdot
.42857 .15123 Mdot
.45238 .1369 Mdot
.47619 .14206 Mdot
.5 .15651 Mdot
.52381 .1764 Mdot
.54762 .20144 Mdot
.57143 .23183 Mdot
.59524 .2665 Mdot
.61905 .30342 Mdot
.64286 .34061 Mdot
.66667 .37675 Mdot
.69048 .41113 Mdot
.71429 .44309 Mdot
.7381 .47135 Mdot
.7619 .4929 Mdot
.78571 .50049 Mdot
.80952 .4781 Mdot
.83333 .40455 Mdot
.85714 .29425 Mdot
.88095 .20084 Mdot
.90476 .15123 Mdot
.92857 .1369 Mdot
.95238 .14206 Mdot
.97619 .15651 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`;o0000Ooooool2o`0008oooooo0_l0000T
ooooo`00<?ooool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`0001gooooo000`ooooo`03
o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/oooo
o`005Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool4o`00
07Oooooo0_l0000Dooooo`;o0000N?ooool2o`0001Cooooo0_l0000Fooooo`005Oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool2o`0008oooooo0_l0002>oooo
o`;o00005_ooool001Gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`00
09oooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool2o`0000cooooo0_l0001Sooooo`;o0000:Oooool2o`0006?ooooo0_l0000cooooo`00<?ooool0
0ol0003oooooooooo`0;ooooo`;o0000Hoooool2o`0002Wooooo0_l0001Sooooo`;o0000<oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`0001;ooooo0_l0002>ooooo`;o0000TOoo
ool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003ooooooooo
o`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001Yooooo`;o0000Soooool2o`00
03[ooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l00022
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolfooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000:?ooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0
003oooooooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKo
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Ooo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1Qoooo
o`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o
0000KOooool0033ooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00<?oo
ool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`00
06Gooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033ooooo
0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001So
oooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`14ooooo`;o0000Sooo
ool2o`0005kooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooo
oooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo0_l0001Kooooo`;o0000Soooool2o`00
04Sooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`
ooooo`;o0000COooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo
00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Ooo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
00kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000oooooooo
ool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMg
ofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05
o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<
0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c02:ooooo`00Y?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q08[ooooo
002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
0oooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00004oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S80R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000o`00
0?l0003oc<c<08[ooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001?ooool01Ol@413o^[Zjoooooonj^[[o410@08[o
oooo002Tooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Cooooo00Go0000okZj^_oooooo^[Zjo`00002:ooooo`00Y?ooool00ol0003o
ooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`03oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15313 Mdot
.04762 .16883 Mdot
.07143 .19111 Mdot
.09524 .21904 Mdot
.11905 .25111 Mdot
.14286 .2853 Mdot
.16667 .31986 Mdot
.19048 .35376 Mdot
.21429 .38646 Mdot
.2381 .41756 Mdot
.2619 .4463 Mdot
.28571 .47083 Mdot
.30952 .48681 Mdot
.33333 .48429 Mdot
.35714 .4449 Mdot
.38095 .35844 Mdot
.40476 .2576 Mdot
.42857 .18614 Mdot
.45238 .15296 Mdot
.47619 .1459 Mdot
.5 .15313 Mdot
.52381 .16883 Mdot
.54762 .19111 Mdot
.57143 .21904 Mdot
.59524 .25111 Mdot
.61905 .2853 Mdot
.64286 .31986 Mdot
.66667 .35376 Mdot
.69048 .38646 Mdot
.71429 .41756 Mdot
.7381 .4463 Mdot
.7619 .47083 Mdot
.78571 .48681 Mdot
.80952 .48429 Mdot
.83333 .4449 Mdot
.85714 .35844 Mdot
.88095 .2576 Mdot
.90476 .18614 Mdot
.92857 .15296 Mdot
.95238 .1459 Mdot
.97619 .15313 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool001Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`005Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00020oooo
o`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o00005_ooool001Gooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo1?l0001nooooo`;o00003Oooool2o`00
083ooooo0_l0000<ooooo`;o00005_ooool001Gooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo=_ooool001Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000Soooool2
o`0009oooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00004
ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000N?ooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1g
ooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>oooo
o`;o0000V?ooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o00004oooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`0B
ooooo`;o0000S_ooool2o`00097ooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000=ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool06Ooo
ool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2
o`0003?ooooo000`ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0033ooooo00?o0000ooooooooool08?oo
ool2o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Nooo
ool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Wooooo`;o0000Soooool2
o`0007_ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool2
o`00033ooooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0J?ooool2o`00
08oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[o
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000=_ooool2o`0008ko
oooo0_l0001]ooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006gooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`
ooooo`03o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`14ooooo`;o00006oooool2o`0007;ooooo0_l0000Kooooo`;o0000@Oooool0033ooooo
0_l00015ooooo`;o00006oooool2o`0007;ooooo0_l0000Kooooo`;o0000@Oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04cooooo
0_l0002>ooooo`;o0000Eoooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00
<?ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool2o`0008Oooooo0_l00006ooooo`;o0000
B?ooool0033ooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`000003oa0@4?oooooooooo08So
oooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
08Wooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00Go0000R_ooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000?ooooo`08ogMgMolb<S;ooooooooooom4A4CogMgMoooo
ool0002;ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo0000Roooool00:;o
oooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000008_ooooo002Tooooo`03o`000?oooooooooo01[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4
A?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03ogMgMol0003ooooo08[ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15399 Mdot
.04762 .16451 Mdot
.07143 .18347 Mdot
.09524 .20869 Mdot
.11905 .23811 Mdot
.14286 .26968 Mdot
.16667 .30181 Mdot
.19048 .33358 Mdot
.21429 .36459 Mdot
.2381 .39455 Mdot
.2619 .42297 Mdot
.28571 .44866 Mdot
.30952 .46895 Mdot
.33333 .4777 Mdot
.35714 .46239 Mdot
.38095 .40661 Mdot
.40476 .31621 Mdot
.42857 .23058 Mdot
.45238 .17758 Mdot
.47619 .15572 Mdot
.5 .15399 Mdot
.52381 .16451 Mdot
.54762 .18347 Mdot
.57143 .20869 Mdot
.59524 .23811 Mdot
.61905 .26968 Mdot
.64286 .30181 Mdot
.66667 .33358 Mdot
.69048 .36459 Mdot
.71429 .39455 Mdot
.7381 .42297 Mdot
.7619 .44866 Mdot
.78571 .46895 Mdot
.80952 .4777 Mdot
.83333 .46239 Mdot
.85714 .40661 Mdot
.88095 .31621 Mdot
.90476 .23058 Mdot
.92857 .17758 Mdot
.95238 .15572 Mdot
.97619 .15399 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool4o`0008Gooooo0_l00006oooo
o`;o0000Qoooool2o`0000Gooooo0_l0000Fooooo`005Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool00oooool2o`0008Oooooo0_l00006ooooo`;o0000Qoooool2o`00
00Gooooo0_l0000Fooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2
o`0008oooooo0_l0002Oooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000Eoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oo
oooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo
000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool0033ooooo00?o0000oooooooo
ool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
001gooooo`;o0000S_ooool2o`0002cooooo000=ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Mooo
ool2o`0008kooooo0_l0000/ooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
6Oooool2o`0008kooooo0_l0002:ooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo
0_l0002>ooooo`;o0000R_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l0
0022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo
0_l0000cooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0_l0
002>ooooo`;o0000<oooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o
0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`00
0?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool0
033ooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_ooool0
033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
COooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_oo
ool2o`0005Oooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`00067ooooo0_l0002?ooooo`;o0000@Oooool001Sooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0Doooool2o`0008kooooo0_l0001@ooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`006?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`1J
ooooo`;o0000Soooool2o`0004Sooooo000`ooooo`;o0000Foooool2o`0008oooooo0_l00018oooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`0S_ooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B40S_ooool00:Sooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00Z?ooool00ol0003oooooooooo`0;
ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@2>ooooo`00Z?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<08kooooo002Vooooo`03oa0@4?l0003o000000?o0000
6Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0T?ooool00:Sooooo
00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P0T?ooool00:Sooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16006 Mdot
.04762 .16384 Mdot
.07143 .17855 Mdot
.09524 .20059 Mdot
.11905 .22724 Mdot
.14286 .25625 Mdot
.16667 .28608 Mdot
.19048 .31587 Mdot
.21429 .34523 Mdot
.2381 .37393 Mdot
.2619 .4016 Mdot
.28571 .42743 Mdot
.30952 .4497 Mdot
.33333 .46457 Mdot
.35714 .46399 Mdot
.38095 .43427 Mdot
.40476 .36646 Mdot
.42857 .28041 Mdot
.45238 .21126 Mdot
.47619 .17299 Mdot
.5 .16006 Mdot
.52381 .16384 Mdot
.54762 .17855 Mdot
.57143 .20059 Mdot
.59524 .22724 Mdot
.61905 .25625 Mdot
.64286 .28608 Mdot
.66667 .31587 Mdot
.69048 .34523 Mdot
.71429 .37393 Mdot
.7381 .4016 Mdot
.7619 .42743 Mdot
.78571 .4497 Mdot
.80952 .46457 Mdot
.83333 .46399 Mdot
.85714 .43427 Mdot
.88095 .36646 Mdot
.90476 .28041 Mdot
.92857 .21126 Mdot
.95238 .17299 Mdot
.97619 .16006 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0002?oooo
o`;o0000S_ooool2o`0001Kooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo0_l0002?ooooo`;o0000Woooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0008oooooo0_l0002O
ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000Q_ooool2
o`0008oooooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`00
01gooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool0033ooooo
00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`0001?ooooo0_l0002>ooooo`;o0000TOooool0033ooooo00?o0000
ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo
00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`003Oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00006Ooo
ool2o`0008kooooo0_l0002:ooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool08?ooool2
o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`00
08;ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000N?ooool2o`0008ko
oooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo
000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000
ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocKooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000V
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0=_ooool2o`0008kooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000
S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo
000`ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo0_l0000n
ooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?oooo
o`;o0000IOooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000AOooool2o`0008oooooo0_l0
001Nooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool2o`0004gooooo
0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0
000jooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`0005Cooooo0_l0002>ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0Dooo
ool2o`0008kooooo0_l0001@ooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0001Jooooo`;o00001Oooool2o`0008Sooooo0_l00005ooooo`;o
0000@Oooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0F_ooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`00047o
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0R_ooool00:Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q08[ooooo
002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03
o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2:ooooo`00Y?ooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00?ooooo00Go0000oeEEEOl0003o410@olc<c02:ooooo`00X_ooool00ol@413o0000
o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Go
oooo00?oEEEEohN7Qoooool0S?ooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01Oooool00ooMgMgo410@oiRHV02<ooooo`00
Y?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4104ooooo`04olc<c?m4A4Co0000oa0@48[ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17244 Mdot
.04762 .16752 Mdot
.07143 .17666 Mdot
.09524 .19481 Mdot
.11905 .21838 Mdot
.14286 .24481 Mdot
.16667 .27243 Mdot
.19048 .30033 Mdot
.21429 .32809 Mdot
.2381 .35547 Mdot
.2619 .38215 Mdot
.28571 .40752 Mdot
.30952 .43042 Mdot
.33333 .4484 Mdot
.35714 .45635 Mdot
.38095 .44464 Mdot
.40476 .40131 Mdot
.42857 .32816 Mdot
.45238 .25198 Mdot
.47619 .19845 Mdot
.5 .17244 Mdot
.52381 .16752 Mdot
.54762 .17666 Mdot
.57143 .19481 Mdot
.59524 .21838 Mdot
.61905 .24481 Mdot
.64286 .27243 Mdot
.66667 .30033 Mdot
.69048 .32809 Mdot
.71429 .35547 Mdot
.7381 .38215 Mdot
.7619 .40752 Mdot
.78571 .43042 Mdot
.80952 .4484 Mdot
.83333 .45635 Mdot
.85714 .44464 Mdot
.88095 .40131 Mdot
.90476 .32816 Mdot
.92857 .25198 Mdot
.95238 .19845 Mdot
.97619 .17244 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000Eooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Gooooo0ol00004ooooo`;o0000R?ooool2o`0000Gooooo0_l00027
ooooo`;o00005_ooool002oooooo0_l0000=ooooo`;o0000P?ooool2o`0000cooooo0_l00020oooo
o`;o00005_ooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003ooooo
ooooo`0Booooo`;o0000LOooool2o`0001_ooooo0_l0001booooo`;o00007Oooool0033ooooo0_l0
0026ooooo`;o0000Soooool2o`0001gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0000Jooooo`;o0000S_oo
ool2o`0008[ooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0
00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08?ooool2o`0008oooooo0_l00022ooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`00027ooooo0_l0002?ooooo`;o0000P_ooool0033ooooo
00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?ooool00ol0003ooooooooo
o`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000oooo
ooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05oooo
o`?o0000oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`009_ooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0000goooo
o`;o0000?oooool2o`0004gooooo0_l0000oooooo`;o0000;?ooool0033ooooo00?o0000oooooooo
ool0=_ooool2o`0003oooooo0_l0001=ooooo`;o0000?oooool2o`0002cooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`0003kooooo0_l0002?ooooo`;o0000IOooool0
033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`00
05kooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000A?ooool2o`0008oooooo0_l0001Nooooo`004?ooool00ol0003ooooo
ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooo
oooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo00?o0000ooooooooool0C?ooool2o`00
08kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000`ooooo`;o0000
E?ooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`;o0000
Foooool2o`0000cooooo0_l00021ooooo`;o00003?ooool2o`0003[ooooo000`ooooo`03o`000?oo
oooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0HOoo
ool2o`0008oooooo0_l00011ooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool00oooool5o`0008[ooooo002Tooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0R_ooool00:Co
oooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool01?ooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko
00002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01?ooool00onH
V9So8B4Qonk^kP2:ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`05ooooo`03ogMgMomVIVKooooo08Wooooo002Rooooo`03
oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool01_ooool00ol0003oooooooooo`28ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go0000
okZj^_ooooooV9RHoa0@402:ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .19186 Mdot
.04762 .17637 Mdot
.07143 .17834 Mdot
.09524 .1916 Mdot
.11905 .21161 Mdot
.14286 .23528 Mdot
.16667 .26067 Mdot
.19048 .28672 Mdot
.21429 .31291 Mdot
.2381 .33892 Mdot
.2619 .36444 Mdot
.28571 .389 Mdot
.30952 .41176 Mdot
.33333 .43112 Mdot
.35714 .44381 Mdot
.38095 .44343 Mdot
.40476 .41998 Mdot
.42857 .36651 Mdot
.45238 .29478 Mdot
.47619 .23123 Mdot
.5 .19186 Mdot
.52381 .17637 Mdot
.54762 .17834 Mdot
.57143 .1916 Mdot
.59524 .21161 Mdot
.61905 .23528 Mdot
.64286 .26067 Mdot
.66667 .28672 Mdot
.69048 .31291 Mdot
.71429 .33892 Mdot
.7381 .36444 Mdot
.7619 .389 Mdot
.78571 .41176 Mdot
.80952 .43112 Mdot
.83333 .44381 Mdot
.85714 .44343 Mdot
.88095 .41998 Mdot
.90476 .36651 Mdot
.92857 .29478 Mdot
.95238 .23123 Mdot
.97619 .19186 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?oooo
o`;o0000Woooool0033ooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l00027ooooo`;o
00001Oooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000
V?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
02oooooo0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001iooooo`;o00005_ooool002oo
oooo0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001iooooo`;o00005_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0
6Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o0000QOooool2o`0008oooooo0_l0000Mooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo023ooooo0_l0001Sooooo`;o0000:_ooool2o`0006?ooooo0_l0
000Mooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool08?ooool2o`0008oooooo
0_l00022ooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?oooo
o`;o0000Noooool0033ooooo0_l0000Xooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`0_
ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`;o0000Ooooool2o`0008oooooo0_l0000Toooo
o`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`;o
0000S_ooool2o`0006gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=_ooool2o`0008kooooo0_l0001]ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`0003kooooo0_l0002?ooooo`;o0000IOooool0033ooooo00?o0000oooo
ooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`03o`00
0?oooooooooo04Cooooo0_l0000aooooo`;o0000G?ooool2o`00033ooooo0_l0000/ooooo`00<?oo
ool00ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04cooooo
0_l0002>ooooo`;o0000Eoooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1<ooooo`;o0000
S_ooool2o`0005Oooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0
Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool2o`00077ooooo0_l0002>ooooo`;o0000<ooo
ool0033ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
0_l0001Kooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`03o`000?oooooooooo067o
oooo0_l00005ooooo`;o0000R?ooool2o`0000Gooooo0_l0000jooooo`00<?ooool2o`0006;ooooo
0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0R_ooool00:Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2:
ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`03ooooo`05o`000?ooooooooooooooool00000R_ooool00:Cooooo00?o0000
ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2:ooooo`00Y?ooool00ol0003ooooooooo
o`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`02ooooo`05olc<
c?l0003o0000o`000?o<c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?nj^[[ooooookZj
^_l@4100R_ooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooookZj^_l00000R_oo
ool00:Cooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .21807 Mdot
.04762 .19109 Mdot
.07143 .18426 Mdot
.09524 .19139 Mdot
.11905 .20713 Mdot
.14286 .22768 Mdot
.16667 .2507 Mdot
.19048 .27486 Mdot
.21429 .29944 Mdot
.2381 .32404 Mdot
.2619 .3483 Mdot
.28571 .37183 Mdot
.30952 .394 Mdot
.33333 .41374 Mdot
.35714 .42893 Mdot
.38095 .43543 Mdot
.40476 .42593 Mdot
.42857 .39187 Mdot
.45238 .33339 Mdot
.47619 .26826 Mdot
.5 .21807 Mdot
.52381 .19109 Mdot
.54762 .18426 Mdot
.57143 .19139 Mdot
.59524 .20713 Mdot
.61905 .22768 Mdot
.64286 .2507 Mdot
.66667 .27486 Mdot
.69048 .29944 Mdot
.71429 .32404 Mdot
.7381 .3483 Mdot
.7619 .37183 Mdot
.78571 .394 Mdot
.80952 .41374 Mdot
.83333 .42893 Mdot
.85714 .43543 Mdot
.88095 .42593 Mdot
.90476 .39187 Mdot
.92857 .33339 Mdot
.95238 .26826 Mdot
.97619 .21807 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0000=oooo
o`;o0000P?ooool2o`0000cooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o
00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000TOooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03
o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00;oooool3o`0008kooooo0_l0002>ooooo`;o00005_ooool002oooooo0_l0002?
ooooo`;o0000S_ooool2o`0001Kooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Pooooo`;o0000Soooool2o`0008;ooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Pooooo`;o0000Sooo
ool2o`0008;ooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000
Noooool0033ooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o0000
7Oooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00<?ooool0
0ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`03o`000?oooooooooo
02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0fooooo`;o0000S_ooool2o`0006gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000`oooo
o`;o0000?_ooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o
0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_ooool0033ooooo00?o
0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000oooo
ooooool0C?ooool2o`0008kooooo0_l0001Gooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Doooool2o`0002;ooooo0_l0001Zooooo`;o0000
8_ooool2o`0002cooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05?ooooo0_l0000Rooooo`;o0000J_oo
ool2o`0002;ooooo0_l0000/ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0F_ooool2o`0008oo
oooo0_l00018ooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo00?o0000oooooooo
ool0HOooool2o`0000gooooo0_l00020ooooo`;o00003?ooool2o`0003?ooooo000`ooooo`;o0000
H_ooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Sooo
ool2o`0003[ooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo=_ooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool2o`000003oa0@4?oooooooooo08So
oooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0ROooool00:Cooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000003ooooo`Go0000R_ooool00:Cooooo00?o0000
ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S800oooool01?m4A4CogMgMooooool0002;ooooo`00Y?ooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00?ooooo00CogMgMoeEEEOoooooo0000Roooool00:;ooooo00?o410@o`000?l000000ol0000Ioooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Cooooo00?o
MgMgolc<c?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03onk^k_m4A4Co000008_ooooo
002Tooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`2:ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .24932 Mdot
.04762 .21178 Mdot
.07143 .19505 Mdot
.09524 .19474 Mdot
.11905 .20525 Mdot
.14286 .22215 Mdot
.16667 .24251 Mdot
.19048 .26461 Mdot
.21429 .28751 Mdot
.2381 .31062 Mdot
.2619 .33355 Mdot
.28571 .35592 Mdot
.30952 .37725 Mdot
.33333 .3968 Mdot
.35714 .41321 Mdot
.38095 .42377 Mdot
.40476 .42347 Mdot
.42857 .40495 Mdot
.45238 .36306 Mdot
.47619 .30481 Mdot
.5 .24932 Mdot
.52381 .21178 Mdot
.54762 .19505 Mdot
.57143 .19474 Mdot
.59524 .20525 Mdot
.61905 .22215 Mdot
.64286 .24251 Mdot
.66667 .26461 Mdot
.69048 .28751 Mdot
.71429 .31062 Mdot
.7381 .33355 Mdot
.7619 .35592 Mdot
.78571 .37725 Mdot
.80952 .3968 Mdot
.83333 .41321 Mdot
.85714 .42377 Mdot
.88095 .42347 Mdot
.90476 .40495 Mdot
.92857 .36306 Mdot
.95238 .30481 Mdot
.97619 .24932 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00027ooooo`;o00001Oooool2o`00097ooooo000`ooooo`03o`000?oooooooooo00_ooooo
0_l00005ooooo`;o0000Qoooool2o`0000Gooooo0_l0002Aooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0
003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo00?o
oooo0_l0002?ooooo`;o0000Woooool0033ooooo00?o0000ooooooooool00oooool2o`0008oooooo
0_l0002Oooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool08?ooool2
o`0008oooooo0_l00022ooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo023ooooo0_l0002?ooooo`;o0000P_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o0000
Soooool2o`0007_ooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o
0000Soooool2o`0007_ooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolgooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o0000
5_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00033o
oooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo
0_l0001dooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oo
oooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`0fooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>
ooooo`;o0000KOooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`25ooooo`;o0000Sooo
ool2o`0001gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0QOooool2
o`0008oooooo0_l0000Mooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000?Oooool2o`00
08oooooo0_l0001Uooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03go
oooo0_l0002?ooooo`;o0000IOooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolfooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003ooooooooo
o`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000COooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`1<oooo
o`;o0000S_ooool2o`0005Oooooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o
00009?ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool0013ooooo00?o0000
ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0
003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo067o
oooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0HOooool2o`0008oooooo
0_l00011ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0J?ooool2
o`0000Kooooo0_l00027ooooo`;o00001Oooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo
06Sooooo0_l00006ooooo`;o0000Qoooool2o`0000Gooooo0_l0000cooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=
ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04oa0@
4?l0003oA4A4olc<c8oooooo002Xooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00onHV9So410@omgMg@2>oooo
o`00Z?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00on7
QhOoEEEEooooo`2=ooooo`00Z?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003o
oooooooooooooooo000000_ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002>ooooo`00Z?ooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01OlQ8B7oQhN7oooooonH
V9So000008kooooo002Vooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00Z?ooool00ol0003ooooooooo
o`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooooomgMgOoEEEE08ko
oooo002Xooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
olc<c?l@413o0000oc8b<_o^k^h0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .28234 Mdot
.04762 .23753 Mdot
.07143 .21098 Mdot
.09524 .20218 Mdot
.11905 .20642 Mdot
.14286 .21891 Mdot
.16667 .23616 Mdot
.19048 .25595 Mdot
.21429 .277 Mdot
.2381 .29853 Mdot
.2619 .32005 Mdot
.28571 .34118 Mdot
.30952 .36153 Mdot
.33333 .3806 Mdot
.35714 .39748 Mdot
.38095 .4104 Mdot
.40476 .41598 Mdot
.42857 .40866 Mdot
.45238 .38223 Mdot
.47619 .33622 Mdot
.5 .28234 Mdot
.52381 .23753 Mdot
.54762 .21098 Mdot
.57143 .20218 Mdot
.59524 .20642 Mdot
.61905 .21891 Mdot
.64286 .23616 Mdot
.66667 .25595 Mdot
.69048 .277 Mdot
.71429 .29853 Mdot
.7381 .32005 Mdot
.7619 .34118 Mdot
.78571 .36153 Mdot
.80952 .3806 Mdot
.83333 .39748 Mdot
.85714 .4104 Mdot
.88095 .41598 Mdot
.90476 .40866 Mdot
.92857 .38223 Mdot
.95238 .33622 Mdot
.97619 .28234 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00004oooool2o`0008kooooo0_l0
002Aooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o00001Oooool2o`0008Oooooo0_l00005
ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:oooo
o`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`00
0?oooooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool0033ooooo0_l0000Qooooo`;o0000Sooo
ool2o`0008;ooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0
00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooo`;o00008_ooool2o`0006_ooooo
0_l0000Rooooo`;o0000Noooool000gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000
8_ooool2o`0006_ooooo0_l0000Rooooo`;o0000Noooool000gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0_
ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`03o`000?oooooooooo02oooooo0_l0002>oooo
o`;o0000M?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033o
oooo0_l0000gooooo`;o0000S_ooool2o`0006gooooo000_ooooo`;o0000Soooool2o`0008kooooo
0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0?Oooool2o`0008oooooo0_l0001Uooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000V
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001N
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0
002?ooooo`;o00007Oooool0033ooooo0_l0001=ooooo`;o0000=oooool2o`0005Gooooo0_l0000h
ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Goooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o
0000S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000
D?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0F_ooool2o`0008oooooo0_l00018ooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1Jooooo`;o00008_ooool2o`0006_ooooo0_l0000Rooooo`;o00009?ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0001nooooo`;o0000Soooool2o`0002Cooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Qooooo`;o0000Soooool2o`00047ooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o00003Oooool2o`00
083ooooo0_l0000<ooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0J?ooool2o`0000go
oooo0_l00020ooooo`;o00003?ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo073ooooo
0_l0002>ooooo`;o0000<oooool0033ooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo=_ooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`04oa0@4?l0003oA4A4olc<c0Cooooo00Gok^k^oc8b<_l0003o410@olc<c02:oooo
o`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd00oooool01OmEEEGoMgMgoooooonH
V9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ohN7QomEEEGooooo00;ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Y?oo
ool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`05o`000?nHV9SooooooiRHV?lQ8B40R_ooool00:Co
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go8B4QohN7
QoooooooV9RHo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0R_ooool00:;ooooo00?o410@
o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?oEEEEohN7Qoooool0S?ooool00:Cooooo00?o0000ooooooooool06_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`03
omgMgOl@413oV9RH08cooooo002Tooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@412:
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .31321 Mdot
.04762 .26623 Mdot
.07143 .23166 Mdot
.09524 .21403 Mdot
.11905 .21105 Mdot
.14286 .21828 Mdot
.16667 .23181 Mdot
.19048 .2489 Mdot
.21429 .26787 Mdot
.2381 .28768 Mdot
.2619 .30772 Mdot
.28571 .32756 Mdot
.30952 .34687 Mdot
.33333 .36529 Mdot
.35714 .38222 Mdot
.38095 .39646 Mdot
.40476 .40575 Mdot
.42857 .4061 Mdot
.45238 .39201 Mdot
.47619 .35964 Mdot
.5 .31321 Mdot
.52381 .26623 Mdot
.54762 .23166 Mdot
.57143 .21403 Mdot
.59524 .21105 Mdot
.61905 .21828 Mdot
.64286 .23181 Mdot
.66667 .2489 Mdot
.69048 .26787 Mdot
.71429 .28768 Mdot
.7381 .30772 Mdot
.7619 .32756 Mdot
.78571 .34687 Mdot
.80952 .36529 Mdot
.83333 .38222 Mdot
.85714 .39646 Mdot
.88095 .40575 Mdot
.90476 .4061 Mdot
.92857 .39201 Mdot
.95238 .35964 Mdot
.97619 .31321 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003ooooo
ooooo`0Booooo`;o00001Oooool2o`0008Oooooo0_l00005ooooo`;o0000R_ooool0033ooooo0_l0
000Cooooo`;o00003?ooool2o`00083ooooo0_l0000=ooooo`;o0000P_ooool0033ooooo00?o0000
ooooooooool08?ooool2o`0008oooooo0_l00022ooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00002oooool2o`0001[ooooo0_l0
001booooo`;o00006oooool2o`0007_ooooo000=ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02ooo
ool2o`0001[ooooo0_l0001booooo`;o00006oooool2o`0007_ooooo000=ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`00
3Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`00033o
oooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo
0_l0001dooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oo
oooo=oooool0033ooooo00?o0000ooooooooool00oooool2o`00037ooooo0_l0001Looooo`;o0000
<?ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0000aooooo`;o0000G?oo
ool2o`00033ooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0
001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0004Cooooo0_l0002?ooooo`;o0000G_ooool002Sooooo00?o0000oooooooo
ool01?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0
1?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o0000Eoooool0033o
oooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000
S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033o
oooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00<?ooool00ol0003ooooo
ooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011oooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`00067ooooo0_l0002?ooooo`;o0000@Oooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o0000
9?ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0J?ooool2o`0001Cooooo0_l0001iooooo`;o00005?oo
ool2o`0002Cooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0
000jooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo073ooooo0_l00005
ooooo`;o0000Qoooool2o`0000Gooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1`oooo
o`;o00001Oooool2o`0008Oooooo0_l00005ooooo`;o0000;?ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol0002:ooooo`00Y?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol@413o
oooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h0Roooool00:Cooooo00?o0000oooooooo
ool02oooool6o`0000cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?oV9RHob4Q8Oo^k^h0R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`29oooo
o`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02_ooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool0R?ooool00:Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0
003o^[ZjoooooonHV9So410@08[ooooo002Tooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIV
I_l000003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .33874 Mdot
.04762 .29489 Mdot
.07143 .25578 Mdot
.09524 .23019 Mdot
.11905 .21948 Mdot
.14286 .22061 Mdot
.16667 .22969 Mdot
.19048 .24358 Mdot
.21429 .26014 Mdot
.2381 .27805 Mdot
.2619 .2965 Mdot
.28571 .31501 Mdot
.30952 .33326 Mdot
.33333 .35095 Mdot
.35714 .36768 Mdot
.38095 .38263 Mdot
.40476 .39423 Mdot
.42857 .39969 Mdot
.45238 .39466 Mdot
.47619 .37457 Mdot
.5 .33874 Mdot
.52381 .29489 Mdot
.54762 .25578 Mdot
.57143 .23019 Mdot
.59524 .21948 Mdot
.61905 .22061 Mdot
.64286 .22969 Mdot
.66667 .24358 Mdot
.69048 .26014 Mdot
.71429 .27805 Mdot
.7381 .2965 Mdot
.7619 .31501 Mdot
.78571 .33326 Mdot
.80952 .35095 Mdot
.83333 .36768 Mdot
.85714 .38263 Mdot
.88095 .39423 Mdot
.90476 .39969 Mdot
.92857 .39466 Mdot
.95238 .37457 Mdot
.97619 .33874 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o00006_ooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003oooooooooo`0I
ooooo`;o00001Oooool2o`0008Oooooo0_l00006ooooo`;o0000P_ooool000gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`0001;ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0001kooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0
001kooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool000gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000`ooooo`;o0000S_ooool2o`0007Co
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool02ooo
ool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2
o`0009Sooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033o
oooo0_l0000gooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033o
oooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o00001?ooool2o`0008oooooo0_l0002Oooooo`00<?ooool00ol0003o
ooooooooo`03ooooo`;o0000?oooool2o`0004kooooo0_l0000oooooo`;o0000G_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000
G_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool002Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`009_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0Doooool2o`0008kooooo
0_l0001@ooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000_
ooooo`?o0000S_ooool2o`0008kooooo0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>oooo
o`;o00005_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0
002?ooooo`;o0000@Oooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0J?ooool2o`0008oooooo0_l0000jooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0006Sooooo0_l0002?ooooo`;o
0000>_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?oo
ool2o`0000cooooo0_l00020ooooo`;o00003Oooool2o`0002Cooooo000@ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Moooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0002Cooooo000>
ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool2o`0007Sooooo0_l0002>ooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`0R_ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool00000R_oo
ool00:Cooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2:ooooo`00Y?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooooooo
o`000003ooooo`05olc<c?l0003o0000o`000?o<c<`0R_ooool00:;ooooo00?o410@o`000?l00000
0ol0000Looooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?nj^[[ooooookZj^_l@4100R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o
000008[ooooo002Tooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2:ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .35735 Mdot
.04762 .32057 Mdot
.07143 .28124 Mdot
.09524 .2499 Mdot
.11905 .23172 Mdot
.14286 .22617 Mdot
.16667 .23008 Mdot
.19048 .24017 Mdot
.21429 .25392 Mdot
.2381 .26968 Mdot
.2619 .28642 Mdot
.28571 .30354 Mdot
.30952 .32069 Mdot
.33333 .33762 Mdot
.35714 .354 Mdot
.38095 .36926 Mdot
.40476 .3823 Mdot
.42857 .39111 Mdot
.45238 .39245 Mdot
.47619 .38216 Mdot
.5 .35735 Mdot
.52381 .32057 Mdot
.54762 .28124 Mdot
.57143 .2499 Mdot
.59524 .23172 Mdot
.61905 .22617 Mdot
.64286 .23008 Mdot
.66667 .24017 Mdot
.69048 .25392 Mdot
.71429 .26968 Mdot
.7381 .28642 Mdot
.7619 .30354 Mdot
.78571 .32069 Mdot
.80952 .33762 Mdot
.83333 .354 Mdot
.85714 .36926 Mdot
.88095 .3823 Mdot
.90476 .39111 Mdot
.92857 .39245 Mdot
.95238 .38216 Mdot
.97619 .35735 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l0
0022ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Pooooo`;o0000Sooo
ool2o`0008;ooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Iooooo`;o00003?ooool2o`00083ooooo0_l0
000=ooooo`;o0000Noooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`;o00003?oo
ool2o`00083ooooo0_l0000=ooooo`;o0000Noooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`;o0000
S_ooool2o`0007Cooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`;o
0000S_ooool2o`0007Cooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000
S_ooool2o`00097ooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0000Rooooo`;o0000J_oo
ool2o`0002;ooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2
o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0?Ooo
ool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2
o`0006Gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0000<ooooo`;o
0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000
V?ooool0033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool0
0ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool002Sooooo00?o0000oooo
ooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0
001>ooooo`;o0000?oooool2o`0004gooooo0_l0001@ooooo`009_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo00?ooooo0_l0001>ooooo`;o0000?oooool2o`0004gooooo0_l0001@
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo0_l0001Kooooo`;o0000Soooool2o`0004Sooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0
002?ooooo`;o0000@Oooool002oooooo0ol0001Rooooo`;o0000:_ooool2o`0006?ooooo0_l0000Y
ooooo`;o00005_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`;o0000JOooool2
o`0008oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo073ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0000Moooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`00073ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0000Mooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Moooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0002Cooooo000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Oooooo0_l00005ooooo`;o0000Qoooool2o`0000Kooooo0_l0000Tooooo`004?ooool0
0ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@oooo
o`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000oooooolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403ooooo
ocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l0
00000ol@413oooooooooo`28ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0ROooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo1Ol0002:ooooo`00Y?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgM
gOoooooo0000Roooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo0000Roooool00:;ooooo00?o410@o`00
0?l000000ol0000Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00omg
MgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`00002;ooooo`00Y?ooool00ol0003ooooo
ooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000
ooooo`2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .36908 Mdot
.04762 .34117 Mdot
.07143 .30557 Mdot
.09524 .27172 Mdot
.11905 .24738 Mdot
.14286 .23507 Mdot
.16667 .23322 Mdot
.19048 .23889 Mdot
.21429 .24936 Mdot
.2381 .26265 Mdot
.2619 .2775 Mdot
.28571 .29316 Mdot
.30952 .30919 Mdot
.33333 .32532 Mdot
.35714 .34126 Mdot
.38095 .35658 Mdot
.40476 .37045 Mdot
.42857 .38144 Mdot
.45238 .38715 Mdot
.47619 .38417 Mdot
.5 .36908 Mdot
.52381 .34117 Mdot
.54762 .30557 Mdot
.57143 .27172 Mdot
.59524 .24738 Mdot
.61905 .23507 Mdot
.64286 .23322 Mdot
.66667 .23889 Mdot
.69048 .24936 Mdot
.71429 .26265 Mdot
.7381 .2775 Mdot
.7619 .29316 Mdot
.78571 .30919 Mdot
.80952 .32532 Mdot
.83333 .34126 Mdot
.85714 .35658 Mdot
.88095 .37045 Mdot
.90476 .38144 Mdot
.92857 .38715 Mdot
.95238 .38417 Mdot
.97619 .36908 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l0
0028ooooo`;o00001Oooool2o`0007_ooooo000=ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Pooooo`;o00001Oooool2o`0000Kooooo0_l00020ooooo`;o00001Oooool2o`0000Gooooo
0_l0001dooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000
M?ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000Jooooo`;o
0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0000Kooooo`;o0000
LOooool2o`0001_ooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000S_oo
ool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool2o`0003kooooo0_l0002?ooooo`;o0000IOooool0033ooooo
00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003ooooooooo
o`0Booooo`;o0000S_ooool2o`00097ooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0002>
ooooo`;o0000TOooool0033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Noooo
o`00<?ooool2o`0004Gooooo0_l0002?ooooo`;o0000G_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0001=ooooo`;o0000S_ooool2o`0005Oooooo000`ooooo`03
o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00:?ooool00ol0003oooooooooo`05oooo
o`?o00002oooool2o`0004Kooooo0_l00016ooooo`;o0000A_ooool2o`00053ooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`0005_ooooo0_l0002?oooo
o`;o0000B?ooool0033ooooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l00004ooooo`;o0000G?ooool2o`00037ooooo0_l0001Looooo`;o0000@Oooool0
033ooooo00?o0000ooooooooool00oooool2o`0005cooooo0_l0000aooooo`;o0000G?ooool2o`00
047ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000JOooool2
o`0008oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`00
03[ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00;oooool2o`0007;ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0
000Fooooo`00;oooool3o`00077ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0000F
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
07Oooooo0_l0000<ooooo`;o0000P?ooool2o`0000gooooo0_l0000Mooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0007Oo
oooo0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l00006ooooo`;o00001Oooool2o`0001go
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol0002>ooooo`00Z?ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0S_ooool00:Sooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^08oooooo002Xooooo`03o`000?oooooo
oooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0S_ooool0
0:Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
08gooooo002Vooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo08cooooo002Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool01Ol0003o^[ZjoooooonHV9So410@08kooooo002Xooooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<08kooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .37497 Mdot
.04762 .3559 Mdot
.07143 .32662 Mdot
.09524 .29373 Mdot
.11905 .26551 Mdot
.14286 .24712 Mdot
.16667 .23926 Mdot
.19048 .23997 Mdot
.21429 .24665 Mdot
.2381 .25712 Mdot
.2619 .26986 Mdot
.28571 .28393 Mdot
.30952 .29878 Mdot
.33333 .31407 Mdot
.35714 .3295 Mdot
.38095 .34469 Mdot
.40476 .35901 Mdot
.42857 .37137 Mdot
.45238 .38001 Mdot
.47619 .38227 Mdot
.5 .37497 Mdot
.52381 .3559 Mdot
.54762 .32662 Mdot
.57143 .29373 Mdot
.59524 .26551 Mdot
.61905 .24712 Mdot
.64286 .23926 Mdot
.66667 .23997 Mdot
.69048 .24665 Mdot
.71429 .25712 Mdot
.7381 .26986 Mdot
.7619 .28393 Mdot
.78571 .29878 Mdot
.80952 .31407 Mdot
.83333 .3295 Mdot
.85714 .34469 Mdot
.88095 .35901 Mdot
.90476 .37137 Mdot
.92857 .38001 Mdot
.95238 .38227 Mdot
.97619 .37497 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`003Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o0000Qoooool2o`0000Gooooo
0_l0001dooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool2o`0008ko
oooo0_l0001dooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`00027ooooo0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001]ooooo`00
<?ooool00ol0003oooooooooo`0Pooooo`;o00005?ooool2o`0007Wooooo0_l0000Cooooo`;o0000
KOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0m
ooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?oooo
o`;o0000IOooool0033ooooo0_l0000Jooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`00
0?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0A?oo
ool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2
o`0005kooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOo
oooo000`ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o
0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o00004oooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003o
ooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000Xooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hoooo
o`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000E?ooool2o`0003Sooooo0_l0001Eooooo`;o
0000@Oooool0033ooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`03o`000?oooooooooo06So
oooo0_l0002?ooooo`;o0000>_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00001?ooool2o`0008oooooo0_l0002O
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Joooool2o`0002;ooooo0_l0001Zoooo
o`;o0000<oooool0033ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0001hooooo`;o0000S_ooool2o`0002cooooo000_ooooo`;o0000NOooool2o`00
01Cooooo0_l0001hooooo`;o00005?ooool2o`0001Kooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`00
083ooooo0_l0000=ooooo`;o0000P?ooool2o`0000cooooo0_l0000Fooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`1nooooo`;o00001Oooool2o`0008Sooooo0_l00005oooo
o`;o00007Oooool0013ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol00025ooooo`;o0000Soooool2o`0001gooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0R_ooool00:Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2:oooo
o`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
V9RHoooooonHV9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0R_ooool00:;o
oooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00kooooo00Ko0000oooooooo
oooooooooeEEEOn7QhN=ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH08cooooo002Toooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo00Coc<c<odA4A?l0003o410@R_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .37639 Mdot
.04762 .36503 Mdot
.07143 .34309 Mdot
.09524 .31401 Mdot
.11905 .2847 Mdot
.14286 .26173 Mdot
.16667 .24816 Mdot
.19048 .24359 Mdot
.21429 .24602 Mdot
.2381 .25326 Mdot
.2619 .26361 Mdot
.28571 .27592 Mdot
.30952 .28949 Mdot
.33333 .30387 Mdot
.35714 .31871 Mdot
.38095 .33364 Mdot
.40476 .34812 Mdot
.42857 .36132 Mdot
.45238 .37188 Mdot
.47619 .3778 Mdot
.5 .37639 Mdot
.52381 .36503 Mdot
.54762 .34309 Mdot
.57143 .31401 Mdot
.59524 .2847 Mdot
.61905 .26173 Mdot
.64286 .24816 Mdot
.66667 .24359 Mdot
.69048 .24602 Mdot
.71429 .25326 Mdot
.7381 .26361 Mdot
.7619 .27592 Mdot
.78571 .28949 Mdot
.80952 .30387 Mdot
.83333 .31871 Mdot
.85714 .33364 Mdot
.88095 .34812 Mdot
.90476 .36132 Mdot
.92857 .37188 Mdot
.95238 .3778 Mdot
.97619 .37639 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oo
oooo0_l0002>ooooo`;o0000M?ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l0000Xooooo`;o00001_ooool2o`0000Gooooo0_l00020ooooo`;o
00001Oooool2o`0000Gooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0Wooooo`;o0000
3Oooool2o`00083ooooo0_l0000<ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0?Ooo
ool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2
o`0006Gooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0033o
oooo0_l0000Qooooo`;o00008_ooool2o`0006_ooooo0_l0000Rooooo`;o0000G_ooool0033ooooo
00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o
0000Eoooool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?oo
ool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooo
oooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo0_l0001Dooooo`;o0000S_ooool2o`00
053ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00:?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool002Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`009_ooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003ooooooooo
o`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00_o
oooo0_l0001Sooooo`;o0000:Oooool2o`0006?ooooo0_l0000cooooo`00<?ooool00ol0003ooooo
ooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo07Oooooo0_l0002>oooo
o`;o0000;?ooool0033ooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`00
<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oo
oooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l0001oooooo`;o0000Soooool2
o`0002Cooooo000_ooooo`;o0000P?ooool2o`0000Gooooo0_l00006ooooo`;o0000P?ooool2o`00
00Gooooo0_l00005ooooo`;o00005_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o0000Qoooool2o`00
00Kooooo0_l00027ooooo`;o00001Oooool2o`0001Kooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`Go0000R_ooool00:Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q
1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02:oooo
o`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo00Cooooo00?oV9RHob4Q8Oo^k^h0
R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0
003o^[Zj00Kooooo00?oMgMgofIVI_ooool0ROooool00:;ooooo00?o410@o`000?l000000ol0000L
ooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool01_ooool00ol0003oooooooooo`28
ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooooiRHV?l@4100R_ooool00:Cooooo00?o0000
ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<08[ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .3746 Mdot
.04762 .36946 Mdot
.07143 .35462 Mdot
.09524 .33103 Mdot
.11905 .30333 Mdot
.14286 .27791 Mdot
.16667 .25956 Mdot
.19048 .24978 Mdot
.21429 .24763 Mdot
.2381 .25126 Mdot
.2619 .25891 Mdot
.28571 .26925 Mdot
.30952 .28139 Mdot
.33333 .29476 Mdot
.35714 .30892 Mdot
.38095 .32346 Mdot
.40476 .33789 Mdot
.42857 .35153 Mdot
.45238 .36333 Mdot
.47619 .37173 Mdot
.5 .3746 Mdot
.52381 .36946 Mdot
.54762 .35462 Mdot
.57143 .33103 Mdot
.59524 .30333 Mdot
.61905 .27791 Mdot
.64286 .25956 Mdot
.66667 .24978 Mdot
.69048 .24763 Mdot
.71429 .25126 Mdot
.7381 .25891 Mdot
.7619 .26925 Mdot
.78571 .28139 Mdot
.80952 .29476 Mdot
.83333 .30892 Mdot
.85714 .32346 Mdot
.88095 .33789 Mdot
.90476 .35153 Mdot
.92857 .36333 Mdot
.95238 .37173 Mdot
.97619 .3746 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0000gooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo02oooooo
0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l00005ooooo`;o00001_ooool2o`0006Gooooo
000`ooooo`03o`000?oooooooooo02oooooo0_l0000<ooooo`;o0000P?ooool2o`0000gooooo0_l0
001Uooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`oooo
o`03o`000?oooooooooo02Oooooo0_l0000Kooooo`;o0000L_ooool2o`0001_ooooo0_l0001Noooo
o`00<?ooool2o`0002Sooooo0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`
ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000oooo
ooooool08?ooool2o`0008oooooo0_l00022ooooo`00<?ooool2o`00027ooooo0_l0000aooooo`;o
0000G?ooool2o`00033ooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000
S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`0005_ooooo0_l0002?ooooo`;o0000B?ooool0033o
oooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool002Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000Xoooo
o`03o`000?oooooooooo00Gooooo0ol0001Qooooo`;o0000Soooool2o`00047ooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool2o`00
06Wooooo0_l0002?ooooo`;o0000>_ooool0033ooooo00?o0000ooooooooool04_ooool2o`0008ko
oooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo
000`ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo0_l0001a
ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo00_ooooo0_l0001Zooooo`;o00008_ooool2o`0006[ooooo0_l0
000/ooooo`00<?ooool2o`0000cooooo0_l0001Zooooo`;o00008_ooool2o`0006[ooooo0_l0000/
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo07ko
oooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oooooo
0_l0000Tooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000`
ooooo`;o00001?ooool2o`00083ooooo0_l0000=ooooo`;o0000P?ooool2o`0001gooooo000_oooo
o`;o0000Qoooool2o`0000Kooooo0_l00027ooooo`;o00001Oooool2o`0001Kooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c02:ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OlQ
8B7oV9RHoooooonHV9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool03_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R?ooool0
0:Cooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03Oooool00onY
ZJWo410@ooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80R_ooool00:Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o^[Zj00?ooooo00Goc<c<o`00
0?l0003o0000olc<c02:ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000oooo
ooooool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100R_ooool0
0:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000008[ooooo002Tooooo`03o`000?oooooo
oooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .37064 Mdot
.04762 .37025 Mdot
.07143 .36157 Mdot
.09524 .34402 Mdot
.11905 .31994 Mdot
.14286 .29439 Mdot
.16667 .2728 Mdot
.19048 .25836 Mdot
.21429 .25158 Mdot
.2381 .2513 Mdot
.2619 .25592 Mdot
.28571 .26402 Mdot
.30952 .27455 Mdot
.33333 .28677 Mdot
.35714 .30013 Mdot
.38095 .31416 Mdot
.40476 .32837 Mdot
.42857 .34216 Mdot
.45238 .35468 Mdot
.47619 .36474 Mdot
.5 .37064 Mdot
.52381 .37025 Mdot
.54762 .36157 Mdot
.57143 .34402 Mdot
.59524 .31994 Mdot
.61905 .29439 Mdot
.64286 .2728 Mdot
.66667 .25836 Mdot
.69048 .25158 Mdot
.71429 .2513 Mdot
.7381 .25592 Mdot
.7619 .26402 Mdot
.78571 .27455 Mdot
.80952 .28677 Mdot
.83333 .30013 Mdot
.85714 .31416 Mdot
.88095 .32837 Mdot
.90476 .34216 Mdot
.92857 .35468 Mdot
.95238 .36474 Mdot
.97619 .37064 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o0000
Qoooool2o`0000Kooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o00001Ooo
ool2o`0008Oooooo0_l00006ooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0;oooool2
o`0001?ooooo0_l0001iooooo`;o00005?ooool2o`0005kooooo000`ooooo`03o`000?oooooooooo
02oooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0001Nooooo`00<?ooool2o`0004go
oooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo
0_l0001Gooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo02Oooooo0_l0000Zooooo`;o0000Hoooool2o`0002Wooooo0_l0001@ooooo`00<?ooool00ol0
003oooooooooo`0Wooooo`;o0000:_ooool2o`0006?ooooo0_l0000Yooooo`;o0000D?ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00<?ooool00ol0003oooooooooo`1J
ooooo`;o0000Soooool2o`0004Sooooo000`ooooo`;o00008Oooool2o`0008oooooo0_l00022oooo
o`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l0
0011ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool0
02Sooooo00?o0000ooooooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_oo
ool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2
o`0008[ooooo000`ooooo`;o0000LOooool2o`0008kooooo0_l0000cooooo`00<?ooool00ol0003o
ooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool04_ooool2o`0006?ooooo0_l0000Yooooo`;o0000Hoooool2o`00
02cooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0001Sooooo`;o0000:Oooool2o`0006?o
oooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo0_l0001oooooo`;o0000Soooool2
o`0002Cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000
N?ooool2o`0001Cooooo0_l0001iooooo`;o00007Oooool002oooooo0_l00005ooooo`;o0000P?oo
ool2o`0000Kooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l0000Fooooo`00;oooool3
o`0000Cooooo0_l00028ooooo`;o00001Oooool2o`0008Oooooo0_l0000Fooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`03ooooo`;o000000?o410@ooooooooool0R?ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo08Wooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02_ooool5o`0000?ooooo1Ol0002:ooooo`00Y?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`0:ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4
omgMgOoooooo0000Roooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo0000Roooool00:;ooooo00?o
410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00_ooooo00?oMgMgolc<c?l000001Ooo
ool00omgMgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00_ooooo00?ok^k^odA4A?l000001Oooool00oo^k^koA4A4o`00002;ooooo`00Y?ooool00ol0
003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000kooooo00?oMgMgo`000?ooool01Oooool00omg
MgOo0000ooooo`2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .36526 Mdot
.04762 .36837 Mdot
.07143 .36468 Mdot
.09524 .35286 Mdot
.11905 .3335 Mdot
.14286 .30988 Mdot
.16667 .28693 Mdot
.19048 .26891 Mdot
.21429 .25779 Mdot
.2381 .25347 Mdot
.2619 .25479 Mdot
.28571 .26038 Mdot
.30952 .26906 Mdot
.33333 .27995 Mdot
.35714 .29237 Mdot
.38095 .30576 Mdot
.40476 .31959 Mdot
.42857 .3333 Mdot
.45238 .34619 Mdot
.47619 .35729 Mdot
.5 .36526 Mdot
.52381 .36837 Mdot
.54762 .36468 Mdot
.57143 .35286 Mdot
.59524 .3335 Mdot
.61905 .30988 Mdot
.64286 .28693 Mdot
.66667 .26891 Mdot
.69048 .25779 Mdot
.71429 .25347 Mdot
.7381 .25479 Mdot
.7619 .26038 Mdot
.78571 .26906 Mdot
.80952 .27995 Mdot
.83333 .29237 Mdot
.85714 .30576 Mdot
.88095 .31959 Mdot
.90476 .3333 Mdot
.92857 .34619 Mdot
.95238 .35729 Mdot
.97619 .36526 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0?Oooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`0005kooooo000`
ooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l00006
ooooo`;o00001Oooool2o`0005kooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0000Doooo
o`;o0000N?ooool2o`0001Cooooo0_l0001Gooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o
0000Eoooool0033ooooo00?o0000ooooooooool0;oooool2o`0002;ooooo0_l0001Zooooo`;o0000
8_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo02oooooo0_l0000Rooooo`;o0000J_oo
ool2o`0002;ooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001Kooooo`;o0000Soooool2o`0004So
oooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo00?o
0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003oooooooooo`0W
ooooo`;o0000Soooool2o`0007_ooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011oooo
o`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`00023ooooo0_l00016ooooo`;o0000Aoooool2o`0004Kooooo0_l0000joooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo0_l0002?ooooo`;o
0000P_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0
000cooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo073ooooo0_l0002>
ooooo`;o0000<oooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool06Oooool2o`0005cooooo0_l0000`ooooo`;o0000
G?ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0001Looooo`;o0000<?oo
ool2o`0005cooooo0_l0000/ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Co
oooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o
0000ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool2o`0001?ooooo0_l0001a
ooooo`;o00006oooool2o`0007;ooooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`25oooo
o`;o0000Soooool2o`0001gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002oooooo
0_l0000=ooooo`;o0000P?ooool2o`0000cooooo0_l00020ooooo`;o00005_ooool002oooooo0_l0
0005ooooo`;o00001_ooool2o`00083ooooo0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l0
000Fooooo`00<?ooool2o`0000Cooooo0_l0002?ooooo`;o0000Woooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o
0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o0000odA4A?nj^[X06Ooo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
SOooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2<ooooo`00Z?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Roooool00:Sooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`2<
ooooo`00Z?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c02=ooooo`00Y_ooool00ol@413o0000o`000003o`0001cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2?ooooo`00Z?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Soooool00:Sooooo00?o0000ooooooooool0
6oooool00omEEEGoIVIVo`00000=ooooo`Co0000S_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .35903 Mdot
.04762 .36463 Mdot
.07143 .36478 Mdot
.09524 .35793 Mdot
.11905 .34358 Mdot
.14286 .32331 Mdot
.16667 .30089 Mdot
.19048 .28074 Mdot
.21429 .26601 Mdot
.2381 .25778 Mdot
.2619 .25563 Mdot
.28571 .25844 Mdot
.30952 .26503 Mdot
.33333 .27438 Mdot
.35714 .28568 Mdot
.38095 .29827 Mdot
.40476 .31157 Mdot
.42857 .32502 Mdot
.45238 .33798 Mdot
.47619 .34967 Mdot
.5 .35903 Mdot
.52381 .36463 Mdot
.54762 .36478 Mdot
.57143 .35793 Mdot
.59524 .34358 Mdot
.61905 .32331 Mdot
.64286 .30089 Mdot
.66667 .28074 Mdot
.69048 .26601 Mdot
.71429 .25778 Mdot
.7381 .25563 Mdot
.7619 .25844 Mdot
.78571 .26503 Mdot
.80952 .27438 Mdot
.83333 .28568 Mdot
.85714 .29827 Mdot
.88095 .31157 Mdot
.90476 .32502 Mdot
.92857 .33798 Mdot
.95238 .34967 Mdot
.97619 .35903 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003oooooooooo`0m
ooooo`;o00001Oooool2o`0000Kooooo0_l00020ooooo`;o00001Oooool2o`0000Gooooo0_l0001G
ooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o00003Oooool2o`00083ooooo0_l0000<oooo
o`;o0000Eoooool0033ooooo0_l0001Dooooo`;o0000S_ooool2o`00053ooooo000`ooooo`03o`00
0?oooooooooo03Kooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0001@ooooo`00<?oo
ool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooo
oooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0F_ooool2o`00
08oooooo0_l00018ooooo`00<?ooool2o`00033ooooo0_l0002>ooooo`;o0000M?ooool0033ooooo
00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool00ol0003ooooooooo
o`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0002?
ooooo`;o0000@Oooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo06So
oooo0_l0002?ooooo`;o0000>_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo02Oooooo0_l0000oooooo`;o0000C_ooool2o`0003oooooo0_l0000jooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Nooo
ool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xoooo
o`03o`000?oooooooooo00Gooooo0ol0001`ooooo`;o0000S_ooool2o`0003?ooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool08?ooool2o`0005Gooooo0_l0000hooooo`;o0000E?ooool2
o`0002cooooo000`ooooo`;o00008Oooool2o`0005Gooooo0_l0000hooooo`;o0000E?ooool2o`00
02cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000`
ooooo`;o0000Ooooool2o`0008oooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`0Ioooo
o`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o
0000R_ooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00<?oo
ool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`0001gooooo000`ooooo`;o00004oooool2
o`0008kooooo0_l0002Aooooo`00;oooool2o`0001Cooooo0_l0001iooooo`;o00004oooool2o`00
07Wooooo0_l0000Fooooo`00;oooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`0008Oo
oooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`0008Oooooo
0_l00005ooooo`;o0000V?ooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0
002Hooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`006?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooo
ooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004oooo
o`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Go
oooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Go
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08[ooooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000co
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_oooooooooooeEEEOmgMgOo
oooooiRHV?lQ8B40R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0R?ooool00:Cooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8boooooooo
oooo0000oiRHV?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool00omEEEGoQhN7ooooo`2<ooooo`00Y?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ooMgMgo410@
oiRHV02<ooooo`00Y?ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo1?l0
0004ooooo`04olc<c?m4A4Co0000oa0@48[ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .35231 Mdot
.04762 .35964 Mdot
.07143 .36266 Mdot
.09524 .35985 Mdot
.11905 .35018 Mdot
.14286 .334 Mdot
.16667 .31366 Mdot
.19048 .29301 Mdot
.21429 .27575 Mdot
.2381 .26407 Mdot
.2619 .25846 Mdot
.28571 .2583 Mdot
.30952 .26254 Mdot
.33333 .27012 Mdot
.35714 .2801 Mdot
.38095 .29172 Mdot
.40476 .30433 Mdot
.42857 .31734 Mdot
.45238 .33016 Mdot
.47619 .34211 Mdot
.5 .35231 Mdot
.52381 .35964 Mdot
.54762 .36266 Mdot
.57143 .35985 Mdot
.59524 .35018 Mdot
.61905 .334 Mdot
.64286 .31366 Mdot
.66667 .29301 Mdot
.69048 .27575 Mdot
.71429 .26407 Mdot
.7381 .25846 Mdot
.7619 .2583 Mdot
.78571 .26254 Mdot
.80952 .27012 Mdot
.83333 .2801 Mdot
.85714 .29172 Mdot
.88095 .30433 Mdot
.90476 .31734 Mdot
.92857 .33016 Mdot
.95238 .34211 Mdot
.97619 .35231 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o00001_ooool2
o`0008Oooooo0_l00005ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0A?ooool2o`00
00Kooooo0_l00027ooooo`;o00001Oooool2o`0005Oooooo000`ooooo`;o0000?_ooool2o`0001Co
oooo0_l0001iooooo`;o00004oooool2o`00053ooooo000`ooooo`03o`000?oooooooooo03gooooo
0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001@ooooo`00<?ooool00ol0003ooooooooo
o`1Jooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0002?
ooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]oooo
o`00<?ooool2o`0003Oooooo0_l0000Yooooo`;o0000Hoooool2o`0002[ooooo0_l00011ooooo`00
<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000j
ooooo`00<?ooool2o`00033ooooo0_l0000gooooo`;o0000EOooool2o`0003Sooooo0_l0000joooo
o`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0
02Sooooo00?o0000ooooooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09oooool2o`0004kooooo0_l0000oooooo`;o0000
COooool2o`0002cooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Mooo
ool2o`0008kooooo0_l0000/ooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo07ko
oooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool08?ooool2o`0005cooooo
0_l0000aooooo`;o0000G?ooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0
002?ooooo`;o0000P_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oo
oooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo
000_ooooo`;o00006oooool2o`0007;ooooo0_l0000Jooooo`;o0000L_ooool2o`0001Kooooo000_
ooooo`?o0000S_ooool2o`0008kooooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`03oooo
o`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000TOooool0033ooooo00?o0000oooooooo
ool00oooool2o`0000Kooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l00005ooooo`;o
0000TOooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c003ooooo`Go0000R_ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A02:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^
08_ooooo002Tooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03oiRHV?lQ8B7ok^k^08[ooooo002Tooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?oMgMgofIVI_ooool0ROooool00:;ooooo00?o410@o`000?l000000ol0000Looooo`03
o`000?oooooooooo00[ooooo00?oEEEEohN7Qoooool02Oooool00ol0003oooooooooo`28ooooo`00
Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01Ol0003o^[ZjoooooonHV9So410@08[ooooo002Tooooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@4103ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0R_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .34539 Mdot
.04762 .35385 Mdot
.07143 .35894 Mdot
.09524 .3593 Mdot
.11905 .35369 Mdot
.14286 .34171 Mdot
.16667 .32448 Mdot
.19048 .30483 Mdot
.21429 .28636 Mdot
.2381 .27201 Mdot
.2619 .2632 Mdot
.28571 .26001 Mdot
.30952 .2617 Mdot
.33333 .26725 Mdot
.35714 .27569 Mdot
.38095 .28616 Mdot
.40476 .29791 Mdot
.42857 .31032 Mdot
.45238 .3228 Mdot
.47619 .33473 Mdot
.5 .34539 Mdot
.52381 .35385 Mdot
.54762 .35894 Mdot
.57143 .3593 Mdot
.59524 .35369 Mdot
.61905 .34171 Mdot
.64286 .32448 Mdot
.66667 .30483 Mdot
.69048 .28636 Mdot
.71429 .27201 Mdot
.7381 .2632 Mdot
.7619 .26001 Mdot
.78571 .2617 Mdot
.80952 .26725 Mdot
.83333 .27569 Mdot
.85714 .28616 Mdot
.88095 .29791 Mdot
.90476 .31032 Mdot
.92857 .3228 Mdot
.95238 .33473 Mdot
.97619 .34539 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo04cooooo0_l00005ooooo`;o0000Qoooool2o`0000Gooooo0_l0001@oooo
o`00<?ooool2o`0004Gooooo0_l00006ooooo`;o00001Oooool2o`00083ooooo0_l00005ooooo`;o
00001Oooool2o`00053ooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0000Dooooo`;o0000
NOooool2o`0001Cooooo0_l00018ooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o00006ooo
ool2o`0007;ooooo0_l0000Kooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0?Oooool2
o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00
047ooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0000`ooooo`;o0000G?oo
ool2o`00037ooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000<?ooool2
o`0005cooooo0_l0000aooooo`;o0000>_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001d
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000Moooool2o`0008kooooo0_l0000/oooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o
0000;?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`009_ooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo02Oooooo0_l0001Eooooo`;o0000>?ooool2
o`0005Gooooo0_l0000Tooooo`00<?ooool2o`0002Sooooo0_l0001Eooooo`;o0000>?ooool2o`00
05Gooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0QOoo
ool2o`0008oooooo0_l0000Mooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool08?ooool2o`0008oooooo0_l00022ooooo`00;oooool2o`0002;ooooo0_l0001[ooooo`;o
00008_ooool2o`0006[ooooo0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o0000
5_ooool0033ooooo00?o0000ooooooooool00oooool2o`0001Cooooo0_l0001iooooo`;o00004ooo
ool2o`0008[ooooo000`ooooo`;o00001?ooool2o`0001Cooooo0_l0001iooooo`;o00004oooool2
o`0008[ooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o0000Qoooool2o`00
00Gooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool2o`0008Oo
oooo0_l00005ooooo`;o0000TOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0R_ooool00:Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000R_ooool00:Cooooo00?o0000ooooooooool02oooool6
o`0000cooooo00?o0000ooooooooool02_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P2:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05olc<c?l0003o0000o`000?o<
c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo
00?oEEEEohN7Qoooool01Oooool01Ol@413o^[Zjoooooonj^[[o410@08[ooooo002Tooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02_ooool00ooMgMgo410@oiRHV005ooooo`05o`00
0?nj^[[ooooookZj^_l00000R_ooool00:Cooooo00?o0000ooooooooool06oooool00omEEEGoIVIV
o`00000=ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2:oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .33846 Mdot
.04762 .34761 Mdot
.07143 .35414 Mdot
.09524 .35688 Mdot
.11905 .35463 Mdot
.14286 .34656 Mdot
.16667 .33291 Mdot
.19048 .31542 Mdot
.21429 .29709 Mdot
.2381 .28109 Mdot
.2619 .26962 Mdot
.28571 .26351 Mdot
.30952 .26252 Mdot
.33333 .26585 Mdot
.35714 .27253 Mdot
.38095 .28162 Mdot
.40476 .29233 Mdot
.42857 .30397 Mdot
.45238 .31594 Mdot
.47619 .32765 Mdot
.5 .33846 Mdot
.52381 .34761 Mdot
.54762 .35414 Mdot
.57143 .35688 Mdot
.59524 .35463 Mdot
.61905 .34656 Mdot
.64286 .33291 Mdot
.66667 .31542 Mdot
.69048 .29709 Mdot
.71429 .28109 Mdot
.7381 .26962 Mdot
.7619 .26351 Mdot
.78571 .26252 Mdot
.80952 .26585 Mdot
.83333 .27253 Mdot
.85714 .28162 Mdot
.88095 .29233 Mdot
.90476 .30397 Mdot
.92857 .31594 Mdot
.95238 .32765 Mdot
.97619 .33846 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001=ooooo`;o00001Oooool2o`0008Oo
oooo0_l00005ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0C?ooool2o`0000Gooooo
0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l00006ooooo`;o0000B?ooool0033ooooo00?o
0000ooooooooool0A?ooool2o`0001Cooooo0_l0001iooooo`;o00005?ooool2o`0004Sooooo000`
ooooo`03o`000?oooooooooo04Cooooo0_l0000Kooooo`;o0000L_ooool2o`0001_ooooo0_l00011
ooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`;o
0000?_ooool2o`0002Wooooo0_l0001Tooooo`;o0000:Oooool2o`0003[ooooo000`ooooo`03o`00
0?oooooooooo03gooooo0_l0000Yooooo`;o0000I?ooool2o`0002Wooooo0_l0000jooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo03Ko
oooo0_l0000hooooo`;o0000E?ooool2o`0003Sooooo0_l0000cooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o0000;?oo
ool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`;o0000S_ooool2
o`0002cooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocKooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02oooooo0_l0001=ooooo`;o0000?oooool2o`0004kooooo
0_l0000Tooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo0_l0
001=ooooo`;o0000?oooool2o`0004kooooo0_l0000Tooooo`009_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l00026ooooo`;o0000Soooool2o`00
01gooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo
00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003ooooooooo
o`0Wooooo`;o0000Soooool2o`0007_ooooo000_ooooo`?o0000S_ooool2o`0008kooooo0_l0000F
ooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0033ooooo00?o0000oooooooo
ool00oooool2o`0001_ooooo0_l0001booooo`;o00006oooool2o`0008;ooooo000`ooooo`03o`00
0?oooooooooo00?ooooo0_l0000Kooooo`;o0000L_ooool2o`0001_ooooo0_l00022ooooo`00<?oo
ool00ol0003oooooooooo`0;ooooo`;o00003?ooool2o`00083ooooo0_l0000<ooooo`;o0000R_oo
ool0033ooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001Oooool2
o`0000Gooooo0_l0002:ooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00
097ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>
ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001So
oooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo
000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Ooo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
00kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000oooooooo
ool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMg
ofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05
o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<
0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01Oooool2o`000003oa0@4?oooooooooo08Sooooo002Tooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01_ooool00ol0003oooooooooo`29ooooo`00Y?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool00oooool5o`0008[ooooo002Toooo
o`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o8B4Qoooo
ooooool00_ooool01?m4A4CogMgMooooool0002;ooooo`00Y?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00_ooool01?oMgMgoEEEEooooool0002;
ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00onY
ZJWoMgMgooooo`03ooooo`03ogMgMoo<c<co000008_ooooo002Tooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?ok^k^odA4
A?l00000Roooool00:Cooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`Go
00001Oooool00omgMgOo0000ooooo`2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .33166 Mdot
.04762 .34116 Mdot
.07143 .34864 Mdot
.09524 .35313 Mdot
.11905 .35353 Mdot
.14286 .34889 Mdot
.16667 .33885 Mdot
.19048 .32424 Mdot
.21429 .30722 Mdot
.2381 .29071 Mdot
.2619 .27733 Mdot
.28571 .26864 Mdot
.30952 .265 Mdot
.33333 .26595 Mdot
.35714 .27065 Mdot
.38095 .27817 Mdot
.40476 .28765 Mdot
.42857 .29835 Mdot
.45238 .30964 Mdot
.47619 .32093 Mdot
.5 .33166 Mdot
.52381 .34116 Mdot
.54762 .34864 Mdot
.57143 .35313 Mdot
.59524 .35353 Mdot
.61905 .34889 Mdot
.64286 .33885 Mdot
.66667 .32424 Mdot
.69048 .30722 Mdot
.71429 .29071 Mdot
.7381 .27733 Mdot
.7619 .26864 Mdot
.78571 .265 Mdot
.80952 .26595 Mdot
.83333 .27065 Mdot
.85714 .27817 Mdot
.88095 .28765 Mdot
.90476 .29835 Mdot
.92857 .30964 Mdot
.95238 .32093 Mdot
.97619 .33166 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001Dooooo`;o0000S_ooool2o`00053o
oooo000`ooooo`03o`000?oooooooooo04cooooo0_l00005ooooo`;o00001Oooool2o`00083ooooo
0_l00005ooooo`;o00001_ooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo04cooooo0_l0
000<ooooo`;o00001Oooool2o`0007Wooooo0_l0000=ooooo`;o00001Oooool2o`00047ooooo000`
ooooo`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000oooo
ooooool0A?ooool2o`0002;ooooo0_l0001[ooooo`;o00008_ooool2o`0003[ooooo000`ooooo`;o
0000AOooool2o`0002;ooooo0_l0001[ooooo`;o00008_ooool2o`0003[ooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0
000cooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000<Oooool2o`0005cooooo0_l0000`
ooooo`;o0000<oooool0033ooooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03
o`000?oooooooooo07Oooooo0_l0002>ooooo`;o0000;?ooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o0000;?ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00:?ooool00ol0
003oooooooooo`05ooooo`?o0000=_ooool2o`0004Kooooo0_l00016ooooo`;o0000Aoooool2o`00
02Cooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool2o`0008oo
oooo0_l0000Tooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`25ooooo`;o0000Sooo
ool2o`0001gooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0;oooool2
o`0005Cooooo0_l0000hooooo`;o0000EOooool2o`0001gooooo000`ooooo`;o0000<?ooool2o`00
08kooooo0_l0001dooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002oooooo
0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l00004ooooo`;o00008_ooool2o`0006_ooooo0_l0000Rooooo`;o0000Noooool0
033ooooo00?o0000ooooooooool00oooool2o`0002;ooooo0_l0001[ooooo`;o00008_ooool2o`00
07_ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
2oooool2o`0001?ooooo0_l0001iooooo`;o00005?ooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o0000P_ooool0033ooooo0_l0000Cooooo`;o00001Oooool2
o`0008Oooooo0_l00005ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=
ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`0S_ooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q08ko
oooo002Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000008kooooo002Xooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2>ooooo`00Z?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Goc<c<o`000?l0003o0000olc<c02>ooooo`00
Y_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02_ooool01Ol@413o^[Zj
oooooonj^[[o410@08kooooo002Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool01Ol0003o^[Zjoooooonj^[[o000008kooooo002Xooooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413oZJVY08kooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .3251 Mdot
.04762 .33468 Mdot
.07143 .34274 Mdot
.09524 .34847 Mdot
.11905 .35091 Mdot
.14286 .34912 Mdot
.16667 .34244 Mdot
.19048 .33101 Mdot
.21429 .31615 Mdot
.2381 .30022 Mdot
.2619 .28586 Mdot
.28571 .27513 Mdot
.30952 .26902 Mdot
.33333 .26755 Mdot
.35714 .27011 Mdot
.38095 .27585 Mdot
.40476 .28391 Mdot
.42857 .2935 Mdot
.45238 .30394 Mdot
.47619 .31466 Mdot
.5 .3251 Mdot
.52381 .33468 Mdot
.54762 .34274 Mdot
.57143 .34847 Mdot
.59524 .35091 Mdot
.61905 .34912 Mdot
.64286 .34244 Mdot
.66667 .33101 Mdot
.69048 .31615 Mdot
.71429 .30022 Mdot
.7381 .28586 Mdot
.7619 .27513 Mdot
.78571 .26902 Mdot
.80952 .26755 Mdot
.83333 .27011 Mdot
.85714 .27585 Mdot
.88095 .28391 Mdot
.90476 .2935 Mdot
.92857 .30394 Mdot
.95238 .31466 Mdot
.97619 .3251 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo05?ooooo0_l00005ooooo`;o0000Qoooool2o`0000Kooooo0_l00018ooooo`00<?oo
ool00ol0003oooooooooo`1Cooooo`;o00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001_oo
ool2o`0000Gooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o00004oooool2
o`0007Wooooo0_l0000Dooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0C?ooool2o`00
01[ooooo0_l0001booooo`;o00006oooool2o`0003[ooooo000`ooooo`;o0000JOooool2o`0008oo
oooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo
000`ooooo`03o`000?oooooooooo04Cooooo0_l0000Zooooo`;o0000Hoooool2o`0002Wooooo0_l0
000cooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`oooo
o`;o0000N?ooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1gooooo`;o
0000S_ooool2o`0002cooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0mooooo`;o0000Soooool2o`0006Gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0?Oooool2o`0003oooooo0_l0001>ooooo`;o0000?oooool2o`0002Cooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000T
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool002Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`;o0000COooool2o`0003oooooo
0_l0001>ooooo`;o00007Oooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0fooooo`;o0000S_ooool2o`0006gooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000
ooooooooool0oooooolfooooo`00;oooool3o`0008kooooo0_l0002>ooooo`;o00005_ooool002oo
oooo0_l0000aooooo`;o0000G?ooool2o`00033ooooo0_l0001Looooo`;o00005_ooool0033ooooo
00?o0000ooooooooool00oooool2o`0002[ooooo0_l0001Sooooo`;o0000:Oooool2o`0007Cooooo
000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0000Jooooo`;o0000L_ooool2o`00
01_ooooo0_l0001kooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o00006_ooool2o`0007;o
oooo0_l0000Kooooo`;o0000Noooool0033ooooo00?o0000ooooooooool04_ooool2o`0000Gooooo
0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l00006ooooo`;o0000P_ooool0033ooooo00?o
0000ooooooooool04_ooool2o`0000Gooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l0
0006ooooo`;o0000P_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02:ooooo`00
Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So
8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Y?ooool0
0ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S800oooool01Ol0003oV9RHoooooonHV9So8B4Q08[ooooo002Tooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02_ooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo
00Go0000oeEEEOl0003o410@olc<c02:ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo
00?o0000ooooooooool02_ooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00?oEEEEohN7Qooo
ool0S?ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05o`00
0?nj^[[ooooookZj^_l000000oooool00ooMgMgo410@oiRHV02<ooooo`00Y?ooool00ol0003ooooo
ooooo`0Kooooo`03oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`04
olc<c?m4A4Co0000oa0@48[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.92) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .31886 Mdot
.04762 .32832 Mdot
.07143 .33667 Mdot
.09524 .34324 Mdot
.11905 .34721 Mdot
.14286 .34771 Mdot
.16667 .34396 Mdot
.19048 .33569 Mdot
.21429 .3235 Mdot
.2381 .30903 Mdot
.2619 .29463 Mdot
.28571 .28258 Mdot
.30952 .27438 Mdot
.33333 .27057 Mdot
.35714 .27091 Mdot
.38095 .27471 Mdot
.40476 .28116 Mdot
.42857 .28945 Mdot
.45238 .29889 Mdot
.47619 .30888 Mdot
.5 .31886 Mdot
.52381 .32832 Mdot
.54762 .33667 Mdot
.57143 .34324 Mdot
.59524 .34721 Mdot
.61905 .34771 Mdot
.64286 .34396 Mdot
.66667 .33569 Mdot
.69048 .3235 Mdot
.71429 .30903 Mdot
.7381 .29463 Mdot
.7619 .28258 Mdot
.78571 .27438 Mdot
.80952 .27057 Mdot
.83333 .27091 Mdot
.85714 .27471 Mdot
.88095 .28116 Mdot
.90476 .28945 Mdot
.92857 .29889 Mdot
.95238 .30888 Mdot
.97619 .31886 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0F_ooool2o`0000Gooooo0_l0
0028ooooo`;o00001Oooool2o`00047ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o0000>_ooool0033ooooo00?o0000ooooooooool0Doooool2o`0001?ooooo0_l0001ioooo
o`;o00005?ooool2o`0003[ooooo000`ooooo`;o0000LOooool2o`0008kooooo0_l0000cooooo`00
<?ooool00ol0003oooooooooo`1<ooooo`;o00008_ooool2o`0006[ooooo0_l0000Rooooo`;o0000
<oooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool0
0ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`;o0000AOooool2o`00
037ooooo0_l0001Looooo`;o0000<?ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo04Co
oooo0_l0002?ooooo`;o0000G_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05oooo
o`?o0000?Oooool2o`0004Kooooo0_l00017ooooo`;o0000A_ooool2o`0001gooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool2o`0004Kooooo0_l00017ooooo`;o
0000A_ooool2o`0001gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolfooooo`00:?ooool00ol0003oooooooooo`04ooooo`;o0000Soooool2o`0008kooooo0_l0
000Fooooo`009_ooool00omEEEGoIVIVo`000006ooooo`;o0000>?ooool2o`0005Gooooo0_l0000g
ooooo`;o0000EOooool2o`0001Kooooo000`ooooo`;o00001?ooool2o`00037ooooo0_l0001Loooo
o`;o0000<?ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o
0000Woooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`0;ooooo`;o00008_ooool2o`0006[ooooo0_l0000Rooooo`;o0000M?ooool0033ooooo0_l0000<
ooooo`;o00008_ooool2o`0006[ooooo0_l0000Rooooo`;o0000M?ooool0033ooooo00?o0000oooo
ooooool04_ooool2o`0001?ooooo0_l0001iooooo`;o00005?ooool2o`0007_ooooo000`ooooo`03
o`000?oooooooooo01;ooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o
00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000Noooool0033ooooo00?o0000ooooooooool0
6Oooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01?l@413o0000odA4A?o<c<`4ooooo`Go0000R_ooool00:Cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00onHV9So410@
omgMg@03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0R_ooool00:Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0=ooooo`03ohN7QomEEEGooooo00?ooooo00?oV9RHob4Q8Oo^k^h0
Roooool00:Cooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool02_oo
ool01Oo<c<co8B4Qo`000?mEEEGo000000Gooooo00?oV9RHob4Q8Oo^k^h0R_ooool00:Cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ob4Q8On7QhOooooooiRHV?l00000
1_ooool00omgMgOoIVIVooooo`29ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
R?ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ob4Q8OnH
V9SoooooogMgMomEEED00oooool01Ol0003o^[ZjoooooonHV9So410@08[ooooo002Tooooo`03o`00
0?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01Oo<c<co410@o`000?lb<S;ok^k^00?o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .31303 Mdot
.04762 .32218 Mdot
.07143 .33059 Mdot
.09524 .33769 Mdot
.11905 .34277 Mdot
.14286 .34507 Mdot
.16667 .3438 Mdot
.19048 .33844 Mdot
.21429 .32908 Mdot
.2381 .31669 Mdot
.2619 .30312 Mdot
.28571 .29054 Mdot
.30952 .28078 Mdot
.33333 .27488 Mdot
.35714 .273 Mdot
.38095 .27476 Mdot
.40476 .27944 Mdot
.42857 .28628 Mdot
.45238 .29456 Mdot
.47619 .30365 Mdot
.5 .31303 Mdot
.52381 .32218 Mdot
.54762 .33059 Mdot
.57143 .33769 Mdot
.59524 .34277 Mdot
.61905 .34507 Mdot
.64286 .3438 Mdot
.66667 .33844 Mdot
.69048 .32908 Mdot
.71429 .31669 Mdot
.7381 .30312 Mdot
.7619 .29054 Mdot
.78571 .28078 Mdot
.80952 .27488 Mdot
.83333 .273 Mdot
.85714 .27476 Mdot
.88095 .27944 Mdot
.90476 .28628 Mdot
.92857 .29456 Mdot
.95238 .30365 Mdot
.97619 .31303 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`1Jooooo`;o00001Oooool2o`0000Gooooo0_l00021ooooo`;o00001Oooool2
o`0000Gooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o00001Oooool2o`00
00Gooooo0_l00021ooooo`;o00001Oooool2o`0000Gooooo0_l0000jooooo`00<?ooool2o`0005Co
oooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0000cooooo`00<?ooool00ol0003ooooo
ooooo`1Cooooo`;o00006oooool2o`00077ooooo0_l0000Kooooo`;o0000<oooool0033ooooo00?o
0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1<
ooooo`;o0000:Oooool2o`0006?ooooo0_l0000Yooooo`;o0000;?ooool0033ooooo0_l0001=oooo
o`;o0000<?ooool2o`0005cooooo0_l0000aooooo`;o00009?ooool0033ooooo00?o0000oooooooo
ool0O_ooool2o`0008oooooo0_l0000Tooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Cooooo0_l0000oooooo`;o0000C_ooool2o`0003oooooo0_l0000Mooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo0_l0000oooooo`;o0000C_ooool2
o`0003oooooo0_l0000Mooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000oooooolfoooo
o`00:?ooool00ol0003oooooooooo`04ooooo`;o0000Soooool2o`0008kooooo0_l0000Fooooo`00
:?ooool00ol0003oooooooooo`04ooooo`;o0000?oooool2o`0004kooooo0_l0000oooooo`;o0000
COooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Ooo
ool2o`0008oooooo0_l0001Uooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l00004ooooo`;o0000Soooool2o`00
09oooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0000Yooooo`;o0000Hoooool2o`0002Wo
oooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000:Oooool2o`0006?ooooo
0_l0000Yooooo`;o0000KOooool0033ooooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0
002Aooooo`00<?ooool2o`0001?ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0001d
ooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o00003?ooool2o`0000Kooooo0_l0001hoooo
o`;o00003Oooool2o`0000Gooooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o
00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001_ooool2o`0000Gooooo0_l0001kooooo`00
<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01?l@413o0000odA4A?o<c<`4ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0R_ooool00:Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00onHV9So410@omgMg@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40R_ooool00:Co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03ohN7QomEEEGooooo00;o
oooo00Go0000ooooooooooooooooo`00002:ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko
00003?ooool00ol0003oooooooooo`0:ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01Olb
<S;oV9RHoooooonHV9So<S8b08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02_ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Goc<c<o`000?l0003o0000olc<
c02:ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go410@okZj^_oooooo^[Zjoa0@402:ooooo`00Y?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go8B4QoiRHV?ooooooMgMg
oeEEE@03ooooo`05o`000?nj^[[ooooookZj^_l00000R_ooool00:Cooooo00?o0000ooooooooool0
6oooool00omEEEGoIVIVo`00000<ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01OnYZJWo
410@o`000?l@413oZJVY08[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.04) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30768 Mdot
.04762 .31637 Mdot
.07143 .32466 Mdot
.09524 .33202 Mdot
.11905 .33788 Mdot
.14286 .34155 Mdot
.16667 .3423 Mdot
.19048 .3395 Mdot
.21429 .3329 Mdot
.2381 .32293 Mdot
.2619 .31085 Mdot
.28571 .29852 Mdot
.30952 .28785 Mdot
.33333 .28024 Mdot
.35714 .2763 Mdot
.38095 .27598 Mdot
.40476 .27878 Mdot
.42857 .28401 Mdot
.45238 .29098 Mdot
.47619 .29905 Mdot
.5 .30768 Mdot
.52381 .31637 Mdot
.54762 .32466 Mdot
.57143 .33202 Mdot
.59524 .33788 Mdot
.61905 .34155 Mdot
.64286 .3423 Mdot
.66667 .3395 Mdot
.69048 .3329 Mdot
.71429 .32293 Mdot
.7381 .31085 Mdot
.7619 .29852 Mdot
.78571 .28785 Mdot
.80952 .28024 Mdot
.83333 .2763 Mdot
.85714 .27598 Mdot
.88095 .27878 Mdot
.90476 .28401 Mdot
.92857 .29098 Mdot
.95238 .29905 Mdot
.97619 .30768 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo067ooooo0_l00005oooo
o`;o00001_ooool2o`00083ooooo0_l00005ooooo`;o00001Oooool2o`0003?ooooo000`ooooo`;o
0000Foooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0007Wooooo0_l00005ooooo`;o
00001Oooool2o`0000Gooooo0_l0000cooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o0000
6oooool2o`0007;ooooo0_l0000Jooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0Dooo
ool2o`0002;ooooo0_l0001Zooooo`;o00008_ooool2o`0002cooooo000`ooooo`03o`000?oooooo
oooo05?ooooo0_l0000Yooooo`;o0000Hoooool2o`0002[ooooo0_l0000Tooooo`00<?ooool2o`00
07oooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008ko
oooo0_l0001Gooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
C?ooool2o`0003Oooooo0_l0001Eooooo`;o0000>?ooool2o`0001gooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00:?ooool0
0ol0003oooooooooo`04ooooo`;o0000Soooool2o`0008kooooo0_l0000Fooooo`00:?ooool00ol0
003oooooooooo`04ooooo`Co0000A?ooool2o`0004Oooooo0_l00016ooooo`;o0000A_ooool2o`00
01Kooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool2o`0008oo
oooo0_l0001Nooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
0_l0002?ooooo`;o0000Woooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`;o0000Soooool2o`0009oooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000
ooooooooool02oooool2o`00033ooooo0_l0001Looooo`;o0000<Oooool2o`0006Gooooo000`oooo
o`;o00003?ooool2o`00033ooooo0_l0001Looooo`;o0000<Oooool2o`0006Gooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool04_ooool2o`0002;ooooo
0_l0001Zooooo`;o00008_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0
0005ooooo`;o00006oooool2o`0006[ooooo0_l00005ooooo`;o00006oooool2o`0006gooooo000`
ooooo`;o00006_ooool2o`0000Gooooo0_l0000=ooooo`;o0000N?ooool2o`0000Kooooo0_l0000<
ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l00006oooo
o`;o0000P?ooool2o`0000Gooooo0_l00005ooooo`;o0000M?ooool0033ooooo00?o0000oooooooo
ool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`28ooooo`00Y?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
08Wooooo002Tooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03?ooool01Ol@413o
oooooooooooooooo410@00?ooooo1Ol0002:ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko
00002oooool00onHV9So8B4Qonk^kP0;ooooo`05o`000?ooooooooooooooool000000oooool01?m4
A4CogMgMooooool0002;ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo
00[ooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`0008_ooooo002R
ooooo`03oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`09ooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00omgMgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0J
ooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00?ok^k^odA4A?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo08[o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30287 Mdot
.04762 .31097 Mdot
.07143 .31897 Mdot
.09524 .32641 Mdot
.11905 .33277 Mdot
.14286 .33746 Mdot
.16667 .33981 Mdot
.19048 .33917 Mdot
.21429 .3351 Mdot
.2381 .32763 Mdot
.2619 .31748 Mdot
.28571 .30607 Mdot
.30952 .29517 Mdot
.33333 .28635 Mdot
.35714 .28063 Mdot
.38095 .27831 Mdot
.40476 .27918 Mdot
.42857 .28269 Mdot
.45238 .28821 Mdot
.47619 .29512 Mdot
.5 .30287 Mdot
.52381 .31097 Mdot
.54762 .31897 Mdot
.57143 .32641 Mdot
.59524 .33277 Mdot
.61905 .33746 Mdot
.64286 .33981 Mdot
.66667 .33917 Mdot
.69048 .3351 Mdot
.71429 .32763 Mdot
.7381 .31748 Mdot
.7619 .30607 Mdot
.78571 .29517 Mdot
.80952 .28635 Mdot
.83333 .28063 Mdot
.85714 .27831 Mdot
.88095 .27918 Mdot
.90476 .28269 Mdot
.92857 .28821 Mdot
.95238 .29512 Mdot
.97619 .30287 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?oooo
o`;o0000>_ooool0033ooooo0_l0001Rooooo`;o00001Oooool2o`0000Kooooo0_l00020ooooo`;o
00001Oooool2o`0000Gooooo0_l0000cooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000
3Oooool2o`0000Gooooo0_l0001iooooo`;o00003?ooool2o`0000Gooooo0_l0000/ooooo`00<?oo
ool00ol0003oooooooooo`1Jooooo`;o00006oooool2o`0000Gooooo0_l0001[ooooo`;o00006_oo
ool2o`0000Kooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o00008_ooool2
o`0006_ooooo0_l0000Rooooo`;o00009?ooool0033ooooo0_l0001Dooooo`;o0000<?ooool2o`00
05cooooo0_l0000aooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0Doooool2o`00033o
oooo0_l0001Looooo`;o0000<Oooool2o`0001gooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Cooooo0_l0
002?ooooo`;o0000S_ooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo00Cooooo0_l0001>
ooooo`;o0000?oooool2o`0004gooooo0_l0000oooooo`;o00005_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0000?ooooo0_l00017ooooo`;o0000A_ooool2o`0004Kooooo0_l0001Goooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o
0000Woooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`;o0000
Soooool2o`0005kooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool2o`0003Oooooo0_l0001Eooooo`;o0000>?ooool2o`0005kooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool2o`00
01?ooooo0_l0000Yooooo`;o0000Hoooool2o`0002[ooooo0_l0001Uooooo`00<?ooool00ol0003o
ooooooooo`0Booooo`;o0000:Oooool2o`0006?ooooo0_l0000Zooooo`;o0000IOooool0033ooooo
00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003ooooooooo
o`0Iooooo`;o00001Oooool2o`0001Cooooo0_l0001aooooo`;o00001_ooool2o`0001?ooooo0_l0
001]ooooo`00<?ooool2o`00027ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0001i
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000KOooool0033ooooo00?o0000oooo
ooooool09oooool2o`0000Kooooo0_l00027ooooo`;o00001Oooool2o`0007Cooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Sooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool2ob4Q8@Gooooo1?l0
00000ol@413oooooooooo`2;ooooo`00Z?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
SOooool00:Sooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP0?ooooo`03o`000?oo
oooooooo08gooooo002Xooooo`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00kooooo00?o0000ooooooooool0SOooool00:Sooooo00?o0000ooooooooool07Oooool00omg
MgOoIVIVooooo`0=ooooo`03o`000?oooooooooo08gooooo002Vooooo`03oa0@4?l0003o000000?o
00007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08gooooo002Xooooo`03o`00
0?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo08go
oooo002Xooooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03
oeEEEOmVIVKo000008oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.16) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29867 Mdot
.04762 .30605 Mdot
.07143 .31363 Mdot
.09524 .32097 Mdot
.11905 .32761 Mdot
.14286 .33302 Mdot
.16667 .33661 Mdot
.19048 .33774 Mdot
.21429 .33589 Mdot
.2381 .33081 Mdot
.2619 .32281 Mdot
.28571 .31282 Mdot
.30952 .30231 Mdot
.33333 .29287 Mdot
.35714 .28575 Mdot
.38095 .28163 Mdot
.40476 .28059 Mdot
.42857 .28232 Mdot
.45238 .28629 Mdot
.47619 .29192 Mdot
.5 .29867 Mdot
.52381 .30605 Mdot
.54762 .31363 Mdot
.57143 .32097 Mdot
.59524 .32761 Mdot
.61905 .33302 Mdot
.64286 .33661 Mdot
.66667 .33774 Mdot
.69048 .33589 Mdot
.71429 .33081 Mdot
.7381 .32281 Mdot
.7619 .31282 Mdot
.78571 .30231 Mdot
.80952 .29287 Mdot
.83333 .28575 Mdot
.85714 .28163 Mdot
.88095 .28059 Mdot
.90476 .28232 Mdot
.92857 .28629 Mdot
.95238 .29192 Mdot
.97619 .29867 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0001Yooooo`;o00001_ooool2o`0008Oooooo0_l00005ooooo`;o0000<oooool0033ooooo
00?o0000ooooooooool0J?ooool2o`0000Kooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo
0_l00005ooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0HOooool2o`0001Cooooo0_l0
0005ooooo`;o0000L_ooool2o`0001?ooooo0_l00006ooooo`;o00009?ooool0033ooooo00?o0000
ooooooooool0HOooool2o`0001_ooooo0_l00005ooooo`;o0000Joooool2o`0001_ooooo0_l00005
ooooo`;o00007Oooool0033ooooo0_l0001Kooooo`;o0000:Oooool2o`0006Cooooo0_l0000Yoooo
o`;o00007Oooool002oooooo0_l0001Looooo`;o0000<Oooool2o`0005cooooo0_l0000`ooooo`;o
00005_ooool002Kooooo1?l000000ol@413oooooooooo`02ooooo`;o0000Soooool2o`0008kooooo
0_l0000Fooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05?ooooo0_l0
002>ooooo`;o0000D?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`;o0000C_ooool2o`0003oooooo0_l0001=ooooo`;o0000D?ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0000?ooooo0_l0002?ooooo`;o0000Woooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`;o0000?oooool2o`0004gooooo0_l0000oooooo`;o
0000Eoooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`;o0000
?oooool2o`0004gooooo0_l0000oooooo`;o0000Eoooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool04_ooool2o`00033ooooo0_l0001Looooo`;o0000<Oooool2
o`0005kooooo000`ooooo`;o00006_ooool2o`0002Wooooo0_l0001Sooooo`;o0000:_ooool2o`00
05kooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0000Rooooo`;o0000J_ooool2o`0002?o
oooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o00006oooool2o`0007;ooooo
0_l0000Kooooo`;o0000IOooool0033ooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0007Wooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
001]ooooo`00<?ooool2o`0002Sooooo0_l00006ooooo`;o00001Oooool2o`00083ooooo0_l00005
ooooo`;o00001Oooool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oa0@4?o<c<b:ooooo`00Y?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q08[ooooo002T
ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000R_ooool00:Cooooo00?o0000ooooooooool02oooool6
o`0000_ooooo00?oV9RHob4Q8Oo^k^h03_ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9So
oooooiRHV?lQ8B40R_ooool00:Cooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`0=
ooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02:ooooo`00X_ooool0
0ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`03oeEEEOn7QhOooooo08cooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go0000okZj
^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0S?ooool0
0:Cooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEE
ofIVI_l000001Oooool01?o<c<coA4A4o`000?l@412:ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29513 Mdot
.04762 .30169 Mdot
.07143 .30872 Mdot
.09524 .31582 Mdot
.11905 .32255 Mdot
.14286 .32844 Mdot
.16667 .33295 Mdot
.19048 .3355 Mdot
.21429 .33552 Mdot
.2381 .33261 Mdot
.2619 .32677 Mdot
.28571 .31851 Mdot
.30952 .30893 Mdot
.33333 .29944 Mdot
.35714 .2914 Mdot
.38095 .28577 Mdot
.40476 .28295 Mdot
.42857 .2829 Mdot
.45238 .28524 Mdot
.47619 .28949 Mdot
.5 .29513 Mdot
.52381 .30169 Mdot
.54762 .30872 Mdot
.57143 .31582 Mdot
.59524 .32255 Mdot
.61905 .32844 Mdot
.64286 .33295 Mdot
.66667 .3355 Mdot
.69048 .33552 Mdot
.71429 .33261 Mdot
.7381 .32677 Mdot
.7619 .31851 Mdot
.78571 .30893 Mdot
.80952 .29944 Mdot
.83333 .2914 Mdot
.85714 .28577 Mdot
.88095 .28295 Mdot
.90476 .2829 Mdot
.92857 .28524 Mdot
.95238 .28949 Mdot
.97619 .29513 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo073ooooo0_l00005ooooo`;o0000
1Oooool2o`00083ooooo0_l00005ooooo`;o00001_ooool2o`0002Cooooo000`ooooo`03o`000?oo
oooooooo06Sooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0HOooool2
o`0000Gooooo0_l0000Kooooo`;o0000Joooool2o`0000Gooooo0_l0000Kooooo`;o00007Oooool0
02oooooo0ol0001Rooooo`;o00008_ooool2o`0000Kooooo0_l0001Sooooo`;o00008_ooool2o`00
00Gooooo0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Eooooo`;o0000
>?ooool2o`0005Gooooo0_l00018ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0_l0001Eooooo`;o0000>?ooool2o`0005Gooooo0_l00018ooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0000_ooooo0_l00016ooooo`;o0000A_ooool2o`0004Kooooo0_l0001@oooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l00016ooooo`;o
0000A_ooool2o`0004Kooooo0_l0001@ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Booooo`;o0000>?ooool2o`0005Cooooo0_l0000hooooo`;o0000Eooo
ool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Iooooo`;o0000<Oooool2
o`0005_ooooo0_l0000aooooo`;o0000Eoooool0033ooooo0_l0000Jooooo`;o0000:Oooool2o`00
06?ooooo0_l0000Zooooo`;o0000G_ooool0033ooooo00?o0000ooooooooool08?ooool2o`0002;o
oooo0_l0001[ooooo`;o00008_ooool2o`0005kooooo000`ooooo`03o`000?oooooooooo023ooooo
0_l00005ooooo`;o00005?ooool2o`0007;ooooo0_l00005ooooo`;o00005?ooool2o`0006Gooooo
000`ooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
001iooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000IOooool0033ooooo0_l0000`
ooooo`;o00001Oooool2o`0008Oooooo0_l00005ooooo`;o0000KOooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o
0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool5o`0000Gooooo0_lQ8B44ooooo`Go00000oooool5o`0008[ooooo002Tooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02:oooo
o`00Y?ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00gooooo00?oV9RHob4Q8Oo^
k^h01Oooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko0000
2oooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0
R_ooool00:Cooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomV
IVKooooo00Gooooo00?oMgMgofIVI_ooool0ROooool00:;ooooo00?o410@o`000?l000000ol0000M
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`28
ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@402:ooooo`00Y?oo
ool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.28) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29232 Mdot
.04762 .29794 Mdot
.07143 .30432 Mdot
.09524 .31104 Mdot
.11905 .3177 Mdot
.14286 .32385 Mdot
.16667 .32902 Mdot
.19048 .33266 Mdot
.21429 .33422 Mdot
.2381 .33321 Mdot
.2619 .32941 Mdot
.28571 .32301 Mdot
.30952 .31473 Mdot
.33333 .3057 Mdot
.35714 .29725 Mdot
.38095 .29049 Mdot
.40476 .28613 Mdot
.42857 .28438 Mdot
.45238 .28508 Mdot
.47619 .28788 Mdot
.5 .29232 Mdot
.52381 .29794 Mdot
.54762 .30432 Mdot
.57143 .31104 Mdot
.59524 .3177 Mdot
.61905 .32385 Mdot
.64286 .32902 Mdot
.66667 .33266 Mdot
.69048 .33422 Mdot
.71429 .33321 Mdot
.7381 .32941 Mdot
.7619 .32301 Mdot
.78571 .31473 Mdot
.80952 .3057 Mdot
.83333 .29725 Mdot
.85714 .29049 Mdot
.88095 .28613 Mdot
.90476 .28438 Mdot
.92857 .28508 Mdot
.95238 .28788 Mdot
.97619 .29232 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo07Oooooo0_l00005ooooo`;o0000
Qoooool2o`0000Kooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o0000NOooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0001gooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l00006ooooo`;o00004oooool2
o`0007;ooooo0_l00005ooooo`;o00005?ooool2o`0001gooooo000_ooooo`?o0000JOooool2o`00
02?ooooo0_l0001Zooooo`;o00008_ooool2o`0001Kooooo000_ooooo`;o00001Oooool2o`0005co
oooo0_l0000Zooooo`;o00001Oooool2o`0005cooooo0_l0000Yooooo`;o00005_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Looooo`;o0000
<Oooool2o`0005cooooo0_l00011ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`;o0000COooool2o`0003oooooo0_l0001>ooooo`;o0000B?ooool0
02Sooooo00?o0000ooooooooool01Oooool3o`0001;ooooo0_l00016ooooo`;o0000A_ooool2o`00
04Oooooo0_l00018ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;o
oooo0_l0000oooooo`;o0000COooool2o`0003oooooo0_l0001@ooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Wooooo0_l0000hooooo`;o0000E?ooool2o`0003Sooooo
0_l0001@ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo0_l0
002>ooooo`;o0000R_ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0P
ooooo`;o0000:_ooool2o`0006?ooooo0_l0000Yooooo`;o0000Eoooool0033ooooo0_l0000Qoooo
o`;o0000:_ooool2o`0006?ooooo0_l0000Yooooo`;o0000Eoooool0033ooooo00?o0000oooooooo
ool09oooool2o`0001_ooooo0_l0001booooo`;o00006oooool2o`0005kooooo000`ooooo`03o`00
0?oooooooooo02Oooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000
L_ooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0001Nooooo`00<?oo
ool00ol0003oooooooooo`0_ooooo`;o00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001Ooo
ool2o`0000Kooooo0_l0001Uooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o
0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool5o`0000Gooooo0_lQ8B44ooooo`Go00000oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08[ooooo
002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^
00gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000008[ooooo002Toooo
o`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Olb<S;oV9RHoooooonHV9So<S8b08[ooooo002Tooooo`03o`000?oooooooooo
01gooooo00?oMgMgofIVI_ooool03Oooool00omgMgOoIVIVooooo`02ooooo`05olc<c?l0003o0000
o`000?o<c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooooooo
00gooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@4100R_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05o`000?nj^[[ooooookZj^_l00000R_ooool00:Cooooo00?o0000oooooooo
ool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.34) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29026 Mdot
.04762 .29486 Mdot
.07143 .30047 Mdot
.09524 .3067 Mdot
.11905 .31314 Mdot
.14286 .31939 Mdot
.16667 .32499 Mdot
.19048 .32944 Mdot
.21429 .33221 Mdot
.2381 .3328 Mdot
.2619 .33085 Mdot
.28571 .3263 Mdot
.30952 .31952 Mdot
.33333 .31138 Mdot
.35714 .303 Mdot
.38095 .29555 Mdot
.40476 .28995 Mdot
.42857 .28666 Mdot
.45238 .28578 Mdot
.47619 .2871 Mdot
.5 .29026 Mdot
.52381 .29486 Mdot
.54762 .30047 Mdot
.57143 .3067 Mdot
.59524 .31314 Mdot
.61905 .31939 Mdot
.64286 .32499 Mdot
.66667 .32944 Mdot
.69048 .33221 Mdot
.71429 .3328 Mdot
.7381 .33085 Mdot
.7619 .3263 Mdot
.78571 .31952 Mdot
.80952 .31138 Mdot
.83333 .303 Mdot
.85714 .29555 Mdot
.88095 .28995 Mdot
.90476 .28666 Mdot
.92857 .28578 Mdot
.95238 .2871 Mdot
.97619 .29026 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0Moooool2o`0000Gooooo0_l00005ooooo`;o0000P?ooool2o`0000Kooooo0_l0
0005ooooo`;o00007Oooool002oooooo0_l0001booooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`00077ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o00005_ooool002oooooo0ol00004ooooo`;o0000Joooool2o`0001_ooooo0_l00005oooo
o`;o0000J_ooool2o`0001_ooooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o
0000Hoooool2o`0002[ooooo0_l0001Sooooo`;o0000>_ooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0001Kooooo`;o0000<Oooool2o`0005cooooo
0_l0000jooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l0
001Dooooo`;o0000>?ooool2o`0005Gooooo0_l00011ooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo0_l0001=ooooo`;o0000?oooool2o`0004kooooo0_l00011
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o00004_ooool2o`0004Kooooo0_l00016oooo
o`;o0000Aoooool2o`0004Sooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool2o`0003oooooo0_l0001=ooooo`;o0000@?ooool2o`0004Sooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo0_l0000aooooo`;o0000G?oo
ool2o`00033ooooo0_l0001@ooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo023ooooo0_l00005ooooo`;o0000:_ooool2o`0005cooooo0_l00005ooooo`;o0000:Oooool2
o`00053ooooo000`ooooo`;o0000:?ooool2o`0002?ooooo0_l0001Zooooo`;o00008_ooool2o`00
05Oooooo000`ooooo`03o`000?oooooooooo02oooooo0_l0000Cooooo`;o00001_ooool2o`00077o
oooo0_l0000Dooooo`;o00001Oooool2o`0005Oooooo000`ooooo`03o`000?oooooooooo02oooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o0000G_ooool0033ooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo0_l0
0027ooooo`;o00001_ooool2o`0006Gooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`Go00001Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o0000
00?o410@ooooooooool0R?ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
2Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMg
Molb<S801_ooool00ol0003oooooooooo`29ooooo`00Y?ooool00ol0003oooooooooo`0Kooooo`03
oiRHV?lQ8B7ok^k^013ooooo00Co0000oooooooooooooooo1Ol0002:ooooo`00Y?ooool00ol0003o
ooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP0>ooooo`03ojVYZOl@413ooooo00;o
oooo00CoA4A4omgMgOoooooo0000Roooool00:Cooooo00?o0000ooooooooool07Oooool00omgMgOo
IVIVooooo`0<ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000Roooool00:;o
oooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooooooo00cooooo00?o^[Zjob4Q8Ooo
ool00oooool00omgMgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41002oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?ok^k^odA4
A?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo08[ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .28899 Mdot
.04762 .29248 Mdot
.07143 .29724 Mdot
.09524 .30286 Mdot
.11905 .30897 Mdot
.14286 .31515 Mdot
.16667 .32098 Mdot
.19048 .326 Mdot
.21429 .3297 Mdot
.2381 .33159 Mdot
.2619 .33123 Mdot
.28571 .32841 Mdot
.30952 .32323 Mdot
.33333 .31625 Mdot
.35714 .30837 Mdot
.38095 .30068 Mdot
.40476 .2942 Mdot
.42857 .28962 Mdot
.45238 .28727 Mdot
.47619 .28713 Mdot
.5 .28899 Mdot
.52381 .29248 Mdot
.54762 .29724 Mdot
.57143 .30286 Mdot
.59524 .30897 Mdot
.61905 .31515 Mdot
.64286 .32098 Mdot
.66667 .326 Mdot
.69048 .3297 Mdot
.71429 .33159 Mdot
.7381 .33123 Mdot
.7619 .32841 Mdot
.78571 .32323 Mdot
.80952 .31625 Mdot
.83333 .30837 Mdot
.85714 .30068 Mdot
.88095 .2942 Mdot
.90476 .28962 Mdot
.92857 .28727 Mdot
.95238 .28713 Mdot
.97619 .28899 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0O_ooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`0001gooooo000_
ooooo`;o0000NOooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0007Sooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l0000Fooooo`00;oooool3o`0000Cooooo0_l0001[oooo
o`;o00001Oooool2o`0001Cooooo0_l00005ooooo`;o0000J_ooool2o`0000Gooooo0_l0000Doooo
o`;o00005_ooool0033ooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l0001Sooooo`;o
00008_ooool2o`0000Gooooo0_l0001Sooooo`;o0000<oooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0001Kooooo`;o0000<Oooool2o`0005cooooo
0_l0000jooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo0_l0
001Dooooo`;o0000>?ooool2o`0005Gooooo0_l0000jooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo0_l0001=ooooo`;o0000?oooool2o`0004kooooo0_l00011
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o00006Oooool2o`0004Kooooo0_l00016oooo
o`;o0000Aoooool2o`00047ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0008;ooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08?ooool2o`0003Sooooo0_l0001Eooooo`;o0000
>?ooool2o`0004Sooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09ooo
ool2o`00037ooooo0_l0001Looooo`;o0000<Oooool2o`0004Sooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool09oooool2o`0002[ooooo0_l0001Sooooo`;o0000:Oooool2
o`00053ooooo000`ooooo`;o0000<?ooool2o`0002;ooooo0_l0001Zooooo`;o00008_ooool2o`00
053ooooo000`ooooo`03o`000?oooooooooo02oooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o0000LOooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000N?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0005Oooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003o
ooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEEofIVI_l000003Oooool4
o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKo
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omE
EEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKo
oooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKo
oooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooolfooooo`009ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool00omgMgOoIVIVooooo`3o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Gooooo00Go0000okZj^_oo
ooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooolooooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo08cooooo002X
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q1oooool00ol0003oooooooooo`2=ooooo`00Z?ooool00ol0003ooooooooo
o`0Kooooo`03oiRHV?lQ8B7ok^k^00cooooo1Ol0002>ooooo`00Z?ooool00ol0003oooooooooo`0;
ooooo`Ko00002oooool00onHV9So8B4Qonk^kP0;ooooo`04odA4A?oMgMgoooooo`0008oooooo002X
ooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgoEEEEooooool0
002?ooooo`00Y_ooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool02_ooool0
0omgMgOoc<c<o`00002?ooooo`00Z?ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooo
oiRHV?l@41003?ooool00oo^k^koA4A4o`00002?ooooo`00Z?ooool00ol0003oooooooooo`0Joooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`03Oooool00omgMgOo0000ooooo`2>ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}]
}, Closed]]
}, Open  ]],

Cell["\<\
\tThe wave steepens, but also decays due to the finite diffusivity. \
 In order to see a shock wave form, it is necessary to drive the system with \
a source. The is done by reevaluating the previous cells, but now we take the \
following source:\
\>", "Text"],

Cell[BoxData[{
    \(\(S[j_, n_]\  := \ 0 /; \ j > 2;\)\), "\n", 
    \(\(S[0, n_]\  = \(S[1, n_]\  = \ \(S[2, n_]\  = \ 10\)\);\)\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 7.64"],

Cell["along with a zero initial condition.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f[j_, 0]\  := \ 0\ ;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Table[{j\ \[CapitalDelta]x, f[j, n]}, {j, 0, M}], 
          PlotRange \[Rule] {0, 5}, 
          PlotLabel -> "\<t = \>" <> ToString\ [n\ \[CapitalDelta]t]], {n, 0, 
          80, 2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.65"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 0 Mdot
.04762 0 Mdot
.07143 0 Mdot
.09524 0 Mdot
.11905 0 Mdot
.14286 0 Mdot
.16667 0 Mdot
.19048 0 Mdot
.21429 0 Mdot
.2381 0 Mdot
.2619 0 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 0 Mdot
.80952 0 Mdot
.83333 0 Mdot
.85714 0 Mdot
.88095 0 Mdot
.90476 0 Mdot
.92857 0 Mdot
.95238 0 Mdot
.97619 0 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Tooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`00027o
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooo
oom1ooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@
o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0
003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Rooooo`00Y?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0X_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@0:;ooooo002Tooooo`03o`000?oo
oooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool00000X_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol0003ooooooooooooooooo00000:;ooooo002Rooooo`03oa0@4?l0
003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@0:;ooooo002Tooooo`03o`000?oo
oooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Rooooo`00Y?ooool00ol0003ooooooooo
o`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0X_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .05946 Mdot
.04762 .06946 Mdot
.07143 .06379 Mdot
.09524 .01241 Mdot
.11905 .00242 Mdot
.14286 .00047 Mdot
.16667 9e-05 Mdot
.19048 2e-05 Mdot
.21429 0 Mdot
.2381 0 Mdot
.2619 0 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 0 Mdot
.80952 0 Mdot
.83333 0 Mdot
.85714 2e-05 Mdot
.88095 9e-05 Mdot
.90476 .00044 Mdot
.92857 .00225 Mdot
.95238 .01157 Mdot
.97619 .05946 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0000Zooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0fooooo`;o00003_ooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool0
0ol0003oooooooooo`0Booooo`;o0000ooooool3ooooo`;o0000:?ooool002Gooooo00?o0000oooo
ooooool04_ooool2o`000?oooooo;Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Ooo
ool002Cooooo0_l0000<ooooo`;o0000oooooolBooooo`;o00008Oooool002Gooooo00?o0000oooo
ooooool02_ooool2o`000?oooooo=Oooool002Gooooo00?o0000ooooooooool00oooool2o`000?oo
oooo??ooool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`0UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmEEEGoMgMgoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooo
oooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol0003ooooooooooooooooo000009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Joooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000oeEEEOl0003o410@olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001Wooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool00omEEEGo
QhN7ooooo`2Gooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P0Uoooool009Wo
oooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`04olc<c?m4A4Co0000oa0@49Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .09618 Mdot
.04762 .12555 Mdot
.07143 .11987 Mdot
.09524 .04371 Mdot
.11905 .01197 Mdot
.14286 .00297 Mdot
.16667 .0007 Mdot
.19048 .00016 Mdot
.21429 4e-05 Mdot
.2381 1e-05 Mdot
.2619 0 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 0 Mdot
.80952 1e-05 Mdot
.83333 3e-05 Mdot
.85714 .00013 Mdot
.88095 .00057 Mdot
.90476 .00235 Mdot
.92857 .00906 Mdot
.95238 .03167 Mdot
.97619 .09618 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool08?ooool2o`0002?ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02oooooo
0_l0000Eooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0
003cooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool06Oooool2o`000??ooooo0_l0000`
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000oooo
ooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0
003oooooobgooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool3o`000?oooooo7oooool2o`00
027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o
0000ooooooleooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
0_l0003oooooocGooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o0000oooo
oollooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0003o
oooooccooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`05o`0009Gooooo002I
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP2Fooooo`00VOooool00ol0003ooooo
ooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool01?ooool00onHV9So8B4Qonk^kP2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo09Co
oooo002Gooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Cooooo`00VOooool00ol0003ooooo
ooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`02ooooo`05
o`000?nj^[[ooooooiRHV?l@4100UOooool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o
c<c<09Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .12171 Mdot
.04762 .16552 Mdot
.07143 .17431 Mdot
.09524 .08655 Mdot
.11905 .03156 Mdot
.14286 .0097 Mdot
.16667 .00273 Mdot
.19048 .00073 Mdot
.21429 .00019 Mdot
.2381 5e-05 Mdot
.2619 1e-05 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 1e-05 Mdot
.80952 3e-05 Mdot
.83333 .00014 Mdot
.85714 .00052 Mdot
.88095 .00183 Mdot
.90476 .00605 Mdot
.92857 .01801 Mdot
.95238 .04783 Mdot
.97619 .12171 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0000Looooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0_ooooo`;o00005Oooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`0Pooooo`;o0000iOooool2o`0003Oooooo000U
ooooo`03o`000?oooooooooo023ooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo
01Wooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`;o0000oooooolHoooo
o`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgo
oooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01?ooool2o`000?oooooo8?ooool2o`00027ooooo
000Mooooo`03o`000?oooooooooo00Cooooo0ol0003ooooooaoooooo0_l0000Qooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo00?o
oooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
000;ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o0000oooooole
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000002?l@413ooooooooo
ooo<c<co8B4Qo`000?lQ8B7oc<c<UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009oooo
o`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0J
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000UOooool009Wooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0UOooool009Oo
oooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000oooo
ooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool0
1Ol0003o^[Zjoooooonj^[[o000009Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@2Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .13887 Mdot
.04762 .19224 Mdot
.07143 .22014 Mdot
.09524 .13936 Mdot
.11905 .06304 Mdot
.14286 .02301 Mdot
.16667 .00747 Mdot
.19048 .00226 Mdot
.21429 .00065 Mdot
.2381 .00018 Mdot
.2619 5e-05 Mdot
.28571 1e-05 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 1e-05 Mdot
.78571 3e-05 Mdot
.80952 .00012 Mdot
.83333 .0004 Mdot
.85714 .0013 Mdot
.88095 .0039 Mdot
.90476 .01065 Mdot
.92857 .02627 Mdot
.95238 .05999 Mdot
.97619 .13887 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`0001Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo
0_l0000Looooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0
003Nooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo023ooooo0_l0003ooooooaoooooo000Uooooo`;o00008Ooo
ool2o`000>cooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool0
0ol0003oooooooooo`0Iooooo`;o0000noooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo
01Wooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000006ooooo`;o0000
5?ooool2o`000?oooooo2_ooool2o`00027ooooo000Tooooo`;o00005?ooool2o`000?oooooo2_oo
ool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0003oooooocGooooo
000Uooooo`;o00002oooool2o`000?oooooo=Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2
ooooo`007?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00VOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Gooooo0_l000000ol@413oooooooooo`2Cooooo`00VOooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo09Cooooo002Iooooo`03o`00
0?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo1Ol0002Eooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0002Foooo
o`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`02ooooo`04omgMgOmEEEGoooooo`0009Kooooo002Gooooo`03oa0@4?l0003o0000
00?o00006Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0omgMgOoc<c<o`00002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000U_oo
ool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1503 Mdot
.04762 .20893 Mdot
.07143 .25165 Mdot
.09524 .1945 Mdot
.11905 .10839 Mdot
.14286 .04607 Mdot
.16667 .0168 Mdot
.19048 .00562 Mdot
.21429 .00178 Mdot
.2381 .00054 Mdot
.2619 .00016 Mdot
.28571 4e-05 Mdot
.30952 1e-05 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 1e-05 Mdot
.7619 3e-05 Mdot
.78571 9e-05 Mdot
.80952 .0003 Mdot
.83333 .00089 Mdot
.85714 .0025 Mdot
.88095 .00646 Mdot
.90476 .01527 Mdot
.92857 .0332 Mdot
.95238 .0689 Mdot
.97619 .1503 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0^ooooo`;o00005Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08Oooool2o`0000Gooooo
0_l0000Looooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo02kooooo0_l0
003@ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool0
02Gooooo00?o0000ooooooooool09oooool2o`000=kooooo0_l0000gooooo`009Oooool00ol0003o
ooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`0Pooooo`;o0000oooooolO
ooooo`009Oooool2o`00027ooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`0Iooooo`;o0000oooooolVooooo`009Oooool00ol0003oooooooooo`0Iooooo`;o0000oooooolV
ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7o
oooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Cooooo0ol0003ooooooaoooooo0_l0000Qooooo`009?ooool2o`000?oooooo8?ooool2o`00027o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool04_ooool2o`000?oooooo;Oooool0
02Gooooo0_l0000Cooooo`;o0000ooooool]ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool00ooo
ool2o`000?oooooo??ooool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`0:ooooo`;o0000ooooooleooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo00[ooooo0_l0003oooooocGooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@
o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0
003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00WOooool01OnHV9So0000o`000?m4A4Co
^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`00
0?lb<S;oc<c<09Wooooo002Mooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b
09Wooooo002Mooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo09Oooooo002Mooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`2Hooooo`00WOooool00ol0003o
ooooooooo`0Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P2Ioooo
o`00Voooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400>oooo
o`03okZj^_lQ8B7ooooo09Sooooo002Mooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000VOooool009gooooo00?o0000oooo
ooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@2Iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15796 Mdot
.04762 .21923 Mdot
.07143 .26924 Mdot
.09524 .23941 Mdot
.11905 .16481 Mdot
.14286 .08277 Mdot
.16667 .03367 Mdot
.19048 .01226 Mdot
.21429 .00419 Mdot
.2381 .00137 Mdot
.2619 .00043 Mdot
.28571 .00013 Mdot
.30952 4e-05 Mdot
.33333 1e-05 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 1e-05 Mdot
.7381 2e-05 Mdot
.7619 7e-05 Mdot
.78571 .00021 Mdot
.80952 .0006 Mdot
.83333 .0016 Mdot
.85714 .004 Mdot
.88095 .00918 Mdot
.90476 .0195 Mdot
.92857 .03882 Mdot
.95238 .07543 Mdot
.97619 .15796 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0fooooo`;o00003Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08Oooool2o`0002?ooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_oo
ool002Gooooo00?o0000ooooooooool0;_ooool2o`000=3ooooo0_l0000nooooo`009Oooool00ol0
003oooooooooo`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003oooooooooo`3oooooo`So
oooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o
0000oooooolHooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Ooo
ool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000
ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool08?ooool2o`00
0?oooooo7oooool002Gooooo00?o0000ooooooooool08?ooool2o`000?oooooo7oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2
o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0003ooooo
obKooooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobKooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool002Gooooo00?o0000ooooooooool0
0oooool2o`000?oooooo??ooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol0
0006ooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Jooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Booooo`;o0000ooooool]ooooo`006oooool0
0onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo0_l0003oooooocGooooo000Uooooo`;o00002oooool2o`000?oooooo=Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000
oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q
8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj
^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001co
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_oo
ool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000K
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000
odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l@413oc<c<09Gooooo002Iooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoEEEEogMgMoooooooV9RHob4Q
8@2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0Toooool009Wooooo00?o
0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P03ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`0UOooool009Oooooo00?o410@o`000?l000000ol0000Iooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`02ooooo`03oeEEEOn7QhOooooo
09Oooooo002Iooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRHV02Gooooo`00VOooool00ol0
003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16321 Mdot
.04762 .22575 Mdot
.07143 .27848 Mdot
.09524 .26598 Mdot
.11905 .22024 Mdot
.14286 .13483 Mdot
.16667 .06239 Mdot
.19048 .02459 Mdot
.21429 .00893 Mdot
.2381 .00309 Mdot
.2619 .00103 Mdot
.28571 .00033 Mdot
.30952 .0001 Mdot
.33333 3e-05 Mdot
.35714 1e-05 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 1e-05 Mdot
.71429 2e-05 Mdot
.7381 5e-05 Mdot
.7619 .00014 Mdot
.78571 .0004 Mdot
.80952 .00103 Mdot
.83333 .0025 Mdot
.85714 .00565 Mdot
.88095 .01184 Mdot
.90476 .02321 Mdot
.92857 .04332 Mdot
.95238 .08026 Mdot
.97619 .16321 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0mooooo`;o00001_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool2o`0000Kooooo
0_l0000Sooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo03Kooooo0_l0
0031ooooo`;o00001Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo03Kooooo0_l00038
ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo02kooooo0_l0003Gooooo`;o0000
=oooool002Gooooo0_l0000_ooooo`;o0000eoooool2o`0003Oooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0ooooool?
ooooo`;o0000<?ooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uoooo
o`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000oooo
ooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`;o
0000oooooolOooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo023ooooo
0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2o`00
0?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01Wooooo
0_l0003oooooobKooooo000Uooooo`;o00001?ooool2o`0001Cooooo0_l0003oooooobKooooo000U
ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003oooooooooo`3ooooood7ooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003ooooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000U
ooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003ooooo
ooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@
o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Ooo
ool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2
o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_o
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8boooo
o`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOoo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00VOooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000004oa0@4?ooooooooooooooo`Go0000UOooool009Wooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Eoooo
o`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
00Cooooo00?oV9RHob4Q8Oo^k^h0U_ooool009Wooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?oV9RH
ob4Q8Oo^k^h0UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001oooool00omgMgOoIVIVooooo`2Dooooo`00Uoooool0
0ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Sooooo00?o0000ooooooooool0Toooool009Wooooo00?o0000ooooooooool06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[Zjoooo
oonHV9So410@09Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Eooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16691 Mdot
.04762 .22998 Mdot
.07143 .28413 Mdot
.09524 .27808 Mdot
.11905 .25876 Mdot
.14286 .19525 Mdot
.16667 .10723 Mdot
.19048 .0466 Mdot
.21429 .01795 Mdot
.2381 .00651 Mdot
.2619 .00228 Mdot
.28571 .00077 Mdot
.30952 .00026 Mdot
.33333 8e-05 Mdot
.35714 3e-05 Mdot
.38095 1e-05 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 1e-05 Mdot
.71429 4e-05 Mdot
.7381 .0001 Mdot
.7619 .00026 Mdot
.78571 .00066 Mdot
.80952 .00158 Mdot
.83333 .00353 Mdot
.85714 .00735 Mdot
.88095 .01433 Mdot
.90476 .0264 Mdot
.92857 .04694 Mdot
.95238 .08389 Mdot
.97619 .16691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo03gooooo0_l00005ooooo`;o0000Aoooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo01Wooooo0_l00006ooooo`;o00008oooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`0mooooo`;o0000^_ooool2o`0004Gooooo000U
ooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo
03Kooooo0_l00038ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0=_ooool2o`000?oo
oooo2Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo2Ooo
ool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0;_ooool2o`000=kooooo0_l0000`ooooo`009Oooool2o`00
02oooooo0_l0003Nooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003o
ooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003ooooooooo
o`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o
0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo023ooooo0_l0003ooooooaoooooo000Uooooo`;o00008Oooool2o`00
0?oooooo7oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`03ooooo`;o0000oooooollooooo`009Oooool00ol0003oooooooooo`03ooooo`;o
0000oooooollooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_oo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003o
oooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolVooooo`006_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool06Oooool2o`000?oooooo
9_ooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`0Booooo`;o
0000ooooool]ooooo`009Oooool00ol0003oooooooooo`0Booooo`;o0000ooooool]ooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`0:
ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000Wo410@ooooooooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`0UOooool009Wo
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000?ooooo00Go0000ooooooooooooooooo`00002Eooooo`00VOooool00ol0003ooooooooo
o`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001?ooool01Olb<S;oV9RHoooooonHV9So<S8b09Gooooo002Iooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Goc<c<
o`000?l0003o0000olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001Wooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Cooooo00Go410@okZj^_oooooo^[Zj
oa0@402Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooookZj^_l00000UOooool009Wooooo
00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool00oooool01OnYZJWo410@o`000?l@413oZJVY09Gooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1696 Mdot
.04762 .23284 Mdot
.07143 .28789 Mdot
.09524 .28416 Mdot
.11905 .27674 Mdot
.14286 .24598 Mdot
.16667 .1669 Mdot
.19048 .08345 Mdot
.21429 .03458 Mdot
.2381 .0131 Mdot
.2619 .00474 Mdot
.28571 .00167 Mdot
.30952 .00057 Mdot
.33333 .00019 Mdot
.35714 6e-05 Mdot
.38095 2e-05 Mdot
.40476 1e-05 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 1e-05 Mdot
.69048 2e-05 Mdot
.71429 7e-05 Mdot
.7381 .00017 Mdot
.7619 .00043 Mdot
.78571 .00101 Mdot
.80952 .00223 Mdot
.83333 .00463 Mdot
.85714 .00903 Mdot
.88095 .0166 Mdot
.90476 .02914 Mdot
.92857 .04988 Mdot
.95238 .08669 Mdot
.97619 .1696 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Cooooo0_l00017ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0000[ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`0m
ooooo`;o0000^_ooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo03gooooo0_l00031oooo
o`;o0000?_ooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0ooooool8ooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0=_ooool2o`00
0<oooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`0fooooo`;o0000ooooool9ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo4?ooool2o`00
033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo02kooooo0_l0003ooooooa7ooooo000Uooooo`03o`000?oooooooooo02ko
oooo0_l0003Vooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000
:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o0000oooooolHooooo`009?ooool2o`0002Wo
oooo0_l0003dooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`03ooooo`;o0000oooooollooooo`009Oooool00ol0003ooooo
ooooo`03ooooo`;o0000oooooollooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool08?oo
ool2o`000?oooooo7oooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`00027ooooo0_l0003o
oooooaoooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool06Oooool2o`000?oooooo9_ooool002Gooooo
00?o0000ooooooooool06Oooool2o`000?oooooo9_ooool002Gooooo00?o0000ooooooooool04_oo
ool2o`000?oooooo;Oooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0003o
ooooobgooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0003oooooocGooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`000003oa0@4?oooooooooo09?ooooo
002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo09Co
oooo002Iooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Go0000UOooool009Wooooo00?o0000ooooooooool02oooool6o`0000Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`08ogMgMolb<S;ooooooooooom4A4CogMgMooooool0
002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo0000U_ooool009Oooooo
00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`05ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4A?l0
0000U_ooool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17162 Mdot
.04762 .2349 Mdot
.07143 .29033 Mdot
.09524 .28814 Mdot
.11905 .28397 Mdot
.14286 .27343 Mdot
.16667 .22697 Mdot
.19048 .13806 Mdot
.21429 .06389 Mdot
.2381 .02555 Mdot
.2619 .00956 Mdot
.28571 .00346 Mdot
.30952 .00122 Mdot
.33333 .00042 Mdot
.35714 .00014 Mdot
.38095 5e-05 Mdot
.40476 2e-05 Mdot
.42857 1e-05 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 1e-05 Mdot
.66667 2e-05 Mdot
.69048 4e-05 Mdot
.71429 .00011 Mdot
.7381 .00028 Mdot
.7619 .00065 Mdot
.78571 .00142 Mdot
.80952 .00295 Mdot
.83333 .00576 Mdot
.85714 .01063 Mdot
.88095 .01865 Mdot
.90476 .03149 Mdot
.92857 .05229 Mdot
.95238 .08889 Mdot
.97619 .17162 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`03ooooo`;o0000@?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01;ooooo
0_l00005ooooo`;o0000:oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`14ooooo`;o0000Zoooool2o`0000Kooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`14
ooooo`;o0000/oooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
ooooool1ooooo`;o0000?_ooool002Gooooo0_l0000nooooo`;o0000ooooool2ooooo`009Oooool0
0ol0003oooooooooo`0mooooo`;o0000b?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo
0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo
3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0=_ooool2o`000?oooooo2Oooool002Gooooo00?o0000ooooooooool0=_ooool2o`00
0?oooooo2Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Ooo
ool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003ooooooooo
o`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo
000Tooooo`?o0000oooooolOooooo`;o00008Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uoooo
o`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uooooo`03o`000?oooooooooo00?o
oooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0_l0003ooooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`00027ooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo023o
oooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool06Oooool2o`000?oooooo9_ooool002Gooooo00?o0000ooooooooool04_ooool2
o`0000Gooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006oooo
o`;o0000ooooool]ooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009gooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c02Iooooo`00WOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Ioooo
o`00WOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000009Wooooo002Mooooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q09Wooooo002M
ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`0VOooool009_ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`2Kooooo`00WOooool00ol0003ooooooooo
o`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV02Kooooo`00WOoo
ool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@412Iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17318 Mdot
.04762 .23645 Mdot
.07143 .29204 Mdot
.09524 .29069 Mdot
.11905 .2882 Mdot
.14286 .2835 Mdot
.16667 .26659 Mdot
.19048 .20249 Mdot
.21429 .11109 Mdot
.2381 .04835 Mdot
.2619 .01882 Mdot
.28571 .00697 Mdot
.30952 .00252 Mdot
.33333 .0009 Mdot
.35714 .00031 Mdot
.38095 .00011 Mdot
.40476 4e-05 Mdot
.42857 1e-05 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 1e-05 Mdot
.66667 3e-05 Mdot
.69048 8e-05 Mdot
.71429 .00018 Mdot
.7381 .00042 Mdot
.7619 .00091 Mdot
.78571 .00189 Mdot
.80952 .0037 Mdot
.83333 .00687 Mdot
.85714 .01213 Mdot
.88095 .02048 Mdot
.90476 .03352 Mdot
.92857 .05428 Mdot
.95238 .09064 Mdot
.97619 .17318 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00?ooooo
0_l00006ooooo`;o0000>?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01;ooooo
0_l00005ooooo`;o0000:oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1;ooooo`;o0000Y?ooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015
ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000oooooooo
ool0A?ooool2o`000;[ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000
^_ooool2o`0003kooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000?_ooool2o`000?oooooo0_ooool002Gooooo00?o0000oooooooo
ool0?Oooool2o`000<oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo
0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo5ooo
ool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo03Kooooo0_l0003oooooo`Wooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`0fooooo`;o0000ooooool9ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Cooooo0ol0003ooooooaoooooo0_l0
000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0;_ooool2o`000?oooooo4Oooool002Gooooo00?o0000ooooooooool0;_ooool2o`000?oooooo
4Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`03ooooo`;o0000oooooollooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool00ooo
ool2o`000?oooooo??ooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool0
01cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool09ooo
ool2o`000?oooooo6?ooool002Gooooo00?o0000ooooooooool09oooool2o`000?oooooo6?ooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`0Pooooo`;o0000oooo
oolOooooo`009Oooool00ol0003oooooooooo`0Iooooo`;o00001Oooool2o`000?oooooo7oooool0
02Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o0000oooooolVoooo
o`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`000?oooooo;Oooool002Gooooo
0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7o
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Ooo
ool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06
ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_oo
ool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000J
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo
000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
0oooool01Oo^k^ko<S8bo`000?l@413oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Eooooo`00VOooool0
0ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00002Eooooo`00VOooool00ol0003ooooo
ooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@03ooooo`05o`000?nHV9SooooooiRHV?lQ8B40UOooool009Wooooo00?o0000oooo
ooooool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0UOooool009Oooooo00?o410@o`000?l000000ol0
000Iooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`05ooooo`03oeEE
EOn7QhOooooo09Oooooo002Iooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Gooooo00?ogMgMoa0@4?nHV9P0Uoooool009Wooooo00?o
0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1?ooool01?o<c<coA4A4o`000?l@412Eooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17442 Mdot
.04762 .23764 Mdot
.07143 .29336 Mdot
.09524 .29234 Mdot
.11905 .29097 Mdot
.14286 .28806 Mdot
.16667 .28238 Mdot
.19048 .25462 Mdot
.21429 .17458 Mdot
.2381 .08743 Mdot
.2619 .03628 Mdot
.28571 .01384 Mdot
.30952 .00509 Mdot
.33333 .00184 Mdot
.35714 .00065 Mdot
.38095 .00023 Mdot
.40476 8e-05 Mdot
.42857 3e-05 Mdot
.45238 1e-05 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 1e-05 Mdot
.64286 2e-05 Mdot
.66667 5e-05 Mdot
.69048 .00012 Mdot
.71429 .00027 Mdot
.7381 .00059 Mdot
.7619 .00122 Mdot
.78571 .00239 Mdot
.80952 .00448 Mdot
.83333 .00796 Mdot
.85714 .01353 Mdot
.88095 .02212 Mdot
.90476 .03526 Mdot
.92857 .05596 Mdot
.95238 .09208 Mdot
.97619 .17442 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo
0_l0000hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool2o`0000Gooooo
0_l00005ooooo`;o0000:oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`3aooooo`;o0000COooool002Gooooo00?o0000ooooooooool0Boooool2o`000:cooooo0_l00015
ooooo`009Oooool00ol0003oooooooooo`1;ooooo`;o0000[?ooool2o`0004Gooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000
?_ooool002Gooooo0_l0003oooooo`;ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0A?ooool2o`000<7ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000
`Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Ooo
ool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo
00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0oooo
oolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`?o0000=oooool2o`000>Gooooo0_l0
000Qooooo`009?ooool2o`0003Sooooo0_l0003Uooooo`;o00008Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`03ooooo`;o0000
oooooollooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0;_ooool2o`000?oooooo4Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0^ooooo`;o0000oooooolAooooo`006_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool0
0ol0003oooooooooo`0Pooooo`;o00001Oooool2o`000?oooooo6?ooool002Gooooo00?o0000oooo
ooooool06Oooool2o`0000Gooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo00[o
oooo0_l00006ooooo`;o00001Oooool2o`000?oooooo9_ooool002Gooooo0_l0000;ooooo`;o0000
1_ooool2o`000?oooooo;Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool00ooo
ool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool01?ooool00onHV9So8B4Qonk^kP2Fooooo`00
VOooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01?ooool00onHV9So8B4Qonk^kP2Eooooo`00VOooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`05ooooo`03
ogMgMomVIVKooooo09Cooooo002Gooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool01_ooool00ol0003oooooooooo`2Cooooo`00
VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00?ooooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0
003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c02Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17543 Mdot
.04762 .23859 Mdot
.07143 .29438 Mdot
.09524 .2936 Mdot
.11905 .29264 Mdot
.14286 .29112 Mdot
.16667 .28776 Mdot
.19048 .27969 Mdot
.21429 .23666 Mdot
.2381 .14581 Mdot
.2619 .06765 Mdot
.28571 .02706 Mdot
.30952 .01017 Mdot
.33333 .00372 Mdot
.35714 .00134 Mdot
.38095 .00048 Mdot
.40476 .00017 Mdot
.42857 6e-05 Mdot
.45238 2e-05 Mdot
.47619 1e-05 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 1e-05 Mdot
.61905 1e-05 Mdot
.64286 3e-05 Mdot
.66667 8e-05 Mdot
.69048 .00018 Mdot
.71429 .00038 Mdot
.7381 .00079 Mdot
.7619 .00156 Mdot
.78571 .00293 Mdot
.80952 .00526 Mdot
.83333 .00901 Mdot
.85714 .01482 Mdot
.88095 .02359 Mdot
.90476 .03678 Mdot
.92857 .05738 Mdot
.95238 .09326 Mdot
.97619 .17543 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Booooo`;o0000<Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Cooooo`;o0000W?ooool2o`0004gooooo000Uooooo`03o`000?oooooooooo05?ooooo0_l0002L
ooooo`;o00001_ooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
0Oooool2o`0003kooooo000Uooooo`;o0000C?ooool2o`000;?ooooo0_l0000nooooo`009Oooool0
0ol0003oooooooooo`1;ooooo`;o0000loooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool00ol0003ooooo
ooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000
<?ooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000n_ooool002Go
oooo00?o0000ooooooooool0A?ooool2o`000?[ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`0mooooo`;o0000ooooool2ooooo`009Oooool2o`0003kooooo0_l0003ooooo
o`;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Cooooo0ol0
003ooooooaoooooo0_l0000Qooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
0oooool2o`00037ooooo0_l0003oooooo`Wooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`03ooooo`;o0000<Oooool2o`000?oooooo2Oooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo02kooooo0_l0003ooooooa7ooooo000Uooooo`03o`000?oooooooooo02kooooo0_l0
003ooooooa7ooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uoooo
o`03o`000?oooooooooo023ooooo0_l00005ooooo`;o0000oooooolHooooo`009Oooool00ol0003o
ooooooooo`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolOooooo`00
9Oooool2o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`000?oooooo9_ooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0
003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?oo
ool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
09Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<09Gooooo
002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B40UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool00oooool01Ol0003ooooooooooooooooo000009Gooooo002Ioooo
o`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80UOooool009Wooooo00?o0000
ooooooooool06_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00_oo
ool01Oo<c<co0000o`000?l0003oc<c<09Gooooo002Gooooo`03oa0@4?l0003o000000?o00006Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00_ooool01Ol@413o^[Zj
oooooonj^[[o410@09Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S800oooool01Ol0003o^[Zjoooooonj^[[o
000009Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00000oooool01OnYZJWo410@o`000?l@413oZJVY09Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17627 Mdot
.04762 .23936 Mdot
.07143 .29518 Mdot
.09524 .29459 Mdot
.11905 .29383 Mdot
.14286 .29292 Mdot
.16667 .29107 Mdot
.19048 .28732 Mdot
.21429 .27398 Mdot
.2381 .21309 Mdot
.2619 .11849 Mdot
.28571 .05167 Mdot
.30952 .0201 Mdot
.33333 .00747 Mdot
.35714 .00272 Mdot
.38095 .00098 Mdot
.40476 .00035 Mdot
.42857 .00012 Mdot
.45238 4e-05 Mdot
.47619 2e-05 Mdot
.5 1e-05 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 1e-05 Mdot
.61905 2e-05 Mdot
.64286 5e-05 Mdot
.66667 .00011 Mdot
.69048 .00025 Mdot
.71429 .00051 Mdot
.7381 .00101 Mdot
.7619 .00192 Mdot
.78571 .00348 Mdot
.80952 .00603 Mdot
.83333 .01001 Mdot
.85714 .01602 Mdot
.88095 .02491 Mdot
.90476 .03812 Mdot
.92857 .0586 Mdot
.95238 .09426 Mdot
.97619 .17627 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04_ooool2o`0000Gooooo
0_l0000Zooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool2o`0000Gooooo
0_l0000booooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0
002>ooooo`;o00001Oooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=
ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000oooooooo
ool0Doooool2o`000:Cooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000
Zoooool2o`0003kooooo000Uooooo`;o0000ooooool2ooooo`;o0000?_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo
2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0Boooool2o`000??ooooo000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Ooo
ool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3o
ooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0
000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Co
oooo0_l0003jooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo
0_l0003jooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`?o0000oooooolOooooo`;o00008Ooo
ool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0?Oooool2o`000?oo
oooo0_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
0oooool2o`000?oooooo??ooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l0
003ooooooccooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003ooooood;ooooo000Loooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`0003Oooooo0_l0003ooooo
o`Wooooo000Uooooo`03o`000?oooooooooo03Kooooo0_l0003oooooo`Wooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003oooooooooo`0Woooo
o`;o00001Oooool2o`000?oooooo4Oooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0003ooooooaSooooo000Uooooo`;o0000
2oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000?oooooo7oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0
003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?oo
ool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
09Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`;o000000?o410@ooooooooool0
Toooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000?ooooo1Ol0002Eooooo`00VOooool00ol0
003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P03ooooo`04odA4A?oMgMgoooooo`0009Kooooo002Iooooo`03o`000?oo
oooooooo01[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`00oooool01?oMgMgoEEEEooooool0002Fooooo`00Uoooool00ol@413o0000o`000003o`0001Wo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool0
0omgMgOoc<c<o`00002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000U_oo
ool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17697 Mdot
.04762 .24 Mdot
.07143 .29585 Mdot
.09524 .29536 Mdot
.11905 .29478 Mdot
.14286 .29405 Mdot
.16667 .29314 Mdot
.19048 .29082 Mdot
.21429 .2865 Mdot
.2381 .26361 Mdot
.2619 .18565 Mdot
.28571 .09414 Mdot
.30952 .03911 Mdot
.33333 .01489 Mdot
.35714 .00548 Mdot
.38095 .00199 Mdot
.40476 .00072 Mdot
.42857 .00026 Mdot
.45238 9e-05 Mdot
.47619 3e-05 Mdot
.5 1e-05 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 1e-05 Mdot
.59524 1e-05 Mdot
.61905 3e-05 Mdot
.64286 7e-05 Mdot
.66667 .00016 Mdot
.69048 .00033 Mdot
.71429 .00066 Mdot
.7381 .00127 Mdot
.7619 .00231 Mdot
.78571 .00404 Mdot
.80952 .00678 Mdot
.83333 .01095 Mdot
.85714 .01712 Mdot
.88095 .02609 Mdot
.90476 .03929 Mdot
.92857 .05966 Mdot
.95238 .09511 Mdot
.97619 .17697 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Wooooo
0_l0000Zooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool2o`0000Gooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Qooooo`;o0000Qoooool2o`0000Gooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`1J
ooooo`;o0000UOooool2o`0004gooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0002Moooo
o`;o0000AOooool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003oooooo`;ooooo0_l0000nooooo`009Oooool0
0ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
Doooool2o`000;;ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000/_oo
ool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool0
0ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`1;ooooo`;o0000loooool002Gooooo00?o0000ooooooooool0Boooool2o`000<Wooooo0_l0000X
ooooo`009Oooool2o`000?oooooo6?ooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooo
oom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0A?ooool2o`000?[ooooo000Uooooo`03o`00
0?oooooooooo04Cooooo0_l0003jooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0?Ooo
ool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0=_ooool2o`000?oooooo2Oooool002Gooooo00?o0000ooooooooool0;_ooool2o`00
00Kooooo0_l0003oooooo`Wooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`;o
00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolAooooo`009Oooool2o`0000_ooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolHooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<V_ooool009gooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM09Wooooo002Mooooo`03o`000?oooooooooo01[ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ohN7QomEEEGooooo09Sooooo002Mooooo`03o`00
0?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
8B4Qo`000?mEEEGo000009Wooooo002Mooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05ob4Q8On7QhOooooooiRHV?l00000VOooool009_ooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000009Wooooo002Mooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0VOooool009gooooo00?o0000ooooooooool06_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP2Iooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17757 Mdot
.04762 .24055 Mdot
.07143 .2964 Mdot
.09524 .296 Mdot
.11905 .29554 Mdot
.14286 .29497 Mdot
.16667 .29428 Mdot
.19048 .29324 Mdot
.21429 .29045 Mdot
.2381 .28458 Mdot
.2619 .24743 Mdot
.28571 .15674 Mdot
.30952 .07349 Mdot
.33333 .0294 Mdot
.35714 .01102 Mdot
.38095 .00403 Mdot
.40476 .00146 Mdot
.42857 .00052 Mdot
.45238 .00019 Mdot
.47619 7e-05 Mdot
.5 2e-05 Mdot
.52381 1e-05 Mdot
.54762 1e-05 Mdot
.57143 1e-05 Mdot
.59524 2e-05 Mdot
.61905 5e-05 Mdot
.64286 .00011 Mdot
.66667 .00022 Mdot
.69048 .00043 Mdot
.71429 .00083 Mdot
.7381 .00154 Mdot
.7619 .00271 Mdot
.78571 .0046 Mdot
.80952 .00751 Mdot
.83333 .01185 Mdot
.85714 .01813 Mdot
.88095 .02716 Mdot
.90476 .04033 Mdot
.92857 .06058 Mdot
.95238 .09584 Mdot
.97619 .17757 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo023ooooo
0_l0000Sooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool2o`0000Gooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Qooooo`;o0000Qoooool2o`0000Gooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`1Q
ooooo`;o0000S_ooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015oooo
o`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo0_ooool2o`0003kooooo000Uooooo`03o`000?oooooo
oooo05[ooooo0_l0002Tooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0F_ooool2o`00
0>Cooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
ooooool8ooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000
joooool002Gooooo0_l0001Dooooo`;o0000joooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uoooo
o`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0Boooool2o`000??ooooo
000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00015ooooo`;o0000n_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`14ooooo`;o0000n_ooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`0mooooo`;o0000ooooool2ooooo`009Oooool00ol0003oooooooooo`0m
ooooo`;o0000ooooool2ooooo`009Oooool00ol0003oooooooooo`0fooooo`;o0000ooooool9oooo
o`009Oooool00ol0003oooooooooo`0Pooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o
0000ooooool9ooooo`009Oooool2o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`000?oooooo4Oooool002Gooooo00?o0000ooooooooool02_oo
ool2o`0000Kooooo0_l00005ooooo`;o0000oooooolVooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00onHV9So410@omgMg@03oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B40UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oQhN7oeEEEOooool00_ooool01Ol0003ooooooooooooo
oooo000009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool0
00002oooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000oeEEEOl0003o410@olc<c02E
ooooo`00Uoooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000000oooool00omEEEGoQhN7ooooo`2Gooooo`00VOooool0
0ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooo
oomgMgOoEEEE00?ooooo00?ogMgMoa0@4?nHV9P0Uoooool009Wooooo00?o0000ooooooooool06_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP04ooooo`04
olc<c?m4A4Co0000oa0@49Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17809 Mdot
.04762 .24101 Mdot
.07143 .29687 Mdot
.09524 .29653 Mdot
.11905 .29615 Mdot
.14286 .2957 Mdot
.16667 .29514 Mdot
.19048 .2945 Mdot
.21429 .29316 Mdot
.2381 .29001 Mdot
.2619 .28027 Mdot
.28571 .22541 Mdot
.30952 .1287 Mdot
.33333 .0566 Mdot
.35714 .02199 Mdot
.38095 .00814 Mdot
.40476 .00296 Mdot
.42857 .00107 Mdot
.45238 .00038 Mdot
.47619 .00014 Mdot
.5 5e-05 Mdot
.52381 2e-05 Mdot
.54762 1e-05 Mdot
.57143 2e-05 Mdot
.59524 3e-05 Mdot
.61905 7e-05 Mdot
.64286 .00014 Mdot
.66667 .00029 Mdot
.69048 .00055 Mdot
.71429 .00102 Mdot
.7381 .00182 Mdot
.7619 .00312 Mdot
.78571 .00516 Mdot
.80952 .00822 Mdot
.83333 .01268 Mdot
.85714 .01906 Mdot
.88095 .02813 Mdot
.90476 .04126 Mdot
.92857 .06139 Mdot
.95238 .09648 Mdot
.97619 .17809 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08?ooool2o`0000Gooooo
0_l0000Looooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool2o`0000Gooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Xooooo`;o0000P?ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=
ooooo`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo00?o0000oooooooo
ool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo067ooooo0_l0002Fooooo`;o0000
AOooool002Gooooo0_l0001Rooooo`;o0000WOooool2o`0003kooooo000Uooooo`03o`000?oooooo
oooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo
0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0003Tooooo`009Ooo
ool00ol0003oooooooooo`1Jooooo`;o0000/_ooool2o`00033ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Cooooo`;o0000joooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Cooooo`;o0000joooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000T
ooooo`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qoooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000C?ooool2o`000??ooooo000Uooooo`03o`000?oooooo
oooo04_ooooo0_l0003cooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003ooooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000n_ooool002Gooooo00?o
0000ooooooooool0A?ooool2o`000?[ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000oooooooo
ool09oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`000?oooooo0_ooool002Gooooo
0_l0000;ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000ooooool9ooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o0000oooooolOooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go0000UOoo
ool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A02Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo
00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7ok^k^09Kooooo002Iooooo`03o`00
0?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03oiRHV?lQ8B7ok^k^09Gooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Kooooo00?oMgMgofIVI_oo
ool0U?ooool009Oooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo
00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo09?ooooo002Iooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0UOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17854 Mdot
.04762 .24142 Mdot
.07143 .29728 Mdot
.09524 .29699 Mdot
.11905 .29666 Mdot
.14286 .29629 Mdot
.16667 .29586 Mdot
.19048 .29531 Mdot
.21429 .29469 Mdot
.2381 .29288 Mdot
.2619 .28942 Mdot
.28571 .27192 Mdot
.30952 .19887 Mdot
.33333 .10326 Mdot
.35714 .04315 Mdot
.38095 .0164 Mdot
.40476 .00602 Mdot
.42857 .00218 Mdot
.45238 .00079 Mdot
.47619 .00028 Mdot
.5 .0001 Mdot
.52381 4e-05 Mdot
.54762 2e-05 Mdot
.57143 3e-05 Mdot
.59524 5e-05 Mdot
.61905 9e-05 Mdot
.64286 .00019 Mdot
.66667 .00036 Mdot
.69048 .00068 Mdot
.71429 .00122 Mdot
.7381 .00212 Mdot
.7619 .00354 Mdot
.78571 .0057 Mdot
.80952 .0089 Mdot
.83333 .01347 Mdot
.85714 .01992 Mdot
.88095 .02901 Mdot
.90476 .04209 Mdot
.92857 .0621 Mdot
.95238 .09704 Mdot
.97619 .17854 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Wooooo`;o00001_ooool2o`0001Cooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`04ooooo`;o00001Oooool2o`0003Wooooo00?o0000ooooooooool07oooool002Gooooo00?o
0000ooooooooool0Koooool2o`0007;ooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000
ooooooooool0j_ooool2o`0000Gooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`1Xoooo
o`;o0000Qoooool2o`0004gooooo000Uooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o
0000AOooool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0
003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0HOoo
ool2o`000:Cooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`1Qooooo`;o0000Y?ooool2
o`0003Oooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0
003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooooaOooooo0_l0000Xooooo`009Oooool2o`000?oooooo6?ooool2o`0002Sooooo000Uooooo`03
o`000?oooooooooo05[ooooo0_l0003Tooooo`009Oooool00ol0003oooooooooo`1Jooooo`;o0000
i?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Cooooo0_l0003oooooob3ooooo0_l0000Q
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0001Doooo
o`;o0000joooool002Gooooo00?o0000ooooooooool0Doooool2o`000>_ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1;ooooo`;o0000loooool0
02Gooooo0_l0001<ooooo`;o0000loooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`14oooo
o`;o0000n_ooool002Gooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l00005ooooo`;o
00001Oooool2o`000?[ooooo000Uooooo`;o00002oooool2o`0000Kooooo0_l00005ooooo`;o0000
1Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0003oooooo`;ooooo
000Uooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0
003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?oo
ool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
09Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool00000UOooool0
09Wooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2Eooooo`00VOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05olc<c?l0003o0000o`000?o<c<`0UOooool009Oooooo00?o410@o`000?l000000ol0
000Looooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?nj^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o0000
09Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Eooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17894 Mdot
.04762 .24177 Mdot
.07143 .29763 Mdot
.09524 .29738 Mdot
.11905 .2971 Mdot
.14286 .29678 Mdot
.16667 .29643 Mdot
.19048 .296 Mdot
.21429 .29548 Mdot
.2381 .29478 Mdot
.2619 .29245 Mdot
.28571 .28818 Mdot
.30952 .25809 Mdot
.33333 .17002 Mdot
.35714 .08132 Mdot
.38095 .03265 Mdot
.40476 .0122 Mdot
.42857 .00444 Mdot
.45238 .0016 Mdot
.47619 .00058 Mdot
.5 .00021 Mdot
.52381 8e-05 Mdot
.54762 4e-05 Mdot
.57143 4e-05 Mdot
.59524 6e-05 Mdot
.61905 .00012 Mdot
.64286 .00024 Mdot
.66667 .00045 Mdot
.69048 .00082 Mdot
.71429 .00144 Mdot
.7381 .00242 Mdot
.7619 .00395 Mdot
.78571 .00624 Mdot
.80952 .00954 Mdot
.83333 .01421 Mdot
.85714 .02072 Mdot
.88095 .02981 Mdot
.90476 .04283 Mdot
.92857 .06275 Mdot
.95238 .09754 Mdot
.97619 .17894 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0_ooooo`;o00005?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000Gooooo
0_l0000iooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo0>?ooooo0_l0
0005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Koooool2o`0007Wooooo0_l00005
ooooo`;o0000COooool002Gooooo00?o0000ooooooooool0Koooool2o`00083ooooo0_l0001=oooo
o`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0
nOooool2o`0004Gooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
ooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`1Xooooo`;o0000U_ooool2o`00
03kooooo000Uooooo`03o`000?oooooooooo06Sooooo0_l0003Fooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000U
ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
ooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`03o`000?oooooooooo067o
oooo0_l0003Mooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool0
02Gooooo0_l0003ooooooaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo05[o
oooo0_l0003Tooooo`009Oooool00ol0003oooooooooo`1Jooooo`;o0000i?ooool002Gooooo0_l0
003ooooood;ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003ooooo
ob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000oooooollooooo`006_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05?ooooo0_l0003[ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0Doooool2o`000>_ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0Boooool2
o`000??ooooo000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Oooool00ol0003o
ooooooooo`0mooooo`;o00001Oooool2o`000?[ooooo000Uooooo`;o00002oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o0000n_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000?oooooo2Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000
oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q
8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj
^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001co
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_oo
ool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000K
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000
odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool00_ooool2o`000003oa0@4?oooooooooo09?ooooo002Iooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool5o`0009Gooooo002Iooooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool01?m4A4CogMgMooooool0002Fooooo`00VOooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool0002Foooo
o`00Uoooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000009Kooooo
002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`00
0006ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1793 Mdot
.04762 .24208 Mdot
.07143 .29793 Mdot
.09524 .29772 Mdot
.11905 .29747 Mdot
.14286 .29721 Mdot
.16667 .2969 Mdot
.19048 .29656 Mdot
.21429 .29613 Mdot
.2381 .29566 Mdot
.2619 .29472 Mdot
.28571 .29198 Mdot
.30952 .28522 Mdot
.33333 .23828 Mdot
.35714 .14127 Mdot
.38095 .06311 Mdot
.40476 .02457 Mdot
.42857 .00907 Mdot
.45238 .00328 Mdot
.47619 .00118 Mdot
.5 .00043 Mdot
.52381 .00016 Mdot
.54762 7e-05 Mdot
.57143 6e-05 Mdot
.59524 9e-05 Mdot
.61905 .00016 Mdot
.64286 .0003 Mdot
.66667 .00055 Mdot
.69048 .00097 Mdot
.71429 .00166 Mdot
.7381 .00274 Mdot
.7619 .00437 Mdot
.78571 .00676 Mdot
.80952 .01016 Mdot
.83333 .0149 Mdot
.85714 .02145 Mdot
.88095 .03054 Mdot
.90476 .04351 Mdot
.92857 .06332 Mdot
.95238 .09798 Mdot
.97619 .1793 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Kooooo
0_l0000=ooooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o00001Oooool2o`0003Wooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0Moooool2o`0006[ooooo0_l0
0005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Moooool2o`00077ooooo0_l00005
ooooo`;o0000COooool002Gooooo00?o0000ooooooooool0lOooool2o`0004gooooo000Uooooo`03
o`000?oooooooooo0?Wooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`1_ooooo`;o0000
R?ooool2o`0004Gooooo000Uooooo`;o0000L?ooool2o`000<oooooo000Uooooo`03o`000?oooooo
oooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`00
03kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool0
0ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0J?ooool2
o`000:Cooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`1Xooooo`;o0000Y?ooool2o`00
033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Qooooo`;o0000gOoo
ool002Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0F_ooool2o`000>Cooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000EOooool2o`000>Cooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`1Cooooo`;o0000joooool002Gooooo00?o0000ooooooooool0Doooool2
o`000>_ooooo000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Oooool00ol0003o
ooooooooo`14ooooo`;o00001Oooool2o`000??ooooo000Uooooo`;o00002oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o0000n_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
003oooooo`;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00WOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5
o`0009Wooooo002Mooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Iooooo`00WOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0V_ooool0
09gooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03?ooool00onH
V9So8B4Qonk^kP2Iooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?oMgMgofIVI_ooool0V?ooool009_ooooo00?o410@o`000?l000000ol0000Looooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Uoooool009gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@4100VOooool009gooooo00?o
0000ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
VOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17962 Mdot
.04762 .24236 Mdot
.07143 .29821 Mdot
.09524 .29801 Mdot
.11905 .2978 Mdot
.14286 .29757 Mdot
.16667 .29731 Mdot
.19048 .29702 Mdot
.21429 .29669 Mdot
.2381 .29626 Mdot
.2619 .29582 Mdot
.28571 .29445 Mdot
.30952 .29149 Mdot
.33333 .27897 Mdot
.35714 .21327 Mdot
.38095 .11455 Mdot
.40476 .04844 Mdot
.42857 .01842 Mdot
.45238 .00673 Mdot
.47619 .00243 Mdot
.5 .00088 Mdot
.52381 .00032 Mdot
.54762 .00014 Mdot
.57143 9e-05 Mdot
.59524 .00012 Mdot
.61905 .00021 Mdot
.64286 .00037 Mdot
.66667 .00066 Mdot
.69048 .00113 Mdot
.71429 .00189 Mdot
.7381 .00305 Mdot
.7619 .00478 Mdot
.78571 .00726 Mdot
.80952 .01075 Mdot
.83333 .01556 Mdot
.85714 .02213 Mdot
.88095 .03121 Mdot
.90476 .04413 Mdot
.92857 .06384 Mdot
.95238 .09838 Mdot
.97619 .17962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0fooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool0AOooool2o`0000Gooooo
0_l00005ooooo`;o0000>Oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1nooooo`;o0000Hoooool2o`0000Gooooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`3Z
ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Moooool2o`0007Sooooo0_l0001=oooo
o`009Oooool00ol0003oooooooooo`1gooooo`;o0000N?ooool2o`0004gooooo000Uooooo`03o`00
0?oooooooooo0?Wooooo0_l00015ooooo`009Oooool2o`000?[ooooo0_l00015ooooo`009Oooool0
0ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooo
o`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=ooo
ool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool002Gooooo0_l0001`oooo
o`;o0000coooool002Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooo
o`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o
0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo06Sooooo0_l0003Fooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo06Sooooo0_l0003Fooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2o`00
0?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`03o`000?oooooooooo067o
oooo0_l0003Mooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ooo
ool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool0
01cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo05[ooooo
0_l0003Tooooo`009Oooool00ol0003oooooooooo`1Jooooo`;o0000i?ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000joooool002Go
oooo00?o0000ooooooooool0Boooool2o`0000Kooooo0_l0003[ooooo`009Oooool2o`0000_ooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0003cooooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l0003jooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0UOoo
ool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoEEEEogMgMooooooo
V9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000009Gooooo002Iooooo`03o`00
0?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0UOooool009Oooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00kooooo
00Ko0000oooooooooooooooooeEEEOn7QhNHooooo`00VOooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH
09Oooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1799 Mdot
.04762 .24261 Mdot
.07143 .29845 Mdot
.09524 .29828 Mdot
.11905 .29809 Mdot
.14286 .29789 Mdot
.16667 .29766 Mdot
.19048 .29741 Mdot
.21429 .29713 Mdot
.2381 .29681 Mdot
.2619 .29639 Mdot
.28571 .29593 Mdot
.30952 .29401 Mdot
.33333 .29071 Mdot
.35714 .26783 Mdot
.38095 .18496 Mdot
.40476 .09105 Mdot
.42857 .03688 Mdot
.45238 .01378 Mdot
.47619 .005 Mdot
.5 .0018 Mdot
.52381 .00066 Mdot
.54762 .00027 Mdot
.57143 .00015 Mdot
.59524 .00016 Mdot
.61905 .00026 Mdot
.64286 .00045 Mdot
.66667 .00077 Mdot
.69048 .0013 Mdot
.71429 .00213 Mdot
.7381 .00337 Mdot
.7619 .00518 Mdot
.78571 .00775 Mdot
.80952 .01131 Mdot
.83333 .01617 Mdot
.85714 .02277 Mdot
.88095 .03183 Mdot
.90476 .04469 Mdot
.92857 .06431 Mdot
.95238 .09874 Mdot
.97619 .1799 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0mooooo`;o00001_ooool00ol0003oooooooooo`0mooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o0000>Oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`3Sooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo07kooooo0_l0001Z
ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0O_ooool2o`00077ooooo0_l0001=oooo
o`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
nOooool2o`0004Gooooo000Uooooo`;o0000n_ooool2o`0004Gooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Go
oooo00?o0000ooooooooool0Moooool2o`0008Oooooo0_l0000nooooo`009Oooool00ol0003ooooo
ooooo`1gooooo`;o0000aoooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=ooo
ool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00
033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oo
oooooooo06oooooo0_l0003?ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o
0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooo
oom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0J?ooool2o`000=Kooooo000Uooooo`03o`00
0?oooooooooo06Sooooo0_l0003Fooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Qooooo`;o0000gOoo
ool002Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0003Tooooo`009Oooool00ol0003o
ooooooooo`1Cooooo`;o00001Oooool2o`000>Cooooo000Uooooo`;o00002oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0003[ooooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000loooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7o
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Ooo
ool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06
ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_oo
ool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000J
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo
000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0U_ooool009Wooooo00?o
0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03Oooool00onYZJWo410@oooo
o`04ooooo`03oiRHV?lQ8B7ok^k^09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool03?ooool00ol@413o0000okZj^P06ooooo`03ogMgMomVIVKooooo09Cooooo002Goooo
o`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0=ooooo`03okZj^_lQ8B7ooooo
00Kooooo00?o0000ooooooooool0Toooool009Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[ZjoooooonHV9So
410@09Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Eooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18016 Mdot
.04762 .24283 Mdot
.07143 .29867 Mdot
.09524 .29851 Mdot
.11905 .29835 Mdot
.14286 .29817 Mdot
.16667 .29797 Mdot
.19048 .29775 Mdot
.21429 .29751 Mdot
.2381 .29724 Mdot
.2619 .29691 Mdot
.28571 .29653 Mdot
.30952 .29591 Mdot
.33333 .2935 Mdot
.35714 .28885 Mdot
.38095 .25078 Mdot
.40476 .15575 Mdot
.42857 .07124 Mdot
.45238 .02791 Mdot
.47619 .01029 Mdot
.5 .00372 Mdot
.52381 .00135 Mdot
.54762 .00052 Mdot
.57143 .00026 Mdot
.59524 .00023 Mdot
.61905 .00032 Mdot
.64286 .00053 Mdot
.66667 .0009 Mdot
.69048 .00148 Mdot
.71429 .00237 Mdot
.7381 .00368 Mdot
.7619 .00558 Mdot
.78571 .00822 Mdot
.80952 .01184 Mdot
.83333 .01674 Mdot
.85714 .02336 Mdot
.88095 .03239 Mdot
.90476 .0452 Mdot
.92857 .06474 Mdot
.95238 .09907 Mdot
.97619 .18016 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A?ooool2o`0003oooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000iooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo08Gooooo0_l0001Eooooo`;o00001Oooool2o`0000Gooooo0_l0
001Dooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000Hoooool2o`0005Cooooo000Uoooo
o`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`3aooooo`;o
0000COooool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`;o0000Oooo
ool2o`0007Wooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000`?ooool0
02Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000oooooooo
ool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2
o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool0
02Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000oooooooo
ool0Moooool2o`000<Oooooo000Uooooo`03o`000?oooooooooo07Oooooo0_l00037ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooooaSooooo0_l0000Xoooo
o`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oo
oooooooo06oooooo0_l0003?ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0J?ooool2o`000=Kooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0J?ooool2o`000=Kooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0HOooool2o`000=gooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l00005ooooo`;o
0000gOooool002Gooooo0_l0000;ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o0000
1Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000
1_ooool2o`0000Gooooo0_l0003Tooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000>_ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
ZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000J
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_oo
ool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00VOooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c02Eooooo`00VOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01OlQ8B7oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool0Toooool009Wooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooooooo
ool03Oooool00onYZJWo410@ooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80UOooool009Wo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Goc<c<o`000?l0003o0000olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj
^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000009Gooooo002Ioooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Eooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1804 Mdot
.04762 .24304 Mdot
.07143 .29886 Mdot
.09524 .29873 Mdot
.11905 .29858 Mdot
.14286 .29842 Mdot
.16667 .29824 Mdot
.19048 .29805 Mdot
.21429 .29784 Mdot
.2381 .2976 Mdot
.2619 .29735 Mdot
.28571 .297 Mdot
.30952 .29667 Mdot
.33333 .29569 Mdot
.35714 .29301 Mdot
.38095 .28455 Mdot
.40476 .22799 Mdot
.42857 .12781 Mdot
.45238 .05506 Mdot
.47619 .02102 Mdot
.5 .00768 Mdot
.52381 .00278 Mdot
.54762 .00104 Mdot
.57143 .00046 Mdot
.59524 .00033 Mdot
.61905 .0004 Mdot
.64286 .00063 Mdot
.66667 .00103 Mdot
.69048 .00166 Mdot
.71429 .00261 Mdot
.7381 .004 Mdot
.7619 .00596 Mdot
.78571 .00867 Mdot
.80952 .01235 Mdot
.83333 .01729 Mdot
.85714 .02391 Mdot
.88095 .03292 Mdot
.90476 .04568 Mdot
.92857 .06514 Mdot
.95238 .09937 Mdot
.97619 .1804 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Cooooo
0_l00006ooooo`;o0000=oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0003Wooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0S?ooool2o`0004kooooo0_l0
0005ooooo`;o0000Foooool002Gooooo00?o0000ooooooooool0j_ooool2o`0005Cooooo000Uoooo
o`03o`000?oooooooooo0>[ooooo0_l00005ooooo`;o0000COooool002Gooooo00?o0000oooooooo
ool0QOooool2o`0006[ooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000
L_ooool2o`0004Gooooo000Uooooo`;o0000n_ooool2o`0004Gooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Go
oooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000
`?ooool002Gooooo00?o0000ooooooooool0O_ooool2o`000<3ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Go
oooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Moooool2o`000<Oooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Moooool2o`000<Oooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oooooooooo06oooooo0_l0003?oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`1Xooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool0J?ooool2
o`000=Kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0HOooool2o`000=gooooo000Uooooo`;o00006_ooool2o`0000Gooooo0_l00005ooooo`;o0000
1Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000
1Oooool2o`0000Gooooo0_l0003Mooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0003Tooooo`009Oooool0
0ol0003oooooooooo`0:ooooo`;o00001_ooool2o`000?oooooo;Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00VOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l000000ol@413oooooooooo`2Cooooo`00VOooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool009Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0:ooooo`Go00000oooool5o`0009Gooooo002Iooooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00CoA4A4omgMgOoo
oooo00001?ooool01?m4A4CogMgMooooool0002Fooooo`00VOooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo00001?ooool01?oMgMgoEEEEooooool0
002Fooooo`00Uoooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02oooool0
0omgMgOoc<c<o`000005ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool02oooool00oo^k^koA4A4o`000005ooooo`03onk^k_m4A4Co0000
09Kooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003_ooool00omgMgOo
0000ooooo`05ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18061 Mdot
.04762 .24322 Mdot
.07143 .29904 Mdot
.09524 .29892 Mdot
.11905 .29878 Mdot
.14286 .29864 Mdot
.16667 .29848 Mdot
.19048 .29831 Mdot
.21429 .29813 Mdot
.2381 .29792 Mdot
.2619 .2977 Mdot
.28571 .29744 Mdot
.30952 .2971 Mdot
.33333 .29679 Mdot
.35714 .29528 Mdot
.38095 .29247 Mdot
.40476 .27613 Mdot
.42857 .20089 Mdot
.45238 .10264 Mdot
.47619 .04217 Mdot
.5 .0158 Mdot
.52381 .00575 Mdot
.54762 .00212 Mdot
.57143 .00086 Mdot
.59524 .0005 Mdot
.61905 .00051 Mdot
.64286 .00074 Mdot
.66667 .00117 Mdot
.69048 .00185 Mdot
.71429 .00286 Mdot
.7381 .00431 Mdot
.7619 .00634 Mdot
.78571 .00911 Mdot
.80952 .01283 Mdot
.83333 .0178 Mdot
.85714 .02442 Mdot
.88095 .03341 Mdot
.90476 .04611 Mdot
.92857 .0655 Mdot
.95238 .09964 Mdot
.97619 .18061 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`04ooooo`;o0000=oooool2o`0000Kooooo0_l00005ooooo`;o0000@?ooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000A_ooool2o`0000Gooooo0_l0
001Kooooo`009Oooool00ol0003oooooooooo`3Sooooo`;o00001Oooool2o`0005Cooooo000Uoooo
o`03o`000?oooooooooo08cooooo0_l0001Looooo`;o00001Oooool2o`0004gooooo000Uooooo`03
o`000?oooooooooo08cooooo0_l0001Sooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
nOooool2o`0004Gooooo000Uooooo`;o0000n_ooool2o`0004Gooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Go
oooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool002Gooooo00?o0000
ooooooooool0QOooool2o`00083ooooo0_l0000gooooo`009Oooool2o`000?oooooo2Oooool2o`00
03Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Go
oooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000U_ooool2o`0002So
oooo000Uooooo`03o`000?oooooooooo07kooooo0_l00030ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooo
oom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0Moooool2o`000<Oooooo000Uooooo`03o`000?oooooooooo07Oooooo0_l00037ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo06oooooo0_l0003?ooooo`009Oooool00ol0003oooooooooo`1_ooooo`;o0000
coooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0HOooool2o`0000Gooooo0_l0003Fooooo`009Oooool2o`00027ooooo0_l00005ooooo`;o0000
1Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000
1Oooool2o`0000Gooooo0_l00005ooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool02_oo
ool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000i?oo
ool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o0000oooooolV
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Mooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0V?ooool009gooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`2Gooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0U_ooool009gooooo00?o0000ooooooooool02oooool6o`00
00cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`2Gooooo`00WOooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c02Hoooo
o`00Voooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`2Jooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0V_ooool009gooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`00
000=ooooo`Co0000VOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18081 Mdot
.04762 .24339 Mdot
.07143 .29921 Mdot
.09524 .29909 Mdot
.11905 .29897 Mdot
.14286 .29884 Mdot
.16667 .2987 Mdot
.19048 .29855 Mdot
.21429 .29838 Mdot
.2381 .2982 Mdot
.2619 .298 Mdot
.28571 .29779 Mdot
.30952 .29753 Mdot
.33333 .29721 Mdot
.35714 .29682 Mdot
.38095 .29475 Mdot
.40476 .29138 Mdot
.42857 .26219 Mdot
.45238 .17172 Mdot
.47619 .08102 Mdot
.5 .03208 Mdot
.52381 .01187 Mdot
.54762 .00434 Mdot
.57143 .00168 Mdot
.59524 .00083 Mdot
.61905 .00068 Mdot
.64286 .00088 Mdot
.66667 .00132 Mdot
.69048 .00204 Mdot
.71429 .00311 Mdot
.7381 .00462 Mdot
.7619 .00671 Mdot
.78571 .00953 Mdot
.80952 .01329 Mdot
.83333 .01828 Mdot
.85714 .0249 Mdot
.88095 .03386 Mdot
.90476 .04652 Mdot
.92857 .06583 Mdot
.95238 .09989 Mdot
.97619 .18081 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0;ooooo`;o0000<?ooool2o`0000Kooooo0_l00005ooooo`;o0000@?ooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000A_ooool2o`0000Gooooo0_l0
001Kooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000COooool2o`0000Gooooo0_l0001D
ooooo`009Oooool00ol0003oooooooooo`3Zooooo`;o00001Oooool2o`0004gooooo000Uooooo`03
o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000
AOooool002Gooooo0_l0003jooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`2<ooooo`;o0000L_ooool2o`0003kooooo000Uooooo`03
o`000?oooooooooo08cooooo0_l0001booooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003o
ooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool0
02Gooooo00?o0000ooooooooool0QOooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo07kooooo0_l00030ooooo`009Oooool2o`0007oooooo0_l0
0030ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`1gooooo`;o0000aoooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo07Oooooo0_l00037ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oooooooooo06So
oooo0_l00005ooooo`;o0000coooool002Gooooo0_l0000Xooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000=gooooo000U
ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0003o
oooooaoooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooooEEEEogMg
MoooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2Cooooo`00VOooool00ol0
003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;ooooo
ooooool0003oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oeEEEOl0003o
410@olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`04ooooo`03oeEEEOn7QhOooooo09Oooooo002Iooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03omgMgOl@
413oV9RH09Oooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003Oooool4
o`0000Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18099 Mdot
.04762 .24355 Mdot
.07143 .29935 Mdot
.09524 .29925 Mdot
.11905 .29914 Mdot
.14286 .29902 Mdot
.16667 .29889 Mdot
.19048 .29876 Mdot
.21429 .29861 Mdot
.2381 .29845 Mdot
.2619 .29827 Mdot
.28571 .29808 Mdot
.30952 .29788 Mdot
.33333 .2976 Mdot
.35714 .29733 Mdot
.38095 .29668 Mdot
.40476 .29422 Mdot
.42857 .28866 Mdot
.45238 .24225 Mdot
.47619 .14283 Mdot
.5 .0631 Mdot
.52381 .02431 Mdot
.54762 .00895 Mdot
.57143 .00336 Mdot
.59524 .00146 Mdot
.61905 .00096 Mdot
.64286 .00105 Mdot
.66667 .00149 Mdot
.69048 .00225 Mdot
.71429 .00336 Mdot
.7381 .00492 Mdot
.7619 .00706 Mdot
.78571 .00993 Mdot
.80952 .01373 Mdot
.83333 .01873 Mdot
.85714 .02535 Mdot
.88095 .03429 Mdot
.90476 .04689 Mdot
.92857 .06614 Mdot
.95238 .10013 Mdot
.97619 .18099 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04_ooool2o`0002;ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00010ooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0
000oooooo`;o00001Oooool2o`0005_ooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l00016
ooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0>[ooooo0_l0001Doooo
o`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
U?ooool2o`0005_ooooo0_l0001=ooooo`009Oooool2o`0009Gooooo0_l0001Sooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003ko
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool2o`00
0?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo08cooooo0_l0002booooo`009Oooool00ol0003oooooooooo`2<oooo
o`;o0000P?ooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000oooooooo
ool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0QOooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo08Gooooo0_l0002i
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo07kooooo0_l0
0030ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ooo
ool2o`0007Wooooo0_l00030ooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`1gooooo`;o0000aoooool002Gooooo00?o0000ooooooooool0Moooool2o`00
0<Oooooo000Uooooo`03o`000?oooooooooo06oooooo0_l0003?ooooo`009Oooool2o`0003Oooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`000<oooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolAooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0UOooool009Wooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
00001?ooool00onHV9So8B4Qonk^kP2Fooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00onHV9So
8B4Qonk^kP2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03ogMgMomVIVKooooo09Cooooo002Gooooo`03oa0@
4?l0003o000000?o00007?ooool00ol0003oooooooooo`0:ooooo`03oeEEEOn7QhOooooo00Wooooo
00?o0000ooooooooool0Toooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0:ooooo`03omgMgOl@413oV9RH00Gooooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOoo
ool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo00Coc<c<odA4A?l0003o410@
0oooool01OnHV9So410@o`000?lQ8B7oc<c<09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18116 Mdot
.04762 .24369 Mdot
.07143 .29949 Mdot
.09524 .2994 Mdot
.11905 .29929 Mdot
.14286 .29919 Mdot
.16667 .29907 Mdot
.19048 .29895 Mdot
.21429 .29881 Mdot
.2381 .29867 Mdot
.2619 .29851 Mdot
.28571 .29834 Mdot
.30952 .29816 Mdot
.33333 .29796 Mdot
.35714 .29767 Mdot
.38095 .29745 Mdot
.40476 .29633 Mdot
.42857 .29374 Mdot
.45238 .28275 Mdot
.47619 .21713 Mdot
.5 .11607 Mdot
.52381 .04867 Mdot
.54762 .01842 Mdot
.57143 .00684 Mdot
.59524 .00275 Mdot
.61905 .00148 Mdot
.64286 .00132 Mdot
.66667 .0017 Mdot
.69048 .00246 Mdot
.71429 .00361 Mdot
.7381 .00522 Mdot
.7619 .00741 Mdot
.78571 .01032 Mdot
.80952 .01415 Mdot
.83333 .01916 Mdot
.85714 .02577 Mdot
.88095 .03468 Mdot
.90476 .04724 Mdot
.92857 .06643 Mdot
.95238 .10034 Mdot
.97619 .18116 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Booooo`;o00001Oooool2o`0001_ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00010ooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo0:;ooooo0_l0
000hooooo`;o00001Oooool2o`0005_ooooo000Uooooo`03o`000?oooooooooo0>?ooooo0_l00005
ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Voooool2o`0004gooooo0_l0001Doooo
o`009Oooool00ol0003oooooooooo`2Kooooo`;o0000E?ooool2o`0004gooooo000Uooooo`03o`00
0?oooooooooo0?7ooooo0_l0001=ooooo`009Oooool2o`000?[ooooo0_l00015ooooo`009Oooool0
0ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0ooooool1oooo
o`;o0000?_ooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000UOooool2o`00
077ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000Z_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?oooo
o`;o0000<?ooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooooaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOo
oooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0S?ooool2o`000;;ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool2o`000;;ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Toooo
o`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo08Go
oooo0_l0002iooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0
003ooooooccooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00004ooooo`;o0000ooooooll
ooooo`007?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000`?ooool002Gooooo00?o0000
ooooooooool0O_ooool2o`000<3ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0Moooool2o`000<Oooooo000Uooooo`;o0000?_ooool2o`0000Gooooo
0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000aoooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o0000coooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000?oooooo2Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@
o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Ooo
ool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2
o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_o
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8boooo
o`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOoo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00VOooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c02Eooooo`00VOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OlQ8B7o
V9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00002E
ooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Olb<S;oV9RHoooooonHV9So<S8b09Gooooo002I
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@
413oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c02Eooooo`00Uoooool00ol@413o0000o`00
0003o`0001cooooo00?o0000ooooooooool02_ooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?nj
^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0:ooooo`03omgMgOl@413oV9RH00Gooooo00Go0000okZj^_oooooo^[Zjo`00002Eooooo`00VOoo
ool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo00Coc<c<odA4A?l0003o410@
0oooool01OnYZJWo410@o`000?l@413oZJVY09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18131 Mdot
.04762 .24382 Mdot
.07143 .29962 Mdot
.09524 .29953 Mdot
.11905 .29944 Mdot
.14286 .29934 Mdot
.16667 .29923 Mdot
.19048 .29912 Mdot
.21429 .299 Mdot
.2381 .29887 Mdot
.2619 .29873 Mdot
.28571 .29858 Mdot
.30952 .29841 Mdot
.33333 .29824 Mdot
.35714 .29803 Mdot
.38095 .29775 Mdot
.40476 .29751 Mdot
.42857 .29582 Mdot
.45238 .29308 Mdot
.47619 .27201 Mdot
.5 .18871 Mdot
.52381 .09256 Mdot
.54762 .0373 Mdot
.57143 .01402 Mdot
.59524 .00538 Mdot
.61905 .00248 Mdot
.64286 .00176 Mdot
.66667 .00196 Mdot
.69048 .0027 Mdot
.71429 .00387 Mdot
.7381 .00552 Mdot
.7619 .00775 Mdot
.78571 .01069 Mdot
.80952 .01455 Mdot
.83333 .01957 Mdot
.85714 .02617 Mdot
.88095 .03506 Mdot
.90476 .04757 Mdot
.92857 .0667 Mdot
.95238 .10054 Mdot
.97619 .18131 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool06Oooool2o`0000Gooooo0_l0000Dooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o0000@?ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`3Eooooo`;o00001Oooool2o`0000Gooooo0_l0001Kooooo`009Oooool00ol0003oooooooooo`2R
ooooo`;o0000?oooool2o`0000Gooooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`2Roooo
o`;o0000A_ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0003jooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0001Sooooo`;o
0000?_ooool002Gooooo00?o0000ooooooooool0Voooool2o`000:?ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool0
02Gooooo0_l0003oooooo`Wooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0U?ooool2o`000:[ooooo000Uooooo`03o`000?oooooo
oooo09Cooooo0_l0002Zooooo`009Oooool2o`000?oooooo6?ooool2o`0002Sooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0S?ooool2o`000;;ooooo000Uooooo`03o`000?oo
oooooooo08cooooo0_l0002booooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool0
02Gooooo0_l00026ooooo`;o0000^Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo07kooooo0_l00030ooooo`009Oooool2o`0004cooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o0000`?ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`000<Oooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`000?[ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0I
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool2
o`000003oa0@4?oooooooooo09?ooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01_ooool0
0ol0003oooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00cooooo00?oZJVYoeEEEOooool00oooool5o`0009Gooooo002Iooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool00_ooool01?m4A4Co
gMgMooooool0002Fooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?oEEEEolc<c?ooool00_ooool01?oMgMgoEEEEooooool0002Fooooo`00Uoooool00ol@413o
0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03
ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?ok^k^odA4A?l00000U_ooool009Wooooo
00?o0000ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`Go00001Oooool00omgMgOo0000
ooooo`2Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18146 Mdot
.04762 .24394 Mdot
.07143 .29973 Mdot
.09524 .29965 Mdot
.11905 .29957 Mdot
.14286 .29948 Mdot
.16667 .29938 Mdot
.19048 .29928 Mdot
.21429 .29917 Mdot
.2381 .29905 Mdot
.2619 .29892 Mdot
.28571 .29879 Mdot
.30952 .29864 Mdot
.33333 .29848 Mdot
.35714 .29831 Mdot
.38095 .29809 Mdot
.40476 .29785 Mdot
.42857 .29745 Mdot
.45238 .29524 Mdot
.47619 .2915 Mdot
.5 .25539 Mdot
.52381 .15939 Mdot
.54762 .07278 Mdot
.57143 .02855 Mdot
.59524 .01083 Mdot
.61905 .0045 Mdot
.64286 .00256 Mdot
.66667 .00236 Mdot
.69048 .00298 Mdot
.71429 .00414 Mdot
.7381 .00581 Mdot
.7619 .00808 Mdot
.78571 .01105 Mdot
.80952 .01493 Mdot
.83333 .01996 Mdot
.85714 .02655 Mdot
.88095 .0354 Mdot
.90476 .04788 Mdot
.92857 .06695 Mdot
.95238 .10072 Mdot
.97619 .18146 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo023ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00010ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0:Wooooo0_l0000Zooooo`;o00001Oooool2o`0000Gooooo0_l0
001Kooooo`009Oooool00ol0003oooooooooo`2Yooooo`;o0000>?ooool2o`0000Gooooo0_l0001D
ooooo`009Oooool00ol0003oooooooooo`3Zooooo`;o0000E?ooool002Gooooo00?o0000oooooooo
ool0lOooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Ooo
ool2o`000?[ooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`2Rooooo`;o0000EOooool2
o`0004Gooooo000Uooooo`03o`000?oooooooooo0:;ooooo0_l0002Looooo`009Oooool00ol0003o
ooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo
0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003o
ooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`2Kooooo`;o0000
Xoooool002Gooooo0_l0002Looooo`;o0000Xoooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`2Dooooo`;o0000Z_ooool002Gooooo00?o0000ooooooooool0U?ooool2
o`000:[ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo08cooooo0_l0002booooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo08cooooo0_l0002booooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0QOooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo07ko
oooo0_l00005ooooo`;o0000^Oooool002Gooooo0_l0001Dooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000`?ooool002Gooooo00?o
0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000<Oooooo000U
ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0003c
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Mooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0VOooool009gooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q09Wooooo002Mooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000009Wooooo002Mooooo`03o`000?oo
oooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P2Iooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go
c<c<o`000?l0003o0000olc<c02Iooooo`00Voooool00ol@413o0000o`000003o`0001cooooo00?o
0000ooooooooool02_ooool01Ol@413o^[Zjoooooonj^[[o410@09Wooooo002Mooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o000009Wooooo
002Mooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`00
0?l@413oZJVY09Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18159 Mdot
.04762 .24406 Mdot
.07143 .29984 Mdot
.09524 .29977 Mdot
.11905 .29969 Mdot
.14286 .2996 Mdot
.16667 .29951 Mdot
.19048 .29942 Mdot
.21429 .29932 Mdot
.2381 .29921 Mdot
.2619 .2991 Mdot
.28571 .29898 Mdot
.30952 .29884 Mdot
.33333 .2987 Mdot
.35714 .29854 Mdot
.38095 .29838 Mdot
.40476 .29814 Mdot
.42857 .29795 Mdot
.45238 .2972 Mdot
.47619 .29473 Mdot
.5 .28768 Mdot
.52381 .23301 Mdot
.54762 .13135 Mdot
.57143 .05668 Mdot
.59524 .02195 Mdot
.61905 .00864 Mdot
.64286 .00413 Mdot
.66667 .00303 Mdot
.69048 .00336 Mdot
.71429 .00444 Mdot
.7381 .00612 Mdot
.7619 .0084 Mdot
.78571 .0114 Mdot
.80952 .01529 Mdot
.83333 .02032 Mdot
.85714 .0269 Mdot
.88095 .03573 Mdot
.90476 .04816 Mdot
.92857 .06718 Mdot
.95238 .1009 Mdot
.97619 .18159 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool08?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o00001Oooool2o`00043ooooo00?o0000ooooooooool07oooool002Gooooo00?o
0000ooooooooool0/?ooool2o`0002?ooooo0_l00005ooooo`;o00001Oooool2o`0005_ooooo000U
ooooo`03o`000?oooooooooo0>?ooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000oooo
ooooool0j_ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`2Yooooo`;o0000A_ooool2o`0004gooooo000Uooooo`;o0000Z_oo
ool2o`0004kooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`7o
oooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2
o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`2Rooooo`;o0000W?ooool002Gooooo00?o
0000ooooooooool0X_ooool2o`0009cooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000oooooooo
ool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooooaSooooo0_l0000Xoooo
o`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo09_ooooo0_l0002Sooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo09_ooooo0_l0002Sooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo09Co
oooo0_l0002Zooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000Z_ooool001[ooooo1Ol0
0006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo08cooooo0_l0002booooo`009Oooool00ol0
003oooooooooo`2<ooooo`;o0000/_ooool002Gooooo00?o0000ooooooooool0QOooool2o`000;Wo
oooo000Uooooo`;o0000Foooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000`?ooool002Gooooo00?o0000
ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0003[
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?l@413oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo
00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B40UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo
00[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?nHV9SooooooiRHV?lQ8B40UOoo
ool009Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05olc<c?l0003o
0000o`000?o<c<`00oooool01Ol0003oEEEEo`000?l@413oc<c<09Gooooo002Gooooo`03oa0@4?l0
003o000000?o00007?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool00omEEEGoQhN7ooooo`2Gooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`03omgMgOl@413oV9RH09Oooooo
002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`00
0?l@413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.92) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18172 Mdot
.04762 .24416 Mdot
.07143 .29994 Mdot
.09524 .29987 Mdot
.11905 .2998 Mdot
.14286 .29972 Mdot
.16667 .29964 Mdot
.19048 .29955 Mdot
.21429 .29946 Mdot
.2381 .29936 Mdot
.2619 .29926 Mdot
.28571 .29915 Mdot
.30952 .29903 Mdot
.33333 .2989 Mdot
.35714 .29876 Mdot
.38095 .29861 Mdot
.40476 .29845 Mdot
.42857 .2982 Mdot
.45238 .29804 Mdot
.47619 .29675 Mdot
.5 .29424 Mdot
.52381 .27996 Mdot
.54762 .20623 Mdot
.57143 .10612 Mdot
.59524 .04398 Mdot
.61905 .01714 Mdot
.64286 .00731 Mdot
.66667 .00428 Mdot
.69048 .00394 Mdot
.71429 .00481 Mdot
.7381 .00644 Mdot
.7619 .00872 Mdot
.78571 .01174 Mdot
.80952 .01564 Mdot
.83333 .02067 Mdot
.85714 .02724 Mdot
.88095 .03604 Mdot
.90476 .04843 Mdot
.92857 .0674 Mdot
.95238 .10106 Mdot
.97619 .18172 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo02Sooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000Aoooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`2hooooo`;o00006oooool2o`0000Gooooo0_l00005ooooo`;o0000Foooool002Gooooo00?o0000
ooooooooool0g?ooool2o`0000Gooooo0_l0001Kooooo`009Oooool00ol0003oooooooooo`2`oooo
o`;o0000>?ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0;3ooooo0_l0000hooooo`;o
00001Oooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Ooo
ool2o`000?[ooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`7o
oooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Ooo
ool00ol0003oooooooooo`2Yooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0ZOooool2
o`0009Gooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Gooooo00?o0000oooooooo
ool0ooooool8ooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000oooooooo
ool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0:;ooooo
0_l0001booooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0X_ooool2o`0009cooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`2Kooooo`;o0000Xoooool002Gooooo00?o0000ooooooooool0Vooo
ool2o`000:?ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol0
0006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0U?ooool2o`000:[ooooo000Uooooo`03o`000?oo
oooooooo09Cooooo0_l0002Zooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0S?ooool2o`000;;o
oooo000Uooooo`;o0000JOooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o0000/_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o0000^Oooool002Gooooo00?o0000
ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`000=gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0I
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1?oo
ool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd00oooool01OnHV9So8B4Qonk^
k_ooooooA4A409Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Ooo
ool00on7QhOoEEEEooooo`03ooooo`03oiRHV?lQ8B7ok^k^09Kooooo002Iooooo`03o`000?oooooo
oooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00
0005ooooo`03oiRHV?lQ8B7ok^k^09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02_ooool01OlQ8B7oQhN7oooooonHV9So000000Kooooo00?oMgMgofIVI_ooool0U?oo
ool009Oooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo09?ooooo002Iooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool02_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00Go
0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0003oooooooooo`0Kooooo`03oeEEEOmV
IVKo000000cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0UOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18183 Mdot
.04762 .24426 Mdot
.07143 .30004 Mdot
.09524 .29997 Mdot
.11905 .2999 Mdot
.14286 .29983 Mdot
.16667 .29976 Mdot
.19048 .29968 Mdot
.21429 .29959 Mdot
.2381 .2995 Mdot
.2619 .2994 Mdot
.28571 .2993 Mdot
.30952 .29919 Mdot
.33333 .29908 Mdot
.35714 .29895 Mdot
.38095 .29881 Mdot
.40476 .29867 Mdot
.42857 .2985 Mdot
.45238 .29827 Mdot
.47619 .29805 Mdot
.5 .29617 Mdot
.52381 .29336 Mdot
.54762 .26689 Mdot
.57143 .17731 Mdot
.59524 .08453 Mdot
.61905 .03423 Mdot
.64286 .01381 Mdot
.66667 .00674 Mdot
.69048 .00496 Mdot
.71429 .00534 Mdot
.7381 .00681 Mdot
.7619 .00906 Mdot
.78571 .01207 Mdot
.80952 .01597 Mdot
.83333 .021 Mdot
.85714 .02755 Mdot
.88095 .03633 Mdot
.90476 .04868 Mdot
.92857 .0676 Mdot
.95238 .10121 Mdot
.97619 .18183 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0;oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0004Oooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0_oooool2o`0001Cooooo0_l0
0005ooooo`;o0000H_ooool002Gooooo00?o0000ooooooooool0^?ooool2o`0002;ooooo0_l00005
ooooo`;o0000Foooool002Gooooo00?o0000ooooooooool0^?ooool2o`0002Wooooo0_l00005oooo
o`;o0000E?ooool002Gooooo00?o0000ooooooooool0j_ooool2o`0000Gooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0003jooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0;3ooooo0_l0002>ooooo`009Oooool00ol0003oooooooooo`2`ooooo`;o0000C_ooool2o`0003ko
oooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oo
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`2Yooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0
ZOooool2o`0009Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000
:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0X_ooool2
o`0009cooooo000Tooooo`;o0000Y?ooool2o`0007Wooooo0_l0000Qooooo`009?ooool2o`000?oo
oooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0Voooool2o`000:?ooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0002S
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo09Cooooo0_l0002Zooooo`009Oooool2o`00073ooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000:[ooooo
000Uooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l0002booooo`009Oooool00ol0003oooooooooo`0:
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`000=Kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0I
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd0
0oooool01OlQ8B7oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03Oooool00on7QhOoEEEEooooo`02ooooo`05o`000?ooooooooooooooool0
0000UOooool009Wooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool0
2_ooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2Eoooo
o`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go8B4QohN7Qooo
ooooV9RHo`000003ooooo`05olc<c?l0003o0000o`000?o<c<`0UOooool009Oooooo00?o410@o`00
0?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000003
ooooo`05oa0@4?nj^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0:ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01Ol0003o^[Zjoooo
oonj^[[o000009Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?oo
ool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Eooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.04) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18194 Mdot
.04762 .24436 Mdot
.07143 .30013 Mdot
.09524 .30006 Mdot
.11905 .3 Mdot
.14286 .29993 Mdot
.16667 .29986 Mdot
.19048 .29979 Mdot
.21429 .29971 Mdot
.2381 .29963 Mdot
.2619 .29954 Mdot
.28571 .29944 Mdot
.30952 .29935 Mdot
.33333 .29924 Mdot
.35714 .29913 Mdot
.38095 .299 Mdot
.40476 .29887 Mdot
.42857 .29874 Mdot
.45238 .29854 Mdot
.47619 .29836 Mdot
.5 .2979 Mdot
.52381 .29559 Mdot
.54762 .2911 Mdot
.57143 .24794 Mdot
.59524 .14864 Mdot
.61905 .06683 Mdot
.64286 .02702 Mdot
.66667 .01174 Mdot
.69048 .00689 Mdot
.71429 .00619 Mdot
.7381 .00729 Mdot
.7619 .00942 Mdot
.78571 .01241 Mdot
.80952 .0163 Mdot
.83333 .02132 Mdot
.85714 .02786 Mdot
.88095 .03661 Mdot
.90476 .04892 Mdot
.92857 .06779 Mdot
.95238 .10135 Mdot
.97619 .18194 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0=_ooool2o`0000Gooooo0_l00006ooooo`;o0000Aoooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`2oooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0006;ooooo000Uooooo`03o`000?oooooooooo0;oooooo0_l0000K
ooooo`;o00001Oooool2o`0005_ooooo000Uooooo`03o`000?oooooooooo0>?ooooo0_l00005oooo
o`;o0000E?ooool002Gooooo00?o0000ooooooooool0j_ooool2o`0000Gooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0002iooooo`;o0000?ooo
ool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0;Sooooo0_l0000oooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`7o
oooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003oooooo`Wooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`So
oooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`2`ooooo`;o0000G?ooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0;3o
oooo0_l0001Looooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo
5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0002Zooooo`;o0000UOooool002Gooooo00?o0000oooooooo
ool0ZOooool2o`0009Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0000Cooooo0_l0002Mooooo`;o0000W?ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`2Rooooo`;o0000W?ooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0Voooool2o`000:?ooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0002Sooooo`00
9Oooool2o`0007oooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0002Zooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000:[ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00037ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo09?ooooo002Iooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0U?ooool009Wooooo
00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP0<ooooo`05oa0@4?ooooooooooooooool@
41000oooool5o`0009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRH
V?lQ8B7ok^k^00_ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`00
09Kooooo002Iooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool02_ooool01Ol0003o
oooooooooooooooo000000?ooooo00CogMgMoeEEEOoooooo0000U_ooool009Oooooo00?o410@o`00
0?l000000ol0000Mooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooooooooooooa0@4004
ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01[ooooo00Go0000okZj
^_ooooooV9RHoa0@400;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`00
002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool0UOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18205 Mdot
.04762 .24444 Mdot
.07143 .30021 Mdot
.09524 .30015 Mdot
.11905 .30009 Mdot
.14286 .30003 Mdot
.16667 .29996 Mdot
.19048 .29989 Mdot
.21429 .29982 Mdot
.2381 .29974 Mdot
.2619 .29966 Mdot
.28571 .29958 Mdot
.30952 .29948 Mdot
.33333 .29939 Mdot
.35714 .29928 Mdot
.38095 .29917 Mdot
.40476 .29905 Mdot
.42857 .29893 Mdot
.45238 .29879 Mdot
.47619 .29858 Mdot
.5 .29845 Mdot
.52381 .29755 Mdot
.54762 .29511 Mdot
.57143 .28599 Mdot
.59524 .22384 Mdot
.61905 .12216 Mdot
.64286 .05284 Mdot
.66667 .02193 Mdot
.69048 .01077 Mdot
.71429 .00774 Mdot
.7381 .00802 Mdot
.7619 .00987 Mdot
.78571 .01276 Mdot
.80952 .01662 Mdot
.83333 .02163 Mdot
.85714 .02815 Mdot
.88095 .03687 Mdot
.90476 .04915 Mdot
.92857 .06797 Mdot
.95238 .10149 Mdot
.97619 .18205 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l00017ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0<Kooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
001Rooooo`009Oooool00ol0003oooooooooo`36ooooo`;o00005?ooool2o`0000Gooooo0_l0001K
ooooo`009Oooool00ol0003oooooooooo`3Sooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03
o`000?oooooooooo0>[ooooo0_l00005ooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
_oooool2o`00033ooooo0_l0001=ooooo`009Oooool2o`000<3ooooo0_l0000hooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000ooooool9oooo
o`;o0000=oooool002Gooooo00?o0000ooooooooool0^?ooool2o`0004gooooo0_l0000gooooo`00
9Oooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooooaOo
oooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool2o`0008kooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0_l0002aooooo`;o0000S_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
002Zooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0ZOooool2o`0009Gooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`2Rooooo`;o0000W?ooool002Gooooo00?o0000ooooooooool0X_ooool2o`00
09cooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0002Sooooo`009Oooool2o`0008Kooooo
0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0002Sooooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`000:[ooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000`?ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00WOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooo
oooo09Kooooo002Mooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1oooool00ol0003oooooooooo`2Hooooo`00WOooool0
0ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00oooooo00?o0000ooooooooool0V?ooool0
09gooooo00?o0000ooooooooool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h03_ooool00ol0
003oooooooooo`2Hooooo`00WOooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00go
oooo00?o0000ooooooooool0V?ooool009_ooooo00?o410@o`000?l000000ol0000Mooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0V?ooool009gooooo00?o0000ooooooooool06_oo
ool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool0V?ooool009gooooo00?o
0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l00000
V_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.16) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18215 Mdot
.04762 .24452 Mdot
.07143 .30029 Mdot
.09524 .30023 Mdot
.11905 .30018 Mdot
.14286 .30012 Mdot
.16667 .30006 Mdot
.19048 .29999 Mdot
.21429 .29992 Mdot
.2381 .29985 Mdot
.2619 .29978 Mdot
.28571 .2997 Mdot
.30952 .29961 Mdot
.33333 .29952 Mdot
.35714 .29943 Mdot
.38095 .29933 Mdot
.40476 .29922 Mdot
.42857 .2991 Mdot
.45238 .29898 Mdot
.47619 .29884 Mdot
.5 .29863 Mdot
.52381 .29851 Mdot
.54762 .29702 Mdot
.57143 .29455 Mdot
.59524 .27645 Mdot
.61905 .19648 Mdot
.64286 .09912 Mdot
.66667 .04221 Mdot
.69048 .01864 Mdot
.71429 .01077 Mdot
.7381 .00928 Mdot
.7619 .01051 Mdot
.78571 .01318 Mdot
.80952 .01696 Mdot
.83333 .02193 Mdot
.85714 .02842 Mdot
.88095 .03712 Mdot
.90476 .04936 Mdot
.92857 .06815 Mdot
.95238 .10161 Mdot
.97619 .18215 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0<gooooo0_l00006ooooo`;o00001Oooool2o`0006;ooooo000U
ooooo`03o`000?oooooooooo0<gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0001K
ooooo`009Oooool00ol0003oooooooooo`3Sooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03
o`000?oooooooooo0<Kooooo0_l0000Rooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0
a_ooool2o`0002Wooooo0_l0001=ooooo`009Oooool2o`000?;ooooo0_l00006ooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0_ooo
ool2o`0007oooooo000Uooooo`03o`000?oooooooooo0;oooooo0_l0001oooooo`009Oooool2o`00
0?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oo
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo
00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000^Oooool2o`0008Kooooo000Uooooo`03o`000?oooooooooo0;So
oooo0_l0001Looooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000
:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0;3ooooo0_l0002>ooooo`009Oooool2o`00
0;7ooooo0_l0002>ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`2Yooooo`;o0000UOooool002Gooooo
00?o0000ooooooooool0ZOooool2o`0009Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0:;ooooo0_l0002Looooo`009Oooool2o`0008gooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0002Looooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l0002Sooooo`009Oooool00ol0003oooooooooo`0:
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0002i
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_lQ8B45
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o410@olc<c9Gooooo002Iooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005oooo
o`;o8B4Q1oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40UOooool0
09Wooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP0?ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00002Eooooo`00VOooool00ol0003oooooooooo`0;oooo
o`Ko00002oooool00onHV9So8B4Qonk^kP0>ooooo`03o`000?oooooooooo00;ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo
00gooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<09Gooooo002Goooo
o`03oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00?oEEEEohN7Qoooool0Uoooool009Wooooo00?o0000ooooooooool06_ooool01Ol0003o
^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool00ooMgMgo410@oiRHV02Goooo
o`00VOooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omE
EEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@49Gooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18224 Mdot
.04762 .2446 Mdot
.07143 .30036 Mdot
.09524 .30031 Mdot
.11905 .30026 Mdot
.14286 .3002 Mdot
.16667 .30014 Mdot
.19048 .30008 Mdot
.21429 .30002 Mdot
.2381 .29995 Mdot
.2619 .29988 Mdot
.28571 .29981 Mdot
.30952 .29973 Mdot
.33333 .29965 Mdot
.35714 .29956 Mdot
.38095 .29947 Mdot
.40476 .29937 Mdot
.42857 .29927 Mdot
.45238 .29915 Mdot
.47619 .29904 Mdot
.5 .29888 Mdot
.52381 .2987 Mdot
.54762 .29845 Mdot
.57143 .29641 Mdot
.59524 .29331 Mdot
.61905 .26146 Mdot
.64286 .16826 Mdot
.66667 .08005 Mdot
.69048 .0345 Mdot
.71429 .01689 Mdot
.7381 .01168 Mdot
.7619 .01155 Mdot
.78571 .01374 Mdot
.80952 .01735 Mdot
.83333 .02224 Mdot
.85714 .0287 Mdot
.88095 .03736 Mdot
.90476 .04957 Mdot
.92857 .06831 Mdot
.95238 .10173 Mdot
.97619 .18224 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0=Gooooo0_l00005ooooo`;o0000H_ooool002Gooooo00?o0000
ooooooooool0eOooool2o`0000Gooooo0_l00005ooooo`;o0000Foooool002Gooooo00?o0000oooo
ooooool0cOooool2o`0001Cooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000oooooooo
ool0cOooool2o`0001_ooooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`3aooooo`;o0000
COooool002Gooooo0_l0003booooo`;o0000COooool002Gooooo00?o0000ooooooooool0nOooool2
o`0004Gooooo000Uooooo`03o`000?oooooooooo0<Kooooo0_l0000aooooo`;o0000AOooool002Go
oooo00?o0000ooooooooool0a_ooool2o`0003Sooooo0_l0000nooooo`009Oooool00ol0003ooooo
ooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003oooooo`Wooooo0_l0000goooo
o`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo
3oooool2o`00033ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`2o
ooooo`;o0000Ooooool002Gooooo00?o0000ooooooooool0_oooool2o`0007oooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002So
oooo000Uooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0
003ooooood;ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`2hooooo`;o0000Q_ooool002Gooooo00?o0000ooooooooool0^?ooool2o`0008Kooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Toooo
o`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Loooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2`ooooo`;o0000S_ooool001[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo0_l0002>ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`2Yooooo`;o0000UOooool002Gooooo0_l0002Eooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o0000UOooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0009cooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0002b
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_lQ8B44
ooooo`Go00000oooool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Eooooo`00VOooool00ol0003ooooo
ooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00gooooo00?oV9RHob4Q8Oo^k^h01Oooool00onHV9So8B4Q
onk^kP2Fooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^
kP0=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0UOooool009Wooooo00?o0000
ooooooooool07Oooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMg
ofIVI_ooool0U?ooool009Oooooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Cooooo`00VOooool00ol0003o
ooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0003oooooooooo`0J
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c02Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.28) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18232 Mdot
.04762 .24467 Mdot
.07143 .30043 Mdot
.09524 .30038 Mdot
.11905 .30033 Mdot
.14286 .30028 Mdot
.16667 .30022 Mdot
.19048 .30017 Mdot
.21429 .30011 Mdot
.2381 .30005 Mdot
.2619 .29998 Mdot
.28571 .29991 Mdot
.30952 .29984 Mdot
.33333 .29976 Mdot
.35714 .29968 Mdot
.38095 .2996 Mdot
.40476 .29951 Mdot
.42857 .29941 Mdot
.45238 .29931 Mdot
.47619 .2992 Mdot
.5 .29909 Mdot
.52381 .29891 Mdot
.54762 .29878 Mdot
.57143 .29823 Mdot
.59524 .29586 Mdot
.61905 .29024 Mdot
.64286 .24112 Mdot
.66667 .14144 Mdot
.69048 .06498 Mdot
.71429 .02928 Mdot
.7381 .01647 Mdot
.7619 .01347 Mdot
.78571 .01461 Mdot
.80952 .01784 Mdot
.83333 .02259 Mdot
.85714 .02897 Mdot
.88095 .03759 Mdot
.90476 .04976 Mdot
.92857 .06847 Mdot
.95238 .10185 Mdot
.97619 .18232 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0g?ooool2
o`0000Gooooo0_l0001Kooooo`009Oooool00ol0003oooooooooo`3Eooooo`;o00001Oooool2o`00
00Gooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0eOooool2o`0001?o
oooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0
003booooo`;o0000COooool002Gooooo00?o0000ooooooooool0cOooool2o`0002[ooooo0_l00015
ooooo`009Oooool00ol0003oooooooooo`3=ooooo`;o0000:_ooool2o`0004Gooooo000Uooooo`03
o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo
0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo2Oooool2o`0003Oooooo000Uooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0<Kooooo0_l0001hooooo`009Oooool00ol0003o
ooooooooo`36ooooo`;o0000A_ooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo
3oooool2o`00033ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo
00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0;oooooo0_l0
001oooooo`009Oooool00ol0003oooooooooo`2oooooo`;o0000Ooooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Cooooo0_l0003ooooo
ob3ooooo0_l0000Qooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0002cooooo`;o0000Q_oo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Loooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`2`ooooo`;o0000S_ooool002Gooooo00?o0000oooooooo
ool0/?ooool2o`0008kooooo000Uooooo`;o0000Xoooool2o`0000Gooooo0_l0002Eooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0009Gooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2
o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2
o`000:?ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool2
ob4Q8@Cooooo1Ol00003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0UOooool009Wooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q
09Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03Oooool00onHV9So
8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool00000UOooool009Wooooo00?o0000oooooooo
ool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h03Oooool00onHV9So8B4Qonk^kP03ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S80UOooool009Wooooo00?o0000ooooooooool07Oooool00omgMgOo
IVIVooooo`0=ooooo`03ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c02Eoooo
o`00Uoooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool03Oooool02Ol0003o
oooooooooooooooo410@okZj^_oooooo^[Zjoa0@402Eooooo`00VOooool00ol0003oooooooooo`0J
ooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00Go0000okZj^_oooooo^[Zjo`00002Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@2Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.34) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18241 Mdot
.04762 .24474 Mdot
.07143 .30049 Mdot
.09524 .30045 Mdot
.11905 .3004 Mdot
.14286 .30035 Mdot
.16667 .3003 Mdot
.19048 .30025 Mdot
.21429 .30019 Mdot
.2381 .30013 Mdot
.2619 .30007 Mdot
.28571 .30001 Mdot
.30952 .29994 Mdot
.33333 .29987 Mdot
.35714 .2998 Mdot
.38095 .29972 Mdot
.40476 .29963 Mdot
.42857 .29955 Mdot
.45238 .29945 Mdot
.47619 .29935 Mdot
.5 .29924 Mdot
.52381 .29913 Mdot
.54762 .29894 Mdot
.57143 .29886 Mdot
.59524 .2978 Mdot
.61905 .29537 Mdot
.64286 .28392 Mdot
.66667 .21675 Mdot
.69048 .11763 Mdot
.71429 .05361 Mdot
.7381 .02618 Mdot
.7619 .01725 Mdot
.78571 .01617 Mdot
.80952 .01857 Mdot
.83333 .02302 Mdot
.85714 .02928 Mdot
.88095 .03783 Mdot
.90476 .04995 Mdot
.92857 .06862 Mdot
.95238 .10196 Mdot
.97619 .18241 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3Looooo`;o00001Oooool2o`0000Gooooo0_l0001Doooo
o`009Oooool00ol0003oooooooooo`3Looooo`;o00001Oooool2o`0000Gooooo0_l0001Dooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0003Fooooo`;o00006_oo
ool2o`0004gooooo000Uooooo`03o`000?oooooooooo0=Gooooo0_l0000Rooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?oo
oooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0<go
oooo0_l0000hooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0cOooool2o`00077ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0
oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0a_ooool2o`0007Sooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
a_ooool2o`0007Sooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qoooo
o`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0_oooool2o`0007oooooo000Uooooo`03o`00
0?oooooooooo0;oooooo0_l0001oooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0;Sooooo0_l00026ooooo`009Oooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`2`ooooo`;o
0000S_ooool002Gooooo0_l0002Zooooo`;o00001Oooool2o`0008kooooo000Uooooo`03o`000?oo
oooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000UOoo
ool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2
o`0009cooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool2
ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o000000?o410@ooooooooool0Tooo
ool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^013ooooo
00Co0000oooooooooooooooo1Ol0002Eooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko0000
2oooool00onHV9So8B4Qonk^kP0>ooooo`03ojVYZOl@413ooooo00;ooooo00CoA4A4omgMgOoooooo
0000U_ooool009Wooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`0<ooooo`03oa0@
4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000U_ooool009Oooooo00?o410@o`000?l00000
0ol0000Mooooo`03o`000?oooooooooo00cooooo00?o^[Zjob4Q8Oooool00oooool00omgMgOoc<c<
o`00002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
2oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000U_ooool009Wooooo
00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18249 Mdot
.04762 .24481 Mdot
.07143 .30055 Mdot
.09524 .30051 Mdot
.11905 .30047 Mdot
.14286 .30042 Mdot
.16667 .30037 Mdot
.19048 .30032 Mdot
.21429 .30027 Mdot
.2381 .30022 Mdot
.2619 .30016 Mdot
.28571 .3001 Mdot
.30952 .30004 Mdot
.33333 .29997 Mdot
.35714 .2999 Mdot
.38095 .29983 Mdot
.40476 .29975 Mdot
.42857 .29967 Mdot
.45238 .29958 Mdot
.47619 .29949 Mdot
.5 .29939 Mdot
.52381 .29929 Mdot
.54762 .29917 Mdot
.57143 .29898 Mdot
.59524 .29887 Mdot
.61905 .29723 Mdot
.64286 .29465 Mdot
.66667 .27313 Mdot
.69048 .19053 Mdot
.71429 .09768 Mdot
.7381 .04553 Mdot
.7619 .02491 Mdot
.78571 .01919 Mdot
.80952 .01985 Mdot
.83333 .02364 Mdot
.85714 .02965 Mdot
.88095 .03809 Mdot
.90476 .05015 Mdot
.92857 .06876 Mdot
.95238 .10206 Mdot
.97619 .18249 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0>?o
oooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0g?ooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`0004gooooo000Uooooo`;o0000gOooool2o`0001?ooooo0_l0
001=ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000oooo
ooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003ko
oooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0eOooool2o`0006Wooooo000Uoooo
o`;o0000e_ooool2o`00033ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`So
oooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0cOooool2o`00077ooooo000Uooooo`;o0000c_ooool2o`00077ooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo
5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2o`000?oo
oooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0a_ooool2o`0007Sooooo000Uooooo`03o`000?oooooooooo0<Kooooo0_l0001h
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000<3ooooo0_l0001oooooo`009Oooool00ol0003oooooooooo`2oooooo`;o
0000Ooooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool002Gooooo
0_l0002aooooo`;o00001_ooool2o`0008Kooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0008kooooo000U
ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
ZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000J
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_oo
ool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00WOooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo09Oooooo002Mooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`2Hooooo`00WOooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7o
k^k^00cooooo1Ol0002Iooooo`00WOooool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onH
V9So8B4Qonk^kP0;ooooo`04odA4A?oMgMgoooooo`0009[ooooo002Mooooo`03o`000?oooooooooo
01gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgoEEEEooooool0002Jooooo`00Voooool00ol@
413o0000o`000003o`0001gooooo00?o0000ooooooooool02_ooool00omgMgOoc<c<o`00002Joooo
o`00WOooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00oo^
k^koA4A4o`00002Jooooo`00WOooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03Oooool00omgMgOo0000ooooo`2Iooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The result is shown in Cell ",
  ButtonBox["7.65",
    ButtonData:>"Cell 7.65",
    ButtonStyle->"Hyperlink"],
  ". The effect of the localized source is to create a shock wave moving to \
the right. (Think of the source as an explosive release of gas.) The height \
of the shock wave is roughly 2.5 units, which depends on the strength of the \
source: if we define ",
  Cell[BoxData[
      \(TraditionalForm\`N(
          t) = \ \[Integral]\_0\%L\( f(x, t)\) \[DifferentialD]x\)]],
  ", then according to Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]N/\[DifferentialD]t\  = \ \
\[Integral]\_0\%\(\(L\)\(\ \)\)S \[DifferentialD]x\)]],
  ".  However, for this moving shock front, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]N/\[DifferentialD]t\), " ", "=", " ", 
          RowBox[{\(v\ \(f\_-\)\), " ", "=", 
            RowBox[{\(\(f\_-\)\^2/2\), Cell[""]}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_-\)\)]],
  " is the height of the shock, and in the second step we have used the \
Hugoniot relation, Eq. ",
  ButtonBox["(7.2.28)",
    ButtonData:>{"Chapter7.nb", "(7.2.28)"},
    ButtonStyle->"Hyperlink"],
  " . Thus, for this shock wave the height of the shock depends on the source \
in the following way: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\_-\)\^2/
          2\  = \ \[Integral]\_0\%\(\(L\)\(\ \)\)S \(\(\[DifferentialD]x\)\(\ \
\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            
            RowBox[{\(\[Integral]\_0\%\(\(L\)\(\ \)\)S \[DifferentialD]x\), 
              "  ", "\[TildeEqual]", 
              RowBox[{"3", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], " ", "\[Times]", "10"}]}], "=",
             "3"}]}], TraditionalForm]]],
  " for our source, we find ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_-\) \[TildeEqual] \@6 = 2.45 ... \)]],
  ", very close to the value observed in the simulation."
}], "Text"],

Cell[TextData[{
  "\tAlso, between times 0.6 and 2.4  the shock covers a distance of roughly  \
2 units, making the speed roughly ",
  Cell[BoxData[
      \(TraditionalForm\`2/1.8\  = \ 1.1\)]],
  ". This is close to the value of 1.25 expected from the Hugoniot relation, \
Eq. ",
  ButtonBox["(7.2.28)",
    ButtonData:>{"Chapter7.nb", "(7.2.28)"},
    ButtonStyle->"Hyperlink"],
  " . "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 7.2", "Subsubtitle",
  CellTags->"c:26"],

Cell[TextData[{
  StyleBox["(1)(a)",
    FontWeight->"Bold"],
  " According to the description by  Scott Russell, the length of the soliton \
that he observed was ",
  Cell[BoxData[
      \(TraditionalForm\`L = 30\ ft\)]],
  ", and the height was roughly 1.25 ft. Use these facts to determine the \
depth of the water in the channel . "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Predict the speed of the soliton using the results of part (a). How does \
your prediction compare to Scott Russell's observation of ",
  Cell[BoxData[
      \(TraditionalForm\`v\_lab = 8 - 9\)]],
  "miles per hour?"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Show that the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " in the potential function ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " is given in terms of the roots ",
  Cell[BoxData[
      \(TraditionalForm\`a, b, c\)]],
  " by \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`A\  = \ \(-\((a\ b\  + \ a\ c\  + \ b\ c)\)\)/6\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "  ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that ",
  Cell[BoxData[
      \(TraditionalForm\`E\  = \ a\ b\ c\ /6\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " The Boussinesq equations describe slightly dispersive shallow-water waves \
propagating both to the left and to the right, as viewed in the lab frame. \
These are coupled equations for the horizontal velocity of the fluid surface, \
",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  ", and the water depth ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, t)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, t) = h\_o\  + \ z(x, t)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`h\_o\)]],
  " is the equilibrium depth, and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is the wave height. The equations are"
}], "Text",
  CellTags->"i:32"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]h\/\[PartialD]t + \
\(\[PartialD]\/\[PartialD]x\) \((h\ u)\)\  = \ 
      0, \[IndentingNewLine]\[PartialD]u\/\[PartialD]t + 
        u\ \[PartialD]u\/\[PartialD]x + \ 
        g \[PartialD]h\/\[PartialD]x\  + \ \(1\/3\) \(h\_o\) \[PartialD]\^3 h\
\/\(\[PartialD]x \[PartialD]t\^2\) = \ 0. \)]]], "UNNEQ"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Linearize these equations, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " are small quantities, and show that the resulting linear equations \
describe waves with the following dispersion relation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ \(c\_o\^2\) 
          k\^2/\((1\  + \ \(k\^\(\(2\)\(\ \)\)\) h\_o\^2/3)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "To second -order in ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h\_o\)]],
  " this is  equivalent to Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  " . "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Defining ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_ = h/h\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\&_ = u/c\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_ = x/h\_o\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`t\&_ = t\ c\_o/h\_o\)]],
  ", the Boussinesq equations become"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]h\&_\/\[PartialD]t\&_ + \(\[PartialD]\/\
\[PartialD]x\&_\) \((h\&_\ u\&_)\)\  = \ 
      0, \[IndentingNewLine]\[PartialD]u\&_\/\[PartialD]t\&_ + 
        u\&_\ \[PartialD]u\&_\/\[PartialD]x + \ \[PartialD]h\&_\/\[PartialD]x\
\&_\  + \ \(1\/3\) \[PartialD]\^3 h\&_\/\(\[PartialD]x\&_ \
\[PartialD]t\&_\^2\) = \ 0. \)]]], "NE2",
  CellTags->"(7.2.32)"],

Cell[TextData[{
  "Show that steady solutions to these equations depending only on ",
  Cell[BoxData[
      \(TraditionalForm\`s = x\&_ - \ v\ t\&_\)]],
  "   are described by the motion of a particle with position ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`1/3\)]],
  " moving in a potential"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`V(h\&_) = \(-\(B\^2\/\(2\ h\&_\)\)\) + h\&_\^2\/2 - 
          1\/2\ h\&_\ \((2\ A + v\^2)\)\)]],
  ", "
}], "UNNEQ"],

Cell[TextData[{
  "and where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " are constants of integration, with ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " relating ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`u\&_\)]]]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_\)]],
  " through ",
  Cell[BoxData[
      \(TraditionalForm\`u\&_ = B/h\&_ - v\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that a soliton solution exists with ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_ \[Rule] 1\)]],
  "  as ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Rule] \(\(\[PlusMinus]\[Infinity]\)\(\ \)\)\)]],
  ", provided that ",
  Cell[BoxData[
      \(TraditionalForm\`A = 1\  + \ \((B\^2 - v\^2)\)/2\)]],
  ",  and find the particle energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " corresponding to this solution. Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(u\&_\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  "at ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(s \[Rule] \(\(\[PlusMinus]\[Infinity]\)\(\ \)\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " only if ",
  Cell[BoxData[
      \(TraditionalForm\`B = v\)]],
  ", which implies ",
  Cell[BoxData[
      \(TraditionalForm\`A = 1\)]],
  " for solitons."
}], "Text",
  CellTags->"i:33"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Show that the height ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_\)]],
  " of this soliton is related to the speed by ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_ = v\^2\)]],
  ".  Solve the equation of motion numerically on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < s < 4\)]],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`B = \(v = 2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A = 1\)\(,\)\)\)]],
  "and plot the form of this soliton solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&_\)(s)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\&_\)(s)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " The ",
  StyleBox["sine-Gordon equation",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"i:34"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          FormBox[
            RowBox[{
              RowBox[{
                
                RowBox[{\(\[PartialD]\^2 f\/\[PartialD]t\^2\), 
                  "-", \(\[PartialD]\^2 f\/\[PartialD]x\^2\), "+", " ", 
                  RowBox[{"sin", " ", "f", Cell[""]}]}], "=", " ", "0"}], 
              ","}], TraditionalForm]]]]], TraditionalForm]]]], "NE2",
  CellTags->"(7.2.33)"],

Cell[TextData[{
  "describes, among other things,  the motion of magnetic domains in a \
ferromagnetic material. Here, ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is proportional to the magnetization in the material, which changes \
rapidly as one moves from one magnetic domain to another.  The linearized \
version of this equation is the ",
  StyleBox["Klein-Gordon equation",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          FormBox[
            RowBox[{
              RowBox[{
                
                RowBox[{\(\[PartialD]\^2 f\/\[PartialD]t\^2\), 
                  "-", \(\[PartialD]\^2 f\/\[PartialD]x\^2\), "+", " ", 
                  RowBox[{"f", Cell[""]}]}], "=", " ", "0"}], ","}], 
            TraditionalForm]]]]], TraditionalForm]]]], "UNNEQ",
  CellTags->"i:35"],

Cell["\<\
which has applications in several areas, including particle and \
plasma physics. \
\>", "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Find the dispersion relation for the Klein-Gordon equation, and show that \
the waves are dispersive, with phase speed ",
  Cell[BoxData[
      \(TraditionalForm\`c = \(\[PlusMinus]\@\(1 + 1/k\^2\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Since the ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ f\)]],
  " term in the sine-Gordon equation causes both nonlinearity and dispersion, \
one expects that the equation has steady solutions, depending only on ",
  Cell[BoxData[
      \(TraditionalForm\`s = x - \ v\ t\)]],
  ". Show that such solutions do exist provided that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(v\)\(|\)\(\(>\)\(1\)\)\)\)]],
  ", and find the functional form of soliton solutions for which ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] 0\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Rule] \ \(+\[Infinity]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] \ \(\(2\)  \(\[Pi]\)\(\ \)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Rule] \(\(-\[Infinity]\)\(\ \)\)\)]],
  ". Show that the range in ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " over which ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " varies from ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(v\^2 - 1\)\)]],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`f(s)\)]],
  "."
}], "Text",
  CellTags->"i:49"],

Cell[TextData[{
  StyleBox["(5) ",
    FontWeight->"Bold"],
  "The nonlinear Schr\[ODoubleDot]dinger equation, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[ImaginaryI] \[PartialD]\[Psi]\/\[PartialD]t + \
\[PartialD]\^2 \[Psi]\/\[PartialD]x\^2 + \ 
          K\ \(\((\(|\)\(\[Psi]\)\(|\))\)\^2\) \[Psi]\)\(=\)\(0\)\(\ \
\)\)\)]],
  ", "
}], "NE2",
  CellTags->{"i:36", "(7.2.34)"}],

Cell[TextData[{
  "describes the evolution of a quantum wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " trapped in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = \(-K\)\ \((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`K > 0\)]],
  " this particle is attracted to regions of large probability density ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ", i.e. it is attracted to itself. This can lead to nonlinear steepening of \
the wave function, but this steepening can be balanced by dispersion, \
allowing steady solutions and solitons. This equation has applications in \
many areas, including",
  ",",
  " of course, quantum physics, as well as nonlinear optics (where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " is the electric field in a high-intensity wave moving through a nonlinear \
dielectric material). "
}], "Text"],

Cell[TextData[{
  "\tSolve for the steady solutions to Eq. ",
  ButtonBox["(7.2.34)",
    ButtonData:>{"Chapter7.nb", "(7.2.34)"},
    ButtonStyle->"Hyperlink"],
  " , and find the functional form of solitons for which ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \[Rule] \ 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]\[Infinity]\)\)]],
  " ."
}], "Text",
  CellTags->"i:50"],

Cell[TextData[{
  StyleBox["(6) ",
    FontWeight->"Bold"],
  "Analyze the steady solutions of Burgers' equation, Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  " . Show that these shock waves have the form given by Eq. ",
  ButtonBox["(7.2.27)",
    ButtonData:>{"Chapter7.nb", "(7.2.27)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Models of compressional shock waves in a gas require the solution of the \
",
  StyleBox[ButtonBox["Navier",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Navier.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["-",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Stokes",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Stokes.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" equations",
    FontSlant->"Italic"],
  ", coupled equations for the pressure ",
  Cell[BoxData[
      \(TraditionalForm\`p(x, t)\)]],
  ", velocity ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  "and  mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t)\)]],
  " of the gas.  The three  equations are the continuity equation for mass \
density,"
}], "Text",
  CellTags->"i:41"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[PartialD]\[Rho]\/\[PartialD]t + \(\[PartialD]\/\
\[PartialD]x\) \((u\ \[Rho])\)\  = \ 0;\)\)]]], "NE2",
  CellTags->{"i:37", "(7.2.35)"}],

Cell["the momentum equation,", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[PartialD]u\/\[PartialD]t + 
        u \(\[PartialD]\/\[PartialD]x\) 
          u\  = \ \(-\(1\/\[Rho]\)\) \(\[PartialD]\/\[PartialD]x\) 
          p + \[Eta]\ \ \(\[PartialD]\^2\/\[PartialD]x\^2\) 
          u\)\(,\)\)\)]]], "NE2",
  CellTags->{"i:38", "(7.2.36)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " is the  kinematic viscosity of the gas (units ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], "2"], "/", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "); and an equation of state relating pressure to density,"
}], "Text",
  CellTags->"i:77"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\  = \ p\_o\ \((\[Rho]/\[Rho]\_o)\)\^\[Gamma]\)]],
  ","
}], "NE2",
  CellTags->{"i:40", "(7.2.37)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] > 1\)]],
  " is the ratio of specific heats in the gas, and where ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " are the equilibrium values of the pressure and mass density respectively. \
(This model neglects thermal conduction for simplicity.)"
}], "Text",
  CellTags->"i:39"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Linearize these equations for small deviations from the equilibrium ",
  Cell[BoxData[
      \(TraditionalForm\`p = p\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Rho]\_o\)]],
  ", to show that sound waves propagate with a dispersion relation given by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ \(k\^2\)(
          c\_o\^2\  - \ \[ImaginaryI]\ \[Omega]\ \[Eta])\)]],
  ","
}], "UNNEQ",
  CellTags->"i:42"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o = \@\(\[Gamma]\ p\_o/\[Rho]\_o\)\)]],
  " is the speed of sound. Show that these waves damp exponentially due to \
finite viscosity, at a rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(\ \)\)\)]],
  "given by ",
  Cell[BoxData[
      \(TraditionalForm\`r = k\^2\ \(\(\[Eta]/2\)\(\ \)\)\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`k\ \[Eta] << \(c\_o\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Analyze steady shock-wave solutions to Eqs. ",
  ButtonBox["(7.2.35)",
    ButtonData:>{"Chapter7.nb", "(7.2.35)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.2.37)",
    ButtonData:>{"Chapter7.nb", "(7.2.37)"},
    ButtonStyle->"Hyperlink"],
  " , which depend only on the variable ",
  Cell[BoxData[
      \(TraditionalForm\`s = x - \ v\ t\)]],
  " (where ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is the shock speed). Show, for a shock moving to the right into still air \
where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Rho]\_o\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"u", "=", 
          RowBox[{"0", "at", 
            FormBox[\(x \[Rule] \ \[Infinity]\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ",   that the fluid velocity in the shock satisfies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\ \[PartialD]u\/\[PartialD]s = \(c\_o\^2\/\(\
\[Gamma] - 1\)\)[\((\[Rho]\/\[Rho]\_o)\)\^\(\[Gamma] - 1\) - 1] + \ \(1\/2\) 
            u\^2 - \ u\ v\)]],
  ","
}], "NE2",
  CellTags->"(7.2.38)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]/\[Rho]\_o = v/\((v - u)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the result of part (b) to derive the following Hugoniot relation:"
}], "Text",
  CellTags->"i:43"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(c\_o\^2\/\(\[Gamma] - 
                1\)\)[\((v\/\(v - \(u\_-\)\))\)\^\(\[Gamma] - 1\) - 
            1] + \ \(1\/2\) u\_-\%2\ \  - \ \(u\_-\)\ v = 
      0\)\(,\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)\)]],
  " is the velocity of the gas well-behind the shock."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Show that the shock always travels with speed  ",
  Cell[BoxData[
      \(TraditionalForm\`v > \ c\_o\)]],
  " and that ",
  Cell[BoxData[
      \(TraditionalForm\`v/c\_o\)]],
  " is an increasing function of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)/u\)]],
  ". (Hint: Scale ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " in the Hugoniot relation, and note that ",
  Cell[BoxData[
      \(TraditionalForm\`\((1\/\(1 - x\))\)\^\(\[Gamma] - 1\)\)]],
  "is an increasing function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".) \n",
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Analytically solve for the shock assuming it is ",
  StyleBox["weak, ",
    FontSlant->"Italic"],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`v\  \[Rule] \ c\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\__\) << \(c\_o\)\)]],
  ". Show that in this limit,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(u\_-\), "=", 
          
          RowBox[{\(\(\(4  c\_o\)\/\(\[Gamma] + 1\)\) \((1 - c\_o/v)\)\), "+",
             " ", 
            RowBox[{"0", 
              RowBox[{"(", 
                SuperscriptBox[
                  FormBox[\((1 - c\_o/v)\),
                    "TraditionalForm"], "2"], ")"}]}]}]}], 
        TraditionalForm]]],
  " ."
}], "UNNEQ"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u(
          s)\  = \ \(u\_-\)\/\(1\  + \ exp\ [\(\(u\_-\)(1 + \[Gamma])\)\ s/\ \
2  \[Eta]]\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 5/3\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_o\), "=", 
          RowBox[{"340", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"v", "=", 
          RowBox[{"360", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Eta]", "=", 
          RowBox[{"1.", " ", "\[Times]", \(10\^\(-2\)\), 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Roughly speaking, what is the width of the shock in meters? (Hint: \
Expand the Hugoniot relation and Eq. ",
  ButtonBox["(7.2.38)",
    ButtonData:>{"Chapter7.nb", "(7.2.38)"},
    ButtonStyle->"Hyperlink"],
  "  to ",
  StyleBox["second",
    FontSlant->"Italic"],
  "-order in ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)/v\)]],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Use the Galerkin method to numerically solve Burgers' equation with \
constant nonuniform forcing, in periodic boundary conditions, on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 20\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]f\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{"f", " ", 
              FractionBox[\(\[PartialD]f\), \(\[PartialD]x\),
                MultilineFunction->None]}], "-", 
            RowBox[{\(1\/10\), " ", 
              FractionBox[\(\[PartialD]\^2 f\), \(\[PartialD]x\^2\),
                MultilineFunction->None]}]}], 
          "=", \(\(2\/15\) e\^\(-\((x - 5)\)\^2\)\)}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 20\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "The forcing function on the ",
  "right-hand",
  " side describes an explosive local increase in temperature, pressure, or \
density. Take 13 Fourier modes (",
  Cell[BoxData[
      \(TraditionalForm\`M = 12\)]],
  "), and solve for",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0 < t < 25\)\)\)]],
  ". Note the formation of a shock front propagating to the right."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Use the CTCS method to solve the sine-Gordon equation ",
  ButtonBox["(7.2.33)",
    ButtonData:>{"Chapter7.nb", "(7.2.33)"},
    ButtonStyle->"Hyperlink"],
  " , in periodic boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`L = 10\)]],
  ". For the initial condition, take ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = \ 3\ \(sin(\[Pi]\ x/L)\)\)]],
  ". Integrate the result for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Use the CTCS method to solve the traffic flow problem ",
  ButtonBox["(7.1.43)",
    ButtonData:>{"Chapter7.nb", "(7.1.43)"},
    ButtonStyle->"Hyperlink"],
  " , taking ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = 0\)]],
  " (i.e. an initially empty freeway) with ",
  Cell[BoxData[
      \(TraditionalForm\`s = 1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " otherwise (i.e., there is an on ramp at this location, feeding cars onto \
the freeway at a constant rate). Take ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  "and use periodic boundary conditions on  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 10\)]],
  ", and integrate in time up to a time as close as possible to the formation \
of a singularity (the CTCS method will become unstable at some point before \
this time, depending on your choice of step size)."
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " A diffusive term is often added to the traffic flow problem in order to \
model diffusive spreading of the cars in the absence of nonlinearity (see for \
example, ",
  ButtonBox["Whitham",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ", Sec. 1.4). The equation now becomes"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \((c - 
                f)\) \[PartialD]f\/\[PartialD]x - \[Chi]\ \[PartialD]\^2 f\/\
\[PartialD]x\^2 = s\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Using the numerical method of your choice, redo the previous problem, \
taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\  = \ 0.2\)]],
  ". Solve the problem over the time interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 15\)]],
  ". Note the formation of a backward-propagating shock (a traffic jam, \
propagating back from the on ramp). "
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " Here's another numerical method for solving PDEs: finite-difference the \
spatial operator on a grid, and then solve the resulting coupled ODEs in \
time. These ODEs can be interpreted as the equations of motion for a system \
of coupled masses and springs, which provides us with another way of thinking \
about the problem. Consider, for instance, the following nonlinear PDE:"
}], "Text",
  CellTags->"i:86"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2 \[Eta]\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{\(c\^2\), " ", 
            FractionBox[\(\[PartialD]\^2 \[Eta]\), \(\[PartialD]x\^2\),
              MultilineFunction->None], 
            RowBox[{"(", 
              RowBox[{"1", " ", "+", 
                RowBox[{"\[Alpha]", 
                  FractionBox[\(\[PartialD]\[Eta]\), \(\[PartialD]x\),
                    MultilineFunction->None]}]}], ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Centered differencing of the spatial operator on a uniform grid of \
positions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", " ", "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " yields"
}], "Text"],

Cell[TextData[StyleBox[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          
          FractionBox[\(\[DifferentialD]\^2 \[Eta]\_j\), \
\(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{\(c\^2\), " ", 
            
            FractionBox[\(\[Eta]\_\(j + 1\) - 
                2\ \[Eta]\_j + \[Eta]\_\(j - 1\)\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{"(", 
              RowBox[{"1", " ", "+", 
                RowBox[{"\[Alpha]", 
                  FractionBox[\(\[Eta]\_\(j + 1\) - \[Eta]\_\(j - 1\)\), 
                    RowBox[{"2", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}]]}]}], ")"}]}]}], " "}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"           ", 
        RowBox[{"=", 
          RowBox[{
            FractionBox[\(c\^2\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{
              RowBox[{"(", " ", 
                
                RowBox[{\((\[Eta]\_\(j + 1\) - \ \[Eta]\_j)\), "-", 
                  "  ", \((\[Eta]\_j - \[Eta]\_\(j - 1\))\), "  ", "+", 
                  RowBox[{
                    FractionBox["\[Alpha]", 
                      RowBox[{"2", " ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}]], 
                    "[", \(\((\[Eta]\_\(j + 1\) - \[Eta]\_j)\)\^2\  - \((\
\[Eta]\_\(j - 1\) - \[Eta]\_j)\)\^2\), " ", "]"}]}], " ", ")"}], "."}]}]}]}], 
      TraditionalForm]}], "NumberedEquation"], "NumberedEquation"]], "NE2",
  CellTags->"(7.2.39)"],

Cell[TextData[{
  "These equations are the same as the dynamical equations for a series of \
masses of unit mass, at positions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_j\)(t)\)]],
  ", connected to nearest-neighbors by nonlinear springs with a nonlinear \
spring force vs. displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " of"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`F\  = \ \(-\ 
              k\)\ \[Eta]\ \  - \ \[Gamma]\ \[Eta]\^2\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "=", 
          RowBox[{\(c\^2\), "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"], " "}]}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Gamma]", " ", "=", " ", 
          RowBox[{\(c\^2\), \(\[Alpha]/2\), " ", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "3"]}]}], TraditionalForm]]],
  ".  In a famous ",
  ButtonBox["paper",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " from the early days of computational physics,  ",
  ButtonBox["Fermi",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/biography/Fermi.html"], None},
    ButtonStyle->"Hyperlink"],
  ", Pasta and Ulam (FPU, 1955) studied the behavior of this coupled \
mass-spring system. The authors were expecting that the nonlinearity of the \
system, combined with the many degrees of freedom, would result in chaotic \
dynamics that would lead to a thermal equilibrium state, where energy was \
shared equally between all degrees of freedom. Surprisingly, however, this is \
not what the authors observed. In this problem, we will repeat a portion of \
their work."
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  StyleBox[" (a)",
    FontWeight->"Bold"],
  " Use the molecular dynamics code in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:27"},
    ButtonStyle->"Hyperlink"],
  " (modified for 1-D motion and nearest-neighbor interactions) to solve Eqs. \
",
  ButtonBox["(7.2.39)",
    ButtonData:>{"Chapter7.nb", "(7.2.39)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  " masses, where ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ", with boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_0 = \(\[Eta]\_M = 0\)\)]],
  " (i.e., the end masses are fixed to walls).  For initial conditions take \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_j\  = \ sin\ \((\[Pi]\ j/M)\)\)]],
  " (i.e.,  all energy in the lowest normal mode of the linearized system), \
and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\& . \_j = 0\)]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 1/4\)]],
  ", integrate the equations for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1000\)]],
  ". Plot  ",
  Cell[BoxData[
      \(TraditionalForm\`2  j + \(\[Eta]\_j\)(t)\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " on a single graph for ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1,  ... , M - 1\)]],
  ".  (The ",
  Cell[BoxData[
      \(TraditionalForm\`2  j\)]],
  " is used to separate the different curves.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the following analysis on your results from part (a). FPU \
expected that the nonlinearity in the force would result in coupling between \
normal modes, and a cascade of energy to higher and higher Fourier modes, \
resulting in eventual energy equipartition where, on average, all modes have \
the same energy.  The amplitude of the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "th Fourier mode vs. time is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(a\_k\)(t)\  = 
        2\/M\ \(\[Sum]\+\(j = 0\)\%M\(\( \[Eta]\_j\)(
                t)\)\ \(sin(\ \[Pi]\ k\ j/M)\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1, 2,  ... , M - 1\)]],
  ". "
}], "NE2",
  CellTags->"(7.2.40)"],

Cell["\<\
The energy in a normal mode (neglecting the nonlinear terms) is \
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`\(E\_k\)(
                  t)\  = \(1\/2\) \((a\& . \_k)\)\^2 + \(1\/2\) \
\(\(\[Omega]\^2\)(k)\)\ \((a\_k)\)\^2\)]]]], " "}], TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\^2\)(k) = 
        4\ \(sin\^2\)[\[Pi]\ k/\((2\ M)\)]\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`frequency\)]],
  " squared of these normal modes. [See Eq. ",
  ButtonBox["(4.2.30)",
    ButtonData:>{"Chapter4.nb", "(4.2.30)"},
    ButtonStyle->"Hyperlink"],
  " .] Evaluate these mode energies  and plot them versus time to show the \
spectral distribution of mode energies. Is energy being shared equally among \
these modes?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  What do you think would happen if we used this technique on the KdV \
equation? Would energy be shared equally among the modes?"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3 The Particle-in-Cell Method", "Subtitle",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"i:55", "c:27"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["7.3.1 Galactic Dynamics", "Subsubtitle",
  CellTags->"c:28"],

Cell[TextData[{
  "\tOur galaxy is a good example of a nearly collisionless (ideal) gas. The \
\"particles\" in this gas are individual stars (see Fig. ",
  ButtonBox["7.9",
    ButtonData:>"Fig. 7.9",
    ButtonStyle->"Hyperlink"],
  "). Although these stars interact via the gravitational force,  for \
individual pairs of stars the interaction potential energy is, on average,  \
very weak compared to the  kinetic energy of typical stars, and so these \
binary interactions can be neglected to  lowest approximation. This can be \
seen using a simple order of magnitude estimate. The average speed of a star \
in the galaxy is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`v \[TildeTilde] 100\)]],
  " km/s. This gives a kinetic energy for a solar mass star of  ",
  Cell[BoxData[
      \(TraditionalForm\`K = \(m\ v\^2/2\  = \ 10\^40\)\)]],
  " joules.  However, the average distance between stars is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`d\  = 1\)]],
  " light year (somewhat more near the edge of the galaxy, less near the \
center).  This gives an interaction potential of ",
  Cell[BoxData[
      \(TraditionalForm\`U = \(\(G\ m\^2/
              d\)\(\ \)\(=\)\(10\^34\)\(\ \)\)\)]],
  "joules, so ",
  Cell[BoxData[
      \(TraditionalForm\`U/K\ << 1\)]],
  " . The typical gravitational interaction between stellar pairs is \
negligible compared to the stars' kinetic energy. "
}], "Text",
  CellTags->"i:76"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<Z0003:R000`400?l00000o`00003ooooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooo
ooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oo
ooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`006oooool04P0;2@X03@/<00`:
2`0B41405aDF00/92P0=2``03`d>00h<3@0=2``03P`=014?40081P/03@/@010>4`0B41D03`dB00L5
2P802`T>00`02PP=00h<4@0?3A8030X=00l:3@0=2@X030P900d92P0@30d04@d>010<3@0B3Pl200X6
1`0300T51P0@30d05A4@00805A4@00D02`L601hJ6@0:1PD030P700X61@0200`81`0;00l;2P0D40l0
3`/:00h:2@0<20L03@T8018>3@0E4A004@d<00d9200<20L00P0>2PT06@0>2PX05A4B014=3P0?30`0
4Ph?00d92P0;20P02@D600/7200A3@h040`=014=3P0D3a005Q0B018>3`0?2``03PX;00/92P0:20T0
3P`=020P800b<S804A4A00D51@0=30d00`0;2@X00`0<2P/03P`=00`:2`0200/92P0900`:2`0;2@X0
2`T:00`:2`0>30d040h?014?400@3Pl02`T:00803@/<018030X;00X82@0:20T02@L800T72P0J61/0
2@L:01PF6@0100803@/>01LE601>C4l07Q`O018@4`0G5AP01`D800X82@0;2@X200h<3@0;00d;300;
2@X00`42018@4@081PL04@l@00/92P091`P01`D600T7200>30d00P0@3Pl0100>30d03@/<014?4007
1@H200l=3P0?00h<3@0>31404A0D0040100E4aP02PP=01<A5P0<2Pl03`dB00X83@071@X02@L<00`:
3`060`X03@XA008030T@00@08AhU00D22@0;20l02`P?0P0<2A0200d:4@0>00`:3`0;2@h03@/@00h<
4@0=2a002@L<00/93P0:20d020H;00L52P0:20d03@/>00h<3P0?3@h2014?400>00`:2`091`P030X;
00X82@071@H03P`=0040000P7Ql030/=01@B5@0=2`h030X=01dK7P01008600`:3@0400X83@0:1`h0
2PL>00X74P802PHD00/02`LE00T64@0:1a002`P?00d;400?3A0020H700`:2`0M6ad05A<F00`:3`02
00d;400<00/83`091Pd02PL>00X73P0<2A8030TD00P5400710h02@H?00d:4`0>2a<030T@100<2Pl0
2P0<2A00514J03Tf?`0]:S802`P?01@A600:20h030X?00`:3@0;2@`200X82`0=00401@0F4aX02@H=
01dJ8@0T8BP02PP>01DB6@050PT02PL>00H32P091Pd030X@00`73@0200d8300B00/62P0<1`/04`hB
05IAE@0P6al03@P<00h93@0<1`/03`X>00`:3@0:20/020H901LE600B41<01`D800`:3@0=2`h03`d@
0P0<2Pd03`0>30l040dD00D32@0B3aH02PL>00T63@0C41L01P<:02PU;00B3aH00P0600`9400=2a00
2@L:00T7200200X82@0:00/92P0<2P/01P@500L51P0=2``02`T:00L51P0?3@h030P900X61`8020@5
00T02PH700`82@0K5aP02@D600D10P0B3Pl020@5010<3@091@H00P0>2P/0100<20T03PX;014=3P0?
2``200d92P0800/720070`@0100100`82@091@H020@500X61`0=2@X200h:2`0300`82@0;1`P02PH7
00802PH700P020@500/720050@803@T:00l;30050@803@T:00`82@802@D600<04@d>01LC500<20T0
100<20T02P0=2@X03PX;01<?400F4Q<03PX;00d92P0>2P/02PH700/7200>2P/200`82@0300l;300>
2P/02`L800802PH70P091@H0300;1`P03@T:00h:2`0=2@X02`L800`82@0H51D07QXK010<3@070`@0
2`L800d82`D02PD900@02`H:00`72`0<1`/02`H:0P0:1@T01P0?2Q403PT@00/63@0910/02PD<00`7
3P803PT@00@02PD<00`73P0?2Q402@@;1P0<1Q001P0?2A<03@LA00/53`0@2Q@01P0:00d74@H030L>
01X03PT@00T42`0<1`h04@`C00/63@0<1`h03@/@00X93P0920h02PPC00T84`0411001`LC00h?6P0L
7bH0=3Ln00/=4@020`L02PP=00h93`0910X03PT?00T52P0A31802PD;00/6308030L=00P02`H<00X5
2`0:20/01`D801<A500<2Pd01P@700@21@8020H900d01P@700d;3P040`D04@lB00l:3P0=20`030L;
00/62P0:1@T02@@800d8300;1PX030L;00803`X>00H03@P<00d;3P030@@02PP;01@B5@071@P300`:
3@802`T<0P0:20/08`0?2Q0030L=00`73@0?2Q403PPB00d74@0;1@l02`H=00`73P0>2@l03`X@010;
4P0?31H03P/D00d:4`0;21402PL>00P52`0>31404Q0C00d;3@0>30d04Q0A00h<3`040PL02PP=00d;
40071@X09R@Y07ajO`0M6b000`4600P62`0C4AH020H;00802PP=01002@L<00`:3`0?3A803`dB00d;
400@3Q<04a4F014?500E4aP040hC00`:3`040PL03`dB00h<4@0H5Q/04PlF0`0:1a0200X74P0300X7
4@0:1a002`P?008030T@0P0;20l00`0?31<03P/B00d:4@0200`9400@00d:4@0:1a002`PA00d:4`0<
2A002`P?00X73P0>31401P@900`:3@0>30l05Q@G00L6200<1`d03@P>00l:4@803`TC00P03@LC00<0
1`0E3aP040/A00/6300A3@l03PX;00/62P804@`@00D050lC00/62P0C3Q8040/?00l:3P0200h93@0E
00l:3P0@2`l040/?00l:3P0=20`03PT=010;3`0A31003@P<010;3`0;1PX03@P<01<>4P0>2@d04@`@
010;3`0=20`02`H:00h93@0C3Q803@P<00<03`X>00H040/?014<400A31003PT=00`72`0;1PX200`7
2`803`X>0P0@2`l0400?2Ph03PX;00`8200@2`l02PD900`83P0K5Al01`4;014;500A31<03@P<010<
2`0C3``040`901<=3P0G4A<200l92`0V01<=4@0<1PX03PP<00d63@0>1`h03`P?00T22P0F41D030H8
00X41P0=1`T050h@01LA4`0>20X01@0101hH6P0=1`T08A/M00@0000=20T030H800d72@0C3@l02P@6
01hH700Y8bL02@<700D01@0H4AP01`0701D>5P0=1`d05Q0D00d72`0=20/03`T=01D?4`090`L200`6
2P0400d72`0<1PX02`D900h52PP040D;00/03`@:00h32@0>0`T0304701873@0>10T02`0601<83P0<
0`L03P<900l42P0201052`803`@:00T03P<;00d22P0=0PX03@8:00h32`0@1@d03`@<00h32`0?10`0
0P0A1Ph01`0>0`/03`<=00h2300>0P`03@4;00h2300?0`d00P0=0@/200h230803`<=00`01`040187
3`0<0@T0304901D:4P0=0PX04@H>00/1200>0`/040D=00`12@0;00PDooooo`006oooool03P0<2P/0
3`d>00d;300>30d03`d>00P61`0@3Pl030X;00/92P0=2``03P`=00`:2`0?3A0030X>0P0:20`0200=
2`l03`dA00`:3P0:20`02@L;00d;3`0<2Ph02`T<0`0>2P/200l;300=010<3@0?2``020@501<?400P
71d03@T:00`82@0>2PT03@T801<?3P0<20L040`;018>3@0200d9200<014=300?2`X03@T800l;2P0;
1`H03PX900l;2P0>2PT03`/:010<2`0>2PT03@T80P0?2`X0700;1`H02`L700/7200@30d0510A00D1
0P070`@0510A01LC500@30d03@T:00l;300;1`P03@P900`6200;1`P03@T:00l;300?3@h04@l@00H4
1@0<30`0410@00H61P0:2PX02`X;00/92P0<2P/300d;300300`:2`0;2@X030X;008030X;00L02`T:
00d;300=2``03P`=010>3`0?3@h02`T:00803@/<018030X;00/92P0:20T02PP900/930061@L0G5YM
020N8@0<2Pd03`d@00@21@0G5AP02@L:00d;3P0;2@`030X=00`:2`0=2``200l=3P0700h<3@0=2``0
928S02XX:@0>30d02`T:00H41@0200`:2`0400d;300?3@h03`d>00`:2`802PP901L03P`=00`:2`0@
3Pl01`D600l=3P0:20/03@/?00`:3P0?3A403P`@00H4200:20`03@/?00h<400=2`l03`dA01<A5@0?
3A<02`P>010=4`081@/08QlU01PF700200/93`8030X@00P03@/A00d;400<2Pl02`T=00d;3`0>3100
3@/?00X830@02`T=00<03`dA01<A500>30d00P0:20T03`0;2@X02PP900T7200>30d03`d>00L51P0:
20T05A<D0490@@0Y9bX01@<600T72P0?3A003@/>00l=400600/9300400X8300:20h02PL>00X74@80
2PLC01T03P/F00`9500<2A4030X?00d;400?3A001`D700H41P0A3a803@/>00X83@0?3A801@<800T6
3@0P7B@05Q<J00/8400A3QP04a0K010=600>2aD03@XC00h;500>2a<03@XA00@03@/@00T03P`C00L4
3@0E4Q/03``D00L42`0A3QD02@L=00`:3`0<2Pd00P0;2@`0400:20/040hC00L52P0:1`d030/@00h<
4P0<2@l01P@9010>500=2Q00=c@j01LD6P0:20d030L;00d8300>2@d200`72`0400l:3P0@30l030L;
00`72`804@`@01X03PT=00P72@0920X03`d@00/9300920X040hA00T72P0;2@`030X=00X82`091`X0
2`T<00/93P0>2a407A/Q06]XKP0;20h0;b`b05=@EP0B3aD04a4F00l<4P0;2@l020H;00P62@802@L8
00T02PP900/92P0;2@X02@L800X82@0?3@h03@/<00P61`0;2@X01P0<20T00`0=2@X03`/<00/72002
00d92P802@D601402`L800`82@0<20T02PH700T51P0;1`P02PH700`82@0>2P/030P900X61`0>2P/0
30P900/7200<20T03`/<010<3@0200/7200:00X61`0<20T03@T:00d92P0E4A8071PI014=3P0:1PL0
3PX;00d92P8030P900@02`L800d92P0C3a005a<D0P0=2@X400`82@802PH700d03@T:00X61`0:1PL0
2`L800T51P0:1PL030P900d92P0>2P/03@T:00/720091@H030P900803`/<00<030P900/7200<20T0
0P0<20T0200;1`P030P900h:2`0=2@X02@D600`82@0;1`P02@D71@0:1@T00`0;1PX030L;00`72`02
00/62P0800X52@0<1`d03`XA018=4`0=20h02`H<00`73P080`T200/6300300X5300>2@l03PT?00H0
30H@00L0208<00X43P0C3AL08adW01H@6P070P/030L>00D030L=00@030L>00P32P0:1@`03PT?0P0:
1@/04`0810X02`L=00P6300610d03P/G01PG8`1EE60061PS09RJX@33aLX06A/P00H72`081P/030L=
00D01P0<1`d02PH;00h93`0;1P`0100<1`d0100;1P`0108500X82`061@L200X82`0900h<3`0?3A00
2`T<018@4`061@L030X=00L5200>2@d03@P<00<030L;00@02`H:00h93@0;1PX030L;0`0?2Ph02P0;
2@`01P@700d;3P0B41<01`D800X82`0<2Pd02`T<00X82`091`X200P62@05010<4P0>2Q003PXA010<
4`0@2aD00P0?2Q@01P0=2A0030P?00`83P0<20h030P?00/84P<02`PA00P02`P?00/83P0;2@h02`T<
00d;3@0D4Q<04a4B00l=40802@L<00`02PP=00D4200:20d06aTN00<21P0B41D01`D:00l=4P061@T0
3@/@010>4`0=2a0200/93P802@L<00/02`T>00h<4@0=2a002@L<00P62`0;2@h071XO03Pf>`0R82D0
30X?01DB6@0300d:4`803@XE00<03@XD00/84@0;20l00`0<2A0200/83`0D00X73P0;20l030T@00h;
4P0@3A@030TB00d:4`0?31D03``C00h;4P0=2Q403`dB00X83@0?3A0020H900T72P0=2`h03PT>00l:
3`0@2a82010:500?00l95@0<2100;BL`03Lb>00E41H03PX<01DA4P0<1`/04PdA01PC5`0P6al04PdA
00h93@0=20`03`X>00804@`@00<03`X>00d8300@2`l00P0@2`l0300B3A405A0D01LB5P0=20`04`hB
00l:3P0=20`04@`@010;3`0;1PX03`X>010;3`<03`X>00<03@P<00l:3P0?2Ph00P0?2Ph00`0@2`l0
4PdA010;3`0400h93@803`X>0P0@2`l0400?2Ph03PX;014=3@0A31003`X>00h9400<1Q003@PA00d8
400<1`d040/?00h:2P0;1`@03PX701@>3`0H4Q@200l92`0D014;3`0<1PX04P`@01<<4`0<1@`050dD
00X32`0>20d04@/=01PB500A2`d03`T;014;3@0;1PL0618D03H`<P0D3Q004@/=00H10P0D3Q0200/5
1`0@014;3@0:1@H02`D901@>4P070PD050dD00`6300=1Pd06A8J00h83P0=1`/01`45014<3`070PD0
5@lC00`62P803PP<00@03@L;00`62P0<1PX03PD:200@1@/200l42P0900h32@0B1`d03`@:00`11`0=
0PP03`@:01052`0>0`T03`@:008040D;0P0?10X03@0>0`/03@8:00d22P0=0PX03P<;01053@0;0@P0
3@8:00h32`0=0PX03P<;01463P0?0`d00P0>0P`0100=0@/03P8<00l33@0=0@/300h230803`<=00`0
3@8:00h32`0?10`03`@<00d32P0900H02P0700d22P0A1Ph03`@<00X01`0?10`Dooooo`006oooool0
4`071@H02`T:00X82@0:20T030X;00h<3@0M6a`05A<D014?400C4A804@l@00X82@0>30l03`d@018@
4`0@3Q402PP;00/9300B41<00P0=2`h0700?3A003P`?00l=400=2@X03`/<010<3@0A3@h03`/<00h:
2`0B3Pl04@d>010<3@0D41403@T:01<?400:1PD030P700/71P091@@01P8101<?3P0<20L02@D400d9
200>2PT03@T800l;2P0;1`H200l;2P0300h:2@0?2`X04@d<008030P701P03PX9014=300?2`X03@T9
018>3`0A3@h03`/<01`H6@0J5QL03`/<01dI6P0>2P/09R8S04A0@@0T82404Pd?018<3P0A3@h03`/<
00d92P0<2P/03P`=00D3100@410200/;2`0601PH600920T02`T:00d;300?3@h03@/<0`0;2@X01`0<
2P/03@/<00`:2`0;2@X030X;00/92P0<2P/00P0>30d01@0:20T03@/<00d;300=2``030X;00802`T:
00d040hA00/9300?3Q0040hA00X82`0>30l04a4D00P62@0=2`h03P`?00X82`0>30l02@L800D02PP9
00H04@l@01`J6`0;2@X040h?00d;300@3Pl300h<3@0A00d;300:20T020H700T7200:20T04@l@01DC
500<2P/08R0Q01TG6P071@P02`T<00`:3@030P@04@lB00/9300:20/00P0<2Pd020091`X030X=00/9
3P0=2a009R@Y018@5@0@3Q<00@040P0;2@h200`:3`803@/@00<03@/>00`:3@0<2Pd00P0=2`h02P0:
20/030X=00`:3@0:20/020H900T72P0;2@`040h?00/92P0:20T300/92P0:00P61`0=2``040h?014?
400100002@L800d;3P0A3a800P0300P62@P02PP;0P0;2@`06@0;2@h02`P@00/84@0;21403``F00d:
4`0=2Q0030X=00/9300>30l02`T<00P62@0=2`h030X=00`:3`0A3a@01`D:00H32P0E4QT04@hE00h;
500>2aD02@HA00X74P0;21800P0;21400`0;21002`P?00/93P0300/93P0800d;4P050P/02PL@00h;
4`0@3A@04PlF00P6300;2@h400/9300@00l=4P0G5AX00@0400d;400100@02@L<01PF6`0100@040hC
07EcN00G5AX01`D:00/62P0<1`/03@P<00`72`802`H:00l01`8601LB5P0?2Ph040/?00/62P0@2`l0
H5iQ04E3AP0Y9bX00@0200T72P0@3Q4020H900T72P0;2@`00P081PT02P0:20/04@lD02h/<@0D4QL0
1P@901DC600A3a@03`dB010>4`091``200/93P0300<110081PT020H700@02@L800P02PP900`:2`0>
30d03@/<00P61`0610D02`L800d92P803PX;01X03@T:00/720091@H030P900h:2`0;1`P03`/<00X6
1`0>2P/030P900d92P0?2``02PH700H20`0>2P/02`L800`82@0=2@X02`L800T51P0=2@X030P900/7
200=2@X03PX;00l;30<02`L800P030P900d92P0>2P/0510A01XF5`0?2``01@4200/720803PX;00<0
3@T:00/720091@H00P0810D0200?2``03@T:00d92P0;1`P02PH700d92P0:1PL020@50P0>2P/01@0;
1`P030P900h:2`0>2P/02`L800803@T:00<03`/<010<3@0=2@X00P0<20T00`0;1`P02PH700X61`04
00X61`0700`82@0;1`P01P8300P41@0B3Pl04@d>00/72@0;00/62P0900T42P0>2@l04@`B00P32@04
00D02`H<00h93`0C3Q@04@`B00<02@@:00<030L>00`6400<1Q000`0<1Q0200X43P0400T33@0G4A/0
4P`F00`63`H02`H<01X03`X@00d83P0=20h03PT?00d83P0;1P`030L=00d83P0910/01`4;00/84P0F
4R00:bLe00D43@0;2a<0:2L]00h?4`0A41D02@L<01@?5@0;1P`03@P>00/6300A31802`H<00`73@80
3@P>00h030L=00/6300C4A@02PP;00/9300>30l04Q0C07ilO`0G5AP01`D800@21@0O7B002@L:00X8
2`8030L;100=20`0100>2@d02PD900X52@0<1`/200h93@0300X82`0610L01085008020H900<01085
00X82`0:20/00`0:20/02P0:20d03P/B00d:4@0>2a8040dD00l<5@0>2a@03``E00d:4@0<2A0200/8
3`0300/84@0:1a402PL@00802PL@00P02PL>00X83P0;2@h02@L:00X82P0A3a003`d>00P62P801P@9
01003@/@01LE6P0C4AH03@/@01DC600K6Ah0108701/I7P0?3A803P`A00`:3`0:20d02`T>00d;400<
2Pl03P`A0P0;2@h0100?3A802`T>00`:3`0C4AH200X83@0300T7300?3A802@L=00<02`PA0P0;21<0
0`0;21802`PA00/83`0200d:4@0600`9400;20l040dD00l<4`0=2Q402PL>0P091Pd00`0;214030TB
00l<5@0200l<4`0700d:4@071@X02@L<01HD5`0:20/01@<601/I7002010;3`0B010;4@0@2a8040XD
010:5P0S7BL030P?01@?5@0>2@l050lB00<0000B3A403@T<00L21P0>2@d020<700h93@0=20`03`X>
0P0A31001P0?2Ph03@P<00`72`0=20`03PT=00l:3P804@`@00<03@P<01@?4`0B3A400P0=20`02P0A
31002@@800h93@0@2`l03`X>00h93@0?2Ph03PT=00d8300>2@d2010;3`0300l:3P0A310040/?0080
3`X>0P0>2@d200l:3P8040/?01003`X>00h:2`0<20P020@501<>4P0j=C/09R0Z01D?6@0>2A002`H<
01HA5@0A30l020@3010<2`0A2`d050h@0P0?2@/04P0A2`l03`T=010:3P0;10/03PL>01@=500700P0
40X?00@0000500402`D700`6200@2P`03PP:00D00@0=1`T02`D701hH6P803`T;01@040X<00`62009
0`D03@L900`62P0=1`/08Q`P00T22@0D3a@0100400P12@0<1@`04`dA010:3P0D3Q803PP<01PB5P0<
1PX03`T=00h830<03@L;00<03`H;01052`0@1@/00`0@1@/600l42P0801<83P0:00D04@H<01P=4`0@
1@/04@H<00h32@0?10X201052`803`@:00d03P<;00d22P0=0PX03@8:00h32`0@1@d0200500`12@0?
10`03P<;01463P0M4QX03`<=00803P8<00<03@4;00h2300?0`d01P0>0P`0300A1Ph0304901<8400@
1@d02@0601P=5@0B1`l03`@<01053@0>0`/02`0800l431Cooooo000Kooooo`<02PP901402@L800/9
2P0?3@h05A<D00h<3@0;2@X03`d>00h<3@081PL02PP;00/9300@3Q403P`?00/9300A3a804Q0C00X8
2`0200/9300400T72P0=2`h03@T:00l;30804@d>0P0?2``0100<20T040`=00L3100A3@h2018>3`09
01DA400400000`00014=300?2`X02PH501<?3P0;1`H030P700803PX900<04@d<00l;2P0?2`X00P0>
2PT05@0B3Pd05A4@00h:2@0;1`H030P7014=300E4A004Ph>00T51P0>2P/04Ph?00<000050@8040`=
01XF5`0<20T09R8S04I2@`0W8b@03`X<00/51`0200d92P0@00`82@0<2P/03P`=00H41@0>3Ph01PH6
00d=3@0W9bL05aHF00/92P0=2``03`d>00d;300;2@X02PP900`:2`<03@/<0P0<2P/200/92P0300d;
300>30d02`T:00<03@/<0`0<2P/0300100805Q@G00T72P0D4QD01@<601<A500<2Pd0108500`:3@0:
20/040hA018@4`<02PP900T02@L800X82@0:20T00@0000h<3@050`@04@l@00l=3P0A3a001@0<2P/0
3`0;2@X03@/<00/92P0@3Pl0518C00h<3@0W9BH0=38e01DC5P0100807Q`O01DC5P0200<040hA00`:
3@0200l=400600/9300>30l0:RP]01/I7P0Q7b@03P`A0P0A3a@200/93P8030X?0P0=2a001P0>30l0
2`T<00/9300<2Pd03@/>00/9308040hA01H03`d@00`:3@0<2Pd03@/>00d;300;2@X030X;00d;300;
2@X02PP900T820091`P02`T:010>3`0:20T040h?01@B5@0A3a80518E00X82`030@@0518E1P0<2Pd0
100;2@X02`T<00/93P0;2@l200/83`0I00d:4P0<2A0030X?00/9300:20T03@/=00d;3P0<2Pd03`dA
00d;400<2Pl03@/A00l<4`0>2a802@H>00`94P0?31D03@XD00`9500>2aH03``F00l<5@0>2a@03@XB
00d:4@0400d;400400`:4@081@h02`PA00h;4`803@XA00<02@L=00/93P0;2@`00`0;2@`00`071@X0
1@<8014?500200d;400301DC600:20d05A<H00803`dB00@05Q@I010>4`0<1`/030L;0P0=20`08@0<
1`/02`H:00/62P0?2Ph01P45010;3`080`L050lC0:VWZP0Q7b806ALJ034_<P01008030X=00T72P0;
2@`030X=00X82`091`X02`T<00`:3`1UHfP00`46010>4`040PL07A/P01<A5P020@D0GE]P08n=TP0:
20d04Q0C00T72P0600T7200700`:2`0;2@X02`T:00T720050`@02PH700`82@0200d92P0900`82@0:
1PL03`/<00X61`0<20T03`/<00h:2`0@30d03`/<008030P900@03`/<00/720070`@03PX;0P0;1`P0
0`0=2@X02`L800X61`0300/7208030P900D03@T:00h:2`0=2@X030P900/7200200`82@803PX;00L0
2@D600P41@0<20T03@T:00P41@091@H02PH700803@T:01L030P900l;300=2@X03@T:00/7200:1PL0
30P900X61`0;1`P04`l@010<3@0;1`P02@D600`82@0;1`P02@D600h:2`0@30d04@d>018>3`0?2``0
3@T:00/7200200T51PD02PH700L02`L800`82@0:1PL02@D6010<3@0B3Pl03PT<00/02`H:00T01P47
00/6300=20h01P4700L2200C3Q@05A0F01XE6`0G4QP00P0=20h00`0<1`d030L>00`73P0400`73P06
00/63@0=20l01P4800/63@0:1@`040/B1P0;1P`06@0@2a403`X@00d83P0=20h03PT?00/6300>20`0
30D;00X32`0;0`h030HA00`64P0300T02`PB00`;4`0@3A@00P4600000P081P/06A@J00l:400>2@l0
30L=014<4P0;1P`0100=20h03@0;1P`02`T<00D31P0;2@`04Q0C01LE6029QhX04a4D014?4P0E4aH0
HEmR010>4@0=2`h00`0=20`300h93@0I00d8300910P02@@800/62P0<1`/02`H:010>4@030@@05aDH
014?4P081PT04Q0C00T72P0:20/02`T<00h<3`0?3A003`dB00`94@0<2A803P/D010=500>2a803@XA
00h;4P0200d:4@0<00d:4`0>2a@03P/D00`94P0;21402PL?00T63@081@`02@H<00`:3`0<2Pd02@L:
0P0;2@`0400=2`l04Q0E00d;400:20d04@lD010>4`081P/04@lD01@B5`0E4aP08b4V00l=4P0<2Pl0
2PP=00T7300;2@h200h<4@0500l=4P0:20d01`D:00d;400?3A800P0>31401@0<2Pl03@/@00P62`0<
2Pl0514H00<02`PA0P0;21<00`0;21802`PA00`9400300d:4@0:00`940091Pd02PL>00/83`0<2A00
3P/B010=500:1a002`PA00d:4`803P/B00L03@XA00/93P0?3A8081hQ01<A500=2`h08AlR008040`=
018040/@010;4P0@2a8040XD00l94`0=2A003`X@00<0100A3@l06aLH00`72`0D3a<05a8F01`G6`0@
2`l04`hB010;3`0?2Ph200h93@0300l:3P0@2`l03@P<00@03@P<00P030L;00h93@0C3Q8050lC00l:
3P0<1`/04@`@00`72`803PT=00@03@P<00h93@0A310040/?0P0>2@d00`0B3A404@`@00l:3P0400l:
3P0400h93@0=20`03`X>00l:3P8040/?01803`X>00h:2`0A3@d081`M00h93@0H51T03PT@00@01P0?
2Q4030L=01LB5P0A30l020@3010<2`0>20X04@/=00l92`0@2P`2018<400Z00d72`0400@05@hE01H?
5P0@2A40;2H[01@>4004000040X<00`6200=1`T03`T;010:300H4Q@030H800d72@0;1@L03`T;018<
3P0C3@l030H800h82P0@2Ph030H:00@00P0I4QT04P`B02lX;`2RVj<06A8I010:3P0400805a8E00@0
0P0:10P04P`@00l93@0>20`03@L;00h8300?2@d040P=1@0@1@/600l42P0801<83P0<0@L06PlE02DJ
800G31804PL=00h32@0?10X201052`803`@:00d03P<;00d22P0=0PX03@8:00h32`0@1@d02`0800h3
2`0A1Ph03P<;00l4300J3aL03`<=00803P8<00<03@4;00h2300?0`d01P0>0P`02@0?10`03@8:01D:
4P0>0`/03@@:02XO9`0N4a/040D=00`12@0200h32`0300d22_oooooooooo01;ooooo000Kooooo`0H
01HD5@0=2``030X;00`:2`0;2@X03P`=00d;300<2P/02`T:00h<3@0@3Pl03`d>010>400;2@/03P`>
00l=3`0E4aD0:BLY01XH6P0>30h040h@00h<3P0;2@/04@lA0P0?2``2010<3@804@d>01804`l@00/7
200;1`P05Q8C00h:2`0?2``03P/:00h:2@0J5QD0510?014=300>2PT06aLF00h:2@0?2`X04@d<010<
2`0A3@`2010<2`803`/:01P04`l>01HB4@0D40l03PX900d9200A3@`0510?014=3@0C3a003@T:00l;
300k=cP0<bl`00d92P0C3a003PX;00d92P0B3Pl03PX;018=3`0F41805a<D018>3`0;1`P200X82@06
00/92P0C4a<03`l?00T92@0=3@d030/<0`0=2``00`0<2P/02`T:00`:2`0200d;300400h<3@0=2``0
3@/<00d;308030X;00<03P`=00l=3P0>30d01P0=2``0100@3Q401`D8014?4P081PT200h<3`803@/>
01@03P`?00/9300>30l03@/>00l=3P0>30d03@/<00`:2`0=2``03`d>00`:2`0G5AH01`H600h<3@0;
2@X03`d>00/92P0:20T02`T:00`:2`803@/<01P03P`=00l=3P0;2@X040h?00`:2`0G5AH02`T;034_
<@0>3@h030X<00d;3@0?3Pl04a4C00P6200<2P`03P`>00/92`0B41806QPL01@B5P0;2@d03@/?00/9
3@0<2Ph200/93@8030X>00T03@/?00d;3P0?3A002`T;00X82P0<2P`03@/=00`:300;2@/00P0=2`d0
1P0<2P`03@/=00h<3P0:20T020H700T720803@/<00d030X;00X82@0F51D0518C00T8200<2P/04@l@
010>4@0;2@`04@lB00h<3`0B41<02`T<00D030X=00D030X;00`;2@0<2`X030X<00`:3P0200`:4006
00/93P0<2Pl03@/>00`;2P0;2PP030X;0P0=2`l200`:3`0400/93`091`d04@hE01DB6P803@XC0P0<
2A<2010=600500h;5@0<2A802`PA00d:4P0@3A@0100@3Q<0200?3A@040dF00`94P0:1`l02`P?00h;
4P0?3A<02PP=0P0;2@`200`:3@0@02TW:`1JF5`040hB00/93@0@3Q802`T=01HD60050`L030X>014?
4`0610P02`X=00h93@0<1`/02`H:00d830803`X>01D04`hB00d8300>2@d040/?00/62P0>2@d0928U
01<A500<2Pd01`D800d;3P0>30l02`T<00`:3@0=2`h02`T<00X82`0<2Pd03P`@00d;3`0<2Ph00P0?
3A401`081PX01@<7014@4`0A3a<0<c4e00X8300920X00P0<2P/300/92P802PP900D02`T:00T7200<
2P/040h?00/92P0600`82@09010<3@0S7b0020@5014=3P0?2``04Ph?00d92P0<20T02`L8008030P9
0P0=2@X200/7200300h:2`0?2``03PX;00802`L8100<20T00`0?2``03@T:00`82@0300`82@0300d9
2P0810D02PH700803PX;00L030P9018>3`0>2P/03@T:00h:2`0=2@X02`L800803@T:0`0<20T02P0;
1`P02PH700d92P0B3Pl03@T:00X61`0B3Pl07ATJ01TE5P0<20T200h:2`0500/7200=2@X02`L800`8
2@0=2@X00`0<20T01@0;1`P02PH700/7200<20T02PH700802`L800@02@D600d92P0>2P/03@P;1@0<
1`/0100;1PX02PD900/62P0;1PX200`72`0<00T42@0;1P/030L<00/62`0?2Pl06QDJ00`7300>2@h0
3@P=00/62`0>2@h03@P=1P0<1`h01`0910/040/B00`73P0@2a803PT@00d83`0=20h01@0=20d200l:
3`0E00/62`0:1@X03@P=00T3200;0`P02`<900d5300?1Pl03PHB00/44@0=1Q803@LB00P42`0810X0
2PL;00h:3P080`T050lE00l:400H4aT05Q4G008030L=01403@P>00h93`0>2@l03@P>00`73@081`T0
3P`?00T72P0=2`h02@L:010>4@0C4A@02PP;00/93013@D@02`T<00l=400200l:3P803PT=0P0=20`0
3@0>2@d030L;00d8300>2@d030L;00T4200=30h00`4400X82`0@3Q40518E00P72@0;2@`00P0<2Pd0
3@0>30l03`d@00l=4P0;2A4030XB00l=4`0A3aD03`dC00d;4@0@3Q@03P`B00d;4@0=2a<00P0>31D0
2P0>2a<030TA00`9400:1`h02@L=00/83P0>31403@/?00/93@0?3A4200h<400=00l=4P0<2Pl02@L<
00P62`0:20d02`T>00l=4P0@3Q<0518G00h<4@0<2Pl040hC00h<4@0200`:3`0>00d;400;2@h02PP=
014?500@3Q<020H;00/93P0<2Pl020H;00/93P0:20d03P`A00l=4P0<2A0300h;50803P/F00<03P/E
00`94P0=2Q400P0>2a8200d:4@03018?5P0@3A@03``C00<030T@00<02PL@00/84@0>2a@00P0?31<0
1`0>2a803@/@00d;400H5QT03@/>00`:3@0@3Q400P0@30`0400?2Pd03PT?00l:400@2a<0618L02XT
;@0D3aH04`hD010;3`0>2P`0=C0d024L800>2@d04PdA00`72`0?2Ph2010;3`803PT=0P0@2`l06@0A
31004PdA018=4@0B3A4040/?00h93@0@2`l04@`@01D@500D3a<03`X>018=4@0?2Ph04PdA014<400@
2`l03`X>010;3`0C3Q803`X>010;3`0D3a<04`hB010;3`0?2Ph00`0@2`l0100?2Ph03PT=00l:3P0?
2Ph2010;3`0?00l:3P0>2@d04Ph>00d92P040@40:B@Y03Xe>P0S7R@04@`B00l:400B3A<03`X>00/7
2@0=2@/03PP:008040X<00h03`T;010:3P0B31005Q0D00L21`0F3aH02@@901dF7P0R72405Q0B00T4
1@0A2`d040X<018<3P8040X<0P0?2@/06`0=1`T03`T;00d72@0B30h0618D01@>400<1PP03@L;010:
3P0C3A402P<:00`6300:0`X0<BXb00h83P0=1`/06Q@H04Q2AP0F4A@01P4400l93@0>20`03@L;00h8
300A2`l04`dA01<:3`0501052`803P<90P0?10X201052`0800h32@0:00D04`P>01T>500@1@/03047
00h32@0?10X201052`803`@:00D03P<;00d22P0=0PX03@8:00h32`0201053@0601463P0@1@d03049
00/1200=0PX03`<=0P0>0P`00`0=0@/03P8<00l33@0200l33@<03P8<00d03@4;00l4300?10`04PL?
00d22P0?1@`09AXR01hC6`0>10/02`4801053@0?10`0304901Cooooo000Kooooo`0301TG600:20T0
2`T:008040h?02804a4B014?400A3a003P`=00`:2`0;2@X03@/<00X82@081PL040h?00h<3@0;2@X0
6aTJ01XH6@0=2``03P`=00/92P081PL040h?014=3P0?2``03PX;010<3@0B3Pl04`l@00d92P050@80
5A4B018>3`0L61T0BDE6075]K00300003`/:0P0E4A001@0<20L03PX900L30P0<20L04`l>00804Ph=
00<030P7010<2`0A3@`00P0@30/00`0A3@`05Q8A014=3002010<2`0F00`81`0<20P03`/<00T51P0?
2``0>CDf034];P0A3@h02@D600`82@0A3@h03`/<014=3P0=20T04@/=01@@4@0B3Pl03@T:00d;300A
3a003P`=00H61P803Ph>00@02PX:014@400>30d030X;0`0;2@X0100<2P/03@/<00d;300>30d200d;
300400h<3@0=2``030X;00h<3@8040h?1P0=2``01P0;2@`03@/>00d;3P0:20/03`d@00h<3`802PP;
010030X=01<A50091`X03@/>00h<3@0=2``02`T:00X82@0;2@X03P`=00X82@0H5QL030X;01@B4`0=
2``02`T:0P0<2P/04@0;2@X02PP900/92P0;2@X01P@500l=3P0;2@X04a4B014?400<2P/040h?00H5
1@0@3Pl03`d>00X82@0C4A808AlP008040h?00T04@l@00`:2`0C4A803P`?018@4`0100804Q0C00`:
3@091`X00P0;2@`200`:3@803@/>00X03`d>00/92P0:20T02`T:00d;300<2P/04@l@018@4@0@3Pl0
3@/<0P0;2@X01@0>30d020H700P61`0>30d0518C00805Q@E00/030X;00T720091`P030X;00@20`06
1@L071XM05ABE@0K6A`0108501<A500500X82`0500X82@0<2`P030/900`;2@0<2Pd00P0<2Pl04@0;
2@h03@/>00l=3P0?3P`03Pd900l=3P0@3Q<03`dB00X83@0;2@h03P/B014>5@0:1`h020D>010=5P0;
21402@HA00803@XE00H030TD00`94`0=2Q<03P/D00h;4`0<2A0400`:3`0:00P63@0:1a0020D>00/8
400=2Q402@H=00d:400:20d02PP;00/9308030X=0240108504Y8B`0<2Pd00@0201`J7@081PT01@<6
00l=400B41<01P@700/9300>30l040/?00`72`0:1@T03PT=014<400B3A403@P<00/62P0?2Ph00`02
00d8300@2`l05Q@G014?4P0<2Pd05Q@G00h<3`071@P02PP;00/9300=2`h00P0:20/03`0<2Pd00P03
00h<3`0<2Pd00`4401HD5`081PT04a4D00`:3@0=2`h01`D800/9300<2Pd03P`=00d;300200`:2`80
2`T:0P0<2P/01P081PL03@/<01LE5P0C4A8040`=00h:2`8030P901H03PX;010<3@091@H0AT9300L3
100=2@X04Ph?00/7200?2``040`=00d92P0<20T04@d>01LC500C3a003PX;00`82@0;1`P02PH700T5
1P0<20T03@T:0`0>2P/02`0=2@X030P900`82@0<20T03PX;00l;300@30d03PX;00`82@0>2P/030P9
008020@500H03@T:00T51P091@H03`/<010<3@0?2``500`82@0@00h:2`0=2@X03`/<010<3@0:1PL0
30P900l;300@30d03PX;00H20`0?2``04@d>00`82@0;1`P02@D600X61`8030P90P0=2@X300/720<0
3@T:0P0<20T00`0A3@h03PX;00X5200500`72`0400/62P0:1@T02`H:00/62P8030L;00@04PdA014<
400>2@d030L;0P0;1PX200d8300500`72`0?2Ph050lC00l:3P0<1`d01@0<1`h01P0=20l040/B00L2
2@0A31<04PdD00T42PH03PT=01D04@`@01<>4P0=20`02`H:010;3`0;1@T03@@901<9400A1`l0308;
00/2300@21D03@DB00L22@0C3QD040/A00T4200D3a<030L=00d83P0>2@l00P0X8bT00`0910X030L=
00d83P0200h93`0F00d83P0<1`d020H900H41`0C4A@030X=00L520050`H03`d@00X82`0K6A`00`44
014?4P040PD04@`@010;3`0?2Ph03PT=00`72`0;1PX03`X>010;3`804PdA00X03@P<00T4200;2@`0
6aTL085oPP1NG5l01`D8014?4P0=2`h030X=0P0;2@`030091`X02@L<00`;4P0=318040lD01<C5P0@
41803Ph@01<C5@0@41803PdB00`;40802`XB01`02`P?00`9400<2A003@XA00d;400?3A803@/@00T7
300?3A806aTN01LE6P0>31402PP=00/93P0C4AH03@/@00X83@0<2Pl02PP=00/93P0C4AH03P`A00l=
4P081`/03@/@00/93P0<2Pl03@/@0P0<2Pl0200U8bP0:RP]00h<4@0<2Pl040hC00T7300=2a002PP=
0P0<2Pl0100<2A0030TB00`94P0<2A8200`9500300`94`0<2A803@XA00803P/B0P0=2Q4200l<4`07
00h;4P0?31<03``C014>5@0;214030TB00l<5@02014>5@0K010=500@3Q<02`T>00l=40091`X04Q0C
00h<3P0?2`X03`/800d92@0<1`/03@P>00l:4@0300L0;RPa00X5300E41H030P<00`72`0n>Cd081/O
014<400O6Qh061<G00d8300<1`/03`X>00804PdA00D03`X>00`72`0>2@d040/?018=4@0201<>4P05
014<400@2`l03@P<01D@500G4QH00P0A31001`0?2Ph050lC01LB5P0D3a<03PT=00/62P0E41@00P0A
31001@0G4QH05A0D014<400@2`l04PdA00804`hB00@04@`@010;3`0?2Ph03`X>0P0@2`l03`0?2Ph0
3PT=00l;300<20T03`/<018=4@0K5QX02@@801HA5`0E41H040/A014<4P0B3A<03`X@018<3`02014;
3@0;00d72@0;1@T03PP<010:3P0?20l05a0G018;4P1?B5005@lD014;3@0I4aD00P0A2`d01P0D3Q00
3@L900h82P0600803PP:00`620803PP:01804@/=00l92`0A2`d03PP:01D?4`0H4QH01@0301H?5P0<
1@`071DL00@01@0C31<05a4E018<400=20/02`D901PB5P0:10P200`62P0400h8300B31005Q0D01@<
4@D040D;0P0>0`T200l42P8040D;00P060dC01873@0=0PP03@8800h32@0A1P`03P<900l42P8040D;
0P0?10X02@0>0`/03@8:00d22P0=0PX03P<;01053@0>0`/03@8:00h32`0201463P0600l4300?0`d0
3P8<00h2300=0@/03P8<0`0?0`d200h230803@4;00<04@H>00d22P0<0@T00`0<0@T0100>0`/02`08
00l4300@1@d200`12ACooooo000Kooooo`0800l=3P0=2``03`d>00X82@0B41402PP900h<3@0<2P/2
00X82@0500`:2`0>30d03P`=00d;300<2P/00P0>30d02`0<2P/03@/<00X82@0=2``030X;00X82@0=
2``03@T:00h:2`0?2``040`=00804@d>00`04`l@00d92P0?2``03@T:01lK700f<S<0FEED00d9200?
2`X04@d<010<2`0B3Pd600l;2P08014=300:1PD04@d<010<2`0H51<01@4000h:2@0@30/2014=300]
00h:2@0>2PX03PX;00d92P0?2``04@d>01@@4@0@30d01@42010<3@0F4Q<01P8301DA4P0;1PL03PP:
010<3@0A3@h02@D600L51P0;2@X0Cde>01/K6`0A4A40N7Qh03lo?`071PL04@l@00d;300;2@X03`d>
00T7200B41401@<400H41@0A3a002`T:00`:2`0;2@X030X;018@4@0A3a002PP900P61`0<2P/03@/<
00803`d>00<03@/<00`:2`0<2Pd01@0<2Pd0100?3A003P`?00h<3`0=2`h200`:3@0300h<3@0=2``0
3@/<00804@l@00T030X;00h<3@0=2``03@/<00P61`050`@03P`=00`:2`0=2``00P0>30d3010>3`06
00h<3@0C4A804Q0A00`:2`0A3a0030X;100;2@X02@0:20T0518C00h<3@091`P02PP900h<3@0@3Pl0
2`T<00d;3P0200l=400500d;3P0;2@`01`D800X82`0>30l00P0?3A000`0=2`h03`d>00h<3@0200`:
2`0400h<3@0?3@h030X;00`:2`803@/<00H030X;00/92P071@H020H700T7200<2P/200d;300;00/9
2P0@3Pl02@L800h<3@0;2@X03P`=00P72@0Q7b809R@W05YHF`0=2`h00P0;2@`04@0>30l030X=018@
4`0:20/030X;00d<2@0F5A<02PT700`:3@030@H020H;00l=4P0=2`h030X;00`;2@0<2`L030/;0080
30X?00D030X@00`9400<2A0030TA00`94P0400`9500:00/84`0A3QT01`@?010=5`0100L05a@M00d:
4P0;20l030X?00d;40801P@900`030XA00<02@0a;SL02`P@01@A600100D03@X@00H42@0;2@`03@/>
010>4@0<2Pd300d;3P801P@700h06ALJ01hL7`0F51L02`T<00X82`0;2@`020H900d8300;1PX040/?
018=4@0=20`030L;01@?4`8040/?01403`X>00`72`0>2@d03P`?00/9300>30l020H900800`0I5aX0
DU1C01LE600=2`h020H900@21@0?3A002PP;00/9300200`:3@0J00/9300:20/040hA00/9300E4aH0
3@/>00@21@0A3a8030X;00l=3P0;2@X01`D600`:2`0C4A803`d>00X82@081PL02`T:014?400C4A80
2`L800h:2`0;1`P04@d>00/7200<20T200h:2`803@T:0P0<20T0300=2@X03`/<00/7200;1`P05a<D
020L7@0N6Q/02PH700l;300B3Pl02PH700T51P802PH700D0?SXk00h:2`091@H02@D600d92P0200X6
1`0500d92P0<20T030P900d92P0E4A800P0<20T03@0>2P/01`<400H20`091@H02PH700/7200=2@X0
3`/<018>3`0810D02@D600X61`0;1`P00P0>2P/02@0=2@X030P900X61`0:1PL02@D600`82@0B3Pl0
4`l@00T51P0200P41@0=00`82@0@30d02`L800X61`0<20T03`/<00<000070`@04Ph?00H20`0<20T0
3`/<00`82@0200d92P0800/7200<20T04@d?01`G6`0M61`04@`@00/62P0=20`200`72`803@P<0P0<
1`/08@0910P061<G01dH700=20`02@@800`72`0=20`081/O00T5200F4AD071LK00h93@0=20h02PD;
00/7300B3A<03@P>010;4@0;1P`00`0401/F700300@050lE00H21`0=20`020<700l:3P0<1`/03`X>
00T5200C3Q804@`@00d8300200T4200=00/52@0700403@<700P01P0G3AH040PA01H>6@0500P040TB
00l:4@0<1`d02PD900h93@0200d83P803PT?0P0?2Q00100910X02PD;01@?5@0D3aD200/6300=00@2
1@0@3Q400@0201@B5@0;2@`03P`?014?4P0;2@`020H900/9300<2Pd02@L:00d8300200`72`0k00d8
300>2@d03`X>014=400;1PX00`02018=4@0400<05A0D00P72@0:20/0DU1C03Xh>`0:20/040hA00h<
3`091`X04@lB00l=40091`X03@/@00h=50081`d010<801PH6@0M7A/03`l=01HF500A4A403Ph@00L6
300;2Q804A0H010>500;2@h02PP=00h<4@0=2a0030X?00H42@0F4aX01`@;00l<4`0O72<01@8800X8
3@0=2a002PP=00P62`0=2a004Q0E00d;400;2@h040hC018@5@0=2a002PP=010>4`0B41D00P0?3A80
200=2a002PP=00`:3`0>314040hC00h<4@0<2Pl02`T>0P0<2Pl02`0;2@h02PP=00T63@0100L04a0I
00H3300?31L01`@?00/84P0=2Q<03@XA00803P/B0P0?31<0100A3QD01@89014>5@0?31<200T63@0Q
01HC700710d0>3Dn018?5P0>2a8030T@00d;400610T0518E00400P0<2Pd03`d?00/7100C3``04Ph<
01HB4`0B3A402`H<01@?5P0A31<03PT@00h93`0A314050lC00l:3P0A3A007aXN01HA5@0;1PX050lC
01<>4P0@2`l03`X>008040/?00<03`X>010;3`0@2`l00P0A3100100B3A404`hB018=4@0A3102010;
3`0M014<400B3A404@`@01`G6`0R7B407QTM01<>4P0<1`/04PdA00`72`0=20`05Q4E01TD600C3Q80
4@`@010;3`0A310050lC01LB5P0I51P03`X>00`72`0B3A405A0D00h93@0;1PX0510A00h:2`0=2@X0
0P0@30d05P0>2P/04PdA01<>500C3Q@04`hE014<4`0@2a804@/>00/51`0<1PP040X<010:3P0>20`0
3PT<01/D6`0>1`h05PlF02DN9P0H4AL040X<00h82P0?2@/2014;3@0S00`6200G4A<02084028L7P08
0P@05a4C00d72@0;1@L02P@600h82P0J51H0208600/52@0A2`l050dD00l83`0A2Q4040TA00`5300=
1`/030H:00/52@0=1`/03PP<00/52@0W8BD08adQ00/52@0_:Bd0;2HZ01893P0?10X04@H<01<83P0B
1`d00P0>0`T00`0?10X04@H<014630020146300401P=4`0D2@l03@8800h32@803`@:00P02`0601D:
400C20h02P0501T>500A1P`0304901053@804PL?00@0200500l4300C210040D=0P0=0PX00`0>0`/0
304900l33@0500l33@0B01H:500?1Pd02`0901D94`0<0@X03`<=01873`0<0PT03`@<00L0100A1Ph0
200500L0100D2A403`@<00/0200B1`l040D=5?ooool001_ooooo00H040h?00l=3P0?3@h02@L800l=
3P081PL600`:2`0300h=300=30/030/:00803Pd<00/030/:00h=300;2PT03Pd<00d<2`0;2PT03Pd<
00d92P0>2P/03`/<010<3@02014=3P0<00l;300E4A807ATJ01DA4P0?2``05Q8C010=300E4A005Q8A
00/81`0S7ah03@T81P0?2`X01`0B3Pd030P700h:2@0:1PD06ADD00`9200?2`X00`0@30/0100?2`X0
40`<014=3P0@30d200l;308040`=00X03`/<018>3`0<20T061@E00/7200?2P/040X<01LC500N6Q/0
510A0P0<2P/05`0a;c004Q8B00l?3`0k>c/06ATI00d<30040`<03P`=010>3`0;2@X0518C00/92P0B
41403P`=00X82@0>30d03`d>01@B4`091`P02PP900d;300<2P/03@/<00802PP900@02`T:00`:2`0<
2P/03@/<1P0<2Pd200h<3`0700d;3P0<2Pd030X=00`:3@0>30d03@/<00h<3@02010>3`0700d;3009
1`P02@L8014?400D4Q<03`d>00h<3@0300d;308030X;00<02`T:00l=3P0=2``00P0A3a001P0=2``0
3`d>00`;2P0<2`X03@/;00d<2`803Pd<00H02@L700d<2`0?3@d03@`;00`:2P0;2PT700d;3@0700`:
300:20X02PP:00`:300=2``02@L800d;2`0200l>3@0400d;2`0920L030/:00`;2P803@`;00<030/:
00/:2@0;2@X00P0<2P/300d;300F010>3`081PL061HG00d;300;2@X02@L800l=40091`X0108501<A
50050`H0518E00l=400<2Pd02@L:00l=40081PT030X;014@3P0510<061HH00l=40803`dC00H03`dB
00d;400<2Pd030/:00d<2P0=30d300d;4@0500d:4@0=2Q803@XC00`94`0<2A@00`0<2AD0400<2A@0
4PlJ00`9500<2A<03``E00l=5@0<2A402PL>00X83@0?3A803P`A00d;400>2a8030TB01lL9@0<2A42
014>5@06014>50091``02`T<00`:3@0>30l03`d@0P0;2@/02`0?3@l03@/=00X82P0A3a40518D00l=
3`0:20X030X<00d;3@0;2@/04PdA00803PT=00@03`X>00h93@0C3Q804PdA0`0>2@d03`0;1PX03@P<
00`:3@091`X02PP;00T72P0:20/09B<V00l=400C4A@081hQ00d;3P0l>Sd0518E00/92`0400`:300>
00/92`040P@03`d?00T72@0:20X04@lA00H41P0:20T02`T:018@4@0F51D04Q0A00P61`0;2@X200d;
30<030X;00H02PH7010<3@091@H030P900/7200F4Q<200h:2`<03@T:00h030P900/7200?2``03PX;
00X61`0<20T040`=018>3`0D414040`=00P41@0<20T04@d>00l;30803PX;00D04`l@00h;2`0<20T0
6ADF010<3@0200`82@803@T:00P061@E028N7`0G4a@030P900d92P0<20T02PH700`82@803@T:00@0
3`/<014=3P0@30d02PH70P0;1`P00`0:1PL03PX;010<3@0200l;30<03@T:00l03PX;018>3`0C3a00
2`L800`82@0B3Pl02PH700D20P0=2@X04@d>00h:2`0:1PL05Q8C018>3`060P<00P0@30d02P0>2`/0
2@D600X61`0=2@X03PX;00`82@0:1@P030L;00/62P0:1@T200h93@0h00`72`0=20`030L;00/62P0<
1`/03@P<00X5200C3Q405A0C00/62@0:1@P030L:01LC5@0l>3X07a/M00P31P0=2@/04Ph@010;400;
1P/030P<00d83@0:1@X02`L;00X52P0A3140IV5V00h93P070`L03`X?00l:3P091@L03@T;00H2100D
41803`X=00l;3@0>2@`02`L900X5200<20X03PT:00l82P0D3A003@L:00`52`0=1Ph040XC00l84@0:
1@`02`P=00T62@081@L03``=00d8300=20h200h93`803`X@00`061<I00/6300?2Q003`X@00P32@0C
3Q@030X=020N8@040PD01`H800T72P0>30l200`:3@802PP;00D030X=00d;3P0>2@d03@P<00`72`02
00/62P0=00`72`0@2`l03`X>01HA5@0=20`04`lB00X62@0<2Pd02PP;00/930091`X03`d@00<11002
00/9300L00d;3P0A3a804Q0C014?4`0;2Pl0410C01DF5`0N81`09bTR02X/900S9Ad04Q@?01PI5`0A
4A<03`lD00P73@0@3Q<02`T=018@50030@D0;B/`06ARI`0I5Q`00`4700d:4P0:20l02`P@00l<4P80
30X?00L02`T>00X83@0=2a003P`A00/93P0:20d03P`A008040hC00P03P`A00d;400>31402`T>00L5
2P0@3Q<0518G00d;40<03P`A00<03@/@00`:3`0<2Pl00`0<2Pl02@0<2A003``E00P63P0A3QL02PLB
00X84P0B41T03@XC00d:4@0200h;4P803``C00X01@89014?5@0:1`h04@hE00L42`0B3aH04a0I00P5
3P0F4a`01P<:0P0@3A@0300C4AH040hC01DC5P0E51H05Q@G02LU9`0n>SH07a`F01HC3`0C3`h03@T:
01D@5@804PdD01<040/B010;4@0B3A804PdA01<>4P0@2`l03PT=014<400C3Q802PD901<>4P0@2`l0
3`X>010;3`0A31003`X>010;3`0B3A404`hB00804PdA00<040/?018=4@0A31000P0@2`l01P0A3100
4PdA00h93@0C3Q805A0D01<>4P804@`@00L03@P<014<400B3A404@`@00l:3P0@2`l03`X>00803PT=
00X04@`@018=4@0D3a<04PdA00l:3P0E41@05a8F010;3`0?2Ph04@d>0P0?2`/0100B3Ph04@d=00l;
2`0B3A02010;4@0401<=5P0G4A`06A<L010:3@<040X<0P0@2Ph07P0M5a/08AXQ01D>5@0>1`h03PL?
00l83P0B30h040X<014;3@0C3@l04P`>01@>400?2P/07aTK071ZK00O6A/03`X;01D@4@070P<06aDG
00l:2`0D3Q0020<601@>4P0A2`l04@XA00`5300>1`h03`P@00h73P<03`T=00H040X>014;3`0F41@0
9AlS01lI7@0?2@d2018<400801L?500D2@l03`@:00l42P0@1@/04@H<00h32@0?10X40146300300l4
2P0>0`T03`@:00804PL=01<03`@:01873@0D2@l04@H<00`11`0D2@l03`@:00l4300@1@d04PP?020E
7@0:0@L050TA00/2200B1`l05``D00l4300:00L03P<;00H03`<=00T03@8;01<74@0<0@X0304:0104
3P0<00X0200500l4300900H00P0@1@d0100>0`/05@XB01053@0>0`/201873`0300`22Ooooooooooo
01;ooooo000Kooooo`08014?400D4Q<05aDF014?400J61T05Q@E00X82@0<2P/200h<3@0500`:2`0:
20T03Pd;00d<2P0<2`T00P0>3@/01`0<2`T03Pd;00/:200>3@/03@`:00/:200>3@/00P0>2P/0400?
2``040`=010<3@0@30d04Ph?010<3@0F4Q<05A4B018>3`0D41403PX900l;2P1;AdH08AdL01LC4P0@
30/700l;2P05014=300E4A003@T801lK6P0F4Q401@0?2`X0100A3@d04Ph?014=3P0?2``200d92P0U
01PD5@0@30d00`0002/W:01dL7407ATJ00`72@0>20X030P900h:2`0<20T03@/<00`:2`0?3@h02@T9
00h>3P0C4a<02`/;01@C500C4A804@l@00`:2`0E4a@04Q0A0040000:20T02`T:024O800;2@X030X;
030^;`0F51D03@/<00l=3P0>30d030X;00d;300200`:2`0300d;300?3@h04Q0A00X030X=0P0;2@`3
00d;30803P`=00L03@/<00`:2`0@3Pl05aDF010>3`050`@0108300<03`d>00d03P`=00d;300=2``0
3@/<00`:2`0>30d03`d>00d;300<2P/02PT700/:200<2`T03@`:00803`h<00P03Pd;00l>300<2`T0
2PT701HE4`0V9B<03`d>00d;30802`T:00@03@/<00l=3P0@3Pl03P`=0P0<2P/0100=2``03P`=00L6
100;2PP200l>300400/:20071P@030/900`;2@803@`:00<030/900/:200>30d00P0=2``08@0<2P/0
2`T:00/92P0B41408b4R04U7B00B414030X;01@B4`071PP0518E01LE60081PT03@/>010>4@0=2`h0
1`D800T72P0B41<030X=018@4`0@3Pl0928U01@B5`1:Add0?3U003Xg?P0>2a<03@XA00`:3`0<2Pd0
3@/<00h<3`0200d:4@8030T@00D030TB00d:500=2QD03@XE00d:5P0200d95`0900d95P0300/03P/F
01<@6P081@h04@hG04=0B00C41L030X?00803P`A01@02`T>00h;4P0K62403@XC00h;4`0>2a807a`S
00l<4P040PL01`D800X82`071@P02PP;00`:2`091`P03@/<010>3`0<2P/02PP900d;308030X;00X0
3P`=00l=3P0<2P/04@`@00`72`0;1PX030L;00d8300D3a<04@`@0P0=20`00`0>2@d02`H:00d83002
00T72P0<00d;3P091`X00`4400T72P0D4QD020H900/930071@P0108500h<3`0;2@X030X;0P0=2``0
4@0<2P/02`T:01@B4`0:20T01P@500d;300610D04@l@00/92P0?3@h030X;00<10P0510@05A<D00h<
3@0?3@h03@/<00802PP900L03@/<00h:2`0810D02`L801lK700G4a@0100100H03@T:01H020@500d9
2P0@30d03PX;00d92P0>2P/0510A018>3`0:1PL040`=018>3`091@H040`=00d92P0300002`L800l;
300D41404@d>00/720091@H02`L80P0>2P/01`0=2@X05A4B00h:2`070`@02PH700/720091@H00P0;
1`P02@0:1PL030P900d92P0=2@X02`L800h:2`0<20T02@D600`82@0200d92P0O00`82@0;1`P02`L8
00`82@0;1`P030P900d92P0810D02PH700/720050@803PX;01LC500;1`P040`=01HB4`0<20T00`00
01@@4@091@H00`0001@@4@0=2@X02@D600`82@0@30d03@T:00`72P0@2`l03`X>00d83002010;3`06
00h93@0=20`02PD900T4200;1PX03PT=0P0<20T200/7208030P900T03@T:00/7200810D04@d>00T5
1P0J5QL05A0D018=4@0A31000P0<1`/03@0@2`l03`X>00D0100810L030L;01LB5P0=20`05a<D00/7
200=2@X0100100X61`0810D00`0:1PL0400;1`P03PX;010<3@1TGUh03`T:01D?4`0E3QD02@@:010;
4P0300D06QLM01@C600C4A@02`/:00@4100:20/300d83P803PT?00d03`X@01XE6`0m>3h0?3Lm01HA
5`0;1P`020H900@21@091`X03P`?014?4P1:B4/01`D8008030X=00@02@L:00/9300?3A003`X>100=
20`03@0>2@d040/?00T4201`Jfl0BTE901LB5P0C3Q802@L:00l=400@3Q403@/>00/9300610L00P0>
30l07P091`X03`d@018@4`092@/04a@F01@F5@0<3PT09BPO051CB01LH580DUI802<V7@0Q91d05QPE
01dN800C51H04Q0C01TG6P0H5QT03P`?00h<4@0J5ad02PL>00D22@0B3aL04a0I00L43@0<2A403@/@
00/93P8030X?0P0;2@h200d;400>00`:3`0=2a0040hC01`J7`0J61d05Q@I01DC600;2@h0518G01XH
7@0=2a0030X?00/93P0<2Pl200d;408030X?00X03@/@00h<4@0?31<08AhW00`94P0=2Q<05A8M00H3
3P0:1a403P/D1@0>2a809`0I5Qd0FUMN020M900<2A004a0G00`:400?31D05Q<L00l<5@0?31<05Q<J
00X73P0B41D05A<H06YXJ`0R82<0928U09JDU@3`kNH0MgA[01hK5@0?2`P03`/:018=4P0@2a804@`C
018=500B3A<04@`A010;3`0300802`H:00<00P0E41@030L;01dH700D3a<04@`@00l:3P02014<4003
00l:3P0A31004`hB00804`hB00@040/?00d8300B3A404@`@0P0@2`l00`0A31004PdA010;3`03014<
400901<>4P0E41@05A0D01lJ7P0400<04PdA01/F6P0@2`l04PdA00D04@`@00@03`X>00d8300B3A40
4`hB0P0>2@d06`0>2P/03`/:014=300B3Pd04@d<00l;2P0A3@h03`X>00l:4@0C3AP05a4O01TC7`0?
2@d05@lA01@>400@2P`040X>018<400<1PX03`P?01<<4`0@2A003PL?014;400>20X030H800d72@03
00h82P0B01D?4@070@<03`T;00L10`0E3a402`D702PR90080P@040X<00`6200H4QH02`H9010:3P0?
20l040T@018;4P0B2a<03`P?0P0=1`/200h8300?00l93@0>20`040X>00d72`0@2Ph03PP<014;3`0O
5Q/05``B00l42P0=0PP03`@:01873@0>0`T03`@:00D04@H<0P0@1@/01`0?10X03P<900`11`0C20h0
40D;00h32@0=0PP00P0>0`T0300900H03`@<01D:4P0700@06a0H00L0100900H04@H>01L<500>0`/0
2@0600l430H03P8<0180300:00l53@0@10h03@4;01<74@0>0P`03`@<01873`0;00P05@XB02lT;007
00@03@8:01053@0700@02`0801X?5`0700@Dooooo`006oooool0200=2``04@l@01@B4`0=2``05Q@E
01<A4P0:20T030X;0P0>30d01@0<2P/02PP900h=2`0=30X030/900803Pd;00P030/900l>300<2`T0
3`h<00h=2`0<2`T03`h<00h:2`<03`/<0P0@30d0300?2``020@500T51P0=2@X040`=01<?400?2`X0
2PH502@P7`0H51<0:2@S018>3@L03`/:00D02@D400h:2@0J5QD0CDU805=?CP0500l;2P0300l;2`0?
2``03`/<00803`/<02D03PX;00T51P0@30d061@E00@00@0R7Ql00`0001<>3`0=1`T03`/<01HB4`0B
3Pl03@/<00l=3P0B41404A4A00l?3`0A4A403Ph>00P7200E4a@03@/<018@4@071@H00@0001PF5`0G
5AH020H700800@0100009R@U05IDE@0O7Ah020H700D310091`P04a4B00803@/<00@030X;00d;300?
3@h04Q0A300<2Pd300d;308030X;00@03P`=00d;30050`@01P@50P0A3a000`0<2P/03@/<00d;3002
00h<3@803`d>0P0=2``0200<2P/03P`=00h<3@0:20T02@P600X91`0;2PP030/90P0>3@/0200A40h0
3`h<00T81P081`D05QDC02TX9P0?3@h03@/<0P0;2@X0100=2``03`d>00X82@0<2P/300h<3@0300`:
2`0:2@L02`X8008030/900@02`X800X91`0<2`T030/90P0=30X01P0<2`T02`X800d;300=2``030X;
00/92P802PP900l040h?028P8@17ADH040h?00/92P0C4A8020H900l=400>30l020H901dK7P0S8B@0
71XM00D31P0100800P071@P01@0B41<01`D801/I70050`P0;b`d00807Q/T00d03P/E00`94P0<2Q00
3@/>00h<3`0>31003@XA00`9400<2A402`PA00X7400<2A<03@XE00@03@TG00P04@dJ00P5400;21<0
20D?00X7400X9Bh0FeQP01XG7P8040hC01@03`dB00h<4@0B3aH08b0Y00X7400@3AD03@XA01lL8`0?
3A<02@L<010>4@0E4aH03@/>00h<3`0?3@h02PP900/92P0?3@h030X;00X82@803P`=0P0?3@h02P0>
30d030X;010;3`0<1`/03PT=014<400?2Ph04`hB018=4@0>2@d200l:3P0400`72`0?2Ph020H900X8
2`803`d@00<02`T<00`:3@0@3Q400P0@3Q40100610L04Q0C00d;3P0;2@X400d;300?00/92P0@3Pl0
1PD50040000B41402PP900T7200<2P/01@<400`:2`0B41403@/<00P61`0100002@L800803P`=00P0
20H700@20`0B3Pl03@T:014=3P0U8B8071PI00P41@H03@T:00/02`L800d92P0=2@X030P900h:2`0?
2``03@T:00`82@060P<03@T:014=3P0200X61`0800/7200U8B80104100L3100;1`P02@D600P41@0:
1PL200d92P0800`82@0;1`P03@T:00X61`0<20T03@T:00`82@0:1PL200`82@0300X61`0;1`P03@T:
008030P900@03`/<00`82@091@H03@T:0`0<20T200/7200:00`82@0;1`P02PH700`82@091@H02`L8
00`82@0:1PL05Q8C01hJ6`802`L800P03PX;014=3P0A3@h02`L800<0000j=SL0HemP018>3`802PH7
00P03PX;00d92P0:1PP040/?018=4@0;1PX020<700/62P803@P<00P02PD900T4200;1PX03PT=00l;
300;1`P02@D600d92P803PX;01P04Ph?00D10P091@H05A4B00X61`0B3Pl00`0200`72`0>2@d04@`@
00d8300:1PT03PT=00/62P080`L050lC01LB5P0>2@d04`l@00X61`0>2P/040`=00L3100;1`P200T5
1P0B00/7200<20T03`/<010<3@24P7l06ADE00`72`0=20h020H<01@A600T8BP0@d9700L830061PP0
2`d;018B4P0:20/030L=0P0=20h200h93`0C00H11`060PL06aHL01/F70070`P01`8801HD5`0:20/0
5A<F018@4`0:20/0>3Hi00L5200<2Pd03@/>00X82`0;2@`03`d@00`72`0200/62P0_00d8300>2@d0
3`X>00d9300D3a<030L;010<3`0?2Ph01`8600d;3P071@P02PP;00/930081PT03`d@00d;3P0>30l0
1`D800d;3P0A3a8020P:00d>3`0C5A009BPQ02<V6@1_Lf@0b/jm0:JZV@1DF4X0?3ld02d`:P0S9B@0
3a4@01/I6P091`P00P4200h<3`0;2@h02`T?01HC6P050P/01@<;01TF7`0B3aX04PlG00d;400<2Pl0
0P0=2a004P0;2@h030X?010>4`0?3A803@/@00`:3`0?3A806aTN01DC600>31404a4F00X83@0<2Pl0
4Q0E00d;400;2@h02PP=00/93P803@/@0P0<2Pl01P0=2a003P`A00l<4`0100L0924Z00T73`803P/F
00<040dG00h;500>2a80100>2a80<P0=2Q40CdaC01PE70081@`04PlF00h;4P0?31D07AXS01@A6P0F
4aX0514H00`9400I5a`02`T>01DC5P0F51L01P@70::QX@3oo_L0Ogac01XG4@0>2PL04@d<014<4@0@
2a804@`C018=500B3A<04@`B010;4@0A3100=S4e00d8300J5AT02@@801/F6P0D3a<04@`@010;3`0A
31004PdA010;3`0A31004PdA01<>4P0B3A4040/?00h93@0B3A404@`@0P0@2`l0100A31004PdA01<>
4P0B3A4201<>4P08018=4@0@2`l06QDI00D1100B3A404`hB00<00P0A3102018=4@804@`@0`0@2`l0
7P0>2@d04PdA018=4@0>2@d03`X>00d92P0@30/04Ph=018>2`0A3@X040`9014=3@0A31004PdD01<=
600B31X04P`H00l93@0E3a4050h@010:300@2Ph04P`@014;3`0B2a805a0G01<<4`0@2A404``B00l9
2`803@L900<03PP:00d72@0=1`T00P0=1`T04P0M5aT03@L900d72@0910D0618D0;J`/P0K5AL0AT12
01H@500P6Qh03@L;00d63@0A2Q404P/B014:4P0>1`h03@L;00h830<03`T=00h03PP<01@>4P0?2@d0
3@L;014;3`0<1PX04`/@01H;4@0A1P`040D;0146300@1@/03P<900l42P@04@H<00L04`P>0146300?
10X0304700d2200@1@/03`@:008040D;00X03P<900`11`0?10X05@XB00T01P0=0PX02`0806AIH@0C
21003P<;0P0@1@d00`0=0PX0304900l4300600h2300B01043P0:00P03P8<0186400?0`d040@>0146
3P0=10X04PL?01X?5`1ICUH04@H>00L0100=0`X06@hF01`A6@0B1`l01`045?ooool001_ooooo00D0
3`d>01<A4P0B41402@L800l=3P0700`:2`0300h=2`0=30T030/800803Pd:00L030/800l>2`0<2`P0
3`h;00h=2P0<2`P03`h<00H03`/<00`05A4B014=3P0@30d03`/<010<3@0?2``040`;00l;2P0A3@`0
4Ph=014=300<20L600l;2P0>010<2`0=2@P04Ph=010<2`0Z9RD09B4P010<2`0?2`X03PX900l;2P0@
30/03PX:00d92P0>2P/2010<3@803`/<02<040`=01@@4@0;1`P0510A00P41@0E414040X<00X61`0=
2@X03PX;00d;300?3@h030X;00/;2`0>3Ph06ATI01PH600?3Ph0G5YK05ABD`0A3a004a4B00T8200=
2``03`d>00P61`0<2P/05A<D010>3`0C4A803P`=018@4@0D4Q<03P`=00P61`0300`:2`803@/<00<0
3P`=00`:3@0<2Pd0100<2Pd200d;3P803P`?0P0?3A000`0<2P/03@/<00d;300200/92P0700h<3@1^
K6d0AdE6014?400:20T040h?00h<3@0200/92P8030X;0P0=2``01`0?3@h03P`=00`:2`0?3@h04Q0A
00T7200:2@L00P0;2PL400`;200500d<2@0<2`P02PT600/:1`0>3@/01P0=2``0200;2@X03@/<00l=
3P0>30d03@/<00`:2`0>3@/03@`90P0;2PL0100=30T03Pd:00`;200<2`P200d<2@0300`;200;2PP0
3@/<00803@/<00L030X;00/92P0;2@X040h?00H41@0D4Q<02`T:00802PP901T03@/>00`:3@081PT0
40hA01dK7P0P7R403P`?00`:3@0G5AP07Q`O00/9300=2`h040hB00X83@0J5ah02@L@00`85@0@31T0
3@XF00`9500<2A403@/@00h<4@0?3A<03``C00803P/C00@030TB00/84P0=2Q@03P/F100>2QP0100=
2QH05A8M014>6@0<2A<200h;500H01HC6`0>2a802PP=00d;400;2@h030X?010=500O72D030TB00h;
4`0@3A@04a0G00d;4@091``04@lB01LE600;2@`03@/>00h<3@0;2@X03P`=010>3`0<2P/03@/<0`0?
3@h07@0>30d03@/<00d;300A31003PT=014<400D3a<04@`@018=4@0A31003PT=00l:3P0@2`l03@P<
010;3`0A3a803`d@00/930091`X02PP;00`:3@0>30l02PP;00`:3@0>30l02PP;00X92`0<2P/03@/<
00803P`=01/03@/<00`:2`081PL0=C<d01PF5`0@3Pl02PP9014?400=2``02`T:00d;30081PL03@/<
02@R8`0b<3407A/L00X82@081PL03@/<010>3`0810D040`=00`82@0>2P/02`L801<?400<20T00`0=
2@X200h:2`0K00l;300=2@X02`L800X61`0;1`P02PH700l;300A3@h03PX;00/7200D414071PI00l;
300H51D0@cm001LC500:1PL03PX;00d92P0<20T03@T:00l;300=2@X02`L800h:2`0;1`P02PH70080
2`L800@02PH700l;300@30d03`/<0P0=2@X01`0>2P/030P900`82@0?2``02`L800X61`0?2``01@0>
2P/0100?2``030P900/7200?2``200d92P0E014=3P0<20T02PH700l;300=2@X02`L8010<3@0?2``0
1`@400`82@0:1PL02@D601HB4`0A3@h030P900X61`0;1`P030P900X6200?2Ph04PdA00802`H:0P0>
2@d01P0=20`030L;00/62P0<1`/03@P<00l;30802PH701/03`/<00d92P0=2@X02@D6010<3@0A3@h0
1`<400T51P0:1PL0:RDY03lj?P0<20/02PD900D1100=20`04PdA00<00P0D3a<01P8500T4200?2Ph0
0`0001TE5P091@H04`l@00H20`0<20T00P0;1`P400d92P803P/;00/02@P800X9300=2a001`L<040o
A@1BDeP03Q0B00d@3`082`P02@X900T72P0200`73@<03@P>00P03`X@00/6300=20h03@P>00`73@0?
2Q0040hA00X82`802`T<00<03@/>00X82`0:20/0100<2Pd01@0:20/03PT=00`72`0<1`/02`H:0080
30L;00d040/?00X52@0?2`h04@`@08=nPP1@Bdl02`T<010>4@091`X03@/>00L5200>30l03`d@0080
2`T<02T03`d@014?4P0@41404aHC01dQ6@0[<2<0GF=B0<G;]@3mond0m_[V0:neXP1TJET0:RhU018F
4@0J71X040l?01@B4`0C4A<02`X<014?500>31802`P?00d:4`0a;SL0;2Tb010>600:1`l03P`A00l=
4P0>314030X?00/93P0>31403@/@00`:3`0=2a003P`A00d;400@3Q<030X?00T7300200`:3`0800/9
3P0=2a0030X?00/93P0:20d02`T>00`:3`0=2a0400`:3`0800`9400A3aL0I65Z03<`>@0=2QD04a0K
01<@6P0?31D200l<4`803P/B01T03@XA00/93`0E4QT02PL>00l<4`040PP040dD014>5`0C41T040dF
018?5P0<2A00514H010>4`081P/05Q@G00/:300K6A`0<S0a05YGC`0/:Qh03``500l<1`0?2`X04`lA
00804PdC00L040/B010;4@0B3A<04PdC018>4@12?D4030P;00804`hB00@03`X>01D@500B3A4040/?
0P0B3A400`0@2`l04PdA018=4@02010;3`04018=4@0C3Q804PdA014<408040/?00<04@`@018=4@0D
3a<00P0A31002P0B3A4040/?00`72`0B3A40AD14010;3`0>2@d05Q4E00h93@0?2Ph3014<400E010;
3`0?2Ph04PdA014<400D3a<04`hB010;3`0D3a<040`=018>3@0A3@`03`/8010<200B3P/04@d=014<
400A31<040XF00h75`0>21D040X>00<040X<0`0@2Ph01P0?20l040T@014:4@0@2A404`dB01<=3`<0
4@/=010040X<00h82P0@2P`04@/=00d82@0A2`d040X<018<3P0<1`P05Q0B00l92`0X8b@04@/?01PB
5P0A2`l030D<0P0?20l05@0>1`l03`P?010:3P0A2`l04`dA018<400A2`l03PP<01@>4P0@2Ph03@L;
018<400<1PX040L<01<83P0A1P`04PL=0146300?10X03P<900l42P040146300700l42P0@1@/040D;
00l42P0@1@/05P/A00`11`0201`A5`0?01052`0>0`T04@L<00h52`0=0PX04`P@00T01P1<@DT050XA
01463P0>0`/03@8:00l4300@1@d03P<;00H03@4;00L04@D?01hD700800H04PH@00d12`0?0`d04PL?
0080308900T04`P@03`a>@0900H05P/C01473P0i;SH0>2de00l5300D2A405?ooool001_ooooo00P0
20H700h<3@0?3@h01@<400d;300<2P/03P`=00`:2`802PP900h030X;00h<3@0>3@/03@`900`;1`0>
3@/03Pd:00`;1`0@3`d03@`9010?2`0?3P/03@`:010?3@H03`/<00d05Q8C01<?400>2P/03@T:018>
3`0D4140>cXh018A3`0300004Ph=00d9200E4A0040/:00803`/:02X03P`:00d<2P0=30X03`/:00d9
200A3@`02PH501LC4P0:1PD04@d<00h:2@0=2@P03PX9010<2`0?2`/03PX;00l;300@30d03PX;00d9
2P0C3a0030P900h:2`0B3Pl01`<401LC500<1`T03@L;00l:3P0H51D04Ph?00X61`0<2@X02@L800D3
100<2P/03`h<00X91`0:2@P04@l@018@4@0@3Pl200X82@0;00h<3@040P<030X;010>3`040P<03P`=
01DC500>30d030X;00X82@081PL00P0>30d01@0?3@h04@l@014?400@3Pl03P`=00H030X=0P0>30l2
00l=4003010>4@0A3a802`/=008030`>0P0820X01`0=3@h02@T900l=3P0F51D03P`=00H41@0=2``0
0P0@3Pl0100?3@h03P`=00d;300<2P/200l=3P0B00`:2`0@3Pl0518C00T7200>3@/03Pd:00d<200=
30X03@`900`;1`0@3`d03Pd:00d<200?3P`03`h;00`;2@0;2@X03@/<0P0?3@h01@0=2``02`T:01PF
5`0E4a@04@l@008040hA00<04@l@00h=2`0=30X00`0=30X00`0>3@/030/900`;2@0200d<2P0300`;
2@0;2PP03P`=00D03P`=01h03`d>014?40081PL03@/<00l=3P0C4A804@lB00d;3P091`X03`d@00T7
2P081PT03P`?00400P091`X04a4D00T72P0A3a803`dB014>5@081@`04a0I00T64@081A0030TD00`9
4P0<2A403@XA00l=4P0A3aD2018?6003014>5`0?31D03P/F00803P/F100>2QP07`0A3A`04`lN0080
3@0>2QP01P<>01LD7`091Q402`PA010=5P0F4aX03``C00`9400;20l0514H00d:4`091`d04@hE00H3
2P0<2A001P<:00d;400A3a@01@<800`93`091``02`T<018@4`0C4A@03@/>00h<3`0;2@`00P0<2P/2
00/92P0K00h<3@0=2`h02@L:00X72P0<1`/02@@800`72`0?2Ph02`H:00`83@0<2Pl02@L<00/:3`09
1`X02PP;00`:3@0@3Q404@lB00/9300:20/02@L:00@21@0?3A002`T<00d;3P0>2P/03`/<008040`=
00L03P/<00`:2`0E4a@04a4B0040000?3@h01P@5008040h?01402PP9018@4@0C4A802@L800h<3@0@
3Pl020H700X82@0B41404@l@00H41@0810D03`/<00h:2`0E4A8030P900T51P0200`82@803@T:0P0>
2P/00`0;1`P030P900h:2`02014=3P0>00l;300L61T01@4200T51P0>2P/02`L800`82@0?2``02`L8
014=3P0@30d00`0001<?400<20T200T51P0900`82@0?2``03`/<010<3@0A3@h040`=00/7200>2P/0
510A00803PX;00@03@T:00X61`0:1PL02`L80P0<20T0100>2P/02PH700/7200>2P/600`82@0=00P4
1@080`L03@T;00`82@0:1@T02PD800l;300A31002@@701LC500_:Rh09b<T00L3100200`82@0600<0
000;1`P02`L800T4200;1PX030L;0P0:1@T0200<1`/03PT=00d8300;1PX03`X>00d8300:1@T030L;
0P0=20`200`72`0:00d92P0810D02`L800l;300:1PL02`L801@@4@0300002PH700h:2`802PH70180
40/?03`g>`060PD05A0D00T420091@P030L;01LB5P060@D061<G00T420070`H03PX;04Y6A`0E4A80
4Ph?00/7200810D300d92P0A00`82@0;1`P02@D600800@0<2``00@4300P82P040`P04a@I00X;400>
3a@0004200/<3P041PH00`D400T72P0;1PX00P0<1`/200d8300=00d83P0D3aD03`X@00h93`0@2a40
20<9044o@P0@3Q403`d@010>4@0:20/02`T<00d;3P0200/9300?00h<3`0<2Pd01@<601PC5`0D3a<0
4PdA00l:3P0=20`030L;00T4200I51P01P45010<3`0E41@02PD900<03@/>02d02PP;00/9300a;c80
5aDH00h<3`0B41<03`d@00`:3@0A4A403Q8=01lU6`0e>bd0LGQT0<C<]03^mm`0m?[S08ZBO@0a>2H0
92XN00`A2`0@4Pl02@P802DS9P0O7B004Q0C01dK800710X03@XA014>5@0G51`03P/D00P53P0;2100
3@/@018?5P0?31802PP=00`9400<2Q001P@900D22@0<2@l040hC00`940091``00P0?3A8010081P/0
2PP=00d;400<2Pl500/93P<030X?00T02`T>00X83@091Pd03@XA01HC6P0?31D040dF00P53P0E4Q/0
0`0?31<01@0>2a803@XA00d:4@0?31<00@05008030T@01H02PL>010=500B3aH01P<:010=5@0F4aX0
2@H=00h;4P091``02`T>018@4`0N71l04a4D00d<3@0>2`H0514800h;1@0@30T03`/:010<3P0D3aD0
4@`B0P0>2@l02`0A318050lE01D@500;1`X03@P<01PC5`0=20`04PdA01D@500B3A404@`@00804PdA
00T04@`@01<>4P0@2`l03@P<00h93@0C3Q805Q4E018=4@0A31000P0@2`l02P0A31004PdA01HA5@0@
2`l03PT=010;3`0B3A4040/?00l:3P0I51P201D@500400D0100E41@04PdA01<>4P805A0D024050lC
01<>4P0@2`l03`X>018=4@0?2Ph03PT=018=4@0B3Pl04`l>010<2`0=2@L03`/8018>2`0@30`03@P<
00/6300<1Q403`TG014;5@0A2`l02`D700`6200@2P`040X>00h8300B31004@/?00/52@0@2A004``C
014;400B30h00P0@2P`08P0?2``03PX;010<3@0=2@X03`/<00/51`0@2P`03PP:01072P0O5QL04`X;
01092`0K5AL05Q0B020K7`0M61`040/A00l83`0>1`h03`P@0109400=1`/04@P=018:3`0@2Ph04@P=
00`52@0>20`03PD:00l8300:10P03PD:01T?5@0A1P`200h32@0401052`0A1P`03P<900l42P@04@H<
01003`@:01<83P0E2Q004PL=01052`0B1`d03P<902XO9@0X7B<04PL=01052`0A20`04PL?01D:4P0?
10`05P/C0P0@1@d01P0=0PX03P<;01873`0C21004PL?00h32`803@8:01H03@8;00d12`0=0P/03@8:
01864013>4401`0400h2300B1a0040D=00X01`0B1`l01`0401P=5@0900H05P/C00T01P0=0PX02P07
00d22P0B1`l02P075?ooool001_ooooo00P01`D600`:2`0B41403`d>00L51P081PL061HG00l=3P80
3@/<00d03P`=01@B4`0>2P/040`<014=300A3@h03`/;00`81`0B3Pl04@d=00l;2P0?2`/03`/<0080
40`=01P03`/<00h:2`0?2``03`/<010<3@0B3Pl03`/<00h:2`0B3Pl00`0001XH6@0H6AH01PL200d<
200C3``03PT6014<2@0B2`T03@T6014=2P0B4Ph03a4<00d=2`0@3Pd201DA4P0?014=3P0>2P/03PX;
00h:2`0C3a00Cd]<01lK70030000510A00H20`0C3a004@d>00l;300>2P/04@d>00D03`/<00X04P`A
00h73P0B2a806A<G00l93@0I4aL030L900h:2@0=2@P03`/:0P0=2@H0500A3P`03P`=00X82@0B4140
2`T:00T7200B41402`T:00l=3P0;2@X03@/<010>3`0<2P/040h?00/92P0B41402`T:010>3`0A3a00
3P`=0P0;2@X07`0=2``03`d>00`:2`0;2@X030X;00d;300@3Pl04a4B00P61`0?3@h040h?00`:2`0>
30d02PT;00hB5@0?51P01@T<01@H6`0:3Q4010D800X;3@0;2`d03@d=00d<2P0;2PP03Pd;00X82@07
1@H02`T:00l=3P0=2``00`0>30d0400K6AX0518C00h<3@0610D03@/<00X9200=30X040h?00h=300=
30X03@/<00/:2@0=30X03`d>00d<2`0610D400`:2`0J00`:300<2Pd01P@703hl?`1]Jfh07A/P00l=
4P091``02`T<00d;300;2@X03P`=018@4@0>30d03`d>00X82@0>30d04@l@00/92P081PL030X;00d;
300<2P/02@L801@B4`0Q7b0200`:2`0<00d;300>30d02`T:00P61`0D3a<04@`@010;3`0A310040/?
00l:3P0A31003`X>0P0<1`/09`0@2`l050lC00l=4P0<2Pl02`T>00X73P0?31<03@XA018?5P0;20l0
2`T?00d;400<2Pl040dE00h;5P0J5b805a@O00l<5`0E4Qd030TD00/84`0D4A`02PLB014>6@0;21<0
4PlO0080500E4RL02`PK01HC900f<d@0518P00h<6@0G5B805aDQ00d;5P091a802`T@00d;400300d:
4@<03@XC0P0=2QD01`0>2aH040dI01DB6`050P/03@XA00`9400?31<00P0=2a0200d;3P0C00d;300<
2P/02PT900/;3@0D5AL020L901/G600?2``03PP:01D@500I51P00P4601@D700;3QL03a<K01DD6@05
0`H030X=00d;3P0200P62@08014?4P0?3A003@/>00l=400>30l02`L;00l93@0<1PX200h8300:00P3
1P0:1@T030L;010<400100803@/>00h<3`0C4A@02`H:00`72`803@P<00H03PT=00l:3P080`L040/?
00h93@0400<300d8300G00`72`0;1PX030L;00h93@0@2`l03`X>00T4200B3A4050lC00`72`0D3a<0
3PT=014<400>2@d02`H:00d8300A3100DTeA00H11@0@2`l03@P<01<>4P070PH00P0>2@d200l:3P0b
00h93@0=20`01`<6014<400D3a<01P8501PC5`0;1PX03`/<08j:R`0O6a`02`L801<?400>2P/02@D6
00<0000W8b@01P8301DA4P0@30d03PX;00d92P0@30d0510A014=3P0?2``04@d>00l;300<20T02@D6
00/7200>2P`01`8601`G7@091@T05Q4E00h93`0;1P/030L;01@?5@0@31002`H:059=D`12?Sl030P7
00/71P0=2@T03PX;00/62P0:1@T400/6300500/63@0;1P`02PD900X52@0;1PX00P0<1`/01`0=20`0
30L;00`72`0;1PX030L;00d8300910P00P0B3A40400:1@T030L;00h93@0:1@T02@@800X52@0;1PX0
3PT=014<400>2P/00`0000h:2`0;1`P02@D600`82@0@30d200X61`0301DA4P0D414020@500<030P9
00<02`L800X61`0:1PL00P091@H02@0;1`P030P900l;300@30d03`dB020O900000@05QDJ018A5`02
00L6300C01HE6`0h>Cd0000400l?50061PP030X;00l;2`0A3@h020@500d92P0;1`P02`H:00d8300B
3A403`X>00L21`0<1`d03PT=00/7200200h:2`0400X61`0<20T030P900`82@803@T:00`03PX;00h9
3@0=20h03PT?00H11`0=20h04PdA014<400?2Ph030P900<0000A3@h200P41@0I00X82@0<2P/030X;
00`:2`0:20T020H7028P8@0:20T01`D6018@4@081PL06a/K018F4@0K81T0>d4e03Dl:P1[Le`0XJVA
0;W1Z@1DG4L09RdM01@J3`0?50h03a4>00`;3P0201<A5P803@/@01l05aDJ06YXK@1=Be003P`B00`9
40060`X02PH=00d83`0=1a403@P@00d83`0;21402`P@00d:4@0:2A402`XA00`;4@0>3AD02`X?00D3
200<2Pl03@/@0040100c<CH0AD=800/93P091``03`dB00P62`091``040hC00803@/@00L030X?00d;
400>31407Q`Q01HD6@0;20l030T@00803``C00L030T@00d:4@0@3A@040dD00l<4`0=2Q4040dD00<0
3``C00D040dD018?5P0A3QD04@lD014>5002010>4`0D00l=4P081P/03@/@01<A5P0A3a@03`dB010>
4P0B41405QDC01@C4P0>30d040h?018@4`0>30l02`T<00l=40091`X03@/>00T72P0?3A02014?4P0Y
00l=400<2Pd020H900`:3@081PT04@lB00H41`0n?3l04a4D01<A5P0A3a@030X?01<A5P1HEU/0BDM<
014?500@3Q<04@lD01<A5P0E4aP04a4F01D@5P0>2@l02`H<00h93`0B3A<04@`B010;4@0B3A<040/A
00h93`0B3A<05Q4G010;3`0I51P030L;014<400P6al03@P<01D@50070PH00P0?2Ph0;00=20`030L;
014=3P0A3@h04`l@010<300?2`X0510?01@@4@0G4a@04`hB00d83@0H4aT04`hB014;3P0>20X030H8
00d72@0@2P`04@/=00h92P0@2P`06A<E00P31P0K5AT0204501483@0>20`040X>00X82`081PT03P`?
00X82`0100803@P<00T31`0C2Pl07a8F01L92@0?0`<04PP9014;2`0@30/030X<0P0@3Q40900;1P/0
3PL>014:4P0B210040L<01052`0B20d04PT>0146300A1``05PdB01T>500@1P`03@@901L<4P0H3A<0
3`@:01873@0C20h04@H<00l42P0>0`T04PL=01@93`0=0PP02`0601052`0900<03@0701@73P0E20l0
4@@;00X0100B1@`04@@;0185308050L>00L04@@;01D83`0>0@P03@0701/>5@2hZk8091LN00<040<:
00<03`8900h1200>0@P00P0>0@P02P0?0PX03`8;01032`0@0`X0200401853@0A10/03`8;00h12@09
00<800l22@8040<:00<04@@;01853?ooool04oooool001_ooooo00<04Q0A00/92P0<2P/00P0@3Pl0
0`0A3a0030X;00X82@0300d;300301<A4P0@30d03`/<00@03PX;00@04`l@018>3`0@30d040`=0P0A
3@h0100?2``03PX;00h:2`0?2``2014=3P0T00d92P0F4Q<030P901<?400k=cP020H700h@30041@80
2PX7010<2P0@20L05@d<01H?3P0<1`D03@`900h>2`0B51007QlM01DB4`0D41404@d>00h:2`0A3@h0
510A014=3P0>2P/06aLH00`82@0=2@X03``<01XF5`091@H040`=01hJ6`0j=SL0510A1@0?2``0400C
3A<020@901H@5`0B3A803`X>00/6200>2@/03@P800h92@0D3`d040`900l:1`0>2`T04Q0A00d;300:
20T200h<3@0:01DC50091`P030X;00l=3P0<2P/040h?00d;300T8R<07Q`M014?40802`T:00@03P`=
00`:2`0;2@X030X;0P0=2``300`:2`0Y00d;300>30d040h?010>3`0:20T01`D601LE5P0Q7b0051<E
00P<3`0?5Q/092T/00/@50062`h02`lB00T:300`<C<09bLW0040000?3P`04A0=010>3`0<2P/03@/<
00h<3@0<2P/03`d>014?400<2P/02PT900L51P0A3a0030X;00T7200>30d040h?00d;30091`P02PP9
00h<3@0=2``00P0:20T600`:2`0D00`:300<2Pd0518E014?4`0R82D02`T>01LE6`0=2a002`T>00d;
3P0;2@`03P`?018@4`0=2`h03`d@00h<3`091`X02PP;00/930081PT200`:2`0400l=3P0>30d03`d>
01@B4`802`T:00P03@/<010>3`0?3@h03@/<00d8300<1`/03PT=018=4@8050lC0P0@2`l04`0>2@d0
3@P<010;3`0B3A403@/@00l=4P0<2Pl04a4F00d;400D4QL02`T>00`:3`0?3A8040hC00d;400;2100
3``G010=600?31L00`0;21<04`0K62<0;BXe018?6P0D4A`03@XE00l<7@040QL03`/Q00l<800>2al0
6QLZ00h;7@0D4B806QPW01TG9@0A3a`03P`J00h;5@0=2a000P0=2a409@0=2Q403@XC00`94`0<2A@0
3@TG00h:6@0>2QP03@TH00d95`0@3AP02`PA00L43@0?31D02`P?00`:3`0=2a003@/>00d;300<2P/0
2PT:00T;3P0520X01`T;01<A500<2@/03`X<010;3`0?2Ph030/@00T;4`000@/0LGIn02XY;P0A3a80
2@L:00X82`0;2@`00P0>30l200`:3@803P`?00d02`P;00T41`0A20d04PT>00P31P0T7R803PP<01TD
60081@P03`d@024O8P0d<SD02@L:00H03@P<00H02`H:014<400<1`/020<700d8300?2Ph600d83008
020K7`0G4QH061<G00L31P0T7b<02`H:00h93@0=20`200/62P8030L;00D03PX=00`82`0K5QX030L;
01@?4`0200l:3P0300d8300<1`/02`H:00802`H:00/03@P<00/62P0>2@d03`X>00H21@0@2`l030P9
024M7P081@D03PX;00l;300200X61`0J01DA4P0Z9RL05Q8C00T51P0:1PL06ADF00L4100<20T08AdN
01PD5@0=2@X03`/<00h:2`0?2``040`=00h:2`0:1PP05A0E03D`=@0B3A80100400L21`0>2Ph04`hC
00<00`0=2@d201@?500800h:2`0<20H02`L600`8200=2@X02`H:00X52P0<1`d300`73P0400`73`0<
1`d02`H:00/62P<030L;00/03@P<00`72`0<1`/02`H:00`72`0=20`020<700h93@0?2Ph02@@800X5
2@0500/62P0>00d8300?2Ph04@d>00D10P0<20T02`L800h:2`0E4A80JfMX01XG5`0?2``0104100X6
1`0B3Pl300`82@802`L802002PH700`82@0=2@X03PX;00d92P0<20T01`D800L52P0Q82D030/@00T8
3P0410T03`hC00`<4@0i>3h0UIBI01<C60081`d030`?014=300=2@L03`/:00h:2@0A3@d03PX;00d9
2P0>2P`04PdA010;3`0<1``040/?018=4@8030P900@02`L800X61`0?2``030P90`0=2@X0<`0>2P/0
3PT=014<4`0810T03PT?00d93P0C3Q80<B``00l;3P0C3a004Ph?00h:2`0:1PL03@T:00/92P0?3@h0
2PP900l=3P0C4A803P`=02@R8`0H5QL030X;00l=3P0C4A803Ph>00lA3P0F6A<06alE02H[700U;1H0
>D0Y04Y@>`0[<B007b@E01@H3`0>4@h03a4@00`;3`0<2Pl03@/@00l=4P0A3a@030X?02DS:00C4AH0
2PP=00`:3`0>31403`XB00h64@0300d74@0D00/84@0A3QL00`4900l>5P0E51`0Ti:J01`K8`0=2a80
2@L<00`:3`0A3a@02PP=020N8`0X9R/03@/@01<A5P0M6b004Q0E00/93P0>314200d;400900`:3`0=
2a003P`A01@B5`0?3A802PP=00d;400A3a@040hC00<030T@0P0=2Q40100>2a803``C00l<4`0?31<2
010=5003014>5@0?3A803`dB00803P`A0P0=2a001`0O7B804@lD010>4`0B41D03P`A02HT:@0A3a80
0P0F51L01@0A3a804Q0C018@4`0B41<02`T<00804@lB00P06ALJ01<A500@3Q403`d@010>4@0C4A@0
6QPK01lM80804@lB0100518E00l=400Z:2/04@lB00X83@0I5a`040hC00d;400Q7b@071XO014?500D
4QL05A<H018@5@0@3Q<03`dB0P0B3A<01P0D3aD05A0F018=4`0;1P`04@`B018=4`8040/A00D04`hD
01HA5`0@2`l05a8F018=4@02014<400401@?4`0>2@d04PdA01D@50804PdA03<061<G00l;300@30d0
4`l@010<3@0?2``0510A01<?400?2``020@502@P8@0c;c004Ph?018<3P0@2P`03PP:00l92`0A2`d0
4P`>01@>400;1@L02`H701LA4`0910D050`@01@;400=1`/04PdA014?4P0>3Q004a<E00/;3@0H5QT0
2`L:01LA5@0D2a006`lA020@4@0H2PX05P/<010:2P0<20P03Pd=01@D5@0D4QD030T=00`73@0?1@d0
3P@;01052`0B1`d00P0C20h201873@0701<83P0F2a404`P>00h32@0@1@/04@H<00l42P0301052`04
00l42P0=0PP03`@:01052`803`@:00<040D;0185300D1`h00P0H2a800`0F2A004@@;018530020144
2`804PD<00L03P8800d01`0A10/05`XA00h3200S6Ad03P8800<040<:0P0?0PT300h120803`890P0@
0`X01P0E20l0304601462`0E2`l04`H=00h220H03`8900<03P4800l22@0?0PT00`0@0`XDooooo`00
6oooool03P0>30d030X;018@4@0B41402`T:00T7200B41402PP900`:2`0?3@h03@/<00`:2`0@30d0
3`/<0P0<20T01P0=2@X03PX;01<?400C3a004@d>010<3@804@d>0`0>2P/09`0@30d04@d>018>3`0E
4A8061@E01@@4@0B3Pl0R8B502h/;@0<3@/02`/900l?3@0A3@`04`d=01/B4`0T7Ad03PX900l>3009
2@L020X701LG5@0A3Pl03`/<00`82@0:1PL03@T:010<3@0<20T0510A00H20`0=2@X06ADF01@@4@0a
;Bh05a<D00X61`0<20T081`M00T61P0500l;300Q00`72`0S7R@0E4mE01XE6P0?2Ph00`0001PD5@0?
2``03@T800h:200<20D03`/8014>3@0:20T030X;01DC50030@807Q`M04]9BP0H5QL00P0100l=3P0D
4Q<04@l@00/92P1eLg@0FeUJ00<10P0C4A806QPI00/92P0:20T02`T:00803@/<00D02PP900`:2`0<
2P/030X;00/92P0200`:2`0C00/92P0>30d03@/<00H41@071@H03@`>00lC5P1bMg/0]kc001`Q900>
4aH03a<F00D6200=3Q003Ph>00/:200?3P`04A0>010>3`0200`:2`802`T:01<04@l@01lM7P0<2P/0
4@l@00d;300>30d040h?00/92P0C4A80518C01<A4P0A3a0030X;00d;300@3Pl03P`=00X82@0;2@X0
40h?00@030X;01D030X<00`:3@0200<02@L;01<A5P0B41D03``B00L52P0<2Pl03@/>00/9300=2`h0
4@lB00`:3@0;2@`03`d@00P62@0=2`h04Q0C00X82`0>30d00P0;2@X02P0:20T03P`=01DC500=2``0
30X;00d;300A3a0040h?00l=3P0?2Ph200d8300400l:3P0>2@d03@P<00l:3P8040/?01003PT=00l:
3P0@2`l030X?00P62`040PL040hC00l=4P081P/03`dB018@5@0D4QL04a4F00l=4P0=2Q805a@O0P0>
2aH01@0?31L020D@01HC7P0100T00P0:00803@XE00L02PLB01TF900:1aP02`PI01TF9`0E4R<040dP
00803``M00H040dN00d;6P091aD02@LE00`9500=2a0300d:4@0R00d:4`0=2Q@03``G014=6`0C3ad0
4PhL00l;6@0A3QT0:BHa01@A6P091Pl0514J00l<4`0;2@h030X?00d;3P0=2``030X;00/:2`072Pl0
8bP/01TL800B4AH01@<600T6200@2`l030L;00D31`0B4AL02PXB00l?5`0E51T020H900`:3@803`d@
00@03@/>00X82`0:20/02`T<0P0<2Pd03`0<20`050hB00l62`0=10T04`dA03D_<`0600@00`0204=0
@`0a;c804@lB00@21@0D4QD03`X>00h93@0200d8300500`72`0;1PX03PT=010;3`0:1@T00P0>2@d0
4P0@2`l03@P<00l:3P0?2Ph03PT=00`72`0:1@T07APL00d8300>2@d01`8603<^<P080`L04PdA00h9
3@0<1`/040/?00h93@802`H:00H040/?01@?4`0?2Ph040/?00<00P0;1PX200T4200H00d8300A3100
4`hB00`72`0D3a<040/?00h93@0:1@T04`hB00`82@0>2P/06ADF00@10@060P<03`/<00h:2`0;1`P0
0`0000X61`0810D07ATJ010<3@0G4a@03`/<0P0300004`0>2P/02`L800X61`0@30d04`l@00l;300=
2@/00`0200D010091@P04PdA01@?4`070PH00`0200h93@0_:Rh00`0200@00`0:1PP00P0;1`H0100<
20P02`L800X52@0;1P/200d83P<03@P?00<030L=00`72`0<1`/00`0<1`/02@0=20`030L;00`72`0;
1PX030L;00d830080`L02`H:00d8300200T4200300X52@0=20`030L;00@030L;00`00`0000D10P0C
3a001@4200P41@0N6Q/0R8B5020L7@0=2@X0100100h:2`0<20T600/720803`/<01803@T:00/7200:
1PL01`D601DC60040`P00P4600H52P0;2Pl030/@01DD6@0A41D0000401PG700920d0000200<0000<
20H2010<2`0400D20@060P<03@T:00h930803`X>00P03`X?014<400A310030P900d92P0<20T02`L8
00l;30D03@T:01803@P<00`83P0Q72806QDK00/6300>2@d0:B@X08F0Q00?2``04@d>010<3@0A3@h0
6QHG014?400C4A801`D600d;300C4A8200T7200B02HT9@0K6AX03@/<00D3100>3Ph0414@0001000<
3`P0Gf9F038f9@0S9aH0>3`[02P/7P0K7Q<02P`600/=300D5AL04@lD0P0:20d02P0>31403@/@014?
500A3a@020H;018@5@0;2@h04@lD00/63@0>1Q4300d74@0>00/84@0610`01`@=01HE7@0<2a<071/S
00L63P0?3Q<03`dB00`:3`0;2@h02@L<00X83@0?3A8200d;4004014?500=2a0030X?00l=4P803@/@
00@030X?00d;400>31403@/@0P0<2Pl02@0@3Q<04Q0E010>4`0=2Q4030T@00/83`0<2A003@XA010=
500200h;4P@040dD0`0A3a@2010>4`0900l=4P0I5a`04@lD018@5@0@3Q<02@L<01HD6@091`X03P`?
00803`d@01/04Q0C014?4P0@3Q403@/>01<A500@3Q40518E00h<3`0C4A@040hA00d;3P0?3A005Q@G
01`J7@0;2@`040hA00h<3`0@3Q403@/>00`:3@0>31405Q@I010>4`081P/03@/@01TG700A3a@00P0J
61d02@0D4QL03`dB010>4`0C3Q@040/A00l:400A31805Q4G01TD6P04014<4P0C01<>500D3aD050lC
00L21P080`L04PdA07ehO01ED5@061<G00X52@0?2Ph08ahR018=4@0400<03@T:00l;300C3a0040`=
00l;300201<?400900l;300C3a002`L800d92P0;1`P04P`>014;3@0@2P`04@/=00804P`>02<05@lA
01hH6P0G4A<030H801/E5`0?1`/05@`A014;3`0>2@d05A<F05]IG02IVI/06ATK00`:3@0=1`/06Q@H
00X11P0F2@`03`4100/0000?1@D03PP800h:2`0>30d03@d=00h<3`0>2Pl03`P?0188400@1Pd04@H<
01<83P0B1`d03`@:01052`0201873@0401<83P0E2Q004`P>01052`803`@:0`0>0`T0200@1@/03P<9
0146300D2@l03`@:00d2200?10X03`890P0@0`X200l22@0=00h1200C1Pd04@@;01442`0B1@`04@@;
00h1200?0PT04PD<00/11@0I31<02P0401L:4@0600l22@803P480P0?0PT201032P0600h1200?10T0
;1lV03DX;`0J3A@020021P0?0PT600h121Cooooo000Kooooo`0D00@20`0<2P/05Q@E01DC500D4Q<0
71XK028P8@0>30d02PP9010>3`0>30d01`D6014=3P0?2``03@T:00`82@0>2P/03`/<01<?400B3Pl3
010<3@0Z014=3P0?2``03PX;00h:2`0?2``040`=014=3P0>2P/02@D600<0000;1`P06aLH00X82@0;
30T030`:00h>300>2PT03`T901<=3@0E3`l01@4000/:200>3P`02`d:01<C4@0>2``040`=00l;300<
20T02`L800d92P0;1`P05A4B00`82@0B3Pl06ADF00`82@0>2P/04`l@00X61`0B3Pl05a<D1P0?2``0
3@0E4A@01`88028M8@0;1PX03PT=03<_<01HE5D0510A01<?3P0E4A0040`;00l;200@3@`00P071@H0
4P0B41400@0001@B4`0n?3d0518C00@20`0?3@h040h?00h<3@0:20T040h?01LE5P0H5QL00@0000h<
3@0;2@X02PP900/92P803@/<00<02PP900`:2`0<2P/00`0<2P/0100;2@X0108300`:2`0A3a0200P6
1`0G01TH6@052@`0@DA906eaM0000@@02`lB00H6200B4aD01@H800P8200A4A402@T900X82@0B4140
40h?014?400@3Pl04@l@01XH6@2WYJH0;B//0040000:20T00P0?3@h01`0=2``04@l@018@4@0G5AH0
61HG00/92P0<2P/00P0B41400`0?3@h03@/<00l=3P0400`:2`0A00`:300<2Pd01@<600/93@071@X0
108700P6300>314030X?00d;3P0:20/030X=010>4@0;2@`03P`?010>4@0=2`h00P0C4A@0200:20/0
40h?018@4@0B41403P`=014?400I5aP03`d>0P0=2``01@0?3@h03P`=00d;300B3A403PT=00803@P<
00<02`H:00X52@0?2Ph00P0@2`l05P0>2@d03`X>010;3`071@X02@L<01DC600:20d071XO00L52P0;
2@h030X?00h<4@0?3A804@lD01HC6`0Q7RL0514J00l<5@0<2A800`09010=5P040@X2010=5P0?00L4
3@0A3QL08b4]00X85P061180518P018@7P0;21T04@hO010=7P0?31d030TJ00/86@0<2AX03@/F0080
3@XA00l03@XB00d:4`0=2Q<03P/E00l<5`0B3aX04a0L014=6`0>2QP03P/F02PU;P0@3AH00@0500T6
3@071@/00P0;2@h300d;3P0E00/:3P0G7280X:N]06U]L`092Ph03`lA018@4`091@H0510A014<4@0@
2a404@hE00H42`071@X01085014?4P0=2`h030X=00h<3`091`X02PP;008030X=01002`T<00`93005
00<04`X?01483@0=1`/05@lC00l93@0910P0BTI:0490@`0V92L02`T<00T72P0?2Ph03PT=0P0=20`0
1`0<1`/02`H:00`72`0;1PX01P45014<400;1PX00P0=20`200l:3P0:00h93@0<1`/02PD900<00P0?
2`h040/?00<00P0A3A004`hB014<40803@P<00X040/?00h93@0:1@T02`H:00X52@060@D030L;018=
4@080`L02`H:0P0:1@T02P0>2@d04`hB01D@500;1PX02PD901@?4`0>2@d03@P<00h93@0>2P/200`8
2@0:00d92P0@30d01P8301<?400F4Q<02`L8010<3@0:1PL040`=00d92P802@D600T03PX;010<3@0>
2P/02@D600P41@0>2P/04Ph?00h:2`0=2@/00P0=20`0100810L01P4501<>4P0:1@T2020K7`0404e8
C00Q72000`02014<3`<030P900@02PH700X52@0<1`/03@P<0`0=20h00`0=20l03@P>00`72`0400`7
2`0;00d8300<1`/030L;00/62P0<1`/03@P<00X52@0;1PX03@P<00`72`0;1PX00P0<1`/200d83080
30L;00d02`H:00l;3003000020@500`82@0C3a0030P900d92P03000040`=00d92P0:1PL02@D600H0
2`L802@03`/<00h:2`0:1PL02@D600`82@0=2``03@/@00/:3`0?3Q<0000400d<4@0e=3T00@0500d<
4@0510T02@P=00/:3`0=3@l06ADD00X71@0300004Ph=018>3P0I5AH03@T:00d82`0;1PX030L;010;
400@2`l03PT=00d92P0A3@h040`=00/7200<20T500d92P0b00d8300>2A000`04018=4`0C3Q@00`02
02TT:01LEe/03`/<00h:2`060P<02PH700h:2`0@3Pl04@l@00L51P0;2@X03`d>00L51P0G5AH03@/<
00P61`0B41400P0100h>3P0<30h04A<@014C3P0]<2H02@d0024U5P0H70d061/@01TL4`0B51003@h@
010A5@0@3Q<030X?00h<4@0?3A802`T>00X83@0<2Pl02@L<00l=4P0;2@h05aDJ00X6300>1`l300d8
3`0800/83`0B3aH0514H00`;4@0A41H0000500d<4P081P`200d;400500`:3`0C4AH05aDJ01@B5`0;
2@h00`091``01P0<2Pl03`dB00d;400=2a0030X?00d;40<03P`A00@040hC018@5@0B41D03`dB0P0?
31<200d:4@0400l<4`0B3aH03@XA00d:4@<040dD00@03``C014?500A3a@04@lD0P0@3Q<0<P0?3A80
3@/@01<A5P0D4QL03@/@00`:3`0:20d03@/>010>4@0?3A003P`?014?4P0>30l03@/>00l=400F51L0
3P`?014?4P0=2`h04Q0C010>4@0>30l03@/>00l=400@3Q403@/>01DC5P0B41<05aDH00`:3@0D4QD0
4@lD00/93P0?3A801P@900l=4P0G5AX03@/@01HD6@0H5Q/04a4F00l=4P0A3a@04`hD018=4`0@2a40
4@`B01HA5`0J5A/04PdC0P0A318301<>500I014<400O6Qh05Q4E02HQ9@11?400:B@X02lZ;P0I51P0
81/O03Lb=P0R7B4040/?00d92P0@30d0510A014=3P0?2``04Ph?00d92P0@30d061@E00T51P0>2P/0
5A4B018<3P04014;3@0[018<3P0:10H03PP:00l92`0>20X06A<E01PA500G3Q<03PP<00d72`0J61/0
Q8:50=;Ad`0X9RT03`X>01<>4P0E3a<01P0201T>4@0G2@T04PH801882@0<1PH02`L800X82@081PL0
2`H:00l93@0@2Ph04PP@01@9400E2Q005P/A01@93`0A1P`040D;01873@0A1P`03`@:01873@0D2@l0
4`P>0146300200l42P0900h32@0?10X040D;00l42P0F2a406PlE01052`0;00H03`@:00804PD<00D0
4@@;01032P0@0`X040<:01<63@02018530804`H=00L040<:00/01@0C1Pd050L>00/01@0A10/040<:
00H03`890P0>0@P200l22@8040<:00H04`H=00d11`0L3aH07a8I0185300F2A0600l22@H03P485?oo
ool001_ooooo00`03@/<00h<3@0>30d02@L800`:2`0K6AX08AlP00l=3P0;2@X040h?00d;30091`P2
014=3P8040`=0P0?2``00`0B3Pl04@d>00l;300300l;3003014=3P0@30d03`/<00<03`/<01<04@d>
010<3@0C3a003`/<01@@4@0=2P/03`h=010?3`0A40l04@l?014<3@0A30`03PT:010<300@3Ph03`h>
00/:2P081`L040d>0080510A00l04@d>00h:2`0=2@X03PX;01<?400>2P/03`/<01HB4`0@30d020@5
010<3@0B3Pl03`/<014=3P0@30d01@0?2``03P0@30h02PL:010=400C4180510C00h;300M6Q/04@h?
01LD500M6QX05A8A00l<2`0?3@d05A<D0P0=2``04P0A3a002PP900`:2`081PL03P`=00l=3P071@H0
3P`=00/92P0I5aP04@l@01<A4P0L6Q/05aDF00h<3@0<2P/02`T:00`:2`803@/<00<030X;00d;300?
3@h00P0>30d0100=2``04@l@00/92P0:20T200l=3P0G010?4@0A4QH01PL<010C5P041PP03@lB018B
50061`T03@d?00h>3`071`P020P900`;300<2P/03@/<010>3`0>30d03@/<01HD5@1FE5D061LG00l=
3P0A3a000P0=2``02`0:20T03@/<00/92P0A3a0061HG00P61`0>30d040h?014?400@3Pl03P`=00D0
30X;014030X<00`:3@0=2`h02`T=00h<4@0=2a0040dC00/93P0<2Pl03@/>00X82`0<2Pd03`d@00X8
2`0<2Pd03@/>00l=400200/93008018@4`0A3a403@/=010>400>30h02PP:00/92`0?3@l200/92`80
3P`>00@03@/=010;3`0=20`03@P<0P0?2Ph05P0=20`040/?010;3`0>2@d03@P<010;3`0B3A404a4F
00<21P0D4QL04a4F018@5@091``02`T>00`:3`0>31404@lD01LE6P0F4aX03P/D00`94P0>2a@2014>
5`0:00l<5@0<2A80514J00X7400F4a`03@XC00l<5@0@3QP03@/E00d:5P803@XH00L040`K00d:6P0<
2AX03@TJ00h:7@0?2al03``J00803@XB0`0=2Q<03P0=2Q@03@XE00h;5P0>2aL03@XF00`8500610`0
5A8J014>5P0>2a805a@K02XX;P0:20d02`T>0`0=2`l0700<2a004AHM061WL00m@TX02@`A00T:3P0=
30h03@T:00`82@0C31003PH<00/42@0B2a003P/>00/9300B41<01P@700L5200@3Q402`T<00d;3P0?
3A0030X=00X82`0=2@d04@/?00l62`0A20d200l93@0700h8300:1PT03PX>010>4@030P@040hA00l=
400600d83006014<400@2`l03@P<020K7`0A310040/?1P0=20`01`0E41@07QTM01LB5P0F4AD03PT=
018=4@0<1`/00`0=20`02@0;1PX02PD900h93@0E41@03`X>00/62P0=20`040/?00l:3P0200d83080
3PT=00<03`X>02@O8`0b;C400P0?2Ph01@0:1@T04`hB01`H6@0O6a`020@500803@T:00`040`=00h:
2`0810D02PH7018>3`0f<S<07a/L018>3`0=2@X03PX;010<3@0=2@X200/7200E00X61`0<20T03PX;
00d92P0<20X03`X=00h:300B3Q001@43018>40091@L04`lA010;3P0A3@l020@601@?4P0<20X03PT<
00l;3@0>2P`02`L900<030L;00D030L<00`73@0<1`d030L>00d83@0200h93@0400d8300<1`/030L;
00d8308030L;00/02`H:00`72`0=20`03@P<00X52@0=20`040/?00`72`0=20`02`H:00`72`0300d8
300=00`72`0A3@h04`l@01`H6@0=2@X030P900X61`0<20T040`=00X61`0@30d0510A00T51P0200X6
1`802`L80P0<20T07@0=2@X030P900/7200;1`P03PX;00l;300920X02`T=00h=4@0610P03PdA02l]
<@0B4A@081hR01DC5`1mNgl06APL00P6200?2`X030P601XF5@0o>cX09B4Q014>3P0A3@h03`/=00T4
200:1@T04@`A00803PT=00<03@T:018>3`0B3Pl00P0<20T200h:2`<03@T:00d030L;00l:40091@X0
3PT?02hY;`0E4A@04@`@01@?4`0A3@h03@T:01XF5`0K5aP02PH700802PP90`0;2@X0800<2P/03@/<
00`:2`0H5QL03P`=02HT9@081PT030`A00/<300>3`h03Pl:00D70`0D5Pd05AL>010B2`0C51004Q<B
00d=4@0>3A<02`T>00l=4P0B41D040hC00d;400;2@h040hC00/93P0>314020H;01<A5P0<20h03PL?
0`0=20l04`0;20l030T@00X73P0A41H020L=01`K8@081`d02`X?00d;400>31403@/@00`:3`0=2a00
30X?00/93P0=2a003`dB00h<4@0<2Pl00`0=2a002P0<2Pl03@/@00h<4@0>314040hC018@5@0A3a@0
40hC00l=4P0A3QD2010=50<03``C00<030T@00d:4@0@3A@00P0@3A@00`0?31<03`dB00l=4P0200h<
4@<03@/@01405Q@I01@B5`0=2a004@lD01<A5P0J61/06ALJ014?4P0>30l04@lB00d;3P0F51L03@/>
00h<3`0;2@`04@lB00`:3@04010>4@804@lB01003@/>018@4`0B41<04Q0C010>4@0E4aH04a4F010>
4`0H5Q/03`dB01<A5P0<2Pl03@/@014?500C4AH04@lD0P0@3Q<0500@2a405Q4G01LB600E41H04@`B
00l:400C3Q@04@`B018=4`0F4AL050lE018=4`0E41@02`H:014<401aK70030L;01LB5P0C3Q8040/?
0P0C3Q80200?2Ph040/?014=3P0D41405a<D01<?400>2P/04@d>0P0?2``01@0>2P/04Ph?01PD5@0:
1PL040X<00<04@/=0P0@2P`09@1@BT`0NG=e01lI6`0C3@l03PP:014:3@0=10T03PH:01LB5P0<1`/0
:2HY04Q6B@0<2Pd03@P<00h93@0C2a003`D:01D:3@0A1PL040L901892`0=1`P03PP:010;300;1PL0
2PD8010:3@0?2@`03PH<01883P0@1@/03`@:0146300C20h040D;00l42P0@1@/00P0>0`T0100@1@/0
4`P>01873@0A1P`201873@804@H<00T04PL=01D:400H3A<050T?01873@0@1@/04PD<01442`0@0`X0
0P0?0PT0100@0`X04@@;01032P0A10/201@73P070185300C1Pd02@030186300?10T060/B00d31`02
00h120803`890P0@0`X200h120803`890P0@0`X01P0?0`T040<:01<63@0A10/03P8801D83`H03`89
0`0@0`X200l22@0300h12?oooooooooo01;ooooo000Kooooo`8030X;0P0B4140100?3@h04Q0A00d;
300;2@X200d;300400/92P0?3@h04@d>018>3`804`l@00@04@d>00h:2`0@30d03`/<0`0=2@X01@0>
2P/04`l@010<3@0?2``03PX;00803@T:02@03`/<014=3P0>2P/040`=01XF5`070`@02@L800/92P0<
2P/040h?00l;300;1`P04`l@02HT9@0M6a`04Q0A01<A4P0@3Pl040`=018>3`0A3@h03PX;00`82@0=
2@X03`/<01PD5@0C3a0040`=01PD5@0?2``071PI00@00@0E4A802@D6024M7P0:1PL500l;300P010=
3P0B41403`d>03Hd=@0X9RL04a4B00d;30091`P020H700d;300<2P/03`d>00h<3@0;2@X02PP900h<
3@071@H03`d>02LU9P0I5aP040h?00X82@0B41405A<D00X82@0G5AH0518C010>3`0;2@X03@/<014?
400>30d200/92P0P00d;300?3@h02`T:00d;300?3@h040h?00l=3P0>30d03`d>00/92P0<2P/03`d>
00/92P0?3@h01PH800/<40071``07alQ00l?4@0b<S@03`lA00T92`0:2P`03`lA00d=3`0<30h030X;
00h<3@0B41403P`=00X82@0A3a02018@4@0@014?400:20T03P`=00D310081PL040h?00T7200:20T0
4Q0A00P61`0A3a002`T:00P61`0;2@X03@/<00/92P@030X;01h030X<00`:3@0D4QD03P`@018@5@04
0PL040hD018@5@0<2Pl03@/>00X82`0;2@`03P`?00T72P0?3A005Q@G01`J7@0?3A0071XM03Pf>@0Y
9bX01`D800<1100?3A004Q0C010>4@0;2@`020H900T72P0=2`h200l=4008018=4@0>2@d03PT=00l:
3P0>2@d03@P<014<400?2Ph200`72`0V010;3`0D3a<02`X>00d;400j>3d0QhF:01XH7@0>31403@/@
00l=4P0<2Pl02PP=00`:3`0B41H01`@=00d:4`0>2a@03@XC01<@6@091Pl01@8;01@A6P0@3AH02PL@
00P53P0A3QD03@XA018?600:21002`PC014>6@0>2QP03PXI00d96P0?2a`04`hR01@?8`0A3A/500d:
4`0300l<5P0@3AP03P/F00803@XE00L03@XD010=500>2a804a0G00h;4P0?31<0:bT^00802PP=0`0=
2a001`0=2a405ALS00013@0;3aT03Q4H00l@500E51P00P0?2``07P0E30l03PD:01H;4@0D2Pl030L;
00P62@0?3A002@L:00/930091`X03@/>010>4@0A3a8030X=00X82`0<2@`02`D900l62`0F3A801002
01@?4P0G4AD030L;01<?4`0>30l05A<F00@31@0A3a802`H:00`72`803@P<01803PT=00l:3P0;1PX0
2`H:00X52@0R7B4030L;00T4200=20`030L;00/62P0<1`/03PT=010;3`060@D05A0D00/62P080`L2
00h93@0?00/62P0A31004@`@00d8300<1`/03PT=014<400<1`/02`H:01<>4P0;1PX03PT=00T4200;
1PX030L;00<03PT=01P0QX650=7<d00S7R803PX=00L21P0@2`l03PX;01<?400?2``05Q8C00<0000L
61T03`/<00<0000@30d04`l@05IBD`0V8R<030P900/7200=2@X03PX;00/7200<20T200h:2`802`L8
01403@T:01@@4@0L61T05A4B018>3`0300004Ph?00/7200>2P/00`00018>3`050@802`L800h:300?
2Ph04@`@00l:3P0200`72`0400d8300;1PX02`H:00/62`802`H<00@03@P=00h93@0>2@d03@P<0P0<
1`/01@0=20`030L;00`72`0;1PX030L;00803@P<01L020<700/62P0@2`l030L;00d8300910P02PD9
00d8300>2@d03@P<00`72`0:1PL030P901HB4`0;1`P03`/<00d92P0A3@h01`<400T51P0=2@X0510A
00T51P0200X61`802`L80P0<20T0800810D02`L800l;300@30d030P900P41@050`H020H900X82`0?
3A001@<600L5200>30l03`d@00400P0D4QD02`T<00/92P0300004Ph<01@@3`0R7Qd02@H501dI6P0E
4A804Ph@00T4200;1PX04`hC00h93@0A31003PX;0P0?2``0100<20T03`/<00h:2`0>2P/200d92P0T
00`82@0<1`/02`H=014<4P0=20h05Q8G00<00P0O6Qh03PT=00`82@0>2P/04`l@00<0000B3Pl03@/<
00T7200A3a002`T:00<10P0:20T02`T:0040000Q7b007Q`M08N5QP0H5QT03`hD00<21`0<30h04Q8A
01LG5@0720<02@T700h>300E5AD04a<F0P0;2Q000`0@3Q<05A<H014?500200/93P0800d;400?3A80
0P05018@5@040PL02PP=014<4`0>1`l300d83`0D00/83`0=2Q4020D<00X93`0920h02`X@00`;4@0;
2Pl02@L<00d;400F51T03@/@00D320071@X03@/@00`:3`0;2@h03P`A00l=4P0>314200d;400600`:
3`0=2a003P`A00/93P0<2Pl03`dB0P0>31403@0@3Q<03``C010=500@3A@03``C00d:4@0:1`h02`P?
00`9400?31<04@hE010=500>2a800`0A3a@2010>4`803`dB00T030X?01<A5P0B41D02PP=00l=4P0F
51L0518E00`:3@0;2@`00P0A3a80200l>Sd071XM014?4P0D4QD07Q`O018@4`0A3a803`d@0P0>30l0
500@3Q404a4D00h<3`0?3A0040hA00/9300E4aH04@lB00X83@0B41D03P`A00d;400C4AH05A<H01LE
6P0E4aP0518G01DC600D4QL04Q0E0P0C3Q@08P0@2a403PT?014<4P0G4QP04`hD014<4P0B3A<05Q4G
01@?5@0A31804@d@01TD600H4aL03@P<01hI7@0;1PX04PdA00d8300B3A402`L:00d8300B3A404`l@
01HB4`0I5AH0510A00h:2`0@30d030P900T51P0J5QL03PX;00`82@0G4a@200l92`8040X<01@03`T;
00h82P0L5QP0<B/]01/E5`0=1`T05a4C01D;400H3A<04@P=00`42@0@2`l03@P<00T72P0>30l020<7
014:3P0=10T04PL=01@:3P8040L:00@04PX=00d72@0>20X04@/=0P0:10H02@0C3@l04@/=00h82P0E
31404`P>00l42P0I3Q@081DK01/@5P0201D:400301H;4@0C20h040D;00804PL=00/04@H<01@93`0E
2Q004`P>0146300B1`d03@8800h32@0J3aD0714G01052`03018530804@@;00d040<:00d01`0=00L0
3P480185300C1Pd04PD<00/01@0I31<05PT@00l22@0<00H04@@;00803P480P0?0PT201032P803P48
0P0?0PT201032P0600d01`0@0`X02P0400T00`0>0@P03@071P0?0PT0100B1@`04@@;01032P0@0`X2
00l22ACooooo000Kooooo`0I00h<3@0?3@h03`d>00l=3P0>30d030X;018@4@0:20T02@L800P61`07
1@H03P`=014=3P0@30d03PX;00l;300I5AH08alP00/7200>2P/040`=014=3P0@30d03`/<01<?4002
00X61`0601@@4@0810D0510A00`82@0:1PL030P90P0>2P/200l;300300X82@0C4A803@/<008030X;
00H0518C038`<@0]:b`0518C00/7200@30d200d92P0401`H6@0;20P040`=01HB4`804Ph?00H07QXK
00X61`0B3Pl03`/<00h:2`0@30d3014=3P04010<3@0<20T02PH700d92P804@d>01T03``=010>3`0@
3Pl040h?00l=3P0>30d030X;014?400=2``08R0Q00`:2`0;2@X03P`=00/92P0@3Pl03`d>00@20`0T
8R<0EeEF01LE5P0200403`d>0040000?3@h04Q0A00D03P`=00D020H701@B4`0D4Q<02PP900l=3P03
00h<3@0>00l=3P0A3a0040h?00`:2`081PL03`d>00h<3@0:20T03P`=00H41@0?3A003Ph@00l>400?
3A0300h>400600000P0Q8B<061LL00H52P0?3a802`T:0P0:20T00`0;2@X03P`=010>3`0200h<3@0:
00l=3P0A3a004a4B01<A4P0B414030X;00L51P081PL040h?01HD5@803@/<00@030X;00l=3P071@H0
4Q0A100>30d0800>30h03P`?00`:3@0@3Q80518G00/93P0A3Q@04@lD01@B5`091`X04a4D03hl?`0C
4A@02@L:00X92`0?3A00?S`o038`<`040PD04@lB00l=400>30l03`d@00h<3`0:20/020H900d;3P07
1@P071XM00d;3P091`X05aDH0P0@2`l200l:3P803PT=0P0A3102010;3`803`X>01D04Q0E00P62`0M
6b00;2X_00L52P0E4aP03`dB014?500<2Pl04@lD018@5@0=2Q002`P?00`9400=2Q403P/B00l<4`0:
1`h02@H=00d:4@0?31<00P0=2Q40100>2a8030X?00/83`0<2A0200h;500400d95P0<21H030PG00d9
60803PXK00d040`J010=600=2QD030TD01<@6`0B3aX040dG018?600A3QL040dF00d:4`0<2A803@XA
00D03@/@01@02PP=00`:3`0>2a8030T@00/83`0<2Q802`dI00/=6P092aH020P@00X;3`0<2`l03@T:
00H20`0E30l040D;00/01P0F2Q003PT=00`:3@803@/>0P0>30l02P0C4A@0EE=F018@4`0;2@`00@02
00l;3`0>20`040L<01483@0?2@d2010:3P08014<400;20/03P`?010>4@0;2@`02@L:00`72`0>2@d2
010;3`0400h93@0=20`03@P<00h93@803`X>00<03PT=00d8300;1PX00P0A31001`0;1PX06aHJ01/F
6P0A31003`X>00d8300<1`/00P0;1PX02P0=20`03`X>014<400A31003PT=00d8300:1@T02`H:00`7
2`0=20`200h93@0W00d8300<1`/030L;00d8300>2@d03`X>03dh?01NFEd08ahR00T4200E41@0;2L[
02DQ8P0?2``00`00014=3P0300008alP010<3@0<20T02`L800h:2`0B3Pl05A4B00d92P0300005a<D
00L3100F4Q<03@T:00`82@0@30d03PX;00T51P0:1PL030P900d92P0?2``03PX;008030P900<03@T:
00`82@0;1`P00`0:1PL01P0=2@/030L=018=4`0@2a003@P<05MBEP803`X>00D040/?00`72`0=20`0
3PT=00`72`0200/62P0I00`72`0=20`03@P<00l:3P0500@03@T<01@?4`030080;BP/00H11@0910P0
3@P<00/62P080`L030L;018=4@070PH04PdA055<D0080`L03@P<00h:2`091@H02`L800P41@02010<
3@<03@T:00P030P900/7200;1`P03@T:010<3@0A3@h0100101DA4P803@T:0P0>2P/01@0<20T02PH7
00T51P091`X02`T<00803@/>01H02`T<00T72P0>30l030X=00X82`091`X02`T<00`:2`0=2@P02PH4
01HB4@091@@04Ph>04M3A00E4A803`X=00H11@03008040/@00X52@0>2@d03@T:0P0<20T0500=2@X0
3PX;00/7200<20T03@T:00l;300>2P/02`H:00d83`0A31801@0600/6300@2`l01P4500h93@0;1`P0
30P9014=3P0@30d03@T:1P0=2``0400A3a0040h?00`:2`0=2``04a4B00h<3`1CDUL02`X?00L72@0>
3Pl030`<014A3`0@41004Q8B00l?4@0<2`l200`;4@03014?500?3A803P`A00<030X?00X05Q@I0040
100C4AH00@0401PF6`0G4aT050dD018=4`0@2a403PT?0P0<2Pl00`0;2@h030/@00l>4`0200X93P0;
00h<4@0?3A803@/@00`:3`0B41D04@lD00h<4@081P/01`D:01LE6P0?3A800P081P/0200K6Ah00@04
01DC600>31403@/@01<A5P050`P040hC0P081P/00`091``030T@00d:4@02010=500300l<4`0=2Q40
40dD00803``C01d03P/B00l<4`0@3A@01`D:010>4`0>31404@lD010>4`0?3A800P05018@5@0A3a@0
2PP=01<A5P0B41D04@lB01@B5@0F51L040hA00`:3@0?3A00>3Hi00`:3@091`X07adP092>T@0Q7b80
40hA014?4P0201<A500@014?4P0@3Q405A<F03@b=@0<2Pd05A<F00D41P0S8B@04Q0E014?500=2a00
30X?00l=4P0C4AH04Q0E014?508040hC00l04@lD018@5@0>2@l05a8H00L220080`T06A@J00l:400D
3aD040/A02PS:@1/Ifd071LM010;4@0B3A400P0A31001@0B3A404`hB01<>4P0E41@04`hB00<04PdA
00P04`hB03<_<012?Sl040`=014=3P0C3a00510A010<3@803`/<01803@T:01HB4`0@30d04@/=00h8
2P0<1PP03`T;010:300>20X04@/=018<3P0H4Q@04P`>01PB500C2@d04`P>01893P0A2Ph200l:3P0Z
01<>4P0910P030H:01D=4P0A20d05@X@01L>4`0H4Q@01`4300h92P0E3a403PD801D<3`0800801P00
01L>4@0H3a8040X<0148300B1`d0304701<83P0J3aD01`0201<83P0:00D06@hD00l52P0?10X03@88
01052`0A1P`04`P>01873@0700804@H<00h32@0?10X04PL=01D:400D2@l03`@:1P0A10/?01032P03
00l22@0>0@P03P4800H03`891P0@0`X01@0?0PT03P4800h1200>0@P040<:00804@@;00D03`890185
300F2A005@P?00h1200Dooooo`006oooool00`0=2``03P`=00h<3@0200d;30<02`T:0P0B414200`:
2`0600l;300@30d040`=010<3@0F4Q<071PI0P0A3@h0100@30d03`/<00h:2`0=2@X202l[;00Q00X6
1`0@30d05a<D00X61`0C3a003`/<00h:2`0?2``040`=014=3P0?2Pd03@P;00`:300<2``02`X<014B
4`0=30d05A@E00d;3@0:1`T03`X=00/62@0B3Pl030P900l;300C3a0061@E00P41@0E4A80920Q02hZ
:`0?2``03PX;00803`/<00P040`=014=3P0A3@h04@d>01XF5`0M6AX05Q8C010<3@803`/<01T03P`;
00h>2P0>3@`03@`<00`;2`0<2``02PT901PG600510D040l@00h=3`0;2Ph04a8D00/92P081PL03`d>
00/92P0:20T040h?00H41@0E4a@0<Bl`01/I6P0?3@h03P`=00D03@/<018020H7014?400A3a002PP9
010>3`0B414030X;00/92P0:20T030X;00d;300;2@X03@/<00T7200<2P/03P`=00T7200?3@h400l<
3P0?00h<3P0>30l03`h@00L6200];C00:2L/00X93P1BDEH0518E01@B4`0B41403`d>00h<3@0<2P/0
2`T:00803P`=0P0;2@X09`0>30d0518C014?400<2P/02`T:00`:2`0=2``02`T:00X82@0=2``040h?
00/92P0>30d030X;00d;300>30d03`d>010>400A3a8030X=00/93@091``0518G01LD6P0R82D040hC
00/9300B41<0;R`_01HD5`091`X03`d@00d;3P091`X05Q@G01@B5@091`X03P`@00`:3P0200d;3`80
30X>00H03`dA00X9300<2Ph030X>01HD60081PX2010;3`803`X>0P0>2@d2014<408040/?0P0?2Ph0
30091``04@lD00D4200A3a@02@L<00X83@0>314040hC00h<4@0C4AH05A<H014>50803P/B100=2Q40
1@0>2a803``C00h;4P0;20l030T@008040dC0`0>2Q401@0=2A803@PB00d85@0=21D03PTG00803`XI
00L03PXH010<6@0>2aL02`LC00h;5P0?31L03@XD00803@XC00@03P/D00l<500?31@030X?100<2Ph0
100<2Pl02PP>00`93`0=2Q4200X73`0M00`94P0;2QD02PTE00/:500;2a002PX?00X:300A3a0040`=
01@<400?10/060dD01@8400A31003`d@00h<3`0<2Pd02`T<00X82`081PT04a4D018@4`0200<04a4D
00h:3P0>20`040L<01483@0?2@d00P0@2Ph01`050@@040d@00X82`0:20/04Q0C00X82`0=20`01@0>
2@d01@0=20`03PT=00l:3P0?2Ph03PT=00803@P<00T04PdA00`82`0=20`0C4M;018=4@0?2Ph03PT=
00d8300<1`/00P0=20`2010;3`0500d8300>2@d040/?010;3`0>2@d00P0=20`200`72`0M00/62P0=
20`030L;00`72`0=20`03PT=00l:3P0B3A402@@800D1100E41@020<700h93@0@30d00`00014=3P0<
20T03`/<00`82@0=2@X03`/<010<3@0?2``030P900X61`0?2``01`<400/7200?2``00P0@30d00`0?
2``02`L800`82@0200d92P0400/7200=2@T03`/;00h:2P8030P80`0>2PX04@0=2@T030P800d92@0>
2@d04`hE014=4P0E41D05a8G02TT:00@2`l03@P<00`72P091@L030P:00/72@0:1@P03@P<00803PT=
0P0?2Ph01P0@2`l01`<601`G6`030080>cHj06iYK@<03PT=00l02`H:00X52@0;1PX02@@801LB5P08
0`L03`/>00P31`0>2@d02@D601DA4P0R7Ql02`L800P51@0C3a000`0=2@X200`82@0=00/7200810D0
3PX;00h:2`0D414030T900`82@091@H03PX;018>3`0;1`P03PX;01HB4`0200d:30802`P:0P0=2P`0
500>2`d03@X<00/82P0;20X030T;00`92P0<20L04@d;00T5100:1PD02`L701/G600>2P/03@T;00`7
2`0@2`l03@T=00d8300>2@d03@T:0P0<20T01@0=2@X03PX;00d92P0=2@X03PX;008040`=00P03@P<
00`83P0K5Q`0JVE[01PC6@060PD04@`@00d830803@T:00<03PX;00l;300?2``00`0:20T200/92P80
30X;01h0518C00d;300>30d02@L800h<3`0N72402`T>00h<4@0@3a402`X;00`;3@0@3a003Pd?00l>
4@0B41D03`dC00/93`0@3Q<03`dB00h<4@0=2a003P`A00l=4P071@X07A/P00d;400O7B803`dB00`9
3@0@2@l200l:3`0G010;400>31003P`@00/93@0;2`h0410C00d<400<2`l03@/@00`:3`0@3Q<03`dB
00T7300?3A8061HK00/93P0B41D03`dB014?500I5a`03@/@00P72`0B41D00P0A3a@01`0B41D01@<8
01DC600<2Pl04@lD00X83@0?3A801P0>2a80400@3A@03``C00l<4`0>2a803``C010=500=2a00518G
018@5@0G5AX04a4F00h<4@0@3Q<07Q`Q01`J7`0=2a02010>4`0>014?4P0>30l030X=014?4P0B41<0
3`d@00h<3`0A3a804a4D010>4@1lNWd03`d@00h<3`0?3A02010>4@0=00l=400>30l07Q`O04]9C00@
3Q402`T<01TG6P091`X040hC01<A5P0G5AX061HK01DC6007010>4`0=01HA5`0?2Q007APN01dH7P0@
2a406A@J014<4P0F4AL04PdC04e8CP0J5A/06aHL01@?4`03018=4@0301<>4P0D3a<04`hB00804PdA
0`0A31001P0E4A8020@500/7200F4Q<03`/<01LC50804Ph?02d04@d>00h:2`0B3Pl04@d>01@>400C
3@l04@/=00l92`0B30h05@lA01H@4P0I4aD0=S0b03`f>01/IVP06A0D01@73P0C20h04@X>010:3P0?
2Ph03`/>018=4@0D3Q806aDH01P=4`0D1`h0610E014>4@0;20/04Pd?00h82`0<10H04@L;01882`0H
3Q004@P:01092@0W8B40;2@V01D:400@1@/04@H<00h52@0M4QP00P0B1`d03@0E2Q0040D;01X?5@0;
0PH06@lD01052`0<0PL040D;01/@5P0B1`d04`P>0146300B1`d00P0C20h00`0?10X04@@;01442`04
01442``040<:0`0B1@`201442`0301032P0?0PT03`8900@03`891P0@0`X0300?0PT03P4800h1200>
0@P040<:01442`0D1`h060/B01L:4@0B1@`03P8800d11aCooooo000Kooooo`0J00d;300>30d03P`=
00h<3@0=2``02`T:010>3`0<2P/02`T:00d;300D4Q<06QPI00d92P0@30d04@d>010<3@0A3@h04`l@
00l;300>2P/03@T:00l;300A3@h04`l@00l<300A3@h400l;30803@T:01D02PH700h:2`0D41405A4B
00l93@0@2`l02@L:018A4`092P`07AhP02l`<P0S8bD03`lA00h93@0F41@040X>00l;300A3@h03@T:
00h:2`0B3Pl00P0;1`P01`0810D04@d>018>3`0=2@X030P900l;300@30d00P0A3@h02P0@30d05A4B
01LC500C3a003`/<00h:2`0?2``03`h<00d>2@0=3@/200`<2P0=00`<300@41002@T900`<3P0^;S00
2PX<00X93P0=30l03`d>014?400<2P/03P`=018@4@0201<A4P0501@B4`0D4a<02`T:00/92P0=2``0
0`0<2P/200d;300:00/92P0@3Pl03P`=00X82@0>30d04Q0A00l=3P0=2``02PP900`:2`803P`=00H0
4@l@00/92P0:20T03`d>00h<3@0<2P/500h:2`0900d:3@091`X08AlR01TH7@0F5AX01`H;01XK800<
2Pd03@/<00803`d>00<03P`=00`:2`0?3@h00P0>30d200l=3P0?00h<3@0100003@/<018@4@0?3@h0
5Q@E02DS900B41402PP900/92P091`P03P`=00d;300<2P/03@/<00803P`=01T03`d?010>4@081PT0
>CLk00D3200100@03@/A014?500<2Pl040hA014?4P0M6ah061HI00X82`0<2Pd01P@702@R9@0L6Qd0
1085010>4@0@3Q<03P`A00`:3`0:20d02`T>008030X?00D05Q@I010>4`081P/03`dB00<11P02010;
3`803`X>0P0>2@d00`0@2`l03`X>00l:3P0300l:3P0600d;400>31402`T>00`:3`0=2a004Q0E0`0;
2@h02@0=2a003`dB00`:400:1`h02`P?00d:4@0?31<040dD00l<4`0200d:4@0800`9400>2a804@hE
01DA600C3QD040/B00h9400=20l200`640803PPB00@03`TC010:500@2Q@04@`I0P0F4R00100>2QL0
2PLB00/84`0:1a4200X7400300d:4P0>2a803``B00D03`d@00@03`dB00h;4P0?31<03P/B0P0;2140
1@0>2a@050hH018<5P0@3AD03PdB00802PX<00X0108300T7200H4QP040H>01@84P0H31H040/A00h<
3`0=2`h02`T<0P0:20/02P0;2@`00@0201DC5P0=2`h06QPK00h:3P0>20`040L<01483@0?2@d2010:
3P0800d8300;1`/00P0300P62@0F51L04@lB014<400?2Ph200d8300300h93@0?2Ph030L;00@03PT=
00P030L;00X52@0>2@d030L;00d83003008050lC00d830<030L;00T03PT=00l:3P0@2`l03`X>00d8
300>2@d03`X>010;3`0>2@d00`0=20`200`72`0>00d8300<1`/030L;00d8300>2@d03`X>010;3`0B
3A404`hB00/72P03008050lC00d92P0K5aP200d92P0700T51P0?2``0510A00h:2`0:1PL02@D600/7
200200d92P0400<0000N6Q/01@4200X61`804@d>00P03PX;00d92P0>2P/030P900/71`0=2@P03`/:
00h:2@8030P700@03@T800h:2@0>2PT03PX90P0=2@P01P0=20`00`0500h93`0@31404`hD00<00P80
2`H:00D02@D600d92P0F4Q<0510A00h9300200d830803PT=00T03`X>00/62P0P6al02PD902DP900=
20`02`H:00d8300>2@d00P0=20`2014<400600l:3P0>2@d04PdA00d8300>2@d02PD90P0:1PL0100D
414040`=01@@4@0@30d600`82@0>010<3@0<20T03`/<044m?P0U8B803PX;00/7200>2P/040`=00`8
2@0@30d06QHG00h:2`0=2@X200`82@0500d92P0>2P/03PX;00h:2`0=2@X00P0<20T03`0<20L02`L6
00l;2@070`807ATH00l;2`0810D04Ph?00d92`0910P04PdA00/62`0D3a<03PT=00d92P0200`82@03
00d92P0>2P/03`/<00803PX;010040`=014=3P0?2Ph040/B00X52`0U82H04@`B01XE6@0=20`02`H:
00l;300>2P/02`L800d92P0@30d030X;0P0=2``300l=3P0A010>3`1=Bd`020H700l=3P0A3a006ALH
00`:3@0@3Q<030X=00T72P0>30l040hA014?4P0;2@`030X=00d;3P0<2Pl00P0>314200d;400>00h<
4@0?3A803@/@00P62`1]Jg00A49705eKH00>31404PhB014;3`0?2Ph03@P<00`72`0:20/200l=4007
00/;3@0=3@l030`>00`<3P0?3Q8020H;00L52P0200`:3`0H024O900Z:2d02PP=00d;40081P/02@L<
01HD6@0A3a@03`dB01dK80040`L04@lD018@5@0<2Pl09R@Y00T7300M6b000@04010>4`0@3A@03``C
00d:4@0<2A003@XA0P0@3A@200l<4`0400h;4P0?31<040dD00d;40804Q0E00L07A/P01PF6`0A3a@0
20H;014?500B41D040hC00806ALL00`02`T<010>4@0D4QD03@/>00/9300B41<0518E014?4P081PT0
7Q`O00/9300L6Qd6014?4P0;00l=400=2`h06QPK01@B5@0@3Q407Q`O01<A5P0D4QL071XO024O900M
6b000P0B41D401<A5P0>018@5@0A318071LM00h93`0@2a409B0V01hI7`0H4aT04@dB00X52`0U82H0
3@P>01<>500B3A42010;3`0300l:3P0@2`l040/?00<04`hB01404PdA014<400A310040`=01DA4P0@
30d03`/<01TE5P0?2``04Ph?01<?400G4a@06ADF00`82@0=2@X030H800d72@02010:300;00l92`0B
30h050h@010:30070@<0EU1B0=7;c@0^92P050L>01<83P0C2@h00P0@2Ph09P0@2`l04PdA01H@501f
K740@CHl00P00P0?2@h05aHK01`J7@0B3Q804P`@00h31`0F2`l060dA01T?400@1PL01P0000H1000@
20X04`P>01052`0E2Q00714G069GG@0]8RP0304700d2200E2Q001`0200`11`14>Cl01`0201D:400C
20h03P<902TO900F2a4050T?100@1@/<01442`H040<:1@0A10/00`0@0`X03`8900l22@0400l22@H0
40<:00`03`8900h1200>0@P03P4801032P0A10/02`0500l22@0@0`X03@0700`01P0=00LDooooo`00
6oooool00`0@3Pl04@l@014?4002010>3`0300h<3@0;2@X03`d>00<03P`=01002PP900`82@0@30d0
4Ph?010<3@0?2``040`=014=3P0@30d03PX;00l;300@30d04@d>01<?40070`@04Ph?0P0A3@h00`0>
2P/04@d>01DA4P0200l;300901@@4@0B3Pl040X>01<=4@0610L040lB018C5@1?D5806AXL008030`>
00/040/?01@=4@0D3Q804`l@00d92P0A3@h04`l@00X61`0A3@h03PX;014=3P0200h:2`0300X61`0B
3Pl040`=00804@d>00@040`=00l;300=2@X03@T:0P0?2``03`0>2P/03`/<010?3@0@4@`03Pl:00d=
2P0=3@/03Ph>00l?3`0A4A40LW9d0:VX[00I61d03PdB00h=4002010>3`0<00`:2`0?3@h03`d>00/9
2P071@H02PP900/92P0A3a004Q0A00X82@0=2``03P`=0P0?3@h2010>3`03014?400?3@h02`T:0080
3@/<00@03P`=00/92P0:20T03@/<0P0?3@h050091`P03`d>00`:2`0G5AH0:2HW01TF5`0?2@T040T9
00l92@0?2@/03`X;00h93@0<2Pl08R0U00P7300>3a@03@hC00l@500;2@`030X;0`0>30d0:00=2``0
4@l@00/92P0<2P/04Q0A01DC500>30d03@/<01@B4`0>3@d020H7024P8016A4D030X;00d;300H5QL0
3@/<014?40071@H04@l@010>3`0?3@h03P`=00d;3@0<2Pd0518E038`=00@3Q<03P`A00`:400<2Pl0
2`T>014?4P0<2Pd061HI01@B5@0;2@`03`d@00/9300<2Pd2010>4@0=00H41`0=2a003`dB00h<4@0=
2a0040hC01<A5P13@DH0KVaa00l=4P0D4QL01`H:018@5@02010;3`803`X>0P0>2@d600l:3P0700h<
4@0?3A803P`A01PF6`0Q7b@03P`A00l=4P0200d;40802`T>0`0=2a0300h<4@0300l=4P0>31403P`A
008030X?00<040hC01@@5`0A2aD00`0?2A<200d83`803PT@00/03`XA010;4@0@2a803PTD010<6`0B
3Q`03@TG00h:600?31L03@XD00`94P0300`9400400`:3P0>30l03P`=00h<3@803P`?01D03P`A00`9
400>2a803``E00/84@0:1a003@PC01894`0B21006Q<J01dI7P0D4QD04A4A030`<P0A41<030L>0148
4P0=0`l04PLC00h93`0<2Pd0100=2`h00`0B41<030/=00l=400200h<3`0504I2AP0>20`040L<0148
3@0?2@d00P0@2Ph0200F4AD040`@00h<3`0<2Pd0;R`_06e[KP0C3Q804@`@0`0?2Ph00`0@2`l030L;
00d8300200h93@0800d8300<1`/04PdA00`82`0C3Q801`<601<>4P0910P300`72`0800d8300?2Ph0
40/?00`72`0>2@d040/?00l:3P0=20`200`72`803@P<0`0?2Ph01`0=20`030L;00`72`0=20`03PT=
00l:3P0;1PX00P080`L03@0@2`l04PdA010;3`0I5QH04@d>00L3100:1`L0;BTZ01PD5@0C3a0040`=
00l;300>2P/00P0=2@X02@0<20T04`l@05]GF00F4Q<04@d>00h:2`0@30d0510A010<3@0200X61`04
00/71`0=2@P03`/:00h:2@@030P701<03@T800h:2@0>2PT030P700h93@0D41H0HeiU04E0A`0=2@h0
20@900l:3`0>2@d030P900h:2P0F4Q40510?00d92P0;1PX030L;00<03@P<01P03PX=00T5200>2@d0
1P45010;3`0B3A402`H:014<400?2Ph02@@800`72`0;1PX04@`@00P31`0:1PT030L;010;3`0=20`0
3`/<00T51P0<20T02`L801<?400A3@h500`82@0?00d92P0<20T03`/<00d92P0T82403@T:00`82@0B
3Pl03PX;00/7200>2P/040`=00h:2`0<20T03@T:00803`/<00<03@T:00`82@0>2P/00`0>2P/0400=
2@X030P700h:2@091@@03PX902<O7P0>2PX03`/<00d92P0=20/04@`@010;3`0@2a0030P;00h93@0=
2@X200`82@0300d92P0>2P/040`=00803PX;00X040`=014=3P0?2Ph09b8X00h:3`0H4aT04@dB00H1
1@0=20`030L;0P0?2``00`0=2@X03PX;010<3@0600h<3@0<00X82@0]:b`00`8200l=3P0;2@X03@/<
014?400B41803@/=00d;3P0@3Q403@/>0P0<2Pd0200?3A003`d>01`J700[:B/03`dB00h<4@0=2a00
3P`A0P0?3A801`0<2`l0518G014?500>314040hC00l;3`0@2Ph00P0>2@d0100?2Ph03@/>01DC5P0D
4QD200`<3P0300/;3@0<30h03`hB00801`D:01X040hC00T730081P/03P`A00X83@0E4aP0;R`a01HD
6@081P/04@lD01DC60081P/03@`@01<A5P1=Be005aDJ04Q6B`0E4aP03@/@018@5@0A3a@040dD00l<
4`0>2a803@XA00h;4P8040dD0P0?31<03`0>2a803``C010=500>314040hC00l=4P0F51T03P`A010>
4`0B41D04@lD00h<4@0B41D06QPM01@B5`0200`:3@0;00l=400E4aH05Q@G018@4`0A3a8040hA018@
4`0A3a805aDH00T72P0A3a80100@3Q402P0A3a805aDH00h<3`0C4A@04Q0C01LE60081`T05A<H014?
500C4AH201PF6`0301<A5P0A3a@04a4F00805A<H00@04a4F014?500G4QP09B0V0P0E41H02`0U82H0
5a8H01D@5P0E4AH06QDK010;4@0H4aT040/A01HA5@0D3a<04`hB00<04PdA00d05A0D01HA5@0F4AD0
5Q4E01<>4P0B3A403`/<018>3`0C3a004Ph?01<?400?2``0510A008030P900D061@E00`82@0H51D0
4P`>00h82P0201@>40803@L903404`d?00X51P0F4180618D02XT9P0E2Pl05@L>01@83P0C2@h04@X>
010:3P0?2Pd04@`?01<;3`0F31805`/A01P:4@0?20h05AHJ04M6B`1>BTl050`A01<8300E2Ph04`L;
01<72@0E30`050`:014<2@0B2@/05P/A01873@0@1@/03@@803L/<P0G3A8040D;01<83P0B20d03`D:
01L<4P11=c`04@P<01<83P0=10P05P/A03X`=@0F2a4050T?008040D;0P0A1P`601442`H04PD<1P0@
0`X500l22@0301032P0?0PT03`8900@03`891P0@0`X01@0?0PT03P4800h1200>0@P040<:00804@@;
00D03@4700h1200B1@`04PD<00h2200Dooooo`006oooool03`0?3@h040h?010>3`0@3Pl03`d>00d;
300<2P/02PP900H41@0>30d0:2HW03Dc=00<20T040`=014=3P02010<3@09014=3P0@30d040`=010<
3@0?2``03@T:00`82@0A3@h02PH700803@T:020071PI00d92P0E4A8071PI01<?400@30d04Ph?00d9
2P0E3A<03PL>00L52P0F51T01`P<05QLG`1ZK70051<H00h=4P0G4QP03`D=018<400D3a007ATJ01<?
400@30d02PH701XF5`0<20T03`/<01PD5@0a;Bh040`=00/720<04@d>01D040`=00l;300>2P/03`/<
014=3P0?2``030P900h:2`0@3``03a0:00d>2@0;30P030`:00d=2`0E5AD02`/=028R9019BD`02@P=
00P73@0<2Ph00P071@H05@0D4Q<06ALH01@B4`0?3@h04a4B00/92P091`P03P`=00/92P0<2P/02`T:
00d;300>30d03`d>010>3`0>30d03@/<00h<3@0?3@h03@/<00`:2`0200/92P0600`:2`0?3@h040h?
00l=3P0=2``04Q0A0P0<2P/01@0E4a@02PL8010:2P0B2PP04PT:008040X<00/03`X>00L52P0>3140
2PT?01<D6@010PL01PH=018@4`0A3a0040h?00h<3@0200d;300A00/92P0=2``03@/<00d;300>30d0
3`d>00`:2`0H5QL07A/L01PF5`0C4A805A<D00`:2`0?3@h061HG00D3100F51D00P0@3Pl03`0?3@h0
3P`=00h<3@0=2`d030X=01DC5P0:20`04Q0E01LE6P0=2a4040hC01<A5P0F51L03@/>02DS9P0201<A
500B00l=40030@@06QPK010>4@050`H03P`?00h<4P0D4AP04a0G00h;4P0@3A@04a0G01`I800V8bX0
0P0600/93`0P7B@02`T>0P0@2`l200l:3P803PT=0P0=20`05P0>2@d03`X>00l:3P0?2Ph040hC00<1
1P0=2a00;bdb03Tg?00;2@h040hC00d;400@3Q<030X?00d;400A3a@040hC00l=4P0=2a002`T>00X8
3@0<2Pl200h<4@0:00/93P0:20d030X?00l:4`0?1a@03@DB00l74`0B2QD04P/C01094@803`P?00D0
40X>014;3@0A2`l03@TA00`85`0200d96009014=6`0@3AP03@XD00h;500=2Q403@X@00`:3`0<2Ph0
2`T<00802`T:0P0;2@`0500;2@h030T@00l<4`0B3aP03``E00`94P0<1a806PlG01032P090@D020<7
00H41@0E5AD0?Ci001XJ700;20h04PXG01<;6P0A21H04@`B0P0?3A0300h<3`0:01@B5@0100805aDH
00800`0F51L05A8E00h8300@1``04@P=00l93@8040X>00H01@0400l<3`0D4QD030X=01HD5`0j>3/3
00l:3P0500h93@0=20`02`H:00/62P0<1`/00P0=20`0200<1`/02`H:00@00`0E41@00`0201XE6@0D
3a<030L;0P0=20`200`72`803PT=0P0=20`200h93@803@P<1P0>2@d02P0=20`030L;00`72`0=20`0
3PT=00l:3P0>2@d040/?00l:3P070PH200d8300800L4100300001`<402HR8`2IUIH0PGen00d92P0?
2``2010<3@0800h:2`0<20T03PX;00H20`0L61T01P<300`82@0@30d200h:2`0700d92P0;1`P02`L8
00/71`0=2@H03`/800h:1`0400`81@0A00h:1`0@30T03`/800h:1`0H4aL030H@02hY<00Q72<02PD<
01HA5`0;1P/03PT=00h:2`0;1`L03PX900h:1`0<20P00P0<1`/200d8300800h93@091@P03@P<00d8
300@2`l05Q4E00/62P0D3a<2028M8@804`hB00`04PdA00@00`0A31005A0D00P31`0?2Ph05a<F00d9
2P0;1`P03@T:00<000070`@300/7208030P90P0=2@X0300H51D04@d>00H20`0;1`P0510A00/7200?
2``03@T:00`82@0>2P/03`/<00`82@L03PP:01<03`T;010:300?2@/03PP:00`61P0<20L03PX800d9
200>2PT030P8010<3@0?2``03@P;01D@500400<07aXO00P31`0>2@d03@T:008030P900l03@T:00h:
2`0?2``030P900/7200=2@X03`/<00l:3P0I51/050lE00<0100E41H020<702LR9P0?2Ph00P0>2P/0
1`0A3@h040`=00l;300=2``030X;00/92P0:20T00P091`P02P0;2@X01@<400d;300A3a003@/<00h<
3@0;1`H040`=01DA4P0D4142010;3`0901@?4`0@30d04Ph?00X61`0?2`X07ATJ014?4`0?3A803P`A
00803@/@01@04@lD01@B5`040PL03P`A00H42@0K6Ah03`/?00h8300=20`03`X>014<400@3Q40518E
010>4@0<30h04a<E014A4`0=3@l040lC00h<4@801`D:01H03@/@018@5@0C4AH01`D:00h<4@0J61d0
2PP=00/93P0B41D0>SPm01<A5P0I5a`040hC00X83@0=2a002`T>00X83@0<2Pl01P@900l=4P0=2Q40
3P/B0P0?31<200h;4P0=010=500?31<03``C00h;4P0?31<040dD014?500B41D03`dB01<A5P0=2a00
7Q`Q00d;400200l=4P0A014?500F51T06ALL010>4@0B41<06ALJ01`J7@0J61/04Q0C01PF6@0?3Q00
1`D801hL7`0B41<09R@W010>4@0?3A000P0>30l02P0?3A0040hA00400P0L6Qd040hA00@21@0<2Pd0
3P`?01DC600B41D2010>4`0401<A5P0E4aP040hC01<A5P805A<H00P04a4F010>4`0H4aT04`hD01XE
6`0I51X03`X@014<4P805A0F00L07QTO00l;400J5A/050lE01HA5@0D3a<04`hB00<04PdA02<050lC
01HA5@0F4AD05A0D018=4@0A31005A4B01hJ6`070`@09B4R02<O800=2@X04`l@00d92P0V8R<0B4A5
01DA4P091@H03PP:00`6200A2`d030H8014;3@0O6A/02PD600d72@0A2`d050h@00P2100F2a005PL>
01@73P0C2@h04PT>010:3P0201<=4@0Q01D<4@0A20`0200201832P0G4AL04Q<H04i=DP1PG6406Q4F
0146300900004`@701X>400I3`l040P600`70`0<10@040D;00l42P0G31806@hD01P=4`0G31805@X@
01P=4`0900@05``B00T0100A20`06@hD00l52P0;00H050T?00804`P>00D04@H<01052`0A1P`04PL=
0146300601442`H04PD<1P0@0`X200l22@<040<:00<04@@;00l22@0?0PT0100?0PT601032P0800l2
2@0>0@P03P4800h1200@0`X04@@;00l22@0=0@L300`01P0300/01Ooooooooooo01;ooooo000Koooo
o`0800h<3@0>3Ph03Ph>00h>3P0=3@d02`/;00X:300<30h200H6200>00l?4@0=3@l02PP9010<3@0A
3@h040`=014=3P0B3Pl02`L800h:2`0@30d04@d>010<3@0?2``200`82@0R01XF5`0<20T04@d>00T5
1P0?2``06QHG010>3`0>2``04Ph?00d92P0>20`07aXN00l=400@3Q80>CXn0<K:c@2g^K/08B0U00T9
2`0D3a<02P@8018<3P0H51D0@Cdn02@P8@0<20T05A4B030/;@0I5AH0510A00T51P0F4Q<020@5018>
3`<04@d>00<040`=00h:2`0>2P/00P0?2``01P0<20T02`L800l;300A3`h03Pl:00d<20802PX800`0
3@`:00X92@0?3a400@02018A4`0:2@h03@/@01@B5P0;2@X02PP900h<3@091`P200`:2`0@01HD5@0?
3@h040l?00d;30030@8030X;00X82@0;2@X030X;00d;300>30d02`T:00X82@0=2``040h?00l=3P<0
3@/<00@040h?01<A4P0D4Q<04@l@0P0=2``300`:2`0D010=3@0@2PX040/8010:2P0@2P`03`/<00l;
3@0>30l03`d@00L62`0@3a@02P/?00`;400A3a803`d>00d;300<2P/03P`=00l=3P0:20T2018@4@05
00/92P0:20T04Q0A01@B4`0>30d00`0:20T01`081PL02`T:00/92P0D4Q<01`D603Dc=015@d@0100>
30d0800>30h03P`?00/9300>31003`dB00D3200:20d02`T>00h<3`0>30d01@<402@R8`0:20T03@/<
01HD5@0100004@l@00T7200:20/05ADG01@D600G61d05A@I00d<4@0920h02`X?00T73@0:1`h06aTN
014>500<2A0030L=0P0@2`l200l:3P803PT=0P0=20`0;P0>2@d03`X>00l:3P0?2Ph030X?010>4`0M
6b001PD900h<4@0<2Pl03@/@00X83@0?3A802`T>00`:3`0@3Q<03P`A00h;4P0=2a4030X?00`9400:
20h02PP=00/83`0;2@l030X?00h;4P0?2a<030H@00`43`0?21<04PdD01@=5@0A2a803PT?00l93@0@
2Ph040`=014;3`0A3AD04PhL010<6P0?31P04PlJ00h;500:1a0200d:4@0500d;4@0=2a003@/@00d;
3P0=2``00`0=2`h0700=2a0040dD01<@5`0H5A`05A8K014>5`0?2a<04PP@00l42P0F3a<061<G00X8
2@071PP03`lA00T83@0>31802@<=00`44@0>1Q@050lE018@4`0A3a803`d@00h<3`0=2`h00@0201`J
7@081PT201<A500300`9300>1`h03PL>00803`P?00T040X?00l:3P0F4AD040`@00X82`0?3A004Q0C
00P62@0=20`00P0>2@d01@0=20`02PD900P31`0;1PX030L;00803@P<00X030L;00/62P0>2@d02`H:
01HA5@0<1`/02`H:018=4@0>2@d03@P<0P0<1`/02P0=20`03PT=00l:3P0=20`02`H:00`72`0>2@d0
3`X>010;3`0?2Ph200h93@8030L;00h03@P<00`72`0<1`/03@P<00h93@0?2Ph050lC00/62P0E41@0
4@`@00h93@0:1@T03PT<024M7P800`0001L0<Bd^01`H6@0>2P/02PH700T51P0;1`P040`=01<?400B
3A403@P<00<0000B3Q003@T:014=3P0=2@X020@500X61`0>2P/03@T:00/71`0=2@P03`/:00h:2@03
00`81`0B00d9200?2`X04Ph=014=300?2`X0920S01`G7P0C3Q@02`H<00T42P0G4QP02@@900`72`0>
2@d030P900l;300A3@`03PX<0P0=20`0300>2@d03`X>00l:3P0C3Q801@0400/62P0B3A4020<700l:
3P0400<05Q4E01TD60802@@80P0:1@T06P0>2@d04PdA00D00`0B3100BTA801LB5P0?2``03`X=00h9
3@0E4A803PX<00/62P0;1`P030L:00`72`0=2@X03@T;00<0000>2P/05a<D00<0000>2P/04Ph?00X6
1`0=2@X040`=0P0>2P/00`0@30d040X<00h82P0200`6200F00h82P0@2P`03@L900l92`0@2P`03`T;
00d72@0;1@L0208201@?3P091@@00`00010<3@0A3@h03`/<00T51P0E4A801P4504@o@`0g<SH03PT=
00d92P8030P901P03@T:00h:2`0?2``02`L800X61`0<20T03`/<00h93@0;1``040/A01D@500=20d0
6A@H01dH700@2`l03@T:00h:2`0C3a004Ph?00l;300>30d03@/<00`:2`0:20T200P61`0E00X82@0B
414030X;00T8200B4140518C00`82@0?2``05A4B014=3P0@2`l05a8F01@?4`0?2``05A4B018>3`0A
3@h06QHG014?4`0?3A803P`A008030X?02`02PP=00T7300Q7b@02`T>00l=4P0:20d0510C018<3P0@
2`l03`X>010;3`0>30l03`d@00`:3@0=3@l05aLI01DE5`0>3Q002PT=00h<4@0@3Q<03`dB014?500?
3A803P`A00D3200C4AH04@lD00P62`0C4AH040hC0040100D4QL01@@8020N8`0?3A803@/@00X83@0B
41D020H;018@5@0>314030T@00d:4@8040dD00<03``C00d:4@0@3A@00P0?31<0100>2a803``C010=
500A3a@201<A5P0601PF6`0F51T0;bdb00h<4@0C4AH0518G0P0<2Pl03`0D4QL03`d@024O8P0_;C00
6QPK00`:3@0E4aH03`d@01XH6`0C4A@09R@W00h<3`0:20/04a4D014?4P02010>4@0@014?4P0C4A@0
518E010>4@0B41<06ALJ00l=400D4QD05aDJ01PF6`0E4aP04a4F01DC600I5a`04a4F01DC608061HK
01805A<H01<A5P0G5AX04`lE014?500D3aD05Q4G01`G7@0P6b4030L=01TD600F4AH030L=014<400C
3Q804@`@010;3`0?2Ph200h93@0;01<>4P0E41@05Q4E01@?4`0A310040/?010<3@0A3@h040`=01PD
5@0300000P0E4A804@0>2P/030P901PD5@0D4140=S8c00/51`0?2@/04`d?00h82P0P6Q`0>C<e048l
?P0@2P`0208401TC5@0=1`T04PL<008050L>01d04`P>01893P0B2@h03@D:01L>4`0C2Pl05@X@01X=
500A10/03@H<00T83@0@3a@03PX>01/B5`0W72@07Q4H01T=4@0D20`03`D601491`0E3@/05`h?01@;
400900D030<801<:3`0700804`P>00L00P0201<83P0901X?5@0D2@l03PD900d2200C20h060dC00l4
2P0H3A<04@H<008040D;00<04PL=01<83P0A1P`01P0A10/6018530P040<:0P0A10/2018530H03`89
0P0@0`X01P0@10P040<:01442@0@0`X03P<900d220803P4800P04@<:01<42@0@0@P050D:01452@0>
0PH03`<701@831Cooooo000Kooooo`0400h>3`0930d04aDG00D82P806ahP00P041@G01PL7`0Q9BT0
2PlC00L=400@51L030`>00l=3P8030X;02H040h?00h<3@0=2``03@/<00`:2`0=2``03P`=00l<3@0D
3a006ADF01LC500?2``03@/<00l=3P0A3a002`X:00l?3`0a<C4030/;00l=3@0>2@L040`:01<B400;
2P/08R<U04E6B01BDeD04Q8D00d=3@0>2PT071LD00X60P0C40d06APF014@3P0;2PP03@`:020O7@80
40h?03003`d>00h<3@0<2Pd02@L:018@4`0:20/03P`?01HD5`0:20/02`T<00l=400F51L03`h@00T7
2P0?3A003@/<010=3@0B3Ph040d>018?400A3@h03PX;00l<3@0@30d03PX;00/82P0>2P`03P`=01PH
600:2PX030`<00L71`0C4A8030X;01@B4`0G4a@03@T:010<3@0B3@h040d=014@3P0<2`T02`X8014@
3P0;2PP03@`:00`;2@0=30X200l>300300`;2@0?3P`03`h<00803`h<00<03Pd;00d<2P0>3@/01@0>
3@/0300<2PP040d<018@3`0710@0;Rd[03Dd<P0A40l03P`<00/92@0<2PX02`/:00h=30803@/<100<
2P/200h<3@0500X82@0<2P/040h?00/92P0>30d00P0@3Pl03@0>30d03@/<00h<3@0;2@X040h?00l=
3P0=2``0;B//02h/;@0U8bH0<Blb01PF6@0C4A@00P0<2Pd08@0;2@`03@/>00h<3`0>30l03@/>00/9
2`0?2P/04@`<018>300<20D04a0=00d<200G5Q802PX800l?3@0?3`h02`/;00h@3`0M9bD0WjRY0;W1
`@0k@D803Q8D00`>400?3a802PP<00h<3`0?2Pl04P`A00h93@0;20/030X=00d;3P0200h<3`0@00d;
3P0G5AP04@lB00h<3`0?3A0030X=00X82`0<2@l040dD00L42`0C41L020H<01PE700F4aX0:2D/014>
5@803P/B02403@XA00/8400=2Q<040dE00P53@0?31D040dE01@A6@060``030TA01<@60050P/03@XA
00H42P0<20h05a@J01DC600D41H03@X?00P62`0E4AL03P/@00/:3@0E4QL03@X@00h;4@0<2Q002`T?
010>500@3A<030X@00d;400?3A800P0@3Q<01@0>314030X?00h<400A3a@03`dB00803@/@00`04@lD
00T7300P7R<03@/A00`93`0;2@h03@T?00d:3`0@31803`dB00h<400<2Pl200d;400900l=4P0@3A<0
3`/A00h:400=2a00:BL/01DC600=2a003`dB00803@/@01T03P`A00l=4P0<2Pl02`T>00d;400B3QH0
3PXB00X63P0A3A@02`P>00d;4@0?3A803@/?00X82`091`X02`T<00h<3`0B41<05aDH00@31@0>30l0
2`T<00h<3`0=2`h030X=00802@L:00@030X=00d;3P0<1`/03PT=1@0?2Ph01@0B3A4020@7010<3`0<
20/02`H:00803@P<0P0<1`/00`0=20`03PT=00`72`0300h93@03010;3`0B3A402PP=008020H;00D0
2`T>00l=4P0A3a@02@L<00P62`0200l=4P0300/93P0=2`l03PT=00802PD90P0=20`0100<1`/03PT=
00d8300<1`/200d8300X00h93@0<1`h03@P>00h93P0>2@l03@P<00`72`0@2`l040`=01HB4`0@30d0
20@500l;3@050P<05Q4D00h:300A30l020D606IRI00g<SD03`X=01D@4`0;1`T04@`?010<3P0=2@/0
2`L900X6200;1`T03@P<01D@500G4QH04@`A010;400I51T05A0G018=500@2a402`H<00`73@802@@:
02@03PT?00/6300<20d040/A00l:400>2@l03`X>00`72`0>2@d03`X>00`72`0B31003`T=00h8300?
1``04@P=01893P0C2Pl03`X>010;400910X03@P>00X52P0D41D02`H<01LB5`0F4AL02PD;00h93P0A
31803`X>01@@4`1[IVX061@G00P31`0@2`l300d8300800`72`0;1PX02`H:010<3@0<20T0<Rh_00/7
200@30d300`82@803@T:01<03PX;00h92`0?1`/040L;00l72`0>20`03PP;00h82P0;1`P03@X:00P7
1@0;2@T02PP8020N7P0@3Q403@/>00/9300:20/030X=00L03@/>00X02`T;01<A4`0D4Q<030X;00l=
3P0J61T02PP900`:2`0;2@X030X;0P0>30d0100?3@h03P`=00d;300=2``200`:2`802`T:00X02@L8
00d;300>30d030X;00d;3P0@3Q404a4D05YHF`091`X04@lB1P0>30l01@0=2`h030X=00`:3@0<2Pd0
3@/>00802`T<01403@/>00h<3`0>30l03`d@014=3`0@2PX03`/;00h:2`0?2``03@/<00l=3`0?3A00
3`hC01<B5`0B4AH030/@00/93P0200h<4@0300d;400<2Pl030X?00<03@/@0`0>31401`0;2@l04@hE
010=500>2a802`P?00h;4P0:1`h00P0=2Q402`0;20l03P/B00h;4P0?3Q@03PdC01<B600E51X040lE
00h=4`0@3aD04A0F00803@`B00T04Q4G010?5@0=31403`hC00d<4@0F5AX03@`A00l>4`0@3a@00P0>
3A802@0A41D04Q4F010?500C4A@061<G01XE6@0C3Q8040/?01<>4P06018=4@0<014<4P0B3A<071LM
010;4@0E41H06aHL01HA5`0O6R004`hD00h93`0E41H050lE0P0B41D201<A5P0=01@B5`0E4aP05A<H
014?500H5Q/05A<H01PF6`0=2a004Q0F014@5@0E51T040lD01@C5`02018@4`0801<@4`0E4A805Q8C
01LA500G4A<05Q8C00l;300@30d201<?400:01@@4@0C3a004Ph?010<3@0B3Pl04@d>01<?400D4140
5a<D01<?40804Ph?00D040`=014=3P0A3@h04@d>010<3@02014=3P804@/?01`0618F00h8300C3A40
4`dA01D?4`0A2`l05Q0D010:3P0?2@d06A0E01@93`0B1`d04@H<01873@0E2Q005@/@01D:400F2a40
50T?01873@0C20h03`L:01@?400=20T04``@01H<500P5R0050TD0P0@1@h06P0A1@/04@H901871`0@
20T03`X>010:3P0>20`030H:00h62`0@20d040L<01483@0?1P/0?C<i03DZ<00>1@T06@hD00h42@0K
41H030<704]0AP0F2a404`P>0146300?10X03P<90`0@1@/2014630@040D;00L03@8801P=4`0C20h0
4@H<01032P0E20l03P4800804`H=00<04@D;01032P0@0`X00P0A10/201032P803P<;01H03P<900l2
2@0?0PT03`8901842P0A10L04P<701011P0C10P03P<600T21P0=1`/040H900l4200B0`L04`450180
1@0B0PD04@<40103100?10@03P@45?ooool001_ooooo01803A4D010E600A5QT01``@00/@50001@T0
000506U/L@2/[k@0:Rha00D9300L82<03Ph@014?400<2P/02`T:00h<3@0;2@X600d;300N00T41@0D
4140510A01DA4P0T8R<0<Bl`00d;300?3`l0410@03Ti>@0<30`04A0>018=2P091@@030X;014@4@08
2@d01@H:00`=400H61X0410@01@@400400005Q8?014>3@0@3`d03@`:014@3P0:20T04@l@0`0>30d0
2`0=2``02`T<00`:3@0:20/02`T<00`:3@081PT02@L:00X82`091`X01085008061HI00<020H900X7
2@0=2@X00P0@30d00`0B3Pl040`=00d92P0200l;300H00h:2`0=2@X03`/<018@4@0000001`L700d=
3@0D51@040h?00T7200A3a00510A00d92P0A3@h04`d?00`8200100002`X800L6100E51803`h<00d<
2P0<2`T03@`:0P0?3P`00`0<2`T02`X800`;2@0400d<2PH03Pd;00X051<A014@3P0:2@P040l=00l>
300O7Q`02PT700`;2@0>3@/030/90P0:2@L07P0>30d03@/<00`:2`0;2@X03@/<00h<3@0<2P/03@/<
00X82@0;2@X03`d>00T7200<2P/04@l@01<A4P0A3a003P`=00`:2`0C4A805A<D01LE5P0<2P/02`T:
00P61`091`X061HI00d;3P0?3A003@/>010>4@803@/>0P0<2Pd200d;3P0P01<=4@0A30l04@d>00`8
2@0D4Q003Pd;00`;2@0;2`/02`/=00T83@0920h02P/?03Dn?@3QjnX0logl04]BDP0830d03A4B010A
4`0<2Pd04a4D00`72`0E3a<02@@8010<400=2`h030X=00h<3`0?3A0040hA01PF6@0?3A0200`:3@0L
00d;3P0>30l061HK01/I7P0:20d01P@9018@5@0X9R/0518G00/93P081P/03P`A00P62`0>2a<06QLP
014>5`0710d05A8K00d:4`050`/04PlH00`94P0A3QL04PlH00P53P15@TT0>SPm00d;40801P@900P0
3@/@00l=4P0610T02`T>00L52P0B41D05Q@I00H52@803@/@00@030X?00l=4P0=2a002`T>0`0=2a02
00`:3`0300T7300<2Pl03`dB00803P`A00T040hC00h<4@0<2Pl05A<H010>4`0200D03@/@00`:3`0=
2a000P0>314200d;400@014?500?3A8030X?00X83@0;2@h03@/@014?50081P/03@/@01@B5`0:20d0
3@/@00/93P0>314040hC00h<4@8030X?00`03@XC00d;4`040@X06aPO00X73P091Pd09bDZ01XH700<
2Pd02@L:00H41`030@@201XH6`0600P62@0<2Pd02PP;00d;3P0@3Q403@/>0P091`X03`0=2`h040hA
010;3`0?2Ph03@P<00`72`0>2@d03`X>00/62P0:1@T01@0401HA5@080`L06aHJ00h93@0200`72`06
00l:3P0=20`02PD900T4200=20`03PT=0P0=20`03@0>2@d030X?00X83@091``02`T>00d;400>3140
1`D:01LE6P0o?D80;bdb00H42@0<2Pl00P0=20`00`0<1`/02`H:00d8300200h93@0900d8300<1`/0
3@P<00d8300>2@d02PD<00`73@0=20h03`X@00803`X>01H02@@800`82@0O6a`02`L8018>3`0M6A/0
5A0D00<00P0;1PX00`0201TD601BCE40:RDY00<00P0D3a<02`H:00`72`0>2P`03PX;00`82@0;1`P0
2PH70`0;1PX01`0<1`d03@P>014<4P0?2Q403`X@00d83P0:1@/00P0<1`d01@0=20h03PT?01LB600F
4AL02PD;00802`H<00P02PP;00T72P081PT03@/>018@4`0>2@d03@P<00`72`803@L;01@03PP<00l9
3@080`T04PdC00d83P0?2Q0030L=010;4@0<1`d04`hD014<4P0;1P`03`X@00h93`0[9RX020<701XE
6@0300802@@801XE6@<03@P<0`0<1`/01P0<20T04Ph?03<_<00<20T040`=00d92P@040`=0P0?2``3
00l62`<03@L900H03PX;01HC50091`P020L500@30@0:2@L200d;3P8030X=0P0;2@`600d;3P08010>
3`0;2@X03@/<00`:2`071@H020H700`:2`0=2``200h<3@8030X;01003@/<00X82@0:20T02`T:00h<
3@0@3Pl03@/<00D3100=2``03`d>00T7200:20T02@L:00`:3@0>30l02@L:2@0>30l300d;3P0=00h<
3`0D4QD03`d@00P62@0A3a806QPK01<A500>2P/040X:00l;300>2P/03`/<00d;3P0200l=400500`;
400>3A803PdB00d<4@0=2a000P0>31400`0=2a0030X?00`:3`0300`:3`0800d;400>31403P`A00T7
3@0A3QD03``C00/83`0B3aH200`9400?00l<4`0=2Q402`P?00h;4P0=2Q403@`B00`;4@0@3aD04a8H
00h=4`0=318040lE01<B600A41H030/A00803`hD01<03@`A01LF6`0=31402PT>00d<4@0H5a`03`hC
010?500A41D03`hC00h=4P0@3a@02`T<00l=400B41<040hA00l=400C4A@03P`?00803`d@00l040hA
014?4P0A3a807adR01HD6@0=2a0040hC01hL8@091``04Q0E01HD6@0>31403@/@01@B5`0@3Q<00`0A
3a@3018@5@0801<A5P0G5AX05aDJ01<A5P0L6Ql03`dB00`;4@0J6Al201@C600600l=4@0Y9bX04Q0C
01<@4P0D41404`l@0P0D3Q001@0K5aP0:2@U01`H6@0>2P/040`=00804Ph?00/04`l@01PD5@0;1`P0
4@d>00/7200M6AX071PI01@@4@0?2``03PX;00`82@0600l;300301D?4`0A2`l08adQ008030H:00L0
4P`@014;3`0@2Ph03PP<00l93@0D3Q805@dB00L04`P>00/050T?01873@0@1@/04@H<01072@0F4100
3`T;01@<4@0?1@d05@/F00l43`0201<74@0601@83P0D20`050P:01892`0>20`03PD:0P0?1P/03@0<
1PX040X>00`62P0400804P`@00l93@0:0@H04@L<01D:400;0@H050T?0146300700800P0B1`d01P0A
1P`03`@:00l42P0?10X03P<900l42P804PL=00<04@H<00l42P0;00H00P0?10X03`0I3Q@050T?00l4
2P0>0@P05`XA00d21`0;00D0300600P00P0B1@`04@@;01032P0?0PT040<:0185300400l22@0D00l3
2@0>0`T04`P>01042`0E20l03@0701@73P0E2Q004@XA00h83`0A20d04PL=01<32P0A00H04@0400h0
000@0@@05PL:01<82@0;0@8Dooooo`006oooool04`0:3aD041DK01<H7P0=4QP041DJ00T>4P0c=S/0
7B0U030c>00310P04A8F0042100>3Ph04@l@00`:2`0;2@X03`d>00`:2`0=2``00P0>30d04`0=2``0
30X;00`:2`0B30h05A4B018>3`0?2``05Q@E01hL7@0?3@h020P801@D500>3Ph030`<00/92P0>2@P0
40`=00/9300>31000P0B4aL0300>3a<02`X?00/;3@0D41809AlO014=300<2PP02PT700P71@0?3P`0
20H700l=3P<03@/<00l030X;00X82`0>30l01P@701<A500D4aD01P@7014?4P0C4A@00`4401DC5P11
?d80>SPk028P8`091PP00P0A3@h00`0>2P/04@d>018>3`0200l;30<04@d>0140510A04e;C00P8200
20P800/;2`0>3Ph02PP9010>3`0?3@h04@d>00d92P0A3@h04`d?00`8200920H04Q4?00l>300200T8
1P0300d<2P0<2`T03@`:00803`h<0P0<2`T01@0=30X03`h<00l>300@3`d03`h<00H03Pd;00T010<1
01DD4P0920H06APF004000081`H02PT700l>300@3`d00`0<2`T200`:2`@03@/<01H02`T:00d;300:
20T02`T:00h<3@081PL03@/<014?400C4A804@l@00h<3@0=2``01`D600P61`091`P05aDF00T7200B
41400`44010>4@081PT030X=0P0:20/0800A3a8040hA00h<3`0>30l040hA014?4P0B2a804`dC01LB
5P0B3A405A8C00P61`0@3Q003Ph@00`;400A41L061HQ01TI8@0G8240GFMV06YcLP0O9BD02`l@00`@
4@0=3Q002PP;01<A500:1@T05a4E00P31`0D4QD03`d@0P0<2Pd02@0>30l03`d@00/930081PT01`D8
00T72P0<2Pd03@/>00H52@0200H42@0A014?500610T00`4600X83@0=2a005A<H01<A5P0=2a003`dC
03llA@2`[KH07Q/T00401`0<2A806QLP018?600;21400`0<2A803@1;B4h0?C]000l=4P0?3A8061HK
01LE6P0D4QL05aDJ0040100K6Ah0BDM<02LU:P091``00P0=2a00100<2Pl03`dB00`:3`091``200X8
3@0600/93P0=2a0040hC00/93P0<2Pl03P`A0P0=2a001P0?3A8040hC00d;400<2Pl05A<H00801@T0
3@/@01h02PP=00L52P0:20d02PP=01LE6P0610T03`dB010>4`071@X030X?00X83@0<2Pl040hC00h<
4@0;2@h02PP=01HC700;21403@XC01@A60050PT06AHM01DC600<2Ph020H900d;3P0@3Q403@/>00`:
3@0@3Q4200d;3P0400X82`091`X04@lB00h<3`802@L:01`03P`?014?4P0B3A403`X>00`72`0;1PX0
3@P<00l:3P080`L071LK00<00P0Q720040/?00H11@0=20`02`H:00l:3P0F4AD050lC00l:3P0=20`0
4@`@01<>4P0A31003`X>010;3`0<2Pl02`T>0P0:20d04@0;2@h030X?00d;400@3Q<0518G01DC600@
3Q<03@/@00`72`0?2Ph03PT=00/62P0<1`/03`X>00h93@0=20`030L;00803@P<00<03PT=00/63@0<
1`d00P0>2@l0600>2@d04@`@00P31`0300003`/<00D10P0F4Q<09b<U00d8300S7R802`H:00X52@0=
20`03PT=00d8300C3Q8020@7018=4@0G4QH02PH800l;300=2@X02`L800X61`802PD900T030L;00d8
3P0<1`d02PD;00X5300>2@l03@P>00/6300<1`d00P0=20h0300:1@/08ahT02PS:@060@L01@0601HB
600820X02`/=00P82P0:20/03`d@00`8308030L;0P0<1PX0500=1`/03PP<00l:400>2@l02`H<014<
4P0500H03`X@00d83P0@2a403@P>00`73@0?2Q0030L=01hI7@060@D05Q4E01lJ7P0G4QH03PT=1@0=
20`01`0<1`/040`=00T51P0G4a@00`0000`82@0B3Pl00P0A3@h2010<3@0300l;300>2P/040L<0080
40L<0`0>20X01`0H51D07Q/L00L51P061@<02`X8010>3`0;2@`00`0=2`h00`0<2Pd02`T<00`:3@05
00`:3@0400d;30071@H02`T:00d;30802PP900@04Q0A00l=3P0@3Pl03`d>0P0;2@X04P0D4Q<03`d>
00`:2`0<2P/03P`=010>3`0R82402`T:00l=3P0>30d01`D600d;300;2@`030X=014?4P0920X05A<F
00X82`H03@/>00<03`d@00h<3`0=2`h00P0>30l03P0:20/03@/>018@4`071@P00@0200L5200B3Q40
40X:00l;300>2P/03`/<00d;3P0>30l03@/>100<2a00100=2a003P`A00h<4@0=2a0200`:3`<03@/@
00D03`dB010>4`0@3Q<040dC01<@5`0200/83`0<00h;4P0=2Q4040dD01<@5`0A3QD03P/B014>5@0?
31<03`hD00d<4P0B4AL051<I0P0@3aD0600>3A<051<I018A5`0;2Q0030/A00h=4`0=31404A0E01HE
6P0D4aP03PdB01TH7@0?3Q<04Q4F01<B5`0>3A8030/@00l>4`0B41<0518E01DC5P0A3a803`d@014?
4P803P`?01003`d@010>4@0A3a804@lB014?500H5Q/081hS014?500<2Pl061HK010>4`0B41D03@/@
00l=4P0E4aP040hC1P0A3a@03P0B41D05A<H01@B5`0=2a00518G00P62`0G5Q`04a8G00X93P0?3Q<0
6APL00d;3P0B41<04a0B0P0C3a02018<3P0502TU9P0g<c@08alP014=3P0C3a000P0A3@h02@0E4A80
5Q8C010<3@0P71d01P8301PD5@0G4a@04@d>010<3@0201<?4004010<3@0>2P/03`/<010<3@803`/<
010040X>01@>4P0a:bl05Q0D00`62P0B31002`D9010:3P0>20`040X>00l93@0>1`/04`P>01@93`0E
2Q004`P>0P0B1`d0900C20h050T?01873@0@1@/04@H<00l72P0D3Ph03@L901@<4@0@1Ph05`dF0105
400A1@l04@H>01<73@0D20`050P:01@8300?1P/03P<900l62`0A20d03PD:00T31`0O6Ad04`dA00/5
2@0?2Ph04@/?00`42@0C20h050T?00T0100>0`T060dC014630804`P>00D04@H<01873@0@1@/03P<9
00l42P0201873@0<0146300?10X03`@:01@93`0A1P`05``B01873@0?10X0200201<63@0>0PP04@@;
0P0F2A001P0A10/040<:01032P0B1@`05@P?01T<4`@03`8900@03P<900h32`0:00L030<;0P0800L0
3P0A1a00100500@0100=1`h02@0700L0100B10/04P4900l01P0B0@L05@H901D93@0B1`P030835?oo
ool001_ooooo01<01@/G05QOJP2HWjP0GFA]01lU;@0A5A/030dD00`<4@0A4AD04Q4F00h=400=30l0
30X;00l=3P0;2@X030X;014?400?3@h03@/<00803`d>00@03P`=00/92P0:20T050h@0`0@30d0100=
2``030X;00l=3P092@T2014A4@0A00h>3P0;2@X04@`>014=3`0<2Ph03P`B00h?5@0;2a807QhU051?
EP0d<cP02PH901<>400?2``040d>018@4P0=2``00P0A3a000`0N71d030X;00d;300200d;300K00`:
2`0:20X0518E00/9300]:bh0<S0c00d;3P0B41<040hA01DC5P0K6A`030X=00T72P0@3@l04Ph?010<
3@0>2P/05Q8C01/G600C3a0030P900h:2`0@30d04@d>01@@4@0f=3D061PH00803Ph>00@03`l?00T7
200;2@X03@/<0P0?2``02`0A3@h04@/=00d92@0E51802PT700/:20081`H040l=00d<2P0<2`T03@`:
00803`h<00@030/900/:200;2PP03@`:0P0>3@/00`0=30X03Pd;00h=2`0400h=2`0Z018A3`0:2@L0
3@`:00/:200C4Q0040l>00l>300B4@l03`h<00d<2P0C4Q004Q4?00T7200;2@X03`d>014?400?3@h0
30X;00/92P0>30d030X;00d;300?3@h02@L800l=3P0@3Pl03P`=00`:2`0=2``040h?00X82@0A3a00
2PP902l];P0<2`/03@/<00X82`0@3Q4030X=014?4P0>30l03@/>0P0?3A0200d;3P0T00l=400?3A80
50dE010:4@0B3A<04@`A01`I6`0E4aD03@/>00X93P0<2a402PPD00`:5`0?3aT0318D00H=3@0B61P0
41HF00lB4`061`T03Ph@00T72P0>30l040/?01<>4P0@2`l061HI014?4P0=2`h02`T<00`:3@0=2`h0
2PP;00d;3P0>30l030X=0P0;2@`200l=4P0F00h<4@0Q7b@020H;00X83@0=2a002PT=02DS:00[:Bh0
5A<H00d;4@0>2a80>3Dl010=500B3aH02@H=00P6300;20l03P/B018?5P0:1`h02`P?01@B60802`T>
00l030X?00d;400?3A801`D:018@5@0A3a@03@/@020N8`0T8RL0518G00h<4@0=2a002`T>010>4`0?
3A80100<2Pl01`0=2a003P`A00h<4@0?3A803P`A00/93P0:20d00P0=2a001P0>31405Q@I01HD6@09
1``03`dB00h<4@@03@/@02L03P`A00T7300>31403P`A00`:3`0A3a@03`dB00h<4@0=2a003P`A00T7
300:20d03P`A00d;400?3A804Q0E010>4`0>31403@/@010=5P0>2a@03@XC00h;4P0X9B`020D<018@
5@0=2`l030X=00l=400=2`h01`D800h<3`0<2Pd040hA00T72P0;2@`03P`?00l=400=2`h00P0;2@`0
4`0=2`h03`d@014<400?2Ph03@P<00`72`0>2@d03`X>010;3`0J5QT06A@H00h93@0910P05A0D00l:
3P0<1`/03PT=01@?4`0A31000P0>2@d00`0B3A404`hB014<400200l:3P0300`:3`0;2@h02`T>00<0
2`T>00T030X?00h<4@0;2Ph03`dB010>4`091``03@P<010;3`0?2Ph00P0=20`0100?2Ph03PT=00d8
300<1`/200d8300C00h93@0?2Q403`X@00h93`0=20h02`H:00T4200?2Ph03PX;00l;300<20T020@5
010;3P0=2@`0510C00l:3P0?2`h02@D800h:3@0200d8300900`72`0=20`03`X>00l:3@0>2P/03@T:
00`82@0;1`P02`H:008030L;0P0<1`d01P0;1P`03`XA018=500@2a403@P>00`73@803PT?01P030L=
01<>500?2Q003@P>01D@5P0<20h02PX<00`=3`0?41802`/=00P82P0;2P`02`X=00/9300;20`02`L;
00`72`0=20`03PT?00`73@0V8BL0=c8h018=4`0<1`d200h93`0:00`73@0=20h03`X@00`73@0A3100
2`H:00h93@0A310040`?018=4@<03@P<0`0>2@d01P0<20T02@D601<?400B3Pl0510A00/720803`/<
0`0>2P/0100=2@X04PT<0189300B2@`3010:300800X61`0B3a001P@500T7200:20T030X;00/9300<
2Pd300d;3PL030X=0P0=2``03P0?3@h030X;00/92P0@3Pl03`d>00L51P0<2P/03@/<00/92P0>30d0
71XK01DC500A3a003@/<0P0<2P/0300H5QL020H700h<3@0?3@h020H700`:2`0<2Pd0518E00/9300=
2`h030X=00l=40H03@/>00<03`d@00h<3`0=2`h00P0>30l0400C4A@030X=00T72P0O7B00;B/^01dK
7P0>2P`040X<00l;300>2P/03`/<00d;3P0<2Ph030X?00d<4@0>3A8200`;4@0400d<4@0>31403P`A
00d;40@030X?0`0=2a005`0>31403P/A00h;4P0<2A0061DL00l<4`0=2Q403``C018?5P0@3A@03P/B
010=500?31<03PdC00`;4@0?3Q@04Q4G00l>500@3aD04A0F01HE6`0E51X040lE00804A0F00d05QDJ
010?500S8RL040lD06UXK@0K6Ql040lD018A5P0C4QL03`hC00h=4P0@3a@04Q0C00804a4D00<04@lB
010>4@0?3A000`0A3a83018@4`0;01XH7@0D4QL04Q0E018@5@1VI6T040hC00l=4P0@3Q<03`dB014?
500D4QL0100B41D3014?500@01@B5`0E4aP04a4F01dK800b<3D05aDJ018A5`1FEE/0D4mD00h=4P0D
4aL05aDH018@4`0C4180510A01<?40804`d?01006ADF01lK700D41404Ph?01LC500D414040`=01TE
5P0E4A809b<T03di>P0F4Q<04Ph?01<?400?2``04@d>0P0F4Q<04`0B3Pl03`/<010<3@0D41404Ph?
00l;300C3A4040X>02TS9`0B31002`D9010:3P0C3A4040X>00d72`0?2@d040X>01493P0C2Pl00P0D
2a00;00B2@h040L<01483@0D2a005@`A01<:3`0A20d04PT>014:3@0B30d0208401493P0;0@T05@/D
01463`0@1@h04@H>01@83P0F2Ph05`/>01H:3`0B1P`04@@;0186300B20d03`H;00l7300H4aL030L;
010<40040PD0514D01D>4P0900@04`P>01@93`0A1P`03@<800d2200C20h04@H<00h32@0B1`d03`@:
0P0@1@/30146300501052`0G31807A8H01873@0A1P`00P0@1@/0300>0PP04`H=01032P0B1@`03@47
01042P0B1@`04@@;01032P0A10/04`H=01H940803`<701H03`8900h32@0>0`/030@<01D<5P0:10l0
2P@A00h95@081A00BDA@09J@V@0a:c803@@=01D;4`0>0PX060PB01002P0I2Q806``B0185300>0`L0
40D95?ooool001_ooooo00h07RLf09NP[@3hool0WjFa02L]=P062A005aLO01DE6P0A3a@05Q@G00d8
300A3@h03@/<00l=3P8030X;02L040h?00h<3@0=2``03`d>010>3`0>30d02PP900T7200D3Q004Ph?
014=3P0@30d030X;00/92P0920P05QHF014A4@051@D01PH6014?400A2`l030L=00l=4P0C4AP03`lI
00h>600_;cP0Xj:Z03@c>@0C3Q<05Q0D00X52@091PT030X?00P62@091`X01@<6010>4@0=2`h00`0>
30d03P0=2``03`d?01DC5P01008040hA02TW:P0C4A@03`d@00/930030@@02`T<014?4P071@P02PL9
0P0>2P/0100=2@X0510A01HB4`0A3@h200h:2`0<00d92P0<20T03PX;00`:2`0C4a<030`<00<30`08
20P05aDF010>3`0=2``03@T:0P0?2``02P0>20X0510@00h=2`0C4Q002`X803Xi=`0920H03@`:00`;
2@0=30X200l>300300`;2@0;2PP02`X8008030/900<02`X800X91`0>3@/01@0>3@/0300100007QdK
00h=30040`403`h<01<B40081`D02`X800P71@0=30X05aHD00l>308030X;01d03@/<00h<3@0@3Pl0
40h?00`:2`0?3@h03P`=010>3`0A3a002PP900`:2`0?3@h03P`=00`:2`0;2@X030X;00800@0>30d0
30X;01lM7P0;2@X01`D601PF6@0E4aH03`d@018@4`0;2@`02PP;00/9300400`:3@0A00/9300C31<0
3`X=01<?400D40l07adI01HE400?3P/01PH600h>400E51/0?C]806ATKP0>4Q@01`/<00T=3P0;3Pl0
0P0?4180?@0R8R@05A<F00l=400G5AP01`8601<>4P0B41<03P`?00`:3@0=2`h03P`?00l=400;2@`0
3P`?00d;3P091`X020H900T72P0;2@`00P0302DS9P20OX40;B/^00/9300B41<01P@700L5200@3Q40
3@/>00d;4@0C41L00@05018?5P050PT04@hE010=500;20l05A8I01lL8`0A3QD03P/B01<@5P0:20d0
3@/@018@5@0>31404Q0E00h<4@0100@03P`A00P62`0;2@h09R@Y01DC600>314030X?00X83@0B41D0
518G00l=4P0>31400P0?3A800`0>314030X?00d;400200d;40802PP=00L03@/@0040100J61d0?ce2
01DC600610T02PP=00803P`A0`0<2Pl03P0>31403`dB01DC600?3A802@L<010>4`0=2a001`D:014?
500:20d06ALL01HD6@0<2Pl02PP=0P0<2Pl05P0:20d02@L<00X83@0100L02@H?00@12P0710/0924X
00401@071@X02@L;00`:3@0?3A004a4D01@B5@081PT03`d@02@R9@0E4aH030X=00<1100;2@`400`:
3@0300/9300=20`03PT=00803PT=0P0?2Ph02@0I51P0MW5e00@00`0300806A@H00<00P0@2`l03`X>
00d8300300`72`0300d8300>2@d03PT=008030L;00D03PT=00X83@0;2@h02`T>00`:3`0200/93P06
014?50040PL01P@900L52P0;2@h0518G0P0=20`01`0?2Ph040/?00h93@0<1`/03PT=00d8300<1`/0
0P0=20`0400>2@d03PT@00h93`0>2@l03@P>00/62P0:1@T03`X>00X61`070`@03@T:00h:2`0@2`h0
8ahR0;Ze^@0P6al200/62P07018=4@0F4AD05Q4E00X52@0>2@d040/?010;3P0200`82@0Q00d92P0<
20T02`H:00d8300910P020<900h93`0<1`d03PT@00l:4@0>2@l03@P>00/6300A318040/A00X52`0=
20h04@`B00d83P0;1P`03``A00L82P021PL04QHG01TM7P0:3Pl020T;00/<3P0<30h02`/=00T92`0:
20/02`T<00802`H<00H040/A01TD6P080`T030L=00d83P0<1`d200d83P0300`73@0=20h02PD90080
40/?00<00`0200H11@0:1PT00P0=20`200h93@803`X>00H04Ph?00/7200400403`/<010<3@0>2P/4
00d92P803PX;0`0@1`P0200>20P03PP900h82P0810D030T;00d;3P0B41<020H90`0<2Pd0100:20/0
2`T<00d;3P0?3A0600/930803P`=01P03`d>00/92P091`P03@/<01lM7P0=2``03`d>00/92P0610D0
2`T:00H41@071@H020H700`:2`0?3@h040h?00H41@071@H02PP900h<3@0<2P/02PP900T72P0C4A@2
00T72P0301DC5P0<2Pd030X=00D030X=01003@/>00`:3@0<2Pd030X=00d;3P0;2@`020H900/9300F
51L06ALJ014?4P0=2@`040X<00l:3P0>2@d03`X>0P0=2a001P0>31403@`B00/:400;2Q003PdC010>
50803P`A00X03@/@00`:3`0<2Pl03P`A010>4`0?3A803P`A00d;400<2Pl02PP>0P0I5Qd0400?31<0
40dD00P5300;20l03P/B00d:4@0<2A003``C00h;4P0<2a402@P>00`;4@0?3Q@03@`B00l>500=3183
00l>5009014@5P0=31803PdB01HE6P0K6al07QdR02XY;P0G5Q/04A0E008040lD0`0B4AH200h>4004
010@4P0B4Q@04Q8D018B508051@F00d04a<E018B500A4A<0410B00H52P0J6Ah010<802LV:`0F5AX0
71/P00d<4@0A41D04a8G008040lD00@051<H01@B5`0C4AH04a4F0P0B41D04@0A3a@05Q@I01/I7P04
0PL0:BL/06ARI`0E4aP071/Q02DT:P0A41D071/P01PF6P0<2Pd04Q0C01<@4P0D41405A4B00805Q0B
0P0F4Q<01`0E4A80510A014=3P0@30d04Ph?01@@4@0>2P/00P0H51D05@091@H0510A01LC500B3Pl0
4@d>018>3`0A3@h04Ph?00d92P0>2P/04`l@014=3P0=2@X04`dA00/52@0D3Q8030H:00l93@0=1`/0
4@/?00/52@02014;3`0D00d72`0C2a0050/@01@;400C2Pl04@P=0107300A20d04`X?01@;400B2@h0
40L<01483@0C31005@lC00`62P0F3Q<02`8701@:4P0B210201<8400@01@83`0E20l05@P?01D73P0F
1`h05`P?01<63@0A1P`040L<00/4200E41@04PdA00/9300N7R00BTY<01H@50804@H<00P03@8800/0
1P0F2a403`@:01D:400@1@/0304701@93`804PL=00T04@H<00l42P0>0`T03`@:01873@0@1@/06PlE
0146300>0`T00P0?10X01P0:00@02@0301H9400Y72<08A@K03<V;@804@@;00@040<:00l22@0>0@P0
3P480P0A0PL03`0?0`P03P<900h3300;10`0100700D13@071A<0:BLe01<B8@1iMhD0oo[o04]3CP0:
0Pd08aTT01H:500200h12`8050L@00<03`8;00d12@0B1@`05?ooool001_ooooo01d07BHe05YSL@2k
`m00EeeY01<F800?4Q/03`lG00T83@0?3A003`X>01<>3`0D3Q004@d>014?400<2P/02`T:00h<3@0;
2@X03@/<00l=3P0@3Pl03P`=00X82@081PL04@/=018>3`0@30d03@T:00h<3@02018@4@0I0000000B
4Q801PH602TY:@0K6AX04PdA00l:400<2Pl00`8:00P84P0E5Al06QXT07elQ00J6Al03`X@014;3`0D
3a<03``A014?500?3A8040hB00H41`0<2Pd03@/>00h<3@0200l=3P0@00h<3@0@3Q00108501<A500<
2Pd04Q0C01lM80091`X02PP;01PF6@0>30l02@L:01<A50081@L03`/<010<3@803PX;01@030P900d9
2P0C3a004Ph?00l;300;1`P030P900X82@0E5AD00`<3018B4P071`L04Q0A00l=3P0=2``030P900l;
300>2P/030H800T51@8030/900H0:BPV0=_Jf00d<c403@`:00`;2@0=30X200l>300300`;2@0>3@/0
3Pd;00803Pd;00<03@`:00/:200>3@/01@0>3@/03P0F5A<00@0001<B40030P003`h<00h=2`0;2PP0
3`h<00h=2`0G5Q@08B0N01<B400?3@h03P`=0P0;2@X0700@3Pl0518C00`:2`0@3Pl03`d>014?400B
41402PP900T7200>30d040h?00h<3@0:20T02@L800/92P0?3@h030X;00T7200=2``03`d>018@4`0=
2`h02PP;010>4@0=2`h03P`?00/9300=2`h200l=400K00d;3P0;2@`03`T;01<>3@0N6aH07Q/D01`K
40061P004A4800h?2P0D51801PD9028Q:@1@CeL05aXL00D92P062P/04A8D00l@4P0:2`d05aLI00/9
300610L06QPK00L21P0K5QX03@/>008030X=01h03P`?014?4P0B41<030X=00h<3`0=2`h02`T<00h<
3`0B41<03P`?00P62@010080:BLZ00400P0A3a8020L901<A500@3Q403`d@00L520081PX02@H=01`I
800610X04a0G00l<4`0:1`h01`@;00d:4@0E4QT200X73P0;03Le>`0X9R/00P0500X83@0>314030X?
00X83@081P/03@/@00/93P071@X00P0<2Pl0200?3A802`T>00X83@0C4AH05Q@I00l=4P0;2@h03P`A
0P0A3a@08P0@3Q<02`T>00/93P0<2Pl02PP=00/93P0@3Q<03`dB00@21`0@3Q<00@04018@5@0=2a00
3`dB00h<4@0<2Pl02`T>00`:3`0?3A802PP=010>4`0=2a003`dB01dK800S8BH03P`A01@B5`0=2a00
:RP]01dK80091``03P`A00l=4P0>314200/93P0E00d;400;21403@XC00l<5@091Pd01`@;01<@5`0=
2a003@/?00X82`091`X02`T<00l=400A3a8030X=01XH6`0:20/03P`?010>4@091`X02`T<00803@/>
00@02`T<00T72P0;1PX03@P<100?2Ph020060@D061@G010;3`0910P02`H:014<400>2@d03`X>0P0>
2@d02P0A31004`hB00h93@0>2@d03@P<00/62P0=20`03`X>00X83@0;2@h300`:3`0@00/93P091``0
3@/@00d;400?3A802PP=00@21`0>2@d030L;00h93@0A31003PT=00X52@0>2@d03@P<00`72`803@P<
00<03PT=00`73P0=20h00P0>2@l05P0=20`030L;010;3`0=2@X030P900L310050@804@d?00`72`1H
DeL03PT=018=4@0910P02@D800L21P0300804`hB00h93@0400<030L:00/7200<20T200d92P0800`7
2`0>2@d02PD900T42P0?2Q002PD;00L22@0910X200`73@0300/6300C3Q@04`hD008030L=00X04PdC
010;4@0;1P`040dB00h?4@0420T07B4R02lc=00K7b004A8D0P0<3@l02P0<30h02PX<00X:300<2Pd0
1`88014<4P0<1`d03@P>00/6300>2@l200`73@0:00l:400=20h02`H<00h93`0C3Q803@P<00T42006
0@D071LK00T420803@P<0P0>2@d200l:3P0800/7200@30d02PH701@@4@0<20T020@500`82@0=2@X2
00h:2`803`/<0`0>1@H03`0<1PH030H700`6200C3a0030T;00/9300?3A001P@701<A500=2`h02`T<
00T72P0:20/03@/>010>4@0600/9300800`:2`091`P03@/<00d;300;2@X03@/<01PF5`0610D200T7
200400P61`0>30d03P`=00h<3@803@/<00h030X;00/92P0@3Pl03P`=00P61`0;2@X03`d>00d;3009
1`X030X=01<A500E4aH0:bT/00<110H030X=00<03@/>00`:3@0;2@`00P0<2Pd0300E4aH05Q@G00h<
3`0:20/030X=00h<3`0@30h040X<00l:3P0>2@d03`X>00d;40803`dB00D03@`B00T83P0:2@l040lE
018@5P0200h<4@0@00d;400<2Pl030X?014?500E4aP0518G01<A5P0A3a@040hC01DB600d<CP0:RL^
00H32P0D4AP03``C00`940803``C01h03P/B014>5@0A3QD03PdC00/:400>3A<04A0F00l>500B4AL0
40lE014@5P0@3aD04a8H01HE6`0@3aD03@`A010?501fMGX0T8nD00d<4@0?3Q<04Q4F00l>4`0>3A80
4a8G01DD6@0B4AH04a<E018B500C4aD201DE5`0E01<C5@0F5QP05QHH01@D5P0C4aD04A4C010@4P0D
4aP0?Se202HU:P0^;C805A@I00T83@0<2a004Q4F01DD6@0A41D03`hC01HE6P0E4aP0518G00804a4F
0P0B41D00`0H5Q/03P`A01XH7@0201LE6P0;01PF6`0;2Q006APM00P7300g=S/04@lC01LE600B41<0
4a0B01DA4P0F4Q<00P0H4Q@0200B3Pl0510A01XF5`0G4a@04Ph?01@@4@0E4A80510A0P0F4Q<01@0<
20T0510A01DA4P0I5AH05A4B00804`l@0P0@30d0200;1`P03@T:018>3`0@30d030P900d72`0<1PX0
4`dA0P0D3Q805`0<1PX03PP<014;3`0S7B407aTM00l93@0C2a0050/@01<:3`0B2@h04@P=0107300A
20d04PT>01<:3`0A20d03`H;0107300>1`/03PP<00L11@0D3A402@05008040H>00<04`P@01873@0A
1@`00P0@0`X05P0C10/06@P@01X;4P0E1`h040D;01873@0B31002`H:00@21@0=30h010@603<d=P0;
1PX04`P>01052`0I3Q@06PlE00l42P0D2@l06PlE01@93`0?10X201P=4`0901<83P0A1P`03P<900d2
200?10X04PL=00T0100E2Q0040D;00803`@:00L03P<901H9400=00L050L>01hA600:00@06@dC0080
3`89100B1@`201421`0F00l31`0>0`/03@<<00/4300<1Q804@dJ028P;P24Pi<0BTYK01hM;@19@e40
7ADQ00T1300?1A003@<=00`02P0=0@/03`8<00l22`0>0@X03`8;010331Cooooo000Kooooo`0=00T@
7@0>5R806R4]01TN:P0>4Q/03Q0H00l?5P0?3Q804`hB01H@4`0F3Q0040X:018>3`0200l=3P803P`=
1`0=2``0900?2@/03PX;00l;300?2``030X;00/92P0@3Pl02PX:00h>3P0?3`l0ADE505ECE00A3100
30L=00d;400F51`0L71j07=cO@0@41X04Q4I010?5@0@2a404@/?014<4P0B3QD03P`C018?5P0:1`d0
40dC00`:3`0<2Pd03@/<00h<3@0A3a004Q4?00l=3P804Q0C00H02@P:00d;3P0=2`h02@L:00/9300=
2`h200h<3`0500`:3@0=2P`03PX;00h:2`0?2``00P0>2P/0100?2``04@d>014=3P0B3Pl2014=3P0B
03hl?@0Z:RX02`/;00`<300@41005aDF00/92P0>30d03@T:018>3`0@30d030H8018>3P0>3@/02PT7
01HE4`13@T0061LE1P0<2`T00`0>3@/03@`:00d<2P0200h=2`0700d<2P0?3P`03`h<00d<2P0<2`T0
3@`:00X91`0700d<2P0700L6100=30X030/901dL6P0;2PP02PP900`:2`0200l=3P0401<A4P0I5aP0
2PP900d;30803P`=00@03@/<00`:2`0;2@X03@/<0`0>30d0200=2``03P`=00h<3@0B414040h?00h<
3@0;2@X04@lB0P0@3Q4200`:3@0301LE600C4A@04@lB00803P`?01@03`d@00l>3@0F4@/05a@801PF
1P0`;Q`0J6YC038d700H6PP04aD702X[8@0I6QD020P:00`;3`0<30h02PX<00/<3P0?3a4030`>00T9
2`803@/>0P0<2Pd300/9300<02DS9P0920X030X=00H41`0B41<03P`?00l=400B41<02`T<01PF6@0/
:Rd04@lB0P0=2`h05`0?3A003@/>00X82`0;2@`0518E00`:3@0>30l04Q0C00d;3`0<2Pl03@/@00`:
3`0@3Q<03`dB00/93P0=2a003P`A00l=4P0A3a@040hC00d;400<2Pl03@/@00803P`A0P0<2Pl500/9
3P0600d;400<2Pl02`T>00h<4@0;2@h030X?0P0=2a001P0?3A803P`A00/93P0=2a0030X?00/93P80
2PP=00H030X?010>4`0=2a003@/@00`:3`0;2@h200`:3`0B00h<4@0E4aP04Q0E00l=4P0F51T03@/@
010>4`091``030X?00l=4P0<2Pl061HK06ARI`0V92T03@/@00T7300G5AX0<c4f100>31403`0=2a00
30X?00/94@0;21404PlH00l<4`0;20l05A8I00h<4@0=2`l030X=00T72P0H5QT05Q@G00X82`0200`:
3@0?00d;3P0?3A003P`?00P62@0?3A002`T<00T72P0=2`h02`T<00l:3P0@2`l030L;018=4@0@2`l0
2PD9008040/?00<07APL01`G6`0?2Ph00P0B3A404P0:1PT04@`@00h:3@0;1PX03@P<014<400=20`0
3`X>01@?4`0<1`/04PdA00T7300<2Pl02`T>00d;400;2@h030X?00h<4@<030X?00`02`T>00T7300=
20`03PT=018=4@0?2Ph03PT=01<>4P0<1`/040/?00/62P0?2Ph200h93@0P00h9400=20h03@P>00h9
3`0@2`l050lC010;3`0g<c@05A4B00@00@0C3a002@D701dH70060@D03@P<01<>4P0]:2`04PdA00D1
100C3Q806aHJ00h:3@0@2`l030P:00l;300F4Q<030P9010<3@0F4AD02`H:00`72`0;1P`200h93`0W
00`73P0>2A003PT?014<4P0>2@l03@P>014<4P0;1P`04`hD00T42P0C3Q@04@`B00`93P0?41805QXK
05eQHP3Ri^H0^ko003/l?P0B4aD0414C00d=3`0:2P`02`X<00d;3P0>2@l040/A024L8P0910X05Q4G
00T52P0;1P`03@P>00h93`0<1`d02`H<00d83P0=20`02`H:00803@P<00P02PD900h93@0;1PX030L;
00d8300?2Ph02`H:00h93@H03PX;00L03`/<00h:2`0?2``030P901<?400X92@03`L6008040P60100
3PP800l92P0?2@/02PL700l<3P0;2P`04Q0E00h<4@0920`03`d@00h<3`0<2Pd03@/>00l=400@3Q40
4@lB0P0;2@`01@081PT03P`?00P62@0=2``03`d>00803P`=00T030X;01XH6@0X9RL02PT900P61`0<
2P/02PP9010>3`0?3@h00P0<2P/0100=2``030X;00X82@0<2P/200d;30803P`=01<03`d>018@4`09
1`X040hA00T72P0G5AP02@L:00d;3P0E4aH07Q`O00l=400C4A@02`T<00l=40081PT04Q0C02`Z;@1:
B4/03`d@008040hA01@03@/>00X82`0;2@`040`?01@>4P0A31003@P=018=4`0A3a@03`dC00D32@0<
2a409bH]01PG7`0=31@03`hD00h<4@0<2Pl03P`A00l=4P803@/@0P0;2@h02@0C4AH03@/@00/93P0C
4AL0AT=:03@a>00<2Q005A8I00d:4@0200l<4`0700h;4P0?31<03``C014>5@0Z:Bl0AdI<01<B6002
00d<4P0=010?5@0A41H03@`B00h=4`0?3Q@02`X@00h=4`0E51T02`X?01/J7`0T8bP04A0E00h=4P04
018A5P07014@5@0@3a@04A4C01@D5P0?3a405aLI01@D5P0200l?4@0>014A4`0;2`d05QHH014A4`0@
41805A@I02<R9`0D4aP04A0E01lN8`0F5AX04A0E01DD6@0G5Q/201<B5`0800h=4P0E4aP061HK00P6
2`0D4QL040hC01LE6P0d<SL201DC600301LE6P0@3Q<06ALL00804a8H00/061LL01dL8@0J61`04@lB
01HD5`0C41805a<D01@@4@0I4aD04Pd>01@@4@0301DA4P0601@@4@0C3a005A4B01LC500B3Pl040`=
0P0C3a001P0B3Pl05a<D00X61`0B3Pl05Q8C00l;30804`l@0P0B3Pl2014=3P0600l93@0@2Ph04@/?
014;3`0?2@d03PP<0P0A2`l02P0C3A405@lC00l93@0B31003`T=01@>4P0?2@d03PP<01D?4`0@2Ph2
00l93@0:010:3P0K5AT040X>01<<4P0>1`h02`@:01<;400I41D050/@014730804`P>01@050P>01@7
3P0D1a0050D=01X:4@0P4AP06PdD0146300B20d050dA00H11@0C3a<0?3/n0:f][`1VIfT05A0D01D:
400@1P/0714G00/21PL04PL=1P0A1P`201873@040146300?10X03`@:00l42P804PD<00@03`8900h1
200>0@P030460P0?0PT20185300J01442`0?0PT04@8701421`0?0`P03P<:00h3300;10`02@<=00T5
4P1>C5X0a<;>06=SL`020@l03`TF00d54@0E3aP06A4L00/4300=1Pd050/D00d42`0>0`/03@8901<6
3`0B1@dDooooo`006oooool03P031a802Q0J00`@6@0<41T03a4H00h?500?3Q@03`hB00d;3P0=2@X0
3PT9014;2`0B3Pl040h?0`0?3@h00`0>30d030X;00`:2`0400`:2`0400l92`0?2``03`/<00l;3080
30X;00<02PP901<C4`0C4a<00P0@41005P0?3@h03@P901LB5P091``01`H<030`>00N7RH03PhF010?
5`0>3A<03`X?00l93@0?2Ph020@>00402@091Pl02PL?00h;4P0=2a003`d@00l=3P0@3Pl2014@3P07
01@B4`0h=ST0@T1301TG6P0B41<07A/N01@B5@0300`:3@0:00d;3P0>30l040d?010<3@0?2``03PX;
00l;300@30d04@d>010<3@<04@d>018040`=02DS900J6QX04A4A00P8200000004a4B01LE5P0E4a@0
3`/<018>3`091@H0100000`8200?3P`06QTG01LF50071P@=00d<2P06018A3`0<2`T030/900`;2@0;
2PP06QTG0`0A40h200l>300D00h=2`0@3`d01@@200h=2`0?3P`03Pd;00/:20081PL03@/<01DC500D
4Q<030X;00H41@091`P020H700X82@0>30d03`d>00/92P0>30d300l=3P0@00h<3@0=2``00@0000l=
3P091`P05A<D00h<3@0:20T03P`?00l=400A3a803`d@00h<3`0F51L04a4D014?4P803P`?01P03`d@
00l>30050@005aD2038b6P2MWH<0mOOI0<O:Z`1:CC4051L201<F1@0<3PD0410>01HF5P0<30h030X=
00d;3P0?3A003@/>00/9300:20/02`T<00`:3@0=2`h200h<3`0L010>4@050`H04Q0C018@4`0C4A@0
1085018@4`0@3Q404@lB00/9300F51L09R@W00h<3@0<2P/03@/<00l=3P0>30d030X;00/92P0C4A80
2PP900h<3@0100001P@6010>4@0F51L03@/>00T72P803@/>00H02@L:00d;3P0B41<01`D800D31P0=
2`l200X83@0401<A5P0F51T03`dB00X83@8030X?0`0;2@h0:P0<2Pl02`T>00`:3`0@3Q<030X?00/9
3P0<2Pl02`T>00X83@0<2Pl03@/@00X83@0<2Pl02`T>00X83@0;2@h030X?00l=4P2ASi@0CD]@00/9
3P081P/01@<800`:3`0;2@h04@lD018@5@0D4QL06QPM01<A5P0U8bP04a4F00P62`0>31403`dB018@
5@0I5a`00`4601@B5`0=2a001P@900l=4P8030X?0P0=2a00300<2Pl02`T>00/84@0A3QL00P080040
1@050`T030T@00h<4@0<2Ph03@/>00X82`806QPK0P0@3Q405`0=2`h02PP;00/9300A3a802`T<00X8
2`071@P02@L:00l=400<2Pd05a8F00l:3P0300803@P<01HA5@0E41@02PD900`72`0G4QH05A0D00X5
2@0;1PX04PdA008030L;01003PT=059=D@070PH03@P<00/62P0D3a<07aXN00h93@0<1`/02@L<00h<
4@0@3Q<01@<8010>4`091``030X?0`0=2a001`0<2Pl02`T>00/62P0>2@d04PdA00l:3P0;1PX00P0>
2@d01`0E41@01P4500`72`0B3A402PD900d83`0>2@l00P0?2Q003P0>2@d05a8F00X52@0?2``00`00
00`82@0@30d06A@G02TT:00=20`030L;00H11@0J5AT03`X>0P0@2`l02@0C3Q802PD900/62P0D3a80
2PH700l;300<20T02@D600h93@0200`72`0S00/6300<1`d03PT?00d83`0910/0100500L2200<1`d0
3@P>00`73@0:1@/04PdC00X52`0?2Q003PT?00h;400<30h04a@F09fNX03`lO<0hnCV02`/;P0@4180
3`d@00`:3@0:20/030L;00d8300=20h020<9014<4P0910X06A@J00P32@0<1`d00P0=20h03`0:1@/0
2@@:00/6300D3a<03@P<00`72`0A31003`X>00/62P060@D020<702HQ9@0C3Q802`H:00`72`0600h:
2`0I00l;300=2@X03@T:00d92P0B3Pl071PG018:200B2PL040P500h91P0=1`H030H801hJ6`060`L0
0@0401DB6@081P`06QPM00T72P0;2@`03@/>00l=400D4QD05Q@G00@21@0200L5200400H41`0:20/0
3@/>00d;30801`D60P0?3@h0200J61T0<c4b00D310091`P03`d>00L51P0@3Pl030X;0P0:20T0100<
2P/02PP900T7200>30d300d;308030X;01801@<600`:3@030@@05A<F00800`0;2@`030X=01DC5P0M
6ah04Q0C00l=40091`X020H9018@4`0G5AP0SH^>0<K4a`0U8bH200h<3`0@00`:3@0;2@`03@/>00l;
400A2Q4040/A00d83P0@2a403``C00/83`0M6R406QTQ0860R01OGVH0000900X83`803`dB00l03P`A
00`:3`0<2Pl03`dB00/93P0?3A801P@901XH7@0g=CX0:2D[010=50050PT0514H00h;4P071@/00P0@
3A@05P0?31<040dD010=500B3aH0=SDk06UXKP0=31802`X@00H52`0?3Q@03@`B00/:400>3A<04A0F
00l>500A41H04a8G00P7300F5AX09B@Y01LF6`0<2a02010?50<04Q4F02d04A0E00h?4@0A4Q@03a0B
02//;P0a<S@051DG00d>400D5AL05AHH01@E5`0?41803PlA00L830061`/07AhR01XK7`14ADT06AXN
00@52@0C51P02P/?014B5P0?41@06QTN00d;400;2@h0928W01TG700H5Q/04Q0E01HD6@0?3A804Q0E
01@B5`0E4aP061HK018A5`0E51T051<H014@5@0C4QH06ALJ01<A500F4aD00P0@30d00`0H4Q@01P02
014=3P03018>3`04014=3P0@30d04Ph?01HB4`804Ph?00L04`l@014=3P0?2``04`l@00h:2`0C3a00
5A4B00804Ph?0P0A3@h2010<3@0300l;300?2@d040X>008040X>0P0?2@d0600A2`l03`T=01D?4`0A
2`l03@L;00/52@0L5QX0100201<=4@0O6Ad01002018<400:10P05a4E00L21@0500<01P0401/D6P0F
3aH04@XA00l7300?1PT03PD8010620804PL;01L04`L=01<63`0C1Q004PD=01<63@0D1`h04PD<00l4
2P0>1@X04PX?00H11@080`L0C4Y=0>7OhP29QhX02@@700h32@0?1@X04@H<00L00P0B1`d040D;0146
300201873@0301052`0>0`T040D;00L040D;0P0?10X200h32@0800l22@0>0@P03P4800h1200?0PT0
40<:00l22@0@0`X201442`8040<:0P0?0`L05P0?0PT03P<900h3300;10`01P0900d74`0>2QP0:RHd
00d<60081180100700l73`0=1Ph00`05010;4P0;1P`0<2/a00d4300<0@L0200200`01@0H2@hDoooo
o`006oooool0300:3A@051LN00hA600<3a@04A8F00X;3`0@3a@04a8E014?4P0=2``03PX:018>3@80
40h?100?3@h600`:2`0400l92`0?2``040`=010<3@8030X;01T03`d>01@D500:2PX03@d=00X:2P0A
3a0050lA00h:2`0>30l020L<01/L8@051P/030`C00h=4`0=31403PT<00l92`0?2Ph08A`W014>6@0<
2A@02`PB01DB6@081@`03`dA00803`d>0P0?3P`01@0;2@X05aDH01TG6P0510H020H900802`T<00X0
4Q0C010>4@0?3A003`d@010>4@0B3a404@d>00l;300>2P/03`/<0P0A3@h05`0@30d04@d>014=3P0A
3@h040`=00X82@010@403`l?010@400410@03P`=00`:2`0C4A804`l@00d92P0@30d04@/=014=3@0>
3@/07ahL03<b<00B4@l040l=00H02`X800<030/900d<2P0>3@/00P0<2`T01`0>3@/03`h<00P71@0>
3@/04Q4?010?3@0V9B<00P0B4@l0300A40h03`h<00h=2`0>3@/02`X800X91`0?3P`03@`:00`;2@0>
3@/02`T:00`:2`803P`=0P0=2``01P0@3Pl02`T:00`:2`0B41404a4B00`:2`803P`=00X03`d>00h<
3@0>30d030X;01<A4P0Q7b000`42014?400>30d03`d>0P0<2Pd05P0@3Q403`d@00`:3@0C4A@03@/>
00`:3@0:20/02`T<00d;3P0?3P`061@9030^6`1IFD40aLFY0?cnh03>d[40?d8U018F000A50<03@h6
00h>3P0?3a4200d;3P803P`?00D03@/>00`:3@0;2@`02`T<00`:3@0300d;3P0<00T72P040PD0518E
00X82`0=2`h02PP;01<A500A3a8040hA00P62@091`X04Q0C0P0<2P/05P0=2``03P`=00h<3@0>30d0
6QPI0040000>30d04a4B01DC500B41804Q0C01HD5`0>30l02PP;00d;3P0@3Q4020H900L5200<2Pd0
108500h<3`0G5AT200`:3`04010>4`0B41D03@/@00/93P<030X?0`0;2@h01@0:20d030X?010>4`0<
2Pl02PP=00803P`A00D030X?010>4`0B41D03@/@00`:3`0300/93P0M00`:3`0>3140O7Yo03dk@007
1@X05A<H018@5@0:20d040hC018@5@0?3A803@/@014?500=2a00;bdb01hL8@0?3A8040hC00h<4@0<
2Pl02@L<00P62`0Y9b`09bDZ01HD6@0=2a002`T>00`:3`0=2a000P0<2Pl0800;2@h01`@=028O:00_
;3D09B8Y014>5@0200H05A<H00l=4@0>30l01P@700X82`0610L040hA00`:3@0;2@`02PP;00T72P0<
2Pd03P`?00/9300:20/03@/>00l=400:20/02PD9018=4@0<1`/050lC018=4@0910P04PdA0P0>2@d0
:@0<1`/02`H:01<>4P0A31003`/>01@?4`0M6A`0]K2d02hY;@0=20`02PD9014<400K5QX030L;00d8
300=2a004@lD00T7300G5AX0<S0e00L52P0=2a003`dB00h<4@0=2a002`T>00`:3`0<1`/03@P<010;
3`0=20`02`H:00l:3P0D3a<00`0201LB5P0R7B404`hB00<00P0=20l03`X@008040/A01/03PT=00/6
2P03008040`=01@@4@0L61T02`L801PD5P0U82@03PT=00d8300300803`X>01@?4`0E41@00`0200T4
200?2Ph00`0200T61`060P<02PH700d92P091@H03PT=00l:3P0=20`00P0;1P`02P0=20h03PT@00h9
3`0>2@l04@`B00l:400<1`d03`X@010;4@0?2Q0200/6300;00T42P0>2Q0061PJ02<T9P2JVid0V9RJ
07AdMP0L6ah03`d@00h<3`0<2@`00P0;1PX03`0<1`/03@P>00L2200<1`d020<901D@5P0910X02`H<
00`73@0>2@l03@P>00h93`0A31806QDI018=4@0200h93@8030L;00H02`H:00P31`0]:2`05Q4E00l:
3P0;1PX600h:2`0C00L3100=2@X04`l@01<?400810D00`0001491`0A2@H040P500h91P0=20H03@L7
00/62P0B3a<04Q0E00401@0D4AP01@8900`:3`0200d;3P0300h<3`0@3Q4040hA008040hA01P03@/>
00l=40091`X03@/>018@4@081PL01`D600`:2`050`@030X;00@20`0E4a@04Q0A00`:2`091`P020H7
00`:2`0:20T02`T:00d;300;2@X02PP900l=3P0>30d200d;300800`:2`0;2@X04@lB00/9300200<0
5aDH00<1100<2Pd200X82`0:00d;3P091`X030X=00l=400H5QT02@L:00X82`0Q7b80:BLZ00H51`<0
3@/>00D030X=00h<3`0?2a0040T@00l:400200h93`803P/B01P01@8900`;4`0Z:C408b8Z018@6`0<
2Q403`dB014?500>31402PP=00`:3`0?3A801`D:01PF6`0?3A8020H;01HD6@0;20h04PlF01LD6`0A
3QD04a0G01DB6@0>2a8300d:4@0D00h;4P0@3A@06aXP00P73@0A41H04a8H00l>500E51X03`hD00d<
4P0@3aD04A0F00d<4P0<2a4040lD00/:3`0J6Ah09RDZ01XI7P0>3A8200l>4`09014@5@0B4AH04Q4F
018A5P0=3Q0051DG00l@4P0V9bT0;Rla008051DG00X030d?01`M7`0>3a40414C01@E5`0C51P05QLK
04]<D00S92P0QXN;0P0E5QX07@0?41@04Q<G02@U:@0H6Ad0Bda@02PV:`0>31405A<H01LE6P0A3a@0
3`dB018@5@0F51T04a4F018@5@0G5AX05Q@I00d<4P0C4QP05QDJ01DD6@0B4AD04Q0C01/I700?30h0
5a<D01`H6@0N61X050h@00804@d>0P0B3Pl0100A3@h040`=018>3`0F4Q<201@@4@0401DA4P0A3@h0
4Ph?00l;30803@T:00<04@d>01HB4`0A3@h00`0@30d200l;30D040X>02803`T=01D?4`0>20`05Q0D
01LA5@0C3A403PP<01<=4@0G4AD04@/?00l93@0C3A404@/?01<=4@0400805@lC020J7P0A2`l03@H>
018;4`0A2Q4040P=00l62@0A20T04PP90147200A1PX04PH<01853P0B1@l05@PA01@93`0C1Pd04@H<
0P0A20d02`0D31404P`@01D@500J5AT0BdU<02lZ;P0>1``04@H<01873@0L4AL07A8H008040D;00D0
4@H<01873@0B1`d040D;00d2200600l42P0300h32@0?10X03`@:00803`@:00L03P<900d01`0;00D0
3@4700h1200=00L04PD<00H040<:0P0?0`L00`0?0PT03P<900h32P0200d3300A00d5400400L0208<
00L130090`d08QPQ00H01P0=1Ph05a8I00/7300910X02PD;01D@500D2`h05P/A00/00P0:00005?oo
ool001_ooooo00`02`/;01@D500@41003@h?00l?3`092@X03@d>018B4P0C4a<0410@00d<300<2P/2
00h<3@@03`d>1P0=2``0100@2P`040`=010<3@0@30d200d;300:00P61`0E5AD0410@00h>3P0<30`0
40h>014<2`0I5QD0=C<e010>4@<02``@01X03@d@00d=3P0>2P/03`X8010<3@1IE600E51N00H33`0A
3QT03P/C00d:4@0>31003@/=00d;300=30X030/900h<300:20/020H900h<3`0=2`h02`T<014?4P0D
4QD04@lB00h<3`8030X=00D03``>014=3P0?2``03PX;00l;3002014=3P0700l;300@30d04@d>010<
3@0?2``03@/<00/;2`0300d=3@0=00h<3@0@3Pl0;bd^02l[;00@30d04`l@01@>400C3`l040l=00T8
1P0D4a401@@300h=2`0600`;2@0;00/:200>3@/040l=00`;2@0;2PP03Pd;010?3@0;2PP03`h<00h=
2`061@<00`0@3`d00`0?3P`03Pd;00d<2P0200`;2@0501`K6@0B4@l02@P600`;2@0=30X00P0=2``0
1`0<2P/03P`=00h<3@0=2``05A<D00l=3P0=2``00P0@3Pl00`0:20T02`T:00`:2`0300d;300900`:
2`0P7Ql0:2HW00X82@0B41403@/<00`:2`0=2`h02`T<00803@/>01D02`T<00l=400=2`h03@/>00h<
3`0@3Q40518E01LF500R7AH081d?03Lf8@1BDST0YZR905eQ@@0Q90X041<001<E2@0>3``03PdD00/9
400>2Pl00P0A31001@0@2`l03@/>00d;3P0>30l03@/>008030X=0P0;2@`03@0@3Q403P`?00`:3@0=
30h01`D800d;3P091`X03@/>010>4@0>30l030X=00d;3P0;2@X00`0=2``03P0>30d03`d>05]IFP0?
3@h06QPI00D4100L6Q/04@lA010>4@0?3A003P`?014?4P0?3A003@/>0P0:20/02P0?3A002@L:014?
4P0H5QX040hC00l=4P0;2@h02@L<00X83@0=2a0200h<4@0300d;400<2Pl02`T>00803@/@00D03P`A
01<A5P0>31403@/@010>4`0200h<4@03010>4`0A3a@03P`A00D030X?01/03@/@00h<4@0@3Q<03P`A
00`:3`0=2a0030X?01@B5`0B41D02`T>00T7300<2Pl03P`A010>4`0>314030X?00d;400<2Pl03@/@
014?500<2Pl02`T>00X83@091``03@/@00/93P0<2Pl00`0>31407`0=2a003@XC018?600S82T07Q/R
00`9400C41L03P`A00/93@0C4A@03P`?00l=400;2@`03`d@00L5200<2Pd040hA00`:3@0>30l03@/>
00X82`0=2`h03P`?00/930071@P03@P<010;3`0400<04`lB01`H6`0B3A400P0>2@d02`0=20`02`H:
00X52@0>2@d02PD9018>4@0;1`X04PhA018=4@0D3a<040/?00802`H:00@03PT=00T4200B3A402@L<
0P0@3Q<05`0F51T0;B/`01DC600;2@h030X?00X83@081P/02`T>00l=4P0>2@d03@P<00l:3P0<1`/0
2`H:010;3`0>2@d02@D800d9300W8RH0:2<W01@?4`0>2A003`X@008040/A01D03@P<010;3`0<1`/0
40`=00l;300F4Q<02PH7014<3`0<1`/01P4500h93@0<1`/040/?024L800[9RX02PD900/72P0F4AD0
20@701<?4@0;1`P00P0=2@X0200;1`P03`X>00h93@0>2@d030L=00d83P0?2Q003PT@0P0>2@l04@0A
318040`A00d93P0@2a404`hD00/6300B3A<030L=00L2200=2@l03`hA00P72P0N7Al040hA01HD5`0C
3a<03`X>00803PT=00L03PP<00d72`0=1`/030L=00h93`0@2a402@@:00<030L=0P0=20h200`73@04
014<4P0D3a<040/?00d830802@@800L05Q4E01TD60080`L04`hB00@00`0<1`/03`X>00H03PX;01D0
3@T:00/7200810D02`L8014=3P0A3@`03`L400l80`0@20D03PT6010:2@0@2PX040/?014=4P29Qh`0
<2hd010>5@0:1`h030X?00`:3@0=2`h00P0<2Pd0100;2@`01@@601`K7@091`X200`:3@0E010>4@0=
2``02@L800`:2`0D4Q<02PP900h<3@0E4a@03@/<00`:2`0=2``02PP900/92P0=2``02`T:00`:2`0?
3@h03P`=00d;300?3@h03P`=00803@/<0P0<2P/02`15@dH04a4D00P62@0920X04a4D010>4@0?3A00
3@/>00h<3`0=2`h01P@700<03P`?00D040hA00X82`0<2Pd040hA00`:3@0200d;3P0P00`:3@0?3A00
3`/@00l83`0A31804@`C00h9400>2a804a0H01XG800=31@03`hG014?6P0>3AL05aDM010>4`0A3a@0
3`dB00`:3`0=2a00928W01<A5P081`/04@lD010>4`0E4aP03@X@00d:4@0A3QD02PL>00h;4P0A3QD2
00l<4`0<00h;4P0?31<03``C014>5@0:2@l04Q4G00X93`0L6b403PdC00l>500@3aD03@`B0P0?3Q@0
200<2a403PdC010?500>3A8040lD00l>4`0=31404a8G0P0@3a@4018A5P03010A4`0H6A/0414C00<0
4Q<E02/03a0B03/l?P0S92H06Q/M01DF600?41804A8F01@E6@0@4AD03a0D01PI7@0?41@03@hB014B
5P0=3Q806Q/O01DF6P0e=SX05aDJ01DC600U8bP0DDmD02h/<@0G5AX0518G01LE6P0A3a@040hC01HD
6@0H5Q/051<I014@5P0@3a@04Q4F01<A5@0A3a806ALJ018?4@0N6Q/04`l@01D?4@0I4aD04`l@00<0
510A0P0C3a003@0@30d04Ph?014=3P0D41405A4B010<3@0C3a005A4B01lK700D41402PH7010<3@0B
3Pl00P0A3@h2010<3@0300l;300A2`l040X>008040X>0P0A2`l05`0E3a<02P@8014;3`0K5AT06A<G
00h830060@D05Q4E01HB5@0:1@T05A0D00h:3@1=B4`040/?01LB5P0B3A402PD900l9400@2A404``C
01@<4@0A20/04@P900804PP901P04PL;01<73@0C1Pl04`DA01D94P0B2`l04@L<01483@0B2@h04@X>
010:3P0>20`03`T=00d72`0C3A4040P=00h52P0A1P`04@L<00/21P0J3aD040H;0146300@1@/30146
30L040D;00<03P<900l42P0A1P`00P0A1P`00`0@1@/04PD<00l22@020185300300h2200G2Q404@@;
00@040<:00<04@@;00l22@0?0PT00P0?0PT00`0?0`T03P<:00`2200200l4300?00`12@0G2a<03`@<
00d52`0?20h04@/@028M8P1SHF@020L907UgN@2KV9P04@P900d41P0A10H04@8501Cooooo000Koooo
o`0=00l;200>2`P040l;00l>300@3``05QDC00`<2P0<30/03@d=00d?3P0<3Pd02PX:00/92P0200`:
2`0300d;300>30d03P`=00H03P`=00L04@/=010<3@0A3@h04@d>00h<3@0=2``05Q@E00802`/;0240
0@4100d=3@071P@02@D201TE4P0a<2h02`X;00T:300H6A/02``>00h>400=3@d03`/9010;200A3@h0
4PdJ00d95`0?2aT01P<>00l<5@060`X030X>00d;3P0=2``03@`:00d<200>30`04@lB01<A500?3A00
30X=00h<3`0@3Q400P0?3A001@0>30l030X=00/9300=2P`03`/<00<03PX;100?2``05@0@30d03`/<
00l;300>30d04Q8B00`<300C4a<071`L00h<3@030P805Q@E01PD5@0@30d04Ph?01<=3`0>2PX01@@2
014@3P0B4@l03@`:00l>300600d<2P0<00X91`0>3@/040l=00/:200:2@L03Pd;00/:200<2`T03`h<
00h=2`0=30X030/90`0>3@/300d<2P0>01@C4@0P7ad04a8@010?3@0;2PP04A0>00l=3P0>30d03`d>
014?400>30d01`D600l=3P0=2``200X82@802`T:00@02@L800/92P0=2``03P`=0P0?3@h00`040P<0
2@L800`:2`0200l=3P0300h<3@0D4QD03@/>00803@/>00<02`T<00l=400<2Pd00P0<2Pd0400=2`h0
40hA01<A4P0C3PX05Q<9030_7@1jNF@0DU@j03`o900D5@804A<601PI4`0E5AP04a4N00X74P0>2@h2
014<40803PT=00<040/?00`:3@0<2Pd00P0<2Pd200/;3@0700X82`091`X020H900d;3P0J61/04@lB
010>4@0300l=400C00/930071@P02`T:00h<3@0=2``02`T:00`:2`0>30d05aDF00<10P0B41401P@5
00X82@081PP030X=00X82`0<2Pd04a4D00l=400200L5200600X82`0<2Pd02PP;00L5200:20`03@/@
0P0<2Pl200d;400700h<4@0?3A803P`A00d;400<2Pl02`T>00`:3`0200T7300500`:3`091``02@L<
00/93P0<2Pl00P0=2a001@0;2@h030X?00`:3`0<2Pl03@/@00<030X?00X01@<800/93P0?3A805A<H
01TG70091``040hC00h<4@0=2a003P`A0P0?3A80100>314040hC00l=4P0=2a0200`:3`04010>4`0B
41D02@L<00h<4@8040hC00<030X?00d;400?3A800`0?3A805@0T8BX05Q<L00l<5@0;20l01`@;00h;
4P0@3Q<020H:010>4@091`X02PP;00/9300B41<02`T<00`:3@081PT01P@701LE600=2`h02@L:00`:
3@0200/9300801@B5@0500@02`H:01dH701;ATX0@Se100D0100?2Ph201@?4`03018=4@0?2Ph030L;
00804@`@02<02`H:00T4200@2`l03`X>010;3`0<1`/03`X>01D@500;1PX04@`@00/93P0>314040hC
00@31`0100@01`D:00d;400>31403@/@00l=4P0J61d08AlT00d8300@2`l050lC00l:3P0:1@T03@P<
00`72`0I51P00`0200P41`0G4QH03`X>010;4P0200h93`0?00d83P0=20`03PT=00<00P0E4A80=S8c
03hj>`0G4a@020@600`72`0@2`l03PT=014<400:1@T01@4400803PT=01804PdA01<>4P0=20`04`hA
00X61`0<20T020@5014=3P0F4AD030L;00d8300=20h03`X@010;4@0>2A003`XA018=4`0H4aT202hY
;`0701PC6@0>2Pl03PT?024L8P0F4AL03PT?018=4`02014<400401LB5P0>2@d05a8F00X420803`T=
0P0A20d20107300=00`5300?2Q0040/A00h93`0910X03PT?00d83P0>2@l030L=00X52`0;1P`03`X@
00l:3P0200/62P803@P<00L05A0D00/62P0:1@T04PdA01LB5P0?2Ph01`8600H03PX;00<01P8300h:
2`0=2@X00P0<20T03`050@0040P501090`0@20D03PT600h91`0>20P02`H:00X72`0d<SL00@0500`:
4P091Pd02PP=00`:3@0300d;3P0800/9300G5AP0Kfe`020N8@0100803`d@00@21@0A3a0200d;300<
010>3`0610D030X;00d;300@3Pl05A<D00X82@050`@04Q0A00`:2`0:20T02`T:0P0>30d200`:2`<0
3@/<0P0>30d01`0?3A0020H900d;3P0<2Pd0518E00T72P0<2Pd00P0;2@`07@0?3A000`4400l=400=
2`h05A<F00L6200D4QD07A/N00/9300=2`h03P`?00d;3P0<2Pd03P`?00l;400?20l04PdC01D@5P0>
2A003P/D00l<5@0P7BH05Q@O00H53`0200/0?Sa705]IH00@3Q<03P`A00803`dB00d03P`A01<A5P0B
41D03`dB00T730030@H03@/@01LE6`0:1`h01`@;01DB6@0H5A`05Q<J008040dD01H03``C010=500@
3A@04PlF00X93`0>3A<040lE05ACF@040`T06aXP01HE6`0B4AL040lE00l>500>3A<04Q4G00`;400?
3Q<051<H01DD6@0D4aP030/@0P0A41D2018A5P0Q014@5@0@3a@03a0B00dA4P0>4Q<06QhO01@H6@0I
7Ah0310A05aPH@0h?3d05a/L00`@4@0C5aP041@G00hB5@062Pd05ATL01TM800420/02`lB01PL7`0@
51L03a<F01DI700@4AD06QTN01<A5P0=2a008AlT01LE6P0:20d05Q@I00<04Q0E01004a4F01DC600D
4aT051<H014@5@0?3Q<04@lC01DC5P0:20/06aPJ00`82@0h=3D0DD]=020J700C3a00510A0P0E4A82
01<?400=01DA4P0D41404Ph?01TE5P0L61T05a<D014=3P0D4140:2@U01HB4`070`@04@d>01<?4002
018>3`804@d>00<040`=018<400@2Ph00P0@2Ph01@0A2`l04P`@018<400A2`l030H:00804`dA00d0
5A0D00<00P19A4P0GUUM014<400Z9BT030L;01XE6@0400<0K6M[09:=T@0U82@040XA00804@XB01d0
4PX?0189300@1`P04@P601882@0B1`/04`L=01<63`0C1A804@P@00l:3P0@2Ph03`T=00d72`0>20`0
4PX?01XA5P0C2Pl030<80107300F2a40714G00/01P0>1@T0?c@j06YOI@0E31004PL=014630020105
2`0301873@0E2Q0040D;00D040D;00`03P<900l42P0C20h050T?01<83P0A1P`03@0700X0100A10/0
4`H=01032P0O4QT201442`<03`8900@04@@;00h32`0>0`/03P<90`0?0PT04P0<00H0408701<42@0>
00@050D:01862P07008030D9020L7@0?2``0;2/[00d=2`13@d40KV]Z01/C4@09000040D501<51ACo
oooo000Kooooo`0>014=2P081P<02`X800/:200:2@L061LE010@3P0;2`/02PX:00`>3@0?4A003@d=
00X82@0;2@X200`:2`803@/<1P0?3@h2010<3@0O00l=3P0@3@h03P`=00d;300>30d01P@501@D500?
3@h06ALH00D3100>2PT03PX701`K6@0=30d02PX<00/<3P0=3@l03Ph>00l=3P0>30T040`9018>3`09
1`l06aPS01<@6@0A3QL00@0501DB6@0=2`l03@/<00h<3@0200l>300C00d;2`0B41<04@lB00T72P0B
41<04@lB00X82`0>30l03`d@014?4P0@3Q403`d@00h;3@0=2@X03PX;00l;300>2P/03@T:00h:2`02
00l;300E010<3@0?2``03`/<00X7200@410030`<00L71`0@41003`d>00h<3@0:20T02@D601<?400=
2@X01`<4018@3`020@003Pd<010?3@0>3@/020L500H02`X800D02PT700h=2`0@3`d02`X800T81P02
00h=2`05010?3@0=30X02`X800d<2P071P@00P0=30X400h=2`0F00/:200?3P`020L600l>30020@00
3`h<018@4@0?3@h02`T:00h<3@0@3Pl03P`=00`:2`0=2``02`T:00X82@0<2P/03`d>00T7200;2@X0
3P`=010>3`804@l@00<05A<D00d;300C4A800P0=2``00`0>30l061HI00l=4P0200d;3P0N00d;3@0@
3Pl040h?00l=3P0?2``040`=018>3`0C3a004Ph;01DB301PH5@0h^3C0;>dXP0a<R0051@600h?1`0D
518061LL01TG900=2aH030T>010>4@0?3A003@X<00h:2`0@30d030P900d92P0<2Pd03PX>0P0>30l0
3`0A3a8020H;00L5200E4aL0IF=X06e[KP0?3A402`T>00X82`0>31003`dB00`:3@0<2P`03P`=00d;
300200/92P0700h<3@0:20T04@l@00X82@0>30d01@<4010>400200/9300A00`:3@0A3a803`d@00T7
2P0<2Pd03@/>00`:3@0@3Q403P`?00`83@0<1`d02PD;018=4`0G4QP04`hD010;4@0A31800P0@2a40
1`0>2@l03@P>00h;400<2Pl02`T>00h<4@0;2@h00`0<2Pl00`0?3A803@/@00X83@0300`:3`803@/@
00D030X?00/93P081P/03P`A014?500200T73007018@5@0>314030X?00h<4@0@3Q<03P`A00X83@02
00d;400700/93P0=2a0040hC00h<4@030@H03@/@00X83@02010>4`0300/93P0=2a003P`A00@040hC
01h06QLN01DB6P081@`020D<00h;4P081@`0518G00T72`0>30l02@L:00d;3P0B41<02@L:00X82`0?
3A002PP;01<A500f=3L04@lB00`:3@0=2`h030X=014?4P0S7R8030L;01<>4P0300803@P<01XF6@0F
4AD2014<400@00/62P0910P030L;00h93@080`L03@P<01<>4P0A310040/?018=4@0?2Ph030L;01D@
500P6al03`X>00h93@803@/@00<01`D:01DC600A3a@00P091``02@0;2@h02PP=00l=4P0N7240:2H[
00/62P0C3Q806A@H01<>4P0200T4200:00/62P0@2`l03@P<00`72`0?2Ph03@P<014<4P0>2@l03@P>
00`73@803@P<01X01P4501/F6P0D41802PH700T4200@2`l030L;01<>4P0>2@d061<G010;3`0=20`0
50lC00d8300910P030L;00X52@0>2@d03@T:014<400>2@`081/O02PS9`0C3Q803@P<00d83P8040/A
01<03PT@00P32P0F4AL091lV01D@5P0300@02PD;01D@5P080`T081/Q01@?5@0:1@/030L<01TD6006
0@D03PT=01D@500>2@d04@/?00803`T=00/040X>01893P0A20d040L<00/42`0=20h03PT?014<4P0;
1P`03PT?00`73@0300d83P0300l:400F4AH04`hB008030L;01L04@`@00l:3P0=20`030L;010;3`0<
20/05A0D00l:3P0@30d03PX;00h:2P0>2PT03PX;00h:2P0>2PT01`<400h:2P0:1PD02@D600l;2`0>
2PT040/7014;1@0200h91@0900d81@0<1PH01`<401<@4P0@3Q40518G018@5@081P/03@/>00803`d@
01/03P`?00`:3@091`P020H901lM7P0<2P/05A<D00P61`0B41402PT700H50`071P@02`X800L6100A
3a002@L800l=3P0610D03@/<00l=3P0610D02PP900T7200:20T03@/<00`:2`0;2@X00P0<2P/05P0=
2``03P`=00h<3@0?3@h02@L:018@4`0<2Pd02PP;00/930091`X030X=00L520050`H040hA00d;3P0P
7R402@L:00/9300C4A@02PP;00<1100@3Q4200h<3`0<00`:3@0;2@`03@/>00h;3`0>2@l04`hD01HA
5`0>2A003``C01LD6`040@P01@@<0P0?3QH0500E51`04a4G00l=4P0=2a003`dB014?500?3A802PP=
014?500?3A8040hC01HD6@0>2a802PL>01@A600C41L03``C010=500:1`h03P/B0`0=2Q40500>2a80
40dD00h=4`0510X051<I00<2200V9b`03@hC01hN9P0H6Ah04Q8H00l>500=31804A0E01TH7@0C4QL0
20L<00X93P0A41D040lD0P0B4AH07@0B4QD04A0E010@4P0?3a805aPJ00`@4@0=41407b0R00lC5009
2`d03a0B00/=3`0P92D03PlA01DG6@062P/04A8F018E600<41<04Q<G00/>4@0G6ah051DI00X<400A
5AP03PlC010B5P0E5QX06APM00805A<H00D02`T>01LE6P0@3Q<071XO01@B5`0201LE6P0>010>4`0A
3a@02PT>01HE6P0J6Ah051<H00l=4@0A3a806ALJ00l<3P0G4a@05Q8C01TC5@0B30h201<?4080510A
00h04`l@018>3`0B3Pl040`=00l;300F4Q<06QHG01HB4`0B3Pl02`L801dI6P0=2@X020@501TE5P80
4`l@0P0B3Pl01`0A3@h04@`@01<=4@0@2Ph03`T=010:3P0B31000P0C3A40:P0J51P03@L;00d82`0@
2Ph03@P<00T4200/9b/0Pgj203Lb=P0300805a8F00h93@0O6Qh0J6=W07agN`0300804P`C01094@0=
1Pd03`L=01<:3@0D2``04`X;01892P0C20`04`P?01<8400C1a404@TA010;3`0B3A4040X>00h8300?
2@d03@D:00d42@0>1@X05`dB00T0100?10X04PL=01052`805``B00@0>Bhd00l42P0B1`d04@H<0P0?
10X00`0C20h05``B014630050146300700h32@0@1@/04`P>01D:400D2@l04PL=01P;4P0201853009
00h12008008040D:0185300A10/03`8900h1200?0PT04PD<00803P<;01H03P<900l22@0?0PT03`89
01<42@0?00D04P<601H7300G1`/0404601H;4@0?1PX0100000l;30091`L01@@201@B4`0=2@P05`h?
00T0000?1PH0BSi05?ooool001_ooooo00<030/=00h>3`0?3a000P0=3@h01@0>3Pl030`=00h>4007
1`T0410B00802PX<00<030X;00h<3@0?3@h00`0A3a00600D4Q<03@/<01DC500>30d02@L801<A4P0A
41<04Q4C00d=3`0;2Pd04@lB00`:3@0B41<03``?00l;3`0B3A404`hB018>400I5QH03Pd<00h<3@0@
3Pl03@/<00X92P@03`d>00X03`d=00l=3P0>30l03P`?02@R900B41800`43018@4P0:20T04a4B0P0=
2``020091`P04a4B00P61`0<2P/06ALH014?400>30d03@/<0P0A3a004`0:20T03P`=00l=3P0?30d0
4@d>010<3@0>2P/040`=014=3P0B3Pl0510A01LC500C3a003PX;014=3P0@3Pd03@`:00l>300>3@/0
0P0<2`T0100=30X03Pd;00h=2`0=30X200`;2@0600l>30061@@05aHD02DT8P0B4@l03Pd;0P0;2PP2
00`;2@803@`:00P04Ph;00h:1`0;20D03@T700h:1`0C3``03PX7018>2`803`/800l05Q8?01LE4@0=
30X05ADC00X:200C4a402PX8014@3P0920H04A0>00h:2@0:1PD071PG00l;2P0?30/00`0>3@/200d<
2PH030/904T03@`900d<2P0>3@/03Pd;00l>3@0?3@h03P`=00d;3@0<2Pd03P`?00h<400<2Pl02`X@
01DE6P0=3A402@T;00l?3@0:2@H04@h:010<2@0D3``030H501@<300D3Pl05Q<C01HF5@15AD<0XJ6O
07UiM`0B4a405QHF00/:3@0E51P061LL01DD6`061@`0>C/o00lA4`0:2``03`h=018>300<1`L04P/:
014;2`0A30`040/?00h93`0<2@h04Q0F00l<4`0I5Q`04PlF05QEG01NFf404PlE010=50091``03P/B
00d:4@0?3A803@/>00`:3@0@3Q402PP;010>4@0?3A002`T<00`:3@0?3A002`T<00l=400=2`l04@lD
00803P`A00<03@/@00X83@0@3Q<00P0C4AH300d;400500d73P0A2A0050/C01<:4P0A2A000P0C2a80
3P0B2A404PXA00l73P0>1Pd03`L>01<<4`0?2Q004@`B00d83P0;1P`040/A00h93`0?2Q003PT?0P0=
20h03@0?2Q0040hC00h<4@0C4AH02`T>018@5@0=2a003`dB014?500C4AH03`dB00d;400?3A800`0;
2@`03@0J61/05A<F00h<3`0:20/03P`?014?4P0>30l02`T<00`:3@0=2`h030X=00/9300=2`h00P0>
30l200/9308030X=00D03@/>00h<3`0>314040dC00l=4P0200d;400?00h<4@0:20d030X?00h<4@0=
2a002`T>00T7300@3a@02PT>01@C600:2@h03P`A010>4`0=2a003P/@008030L=00H040/A014<4P0@
2a403P`A00`:3`0;2@h200`:3`0B00X83@0<2Pl03@/@00d;400<2Pl02`T>00h<3`0;2@`03`d@00d;
3P0;2@`03P`?02@R9@0:20/030X=00l=40091`X02PP;0P0<1`/400d830803PT=00L03`X>00h93@0;
1PX02PD900l:3P0=20`03PT=00804@`@01803`X>00d8300;1PX030L;010;3`0>2@d02`H:01@?5@0@
31403@P>014<4P0<1`d05a8H00h:3`0810T03`X@00H11P0G4QP600`72`0H00d8300<1`/030L;00h9
3@0?2Ph03@P<00`7300;1P/03@P>014<4P0=20h030L=00d83P0E41H06QDK014<4P0<1`d03PT?00d8
3`0E41P0?SQ201<>5@0:1@`04@`C0P0=20h200h93@803`X>00<03`X=00h:2`0>2P/00P0>2P/03P0?
2``04@d>00l;300=2@X02`H800`72@0>2@/03PT=00H21@0L5a/02`H:01<>4P0<1`/03@P<0P0<1`/2
00d83007010;3`0>2P`040`=010<3@0=2@X030P900d92P0400`82@0@00h:2`0?2``040l=00T8100:
2@H081lL00d<200@3`/020L400d<2@0:2@D05aHC01<B400@3@X03P/700l;1P803@X500<030T400`8
100>2PH00P0>2`L05P0>2`P03@X700/81P0>30d030`=00/;2`0:2PX02`X:00`;2@0=30/030X900h:
2P0E4A004@d<00h:200;2PD03@`600/:100A40/04a8>00l>2`0;2PP200/92P<02`T<00P02`T:00l=
3P0>30d03@/<00T7200:20T04@l@00h<3@803@/<00/03P`=00d;300=2`h03P`?00X82`0=2`h040hA
00d;3P0?3A003P`?00d;3P0200h<3`0400l=400>30l03P`?00h<3`803@/>00d02PP;00L5200A3a80
3@/>010>4@0C4A@030X=00d;3P0A3a803P`?00X8300<2Ph03`dA00H03P`@01003@/>00l=400B41<0
3@/>00h<4@0A3Q@03``C00h;4P0=2Q803P/C00l<5@0=2a803@`B010?5@0B4AL040lE0P0<2a405P0A
41H030/A014@5P0?3Q@03PdC01DD6@040`L03a0E01<D700?4QT0DUQO0=SMh`1PIF`05QPO010A5P0;
31004A0E010?5@0B4AL051<H018A5P0A41D2018B500:01<C5@0C4a<04A4B014A4@0C4a@071`N01LH
6P0C51H05aLI014B50804Q8D02/04A4C018C5@0@41804Q<E01@D5P0B4AH04a<G01LG6`0K6Ql071/P
01PH7@0C4QL05ADJ01TI7@0F5AX03`lD01<B5`0E4aH04a4D00h<3`0N71l0518E03`j?@0W9BP04a4D
01@B5@0I5aX05A<F01<A500=3@l051@F01HF600G5aT03Pd@014?4P0C4A@04@dA014<400F4AD06Q@H
01<=4@0F4Q<0510A00<04Ph?00T04`l@01DA4P0A3@h04`l@018>3`0A3@h06aLG01@@3`0C3`h00P0A
3@`0800@30d03`/<018>3`0?2Ph040/?01lJ7P0I51T02PD901DA4`0A3@h02`L8014=3P0F4Q<0510A
00d92P0?2``04@d>018>3`0?2``03`X>00P42@0D3aD0?3Lm028M8`0<1`d04PdC00d83P0<1`d050lE
01XE6`0E41H03`T?0P0?20l01P0@2A003`T>00l93P0>20d05@lD01D=4`8040P?00@02`@:04@nA@0P
6b403@P>0P0>2@l01@0E3QD03@D<00l53@0?1@d04@H>00804PL?01804PL>0146300A1P`040D;0146
300B1`d03@8801P=4`0B1`d01`0201@;3`0k<3H03P<90146300B1`d04@H<01052`0B1`d200l42P80
4@H<00/02P450146300H3AD05P/C01463P0=0PX03P<;01463P0?10`040D=01873`0200l430030146
3P0?0PT03`8900H03`89010040<900l22@0>0@L03@0700l42P0>10T03@<800l72`0>1@X0308600/3
1`0C2@d040D:00l42@0=0`L08AHK5?ooool001_ooooo00d03@d?00h>400<30h02`/=00`<3P0@4180
20P:00X:300@41802`/=00d=3`092@/03@/<00@03P`=01T03@/<00`:2`0>30d02@L800X82@0>30d0
30X;018B500C4aD02PX<00d=3`081PT040hA014?4P0@2`l03`X>014<400A2`l03`X>05eJF`0H5QL0
4a4B00/92P091`P07A/L00H03P`=00<02PP900`:2`0;2@X00P0=2``01@0>30d0518C00l=3P071@H0
3`d>008040h?00L020H702DS900m>c`04a4B00@20`081PL03`d>008040h?00l04a4B018@4@0?30d0
3`/<00h:2`0B3Pl061@E01dI6P0G4a@04@d>01<?400@30d030P900h:2`0>30/00P0;2PP00`0>3@/0
40l=00l>300300h=2`0800d<2P0<2`T030/900d<2P0B4@l030/900D40P0<2`T400h=2`<03@`:00L0
2@P601DD4P0E51803Pd;010?3@040`8020L500802`X800/02PT700d<2P0;2PP010@201<C4@0<30X0
410>00H6100<2`T05A@B00d<2P02014=3003010<2`0E41003`/:00803@`:0P0;2PP00`0:2@L030/9
00`;2@0400`;2@0C00d<200>3@X03Pd;00h=2`0?3@d03`d>00d;300;2@/02`T<00d;3P0=2`l02`T>
014@5P0N7B<051<H00/9300=30X03Pd9014=2P0200l;200F00H20@0@2P`05@lA00l=3P0=3@d00@41
00h>3P0A4A805ADG02DU9`0Z:Bh0?ci307IeNP0@3aD03PlD034f>@093@h05ALF02LW9P0]:BH07APE
01491`8040X:01L03PT=00d83P0:20d01`D:00T7300G5AX02`T>01<A5P0100@02`T>00@21`071@X0
<S0e01PF6`0@3Q<08b4T00X82`0200<01`D800d;3P040PD030X=00h<3`0200/9300>00d;3P081PX0
108700T7300A3a@02PP=00L52P0>31403@/@00T7300?3A806QPM01HD6@0A2a420188400<01@:4P0E
2a<050XB0188400A1`l04PP@00l53@0>10`03`D=00l83`070PP02PD;0P0;1P`06@0?2Q002PD;00/6
300<1`d03@P>010;4@0B3A<02@L<00X83@0B41D02@L<00l=4P071@X03P`A010>4`0B41D03`dB00h<
4@0?3A801`D801DC5P0>30l02@L:00P62@071@P00P0A3a801`0@3Q4030X=00/9300=2`h02`T<00X8
2`0<2Pd00P0?3A000`0<2Pd03@/>00d;3P0300`:3@0700/9300<2Pl03`dB00h<4@0<2Pl02`T>00d;
400300/93P<030X?00D04a8G00T83@0<2a000P4600H52P0200X83@0700/83@0=20h03PT?00l93`0?
2Q0030L=00`:3`0200l=4P0400d;400:20d01`D:00T730<030X?00L02PP=00`:3@0=2`h04a4D014?
4P0;2@`030X=00802PP;00H04@lB00`:3@0610L02PP;014<400>2@d200d8300300h93@0?2Ph03@P<
00<03PT=00D030L;00/62P0>2@d030L;00d8300200l:3P0800d8300>2@d030L;00d8300?2Ph03PT=
00`72`0D3aD200d83P09014<4P0300@02PD;00d83P0H4aT02@D:00T42P060@L02PD:00D030L;0P0>
2@d01@0=20`03`X>010;3`0>2@d03PT>00803@P>014040/A00d83P0<1`d03PT?00l:400>2@l030L=
00h93`0=20h030L?00P2300Q6bD040/C00d83`0A31<03PT?00d83P0200h93@803`X>00H030P900d9
2P0@30d040`=00l;300=2@X300h:2`0;00d92P0<20T030P901<>4P0F4AD00`02010;3`0?2Ph020@7
00/62P0<1`/00`0>2@d02@0=20`040`=01@@4@0G4a@04`l@00h:2`0810D02@D600X61`0300d92P0E
00/7200B4@l06aXH01XI5`0[:RP051<A00`;2@0:2@L03`h<00X91`0D4a40:BPV00T8100;1`@03@T6
00h:1`0=2@H030P500X60`0B3P/03`/8008030P500@03PX7010<2@0?3@h03P`=0P0<2P/200d;3007
0040000E4a@00@00018@4@0610D07A`J00X:0`0200/:1@04014@2`0C4Ph040l;00X91`802PP90`0:
20/03`0:20T01`D602PV9`0Q7b006ALH018@4@030P8071XK0040000E4a@04Q0A00l=3P0<2Pd03`d@
00h<3`0200l=400300`:3@0>30l03@/>00803@/>0P0>30l0100:20/02`T<00`:3@0=2`h200h<3`03
02HT9`0100804@lB00800@0200D03`d@010>4@0C4A@04@lB00d;3P0200l=40D03@/>02X040hA014?
4P0A3a804Q0C00`:3@0<2Pl03P`B00d:4@0?31<04@hF00l<5@0=2Q<03P`C00h=4`0<2a402`X@00`;
4@0?3Q@02`X@00`;4@081`d04A0F00h=4`0@3aD04Q0E00X:300B4aP03a8I00hA600a=Ch0P8B=038f
?`0520l02``A014B5P0E4aL040lE018A5`0D4aP04Q4F014@5@0B4Q@201<C5@0501<C4`0D51@051@D
01@D500Z:R`00P0D51H0700I6A/07QhP01dM7`0:2P`061PJ00L72@0>3Q006QXL01<C5@0B4AH03`hC
00h=4P0A41D05QDJ01PG700A41D05A@I01`K800J6Ah04a8G018A5P0A3a803`d@01dK7P0L6Qd04@lB
06UWJP0a;c8200l=400@01TG6P0C4A@03`d@018B500P82803`lA014A4`0K6Q`05Q@G00l=400C41<0
61<G01`G6`0C3A406A<G01<?40804Ph?00/0510A01DA4P0F4Q<05Q8C01<?40091@H0;BTZ048n?`0A
3@`05a<A01@@3`02018>3@804`l@00h0510A01LB5P0G4QH05a8F01@?5@0?2Ph02`L9010<3@0F4Q<0
4@d>00h:2`0C3a003PX;010<3@804@d>00P040`=00l:3P0B3A<05A0F00H21`0;1P`061<I00`73@@0
3PT?00<03`X@010:4@0?20l00`0@2A003P0?20l030D<00@0100:0`X05PlF00X32P0X8BP0`[c207Ia
M`0K5Q`050lE00X52`0A2Q404PTA0P0?1@d0100A1Ph04PL?01873`0B1`h20146300G01052`0A1P`0
4PL=00/01P0<0@L050X?00l42P0700803PD901hC6@0F2a403`@:01@93`0G31803`@:01052`0A1P`0
3@8801873@0:00D03PD900l4300>0`/00P0=0PX02P0>0`/040D=00d22P0?10`040D=00h32`0=0PX0
3`@<00`01P0=00L200h120803`89100@0`X02@0?0PT03P4800`11`0C2@h02P0500/01P0B1`d040D;
00/01P0201052`0301<83P0900@03P<901Cooooo000Kooooo`803Ph@00P02`/=00X:300=3@l04A4C
010@4P0<30h04Q8D00@41P80410B01<03@/<00h<3@0>30d03@/<00`:2`0;2@X030X;010>3`0?3@h0
2@L800`:2`0C4A80>SXl01dM7`092@/05aLI00X82`0A3a8040hA00803`X>00H040/?010:3P0=20`0
7Q/L00P61`030@82010>3`0300L51P0=2``03@/<00D03@/<01P04a4B00D3100@3Pl0518C00`:2`0V
92D05A<D00T7200@3Pl03P`=00d;30050`@03`d>018@4@0?3@h06QPI010>3`0;2@X03`d>01LE5P0E
4a@03`d>00l<3@0@30d200h:2`0?014=3P0E4A804Ph?00h:2`0?2``03@T:00/7200=2@X03``<00d<
2P0;2PP03@`:00h=2`0;2PP030/900803Pd;00T03@`:00`;2@0<2`T020L5014@3P0F5A<03`h<018A
3`0;2PP00P0?3P`0300>3@/03@`:00d<2P0<2`T02@P600`;2@0:2@L020L500d<2P0@3`d02`X800d<
2P803Pd;00@03@`:00X91`030`405ADC0P0;2`T03P030`4030/901<B400920H04@d<01@@3`060P40
4Pd=010<2`0>3@/03@`:00`;2@0;2PP02PT71P0<2`T0:`0>3@T03Pd:00h=2`0>3@/03Pd<00h<3@0?
3@h03P`>00d;3P0?3A003`dA00d;400<2Pl0518G00l=400:20T03@`900l>2P0A3@X03PX7010?3@0;
1`P03PT=00T420091`P03Ph>014A4@0D51@051@E01<C5@0B4Q@040lD01dL8@0k>Sl03`hD00H73004
1PT07B4R01<E5029RHP0XIbI020K600D30X00P0B30`05@0A31003@/@00`:3`0D4QL02@L<00d;400>
31406ALL00d;40091``05A<H018@5@0?3A80518G05]IGP1>C4l02@L:00h<3`0H5QT04Q0C010>4@02
00l=400F00h<3`0?3A002`T<014?4`0=2a003`dB00h<4@0200D01`D:00l=4P0=2a002@L<00d;400F
51T04a4F00l93`0@1Ph03P@<0188400D2Q804PP@01473`8050XB00X04@L?01063P0A1`l03PP?00X5
2`0B3A<04@`B00`73@0@2a402`H<0P0<1`d02`0>2@l040/A014<4P0@3Q<01P@900D420071@X0518G
00/93P0>31403`dB008040hC0P0?3A80300H5QT04@lB00D31P0F51L061HI01<A500=2`h030X=00/9
300:20/02`T<00h<3`802`T<00D03P`?014?4P0@3Q403@/>00h<3`0200d;3P0600`:3@0;2@`02`T<
00`:3`0>31403@/@0P0;2@h300`:3`802`T>0P0=2a00200>3A802PX>010?500@3a@08R0U00d;400@
3Q<03@X?0P0>2@l0300=1`h03`X@00l:400;2@h02PP=00d;400D4QL06ALL01<A5P0A3a@03P`A00`:
3`802PP=00T03@/>00`:3@0@3Q403P`?00/9300=2`h03`d@00`:3@0=2`h00P091`X01`0@3Q403PT=
010;3`0A31003`X>00/62P0910P01@0=20`02@0<1`/03@P<00/62P0<1`/03PT=00d8300<1`/04@`@
00h93@0200d8300>00`72`0;1PX02PH;018=4`0:1@/03PT?00l:400;1P`03`X@00T42P0I5AX0C4M=
01hI7`0>2@h500`72`803PT=00h03@P<00l:3P0?2Ph03@P<00h93P0=20h030L=00h93`0;1P`030L=
00h93`0=20h030L=00/630803@P>00P03PP@00D02@0C3AL03`TB00P32P0?2Q403PT@00d83P803PT=
0P0?2Ph01`0;1`P03@T:010<3@0A3@h03`/<00`82@0=2@X00`0>2P/01@0=2@X030P900<00P0@2`l0
5a8F00800`0200<05a8F00/62P0<1`/00P0?2Ph0700>2@d03@P<00/7200?2``05A4B01<?400@30d0
3@T:00`82@0>2P/04@d>018>3`0@30d03@T:00/92P0_;Rd05QDC01LE5P0=2`/010<100/92P0=2`/0
1@@200/92P0N7A`01`H400X60`0<20D200h:1`0400`81@091@804Ph;010<2@803PX700H03`/8010<
2@0>2PT03@T:00X82@0<20T200/92P0700d;300;2@`06ALL01/I7P0@3a@0000200`;1P0200X91004
00`;1P0;2PH02@P400d<2P803@/<0`0=2`h03@0;2@X00`4202TW:00Y9bP0;2X[01`J6`0G5AH0DU1A
00@20`091`P020H70040000<2Pd00P0=2`h200h<3`0500d;3P0>30l03@/>00`:3@0=2`h00P0>30l0
0`0;2@`030X=00d;3P0200d;3P0;00/9300Q7b802`T<00X82`0200<08R0S00`:3@0@3Q404Q0C014?
4P0>30l00P0?3A0500d;3P0Z00h<3`0<2Pd03@/>00l=400;2@`03@/@01<@5P0@3A@03@XA00/8400=
2Q<040dF01<A600@3aD03PdC00`;4@0>3A<04A0F00l>500L6b404Q4G00d<4P0@3aD04A0E01LE6P0C
4A@0410F00T<4`0>4AP082@]01DI8P072a@05APO01LH7@0D4aP0518F010?5@0B4AL051<H018A5P0A
41D04Q8D0P0A4A<0200A4A404a<C01<C4`0B4Q804Q8D00@41P0K6ad02`/=0P0<30h03P0:2P`05QHH
00H6200A4A<06QXL01LG6@0=31403PdB014@5@0D4aP04a8G010?500A41D04a8G0P0I61d201<B5`0I
018@4`0I5aX04Q0C01<A500?3A00:2HY01TG6P0J61/0518E010>4@0D4QD071XM03hn@01ADE<02PX<
01@D5P0B4A<04a4D00h<3`0F4aH04`hB02PS9`0O6Ad05@lC01DA4P0201@@4@<04`l@00P05Q8C01LC
500810D0=S8c05IBD`0?2`X05A4?018>3@8040`;01004Ph?01<?40091@H04@`@01<>4P0=20`030L=
00l:3P0B3A0040`=018>3`0D414040`=00/7200>2P/040`=0P0A3@h0800@30d04PhA00X52`0A3180
6QDK01LB600E41H03PT?018=4`0A31803`X@010;4@0B3A<04@/B00l83`0@2A004@XA0109400?20l0
4``C0109400B2a803PL>00l83`0F3aH0HE]Q03<^=00=20h040/A00D01P0;10/030<;0P0?1@d0100A
1Ph04PL?01873`0B1`h20146300301052`0A1P`04PL=00803`@:00L04`P>01@93`0?10X060dC02DJ
800L4AL04@H<00804PL=00<02P4500l42P0900@00P0A1P`00`0D2@l02`8600l4300200l4300900h3
2`0=0PX03@8:00d22P0>0`/03`@<00d22P0<0@T03`@<0080300600<03@0700h1200?0PT00P0@0`X3
01442`0>01032P0>0@P01`02034V;00D2@l07a@J00P00`0<0@L04`P>01052`0<0@L04`P>00d2200A
1P`Dooooo`006oooool200h>400;00`<3P0;2`d03@d?014A4`0;2`d02PX<014A4`071`T03@d?00`<
3P0>30d00P0?3@h06`0>30d03@/<00/92P0C4A8030X;01<A4P0<2P/08AlP0490@@3=cLl0De=E01DE
5`0H61X04@lB01<A500@3Q403`X>014<400B3A404@/?00h93@0A3Pl040h?00T7200E4a@07A/L01@B
4`0600h<3@0N00`:2`0B41401`D600h<3@0?3@h01`D601lM7P0B414020H7018@4@0?3@h09bDV04E3
A00E4a@05Q@E01LE5P0>3@d0<c4b01<A4P0=2``03P`=00P61`0<2P/05A8C01<?400@30d03PX;00`8
2@0=2@X03`/<1@0@30d01`0>30/030/900d<2P0=30X030/900/:200=30X00P0>3@/01@0=30X030/9
00`;2@0<2`T02`X800803`h<00D02PT700l>300>3@/03Pd;00d<2P0300`;2@08010?3@0:2@L05QDC
01TH5P0920H030/900l>300=30X200h=2`0@00d<2P0>3@/06ATG02PX9P0D51803Ph<00P81P0@3`d0
1PD301@C4@0@30/06aLF00/71P0G4Q404@d<00l>30<03Pd;00<03@`:00`;2@0<2`T0100<2`T01@0?
3PX03`h;00h=2`0>3@/03Pd<00803P`=02X03@/=00`:3@0>30l03P`@00`:3`0?310030T;00X61P0=
2@T03``:00/:1P0A40h02PX900d=3P091`/03`hC00`<4@0=3@l030`<018B4P0K6a/04Q8C00T92`0<
30h051<H00X93P0?3Q<020P=01PH7@0<41<030d?00@51@19AdL0EU5>01`G500A30T04@/;014<2`0?
2`l030X?00/93P071@X200d;400W014?500<2Pl030X?00d<400A3a@02PP=00h<4@030@H08b4V01LE
600?3A005A<F00`:3@0:2@/02`T<00l=40091`X03`d@00d;3P081PT0BDM;03Xh?@0A3a@030X?00d;
400C4AH02`T>00`:3`0>31402PP=00`:3`0>314040/A0109400>1`h040T@014:4@0@2A003`P?0080
4@XA00T03PL>00d63@0>1`h03PP?010;4@0N6Al06QDK00h93`0A3180100?2Q00200>2@l03@P>01HD
6@0H5Q/07A/P00/93P0=2a0030X?0P0>3140400?3A8040hC014?500?3A80@Cm202DS9P0?3A0040hA
00@21@0U92H04Q0C00l=400<2Pd02`T<00d;3P0>30l200d;3P0300l=400B41<04Q0C00803P`?0P0=
2`h200`:3@0700/9300<2Pl03`dB00h<4@0<2Pl02`T>00d;400300`:3`0Y00d;400>31403P`A00/:
3`0I6Ad0>CPm0:RW[012@DH05Q@I01TG700@3A8040/A00l:400<1P`04PdC00h93`0<2Pl03@/@00h<
4@0A3a@04Q0E01PF6`0B41D02PP=00P62`0;2@h03P`A00l=40091`X02PP;00T72P0:20/03`d@010>
4@0:20/02`T<00l=400=2`h030X=01<>4P0?2Ph00P0<1`/00`0>2@d03`X>00d8300300d8300300h9
3@0?2Ph03`X>00803@P<00<03PT=00d8300<1`/00`0=20`03`0>2@d04PdA01@?4`0`:c401@4600d8
3P0<1`d02PH;00l:400810T06QDK00`73@1ED5H0FUEK010;400500`72`803@P<00P030L;00h93@0=
20`02`H:00d83@0=20h030L=00h93`802PD;0P0=20h0300@2a403`X@00X52`0=20h040/C00d74@0>
21803`XB00<01@0?2Q403`X@00d83P803PT=0P0?2Ph01P0<20T03@T:010<3@0A3@h03`/<00d92P@0
3PX;00P03@T:00`82@0?2Ph01P4500d9300G4aH0EU5E02PT9`803@P<0P0?2Ph01@0>2@d030L;00`8
2@0=2@X03PX;00803@T:01@040`=00h:2`0@30d04`l@01@@4@0@30d030P900/92`0B41<01`D701@B
5@0;2@`05Q@F00D31P0=2`d030X<00X82`0@3Q003P`=00`81`803@T60P0>2PL00`0=2@H03PX7010<
2@02014=2P0B00l;200=20D040T901092P0>2@X03PP:00l:3@0@2a0040hB00d<4P0:2A40410H00d?
5`0>3aD03@`:00X91@0=30P03Pd90`0<2`T300`:2`8030X=00h040h?00<10P0>30d03`d>01`J6`07
1@H06QPI05ECE00F51D02@L800`:2`0B41403@/>00`:3@803P`?00<03@/>010>4@0>30l00`0<2Pd0
0`0=2`h03P`?010>4@0200l=40803@/>00P03`d@04i<C`0^;2l030X=00d;3P0G5AP020H900h<3`80
3`d@200>30l01`0@3Q403P`?00l=400@3Q4030X=00l=4P0B41H00P0@3A@0100?31@040dF010=5P0?
3AD200h=4`0J00l>500>3A<03PdC01LF700f=C/09B@Z00d<4P0F5A/04Q4F00T7300>30l04Q4G00h?
5`0?4QT030lH018F7`0>4Q/03Q4H01TI7`0O7R<04a4E010?5@0B4AL051<H018A5P0A41D2018B500<
014A4`0C4a<05aLG01LG5`0D51@03`lA01HF6010@4807AdO01<C5@0@41805aLI0`0B4Q@04@0G5aT0
4Q8D018A5P0A41D040lD018A5P0C4QL04Q4F01DD6@0@3a@04Q4F01<B5`0A41D051<H018@4`0H5QT0
518E00805Q@G01@030X=01<A500V92L05A<F00d;3P0G5AP03`d@01<C5@0I6A/0820R01@D5P0C4QD0
5Q@G01<A500B3Q8071LK018=4@0?2@d04@/?01@@4@@05A4B00P0510A018>3`0G4a@07ATJ00d92P0K
5aP04Ph=01@@3P<04`l>0P0C3a00300i=CH03`X>00h93@0H4aL050lE018=4@0@30h05A4B00l;300@
30d05A4B018>3`8040`=0P0A3@h03`0B3Pl04@d@018=4`0A31803`X@00P42@0;1P`050lE010;4@0;
1P`030L=014<4P0@2a403`T@01094003014:4@0>0109400A2Q402`H;014:4@0<1@`050dD00/42`0A
2a403@P>01TD6P0>2@l02@D:01<<4`0<0`/200l53@0401463P0B1`l04PL?01873P804@H<00/040D;
0146300B1`d03`@:01H;4@0@1@/03P<901H;4@0D2@l04PL=0146300200l42P080146300C20h04`P>
00/11P0C20h03PD900/11P0C20h200l4300:01463P0B1`l04@H>01053@0=0PX03`@<01053@0>0`/0
3@8:00l430803P48100?0PT04P0@0`X04@@;01442`0A10/040<:00h1200>1@T0;R@Y01dB600L4aL0
3P@901893@0>0`T03@<801052`0J3aD04@H<00l42QCooooo000Kooooo`0=00`<3P0>3Q003Ph@00`<
3P0=3@l03Ph@01/K7@0G5aT03@d?014A4`0@418051@F00h<3@0300l=3P0400h<3@0=2``04@l@00X8
2@803P`=01@08R0Q03Tg>02VYZP0?cm100l?4@0<30h04@lB00L5200=2`h040/?018=4@0D3a<050hB
014<400;20T03`d>01HD5@0B41401`D600D310H03P`=00H03`d>00h<3@0D4Q<03P`=00d;300C4A82
00h<3@0@00X82@0A3a003@/<01/I6P0/:R/00@0000T7200;2@X02@L8040n?`0@3Pl02PP900h<3@0;
2@X07A/L02@Q8P804`l@00@04Ph?014=3P0@30d03PX;0P0<20T02P0>2P/03`/<00l;300<2PT040l=
01@C4@0?3P`02@P600`;2@0?3P`200h=2`0900d<2P0<2`T030/900d<2P0<2`T051<A01PG5@0A40h0
2`X800803@`:100>3@/02@0;2`/00P8200@4100;2`/03Ph>02XZ:P0@41002PX:00T92@0200/;2`0A
01@D500A4@l08B4O00`<2P0:2PP020P600`;2@0@3`d0?Sdk018>3@0E4A003@T800d81`0=2@P030/9
00d<2P0>3@/00P0?3P`600`;2@0500l>2P0?3P/03Pd;00h=2`0=30/00P0=2``0900;2@/02`T<00d;
3P0=2`l02`T>01D@500@2P`03PP800d9200=2`L030/700L71@0D51D06AXN00L83@062A403A0G00T:
30092@T01PH601hN7P0?3a00410B00/;3@0L6b00:RT^00P8300K6R003@`B00X;3`0Q8B<020P801DB
4P0K5Q<01`8000l:1`803`/:00<03@X=00/93P0920d00P0H5QT0;`091`X03@/>00800`0?3A004a4D
00P62@010080518E010>4@071@P03@/>00800`0100801`D8010>4@030@@030X=00H41`0>30l00`44
010>4@1GEET081hS0040100=2a0040hC00l=4P071@X04Q0E01DC600=2a002PP=00d;400=2@l03PL>
00l83`0=1Pd02`@;00`5300>1`h03`P?0109400=1Pd030D<00d63@0>20h02@@:00803`X@00@030L=
00l:400<1`d03`X@0P0@2a401`0=20h02`H<0040100:20d06ALL00L52P0;2@h00P0>31403@0<2Pl0
3@/@010>4`0A3a@03P`A00400P081PT04a4D00H41`010080AdE801@B5@0A3a800P0=2`h00`0>30l0
30X=00d;3P0200`:3@0300h<3`0?3A003P`?00802`T<0`0<2Pd0100=2`h03@/@00l=4P0>314200`:
3`0400h<4@091``02`T>00h<4@803`dB01`03P`A01<B5`0C4QL092<X08b;T00U8bP06ALL01<A5P0=
2Pl05A0F01@?5@0<1Pd04@`B00d83P0=2a003P`A00d;400:20d01`D:00/93P0:20d020H;00T7300<
2Pl03P`A00h<3`0:20/02`T<0P0:20/02`0>30l01`D800P62@0;2@`03`d@00`:3@071@P08QdQ01XE
6@0E41@03`X>00<03@P<00@030L;00/62P0=20`03`X>0P0@2`l200h93@0400l:3P0>2@d030L;00`7
2`803@P<00l03PT=01<>4P0G4QH0<bhd00<0100C3Q@04@`B010;4@0>2@l030L=01LB600910X0JFAZ
08Z5R`0B3A801@0<1`/200h93@0F00d8300>2@d03@P<00/62P0=20d03`X@010;4@0C3Q@03@P>00/6
300>2@l030L=00d83P0A318030L=00/6300=21005a4K00`6400@2a<01`8901@?5P803@P>0P0>2@d2
00l:3PH03PT=00l040/?00l:3P0=20`02`H:00`72`0=20`03PT=03dh?00=20`03PT=04I1A@0I51P0
3`X>00h93@0=20`00`0<1`/200h:2`0600d92P0:1PL02PH700d92P0<20T03PX;0P0@30d0500=2@X0
2PH700X82`0D4QL02@L<01HD6@0@3Q<071XO00d;400?3A803@/@00L52P0k>Ch0AdE800l;300>2PT0
30P700d9200?2`X04Ph=100>2PT0400=2@P03@L701<92P0B20T04@P;0189300@2a004@`B00h;4P0:
21807AdY06EWL`20Q9005QTR00h>3P0;2PP2010?3@0300d;300@3Pl030X;00D030X;00@040h?00`:
2`0>30d03`d>0P0C4A803`0@3Pl020H700T7200D4Q<030X;00P61`0<2Pd03`d@01HD5`0D4QD03@/>
00h<3`0=2`h030X=00/9300200`:3@0300d;3P0>30l03@/>00<03@/>00L04@lB010>4@071@P06aTL
00800`0100805A<F00803@/>0P0>30l00`0=2`h03P`?00l=400500l=400<00`:3@0;2@`030X=00T7
2P0=2a004@hD00l<4`0A3QD04PlG014>5`0?31D03P`C1@0=3180;P0000D05A@J014@5P0=31804A0F
00l>500C4AH040hA00L630061Ph041<J01lR:`0:3AH05aXS01LG7`0?3Q@03@`A010>4P0@3aD04Q4G
01@C600B4AH04A0E018B500C4aD04Q8D01<C4`0J6QX06a/K01DE5@0J6Q`04Q8D014A4`0F5QP05ADG
01LG6@0B4Q@030`>01LG6@092@/08b<U00/;3@0F5AX04Q4F010?500B4AH201<B5`0401LF6`0@3a@0
4Q4F01@C608040lD01X05aDH01<A500J61/04a4D010>4@0F51L040hA00l=400=2`h04@lB01LE600A
3a803@d?01`L7P061PP020P:01HE600A3a805Q@G01HB5P0M61`04PdA02lY;@0H4QH0510A01DA4P80
5Q8C00X05A4B01@@4@0H51D05A4B00l;300J5QL06aLH00X61@0A3@/04`l>0P0E4A002@0B3Pl04@d>
03`h>@0A31003@P<00h93@0@2a406QDI04E0@`02010<3@0301@@4@0:1PL02PH700<040`=00l04@d>
018>3`0=2@`05a8H01lJ800>2@l030L=010;4@0?2Q004@`B010;4@0?2Q004@`B018=4`0B31800P0A
2Q40400B2a804@XA014:4@0E3QD03PL>01L@5`0=1Pd030D<00P1200@2Q000`0402LR:01@Be406QDK
00l83`0C2Q8200l53@0401463P0B1`l04PL?01873P804@H<00d040D;0146300B1`d02P0500h32@0@
1@/050T?01D:400B1`d04`P>01873@0A1P`03P<900803@8800L03P<90146300E2Q00NVme044f?00@
1@/03`@<008040D=0P0A1Ph01`0B1`l03P<;01053@0A1Ph03`@<00h32`0@1@d00P0B1@`0100A10/0
40<:00l22@0>0@P200l22@0@01032P0?0PT03P4800d01`0C20h03P<90146300=0PP05P/A01<83P0=
0PP040D;01D:400O51X050T?01052aCooooo000Kooooo`0>00/;3@0>3Q003`lA00d=3`0<30h03@d?
04e=C`0f=SP03Ph@010@4P0820X04A4C00h<3@0?3@h3010>3`0300h<3@0;2@X03`d>00<03P`=01<0
30X;02PX:P0=3@l02PX<01<C5@0I5aX01@<600d;3P0@2`l04PdA01HA5@0E3a<04PdA014>3`0<2P/0
1P@500`:2`0A3a0030X;00H03`d>00<03@/<00P61`0G5AH00P0;2@X00`0K6AX040h?01DC5002010>
3`0800H41@091`P040h?00h<3@0E4a@020H700800@0G5AH200X82@0400l=3P050`@04Q0A01lL7@<0
510A00H04@d>00l;300@30d040`=00l;300A3@h201<?4007014?3P0F5A<06QTG014@3P071P@02PT7
00l>300200h=2`0;00d<2P0<2`T030/9010?3@0A40h030/900/:200?3P`02PT700d<2P0>3@/00P0?
3P`07P0@3`d04A0>018B4P0C4a<03Ph>00H61P051@D03Ph>01<C4`0;2`/02@T900`<300=3@d06ATI
00<30@0D51801@D300`<2P0>3P`03`h<00`;2@1:BDL03@T8010<2`0A3@`03`X:00/71P0920H02`X8
00d<2P803`h<1P0<2`T0:@0?3PX03`h;00h=2`0>3@/03@`;00d;300?3@h03P`>00d;3P0?3A003`dA
00d;3P0B31004@/<00h:2@0<20L02`X6010A30071`D0:2TZ03<f>`0E61l01PTC00/>5@092Ph03`l?
01DE5@0i>CT05ADF00410`0?3a4010<800h=4P0?3Q<00`8800l>500:2`l03`lA018@4@0;1`L03PT6
00804Pd:0P0A3@`0900>3A0030/@00/:3`0=2`h040hA00@21@0A3a801`D801LE600=2`h0518E01DC
5P0=2`h01P@700/9300A3a800@02010>4@0<2Pd03@/>00l=400=2`h02PP;00l=400100806ALJ05QF
FP0F51T020H;00h<4@0200D03`dB01<A5P0K6Ah06QPM010>4`802`T>00H030P>01<<4`0E3QD04@XA
00h73P0?20l3018;4P0900l83`0>1`h03`P?01<=500:1@/02@@:00d83P0C3Q@05Q4G00803PT?00D0
3`X@010;4@0>2@l030L=00d;400200H42@0400D3200B41D030X?00h<4@8030X?00h040hC018@5@0>
31407A/N00l=40071@P061HI014?4P0C4A@03P`?00/9300:20/03@/>00h<3`8030X=00<02PP;00T7
2P0;2@`00P0<2Pd02@0:20/02`T<00`:3@0<2Pd03@/>00h<3`0>314040hC00l=4P0200d;400700h<
4@081P/030X?00l=4P0@3Q<03`dB00d;400200X93P0<00l>4`0F5AX03`hC00X83@0;2@h02PL<01LB
600H4aT03@L=00l:400C3Q@03@/@0P091``01@0=2a004@lD00L52P0:20d030X?00803@/@01X030X?
00d;3P0;2@`03P`?00d;3P0:20/03@/>00`:3@0;2@`020H900T72P0;2@`02PP;00/62P0C3Q8061<G
01LB5P0?2Ph02`H:00d8300<1`/02`H:00d8300?2Ph040/?014<40803`X>01D040/?00h93@0=20`0
4PdA014<400>2@d02`H:00h93@0B3A403@P>00l:400>2@l020@901D@5P060@L05a8H00D01P0F4AL0
30L=01@?5@0?2Pl01@0<1`/06P0?2Ph040/?00h93@0?2Ph03PT=00`72`0?2Pl04@`B018=4`0F4AL0
3`X@00d83P0@2a402PD;00P32@0B3A<03`X@00X52`0:1@d06aDO00X43P0A31@03PT@01TD6`0<1`d0
3@P>0P0>2@d300l:3P803PT=01803@P<00h93@0?2Ph04@`@00l:3P0<1`/02PD900/62P0>2@d02`H:
05IAE@0910P04`hB018=4@0?2Ph040/?00l:3P0=20`200/62P0400d8300<20T03@T:00h:2`8030P9
0P0>2P/04`0?2``040`=00l;300=2@X02`L800<11P0l>Sl040hC00H42@0>31402`T>00h<4@0:20d0
20H;00`:3`1mNh00UI>F014=3P0>2PT00P0<20L0100A3@`0510?010<2`0>2PT200/71P0D00`81`0?
2@T040H701461`0@1PL03`H;00l83P0=2a003``E00/;5@0=3a/09BLd0<O:f02UYk<04A0A00`:2`0?
3P`03@/<00P61`0:20T600h<3@0600`:2`0=2``04Q0A00`:2`0200404@l@0P0?3@h0200=2``01P@5
00l=3P0=2``030X=01<A500M6ah06ALJ0`0=2`h02@0<2Pd02`T<00`:3@0<2Pd03@/>00X82`0;2@`0
30X=00d;3P0200h<3`0600400P0>30l030X=01<A500?3A002@L:0P0=2`h200l=40803P`?1@0@3Q40
0`0?3A0030X=00d;3P02014?4P1K01HD6@0H5Q`04PlF00h;4P0<2A403P/D018?600C4AP040lE00h=
4`0=31803PdC014@5P0@3aD04a8H018A5`0I61h04A0F00`;4@0<1`d03`X>01@B600C4QX0410H00/>
5`082a@051LP010@600?3Q@04Q0E01/H700A3QD04Q4G01@C600B4AH04A0E018B500A4A<03`lA014A
4@0H61P06ATI01<C4`0>3Q009RHX02`/;P0P828010@601DE5`0=3@l04A4C01hN800=3@l0>c/m01HF
600?3Q<04Q4F01LF6`0H5a`04Q4F00/:3`0G5Q/04Q4F01HE6P0G5Q/04A0E00h=4P0C4A@0518E01PF
6@0E4aH071XM010>4@0I5aX04@lB01TG6P0G5AP04Q0C028P8`0?3a40ShnA018B500H61X03Pd@028P
8`0D4QD07a/O014<400`:bl0J69V01`F6P0301PD5@0L01DA4P0A3@h03`/<01DA4P0@30d06ADF01<?
400810D06QHE00d91`0A3@`04`l>018>3@0?2``03@T:00/7200E41@071LK00l:3P0T7bD0Ad960;fi
^`0K5aP01`<401DA4P0=2@X0510A014=3P8040`=00l04@d>018>3`0C3a801`8800X52`0>2@l03`X@
018=4`0:1@/03`X@018=4`0>2@l02`H<010;4@0B31<00P0A2Q40400B2a804@XA014:4@0A2Q4030D<
01H?5P080@P06a@K01D>5@0<1P`03PT?01dH7P0D3aD01P4700h73P0:0`T200l53@0401463P0B1`l0
4PL?01873P804@H<00`040D;0146300B1`d050T?00h32@0@1@/050T?00d2200A20`04PL=0146300@
1@/20146300;00d2200>0`T05P/A02@I7`3`iN/0SX>901062`0D2A404`P@01463P0?10`00P0>0`/0
0`0?10`040D=01873`0200l4300601463P0D1`h050L>01<63@0A10/03`890P0>0@P200l22@803P48
00d0300601D:400;0@H0200301L<4P0>1@T0304700l42P0<0PL02P0501<83P0=0PP04@H<01Cooooo
000Kooooo`0301<C5@0=3@l04Q8D0080410B00h06a/M096AT`1iNG/03@d?00h>400<30h0410B00d;
300?3@h040h?014?400@3Pl03P`=010>3`@03`d>00P040h?010@4P0A4A<0410B00h>400>30l040hA
00l=40804@`@00T04PdA01@>4P0C3Q804a0A00T720081PL03@/<00l=3P091`P01P0?3@h03@0>30d0
40h?00h<3@0=2``040h?01<A4P0B4140518C01<A4P0?3@h040h?00l=3P0=2``00P0?3@h02`0>30d0
3`d>010>3`0;2@X08b4R00l=3P0=2``02@L8010=3P0B3Pl03@T:00803`/<00D02`L801<?400?2``0
3PX;018>3`0200h:2`0K010>3@0J6AL0I6=Q00l>300:2@P061LE00X91`0@3`d05QDC00/:2@0?3Pd0
;Rd[018A3`0<2`T03Pd;00l>300@3`d05A@B01HE4`0I61H04Q4?00T81P0<2`T03`h<00P8200C4a<0
2`/;00803@d=00`0:BTY014A4@0;2`/03@d=00l?3`092@T030`<014A3`0;2`T01`L500d=2`0<30X2
00h=2`0:00l>300?2`X0510?01`H5`0G4Q8040`;00h=2`0?3P`03Pd;00d<2P802`X803`051<A00`;
2P0>3@/03`h<00d<2P0@3`/03@`900X91`0920H02`X900d;300>30d030X<00d;3P0?3A003P`@00T7
2`0D3a<03PP;00`92@0E4Q802@T701DE4`0?41002@/<00/>4`072a803Q8L00/>5@0:2`h02`/;00T9
2@0>3Ph0410A00`<3P0=3@l03@`A00`;400:2Ph020L=00l>500<31002PP;010>3`0=2@T040/800d8
1@0?2PL03@T800/91`0?3a403@dA00P8300<2Pd02PP;00/9300>30l03@/>00`:3@0=2`h200/93004
014?4P0:20/03@/>00d;3P8030X=00D04Q0C00h<3`0;2@`02`T<00`:3@0200h<3`0C00`:3@0<2Ph0
2PP=00X83@0?3A802`T>01lM8P0@3Q<02@L<010>4`0T8RL0BTQ=010>4`0?31403`X@01`G7@0B3Q<0
4PdC00h93`0200d83P0:00h93`0@2a403PT?00h93`0?2Q003PT?014<4P0=20h03@T>014<4P803PT?
02D03@P>00/6300A318040/A00T7300G5AX061HK00/93P0=2a003P`A010>4`0920`020H;018@5@0<
2Pl04Q0E00L5200A3a801P@7010>4@0=2`h03Pd?014?4P0;2@`02PP;00h<3`0=2`h02`T<00d;3P09
1`X02PP;00h<3`0;2@`030X=00T72P0C4A@0:BLZ008030X=00<03P`?00l=4P0=2a000P0<2Pl01P0=
2a003`dB010>4`091``03`dB00/93P8030X?01@030/@00T83@0?3Q<01PD:00l=4P0:20d03P`A00`9
3P0@2a403`X@00d73@0?2Q003PT?00`:3`0=2a0030X?00/93P0:20d030X?00d;40803P`A0P0?3A80
3P0=2`h02PP;00l=400>30l02`T<00h<3`0<2Pd02@L:00h<3`0C4A@01P@700/9300>2@d040/?0P0A
310200h93@0400l:3P0>2@d03@P<00d830<030L;00P02@@800h93@0<1`/04@`@00X62@0<1`/03@P<
00`72`803@P<00h02`H:010;4@0<1`d04PdC00/6300F4AL02`L<00d83P0?2Q0040/A00l:400=20h0
3PT>00h93@<030L;1@0>2@d01P0=20`030L;00`7300;1P`03PT?018=4`802`H<014040/A024L8P0A
318030L=00d83P0B3A<03@L?010:500B31H04@/D00h9400?2Q404@`C01@?5@0L5a/040/?01@?4`02
00h93@0400l:3P0A31002@D800P31`803@T<00D050lC00d8300J5AT01@4400h93@0600l:3P8030L;
0P0=20`0300>2@d03`X>00/7200@30d02@D6014=3P0B3Pl03@T:00/7200<20T03PX;00l;308040`=
00h03P`@01PF6`0F51T030X?00P62`0>314020H;00`:3`0E4aP0108703/j?P0a;c8040`=010<2`80
3PX900D06QHE014=300=2@P040`;00l;2P0200h:2@0G010:2P0G3@h04@L801<92`0B2@d091hT00`9
3P0?31@030/E00l@70082QL0G5m/0453C`0?3A403@`>00/92`0:20X05Q@F00l=3P0>30d03@/<00`:
2`0=2``00P0>30d0100=2``030X;00/92P0<2P/200d;3004018@4@0?3@h03@/<00h<3@803`d>00<0
3P`?00d;3P0<2Pd00P0=2`h01`0>30l03@/>014?4P0<2Pd04Q0C00h<3`0@3Q400P0?3A00400H5QT0
3`d@00/9300?3A004@lB01<A500>30l02`T<00h<3`0B41<02`T<010>4@0N71l03`d@00T72P0?3A04
00h<3`0a00l=400>30l03`d@014?4P0?3A003P`?014?500H5A/05Q<J00/83`0@3AD0514J00d:4`0>
31<04a8H00/:400Q82H07ahT014@5P0B4AL04A0F00l>500@3aD03`hD00d;4@0C3Q@04`hB014>5@0@
3aL03`lG00h@6@0=41T03Q0I014@600B3aH04a4F01DA5@0A3QD040lE01<B5`0E51T05QDJ01DE5`0G
5aT0410B01@D500E5AD03`l?01TI6@0201@D5P805QHH00X05ADG01@D5P0M7Al05aLI018B500C4aD0
51@F018B500H5a`05A@I0P0D4aP03@0C4QL040lD01@C600G5Q/05QDJ018A5P0A41D04a8G01HD5`0E
4aH061HI01/I700I5aX00P0C4A@04@0B41<04a4D01DC5P0E4aH04a4D014A4`0T92H05QHH00h>400H
5aT04Q0C01`J7@0E4QD05A0D01hI7@0P6Qh07QPL008061@E00D05A4B01@@4@0J5QL07a/L01@@4@02
01<?4004018>3`0@30d040`;01@@3P805A4@00l0510?014=3P0@30d0EE5B01LB5P0D3a<03`X>01PC
6@0I51P0>cLi01TE5P0D41406ADF010<3@0E4A800`0B3Pl0100A3@h03`/<010;3`0A318301<>5080
4@`B00l06aHL010;4@0@2a403`X@01PC6@0=20h06a@K02<L8`0B2a803@H=018;4P0D3A@04``C018;
4P0@2A000P0>1`h00`0>20h03PT?00h93`02010;4@0400h73P0?1Ph04@L?01473`<04PL?00P050T@
06=HGP0H3A<04`P>00`11`0B1`d050T?00d420805@X@0P0@1@/70146300S00/01P0D2@l091TO01lD
6P0B1`d04PL?01463P0@1@d04@H>01053@0>0`/050TA00X01`0O51`05P`C00h32`0?1@`03`D901@9
3P0>0`P04PD<00d31`0E2`l03`8901442`0@0`X03`8901032P0A10/03`H:0146300<0PL03`@:0146
300>1@T00P0>0`T200l42P0301052`0A1Pcooooo01?ooooo000Kooooo`0500T92`0E5AL00002014A
4`0;2`d00P0A4A<02@0P82800`<501<C5@0@418061PJ00`:2`0>30d040h?014?4002018@4@H040h?
00L03@d?00h>400=3@l02`/=00`:3@0>30l030X=00803`X>00T040/?014;3`0@2`l09B8S01<A4P0?
3@h04Q0A01DC500B4140200=2``200`:2`0500h<3@0@3Pl040h?014?400@3Pl00`0>30d200`:2`80
3P`=00@02`T:00d;30071@H061HG0P0?3@h02`0>30d03P/<01XF5`0G4a@03`/<018>3`0@30d04@d>
00d92P0>2P/04`l@008040`=00d040h=00X91`01000030/900L6100H5aD04a8@00@30@0510804A0>
00l>300g=S@07QdK00802`X801X03@`:00l>300A40h02PT700d<2P0<2`T02@P600/:200=30X020P8
014B500<3@l03PlA01PI6`16AdT03@h@00l@4P0>3a4030d?00d>400@4A8030`:010@3P0M7A/02PX8
00d=2`802`X800H030/900d9200A3@`05a<B01@?3P0A3@`200h=2`<03@`:00P00@00034`;P1AD4h0
0@0000l>300P7ad04A0<00l>2`803@`:02d03`d=010>3`0?3@h03@/=00d;3P0>30l03`dA00`:3`05
0`P03P`A00X:30030`D06a/K00840`0?4A001PT:00`?500>4AP05APP00/>5@0:2`d04Q8B02@T900>
3Ph020P900d=3`0>3Q001`H;00D42@0@3a@00P4701XI7`19Ad`061<G01LC500?2@X04`h;01`G500G
4Pl0510?00h=2`0;2`d05aPL00@52@0>3@l00P0=2``01@0?3@h03@/<00`:2`0=2``03P`=00802`T:
02T01P@500d;300>30l040hA01<A500:20/040hA00D31P071@P030X=014?4P0?3A003@/>00d;3`0;
2@h04Q0E00`;3`0B41D0<S0e00h<4@081P/03`dB01<A5P0_;C803`dB01DC600100@0JVQ]02XX;@0F
51T00`4600d;400?3A804@lD00T7300;2@h02PP=00T52`0=20h050lE01PC6@0200/6300400l:400>
2@l03PT?00/630803`X@00@02@L<01<A5P0D4QL02PP=0P0;2@h0300:20d03@/@01DC60030@H03`dB
00D3200F51L02`T<01<A500:20/04@lB00l=40802PP;01003P`?00d;3P091`X03@/>010>4@0>30l0
4Q0C014?4P0=2`h03`d@01PF6@0;2@`04a4D00l=400J61/03P`?0P0<2Pl200/93P8030X?01<04a4F
00T7300?3A803@/@00X83@0M6b005QDJ00l>4`071P/02@P=0040100N72403@/@00/83@0?2Q0040/A
00h83P0@2a403`X@00<03@/@00<030X?00/93P0?3A800`0?3A8200h<4@0=00T72P0;2@`03@/>00T7
2P0>30l05A<F00d;3P0>30l05aDH020N8@0:20/01@<600d8300300h93@803@P<00@030L;00d8300=
20`03@P<0P0>2@d01P0F4AD061<G00<00P0;1PX03PT=028M8@804@`@0P0B3A40200A310040/?00l:
40060@L05a8H00`73@0C3Q@03`X@0P0>2@l0100?2Q003PT?00h93`0>2@h200d8300300`72`0=20`0
3@P<00@03PT=02H03@P<00`72`0=20d03@P>00l:400A31803@P>00l:400;1``05A0F00`73@0@2a40
3`X@014<4P0;1@d03@LA00l94`0>2A4030L>00d83`0?2Q003@P>014<40080`L040/?00`72`0;1P`0
4PdC01<>500N6Al03@P>00X62`0C3Q@02@@:00d93P0E41H06QDK010;4@H03`X>0P0>2@d300d8300:
00`72`0>2P/030P9010<3@0S7b006ADF00X61`0;1`P030P900h:2`<03`/<00@030X=00P62@0610L0
2PP;0`0=2`h08@0:20/06QPK014?4P0<2Pd02`T<010<3@0;1`P02PH701TE5P0K5aP030P900X61`0?
2``04Ph?014=3P0=2@X03@L901P?400C2P`0618D01@>400=2@/03`X@004010071Pd02PXD01@D7P04
1a4051@N00X83P040PL07Q`Q018@500200800`0400/9300:20T02@L800X82@802`X80`0<2P/0100>
30d03`d>010>3`0?3@h200h<3@803@/<00@030X;00h<3`0=2`h030X=0P0=2`h200h<3`0>01<A5001
008020H901DC5P0?3A0040hA00l=400F51L03P`?00/9300A3a804Q0C010>4@0>30l200`:3@0700/9
300=2`h07A/N02TW:P0B41<02@L:00d;3P0200`:3@0H00l=400B41<0518E018@4`0=2`h02`T<00X8
2`091`X02`T>018?5@0D4AP04@hE00X73`0A3QL0514J00`:4P0D4aT030/A01LF700D4aT040lE018A
5`0A41H03`hD0P0@3aD0100>318050lE01@?4`0C3aH2014@600C010@6P0?3aT0410J014@600C41L0
5A0F01H@5@0=2Q405A@J01LF6`0@3a@04Q4F00l?4@0B4Q@03Ph@018B4P0E5AD04Q8B01/K6`0201@D
5P805QHH00X05ADG01@D5P0D51H04a<E018B500D51H05ADG01<C5@0H5a`05A@I0P0B4AH04@0@3a@0
30/@01@C600E51T051<H018A5P0A41D04Q4F01HD5`0C4A@06QPK028P8`0O7B004Q0C01@B5@0C4A@0
518E00805Q@G00/04a4D018B500A4A<0410B01@D5P0G5QT03`d@01TG6P0G51L050lC01<>4P0201@>
4P0701LC500F4Q<0510A01@@4@0L61T08QhO01@@4@0201<?4005018>3`0A3@h04@d<01<?3@0B3Pd0
0P0A3@`2018>3`0>01hJ6`0:1@T05a8F018=4@0A31804`hB00h9300>2P/061@E00/7200=2@X00`00
00h:2`0?2``3010<3@04010<3`0@2a4040/A00l:408040/A00L050lE00P32@0A3180:RD[00P32@0@
2a403`T@00806Q<J00@04@XA018;4P0A2Q403`P?0P0A2Q405P0@2A003`P?00l83`0?2@l03@P>00`7
3@0>2@l04@`B018;4P0@1`l03P@<00l53@0B1`l050TA01D:4P0C20l040D;0148300;00H03P<900l6
2P0F2a4200T0100301P=4`0I3Q@03PD900H04@H<00P04PL=01052`0>0`T02P0500T0100A1P`04`P@
01053@803@8:01X03P<;00l4300<0@T01`0401`A6@0G31@01`0401<8400I31<040<:01L:4@0J3A@0
50L>00`01P0>0@P040<:01442`0@0`X04`H=01H9400<0@L09a`R03H[<@0B1`d02P45014630<03@88
0`0>0`TDooooo`006oooool02@0>3Q0030`>00410`0=3@l04A4C00P82P0:2P`04A4C00L72@0201LG
6@04024Q8`0=2``03P`=00l=3P<040h?00<03@/<00h<3@0>30d00P0>30d0200=2``03@d?00h>400=
3@l030`>00d;3P0>30l02`T<0`0=20`0200>20`03@P<014>3`071@H02PP900h<3@0=2``02PP92P0=
2``300h<3@0300l=3P0>30d03P`=00803P`=02@030X;00d;300@3Pl04Q0A010>3`0A3a0020H700l=
3P0=2``030X;00l=3P0@3@h09B4R024M7P0@30d04Ph?010<3@0=2@X030P900l;300C3a004Ph?014=
3P0B40l051<A00<2000G5Q@00@0000h=2`0920H01@@200/:200@3`d02@P601HE4`061@@300`;2@03
010?3@0?3P`03@`:00803`h<0P0=30X09`0<30X02@T;00h?4@0<3@l01@H800H72@0J6ad01PL901<D
5P0720X010D700P92`072@T06QXJ00@40P0820H00P8001DE4`0A40h040l=00h=2`0>2PT03@T800h:
2@0;1PD04Ph=00l>300=30X030/900h=2`0?3P`06aXH00/:2@0T8b400@0000h=2`0K6QP040l;010?
300200h=2`0400l=3@0@3Pl03`d>00d;3@8030X=01l03P`@00h<4@0A41H01`P=00h?4`0[:Rl0GUmQ
00P:2@0?4A001`X:00`@4`0;3Q<05QPO01@E6P0>3Q006ATI03dm?@0N7Qh03Ph?00T92`0V9RP09bH[
0000100D4aP02PT?00T83P0F51T01`8601<?400C3@h03@P5008020<000H020@3014A3`082``02@d@
01DF600?3Q0200d;300W00h<3@0<2P/02`T:00l=3P0:20T01P@500/92P081PL03P`=00D31P0B41<0
20H9010>4@0Y9bX00P0300/9300>30l03`d@00d;3P0:20/03@/?00l=4P0>31402@L<00P62`0M6b00
2PP=00d;400A3a@020H;014?500100@030X?014?500100@06ALL00d;400B41D01P@900803P`A01<0
2@L<01DC600A3a@02PL<00X52`0A3180:bH/028M8`0B3A<02`H<00d83P0?2Q003@P>00l:400=20h0
108700/93P0=2a002PP=00803@/@00/05Q@I0040100D4QL06QPM01@B5`081`/02@L:00L5200E4aH0
3@/>00@21@0200h<3`0500d;3P0@3Q403`d@00/9300<2Pd00P0;2@`02P0@3Q404@lB00h<3`0B41<0
5aDH00H41`0=2`h030X=01PF6@0;2@`600/93P0C00X83@0A3a@03@/@00X83@0?3A80;B/`010?5001
00D02`X?01LF6`0C4QL03`dB00d;400;20d03`X@010;4@0>20h040/A00l:400300h<4@0400d;400;
2@h040hC00l=4P803P`A00<03@/@00`:3`0;2@`00P0<2Pd200X82`0700`:3@0?3A002`T<00d;3P0F
51L02PP;00/9300600d8308030L;01H03@P<00h93@0>2@d03`X>00D1100;1PX01@04014<400?2Ph0
0`0200`72`070PH04PdA00`72`0500@040/?00h93`070PP04@`B00P32@0C3Q@03@P>1@0>2@l00`0>
2@h03@P<00d8300400d830<03PT=01803@P<00`72`0<1``03@P>00h93`0?2Q003PT?010;4@0G4QP0
9R4W01<>500?2Q002PD;010;4@0<1`l03@LA00h84P0?2A8200d83`0B00d83P0@2a406A@H00h93@0@
2`l01`8601@?5@0910X050lE059=D`0M61h03`X@014<4P0300@03PT?00<0100?2Q0030L=1P0>2@d0
100?2Ph03PT=00h93@0=20`200`72`08014=3P0<20T04Ph?02<O800E4A803@T:00`82@0=2@X400l;
300c014?400;2@/020H700/9300=2`d02PP901HD5`0=2`d03@/<00h<3`081PP05A<D00T51P0?2``0
30P9010<3@0=2@X03PX;00/7200?2``04@d>00l;300>2P/03@T:00`61P0@2P/00`0000`6200E4A<0
0`0200<1100D4QP01@@:014@5P0?3aH05aLO00d;4@0C4AH00@0401HD6@0100@081hQ00/9300:20T0
2@L800X82@0:2@L02`X8014?400?3@h03P`=00D03@/<0P0>30d200`:2`0300h<3`0=2`h030X=0080
3@/>00L03P`?00`:3@0>30l05Q@G00l=4029QhX0;bd`00802`T<00D040hA00/9300:20/03P`?00d;
3P0200/9300S00`:3@0;2@`02`T<00X82`0@3Q405Q@G00P62@071@P03@/>00`:3@0=2`h03`d@01<A
500E4aH0518E014?4P0@3Q404@lB018@4`0D4QL030T?01<@5`0W92/04PlG00/84@0G51d03`dE014@
5P0920h02`X@00T83P0?3Q@04a8H014@5P0?3Q@00P0@3aD01P0?3Q<050lE01D?4`0D3aH04PlH014@
60<0410J01004Q0I01D@5`0E41H05a4F01DB6@0J6Al04a8G00`;400C4QL04A4C018B500?3a404Q8B
01DE5@0D51@06ATI0P0C4aD301@D5P0901<C5@0?3a404A4C01<C5@0E5AL05QHH01@D5P0J6Ah05aHK
00805QDJ00<051<H014@5@0C4QL00P0C4QL3014@5@0M01HD5`0D4QD05aDH01/I700H5QT03`d@01DC
5P0D4QD05A<F01LE600F51L04a4D01`L7P0C4aD051@F01LG6@0C4Q@03@/>01DC5P0H5AP061<G01D@
500H4QH06aDI01PD5@0I5AH05A4B00l;300A3@h00`0D414201<?400C018>3`0A3@`03`/9010<2`0A
3@`05Q8A01XF5`0L61T03@T:00d8300L5a/050lC00l:400E41@05Q8D01DA4P0X92D03`/<01PD5@03
010<3@804@d>01@040`=010<3`0@2a403PT?00d83P0>2@l040/A01<>500300@08A`R06]VK00L5ad0
1`8801<=500?20l02P<:00d63@0G41L04@XA00/52`D040T@00L04@/B00l:400<1`d03@P>010;4@0A
2Q404@T@00804@L?0`0B1`l0300D2A001`0201D:400?10X05@X@01052`0B1`d06a0F01L<4P0?10X0
1`02014630L040D;00P04PL=01@93`0@1@/03@8801052`0<0@T03P<;01@94@806@hF00<050TA0146
3P0?10`00P0>0`/201D:4P0702`O9P0800802`0500P00P0C20d0200200l22@0201032P0900l22@0B
1@`05@P?00L00P0e:S00CD9801dB600?10X0200300H03@885?ooool001_ooooo01004a<E00/;3@0I
6A/01`L900/;3@0A4A<05QHH00d=3`0820X04Q8D00l?4@0@418040h?00l=3P0=2``030X;0P0;2@X0
100>30d03`d>014?400A3a0200h<3@0700d=3`0?3a403Ph@00d=3`0?3A004@lB00l=4003014<4006
014;3`0@2`l06QLH00`:2`0?3@h040h?0P0>30d600l=3P07010>3`0?3@h040h?010>3`0>30d03@/<
00h<3@0200d;30803`d>0`0@3Pl0@P0?3@h03P`=00l=3P0@3Pl02PP900h<3@0M6a`04Q0A01HD5@0<
2@X07QXK01/G600=2@X040`=00h:2`0=2@X03PX;014=3P0B3Pl04`l@018>3`0D4A4010<201TH5P0<
2`T04A0>00l>300A40h03Pd;01<B400m?3X051<A00X9200>3@/040l=00h=2`0?3P`05A@B010?3@0>
3@/030/900h=2`0@3`d03`h<00d=2`0=3@l02@X<00`=3`082@/02P/=00L82P0=3Q00<S<e01DF600F
5aT01PL901PJ6`2<S8`0<c<a00/;2P0<30X010@300d<2P0;2PP02PT700h:2@804Ph=00<050l>014=
300?3P`00P0>3@/2010?3@0800/:2@0?3P`02PT700d<2P0<2`T04A0>00d<200=30T200d<2P0]00h<
300>30d03`d>00h<3P0;2@`02PP;00d;3`0@3aD03a4I014D7@0<3aD020T>01<F600<41403@l>00`>
3P0>3a801PH:018A5`0J6Al03`lA00L71`0J6QX02@T900h>3`0D51H0<C4c04E4B@0A41D02`X?00T8
3P0A41H030X?018=4@0@30d05A0@024I5`0G3`d03PX700X81P0@40h0=cXk02LZ;@0U:BX03Pd?0080
30X;01003@/<00`:2`0;2@X03@/<00`:2`0B41407Q`M00d;30071@H030/=00l>400A3a807adP03<a
=00F51L03@/>0P0;2@`02P0<2Pd03P`?00d;3`0?3A801@<801PF6`091``02PP=00l=4P0<2Pl200h<
4@0C00h=4@0:20d06QPM07ilP@14@TL0<2hc010>4`091``030X?00l=4P0:20d040hC02<Q9P0N7240
3``A00/6300B3A<07aXP01<>500200/63006018=4`0E41H040/A00d83P0:1@/03@/@0`0>31408@0@
3Q<03`dB00X83@0`;S<0?3Xo00d<40091``040hC00h<3`0F51L02`T<01DC5P0610L0@Cm201TG6P0@
3Q403P`?018@4`0@3Q402`T<014?4P0=2`h030X=00d;3P0:20/03@/>01@B5@0;2@`06QPK00l=400C
4A@04@lB00/93P0400`:3`0D00/93P071@X04@lD00H42@0B41D03@`@00`:3`071P/06QXN018A5P0;
2Pl0<Bld010>4`0<2Pl02`L=00l:400@2a403`T?014<4P0?2Q0300h<4@0400d;400;2@h03@/@00d;
408030X?0P0;2@h03@0=2`h030X=00l=400F51L040hA00H41`0;2@`03`d@00X82`0<2Pd02@L:00h<
3`0>2@d00`0=20`200h93@0300`72`0=20`03@P<00803PT=01<03`X>00h:3@0C3Q803PT=028N8@0J
5AT03@P<01D@500K5QX03`X>01@?4`0H4aL030L;00l:400A31803PT?010;4@0V8BL040/A00D03PT?
00@03PT>00d8300=20`03PT=0`0=20`300h93@0?00d8300<1`/02`H;00h93`0?2Q0030L=00d83P0?
2Q005A0F02@O9@0A31803PT?00P32@0=20h03PTA00803PPB014040XC010;4P0?2Q403PT?018=4`0K
5QX03PT=01<>4P0D3a<040/A00`73@0B3A<0>C@j01PC6@0=20h050lE03@_=@02010;4@0300P42@0@
2a403PT=00D03PT=00<03`X>00h93@0>2@d00P0=20`01`0<1`/040`=010<3@0?2``0510A00X61`0B
3Pl00P0=2@X300l;300F00h:2`0;2@T03@`;00d<2P0;2PT02PT800`;2@061@@03`h<00T81P0A40l0
40l=00`;2P0>2P/02`L8018>3`0=2@X040`=00d92P0>2P/03`/<00h:2`803@T:01@04@d>00h;300@
3@h040h?00X7200G5AH04Q0A014?400=2`d030X=00H41`0@3a8020L;00/8400E4QT02@H=01@B6024
PXL0EUAI00d;3P8030X;00H030/900d<2P0=30X03`d>00h<3@0=2``200h<3@0500l=3P0;2@X030X;
00h<3@0?3@h00P0@3Pl00`0>30l03@/>00`:3@0200d;3P0300h<3`0=2`h04@lB008030X=00@0Cde@
01lM800>30l03P`?0P0A3a802`0B41<040hA00`:3@0;2@`03@/>00l=400@3Q404a4D00h<3`0;2@`0
3`d@00803@/>00<040hA00l=400?3A000P0@3Q40;`0B41<040hA010>4@0A3a803`d@00/9300;2@h0
3``B01XG7P0T8BP04a0H00h;500E4Q/03@/B010?5@0C4QP051<I00l>500=318051<I014@5P0?3Q@0
40lE014@5P0A41D04PdC01<=4@0B3A@040dF010>5P0?3QP04A4K014@6`0C4AT05Q4H01HA5`0G4AL0
4PlF014@5P0@3a@04Q4F01HE6P0@41805QHH01@D5P0D51@05ADE008051@D00<04A4C018B500C4aD0
0P0C4aD00`0B4Q@03Ph@018B500401DE5`0301LF6`0F5AX05A@I00805aHK00@05A@I01LF6`0F5AX0
5A@I0P0F5AX0200E51T04@lB01DC5P0E4aH04a4D01HD5`0J61/05Q@G0P0E4aH01@0G5AP05Q@G01<A
500C4aD04A4C00805QHH00T051<E01LE600A3a805Q8F01HA5@0C3Q805@lC01PB5P0F4Q<00P0L61T0
0`0H51D05a<D01PD5@0401@@4@0601<?400C3`h05a<A01@@3`0C3`h04@d<0P0B3Pl04P0D41404`hB
01PC5`0@2`l03`X@01HA5@0C3a40:bLX048n?`0A3@h02PL7014=3P0D41405A4B01@@4@0B3Pl040`=
010;3`803`X@00X03PT?00l:400?2Q0040/A01lJ800@2a404`lD00d93P0>2@l04@/A0P0D3A@0100@
2A003`P?014:4@0A2Q4401094008014:4@0D3QD04`hD00l:400=20h03PT?00l83`0@20l201473`08
01873`0C21004PL?0106300D2@l04`T>01D:400F2a4301052`040147300D2@l05``B014630H040D;
0`0?10X00`0@1@/04`P>0146300201463P0@01D:4P0H3AD06@hF01H;4`0=0PX03`@<00l5300C2100
3@@:01483P0D1`h03`D90185300M41L04@D;01D83`804@@;00X03P4800`01P0?0PT04PD<01<83P0:
0PD0=BX`02/R9P0F31403@@80`0>0`T300d221Cooooo000Kooooo`0500@41P0D51H02`/=03`l?P0F
5QP00P0<30h200h>400;00l?4@0=3@l02@T;010>3`0>30d030X;00/92P0<2P/03@/<00h<3@0@3Pl0
0P0B41400`0?3@h03P`=00/;3@0200d=3`0400`<3P0>30l040hA00h<3`803`X>00T03PT=00h8300=
20`06QLH00X82@0?3@h03P`=00X82@0<2P/01P0>30d03P0?3@h03@/<00l=3P0A3a003@/<00X82@0>
30d030X;00d;300A3a0040h?00h<3@0@3Pl04@l@0P0<2P/03P0D4Q<06QPI014?400;2@X06ALH00L5
1P0D4Q<02PL8018>3`0=2@X03PX;010<3@0=2@X04@d>0P0B3Pl05P0>2P/04Ph?018>3`0?3@`04A0>
03Th=P0@3`d02PT700/:200E51807QdK00l>300<2`X02PT701@C4@0;2PP03@`:00l>300F5A<08B0N
01`K6@0A40h200/:200G010?3@0=30X030/:018C5@072`h02`lB00<72P0<41<02`lB05=GFP3MhN@0
JVia014E600@51L020/=0000000=3@/05ADC00/;2@0:2PP02PT700h=2`0:2@L00P0>2PT01@091@@0
30L700l;2P0>3@/03`h<008040l=00T03`h<01HE4`0>3@`07ahL00/:200<2`T040l=00/:1P0<2`P0
0P0=30X0<P0=30/03@/<01<A4P0A3a403@/>00/9300?3A405A@J028V<@1<Deh06QhW01<H7P093A40
5ATJ00`>3@0<3@`03`l?00L5200=2`l040hC00L72@0<30`04a<C01@D500D51D04Q8D00/;3@071P/0
10<800d<4@081`d030/A00D21`0D3Q80618D018<3@0C2`T02000018>2`0:2@L01@D3024S9@0<4A@0
10P900d<3P0<2P/03@/<00l=3P0>30d03@/<0P0>30d02P0B41407A/L00`:2`081PL05aDH00h<3`0B
41<040hA00`:3@0>30l200X82`0G00/9300=2`h03`d@010>4P0E4aP03@/@01`J7`0<2Pl02`T>00h<
4@091``01`D:01DC600A3a@03@/@00401016A4T06aTN00X93@0C4AH06aTN01DC600C4AH00P0<2Pl0
4@0>31402PP=00d:3`0E41H061<I00h93`0500H02`H<00d83P0?2Q0040/A00/6300>2@l05Q4G014?
500=2a002PP=008030X?00D02@L<018@5@0:20d03`dB01HD6@0200`:3`0900<1100:20/02@L:00d;
3P030@@06aTL01DC5P0>30l02PP;00803@/>00l03P`?02<Q900H5QT03P`?014?4P0@3Q403`d@00P6
2@0100803@/>00D31P091`X02PP;00/93P0=2a000P0>31406`0=2a002`T>00`:3`0;2@h01`D:01HD
6@091``0:2H[01@C601DDeP09RDZ01TH7@0=31400@0400/93P0:1``03`X@010;4@0?2@l04PdC00h9
3`0<2Pl03@/@00`:3`0;2@h02PP=00/93P0400`:3`0D00d;400:20/03@/>00h<3`0F51L04a4D00T7
2P0<2Pd040hA00X82`0>30l02PP;00`:3@0@2`l03PT=00d8300>2@d03`X>010;3`0>2@d300d83080
30L;00d061<G014<400Z9BT0Yj:V018=4@0;1PX040/?01PC5`070PH03PT=01@?4`0300803`X@0080
3PT?00@040/A02DP9P0A31803`X@0`0=20h00`0?2Q003PT>00`72`0300h93@0300`72`0=20`03PT=
00803PT=00D03@P<00`72`0;1P/04@`B01<>500200h93`0G00d83P0910X04`hD00L2200?2Q002@@:
00h93`0>2A403@LA00`6400>2A4040/B00d83`0;1Pd01`8800/62P080`L05A0D01<>4P0;1P`040/B
00d83`0500L00P0;1Pd01P0Q72<0=C0g024L8`080`X03@P?00X530H03@P<0P0<1`/300d8300900h9
3@0;1`P04@d>00`82@0?2``03@T:010<3@0=2@X03PX;00803`/<00@03PX;00d92P081`D02@P40P08
1`<0100;2PH03`h:01@C3`0?3PX200<2000900P70`030P003PX;00T51P0Q7Ah030P901<?40060P<0
30P900803`/<0P0>2P/0500?2``02PP;01/K70000000<C4a0;:a/00I61H05QDC00`9200J5QD05Q8A
00X61@0;1`P03@XB00l<5@0B3aP030T@08b:S`1<BTl03P`?0P0<2P/00`0<2`T03@`:00h=2`0300/9
2P0600d;300>30d03`d>01<A4P0@3Pl03P`=0P0<2P/0100=2``03P`?00d;3P0<2Pd200d;3P0;00h<
3`091`X04a4D00D31P0H5QT00@0201TG6P0?3A003@/>00/9300=2`h00P0>30l0100?3A004@lB00l=
400>30l2014?4P0600d;3P0?3A004Q0C00d;3P0;2@`03@/>0`0>30l07@0?3A0040hA01@B5@0P7R40
9bDX020N8@0E4aH0518G018?5@0;20l0104800X73`0B3aP040dF01@B6P0@3aD03PdC00T83P0=3180
4a8H01@C6@0A41H03PdC010?5@0A41H04a4G01@=500D3Q804`hE00804@hG00`040hI018@6`0B41/0
514J01HA600F4AL0618G01PE700C4QP051<H014@5@0;2Pl201LG6@0701HF600D51@05ADE01DE5@0A
4A404a<E01@D5P0301DE5`0401@D5P0B4Q@05QHH01HF608051@F00P05ADG01@C600C4QL04Q4F01<B
5`0D4aP04A0E01@C60804Q4F0P0D4aP00`0A41D040hA01<A500201HD5`0301TG6P0M6ah05A<F0080
518E01805A<F01@B5@0@3Q404Q8D01@D5P0B4Q@04A4C018A500?3A005Q@G01TE6@0I51P05a8F01H@
500G4AD06ADF01/G600H51D2018>3`0301DA4P0D4140510A00<0510A00D0510?018>300B3Pd04`l>
018>3@02014=3P0901LC500@2`l04@`@00l:3P0A31804PdA014<3`0<20T03PX;00805A4B1@0C3a00
0`0A3@h040/?00l:4003010;4@803`X@00`040/A00@01@0910X01`8801HA5`0H4QP03`P?00H01P0>
1`h05@hE00h73P0;1@/50109400301<=4`0B3A<03`X@00803`X@00@03`P?01073`0A1`l04@L?0`0B
1`l0300@1@`04PL=00l52P0F2a402P0501873@0N4aT0>Rle05A9C`0?10X01`0201H;4@H03`@:00@0
4PL=01<83P0?10X03P<90P0D2@l00`0A1Ph03`@<00h32`0201053@0=00l4300E2Q804`P@00l4300G
31@03@8:02dR:P1MD5L04PD<01H9400A10/0?C0g03HY<00201442`0;00d01`0<00H03`8901D83`0B
1`d02@0401T>500C20h01`0201<83P0@1@/00P0?10X200h32@0300d22?oooooooooo01;ooooo000K
ooooo`0>00l>4`0820/0BDU;0<[9cP0N7B404a<E00T83@0C4QH03`lA00/:3`0=3A003@d?00l=400>
30d200`:2`0400l=3P0@3Pl02`T:00h<3@8040h?00T03@/<00/92P0:2@/03@/>00/;3@0;2@`03@/>
00l=400B41<00P0C3Q801`0B3A404P`@014<400@3@h02`T:01PF5`0I5aP00P0A3a0600d;300a010<
3@0>2P/03`/<014>3`0>2P/020L500l=3P0<2P/03@/<018@4P0A3a8030X=00`<300A3a003@d;010@
3P0N7AT0;RhY02<T7`0>3@/040l>0000000G5AH04Q0B01<?400=20`04Pd@010<3@0<1`/04@d?01<?
400B3A403@T;018>3`0B3A403@X:01LF500d<c408B0N018A3`0<2`T040l=00d<2P081`D04Q4?00D4
0P0A40h03Pd;010?3@0200`;2@0S01@C4@0920H06APF014@3P0>3@/040l=00/:200920L020T;00<4
1P0?41801@H800l@4P0A4Q@0ATM90>c]k`1bLgD03@h@00H72@0=3Q005QHF00l?3@0410803Ph<00/;
2@0<2`T03Pd;00d9200A3@`04Ph=00l92@0C3@d03PX900d<2P0@3`d00P0A40h0900?3P`00@00014@
3P2AT8h0B4M500l>300>3@/02`X600`;200=30X03Pd;00h=300>30d05A<D01@B4`0?3@h030X=014?
4P0H5ad0TIFP0=CIgP0h?4D04aHM00d@4`0620L02`d<00T:2P0@41802`T<00d;40050`P02`/=018B
4P0:2PX03Ph>00d=3P803@d?01@04Q8D00h>400:2@h02`X?00l=4P0C41D03PT?01@?4`0=1`T040X:
014;2`0?2PX04@l@01TI6@0720/0004401@E6@0>3@h03@/<00h<3@804@l@01<03`d>01@B4`091`P0
108300d;300:20T040h?00`:3@0A3a801@<600/9300?3A0040hA00`:3@0=2`h03P`?00`:3@0;2@`0
20H:008030X?00<0518G00l=4P0F51T00`0;2@h0400@3Q<01P@9014?500=2a005aDJ00H42@0D4QL0
0@04020N8`0;2@h03@/@00/93P0=2a002`T>00h<4@0D4AH2014<4P0J00d83P0A318040/A00T42P0A
31804PdC00l:400L5ad0;RT_01<A5P0>314030X?014?500B41D040hC00`:3`0I5a`030X?00D3200D
4QL02PP=00`:3@071@P03P`?00L5200?3A0200h<3`802PP;01402@L:00P62@0B41<081hQ018@4`07
1@P03@/>00l=400>30l040hA00400P0:20/02`T<018@4`0@3Q4030X?00d;400200l=4P0300d;400<
2Pl02`T>00803P`A01003`dB00h<4@1/JVl0WifR010?500D4aP02`T>010>4`0C4AH02`T>00X6300?
2Q0040/A00l9400B3A<03@P>0P0<2Pl200/93P0300T7300;2@h030X?00803@/@00l03P`A00l=4P0:
20d03P`@00X82`0=2`l03@/@00L5200@3Q802PP=00800`0=2`l030X?00d;400?3A800`0<2Pl0900>
31403`d@00d;3P0>2@d03@P<00d82`0<20T02`L800h93@0=20`04`hB03Td>00C3Q806A@H010;3`0<
1`/050lC00h93@080`L03`X>00h93@060@L030L;00D11@0C3Q@03@P=00l:3P0=20h030L<00d8300?
2Q003PT=00`72`0>2@d03`X>00h93@8030L;0`0>2@d03@0=20`030L;00`73@0C3Q@05A0G010;4@0?
2Q003@P?00`73@0G4QP020<:00h9400910X00P0A31<0100;1Pd02P@>00d83`0?2Q4200`73P0A00T4
2P0>2@d050lC01hI7@0>2@h04PdC00P32@0;1Pd04PdD010;4@0A318020<:01HA5`21O8<02PD<00l:
400A31801P0=20`06`0;1PX030L;00d8300=20`03PT=00l:3P080`L04@`@00`7300C3Q@050lE00`7
2`0>2P/03PX900l;2@0?2`X03PX900d9200C3`h02`X600H50@071P8030/700l>2P0<2`L01PD2010?
2`0200h=2@0R00L6100=2@X05Q8C03Te=P0<20T04@d>00d92P0:1PL03`/<018>3`0@30d03PX;00`8
2@0@3Pl020L701TI6@0R8240Hf9Q018A3`061@<040d;00X60`0C3``02`L4018>3@0=2@l081dT0080
1P0B41D040hC01TG6P0=2`h030X;00/92P8030/902/03@`:00l>300=2``02`X800/92@0;2@X02`X8
00P71P081PL02`X8018@400I5aP071XK00h<3@0=2``030X;00d;300=2`h03P`?010>4@0@2`l050lC
00h93@0L5a/020<701<A500@3Q402`T<00`:3@0=2`h030X=010>4@0B41<03P`?00T72P0=2`h03`d@
010>4@0C4A@040hA00T72P0<2Pd03`d@008030X=01803@/>00l=400@3Q402PP;00h<3`0H5QT04a4D
00H41`071@X02`T>018@5@0@3A@0514H00d:4@060`X04Q0G00`;4`0C4QX201DD6P0=00h=4P0D4aP0
4A0E00h=4`0?3Q@04Q4I01@B6@0D3aD05@hE01<?5P0B3aH04PlH014@6002018A6@0C01@A6@0D4AP0
5a8H01PB600F51T03PdC00l>4`0=314030/@03De=`0F5QP05ADG01@D5@0E5AL05aLG018B4`0E5AL0
5QHF01LG600201LG6@0401HF600E5AL061PJ01LG6@804a<E00<05QHH01LF6`0D4aP00P0C4QL00`0B
4AH03`hC01PG700201DD6@8061LL00P05A@I01<A500C4A@05Q@G01TG6P0H5QT04a4D01DC5P804a4D
00/0518E01<A500?3A00410B01<C5@0?3a4051@F01XI6`0A3a804a4D01DB5@0201LB5P0801HA5@0E
41@061@E01PD5@0E4A804`l@01TE5P0N6Q/601@@4@<05a<B0140510?010<3@0>2P/05A4B00h93@0@
2`l04`hB01HA5@0B3A404Ph@01hJ6`070`@04@d>01PD5@0I5AH040`=014=3P02018>3`09014=3P0@
2a003`X@014<4P0B3A<04@`B00l:400@2a404@`B00804PdC00T02PD;01PC6@080`T03`P?0109400>
1`h02`@;00l83`0D3A@00P0A2Q406P0@2A003`P?00l83`0A2a804@`B00l:400@2a404@`B014:4@0C
2a805@/C01@:4P0A1`l03P@<00h2300D2A403@8801D:400J3aD01`0201<93P0B1`d05``B03H]<@0A
1P`050T?1`0?10X0600900@04@H<01<83P0?10X04@H<00d2200>0`/040H>01P>5P0N4a/0714I01@9
4@0;00P05P/C00/1200G31@05P/C01053@0I31<0200201062P0I31<04PL<01442`8040<:0P0>0@P0
2P0C1Pd060/B00d2200C20h01`0200`11`0M4QP02P050146300@1@/200l42P803P<95?ooool001_o
oooo00`04PlF00h;4@0E4QP0:BH]00l=4`0=2a003@XA00/93`0=2Q003``C00l=4`0<2Pl2018B500=
01TI6`0>3Q003`h@018@4`0?3A003@T=014<400?2Ph03PP<018<400B3Pl04@d>010=3P03010<3@0<
01`H6@0?2``03`/<010<3@0=2@X03PX;018>3`0@30d0Ee=D03Pd=@0A3@h05A4B0P0?2``02`0@30d0
4@d>014=3P0A3@h04P`@018;3@0A2`d04@`;014;2P0A30T04Ph<008040`=01d040/@010=4`0>3180
2``>01<D4`0>40/05aX?03/n<@3Gfl`0GF5D01DG3@0@4Pd02P`;01@D5P0A41@08AlS01lM8P0?3A80
4@lC014?500C4AD030X>00l=4P0@3Q80518F0040100>30h04A0>020O7@02010?3@0300P71P0@3`d0
3`h<00@03`h<02P040d<014=300A3@`03PX900d9200?2`X04`l>018>3@0A3@`040`;00l;2P0>2`X0
3`h=014A400;2PT02@P8018A400=30`03`h=02l_;P0M7A`040l>014@3`0;2PT03`h<00H50`0>3@/0
20L500/:200=2@P04@`<018<300>20P040P901H=3P0D3@d0:BDT01TH5P0?3P`040l=0P0=30X300`;
2@0400h=2`0K6QP0:2LU00`;2@<03@`:0P0>3@/04`0E51808B0N0040000A40l03P`<02PW:01ZJW40
UYFM024Q9P0=3Q402``;014A3`0>3P`03`l>00d=3`0=314030/B00P73@0<2Pd00`0=2``200h<3@0=
00l=3P0>30d03@/<00d;3@0<2P`030X=00d:400C41L02PL=010<4P0<20h03`/B00h;4P0200`93`08
00d;4@0>31803P`A00`:3@0:20/03@/>010>4@0=2`h300/9300B018@4`0@3Q404a4D00D31P0=2`h0
4Q0C00810`0A3a802@L:00h<3`0F51L04a4D00`:3@0=2`h02@L:00`9300>2@d03`X>0P0@2`l06@0>
2@d040/?00`82`0G4QH02PH900`72`0B3A4030L<00l:400A318040/A00l:400@2a403PT?00d83P0A
318040/A00/6300B3A<0;2L]00T42P0L5ad03@T>01<>500;1P`00P0@2a401@0<1`d040/A00h93`0O
6R004@`B00803`X@01`0100500`73@0A31802PH;00`73@0D3aD03`X@010;4@0?2Q0030L=014<4P0@
2a403PT?01@?5@0>2@l04PdC00l:400=20h06QDK00T42P091@/03P`?00T92`0B4Q@03@d?00P82P0B
4Q@03`lA0P0>3Q0200d=3`0700l?4@0=2`h03`d@00h<3`0=2`h03P`?00l=400200X82`0=00l=400<
2Pd03`d@02PV:P0_;3403PT@00d9400S7RD03`XA00h9400=20l04`hE018=500200h9400601<>5@09
10/040/B00L32@0G4QT03@P?0P0?2Q407P0@2a804@`C010;4P0?2Q4030L>00/63@0>2A002@@;010<
4@0@2a804@`B00d83`0?2Q404@`B018=500A31<03``D00/;5@0A4Qd01@L@05UHH@0f=S`04Q8G00X9
300<2`/02@P800l=300A40d03P/9018<3P803@L90P0A2`d0100?2@/03PP:00h82P0?2@/3010:3007
014=3P0?2`d03PX;00h92`0>2@`03PX<00h:2`0200h:300800h:2`0>2P`03`X>00l:400>2@l03@P>
00h93`0?2Q0200h93`0=00`73@0>2@l05a8H01D@5P0>2A0030L?01<=5`0N6B8030L?01@>600910d0
3PTA00h84P02010:4`0400h84P0=20l03PT?00h940<03PT?01<03@P>024L8P0J5A/03@T>01hI7`0E
41H04`hC00H11@0A3100If9W030[;`0A31003`X?01D@500J5AT04@`A00`72`0=20`040X=00803`T;
01X03PP:00l92`0@2P`03PP:00`6200@2P`04P`>00l92`0?2@`03PL=014:4P0T72P04@TH01@<6P0?
2A004@`:01D@2P0C3`H05A09014=200B3P/040`:00/71P0@30/04Ph=00h:2@8040`;00X0:bLV00`8
1`0B3Pd030P700h:2@091@H04`l@01HB4`0A3@h030P90P0=2@X03@0>2P/03`/<00l;300>2P/03@T:
018>3P0?2`X03`d;01@@3`0F4Q404`l>014=300@30/00P0>2PT01`0@30/04@d<01PD5P1^JF`050lB
014=3`0>2P`00P0?2``300h:2`0400l;300?2`/04@d;010<2P803`/800@03`/900l;200?2`P03`/9
0P0@30T01P0?2`T03PX8018>300A3@/040`:010<2`803`/;01004`h?010:300D3Q005@dB018;3`0C
3A403``?014?4P0=2`h03`d@00d;3P0C4A@02`T<00l=400>30l04@lB0P0>30l01@0:20/04Q0C010>
4@0?3A0040hA00803`d@00D040hA01@B5@091`X061HI00h<3`0500l=400f010>4@0B41<030X>00h<
400F51P04Q0D01DC6`0F5200518M014@5`0@3a@0410A014A4P0A4A<04A0E014@600B41/04a8L01@B
600@3Q<04Q4F01LF6`0B4AL03`hC01@C600B4AL040lE018A5P0D4QL04a4F00d<4@0A41D05A@I01@C
600F5AX06QTN01DD6@0K6Ql04A0E01hM8P0G5QX04Q8E01@F5@0G6AH05QPF018D4P0C5A<071hM00h?
4@0?41805aPJ018C5`0E5QX03a0D0P0B4AH201<B5`8051<H01T03`hC01<B5`0G5Q/05aHK01DD6@0A
41@05Q@G01HD5@0H5QL05Q@E018@4@0F51D0518C01TG600J61T05Q@E018@4@0A3a005Q@G01LE600D
4QD04Q0C014?4P0C4A@071XM00806QPK00@04@lB01PF6@0F51L04a4D0P0E4aH201@B5@0I01HD5`0A
3a803`d@00l=400O7B003P`?010>400F4Q<04Ph?01DA4P0C3a004Ph?01HB4`0A3@h040`=01LC500A
3@h0510A010<3P0C3A4030H:00/62@0D3Q807QPL014;3`02018<40804`dA00L04P`@01093`0A2a40
9AhU01dF7@0?20l04``C008050dD0P0C31<0400B2a8040T@014:4@0=1Pd0614H00h83P0>2@h06Q<J
03hg?P0C31<02P@:01@=50090PT05a0G00d7300@2Ph201@>4P0D014;3`0@2A0040T@01094@0=1Ph0
4``D00d63`080@X04PTA00d22P0C210040D=01T>5P0>1@/05P/C00`22@0=0`X0714I00/1200A1`h2
010330804@@=00T04PD>01<63`0>0PP04@@;01<63@0A1@T040@801462`0?1Ph00P0>1`h301063P80
3`D=01803`@<00l22@0@0`X04@@;01052P0A10/03`D900`01P0Q5A/0>Rdd01032P0?0PT03P480103
2P0D1`h05`XA0146300@1@/200h32@803`@:00H02`8601L<4P23N7h0=2T_00d3200C20hDooooo`00
6oooool02@0610T04@lD02XX;@0@3Q<08R0U01TG700>31403@/@00h<4@02010>4`0@00d;400>3Q00
ATI80;Ng^@0/;2h04a8D010>4@0<2Pd03P/>014<400=20`03PP<01<=4@0>2P/03`/<014=3P804Ph?
00T04@d>00d92P0@30d04`l@00l;300>2P/04`l@01DA4P0400400P0:1PL01@0L61T03PX;00l;300?
2``040`=00<04@d>00@03`X>010:300@30d04@d<0P0B3P/0900A30T04@/=014;3@0C318050dE01<@
5P0;2`d05QHF00d>2@0A4`P08bDH08V;O@18BS`030h300/<1`0C4a<04Q8D010?4`0;2@`020H900`:
3@071@P04a4D05IDE`0A3a800@0204U7BP0n?3l06aTL028P8P040`401@@200d<2P0N7A/040l=00`;
2@D03@`:00D03``;014=300@30/03PX900d92007010<2`800@0001d0;bh/00L6100D4a403`h<010?
3@0A40h03@`:00L6100?3P`030/900l>300<2`T051<A01TH5P0@3`d03@T8018<300C3@d03PP800`3
100@1`P03`P8024M700C4Q0020L500T81P0:2@L030/900h=2`02014@3P0400h=2`0<2`T02`X800`;
2@803@`:0`0>3@/050040`403Pd;00T81P0B4@l03Pd;00l=3P0000@04a8H00H52P0?3a402@T801<D
3`0>3`X03Ph=00`<3P0:2@h02PT?00`;4@0?3A003`d>0P0=2``00`0<2P/02`T:00`:2`0300d;3009
00h<3@0>30l03@/@01PF6`0=2a0040hC00D320081P/02`T>00803`dB0P0=2a004@0@3Q<040hA00X8
2`0I5aX01`D800400P0<2Pd02@L:018@4`081PT00P4301<A500P7R4040hA00P62@0E4aH03@/>0080
4a4D00H04Q0C00l=400;2@`03@/>00T72P0?2`l3018=4@0<00l:3P0>2@d03`X>00d8300300802`L:
01@?4`0@2`l03@P=00l:400A318040/A0`0>2@l00`0<1`d03`X@018=4`0200`73@0h01XE6`0G4QP0
0`0402DP9P1hLgT0;RT_00L3200E41H040/A00X52`0?2Q002`H<00`73@080`T06A@J020K8@0F4AL0
40/A00`73@0L5ad02PD;00H11`0@2a403`X@00h93`0?2Q0030L=00/6300B3A<02PD;014<4P0C3Q@0
2PH;010;4@0;1P`040`B00400P092@/01`L900d=3`0?3a402PX<00h>400?3a404Q8D014A4`0?3a40
30`>00l=400@3Q403`d@00d;3P0<2Pd03P`?014?4P0;2@`2014?4P0900X82`0=2`h03`X@01@=500:
0`X04``C01PA600B2a803PL>00804P/B0P0?20l0200C31<050lE00`73@0D3aD020<900d83P0H4aT0
3`X@0`0@2a400`0?2Q003@P>00T42P0200h93`0301LB600;1P`05Q4G00803PT?0P0?2Q003`0>2@l0
2`P?00H74P072Q<0I6M`01HF7`0G5Q`02@P=00h>4@0;2@X030X;01LF500G5Q8040l;00l92`0200`6
200300l92`0>20X03PP:00804@/=100@2P`300`82@0:00d92P0>2P/040`=010<3@0?2``03PX;00d9
2P0<20T03@T<00`73@802`H<01D03@P>00l:400A31803`X@00h93`0?2Q0050lE01<>500A31@040XD
00X43P0A2aD02@<=01PB700=1a4030H@010:500?2A<02`D?00`6400=20l01@0=20h0300:1@/0>SDk
02lZ<00300@040/A018=4`0?2Ph02@@800P31`0O6Qh030L;00h93@802`H:00@03@P<00l:3P0?2Ph0
3@P<0P0A2`d0:@0@2P`03`T;010:300A2`d03`T;00`6200?2@/04P`>00h82P0@2P`04@/;01@>3P0L
5A/02`@<01PA6@0B3@d05Q89028O400_;1T02`P0018?1P0K5`h04@d:00l;2P0>2PT030P700X61@0?
2`X03@T801XF5@0<20L0510?00T5100<20L02`L800h:2`0?2``03PX;00`82@0:1PL03`/<00@040`=
00T03`/<00l;2P0>2PT03`/:014=300C3`h04@d<00h:2@0?2`X00P0@30/02@0?2`X03PX900/7200L
61T01`<4010<3@0?2``04@d>010<3@0300l;308040`=00H03`/:014=300B3Pd040`;00d9200;1`H6
00l;2P<03`/801X03PX900h:2`0>2P/03`T;01LA5@0F41@04`dA014;3`0?2@d04@dA00d;3P0;2@`0
3`d@00<110040`D05A<F01<A500<2Pd020H900@21@0B41<0:BLZ00X82`0?3A002@L:01DC5P805Q@G
00D05A<F01<B500200<071XM01@B5@0500l=400D010>4@0B41<040hA01dK7P0G5AP02`T<018@600B
41d04Q0K018A600A41D0410B00d=3`0?3a404Q4G01@C6`0C4A`04@lK01HE6`0A41D200l>4`0300d<
4@0A41D04Q4F00804A0E01/051<H01DD6@0D4aP05A@I00l>4`0B4AH03@`A00l>4`0/:c00D4mD018A
5P0O7R<0DU5F020O900G5QX04Q@C01DG500G6AH04Q@C010B4@0B51<05QLI01DF6@0G61`03PlC01DF
6P0G61`00P0B4AH301<B5`0;01@C600C4QL051<H01DD6@0D4aP04a8G018B500H5QT04@l@01<A4P0F
51D00`0C4A80400F51D05A<D01<A4P0B41404a4B01HD5`0E4aH04@lB010>4@0C4A@061HI010>4@0F
51L07adP01DC5P0G5AP2018@4`805A<F00L04a4D018@4`0B41<04Q0C010>4@0B41<071XM00803P`?
01805a<D01DA4P0G4a@05A4B01<?400E4A80920Q01XF5`070`@04@d>010<3@0Q7Ah05a4E01H@5009
0`L03@L;01@>4P0C3A42018<40804`dA00P04P`@00/62P0T7B@0`K[106eVK@0700L04P/B00l83`80
4@XA02L04P/B014:4@0?20l04@XA00/42`0?20l050dD01<<4`0700L05a0G018;4P0;10/03`P?020I
800>1`h03PP=014;3`0B31004@/?00h8300=1Pd04@XA01L@600D3AD0610J018:5@0;0`h050/D038W
;`0h;CD03@8:00/0200J3aL04`P@00`12@0D2A405@XB01dB6P0D2a400P0B1@l301443@070103300;
00L040<<01D83`0B1@`04@@;01L;4@0301063P<04@H>0P0@1@/300l42P0901452@0<00H03`8901<6
3@0D1`h05@P?01L:4@0@0`X03`8900803P4800<04@@;0185300?10X00P0?10X02@0@1@/04PL=01<8
3P0B1`d03PD902<H7P0E2Q003`@:00L00P0Dooooo`006oooool01P0B41D02`T>01DC600100@02`T>
00d;408030X?01403@/@00h<4@0>314030X?01DE5`0o?d40Zj^]01<C5@0=30h03`d@00X82`0?30l0
4@`@00`72`0>20`04`dA014=3P02010<3@03018>3`0C3a00510A00804Ph?00X0510A010<3@0=2@X0
4@d>00h:2`091@H05a<D014=3P0B3Pl02PH70P0?2``0100@30d04@d>014=3P0A3@h200d;3P0K00h<
3@0B3Pd04`l<01<?300B3@X04@/;010:300A2`l04P/B01D@5`030`D02PP9018B3@0G6@h01`L001`N
400F60/030`201<C3P0>3Ph020H900L52@0A3a806aTL01DC5P0B41<0518E00805A<F00T08R0S00d;
3P071@P040hA00H41@0:2@L01`H401@C4@0100000P0@3`d500d<2P07010=300C3`h04`l>014=300@
30/04`l>00l;2P04010<2`0U014=30071P@040l=0450?P0=30X020L500l>300E518040l=00h=2`02
0@0040l=00h=2`0920H04Q4?00X91`071P@00P4001@@3`0=1`L040X:01<=3@0J4A8071<D00l8200;
1`H02`X8018A3`0F5A<051<A01<B400>3@/04A0>01<B400B4@l03Pd;00/:200200d<2P803Pd;0P0?
3P`200h=2`0B01@C4@0E51805A@B00/92P0>3A802`X?00h>400@410020P500h?2P0=3PT02`/800l?
3`0A4A<03PdB00X93P0>30l03P`=0P0=2``400`:2`0Z00d;300>30d03P`=00l=3P0:20/0108700P6
2@0:20`05Q@I00d;3P0;2@d04Q0E014?4P0;2@d02`T>00h<3`0@3Q402`T<01/I700A3a8040hA01@B
5@0;2@`04@lB00d;3P0L6Qd040hA00X82`081PT05A<F00h<3`0<2Pd0518E00L5200>30l03@/>00/9
300>30l02@L:00`9300<1`/03@P<100>2@d02P0910P05A0D00T5200M61`030L;00h93P0C3Q@050lE
018=4`0@2a4200l:400300X52`0910X03PT?00803PT?00P02PH;00l:40080`T05A0F02lZ<00400D0
4PdC01@?5@8030L=02404PdC00l:400;1P`040/A00d83P0300@04@`B010;4@0C3Q@05a8H00H21`0H
4aT030L=00`83@0>2@l030L=00/6300D3aD07APN00`73@0?2Q004`hD00X52`0A31804PdC01<?5@0I
5aX071`N00H6200;2`d04Q8D00/;3@0?3a400P0@41808@0?3a403@d?00/;3@0?3A0040hA00l=400<
2Pd02`T<00`:3@0J61/020H900T72P0B41<040hA00`72`090`L050hC010:3P0A2Q4040T?00L11@0?
20l04P/A014;3`0?20l03`T>018;4P0E41H03@P>02PS:@0<1`d040/A01LB6002018=4`804@`B00P0
40/A00l:400K5Q`050lE00H11`0:1P/07APN00d83P<03PT?01003@P>00`73@091Pd02P/F02@W<00b
=Ch0000700X93`0<2a402PT=00X82`0=2``05Q@D01PG5@0G4a803`T;0P0>20X200l92`0500h82P0A
2`d04@/=010:300?2@/00P0>20X07P0>2P/03@T:00`82@0=2@X03PX;00d92P0<20T03@T:00h:2`0?
2``040`=010;3`0>2@l030L=00d83P0?2Q004`hD018=4`0=20h030L=00d83P0?2Q003PT?00/63@0=
1a401`4;018<5P070@/03PPB00X43P803PPB00@030H@00T33@0:10h03@P?1@0?2Q002@0=20h06A@J
01PC6@0:1@/03`X@018=4`0;1PX03@P<018=4@0200`72`0900h93@0=20`03@P<00d8300>2@d040/?
014<400A2`d040X<00<03`T;02004@/=00l92`0<1PP03`T;014;3@0>20X040X;01<>2P0E40`050h?
00@00P0E3a4040X7010<0017A340XIn704A2;@0N6`T040`1010=200@30/03`/:00d9200?2`X05Q8A
00d9200@30/03@T801DA400:1PD03@T8014=3P803PX;0P0A3@h00`0=2@X03`/<010<3@03010<3@04
00l;300>2PT03PX900l;2P<040`;00l03@T800l;2P0A3@`04@d<00l;2P0=2@P03`/<00D10P0;1`P0
3PX;010<3@0>2P/04@d>010<3@0?2``00P0@30d01`0A3@h03`/:010<2`0A3@`040`;00h:2@0=2@P0
1P0?2`X300h:1`0<00h:2@0>2P/03PX;010:300D3Q803`T=014;3`0D3Q8040/?01@B5@081PT02PP;
0P0=2`h04`0D4QD040hA00T72P0B41<03@/>01PF6@0k>C`0IfEX02LU:00K6A`00P0300h<3`0@3Q40
6aTL00L5200E4aH04a4D00d;3P0<2Pd01@0@3Q405@0<2Pd03@/>01HD5`0_;C0081hQ00/9300@3QH0
40hI014@600C4QT04Q4F014A500?3a40410B018A5P0C4QX04Q4I014?6P0H5ad04A0E00l>4`0301DD
6@0O00d<4@0@3a@05aHK01`K800J6Ah04a8G01TH7@0100D05A@I01TH7@0G5Q/0O7^00>;QiP1FEEX0
5A@I030_=00;2Pl06APL010B4@0B514051HC018D4`0A4a804aDD01XK7@0F5aX06AXN01<D600J6al0
6AXN01DD6@0601HE6P0601DD6@0D4aP04a8G01<B5`0C4aD05A<F0P0D4Q<2010>3`0G01XH6@0D4Q<0
4a4B018@4@0A3a004a4B01DC500C4A@06ALJ01`J7@0J61/05Q@G01@B5@0@3Q404Q0C01LE600@3Q40
6ALJ01LE600B41<05A<F01HD5`0C4A@00P0A3a801`0E4aH040hA00l=400@3Q403`d@01@B5@0C3a00
0`0A3@h03P0C3a005A4B00X71`0K5aP04Ph?01@@4@0<20T02`L800`62P0400809AlS01D?4`0F41@0
2`D90P0B310201<=4@08018<400F3aD0100402LP9`0?2@l07QLN01XC6P0A2Q42010940804@XA0180
3`P?0109400>1`h030D<01H?5P0G41L02P<:018;4P0G41L0614H00T22@0@2A001P0601<=4P0A2`l0
4P`@00l93@0<1PX200`5300E014:4P0600L01@07018:5@0C2aH030D<00d22P0O51`060dE01T>5P0A
1Ph04`P@00T01P0E2Q802@0600l4300;0PP04`H@01853`0B1@h04@@=008040<<00H04`H?01P;500K
3QH050L@01032P0E2A4301053@0401443@0@1@d040D=01052`<03`@:00<040D901862P0A10/00P0A
10/00`0@0`X0304600P00P0201032P803P4800<03`8901032P0?10X00`0?10X0200A1P`04PL=0105
2`0<0`L01`0200P00`0@1@/01`025?ooool001_ooooo00L0OWb1034_=0081P/05aDJ00h<4@0B41D0
3P`A008040hC00/03`dB00h<4@0>31403@d?00l?4@0E5AL0410B00h=400?3A003@/>014=4@02010;
3`0D018<400A2`l061@E018>3`0?2``040`=01<?400F4Q<04`l@00d92P0@30d04@d>00l;300@30d0
4Ph?00l;300@30d03@T:018>3`0A3@h200l;300^010<3@0A3@h04@d>00l=3`0<3A003@hA00h>3`0A
40h04A0<01<@3@0C3P/04`X;01892`0B2@h04PP@01<;4P0?2`l05A4B00h;200=2`@03``2018@1P0K
6@l06AH>010=2P0=2P/03@P<010>4@0F51L07adP018@4`0:2@/0:bT/030_<@0G5AP01`H8010>4@0D
4QD03P`?018@4@1VIF<051<A014@3`0=30X05QDC014@3PD03`h<00<040d<014=300B3Pd00P0@30/0
0`0C3`h040`;010<2`03010<2`08014=300:2@L04A0>038a;`0D4a4030/9010?3P0920H200d<2P0K
00P71@0A40h03Pd;00D40`0F5A<04A0>030_;@0M71X040`;018<300@2PX04@/;020G600W7Ql06a<D
01@@3`0>3@/03`h<01/J600I61H01`H400h=2`0<2`T02`X800`;2@0=30X030/900<03Pd;0P0?3P`0
2`0@3`d04Q4?00L6100>3@/030/901@C4@0A40l02PX;00/;300<30/02P/700802``700H08B8M00h?
2P0;30P0410?00h>3`0<30d200`:2`803@/<0P0?3@h00`0<2P/03@/<00d;300200h<3@0@00l=3P0[
:BX01@<5010>3`0B4140BDM903Tg>00>30h04Q0B014?400;2@X02PP:00`:300A3a800P0300`:3@80
;B/^00D040hA00`:3@0A3a801P@702PV:@02014?4P0?00X82`0E4aH020H9018@4`0>30l0518E00`:
3@0=2`h02`T<00l=400:20/03P/>010;3`0?2Ph03PT=00803@P<00X03`X>01HA5@1ED5@040`?01LB
5P0910P04@`A010;4@0B3A<04@`B0P0>2@l0EP0?2Q003PT?018=4`0J5A/05A0F00l:400>2@l04@`B
010;4@0>2@l030P=00H21`0A318030L=00X52`0M61h04PdC00`73@0=20h04`hD02/V;00H4aT06QDK
00d83P0?2Q001@0601@?5@16@DL071LM010;4@0A31803@P>010;4@0T7bD0;bX`01HA5`0?2Q004`hD
00l:400B3A<040/A014<4P0H5aT02`/=00d=3`0@41803Ph@014A4`0@41803`lA00/;3@092@/02PX<
00`<3P0A3a804a4D014?4P0?3A003P`?00l=400<2Pd06QPK01dK7P0A3a802`T<01LB5P0O6A`04PT<
01L>4@0B2@d03`H901L>4@0A20`04PT=0189300A20`04PT<014:3@0<1P/03`X@02/V;00F4AL03`X@
00`73@0@2a403`X@100>2@l02@0B3A<040/A010;4@0F4AL0XIbR03`g?@0?2Q003PT?00d83P0200`7
3@0>00X73@0L72D0<30j00P84@0;2a<03`lD00`;4@0;2@h040hA010>400=2@T03PX901@@3`0@2P`2
014;3@<040X<0`0?2@/0200>20X03@L900d72@0C3a004@d>00l;300>2P/03@T:1P0>2P/01@0>2Ph0
3@P>00d83P0=20h03`X@00804@`B00<03PT?00d83P0?2Q000`0=20h02@0B3A@01`8901HA600@2a80
4`hE00l:4@0=20l030L>00d83`0200h9400300l:400>2@l03PT?00<03PT?00l040/A00d83P0>2@l0
40/A00d83P0?2Q002`H:00d8300B3A401`86014<400@2`l03@P<010;3`0A31000P0<1`/06`0A3100
3`T;00l92`0>20X03@L900h82P0?2@/040X<00d72@0?2@/040X<00h82P0A2`/03`/200h:0@0@2`H0
2@@201LB3`0I5@`0?3TW09jLQ03moN40V9Ml02LU4@0A3@<04@h9010<2`0200d920804@d<00T040`;
00`81`0?2`X04Ph=00h:2@0?2`X04Ph?00h:2`0?2``00P0B3Pl00`0?2``03PX;00l;300300l;3004
00h:2`0>2PT040`;010<2`803`/:00<040`;00h:2@0@30/00P0A3@`02`0@30/03PX900l;300?2``0
4`l@00/7200A3@h03@T:014=3P0@30d03`/<008040`=00<04@d>018>3@0?2`X00P0>2PT0200?2`X0
40`;014=300?2`X03PX900l;2P0@30/04@d<0`0>2PT0100?2`X03`/<00l;300B3A4201<>4P04014<
4P0=20h02PL<00h<3`804@lB01D01P@702HT9`0k>C`04Q0C00`:3@0Z:2/040hA00l=400:20/08AlR
00P62@0H5QT02`T<010>4@0H5QT00P0301LE600A3a801`D803Le>00@3Q401@0A3a802`0C4A@04@lB
00X82`0F51L04@lB00X82`0B41L03P`G010?5`0C4QT04a8G00804Q4F00`04A0E010?5@0@3aL04A0H
01@B700A41H03`hC01hM8P0_;S<0:BP]01@C600B4AH2014@5@0K01@C600E51T051<H01dL8@0=3140
5QDJ01<B5`0B4AH0DE1E09bKX00l>d006APM01/J7`0<2a005QDJ01LI6@0F61L04aDD014B500B4aD0
51DG01DF6P0B4aL06a`P01PI7P0J6b00414F00805aHK0`0F5AX00`0E51T05aHK01HE6P0301@C600;
01DE5`0I5aX04a4B01dK700V92D071XK00h<3@0E4a@04a4B014?400B41400P0E4a@03@0G5AP06QPK
01TG6P0F51L0518E018@4`0G5AP061HI01`J7@0C4A@05aDH01@B5@0C4A@00P0E4aH201@B5@0;01DC
5P0A3a804a4D01TG6P0C4A@05aDH01XH6`0M6AX05a<D014=3P0B3Pl00P0F4Q<0300H51D06QHG092<
S@1fLW<07a/L02DQ8P0D3a80=c4e085kO`0G4AD0;BL[03li?@804P`@0P0C3A401`0B310040T?01H?
5P0D3A@05a0G01<<4`0G41L00`0@2A02018;4P0V0109400>1`h06A8I0109400B2a803@H=00l83`0F
3aH03PL>00/52`0D3A@02PD:010:400C31804@/?018<400@2Ph03@L;00d63@0@2A403`P@00l:400@
2A80200;028L9@0g;CH03P<;01D:4P0800D060dE06=HH00M4QX03@<:01D:4P0B1`l05P/C03db>P0B
1Q0201453`8040@>00L03`<=01<74@0E2A<05P/D0186400?0``040@?00804P<>01004P<=01<33@0B
0`d04P@<01442`0@0`X040@801052@0A1PX04`P;0185300@0`X03P8801032P0A1@/04PP<0`0@0`X3
00l22@030146300@1@/03P<900<03@8800H03`@:020E6`0>10T02@0401062`0@1@/Dooooo`006ooo
ool01`0H5QT03`d@00d;3P0F51L03@/>01XH6`0?3A000P0B41<04@0?3A003P`?010>4@0I6A/03@d?
014A4`00008040lB00l=400A3a804PhB00l:3P0E41@05Q0D00l93@0B3Pl04@d>008040`=0P0A3@h0
200=2@X040`=01DA4P0B3Pl03`/<018>3`0@30d071PI0P0C3a001@0B3Pl030P900l;300?2``040`=
00804@d>00D03`d@00d?4`0<41<03PlA00l@3P02010?2`0D014<2@0C2P/050/<01L<400J3A@05@/@
01H@500A2`d06QDC01/F4P0F4@/04Ph6018=1`0C3PX04@/:01@>400A2`l02`L;00/92P0:20T200/9
2P0>00X82@0<2P/07Q`M00800@0F51D01`D600<10P0E4a<051<A01HE4`0<2`X00`8007QgM@1PGed5
00h=2`0300h;2P0>2PT03`/:00803@T800D04@d<018>3@0A3@`04@d<010<2`0200l;2P0B01dL6P1<
BdT0QhJ403Th=P0>3@/02PT801XI5`0A40h020L6028Q7`0;2PP03Pd;01TH5P0A40h051<B04E4@P0A
40h03PX90P0>20P0400;1@D040L801H=3P0D3@d01@4000l>300A40h01@@200d<2P0G5Q@051<A00l>
300<2`T03@`:00l>300=30X200h=2`803`h<0P0@3`d04P0I61H03`h<00d<2P0=30X02`X8010?3@07
1P@040l=00h=2@0D4`l03Pd900h=200Q81/04Q4<010?2`0?3PX02PT7018@4@H03@/<00@03P`=00d;
300=2``03@/<0P0<2P/01P0D4a401`H400l>300:2@L05aHD00T81P803@`:01l030/900d<2P0=30X0
3P`=00d;3P0B41<03P`?00`:3@0?3A002PP;010>4@0=2`h06aTL075_LP0X9RT00@0203Pf>@081PT0
3@/>00`:3@0B41<01@<600d;3P0>30l03@/>00l=400:20/04@hA01D@500C3Q8040/?00<03PT=00L0
20<701D@500?2Ph05a8F018=4@080`P030L=00803PT?0P0<1`d02@0?2Q0040/A01<>500I51X04PdC
00l:400C3Q@040/A01@?5@02014<4P0:01XE6`0<1`d04@`B014<4P0K5Q`050lE00d83P0F4AL030L=
01/F70802PD;01X03`/@01dH7P0D3aD030L=01<>500E41H03@P>00`73@0=20h03`X@01D@5P0M61h0
3PT?00l:400@2a403@P>00L2200:1@/0=c8h0<6o`P1<BTd02@L:00800`071@P040hA00h<3`803@/>
0P0<2Pd0100=2`h02`T<00d;3P0<2Pd200/9300>00`:3@0?3A00:BLZ02XX:`0I5aX03`d@01`G6`0J
4A@06a4B03@Z:`0U6a`04@T900`20`0C2@X301882@0:01<92P0A20/05a4E018=4@0400<03@P<00`7
2`0F4AD040/?00l:3P8030L;01/03@P<00h93@0@2`l03PT=018=4@0G4QH05A0D01/F6P0@2`l03@P<
00`72`0=20`03PT=00`:3`1_KWH0AdM?00L73`0B4AP04a0G00X73P0C4AH05A0D01LB5P0?2``03@T:
01<?400>20`00P0B31000`0?2@d03PP<010:3P0200h830@03`T=00<04@`@00l:3P0>2@d00P0=20`0
2@0?2Ph040/?00l:3P0>2@d03@P<00`72`0<1``030L=00d83P0200h93`0D00d83P0>2@l030L=00d8
3P0@2a4030L=00d83P0:1P`04PdD00X5300O6R4050lF00P32P0400H03`XA01TD6`0F4AP02PD<00/6
3@0>2A0500d83P0>00X52`0@2a404@`B00X52`0>2@l05A0F00l:3P0<1`/02@@800`72`0=20`040/?
00`72`0=20`300h93@0300l:3P0@2P`03`T;00<03PP:01l040X<014;3@0=1`T03PP:00l92`0>20X0
4@`;00h:00091@0050l8018=2P0D3`/07AT@020M2P13@BX0_KbP05ME?00L6PH01P80010=200=2@P0
2PH500l;2P0D40l02PH5014=300@30/03PX900X61@0@30/03PX900803@T:00D03PX;010<3@0@30d0
3PX;00l;3004010<3@0400l;300>2PT04@d<014=30803PX900<04@d<010<2`0?2`X00P0>2PT02@0?
2`X040`;00X61`0E4A803`/<00d92P0<20T040`=00l;300300h:2`803`/<00<04@d>00l;300?2``0
0`0>2P/01`0A3@h03PX;00d92P0>2P/040`=014=3P0>2PT00P0?2`X05`0@30d040/?014<400;2@`0
3@/@01<A5P081P/03`dB02<Q9P0B41<03@/>01DC5P0<2Pd00P0300H41`0W9BP03P`?01dK7P0610L0
3@/>00l=400>30l02`T<008030X=00P040hA00/9300I5aX030X=03Tg>P10?T407Q`O010>4@D04@lB
00L04Q0C01@B5@0?3A004a4D01@B5@0<2Pd03P`B00803`hF00<040lF014@5P0C4QP00`0@3aD2014@
600401<B6P0G5Q`040lD00l>4`8051<H00T05QDJ01@C600B4AH04A0E01<B5`0D4aP04a8G00l>4`0F
5AX00P0H5a`0500N7B806QTN02<R9`0B4AH061LL00T83@071P/04A0E01LH6P0F5aT05AHH01@E6@0C
51P04Q<G01PI7P0G61d061PP00`<500B4QX05QLL0P0G5Q/00`0F5AX05A@I01DD6@0201@C60@05A@I
00d05ADG01XH6`0C4A807A/L02HT9@0N71d03`d>01LE5P0D4Q<04a4B01DC500F51D04a4B00805aDH
00X05A<F018@4`0B41<0518E01DC5P0F51L06aTL01@B5@0M6ah06aTL100D4QD06P0H5QT06aTL01/I
700:20/05A<F01@B5@0G5AP03@/>01HB4`0E4A8040`=014=3P0C3a003`/<01<?400L61T0WYZK08N3
Q00?2``0510A02@N8P0500<0<2X^00h8300D3Q8020860P0B310201<=4@07018<400H4AL03PL>01XC
6P0?2@l0100400T22@02014:4@0B0109400B2a804``C018;4P0=1Pd08Q/R01D>5@0?20l01`0701XC
6P0T7B@0>34h014:4@0U7RD02P<:01TB6@0<1P/040X>0P0C3A40500@2Ph03`P?00h73P0=1Ph05@hF
020H8P0400L01`0:02LN9`0=0PX05``D01<8400<0@T04PT?02@I8@0I3QH03`@<00T01P0700@071<I
0P0?0`d301043P0701454@0@11003`<?00l33`0C1a<050PD01<64`0201H44P0401H44@0F11005@D?
01D53`8040<:00`04@D90147200B20T050X;01@73P0B1@`03P4800`01P0B1@`060/B00l22@0@0`X3
01442`0301032P0@1@/03`@:00803P<90P0?10X01P0L4AL0@CHl0146300:00D0304700X01ACooooo
000Kooooo`07010>4@0>30l04Q0C00`:3@0?3A000`4400`:3@02010>4@0L00d;3P0<2Pd03P`?00T9
2`0>3Q005aLI00l?4@0A4A<04Q0C01<A500A3Q403PT=01PC5`0G4AD03PP<00/7200?2``04@d>018>
3`0?2``03PX;00l;300J5QL07ATJ01<?400>2P/04`l@010<3@80510A00<040`=00X61`0D41400P0?
2``0700@30d04@d>014=3P0?3A003A4E00`?500<41<03Q0?00l?3@0?3PX040`9018<300E30d06PlC
01lB6@0G3A806Q@H00d72@0@2P/030L400d8100E40/04Pd901PC400B30d04@/=01LA5@0B3A02018@
4@0@00d;300>30d04Q0A01DC500l>S/07adN01<A4P0I5aP061HG00h<30030P006aXH00/:200E5180
>3Le02d/:PD03@`:00<03P/:00l;2P0@30/00P0?2`X0100B3Pd04`l>018>3@0A3@`200l;2P0500h:
2@0B4@l03Pd;01dL6P0:2@L00P0<2`T07P071P@00@0001LF501EE5807ahL00`;2@020@003`h<04I5
@`24Ph406aXH00T61@0;1@D04`d=01LA4@0C2P/04PT:00l8200A3@`04A0>00`;2@0:2@L03Pd;00D4
0P0A40h03@`:00/:200=30X03`h<00`;2@803Pd;0P0?3P`2010?3@0B00`;2@0;2PP030/901<B400=
30X05aHD00d<2P0=30P01`H201@C3`0920@040l:00`;1`0@3`/06aXF01HE4@0920@04Q4?0P0?3@h2
00d;300400`:2`0;2@X03`d>00h<3@803@/<00`030X;00/92P0<2`T04Q4?00T81P0?3P`03@`:010?
3@0<2`T02@P600X91`0?3P`2014@3P0J00/9300<2Pd03`d@00d;3P0<2Pd03`d@00d;3P0H5QT00@02
01dK7P040PD05Q@G0:bZ[@0b<3<06QPK00h=3`0k>C`04@lB00h<3`0?3A003@/>010>4@0:20/03``?
018=4@0A3102010;3`804@`@00L05a8F00<00P0J5AT01`8601HA5@0<1``03@P>00803`X@00@03PT?
00l:400@2a4030L=0P0910X0:00:1@/04PdC01/F700910X01`88010;4@0400D040/A00T42P0A3180
2`H<00H21`0>2@l040/A00T42P0?2Q004`hD00<0100B3A<030L=00X52`0G4QP03PT?00<0100O6R00
3@P>00h93`0C3Q@04PdC00/6300@2a402`H<00@01@0A31809R4W01XE6`0=20h0=c8h0;6_/P0f=3L2
018@4`0400X82`0@3Q402`T<00d;3P8040hA00<03`d@00d;3P0<2Pd00P0?3A001@0=2`h03P`?010>
4@0A3a803`d@00<030X=00X020@500`31P0=0`@06Q0A00`20`0B20T07A<D01<92P0B20T04@L80P0C
2@X09P0@1`P02P@801D@50070PH081/O00h93@0910P050lC018=4@0@2`l03`X>014<400B3A407APL
010;3`0<1`/03`/>00<00P0K5QX040/?00d8300<1`/03PT=00l:3P0>31403`lF018B6P0;2a<01@@:
01@A600@3A@02`T>00X52@0?2Ph03`X=00d92P0A3@h030H:0P0A2`l200d72`0400h8300?2@d03`T=
010:3P804@/?00D04P`@00d8300<1`/030L;00d8300200h93@0N00`72`0=20`03PT=00l:3P0@2`l0
3`X?00l:400@2a404PdC010;4@0>2@l030L=00T42P0:1@/03PT?00T42P0:1@/06A@J02@O9P070PT0
30L>00T42`0;1Pd03`XA01lJ8@0`:c809B0W00d83`0<1`h04@`B1@0?2Q004`0@2a402`H<00`73@0=
20h02@@:00h93`0@2`l03`X>00d8300H4aL03@P<010;3`0?2Ph02`H:00`72`0C3Q805A0D010;3`0A
2`d00P0@2P`08`0?2@/040X<014;3@0A2`d03@L900h82P0?2@/03@L9014<2`0A3@@02@D001HA300B
30`030L401HB2`0M6P/06QL403dk900W9A003PX000l;0P0>2PL030P700/71P0E4A0071PG00h:2@0A
3@`04Ph=00d920050@0040`;00`81`0<20T03PX;00804@d>00@040`=00l;300@30d04@d>0P0B3Pl0
0`0A3@h040`=00h:2@02018>3@0500l;2P0>2PT04Ph=014=300?2`X00P0=2@P02`0?2`X04@d<00d:
2P0D414030P9014=3P070`@04@d>00l;300>2P/03@T:00803PX;0P0?2``02`0@30d04@d>010<3@0=
2@X030P9014=3P0>2P/03@T:00h:2`0@30d04@d>00803`/:024040`;014=3P0A310040hA014?4P0?
3A804a4F00T7300S8RL0C4]@01DC5P0A3a802@L:018@4`0@3Q40D4iA09>AU00N71l01`H801LE600C
4A@04Q0C00d;3P0H5QT03`d@010>4@0A3a805Q@G01LE600A3a804Q0C00T72P0I5aX01`0A3a804@0C
4A@030X=00/9300E4aH04Q0C010?500@3aL03`hF00l>5@0@3aD04a8H00h=4`0?3Q@04Q4G01<B6P0B
4AT04A0G008040lD02<051<H014@5@0<2a004A0E00l>4`0C4QL071/P01lN8`0K6Ql03`hC010?500B
4AH05QDJ01<B5`0@3a@06APM01@C600B4AH05A@I010?500B4AH051<H00l@4P0@4A<051DH01LH700F
5a/04a@H00h?500Z:S40?Ce502XZ<P0H62003PhF01XI7`0201TH7@0501PG700G5Q/05aHK018A5P0D
4aP00`0F5AX02P0F5QP05A<F01LE5P0D4Q<03@/<014?400S8B8061HG01DC500D4Q<201HD5@0=018@
4@0@3Q405aDH01`J7@0K6A`05A<F014?4P0J61/05A<F01LE600I5aX0;bd`03<a=00201@B5@0J01<A
500E4aH06aTL01lM800d<SD02PP;00l=400B41<06QPK00`:3@0>2P/0510A018>3`0G4a@061@E01<?
400D41404`l@020L7@0/:2T030P900l;300D3Q80618F01`F6P0C3A4201D?4`804P`@0P0C3A40200B
31004``B00H01P0F3aH03`P?02@M900M5Qd0=Bhe0P0A2Q40:@0C31<050dD018;4P0@2A008AXQ00d6
3@0A2Q4030D<0109400400@0614H01lH7`2ITYT05PlF00@0100@2@l040X>01@>4P0E3a<04@/?0109
400@2A4050dE00T22P090`/05PhI0149500@1a002@0601883`0H3AD05P/C01@94@0:00L03P<;00l6
300H3AD0304901053@0>0P`03`<=008040@>00P04@D?01864P0E2AD04PHB01454`0G2aT06@dK01D7
5`8060HF018060HE01P6500G1a805`LB0103300@0`X04@@:01462P0B20T050T<00X0100>0@P04PD<
01032P0>0@P03@0700l22@0A10/4018530<03`@:00T040D;01873@0C20h0;b@Z05Y?E@0>0`T04@H<
01@93`0<0@L05?ooool001_ooooo00<03@/>010>4@0@3Q400P0?3A005`0B41<030X=01<A500K6A`0
>SPk01HD5`0<2Pd0410B018B500=3@l0GUiP02/Z;0091`X04a4D01@A500:1@T04`hB01H@500G4AD0
4Ph?014=3P0@30d03`/<00803PX;00d04@d>01/G601XI6D05Q8C00L3100D41403`/<010<3@0D4140
4Ph?01PD5@0B3Pl0510A00804@d>03@04Ph?01<?400B41<06R0T05IKG`18CE006ahM01TI5`0N7QX0
4a0=01@?300F3`d07aHG01D:3P0D30l04P`@010:300B30d06Q@C00L20P0D3``05A0=01<=300A2``0
618D01LA5@0@30h04Q0A00X82@0>30d03`d>018@4@0C4A80=C<d01<A4P0>30d04a4B00P61`0@3`h0
4A0>00h=2`0<2`T040l=01<B400A40h03@`:00/:200=30X04A0>010?3@0@3P`040`;0P0?2`X01@0@
30/04`l>018>3@0A3@`04Ph=00803PX900L08QhM00X91`0H5aD040l=00`;2@0?3P`030/900803Pd;
00X04Q4?04U8AP0J6AL03Pd;00`;2@0>3@/051<A01DD4P0D4a404Ph=0`0A2`/201<:2`04018;2`0=
2@P030/900h=2`8040l=0P0?3P`300d<2P803Pd;00h02`X800l>300=30X030/900X91`0A40h02@P6
00h=2`0@3`d03@`:00/:200<2`T030/7010?2`8030/700@03`h;00d<2@0=30/03@`9100=30P02@06
1@@04@l@018@4@0?3@h02`T:014?400K6AX03P`=00P61`02010>3`0900l=3P0?3P`03`h<00l>300=
30X030/900X91`0;2PP03@`:008030/900`03Pd;00l=3@0>3@l0FeUL07ekOP0?3A002@L:01TG6P0>
30l03@/>00`:3@0>30l2010>4@0O02XX:`0F51L04@lB00l=400X9RT03`d@014?4P0=2`h03P`?00`:
3@0=2`h0:bP[010<3`0A31003PX=01<>4P0D3a<030L;00h93@0B3A403PT=00`72`0>2@d04@`A00l:
400;1P`03`X@01@?5@0:1P/03PT?00l:400200h93`0?00l:400A31805a8H01HA5`0C3Q@04@`B00`7
3@0?2Q005A0F01lJ80080`T050lE00P32@0=20h040/A00804@`B00X03`X@010;4@0F4AL04`hD00d8
3P0?2Q0040/A00/6300=20h040/A0P0?2Q000`0>2@l03`X@010;4@03014<4P09018=4`0C3Q@050lE
01DC5P0?3A0071XM014?4P0;2@`03@/>008030X=01h03P`?010>4@0<2Pd03P`?00l=400=2`h02`T<
00d;3P0>30l030X=00h<3`0<2Pd02PP;00/9300?3A00510B014;3@0D2``02P@401L>3`0=1@H04``<
01@;300B2P/040T901482@0A2@T040T:014<3P0@2`l200l:3P803PT=00X05Q4E02<N8P0300805A0D
00d8300F4AD03@P<00h93@0?2Ph040/?0P0A3100500@2`l02`H:010;3`0>2@d05Q4E05IDF00C4AL0
2`X@00d<4P0=2Q4030X?00l=4P0A31803PT?00h93P0?2@d04@/?018<400>20`030H:0P0A2`l01P0E
3a<071HJ014;3`0?2@d03PP<00d72`803PP<01P040/?00d8300>2@d04@`@00l:3P0@2`l03@P<00/6
2P0=20`04`hB00l:3P0?2Pl030L=02<N901AC5804`hD018=4`0A31803PT?01D@5P0=20h05A0F02PS
:@0J5A/200`73@804`hD0P0?2Q006`0H4aT0?CPn04E0AP0@2a402PD;00l:400D3aD03`X@00`73@0@
2a402`H<010;4@0<1`d03`X@018=4`0810T04PdC00L21P0H4aL040/?00h93@0<1`/04PdA00l:3P0B
3A403`X>00d83002014<400I00l92`0=1`T03@L900l92`0>20X030H800d72@0?2@/040X<00l92`0>
20X040X;014<1`0D3`/03`X;018;4@0>20h050h?01<>1`0D40<05a<501HB1P0C3PL040/900l;2@05
00l;2P0>010<2`0>2PT030P700d9200?2`X04Ph=00l;300<20T03`/<014=3P0>2P/040`=01HB4`0B
3Pl200d92P0>010<3@0C3a004Ph=00`81`0B3Pd03PX901<?3P0?2`X03PX901<?3P0<20P03@T8024M
700/:2L2014=3P0@01<?400?2``03PX;018>3`0?2``05Q8C00`82@0C3a004Ph?00h:2`0?2``03@T:
00`82@0=2@X03PX;00l;30H040`=00d04@/=01<=3`0@2P`04PdA018@4`0>30l02`X?00l>4`071``0
2`/@02PY;P1lO8405aDI00<03@/>01X03`d@01hL7`0T8RD05A<F00l=400B41<03P`?01@B5@0F51L0
>3Hi01HD5`0C4A@03@/>014?4P0E4aH04Q0C014?4P0?3Q003P`?014?4P0?3A003P`?014?4P0>30l0
3`d@018@4`804@lB00X04Q0C014?4P0A3a8040lD010?5@0?3Q@040lF01<B6P0?3QH04a8J0P0@3aL0
0`0E51X05QDK014@5P0601<B5`805A@I00/051<H018A5P0B4AH04a8G01PG700E51T051<H01PG700I
61d05A@I01HE6P0201LF6`0801<B5`0A41D05A@I01TJ7P0F5a`05aPM01@E6P0?41D201DE7@0f01PH
8@0R8R`051@N01DE800P82X05aHL01/J7`0F5AX05A@I01PG700B4AH05QDJ01DD6@0F5AX061LL01LF
6`0C4aD06ALJ01TG600G5AH07Q`M01DC500H5QL07A/L01DC500B41405Q@E01DC500G5AH040hA01DC
5P0B41<05A<F02<Q900Y9bX05aDH01@B5@0F51L0HV1S020N8@0D4QD05Q@G01TG6P0F51L05A<F01HD
5`0C4A@05A<F01hL7`0>30l0518E01TG6P1@CU4061@E0P0A3@h01@0D41405A4B01<?400D41404`l@
00805a<D00P04`l@01@@4@0F41@05Q0D01D?4`0B31004`dA01H@50D04`dA00<04P`A018;4P0C31<0
0`0D3A@00`0C31<04P/B018;4P02014:4@050109400C31<05a0G01<<4`0B2a800P0I4QT03@0C31<0
3@H=018;4P0O61l04P/B00d63@0B314040X>014;3`0B310040X>00l83`0@2A000P0=1Ph03`0?2140
2P<=01<;5P0B21403P<;01D:4P0B1`l050TA01473P0C21004PL?01053@0?10`040D=01<840020188
4@0N020F7`0C2A@03PH?01@95`0D2AP04@HE01055@0C21P05@XJ01@86P0G1a/03@0A01T96`0>0100
5@HF01<44@0K3AT05`XD0185300A1P/04@H:00l42@0>0@P04@@;01032P0>0@P04@@;00h1200?0PT0
4@@;0P0J3A@03P0B1P`04@@;00l42P0D2@l060dC00h32@0@1P/0;B8X0;:W[@35_<407Q<I00l62P0?
10X02`065?ooool001_ooooo01P04a4B018@4@0>30d02`T:00d;300@3Pl04a4B00h<3@091`P06ALH
00`:2`0D4Q<03@d?01@D5P0E5AL0>CTk00`;3P0@3Q403`d@00T52@0?2Ph04@`@00P21P0C3A42010<
3@0A014=3P0B3Pl04Ph?01<?400?2``030P900P41@0K5aP06QHG00L3100D41403@T:018>3`0H51D0
7a/L01LC500C3a000`0A3@h05P0B3Pl040hA04mCF@3lool0hnOZ02`^;P0M7A/020T400h=2@0=2PD0
6A@@02`W900I41404`d>01DA4P0;1`P0J6AU01PD4`0G4a8040`;01<?3P0G4a@201<?400G01LC500C
41400@000040000A40h05aHD010?3@0;2PP05QDC00L6100D4a404A0>018A3`0@3`d03Pd;00d<2P0<
2`T04A0>010?3@0>3@/03@`:00`;2@0=30X00P0?3P`01@0@3@`03`/:00l;2P0?2`X040`;00804Ph=
01004@d<018>3@0?2`X02`L600h:2@0H5aD0:2LU020O7@0E51804Q4?01@C4@081`D06APF00X9200>
3@/06APF0P0<2`T01@0>3@/04a8@01<B400@3`d03PX900<04@/;0P0C2P/02@0B2`/040`;00d<2P0>
3@/03`h<014@3P0B4@l02`X800d<2P0200l>300900d<2P0;2PP01`H400l>300E51804A0>00l>300@
3`d04A0>00804a8@00`04A0>018A3`0C4Q003@T600l;200>2PL04@d<01@@4@0<20T03`X>00l;300?
2`X300l;200300/:200Y9bP0>SPi00807A/L01/0:BLX06UWJ00:20T00@0000P71`040P<030X;00d;
30081PL040h?00X82@0@3Pl05A<D00d;300>30d030X;00P61`0:20T03P`=00h<3`0I5aX09B<V00/9
300>30l02@L:00h<3`0=2`h00`0<2Pd01P0=2`h03`d@00L5200F51L020L900d;3P802`T<00X02@L:
00l=400@3Q404@lB04E1A@0M61`020<7014<400;1PX02PD90P0D3a<02P0E41@04@`@00d8300>2@d0
4`hC01@?5@080`T04@`B00h93`0U82H2010;4@803`X@00D040/A018=4`0N6Al071LM010;4@0200l:
400D010;4@0B3A<06A@J00T42P0?2Q0020<900l:400E41H04`hD00l:400<1`d03PT?01HA5`0=20h0
40/A00l:400=20h040/A00l:400@2a4200l:400300h93`0?2Q0040/A00<03`X@00L040/A014<4P0C
3Q@01P4500X52@0;1PX04PdA00803PT=00P04`hB00`72`0C3Q802@@8010;3`0B3A407Q`O01LE6080
4@lB0P0B41<200`:3@0A00d;3P0>30l03`d@00l=400B3Pl02`L801<?400I4aD04Pd?00l;300A2`d0
4@`=00l;300A2`d04@`>018>3`0@30d00P0?2``300h:2`0500P41@0C3a0020@5010<3@0?2``00P0=
2@X00`0>2P/03`/<010<3@03014=3P0B010<3@0:1PL04Ph?00T51P0D4QD03@/@00X83@0>31403`dB
00d83P0>2@l040/A0109400?20l040T@0188400C2A404``C0P0A2Q4200h73P0501<<4`0D3A@04@XA
00l83`0>1`h00P0<1@`0=00@2a403PT?00h93`0@2a403`X@010;4@0;1P`00`0401XE6`0K5Q`01@06
00h93`0=20h04PdC02HQ9`0910X03`X@00X52`080`T04@`B00/6300<1`d06A@J01D@5@0>2@d03@P<
00l:3P0<1`/03@P<014<400V8BD050lC00h93@0F4AD01`8600h93P0;1P`03@P>010;4@0;1P`02PD;
00d83P0@2a404@`B01D@5P0R7B<02@D:01@?4`0910P040/?00h93@0500@200`72`803`X>01`03@P<
010;3`0>2@d04P`>01<=3`0F41806A<E01PB500C3@l03PP:010:300B30h040X<00l92`0@2P`05Q0@
00/51@0@2@l03PHC00l7500>1`h04@/;018=1`0D3`T04`h:014;3@0?2@d03`/<1@0?2`X03P0C3`h0
4Ph=014=300A3@`04`l>01DA400=2@X03PX;014=3P0>2P/02PH7010<3@0A3@h040`=0P0>2P/200l;
300501@@3`0B3Pd05A4@00h:2@0C3`h00P0@30/01@0:1PD06aLF00h:2@0B3Ph0Ee=B00804`l@00d0
510A00l;300=2@X04@d>01@@4@0G4a@05Q8C04]7B00W8b@071PI010;3`0?2Ph03PT=00803`X>00<0
40/?00l:3P0?2Ph0100?2Ph0100C3@l040X>00X4200<1`/200l=4P0>00l>4`0L7B804A8G014C600:
3A@01@P=00d;3`0;2@`040hA00h<3`0<2Pd020H900/9300<2Pd2014?4P0D00X82`0=2`h00`4403lm
@0081PT05aDH00L5200D4QD00@0201/I700<2Pd00@0201lM800:20/03P`?00d;3P0A3a803`d@010>
4@0B41<2014?4P0<018@4`0A3a804@lB01<A5@0C4QL04Q4G01<B6@0B4AT040hI01LE800C4A`040lG
0P0B4AL00`0?3Q<04Q4F018A5P04018A5P804a8G0P0B4AH0100C4QL051<H028Q9P0M724301PG7005
01@C600F5AX05QDJ01DD6@0C4QL00P0D4aP04@0I6Ql05aLO014A6@0C4a/05QHN00l?6@0Q8B/0410K
02LW<`0U9C406QXW028R;P0I61h06aXO01PG700G5Q/06APM00805A@I0P0G5Q/07P0F5AX05aHK01XJ
700J61/0?cdn02/Y:P0F51D040h?01lM7P1?CDh06aTJ028P8@0I5aP05A<D02HT9@0N71l071XM018@
4`0@3Q406ALJ01lM800100807adP01LE600P7R404a4D01dK7P0I5aX08R0S01`J7@80518E00X05A<F
01LE600D4QD05A<F02LU:00S8B@081hQ028N7`0C3a004Ph?0P0K5aP00`0G4a@05Q8C014=3P0201<?
4003010<3@0B3Pl050hB00805Q0D200C3A400`0B31404P/B01<<4`0201@=500301<<4`0D3A@04``C
00804``C0P0B2a80100M5Qd07aPO01<<4`0@2A0201/D6`0301@=500B2a804P/B00<04P/B03D050dC
00`62P0;1@T04`dA00X4200:0`X04@XB00h73`0@2A403PL@00l74P0C2aH05`dF01X?5`0=0`X07A8J
01T>5P0@1`d050TA01<8400B1`l04@H>01873`0D2A4050XC01<94P0C2a@03@8@00`13`0@1AD05@XK
0187600>0aD03`<G01866P0E2Al060`T00h26P0I3B<03P8H01H:7P0D21T03P8@00l33`0@10l040<<
01032P0B1@d04@@;01032P0<00H03P4801@73P0201032P0A01@73P0900<02`0501@73P0800801`02
0146300F2a402`0601hC6@1BAdd0mncb07aaM`07008060dC00h32@0?10X05?ooool001_ooooo01P0
3P`=00l=3P0>30d03P`=010>3`0A3a005A<D010>3`0<2P/03`d>00/92P0E4a@05QHH00/;3@0B4Q@0
8b<U03`k?@0>30l02`T<014>4@0G4QH04`hB00/52@0C3A43010<3@804@d>03`04Ph?01hJ6`0T8240
4Ph?03Pd=@070`@05a<D00l;300=2@X040`=018>3`0G4a@040`=00h:2`0?2``040`=01<?400E4A80
4a4D03/mA@3Gf^40_[o402DV:00F5QH00`@000/:1P0@3`X04Pl:01PD4@0A3@`05a<C00/92P0:1PL0
JfQY00l=3P0D41403``<010>3`0E4A804@h?00l=3P0D414051<B00X91`0I61H071/I010?3@071P@0
4a8@01TH5P0B4@l081lM010?3@0C4Q002@P6010?3@0F5A<03@`:00P71@0<2`T200h=2`0500d<2P0>
3@/03`h<00h=2`0?30/00P0?2`X2010<2`0I014=300B3Pd040`;014=300B3Pd04@d<00l;2P0>3@/0
6QTG01@C4@0?3P`03Pd;00l>300100002`X801DD4P0510802@P600/:200A40h04Q4?01<B400B4@l0
40l=010<2`03014;2`804`X;00@04P/;01<?3P0@3`d03@`:0P0;2PP03@0<2`T03@`:00l>300@3`d0
3`h<00h=2`0?3P`03@`:00h=2`0100003`h<01@C4@020@000P0@3`d03P0?3P`03Pd;010?3@0A40h0
30P500h:1`0A3@`06ADF01dH700C3Q803`X@00l:3P0?2``03`/:0P0?2`P01P0E4a@09B<T02XX:@01
000020H701TG60803@/<01T0:2HW038`<@0A3a002@L800X92@0;2@`04@l@00l=3`0?3A003`d>00d;
3@0>30l03`d>00/92`0;2@`03`d@00P72@040PD02`T<01<A500F51L020H900h<3`0=2`h030X=00<0
2`T<00P03@/>00`:3@0@3Q402`T<01HD5`0=2`h02`T<00L520802`T<01D02@L:01dJ7@0=20`04@`@
00/62P0@2`l03@P<014<400D3a<05A0D01<>4P0?2Ph040/?00d83@0>2@l00`0401`G7@0300@04`hD
00X62`0@2a400P0?2Q001`0@2a404PdC01D@5P0A31803PT?018=4`0@2a400`0>2@l04@0:1@/04@`B
00l:400=20h030L=00d83P0@2a403`X@00d83P0<1`d02@@:010;4@0>2@l030L=01@?5@0A318040/A
00803`X@00<03PT?00l:400@2a400`0>2@l04@0?2Q0040/A018=4`0=20`05Q4E00`72`0H4aL050lC
010;3`0C3Q804PdA00l:3P0:1@T0=S4e020K7`0E4aH04@lB00<03@/>0P0;2@`04@0=2`h03`d@00l=
400?3A003P`?00<1100B3a4061HG00h93@091@P05aDF00l:3P0>2Pd03@/<00l:3P0@30l04Ph?0080
3`/<0`0>2P/01`0=2@X04@d>01@@4@0B3Pl03@T:00l;30070`@00P0>2P/0200?2``040`=010<3@0@
30d03@T:00h:2`091@H04`l@0P091@H01@0>3A802`T>00h<4@0>31403@P>00803`X@0`0@2A020188
400:01L@5`0D3A@04@XA00d63@0;10/03@H=01@=500A2Q4040T@00l83`803PL>1@0?2Q003P0@2a40
7QTO00D01P0C3Q@00`0401dH7P0>2Pl02`H<00`73@0?2Q001P4700`73@0?2Q002PD;0P0A31809`0;
1P`02@@:00X52P0=20`03PT=010;3`0;1PX030L;00d8300P6al05Q4E00X52@0?2Ph02PD9014<4@09
10X03`X@018=4`0:1@/030L=00d83P0<1`d020<9055<DP2FTIL09R4W01PC5`080`L03`X>00X52@0;
1PX04`hB00/62P0?2Ph040/?00l:3P0A31003@P<00d72@0300l92`0E014;3@0<1PP03PP:010:300B
30h040X<00h82P0?2@/04P`<00`61P0@2A001`0<00h64`0<1@h03`T9010;1`0A30H04@`9014:3`0?
20l03`/<00L03`/:0P0>2PT02@0@30/04@d<00T51P0@30d05A4B010<3@0810D03@T:00l;3003010<
3@0>00l;300>2P/040`;018>3@0D40l03@T801<?3P0A3@`030P700d9200B3Pd040`;01@@3`0Z9RD2
018>3`0:01@@4@0@30d03PX;01<?400=2@X020@500l;3016@T<08QhO01<?40H040/?1P0=20`0400?
2@/04P`@018<400@2`l02PP=00P62`0@41@03PlD00021`0;3a<0314G01TL8@0=2`l02`T<010>4@0=
2`h200/93009014?4P0?3A003`d@00h<3`0;2@`040hA00T72P050`H03@/>00804a4D00L05aDH0040
0P0F51L03P`?01lM800A3a8061HI00803@/>00@04@lB00l=400@3Q404Q0C0P0A3a803`0B41<04@lB
014?4P0A41@03`hC010?5@0D4aX04a8J01@B7@0B41/040hI00l>5P0B4AL05A@I01HE6P06014@5@<0
4Q4F01404a8G01@C600E51T071/P01LF6`0C4QL05A@I01PG700G5Q/04A0E01LF6`0H5a`04a8G01DD
6@0J6Ah061PP01LG7`02014A6@0=01PH800D51h0:2Pb01hN:@0R8Rh0@d=?01lN:`0@41`061LM01PG
700F5AX05A@I01HE6P0201DD6@0H01TH7@0G5Q/05A@I01PG700N7R001`D801PF5`0C4A806ALH020N
7`0W9BH0clg>03Tg>00A3a006aTJ02XX:@0D4Q<05Q@G01PF6@0E4aH04Q0C010>4@0>30l05A<F0P0C
4A@0400@3Q40108501dK7P0N71l081hQ01TG6P0E4aH05Q@G01DC5P0C4A@0108500400P29QhX0Ti6D
00400P0K5aP201<?400501TE5P0K5aP06ADF01XF5`0D41400P0E4A800`0C3a005A4B01@>4P0201H@
500301D?4`0B31004P`@00D04`dA00<04``B018;4P0C31<00P0D3A@00`0C31<04P/B018;4P02014:
4@8040T@00L050dD01<<4`0@2A004@XA01<<4`0>1`h030D<008050dD01403@H=01@=500D3A@030H;
00l93@0Y8bL0B49602PR9P0=1Pd02@89018;4`0E3QH02@8;01P@6`0?1a802`<:01053@0201873`04
01P=5@0=0`X04`P@01873`<04@H>01H04`P@01884@0E2a@03`L@00/03P0?118060dM01<86@0A1QL0
3P8F00l36@0C1ad060dT01D=9@0;0Qd05PhV00`46`0C2b004PPJ00h34`0B1Q@04`LD0P0@0`d01P0F
2A<04`H=01@73P0A10/03`8901@73P804PD<01405PT@00`01P0;00D04PD<00/01@0D2@l03`@:00`1
1`0:00D04`P>02PM8`21MW`0:B0T00L00P0L4AL03`@:00T0100Dooooo`006oooool05P0<2P/03`d>
018@4@0C4A8040h?00`:2`0B41403`d>01DC500:2@T03P`=00l=3P0;2`d04a<E00`<3P0D51H071/M
02XX:`0@3Q40:2DX01hI7@0C3Q8200h830<040`=0P0?2``03P0>2P/0:BDV00T51P0G4a@061@E00d:
2P0C3a003`/<01PD5@0J5QL03PX;014=3P0=2@X040`=0P0A3@h07`0B3Pl04@d>00l=400D4ad09bH`
020O9@0D4aH02@T900l@2`0=3PP03a0:00`<1`0=3PT02@T500h=2`0D51@04a8B014A4@0>3Ph05QDF
01<B500A4A8040l?014A4@0B4Q8051<C01PG5@020@005A@B014@3P0I61H00P0?3P`02`0;2PP02@P6
01XI5`0<2`T04Q4?00d<2P0?3P`03Pd;01<B400M71X06APF00803`h<00H040l=00l>300=30X03Pd;
00l<2`0?2`X4014=300901<?3P0B3Pd03`/:00l;2P0B3Pd04@d<010?3@0D4a403@`:008051<A00<0
3`h<03Pg=@0O7Q`00P0>3@/01@0Q81h03@`:01<B400B4@l03Pd;008030/900@040`;014;2`0A2`/0
4@/;0P0C2P/0200B2`/04Ph=00l>300>3@/03@`:00h=2`0?3P`02`X80P0>3@/200/:200400l>300B
4@l03@`:03Xi=`8030/901T05A@B00h=2`0=30X030/900d<2P0>3@/03@`:00l;200@30/04@d?01LB
5`0K5Q`04PdC00l:4P0?2Q403`X?00l;3@0?2`X03`/900X82@0<2P/05A<D00L51P0d<S<0F5IG0080
3@/<01H01083014?400B414030X<00`:3P0D4QL03@/?018@50050`P0518F00l=4@0:20d03P`@00d;
400:20d03P`@014?4P0=2`h04Q0C00T72P0A3a802@L:100=2`h200/9300B010>4@0:20/04@lB00d;
3P0K6A`0;2X]018@4`0<2Pd040hA00h<3`0:20/05A4E010;3`0G4QH030L;01@?4`0<1`/03PT=0`0?
2Ph200h93@0;00d83@0H4aT040/A044l@P0D3aD030P=00h93`0@2a403`X@00h93`0@2a400P0A3180
400>2@l040/A014<4P0<1`d03PT?01<>500:1@/04@`B00d83P0D3aD04@`B018=4`0A318040/A014<
4P0B3A<2014<4P0601D@5P0A31803@P>010;4@0=20h040/A0P0?2Q00100>2@l03`X@010;4@0@2a42
00l:400G00h93`0?2Q0040/A00`72`0D3a<030L;018=4@0A31003PT=00`72`0:1@T04@`@00l:3P0Z
9BT08QdQ00d;3P0?3A004@lB018@4`0@3Q402`T<00`:3@0?3A000P0@3Q40400?3A003@/>00T8300?
3Q801PD901@C600[:Bh03PdA00`:3`0;2Ph02PX=00/:3`0=31003P`@00h;3@0?2``200h:2`803@T:
00H030P900X61`0>2P/02@D6014=3P0<20T400l;308040`=00L03`/<00`82@0A3@h040`=00d92P0D
41405Q@H00803@/@0P0>2@l01@0A318040T@01094@0A2Q804`TB00804PPA00@03PL>014:4@0?20l0
40T@0P0B2a8300l83`040109400A2Q404P/B00l:408040/A0P0?2Q005P0=2@h061<I06AOI@0R7B<0
30L=00P42@0F4AL04PhC02/V;00@2a403`/@01DA5P0>2Pl03`X@00T42P0<1`d03@P>00T52P0>2@h0
30L;00h93@0A310200d8300C014<40060PD03@P<010;3`0:1@T04@`@00h93P080`T03`X@00h93`0=
20h050lE00h93`0G4QP04@`B02XU:`1@Be405Q4G014<400200l:3P0400d8300Q7200:RDY00d83080
4@`@00L040/?018=4@0?2Ph03`T;018<3P0>20X03`T;0080618D01<03PP:00l92`0A2`d03PP:00d7
2@0=1`P030L3014<2@0@2Ph04``E01094P0?20d03`X800l:1@0@2`@040/7010;2`0@2Ph03`/<00D0
3`/:100=2@P200l;2P0500`82@0D414071PI01PD5@0?2``00P0@30d0500A3@h04Ph?018>3`0B3Pl0
4@d>00`81`0?2`X040`;00d9200H51<040`;014=300?2`X040`;01<?3P0?2`X02@D400h:2`0?2``0
4`l@0P0A3@h01`0F4Q<03`/<014=3P0D41403`/<00d92P0<20T00P0@2`l2014<40P040/?00l04`/@
018<400D3Q804PdC00`:3`0<2a002`/@00X<4@0>4QL0JFie0;Nm`P0`=CT04a4E00d;3P0?3A000P0=
2`h06@0@3Q405Q@G01<A500C4A@04@lB00`:3@0D4QD04a4D034_<P0@3Q404@lB00/9300@3Q4061HI
00T72P0F51L020H903`k?@0F51L03`d@00h<3`0A3a803`d@010>4@0B41<00P0A3a803`0B41<04@lB
014?4P0A41803`lA018A5P0G5Qd040hH014?700B41d04@lK018@6@0D4aT05QDJ01TI6`06018A5P80
4a8G00P04Q4F01<B5`0D4aP05A@I01PG700E51T04a8G01LF6`806QTN00T02PT>01LF6`0L6b004Q4F
01HE6P0Q82H071`T01/K8`0G5b400P0D51h02@0H62@04a<O02TY=P0Q82h07ah/01PG9P0G5b<06aXQ
01TH7@0301PG700<01XI7P0G5Q/06QTN01PG700F5AX061LL01`L7P0I5aX05Q@E01@B4`0F51D040h?
0P0T8R<02`0G5AH071XK00/92P0F51D0518C01HD5`0E4aH05Q@G01@B5@0B41<05A<F0080518E00`0
4Q0C01TG6P0?3A006QPK024O8P0G5AP04@lB01LE600J61/05A<F01HD5`0D4QD201/I7005024O8P0C
4A@04`l@01HB4`0E4A800P0A3@h00`0C3a006ADF01@@4@0201DA4P0301<?400E4A805@lC00805@lC
00<05Q0D01<=4@0A2`l01@0C3A40200C3A804``C01@=500D3A@04``C018;4P0C31<050dD0P0C31<2
018;4P804@XA01`050dD01D>5@0?20l03`P?0109400D3A@05@hE00l83`0E3QD050dD014;400;1@T0
3@L;01TC5`0<1PX02P<:014:4P0<1@d06Q<K01<;5@0;10h04PXE06UPJ@0S62005P/C00l4300B1`l0
4`P@0P0A1Ph301053@0N01463P0?1`h0614I00d6400=1A803`LD0108600A21X04@PK01487@0C2B40
60hV01lG<00G5C402P/X01HD<00;1b404PdU00l97`0A2Ad04`TK01855P0?01004@4?01L7500D1a00
60/B01D83`0=0@L03`890P0>0@P01`0A10/05@P?01<63@0?10T04`H=00h52@0=0PP00P0?10X0200>
0`T03`@:01L<4P0B1`d040D;00T0100?1@X03`@:5?ooool001_ooooo0P0=2``05P0@3Pl04a4B014?
400<2P/03`d>00h<3@0P7Ql02PP901DC50091`P051@F00/;3@0E5AL03@d?00X92`0610L01`D801DA
5@0B3A404@`@00l93@0C3A4200l;30<040`=00d04@d>00X61`030000510A00l;300G4a@03@T:01<?
400J5QL071PI018>3`0D414040`=00804`l@03404Ph?010<3@0<20T02`H:00h;5P0K62<06AHM01@C
5`020P805aPC010C3@0<3`P02`h701<G400:30L02P`800/=2P092`X051HF00/<3P010P@051DG00l@
4P0>3a403a4A00lA400H6QL06QTG02LV8P1YJ6@0:2LS004000030P005A@@01LF4P0>3@T061LC014@
300C4Ph040l<00h=2`0920H04a8@024P7P0K6QP03Pd;00l>300A40h040l=008030/901P03P/:00l;
2P0A3@`04Ph=014=300@30/03PX9018>3@0@30/030P700l;2P0>2PT02PT700d<2P081`D03Pd;00/:
200920H03`h<01PG5@0G5Q@03`h<01LF500@3`d300d<2P0300`;2@0;2PP03@T800<04@/;0P0C2P/0
1@0B2`/03@T800`;2@0>3@/04A0>00804Q4?00@01`H4010?3@0D4a404A0>0P0<2`T0>00920H040l=
05mNG00L6aT03Pd<018A3`0>3@/03@`:00l>300A40h040l=00/:200?2`X04`d>00l93@0?20l04@XC
00d5400@21D040TB0109400@2Ph040X;00l;2P081PL040h?01<A4P0?3@h040h?01<A4P0>30d05Q@E
00X82@0G5AH05A<D00<1100=2a404PlF00L42`0A3QD040dD06MTJ`0N6b801P<:00T63@0>2a8030T@
010>4`0:20/06aTL04=1A00H5QT0518E00/9300<2Pd03P`?0P0?3A0200d;3P0800P62@0A3a804Q0C
00`:3@0l>Sd0MWAg00h<3`081PT200d;3P0900L5200G51L030L;00P31`0>2@d050lC00T4200G4QH0
50lC00804`hB00X04PdA014<400B3A8040/A00T42P0D3aD02`H<00d83P0E41H03@P>0P0<1`d01P0>
2@l03`X@00l:400<1`d03@P>00l:40802PD;01<03PT?00d83P0Y92X04@`B00`73@0=20h04@`B00d8
3P0:1@/03@P>010;4@0A31803PT?00`73@0?2Q004PdC010;4@0C3Q@040/A00803`X@00L03PT?00l:
400@2a4050lE01<>500@2a403PT?00803@P>01D03@L;00l93@0E3a<030H:010:3P0B310040X>00`6
2P0D3Q803PP<00@00P070PD01P@700L520091`X02`T<00X82`071@P03P`?00l=400@3Q400P0?3A00
0`0>30l020L<02TZ;`0201hO900405EFF`0;314030dB00`=4P802P/@00@02``A00`;400<2Pd03PX;
0`0=2@X01@0<20T04@d>010<3@0@30d03`/<008030P91P0?2``0100>2P/03`/<01@@4@0>2P/2014=
3P0701<A500<2Pd03@/>00l:400>2@l040/A00l83`0301<94P804@L@00L050dE01H?5`0@2A403@H>
00`53@080@T03`P@00803PL?0P0?21003P0@2A403PT@014<4`0@2a803PT@00l:4@0I51/01P48040k
@P0<1`h07APO00<01@0:1@/02`H<0P0<1`d0300X8bT03`X@00h93`0D3aD04@`B01@?5@0=20h01`88
01TD6@0B3A4030L;00h93@803@P<00P04PdA00`72`080`L04@`@01@?4`0@2`l03PT>00@01@803PT?
018091lU034/<P0E41H0100500D01P0A318030L=01HA5`0>2@d05A0D00/62P0>2@d04@`@01HA5@0>
2@d04@`@00l:3P0=20`2010;3`0C00T31@0>20X02P@600X41P0D3Q004P`>00l92`0A2`d04P`>00h8
2P0<1PP03@L8018=1`0>2@<04@`:04@n@P0E3a<03`X900l:100200l;000300l;0P0A2`T04@/=00H0
3`/:00<03PX900l;2P0@30/00`0@30/01@0=2@X030P9010<3@0@30d030P900<03`/<0P0@30d0700A
3@h04Ph?01@@3`0B3Pd04@d<018>3@0O6aX040`;01DA400>2PT0510?01<?3P0<20L05A4@00d92P0>
2P/04@d>00l;300>2P/04`l@018>3`0300003PX;014=3P0G4a@02PH700l:3`0@2a42014<4P0300l:
400>2@l03@P>00D03@P>00l04PT>010:3P0E3a<04PdC00`:3`0>3A8020T>00`?5P083A<0@4I<09RO
Y@0I7R804A0D00`:3@0@3Q400`0?3A005@0@3Q403@/>01<A500E4aH03@/>00l=400=2`h0Cde@018@
4`0J61/03@/>018@4`071@P07adP018@4`0d<SD0_[bo02d[;P0@3Q403`d@014?4P0200d;3P04010>
4@0A3a804@lB018@4`804@lB00`04A0A010@4P0F5AX07A`S00l=600?3AX04Q0M01<A7P0C4Q/04Q4G
014@5@0A4A<6018A5P8051<H00D04a8G018A5P0B4AH04a8G01TH7@0201HE6P0G01/J7`0M72406aXO
01LF6`0O7R<06QTN010?500D4aP04a8H01DE7@0<31H051@N01lO:`0F5R8051@P01`K:@0C4R005aHT
00X96@0L6b/05QHR01hM9@0H5a`00P0J6Ah00`0H5a`07QdR01XI7P0301PG700Y01LF6`0D51H09B<V
018@4@091`P061HG00l=3P030@8020H701PF5`0J61T04a4B01HD5@0M6a`03`d@00d;3P0B41<04a4D
01DC5P0N71l07A/N01@B5@0W9BP06QPK01@B5@0;2@`061HI01@B5@0A3a805aDH01TG6P0E4aH0518E
01<A500M6ah04Q0C00T72P0F51L06ADF01XF5`0H51D00`0D41401`0B3Pl03`/<01<?400D414040`=
014=3P0F41@00P0B31000`0E3a<050hB018<400501<=4@0701<=4P0D3A@050dD01@=500C31<04P/B
01<<4`0201D>5@0401@=500C31<04``C01@=508040T@00@04@XA00d63@0@2A0050dD0P0B2a805P0A
2Q404P/B018;4P0B2a4030H:00T31`0:10P0208600X32P0F3aH02`@<01<<500=1Pl04`/F024I902V
W:D0AS]300`32@0G31@06a0H00l4300@1@d401463P0Y01063P1BB540BdA<01084`0<11405PhK01`C
8`0;0QD03@@G01067@0@1Ql04PPQ01P@:`0/;D/0724o028VA00A4Rh051@^014<900?1ah03`HK0185
600F1AL05PDE01@34P0P4a`06`hE00l32@0>0@P050L>00l22@0@0`X04@@;00`01P0@0`X04`H=00P0
0P0B1`d060dC01D:400>0`T00P0:00D200L00P0400h32@0E2Q005@X@00L00QCooooo000Kooooo`0H
010>3P0=30/03@`;01DC4`0_;Bd051<B018A400=2`/04A0?00H5100>3@`02PP800X9200A41002`X9
00`;300B4A403@`;01<A4`0@3Pl03@X:018?40091PP04@d=0`0@30`04P0A3@d04Ph>014=3@0@30`0
510@01DA4@0A3@d03`/;014=3@0B3Ph02`L701PD500D41003`/;010<300?2`/04@d=01<?3`804@d=
03H04Pd@01<>5`0B3QH03`/B014?4`0=30h02`X:01DE500;30/04a@B00/=2`0F5aL030d<01<D4P0:
2@P03Ph<00d>300<2``030`<00h?3P0A41402`/:00X;2@0D4a405QDB00/91P0P7Q/03P`901<A3P0?
3@X03@X8018?3@0:20D04Pl=01<@3P0A3``03@/9014?3@0B40h03P`:00h;2P0@3P`03P/:01TG5@0h
=S@03`d;010>300B40h040`;00h:2@0E4A006ADD014=300@30/200d9200F018>3@0D40l0920O01DA
400;2PP04a8@00/:200E51803@`:00l>3@0C4Q003`h<00/:200@3`d03Pd;010?3@0;2PP03@`:010?
3@0A40h03`h<00`:20803`d;02P04@`<018=300B3@d04`h>00d;2@0<2`T03@`:014@3P0;2PP03@`:
00`;2@0A40h07A`J01LF500;2PP04Q4?01@B4P0:20P04a4A00h=300A40l02@P700l>3@0;2@T04Q0@
01LE5@0A3`l02PP800l92P0C3@l03PP<00d73@0B31@03`/B010:4`0?2Q803PX@00d93`0R7b<03P/>
0P0>30h0@P0:20X02`T;00h<3P0D4Q@03P`>010>40081PP02PP:00h<3P0=2`h030X>00d;3`0<2Ph0
4Q0D01/I7@1PGV807adQ00`:3P0>310040hB00`:3P0>31003P`>00X92P0M6ad02PP:010>400;2@/0
3`d?014?4@0>30h040h@00d;3@0@3Q003`d@00h<3`0610L05Q@G01TG6P0<2Pd04Q0C00H41`0B41<0
2@L:00P62@0=2@d05a8G00h93P0A314050lD00X52P0C3Q<04PdB014<4@0@2a003`X?00h93P0?2Q00
3@P>01@?5@0@2a403PT?00d83P0?2Q002`H<00`73@803PT?03804@`B01<>4`0@2`h04@`A01LB5P0E
4A<03`X?00h93@0E41<0:RDZ01/F6P0@30h03@P=00/6300<1`h040/A01<>500B3A<03PT?01PC6@0@
2a403`X@01<>500>2A0030L>00l:400>2@h03`X?00h93`0=20h040/A010;4P0B3A@050lF014<500B
3A@03`XA010:3`0?2Ph05A0D00`62P0>2@d040/?01<=4@0<1`X05a4E04M2AP0K5AT03PX=014<4080
3`/?00<040`@014=4@0@3100100@3100:@0?30l03P/>01PG6P1?CU003@/>00T72`0>3A409R@Z01@B
600?3AD02`TC00`:500=2aD02`TA00X8300@3@l030T;00l<3P0@3@l02`P:00X72@0=2P`03P/=010=
3`0<2@/03@X;00l;2`0>2PT03@T900l;2`0B3Ph04`l?00h:2`0E4A804`l@010<3P0C3a403@T;00l;
400>2`l03PX?00804@`B00X040/A00l93`0@2Q404@/B014:4P0@1`l03@L>00h83P0A2a803`T>0P0?
2A001`0=1`h04@XB014:4P0?21003`L@00l6400>1`l01@0>2A006P0<1`d040/A00l:4@0>2A003@P?
01D@5`0>20l04P`B01L?5P0>2@l050hD00X42P0?2Q004@`B00X730081@X02PH<014>4`0O6al04`lA
00`82P0<1`X030P:00d92`0<20X04`hA0P0@2`h0600?2`d02PH8018=4P0<1`d03`X@00`73@0J5A/0
7aXP00`73@0;1P`04@`B01@?5@0<1`d03@T>00d72`0@2Ph03@P<01@>4P0>2@d04@`@010:3P0B3100
4@/?00h830803PT=01/04P`?018=400@2Pd03PT<014;3P0?2@`03PT<01/E600Q6ah02PD7014<3`0?
2P`050l=00`71@0G4Q80?STk01<>3`0@2`/02`L3018>200=2@<06aHC01D@3`0E41803PX:00l;2`0@
30`00P0A3@d00`0@30`03`/;010<3003014=3@07010<300C41002PP700h;2`091PH03P/;01DB4P02
00l=300900h<2`0>2`/03`d<010=3@0@30/03PX900d9200>2PT05Q8A008030P701403`/:00h:2@0>
2PT04@d<010;2`0A2@d03`P;0108300?1`X03`P9010;300C3@d04@d;018>300@30X04Pl<00h:2@02
00h:3`0?01<?500@3A403@T>018>4`0?30l03@X>00h;3@0@3A003``>00h:3@0A310050lC01lK7`0V
92P04Q0D00804A0D01<01PD:00`=4P0@4QL04A<H014B5`0?3A8040hB018@500?3A4040hB018@500A
3a<03@/?00h<400@3Q803`dA014?4P0B3a4030X<00803`d?01402`X<018A4P0<2``04A0A00h>3`0B
4a@04A8C01DE5P0@3a403`h@010?400>3@l03`h@014@4P0@3a404A0A01<B5002014@4P0F018@4P0@
3a405A@G01XI7@0C4QP04A8I00d<500?3QH04Q4G01<A5@0B4A<04A0C01@C6@0F5AX05A@I01<B5`0E
51P05ADG01@D5`0C4aH05A@I01HE6P8051<I02X05QHI018C500C51D06Q/K01/K7P0H61`04Q8G01@D
6@0B4QT04a8J01PH800H5b406QXY01@B900N7Bh0=SE503hmC@1BDF006aXX01PH9@0I62D05aHR01@D
800J6RD07A`T01PF7P0H5ah05aLN01HH7P0I6b405QPN01PJ800H5ah05QDL01HD6`0D4aP03a0B03Lh
>00F5aL04a8B01HE5@0A410201HE5@09014?400B41404Q0A01LD5@0C4A<05A<E01PF600J61X04a4C
00805aDG01h0518D04=1@`0[:B/06ALI01LE600E4aH09B<W028P900D4QH06aTM00h<400D4QH03`dA
01DC5`0J61`04@lC01LE600E4A804`l@018>3`0D41404Ph?01DA4P0B3Pl04@d>018>3`0G4a@05A4B
010<3@0E3a<2018<400301D?4`0D3Q804`dA00@04`dA00h04P`@01D?4`0@31404P`B018>4`0@2Q00
4P`A014;400G4AH04@X@01@=4P0@20h050`B01D=50804P/B00L05PlF01<<4`0@2A005@hE00l83`0>
1`h05@hE00803`P?01804PXB01@;4`0E3AD04`/C0109400@2Q403PPA00h:4P0B3QH05A4J06EPJP0d
<SX06a@L01463P0B20l050TA01463P0D2A4301873`804@H>03404`P@03H]=014?4@04@L@01hB800A
1aD040@G01477@0A1b403PXT010?:`0@4Rh061hj02`jE01?GWP0A51/01hXA@0J8D00414b01@B<00E
3R`05`dV01T;800E21X050DD01lC700H31@03`@:01453@0G2a804PH=02HJ800H31402`4501H:3`0P
51X04@H;01052P0@1@T02@0101042@0C1`/03`@701<8300B20/040D800`21@0=10H05``?01Cooooo
000Kooooo`0600@30@0<2`T020L500H50`0H5aD02PT7100>3@/200l>300=018A3`0H5aD04A0>00l>
300B4@l030/900/:200920H07QdK00`;2P0D4a40ATE3018>3@02014=308040`;0P0?2`X07@0;1`H0
3@T801@@3`0D40l04@d<00T5100L61L02`L6038^;@0O6aX0510?01`H5`0F4Q406QHE014=300;1`H0
3@T:010:3`0A31803@P>010;4@0A3a@03@/@00d<401?CU<04Q4F00d=4@0?3Q<03`h@00D03Pd;00/0
3`h<01HE4`0G5Q@03Pd;00`;2@0>3@/03`d;014=300B3Pd040`;00h:2@0300l;2P804@d<0`0@30/0
8`0?2`X03PX900h:2@0>2PT03`/:01@@3`0300008QhM01LC4P070`801P8102<O7P0A3@`06ADD01dI
600D40l04`l>01HB4@0I5A@02PH500d9200F4Q402`P700h=2`0100003Pd;0040000>3@/03@`;010?
3@0?3P`03@`:00`;2@0=30X040l=008030/90`0=30X00`0<2`T03`h<00l>300200l>3005010?3@0B
4@l030/901XI5`0B4@l00`0>3@/02`0920H03@`:00L6100<2`T051<A00D40P0=2``030X;01@B4`0E
4a@03`d>00<03@/<01805Q@E01LE5P0?3@h03P`=010:300C3Pl03@T:00d8300A3Q403@/>00H42@0I
5a`01`H;00/:4029R8h0;B`a00h<4@0>30l200d;3P803P`?1@0<2Pd0700=2`h04Q0A00P61`0;2@X0
3P`=00L51P030@8020H700H41@0;2@X03P`=00l=3P0A3a0040h?014?400>30d03@/<00h<3@0<2P/0
2PP901/I6P0F51D04@l@00H41@0<2P/03@/>00h<3`091`X201HD5`0=00H41`0?3A004@lB00L5200=
2`h0518E01`H7@0?2Q004`hD014<4P0<1`d03@P>00h93`0500l:400A014<4P0=20h02`H<010;4@0<
1`d02`H<00h93`0<1`d06QDK01@@5@0300@04`hD01`H6P0B3Pl03`/<010<3@0A3@h00P0?2``01`0>
2P/03@T:00h:2`0?2``03@P;00d83P0=20l00`0?2Q402P0=20l04@`C00`73P0>2A005A0G018=500>
2@l050lC00h93@0<1`/200`73@0801<>500I51/05a8I00H22P0:10h00`0701@?5`0?2Q0200l:3P<0
40/?00L04PdA014<400:1PT0;bX^00l:3P0@2`l03PT=00803`X>0P0@2`l00`0A31003`X>010;3`02
010;3`0?00l:3P0=2@X07QXI00/71@060P4030P901@@4`26PHL0<bhe018<5`0=1a<03PPF00/5500L
5R8081hS008020H901<00@0200/9300?3A002PP;00/9300?3A004Q0C01<A500A3a0030P700d91P0>
2PL040`;014=300B3Pd05Q8C01LC500A3@h03@P<00804@`@00<04@`B010;4@0>2@l00P0>2@l00`0<
1`d03PT?010;4@02014<4P0300l:400>2@l03PT=00<03`X>0P0>2@l06P0B2a<04``D018;4`0A1a80
40HA00l74P0?2Q403PT?00d83P0<1`d02PD;00h93`0;1P`050lE018=4`0@2a405A0F00h63@0A1`l0
4PP@018:4@0A2Q4040T@014;4P0B3A<03P`A0P0=2a000`0>31403`/?00h:2`0200h:2`803`/<0180
3PX;00d92P0>2P/03PX;00d92P0?2``040`?00h93`0=20h03`X@014<4P0@2a403`X@010;4@0A3180
40/A00l:400=20h600l93@0T010:3P0B310050hB010:3P0>20`03@L;018=4@0<1`/03PT=018=4@0@
2`l03@P<01/F6P0300805a8F02<N8P0>2@d030L;010<3@0>2P/05Q8C01DA4P0;1`P040`=00`82@0B
3Pl03`/<024M7P0A3@h0<bl`010<3@0>2P/02`L800X61`0<20T03@T:1P0?2``03@0920H05QDC00h=
2`030P003`h<00d<2P0920H03Pd;014@3P0?3P`03@`:00h=2`0?2`X00P0>2PT06`0?2`X040`;014=
300>2PT04Ph=014=300>2PT03`/:01H@4P0C2A004PL=0146300B1`/04PT:01<:2`0C2`T04@`800d8
100>2`H04@h700h:1`0<2Pd02`T<01<A500@3Q403@/>01<A500200d;300=00h<3@0?3@h02`X800T8
1P071@P06ALJ00/9300H5QT020H900X82`0?3A003@/>010>4@0200l=4006018@4`0@3Q<04@lD010>
4`0?3A8040hC0P0?3A801P0A3a@040hC00d;400>31403@X<01@@4@804a4B00D03`d>00`<300B4Q80
3`l?00h@3`0200lA400600hB4@0@4Q804A4A010@400?3`l0410@0P0B4Q8200h>3P0N014A4@0?3`l0
410@01HC5@0G4QH05Q@G01DD5P0A4Q@03Q8C00`@4@0=4A804A8D01@B5@0C4A@04a0D01`I800K6R80
5A@I018A5P0E5AL051@D01PH600G5aL05aLI010?5@0<2a405aHM01LH6P0D5QD04aDD0P0F5aT0400C
51P0414F014A6@0C4ad051@P01DE8@0H5bH0518W01TG;@0S8CP06AL/01`K;@0l>d`05aHT01HF8P0D
51h301<C6`8061DP01805QHP01LG8@0E6B804aLP01@H8@0H6b@051LP018@6`0A3aX04Q4I00d>400X
:bX02`d<01<E500E5QH061PH00/;2`0D4a<201DC500?01PE5P0F4Q<09R@U01LE5P0X9RL0B4I703@b
<`0:20T05aDF01@B4`0H5QL05aDF01DC500I5aP04Q0D00808AlT01T040hC01lM8P0<2Pl07Q`Q010>
4`0F51T061HK01<A5P0I5aX05Q8C01@@4@0C3a0061@E014=3P0E4A8061@E01HB4`0B3Pl07ATJ024M
7P0H51D05Q0D01<=4@0A2`l04P`@00804`dA0P0B310201<=4@0/018<400E41@04@lB010>4@0>30l0
40hA01HA5@0B3A407ALK00d72`0@20d02`8701D<4@0E3A<04P/B01<<4`0D3A@04P/B0109400?20l0
2@8900d63@0@2A004@XA01L@5`0D31@05`dH01T?6P0G3QT04PXE014;5@0B31H05A8K00L43@0K6R80
fMSP09FEW@0C3A@08QLO03X_=`0H3AD01`0401483P0A1Ph201873`0U01053@0?10`04PL?02@K801S
FF408aHP01814@0G1QP05@PJ00`0600I42/03P`Z00489@0>73T07S5=055ZP02fcnD0/lSQ06]jV@0m
BV`0=ciS01LI?`0C4S@04``Y0188800@11P050LG0104400@10h040D=00l4300>0`X03P<90146300>
0`P02`0400d21P0200l4200:00P0000>0P@02P0000X0000900006Ph@01D92`0?0`D03P8401041P80
20005?ooool001_ooooo00T03`h<01DD4P0E518040l=00T81`0A40h03@`:00l>300@3`d00P0A40h0
3@0@3`d03Pd;00/:200T8b4061LE030_;@2NWI/0>cXh00h=2`0;2PP04A0>018A3`0D4a400`0B3Pd3
014=30803@T801`030P7014=300=2@P04Ph=01@@3`0H51<04Ph=020L6`0;1`H01`<200`81`0@30/0
20@3018>3@0H51<020@501<=4@0B3A4040/?018=4@0B41<040hA01DC5P0N7R004A4C01HF60061PP0
4a8C1@0>3@/0500A40h061LE01XI5`0B4@l03Pd;00l>300?3@/04@d<018>3@0@30/03PX900l;2P0>
2PT04`l>01LC4P0A3@`030P7018>3@0D40l03`/:0`0@30/06@0?2`X04Ph=00<0000>2PT04@d<01hJ
6@0C3`h08AdL010<2`0C3`h0510?01<?3P0A3@`02PH501/G5P0;1`H06QHE020L6`0/:2L03@`:00L6
100F5A<06aXH00l>300H5aD01P0>3@/200d<2P<030/900<03@`:010?3@0@3`d00`0?3P`06`0A40h0
4a8@02d/:P0M71X02`X8014@3P071P@03`h<01LF500920H03`h<020O7@0;2PP030X;00h<3@0B4140
4@l@00h<3@0@3Pl02@L8014?400G5AH04Q0A00`:2`0B41404@/=018=3`0200h:2`0:014>400>30l0
7A/P00P730030PL04a8H01TH7P0920d03`dB00l=40803P`?0P0?3A0200/9300^00`:3@0>30l03P`?
00l=400<2P/04a4B014?40081PL04a4B028P8@0D4Q<02`T:00`:2`0=2``03P`=018@4@0;2@X02PP9
00T7200?3@h040h?00/92P0<2P/08R0Q01`J6`0B41401`D6014?400<2Pd03@/>00/9300>30l030X=
00H41`0<2Pd0?S`o00h<3`0B41<02@L:00l;3`03008050lC00h93@070PH050lC00h93@D03`X>00l0
4@`@00d8300;1PX040/?00l:3P0=20`040/?00D0100300807APL01/F6P0>2@d04@d?014=3P0>2P/0
0P0?2``02@0>2P/03@T:00`82@0;1`P03@T:00l;300>2P`03@P>00h93`0200l:40<03PT?00H03@P>
01<>500F4AL04@`B00l:400A310200/62P0:010;4@0?2Q003`X@02`W;P1:AD`04`hE00`6400I4ad0
:R@]00l:40803`X>0`0>2@d010080`L050lC00`82`0?2Ph200h93@0300d8300>2@d03PT=00803`X>
00<040/?00l:3P0@2`l00P0@2`l0500?2Ph03@T:00H20@0B3Pd02PH501PD5@091PP0>SDk03Lb>@09
0`h03`TE01D?7@0H4R00@ce909NEVP0G5AP03P`?02PV:@10?T40518E0P0>30l0300?3A0040hA00d;
3P091`P02PH500h:1`0B3P/04Ph=00h:2`0=2@X05a<D01<>4P8030L;00`04@`@010;3`0C3Q@040/A
018=4`0A31803PT?00l:400>2@l040/A014<4P0B3A<2014<4P8040/?0P0A31002`0@2a403`X@01<<
500D3AD04P/C01084`0?1a8040PC00h9400?2Q403PT@008030L>00X040/B00<01@0<1`h040/B00P3
2P0A31<02`<;01063P0A1`l04PXA0P0A2Q400`0A2a8040/A00d;400300`:3`0D00d:3@0>2P/03`/<
010<3@0A3@h040`=00h:2`0<20T03PX;00d92P0<20T03@T:010<3`0?2Q003PT?00l:400@2a403`X@
00h93`0?2Q02014<4P8040/A1`0?2@d05P0A2`l04P`@010:3P0>20`03`T=010;3`0;1PX03@P<018=
4@0>2@d02PD900T42016@DD0CDQ<00@00`080`L04PdA01<?400=2@X040`=014=3P0;1`P200h:2`0;
01DA4P0A3@h02`L803Pd=@3;alP06aLH01DA4P0=2@X02`L800d92P0A3@h01P0>2P/030071P@0:RTW
018A3`0;2PP05aHD00`;2@0?3P`030/900L6100510802`X8018A3`803`/:00/03PX900l;2P0@30/0
4@d<010<2`0D40l04Ph=00l;2P0@30/05@lA01@:400201<83P0M0189300C2P/050/<01<>2`0A30T0
3@P500h;1P0B3`X04@d:00/92`0<2Pd03`d@014?4P0@3Pl03P`=00`:2`0@3Pl04@l@010>3`0?3P`0
40l=00l=400b<3<02`T<00l=400<2Pd040hA00l=400=2`h00P0@3Q405P0>30l04@lB010>4@0>30l0
3`d@010>4@0?3A003@/>00h<3`0A3a804Q0C00l=400>30l03``>01LC500C4A804Q0A00d;30051@D0
30`<00l?3`0?4A02010B4@0300hB4@0@4Q804Q8B00@04A4A00`04Q8B00h>3P0=3@d0410@00h>3P0?
3`l05Q@F01TD600G5AP05QDG018C5@0>4Q<200lC500A01<C5@0C4A@04Q0C018>4`0A3QD04A0H00h=
4`0?3Q<05ADG01HF5P0D51@05aLG01PH6P0?3Q@04A0F02/Z<@0E5QX00P0E5QP04@0E5QX051DI01<D
6@0A4AT04Q8J01@D7P0F5R005aLQ01LG900Q83807A/`01`J;`0Q7c@0<S5301TH9`0G5R@05aLR0080
5QHN00@051DJ01<C6`0I5R406aPS0P0K6bD01@0G6b@05ATR01HJ8`0E6B805APQ008061HQ03406APP
01PI6`0B5A@04A<B02<U900C51@06QXJ00l?3`0E51@05Q@E01PF5`0K61T05Q8C01/I6P0@3Pl05aDF
02`Z:`0N71d02`T:01DC500C4A805Q@E01DC500D4Q<05aDF01<A500B41<05Q@G014?4P0N71l04Q0C
014?4P0E4aH06QPK00X82`091`X05Q@G01LC500B3Pl04@d>01XF5`0C3a005Q8C01DA4P0B3Pl03PX;
01PD5@0O6a`06ADF00805Q0D00@05@lC01<=4@0@2Ph03`T=0P0A2`l01P0B31004`dA01@>4P0@2`l0
3`d@018@4`803P`?01L050lC010:3P0I4aL040X>01TA5P0A20d04`X?01493`0A2Q404P/B01<<4`0A
2Q403`P?01D>5@0M5Qd08AXQ01<<4`0@2A004``C00d4300C2A805P`E01@<500201094@0Z00d83`0@
3A@07Q/R00d;4@1?CU@0=C@j00`53@0;00P04`T@01T>5P0F2a<04PL?00l4300A1Ph04`P@01463P0@
1@d04@H>00H0100Z82P04`H@01H55@0O3R00?2a101lA:P0O5S4061Hd01PO?00]>5@0<dAP08VO]P3M
lol0k_oo0=;Qo`20SJl0?D=X01XJ?P0D434040TU01<:7`0C21T05@TF0P0A1@l05P0A1Ph040D=0105
300?10X01`0201D:3`0@1@T0200100/1100=0PH04@D90104200F2Ph0710D00h31P0E2@d04`L;0147
2@0800002`0301/?4`0D20`Dooooo`006oooool0200A40h02@P6014@3P0>3@/05QDC00h=2`0@3`d0
4A0>0P0@3`d03P0?3P`03@`:00/:2@0D4a4092<Q01HE4`13@T00^[Zh03/j>00D4a403@`:00h=2`0@
3`d03@`:1P0B3Pd0400A3@`05A4@018>3@0A3@`030P701@@3`0A3@`01P8201XF5@0810<06aLF01DA
400A3@`02PH6010<2`0C3`h2010<2`04010:3P0@2`l040/?014<40803`d@00<0<S0c09ZJW00S8bD0
0P0@41800`0=30`03Pd;00h=2`0200h=2`0Y00l>300@3`d04Q4?01@C4@0B4@l03`h<00h=2`0?3@/0
4@d<018>3@0@30/03PX900l;2P0A3@`0510?01HB4@0B3Pd03`/:01@@3`0F4Q404`l>01@@3`0E4A00
510?01<?3P0?2`X04@d<01/G5P0?2`X08alN01XF5@0C3`h061@C01<?3P0>2PT0510?014=300@30/0
5A4@00l;2P0;1`H00P0C3`h0200D4a403@`;010?3@0?3P`04Q4?00l>300=30X03Pd;0P0@3`d01`0>
3@/03@`:014@3P0@3`d03`h<00h=2`0?3P`00P0A40h00`0@3`d03`h<00h=2`0200l>300=00`;2@0J
6AL03Pd;00`;2@0@3`d02PT700P71@0@3`d02PT700P71@0@3`d051<A00/92P0200l=3P0;00d;300>
30d04Q0A00/92P0A3a004a4B00l=3P0>30d040h?018<3@0A30d00P0@30d02P0@3@l03`d@00/93@0>
3A404a8G00`<4@0?3Q@02@P=010>4@0?3A0200h<3`0300l=400@3Q403@/>00D03@/>00L03@/<00`:
2`0;2@X02`T:01`J6`0[:BX05aDF00803`d>00/03@/<00X82@0=2``05aDF01PF5`0B41403P`=00d;
300;2@X040h?01DC500200d;300D00X82@0B414030X=00h<3`0A3a8030X=00X82`0@3Q4030/=051>
D@0I5aX02`T<00l=400C41<0?3Lk018=4@0@2`l02`H:01LB5P0=20`700l:3P0=014<400?2Ph03PT=
00l:3P0>2Pd04`hB018=4@1GDUH0EE1D01@?4`0=20/03`/<00h:2`0300d92P803`/<00@03PX;00l;
300A3@h03`/<1P0>2@l200l:400A01<>500B3A<03PT?01@?5@0@2`l03@P;01HA5@0P6b006QDJ00h9
3`0>2Pl07APN018=500>2A408Q`U02XU;@0?2Q000P0?2Ph02@0>2@d03@P<00d8300E41@030L;01@?
4`0@2`l03@P<00h93@0200d830803PT=0`0?2Ph3010;3`0]00l:3P0=2@X03`/<01LC4P0<20P05a<D
014=3`1LEed0<B`c010:4`0?2A@03@LD00P33`0Q6bH0<S0e00d;3P081`T03@/>00h<3`0:2@/030X=
01<A500A3a802`T<00l=400J61T03@T800l;2@0@30X03`/:00d92P0<20T03`/=00d8300:1@T03`X?
014<4@0=20d03PT?00d83P0A318040/A00d83P0@2a403@P>00803PT?00@04@`B018=4`0B3A<04@`@
0`0B3A42014<4P03018<4`0C3A@04P`C008040TC01004@XD00l94P0:1@d03@P@01D@600D3QL04`hF
01H@6@0A2a@03@P@00h94@0@2a<04P/B01063P0A1`l04PTA0P0B2a800`0A2a403PT?00`:3`0300`:
3`0300d93@0>2P/040`=00804Ph?00P04@d>00l;300>2P/040`=00l;300=2@X03PX;014<40<040/A
00D03`X@00h93`0=20h03@P>00h93`0200l:4003010;4@0?2@d03`T=00@03`T=00H03PP<010:3P0A
2`l040X>00l93@0B310200d8300700l:3P0;1PX020<701<>4P0@2`l06ADH01lJ7P0200l:3P0600h9
3@0@30d02`L800h:2`0D41404Ph?0P0?2``02`0;1`P040`=01dI6P0C3a00:BDV01TE5P0F4Q<04@d>
00l;300@30d04@d>00H03`/<00H030/9020O7@0;2PP04A0>01@C4@0=30X2010?3@0401<B400E5180
4A0>00T81P804@d<0P0?2`X01@0@30/04@d<00l;2P0@30/03PX9008030P700D03`T901<93@0C2@d0
4`T=01893002014:2P0=010:2@0@2`P040`9010<200?30L03PX700l=3P0@3Q003@/=014?4@0A3a00
2`T:00`:2`0200l=3P0D014?400H5aH07A/L01<A500V92L03@/>00l=400>30l04@lB00l=400>30l0
4Q0C010>4@0>30l040hA018@4`0>30l04@lB01<A500A3a8600l=400>01hK7@0W8b@0518C00l=3P0D
4Q<04A4A018B4P0>3Ph03a4@014C4P0@4Q403A4@010B4P0D51@201<C4`<04A4A00X0410@01<C4`0H
61P04a<C014A4@0E4Q@05A0D01<A500D51H051DG0`0?4a@0900A4Q@04a4D01<A500D4AD04@hE01/J
8P0O7R@051<H018B500C4a@05ADF01<C500C4QL03`hD018A5`0W9Rh04Q<J01HF7`0F5ah05ADN01LG
800D51d05QHO01DE7P0E5Al06ATR01XJ8`0I6B<071//02<R<`0E52D08B0`04M6E00U9C4061PS01XJ
8P806Q/P01<061TM01HG6`0K62406aTT01PH8P0G5b405aXS01XN9`0L82T05APQ01@G800G5B00518M
01DD700E5QP051LF028T8`0Y:bX04a@C00805QHF00/05aHG01HD5@0I5aP06QLH010<3@0F51D061HG
01<A4P0D4Q<04@l@01lM7P02018@4@804a4B0P0D4Q<0<@0K6A`0518E01LE600B41<061HI01HD5`0G
5AP03`d@01hL7`0C4A@05A<F01HD5`0H51D05A4B018>3`0G4a@040`=01HB4`0D41404`l@014=3P0E
4A805a<D01<?400A2`l0618F01XD600G4AD04P`@014;3`0B31004@/?018<400D3Q805Q0D01D@500E
4aH04Q0C01DC5P0@3Q403`X>01D@500K5AT030H:018:3`0?1P/05PdB01@<4P0B2a800`0C31<07@0B
2a805@hE00/42`0=1Pd04@XA0109400C31<040P?01<9400D2Q<050`C018;4@0@2A4050hE00D11@0?
2a804@lD00X93@0:2@h05@hE01873`0G3A@03P<;00l4300B20l03P<;01463P0D2A404PL?008040D=
01P04`XA01473`0F2A<05PHF01<75@0N3b<07@lX00l77P0b<4/07R8n034iE@1WMY00`]C^0>_lo`3^
oOl0c=Sb071iV`0c=e/07Adn01DB<00?22404`XL01<85`0B1Q4201453`804@H>01@04PL>01873@0@
1@/06PlD00l4200<0`D05@X>00`11@0:00<04@D;00X00`0=0PP02`4501L:400E2a003P@801/>500S
5Qh04PH<01052ACooooo000Kooooo`0600l>300F5A<071/I00P71@0U92806aXH0P0>3@/00`0=30X0
3Pd;010?3@02014@3P8051<A0P0C4Q001`0F5A<06aXH01/J600510804Q4?014@3P0920H00`0A3@`3
018>3@0J01<?3P0810<02`L600l;2P0G4a8030P7018>3@0@30/04Ph=01HB4@0300003PX9028N7@0L
61L03@T8018>3@0I5A@02`L6018<3`0C3Q805a8F01HA5@0@3Q404@lB01`J7@13@dD200h>400500D5
1`0?3Pd03`h<00l>300>3@/00`0=30X00`0:2@L02`X800l>300200`;2@0:00l=2`0A3@`04Ph=010<
2`0>2PT03`/:018>3@0A3@`040`;014=30804`l>00@04Ph=014=300A3@`04Ph=0`0A3@`0500=2@P0
4`l>00l;2P0:1PD040`;01@@3`0I5A@04`l>00d9200B3Pd040`;00d920060P405A4@00l;2P0P71/0
5A4@00h=2`0`;bd0:2LU0P0100001`0?3P`03Pd;00l>300@3`d03`h<00h=2`0<2`T00P0A40h3010?
3@03014@3P0?3P`03Pd;00<03Pd;01/040l=01HE4`0?3P`02@P601LF500@3`d04a8@00l>300I61H0
1`H401@C4@0_;R`05A@B00X82@0?3@h03@/<00`:2`0?3@h03P`=010>3`0?3@h030X;00h<3@0A3a00
2PP901<=3@0?2P/00P0@30d0200>2`d040hA065OHP0I5a/07ahS010?500920d01PD:0P0?3A0200h<
3`803`d@00h040hA00l=400>30l03@/>00`:3@0;2@`040h?00h<3@0A3a003P`=00L51P0610D03P`=
00`:2`8040h?00P030X;00d;300B41406ALH01<A4P0<2P/03P`=010>3`<03`d>010071XK00h<3@09
1`P03@/>014?4P0B41<03@/>00l=400F51L04Q0C01DC5P0>30l03`d@01/I700D41@0FUEI0P0@2`l0
0`0A310050lC00d8300500l:3P0900`72`0>2@d040/?00`72`0=20`03PT=01@?4`0B3A402PD90080
30L;00L04PdA01PC5P0?2``03`/<00d92P0<20T03PX;00804Ph?00D040`=014=3P0A3@h03`/<00l:
3P0200h93`0F00d83P0>2@l03`X@00/6300:1@/03@P>00l:400@2a4071LL01@@4@0?2``04@`@01HA
5@0D3a<04PdC00h93`0300@04@`C00X5300J5A`061<K010;4@8040/?00X03PT=00d8300=20`04`hB
00l:3P0>2@d020<7018=4@0>2@d03@P<0P0>2@d200l:3P03010;3`0?2Ph040/?008040/?01`03`X>
00d92P0N6Q/02PH600d9200Q7Ah03PX<014<40060@L02@@<00`6400>21804@/G018<5P091``01PD7
00<1100>30l03`d@00/930091`X04a4D010>4@081PT03`d@028P8@0@30d03PX90P0<20L0300>2P/0
3`/<00X52@0>2@d030L;00l:400A31803PT?01HA5`0M61h05a8H00h93`8030L=00@03@P>00`73@0=
20h03PT?0P0@2a42014<40804PdA00<04@`B010;4@0?2Q400P0@2a8200h84P0=010:500E3aT030H@
00l94`0F41X04P`F00L32`0F41X02@<=01LA6`0I4ad00`0701494P0201473`0601083`0A2Q404P/B
00l9400<1`d02`T>0`0<2Pl00`0=2Ph03`/<010<3@02010<3@803`/<00/040`=014=3P0?2``03@T:
00h:2`0@2a0040/A014<4P0?2Q003@P>00h93`02010;4@0400d83P0:1@/02PD;00T42PL03`T=0140
40X>014;3`0>20`03PP<018<400:1@T03@P<010;3`0<1`/03@P<02@O8`080`L071LK01@?4`030080
4PdA00/62P0200`82@07010<3@0F4Q<05A4B010<3@050@80510A01PD5@0200H20`0700T51P0;1`P0
3@T:00l;300@30d03PX;00`82@06010<3@0<014@3P0;2PP020L500l>300=30X04A0>00T81P0<2`T0
40l=018A3`0A40h03Pd;0P0B3Pd3010<2`03014=300@30/040`;00803PX900<03`/:010:2P0A1`/0
0`0B2@`06P0?2@T03PP8018<300D40d06ADB01LC400A3PT04@d:014@3P0A3a0040h?00l=3P0B4140
5A<D010>3`0<2P/02@L800X82@0A3a005A<D00l=40050`H03P`?010>4@0=2`h03P`?0P0?3A001P0B
41<040hA00`:3@0>30l04Q0C010>4@804Q0C00<04@lB018@4`0@3Q400P0=2`h02`0?3A0040hA00/8
2P0B3Pl040h?00d;300K6AX0<c<c030`<00?3`l03a4@0080418A00<03Q8A00lA4@0B4Q800P0B4Q83
014A4@06018B4P0G5aL07AdM01HF5P0A4A404A0A0P0?3A000`0B4aD051PI014E5P0200lC500T010A
4`0B4Q@0518E01LC600C4QX08B0X02TX;`0H5a`040lD010@4P0K6ad05ADG01<B5`0B4AL040lE014@
6@0A41h05QDU01LF900K6RP08b8`01/K9`0O7b/06QXT01DE7P0H620071`T01lO9`0E5B4071/Y01HF
8`0A4Ad03@dG028R:`0E5Ad05QLL0P0F5a/0100F5aX051DI01XG800K62<201LG8@0b01dP:@0W:c@0
6QhW01<G800G6R<06QPS01PF8@0P7bL05AHH01/N7@0H6QT04Q@C01@E5@0J6QX0410@01DD500E4a@0
5aDF01TF5`0C3a004Q0A010>3`0B41406aTJ014?400?3@h040h?01<A4P0A3a004a4B01DC500B4140
5Q@G01PF6@0E4aH04a4D01@B5@0G5AP04@lB02HT9`0k>C`0518E00h<3`0?3A005a<D01HB4`0D4140
6ADF010<3@0C3a0301PD5@0501HB4`0C3a004@d>01D?4`0C3A400P0@2Ph00`0I4aL081XN01@>4P02
018<400401<=4@0F41@04@`@01PF6@803@/>00T05Q@G010;3`0K5AT0:28V01XD600Q6Qh060lD01H=
4P0B2Q000`0C31<201@=500G02lX;`0U7RD04``C01@=500<1@`03`P?018:400A20d04PT>01@<4@0C
3A404@/?010:3P0F4AD061<G00T420030@@02PD900d6300800D06PlG01H;4`0J3aL00P0?10`07@0A
1Ph04`P@01463P0@1@d04@H>01H<500G3AD04PHA00/0300H2QT05@LJ00T04`040180;2U1010B:`13
BF40SiZd05ESOP2JZ<D0f>?o08jG^00f?5h05QPh014>;@0;1b802P@H01465P0A1a804PL?00803@4;
00/03@8:00h32`0>0`X03P<900T0100<0@H040D901/@500O51P02`0600h12P0201<63`0501/>5`0?
10/0200401853P0M4aT00P0800@00`0E21402`07ooooo`0Cooooo`006oooool01@071P@04Q4?01<B
40040`4051<A00804Q4?00L040l=00d<2P0=30X040l=01<B400?3P`01@@200804Q4?00P020L501LF
500@3`d0HV5O01TH5P0:2@L05A@B010?3@<040`;02404@d<018>3@0B3Pd04Ph=02<O7P0Y9B@02`L6
01TE500810<0510?00/71P0=2@P06ADD00<0000O6aX0AT91044m?00E4A00510?01hJ6@03000050h@
01LC500N6Q/071PI018@4@0C4A803`d>00P8200<30`01`L703@d=00K6aX00P0@3`d01`0>3@/030/9
00`;2@0>3@/030/900/:200?3P`00P0;2PP01`0@3@`04@d<018>3@0@30/03PX900l;2P0@30/00P0?
2`X5014=30<040`;00D04@d<00l;2P0J5QD040`;00h:2@0201HB4@05014=300@30/03PX900`81`0>
2PT0100?2`X02@0;1`H03PX900X61@0J6AL0]KBb06ASH@061@<08b8P014@3P03010?3@0300h=2`0=
30X030/900803Pd;0`0?3P`06@0>3@/03@`:00d<2P0=30X03Pd;00l>300A40h07QdK01TH5P0@3`d0
5aHD00d<2P0B4@l020L500d<2P01000030/9024P7P0920H02PP900h<3@0;2@X03@/<014?400:20T0
0P0@3Pl01P0:20T030X;014?400:20T050h>00l:2@804@d<00D03@X:014?400X9RT0?Sdo00l?4@02
014@5@0301<B5`0>30l03P`?00803@/>1`0>30l04@0=2`h030X;01TG600J61T02PP900T7200B4140
518C00l=3P0A3a003`d>00/92P0<2P/01P@500d;300;2@X03@/<00804a4B01L040h?01<A4P0F51D0
9R@U01<A4P0;2@X03@/>014?4P0>30l030X=00l=400A3a803`d@00L5200?3A004Q0C00T72P091PP0
81`M014=3P0;1`P04Ph?01@@4@0800l;300F00`82@0=2@X05A4B01<?400=2@X02@D6010<3@0B3Pl0
3PX;00d92P091@H03`/<010<3@0>2P/030P900l;300A3@h03`/<00h:2`0@30d04Ph?014=3P803`X>
0`0=20`0100?2Ph030L;00X52@0=20`2010;3`0>01LB5P0?2``02`L800`82@0=20`030L;00l:3P0A
318040/A00l;400300D05A0G00H2200B3A<2014<400500l:3P0>2@d03PT=00P31`0A31000P0B3A40
0`0D3a<03@P<00h93@0200l:3P8040/?00<04@`@00l:3P0@2`l00P0@2`l0200?2Ph03@T:00<0000W
8b<05Q8C00<0000?2Pd04PdA0P0E41H03@0B3A@03`XA00X53P0910/03P`A010>4@0W9BP00P0300L6
200@3Q403@/>014?4P0<2Pd00P0610L05`0=2``03PX;00d9200<20L03@T:00h93@0?2Ph040/?01<>
500?2Q003@P>014<4P0B3A<06aHL02TT:P0J5A/03PT?014<4P0=20h040/A00h93`0=20h03PT?0080
40/A00@040/?014<400A31004@`@0P0@2a402P0;20l03@XA00`9400;214030TB00d:4`0D3QX04@/G
010:5P0A2aL200l95@0>01H@700H4Qh0CTQD03dg@`0@2QH05PhG0188400A1`l040P?0109400A2Q40
3PP>00X52`0:20d200/93P0500X83@0>2Pl040/?00l:3P0>2@d00P0=20`03`0>2@d040/?010;3`0>
2@d030L;00d8300>2@h03`X@014<4P0?2Q003@P>00l:400A31803`X@00d83P0200/6300300`73@0?
2@d03`T=00@03`T=0`0A2`l200h8300=014;3`0?2Ph03@P<00h93@0=20`03PT=01dH700>2@d01`86
00X62@0C3Q804@`@010;3`03010<3@804@d>00T03`/<01<?400=2@X02`L8018>3`0N6Q/02PH700d9
2P0?2``00`0B3Pl00`0@30d03`/<00l;300400l;300>018A3`0<2`T040l=00`;2@0@3`d04a8@00`;
2@0F5A<04a8@00T81P0;2PP06APF01<?3P0B3Pd4010<2`0L014=300@30/03`/:010<2`0A3@`04P`<
01892P0C2P/050/<018<300@2PX03`T901DA400F4Q406aLF01LF4P0B4@d051<?00h=2@0?3P`04Q4?
00l>300F5A<092<Q014@3P0=2``030X;00d;30803P`=00<04Q0C00T72P0E4aH00P0B41<0200C4A@0
3`d@00l=400C4A@040hA00`:3@0=2`h040h?0P0A3a004@0?3@h040h?014?400?3@h03@/<00l=3P0A
3a0040h?018?400P71d071XK00l=3P091`P0410@01TI6@0?3`l03Q0?00803a4@00D03Q8A00lA4@0?
3`l04A4A018B4P02014A4@0b018B4P0A4A404a<C01LG5`0B4Q803`l?018A4`0A3a@040hC01<C600D
61/03a@G014F6@0@5AP04A<G014@5@0B4AH0518G00T8400B4QX061TO018C5`0A4QH04Q<E01DF600A
4Q@051DI01TJ7`0F5Qh05QHQ01@C8`0H5bT06APZ02<R<P0^;Cd08b<`038b?P0X:38061PQ01@D700G
61d06AXO01PH8P0N7RX04Q8M01XJ900E5Ad06ATP01DF6`0E5QX201@E6@0Y01DF600E5QX06aPQ01hL
9`0K6bD061PR01/O:00T:3405ATR018E7P0J7BH07Q`W01lL9`0^;CD08b@X01`N800E5QP03PlA01DE
5`0B4Q@03`lA01HE600G5AP05Q@G01PD600E41@05A<D01TG600G5AH06aTJ01@B4`0N71d040h?01@B
4`0A3a004a4B01HD5@0B41405Q@E01PF5`0@3Pl0100E4a@0300n?3d0EE=D01XH6@0E4a@06aTJ01LC
500A3@h0510A02<O800F4Q<04Ph?01DA4P80510A01/04Ph?014=3P0C3a005Q0D01D?4`0A2`l03`T=
01PB5P0O6Ad05@lC01<=4@0B31004`dA01D?4`0B3A40FeUL06e[KP0_;C005A<F010;3`0F4AD09R0T
01lI7@0/92T07aHK01L>4`0@20h00P0A2Q402P0B2a804``C01<<4`0M5Qd040T@00L01`0:0`X03@H=
018;4P0@20h200h5200@0149300A2`d03`T;01<=3`0A2`d01000010:300A3@h030H801<;4@0W72@0
=b`d00h32`0700@060dE01463P804PL?020040D=00l4300B1`l04`TB00H01@0<0`d04`LE00h2400E
21X09AT]01H=8P0C3bD071db01/P=P0e?5D0;cQE04QCL@1dO9/0CU=c03DhF@0K6cX030TV00T5700=
1aT04PLE01063`0C20h03@8:00h2300>0`/03`@<0105308040D;01403`@901<8300H3A405@X>00`1
1`0@0``0200501853`0K3QP03@0:028E7`0800D0NFaf04i1B`0800D0300900h12`0Dooooo`006ooo
ool0600=30X03`h<014@3P0A40h040l=01@C4@1/JfT09B@R00/:200B4@l03Pd;010?3@0C4Q003`h<
00X91`0920H04Q4?01<B400;2PP0:2LU00/:200A40h03@`:00/:208040`;00P03`/:018>3@0B3Pd0
3`/:01@@3`0d<2l0?c/j014=30804Ph=00h0;BTX02XV9@091@@03`/:01LC4P0A3@`05A4@00h:2@0@
30/03`/:010<2`0F4Q404P`>014=3P80510A0P0>30d00`0?3@h051@D01<C4`0200h>3P07010?3P0>
3@/04A0>010?3@0:2@L03`h<014@3P0200h=2`07014@3P0>3@/03@`:018?3P0E4A004Ph=00h:2@02
01<?3P0400d9200>2PT04@d<018>3@803`/:00`040`;018>3@0A3@`040`;014=300B3Pd04@d<018>
3@0:1PH05A4@01<?3P0;1`H2010<2`0A014=300@30/040`;01<?3P0>2PT0510?00d9200@30/03@T8
01HB4@0J6AL0?Sdk03Th=P0?3P`02`X800`;2@0@3`d00P0<2`T01@0D4a402`X8010?3@0=30X03Pd;
00<03`h<00<03Pd;00/:200<2`T0100>3@/00`0=30X03`h<00`;2@0200h=2`804Q4?01/03@`:014@
3P0<2`T02PT801LF500;2@X030X;00d;300?3@h03P`=00/92P0>30d040h?00`:2`0;2@X03@/<00/9
2P0C3@d03`X9010<2P0@30/03P/:010>3P0B4180AdI803@d=P0=31000P0:2Pd0500?3A0030X=00L5
200@3Q403P`?010>4@0>30l04a4D00h<3`0=2`h040hA00h<3`0@3Pl03@/<00h<3@0?3@h03P`=00l=
3P0>30d030X;0P0>30d200`:2`8040h?00`03@/<00l=3P0@3Pl02`T:00d;300A3a004a4B01/I6P0A
3a003P`=00d;3P0?3A0200`:3@0400h<3`0<2Pd030X=014?4P<02`T<00@04@h@00X71`0I5AH03@T:
0P0?2``01@0=2@X040`=014=3P0@30d04@d>00804`l@00X04@d>00/7200A3@h0DDe>01hJ6`0:1PL0
3`/<010<3@0<20T02`L8100?2``0100>2P/03@T:00l;300A3@h300l;308040`=0P0?2Ph01@0>2@d0
3@P<00h93@0?2Ph02PH900<040/?01T04PdA00l:3P0<20T03@T9014=3@0A3@l03`/=010;3`0@2a00
4`hC00/6300F4AP04@`C00d83P0B3A404@`@00l:3P0B3A403PT=00h:3@0<1`/03`X>00`72`0?2Ph0
3@P<008040/?00@04@`@00h93@0>2@d04@`@0P0@2`l200l:3P8040/?01d03PT=01@@4@0=2@T04Ph?
014=3P0C3a402@D800l:3`0=20d03PT?00`73P0=20h050lF00/93@0D4QD0?3Xm01PF6@0?3A002@L:
00/9300>30l02`T<014?4P0O7B003P`?00h:2`0>2PX03`/;00l;3@0200l:3P0505=>D`0a;3804PdC
00h93`0A31<00P0B3A<00`0K5Q`04PdC00`73@0200l:4003014<4P0?2Q003PT?00803`X@00<040/A
010:3P0A2`l00P0A3100500B3Q@04Q0E00d:4@0<2Q002`T@00`;50051@`040lG010;5P0B31L040XE
00d74P0?2A@04@/F01DA6P0l=T40@ce8038/=`0C3AP040PA0P0C2A403`0A21003`P?0109400>20h0
5A0F00l=4P0D4QL0=S@i018@5@0@31403`X>00h93@0=20`02`H:00`72`0200h93@0@00l:3P0>2@d0
3@P<00d8300=20d03`X@00d83P0A31802`H<02@O9@0e<3H03`X@00d83P0>2@l040/A014<4PL03`T=
00P04P`@014;3`0?2@d03`T=010:3P0B3A403PT=00`72`803@P<00T03PT=018=4@0?2Ph04@`@01/F
6P0D3a<040/?018>3`0C3a000P0?2``01P0>2P/03`/<00l;300<20T05a<D010<3@803`/<00P02`L8
018>3`0=2@X03`/<01@@4@0:1`L03`/<00h:2`804@d>01@03PX;00l;300=30X03`h<014@3P0:2@L0
40l=00l>30081`D07ahL02LV900C4Q002`X900h=2`0?2`X04`l>01HB4@0I5A@03@T8014=30803PX9
01l03`/:010<2`0A3@`040`;014;2P0C30/050d<01<=3@0A30`04@`;014=300=2PT05Q@B00d<2@0C
4a003`l:00l>2P0=30P04Q4<010?2`0C4Pl07QdJ010?3@0;2@X030X;01<A4P0C4A<040h@014?4P0B
41<02PP;00<04@lB00h040hA014?4P0<2Pd04a4D00H51`0C4A@03`d>010>3`0?3@h03P`=010>3`0A
3a003`d>00h<3@804@l@01003`d>00h;300@30d03@/<01@B4`0]:b`0>SXj01DE5@0?3`l03Q0?00lA
400>40l041@C01<E500G5aL04Q8B0`0A4A40<00E5AD0410@010@400A4A403@d=00h>3P0E51L04@lE
01DD6@0?4AH061/O018G6P0T:B`05Q/O00hB5P0D5AT051<I018@5P0A3aX04A4K018B6P0B4aP061TM
01<D600E5QT051DH01<D6@0E5Ad05aLO01LF8P0F52P07A/`01@B:00Y:3X0=SE502h]?00g=d<0:RXd
01PH800F5a`061TM01<D600>3aD08b<Z01HF7P0E5A`061TN014B5P8051DI00/05AHJ01LH6P0H6A/0
5aPL01XG800L6B@061PR01HF800C5Ql05ATR01TM9P0201DH8@0N01HD7`0D4Qd06aXR01TJ7P0C5AL0
4Q<E03@e=`0J6ad04Q8D01LG6@0G5QT061HI01HD5`0D41@06QDI01LE5P0C4A806aTJ028P8@0G5AH0
5A<D01@B4`13@D806QPI01PF5`0B41405A<D01LE5P0D4Q<03P`=0P0F51D01@0C4A805Q@E01@B4`0O
7Ah040h?00805Q@E00L05a<D00h:2`0F4Q<0:RHW024M7P0B3Pl05A4B00804Ph?0P0C3a00100D4140
5@lC01PB5P0H4QH201D?4`805Q0D0`0E3a<0:`0F41@08ahR0;:`/`3Zj>/0FEMJ018@4`0C3Q804`dA
01PB5P0?2@d04``@01<:3`0F3A805@dC00h73P0?20l04``C014:4@0D3A@06a@K01TB6@0F3aH05@hE
01<<4`0@2A0030H:00h62@0?1`X04P/>018<3P0C2`h04PX=01XB5@0A2P`040P;014:300A2@`050X?
00h32`0I3QH04`P@01L<500C21000`0B1`l0<`0@1@d04@H>01<8400@1Pl040LA01<9500K41h04@DC
01P<7@0B1aT040LI01PC9@1JEf/05aPZ01HJ;P0R9D807RA103XmG00a<U40<S5?010=:@0?2R804@XP
018;6P0B21<04@L?01873@0C210030<:00h42`0C21003`D;01@93`0K41H02`8500h31`0;0@@03P@7
00h52@0G2Q<04@@>01L:500;00P0718I07AWL@0X6bD09a/T01P;5@0;00P04@@>01853`0Dooooo`00
6oooool05P0<2`T03Pd;018A3`0@3`d03`h<01LF501RHEl07ahL00T81P0D4a403`h<00/:20051080
2`X800d<2P0E51804Q4?0040000;2PP03@`:00h=2`0@3`d2014@3P0300h:2@0A3@`03@T8008040`;
00@030P7018>3@0A3@`05Q8A0P0>2PT01`0E4A008QhM05QDD`0G4a8040`;01PD4`070`801P0@30/0
100C3@l03PX;00h:2`0@30d200h<3@0<010>3`0>3Ph03@d=00`<300?3`l04A4@01LF50020@003`h<
01lN700920H02`X80P0?3P`03`0>3@/02`X800/:200=2PT04Ph=014=300B3Pd08alN02@P7`0B3Pd0
30P7014=300F4Q40510?014=3006010<2`804Ph=00P040`;00l;2P0?2`X040`;00l;2P0A3@`040`;
00d920803`/:01803PX9010<2`0C3`h03`/:00`81`0;1`H020L500T81P0C4Q0030/900/:200?3P`0
4A0>010?3@0C4Q003Pd;00L6100920H600h=2`8030/90`0=30X00`0<2`T03Pd;00h=2`0400h=2`0<
01<B400;2PP03Pd;04e<BP0K6QP02@P601@B4`0>30d03`d>00d;30091`P03@/<0`0?3@h06`0>30d0
30X;00X91`0A2`/040/800h:1`0>2PT03P`:00h=2`0<2P/04Q4B018B500=3@l02`/=00d=3`0610L0
6ALJ01lM800100802`T<00h<3`0C4A@061HI00l=400>30l04Q0C00d;3P0300d;300400`:2`0:20T0
2@L800h<3@803`d>00/03P`=00d;300<2P/03P`=010>3`0;2@X03@/<00h<3@0:20T030X;010>3`02
018@4@0300l=3P0=2``03@/>00H03@/>00D04@lB00d;3P0@3Q4061HI00h;3@0201<?400E00h:2`0@
30d040`=00/7200<20T04@d>00T51P0300002@D600/7200300006aLH010<3@0Y9BH00`00018>3`0>
2P/03`/<00d92P0<20T03@T:00803`/<0P0@30d200l;300600h:2`0?2``040`=00l;300=2@X03`/<
1P0>2@d01`0L5a/07aXN00l:3P0>2@d061<G02<N8@0?2`X00P0@30/2010<3@0O014<400<1`/03`X>
00T42P0K5Q`05A0F00d83P080`L06aHJ00l:3P0<1`/04`hB02@O8`0B3A406aHJ01LB5P0=20`04@`@
010;3`0<1`/02`H:00X52@0@2`l04`hB00P31`0D3a<04PdA014<400B3A404@`@00h93@0400l;300D
00l;3@0?2Ph03PT=010;3`0>2@d030L;00d83@0A310030X=00h<3`0?3A003P`?00`:3@0:20/02@L:
010>4@0610L02@L:024O8P050`H300l;30<03`X>00l0BDA:03Ha=`0E41H03@P?014<4`0<1`h030L=
018=4`0?2Q002PD;00`73@0A31803`X@00h93`0=20h00P0>2@l06@0?2Q003@L;010:3P0@2Ph03PT=
00`:3`0=2a003PdC00P73@0G61d02PXB01TI8@0000L040`D00l94`0=20l03@P@00h84P0>214040/B
03La>`090``04`hE014;5@0D31@00P0C2A403P0A2A003`P?00l83`0A2a4030L=0040101FE5T0f]SM
05MEFP081@T040/?014<400@2`l03`X>0P0@2`l500h93@0900h93P0F4AL03PT?010;4@0400D04@`B
02dX;P0B3A<040/A00803`X@00<03PT?00l93@0?2@d0100?2@d01P0;1@T03@L;00l93@0D3Q80618F
018<408030L;0`0=20`05P0>2@d02`H:00T4200;1PX04PdA01<>4P0>2@d030P900l;300A3@h03PX;
00H20`0`;2d0@cm001TE5P0<20T0510A00/7200:1PL03PX;034];P0T824200d92P0301HB4`0@30d0
3PX;00804Ph?00<03PX;010<3@0=30X01@0=30X03P030P003`h<00l>300P7ad02`X801@C4@0E4A00
40`;00<0000400009B4P00T5100>2PT03`/:0`0@30/01@0?2`X040/8010;200A30T04P`<00804@d<
00d03P`:00`;2@0C4Q003@`:01<C4@0;30L04a<<00d=1@0E50l07QdH00/:1P0M71P040l=00803`d>
00D040h?014?4P0B41<030X=01PF6@0201<A500800800`0@3Q404@lB01@B5@0<2Pd04a4D01LE600C
4A@200h<3@0400l=3P0@3Pl04@l@014?40803`d>01L040h?00l=3P0?3@h0514B018>3`0>30d03@/<
01HD5@0^;Rh02PX:00l?3`0@4Q404aDD010B4@0A5A@0418B00P8200?3`l07QhN00l?3`071`L04a<C
01HF5P0201DE5@1^010@400B4Q805A@G00h=4`0H6Ah04aDJ01@I7@0>4aL07b@X010E6@0<3a@051DJ
010A5P0?3QD05QHP00H64P0I6B8030dB01<D6@0H6Ad06Q/O01/L800H6Ah06ATQ01dM9`0F5B806QP]
02PV?00K6Bh08R4c038a@@0o?d`08R8/01PH800?41H051DI01LH700@4A<051DJ01XK800B4aP04A8G
010A5P0C51P051DI01HG6`0I6Qh06a`P01dN8@0O82@06aPQ01XH8`0H62805aLQ01DH8@0D62404aLP
01<F7`0D5b0061HQ01PE800D4a/03a0D01XL7P0L7Al0^[^m051AD`0G5aT07AdO01HE600K6A`06QPK
01HC5P0R7B40>cTj02HT9@0M6a`05aDF00/92P0=2``01`D6051>C`0J61T06ALH010>3`0J61T05A<D
01@B4`0G5AH06ALH01HD5@0C4A805Q@E01LE5P0E4a@04a4B01DC500G5AH07ATJ01@@4@0F4Q<06ADF
01PD5@0>2P/04`l@010<3@0A3@h0510A01<?400@30d201D?4`@050hB00<04`dA01@>4P0E3a<00P0E
3a<03`0J5AT0=38e04a:C@0G5AP040hA01`G6`0K5QX050hB018<400B2`l04`X?01@;400Z8RP081TP
014:4@0301@=500701D>5@0B2a8030D<01<<4`0E3QD04``C018<4@0200l92`0401<=3`0?2@/040L:
018930804@P;00H04PT<01<:3@0D2@d04`P?01<8400F2a<201@94@0301P=5@0A1Ph04@H>00<04@H>
03404@H?020F8@0:0Pd04`TD00X03@0=0Q004PXG01D:6P0C2aX0208A02LS<P0<21L040hN01DB;@0>
3RX071Tf01XF<@0H52l030LO00h66`0@2A/03PHD00h43`0A1a004@H>01<74@0L41X05``D00X01`0?
10/03P<9020E6`0800807A8F01462P0800404PL=01@7400?0P`05@PB01033@0:00L07A0J00h12`0<
00T03`8<01D84P0C1Q002P0701Cooooo000Kooooo`0Z00l>300=30X040l=010?3@0>3@/04A0>00h=
2`0A40h030/900d<2P0@3`d02PT700h=2`0C4Q0040l=01LF500;2PP07ahL010?3@0?3P`03Pd;00l>
300A40h04Q4?00l;2P0B3Pd040`;00l;2P0@30/03PX9014=300C3`h02`L6010<2`0E4A004Ph=01TE
5@1HE5<05a<B00h:2@0L61L030P71P0@30/0200A2`/03PX900l;2P0B3Pd03`h<00d<2P0?3P`03Ph<
0P0=3@/01`0@40h02PT800L6100Q81h03Pd;00D40P0H5aD00P0?3P`01@0>3@/030/900`;2@0=30X0
3P/:00<04Ph=00T071PG01/G5P0>2PT03@T8018>3@0H51<05Q8A018>3@0?2`X00`0@30/2014=3080
4`l>00<040`;00h:2@0?2`X00`0A3@`01@0?2`X03PX9018>3@0?2`X04@d<00804`l>00<03`/:00d9
200=2@P00P0B4@l02P0920H030/900`;2@0;2PP03Pd;00/:200C4Q002`X8020O7@0<2`T600h=2`06
00l>300>3@/03Pd;00d<2P0>3@/03`h<1`0>3@/03@0E5180H5mM0=GDdP0];2X01@@201LE5P0@3Pl0
3@/<00/92P0:20T03P`=00l=3P0@3Pl00P0?3@h0100=2``030/9014;2`0@2`P200h:1`0400h<2@0>
3@/03Pd;00h=308030`<01403@d>00h>400?3A001P@700T72P0=2`h03`d@010>4@0B41<0518E00h<
3`0@3Q404@lB00`:3@0>30d03@/<00`:2`0300/92P0300l=3P0>30d03@/<00<03@/<00P03P`=00l=
3P0<2P/03@/<00h<3@0;2@X030X;00d;30803P`=0P0=2``600d;3P0?00`:3@0>30l030X=010>4@0F
51L03``>014=300@30/030P7010<2`0A3@`03`/:00d9200B3Pd05A4@00802PH500@040`;00<0000H
51<040`;0P0300004P0B3Pd03`/:010<2`0=2@P02`L600`81`0>2PX04@d>018>3`0C3a0040`=00h:
2`0<20T03PX;00l;300>2P/03@T:00l;30H03PX;00H02`L800h:2`0:1PL05A4B00l;300A3@h2014=
30<040`;00D040`=018=4@0<1`/03@P<018=4`0200X52`0D00/62P0M61`04`hB010;3`0910P040/?
01D@500Q72007aXN00h93@0=20`04PdA010;3`0<1`/04@`@01dH700N6Ad02PD901D@500B3A42014<
4003010;3`0=20`03`/<00D03`/<00H03PX;00l;300>2P/03@T:00h:300@2`l300d;3P<030X=00P0
4a4D01HD5`0K6A`030X=00X82`0A3a803PX;00h:30803PT=0P0>2@l02@0I51X04PdD00H1200=20l0
7QPR00`73P0>2@l04PdC00l:400201@?5@0400/6300?2Q003PT?00d83P803PT?01003`X@014;3`0E
3a<05@lC014<400<2Pl02`T>00h=4`0I6Ql0VibQ02`]=@082a8092@/00h:4@0>2A003PT?0P0=20l0
6@0@2a801@0601D@5`070PT04`hD00X5300F3aH04`TA0188400A2A0040T@00l83`0@2Q006QDK00`:
3`0S8BH0JVQ]02<Q9P0;20d04PdC01<>500B3A<040/A018=4`0A31801@0>2@l00`0<1`d05A0F00h9
3`02014<4P0500@01@0>2@l04@`B018=4`0?2Q000P0>2@l600l93@803PP<00@03@L;01D?4`0K5AT0
4`dA0P0;1PX200`72`803@P<00P02`H:00d8300?2Ph03@P<00`72`0?2Ph040`=00d92P8040`=00/0
1P8303/g>01SGf00:RHW014=3P0J5QL04@d>01DA4P0:1PL05Q8C01<?400300`82@0600l;300>2P/0
4@d>014=3P0>2P/03`/<1P0=30X03P0@3`d051<A00<200030P00?C`j01LF500E4A005Q8A01PD4`0C
3`h0C4Q702HR8@0A3@`040`;100?2`X2010;2007014<2@0A3@X04@d<014=300D4a4040h?00D51@02
00/;2`0>00d=2`0<30<03Ph404i>AP28R8007A`G00T8100A40h05Q@E01DC500@3Q403`d@018@4`0>
30l200l=400<00/9300?3A00>cTl05QFF@030@@04a4D00T72P0>30l01@<600h<300?3P`040l=0P0A
40h00`0@3`d03`h<00l>300300l>300n018?3`0@30d030X;01<A4P0610D04A4A00`<300@41004Q@C
01HH5`0B51<04ADD01LI6@092@T071`L03dm?@0O7al04a<C01PH600F5QH051@D01<C4`0>3Ph0410@
01DE600B4AL04A8G01<E6P0>4aL05ahQ00hF6@0;4aH04aLK01LH7@0@4AH04Q4H01`L9P082QH07B0X
01XM8P0L7b@03a<F01DI700G6ah06A`Q01`O9P0N8BX051HS01LF:00Q7c@05QDX014@8P0Q83009bHc
01`L9P0F5Qh0414G014B5P0C51P0414C01PI7P0L7B8201<D6@0Q014B5`0E5Q/051DJ01TJ7`0K7240
6Q/P01hO900T9BX06AHO01TF8@0G5b405QHP01<G800B5Ql041@M018E7P0F6B806aTT01TF8@0C4QX0
8B8W018D600J6al09BHZ01XJ7P0I61d06aXO01PF6`0M6b0071XO01PD6P0P6al08R0Q00805A<D00/0
5Q@E01DC500M6a`071XK03lm?P0P7Ql06QPI00d;300C4A805QDC01TH5P0201`K6@0301DD4P0A40h0
61LE008051<A01005A@B01@C4@0C4Q008alP01`H6@0I5AH040`=014=3P0E4A804`l@014=3P0B3Pl0
510A01<?400B3Pl050hB0P0C3A40100B31004@/?014;3`0A2`l2018<40804`dA0180CDQ<0490@`0M
6ah05A<F01/I700>2@d04P`@01D?4`0B31004@X>01<:3`0F3A80:20V01`E700>1`h040T@018;4P0D
3A@2014:4@0500h73P0A2Q406Q<J01L@5`0B2a400P0>20`0100B31003PP<00h52P0A1``201873@80
4`P>00@050L>01<83`0C21005@XB0P0D2A400`0G31@040D=01053@0301053@0G01053P0D2QD0610M
01L?700<11405PhK01L?700800d05@dJ00X44@090a4030HD00l:600B3B@030PS00h:8`0C3RD06QD/
00l97P0=1QP040LH00l44`0=0`h00P0@1Pl200L01@0F00d22P0800D04`P?01T>5007008050T>00T0
0P0700005``@00L00P0@0``03P4:01@7400H2a@04@@=00/01`0<00P03`<;01443@0W6R<070lH00l2
2aCooooo000Kooooo`0401@C4@0?3P`04A0>018A3`803`h<01802@P701@C4@0A40h02`X800d<2P0?
3P`040l=00`;2@0I61H09RDS02LV902>SH/061LE01@C4@0>3@/030/900h=2`0?3P`2018>3@0@010<
2`0?2`X04Ph=01@@3`0?2`X05Q8A00P40`0D40l061@C00h:2@0A3@`06aLF00X61@0C3`h0510?01LC
4PH040`;00L04@/;00l;2P0@30/04Ph=00l>300=30X03Pd;00<03@d;01T04A4?01@C4@0?3P`010<1
014@3P0G5Q@030/900h=2`0=30X03Pd;014@3P0D4a404a8@014?3@0C3`h0510?018>3@0D40l040`;
00d9200B3Pd04`l>01@@3`0B3Pd04@d<00<040`;00@04@d<018>3@0B3Pd04Ph=1@0A3@`05`0B3Pd0
4`l>010<2`0B3Pd05a<B018>3@0E4A004`l>00l;2P0=2@P04@d<01`H5`0J6AL081lM00h=2`0C4Q00
3Pd;00X91`0H5aD02@P600h=2`0A40h0?C`j00L03@`:00H04A0>010?3@0?3P`03Pd;00l>300A40h6
00h=2`0:00P71P0?3P`0;bh/06QWI@0B4@l04a8@00l=3P0>30d03@/<00`:2`<03@/<0`0>30d03`0=
2``030/9014<2@0@30P03P/700h:1`0>30T03Pd:00h=2`0;2`X03@d=014A4@0B4Q<03Ph?00D31P02
018@4`0601LE601HEUT03@/>00l=400>30l02`T<0P0>30l02@0:20/03P`=00`:2`0<2P/03P`=010>
3`0B414040h?00d;300200`:2`0300d;300>30d03@/<00H03@/<0P0<2P/0100=2``03P`=00l=3P0<
2Pd200d;3P<03P`?0P0@3Q401`0<2Pd03`d@00l=400=2P/03PX900l;2P0A3@`00`0@30/0300;1`H0
4@d<02<O7P0L61L04Ph=00d:2@0@30/04`l>00d:2@091@@06QHE00l;2P804Ph=00@040`;00d9200=
2@P040`<0P0A3@h01@0@30d03PX;00d92P0<20T03@T:00803`/<00<03PX;010<3@0?2``01@0?2``0
1`0>2P/040`=01@@4@0U8B805A4B010<3@0?2`X00P0?2`T00`0>2PT03@T800d92P0200l:3@0;018=
4@080`P03@P=014<4@0A310030L;00/62P0G4QH03PT=00l:3P0=20`00P0D3a<00`0<1`/03@P<010;
3`02010;3`07014<400J5AT06aHJ00h93@0A31003`X>00h93@02010;3`0300h93@0?2`d03`/=00H0
3`/<0`0?2`/01@0?2``040hA00l=400>30l03@/>00803`d@00X02PP;01@B5@0610L0518E03Tg>P0:
20/03`/=00l;3P0?2Ph03`X?0P0?2Q003`0@2a40>3<j03dh?`0:10d050hH00/63@0C3Q@03`X@00d8
3P0R7B<07aXP00X52`0?2Q003PT?00d83P0200h93`0I00l:400B2`l04P`@014;3`0?2Ph03`dB014?
500<3180=SLl07QkP01_LgT06QlU00H93P0>2Ph040/@010<3P0@2`l03`X?010<3`0?2`d03PT>00h9
3@0H51H01@4501093`020188400@0149400@2A0040T@00l9400:1@/01@<800d;400E4aP01@@8014>
4`0@2a404@`B010;4@0>2@l03`X@010;4@D03PT?00`03@P>010;4@0:1@/03@P>018=4`0<1`d03PT?
010;4@0C3Q@03`X@00`73@0>2@l600l93@0601@>4P0F41@05@lC014;3`0C3A403`T=0P0=20`200h9
3@@03`X>01D03PT=00`72`0<1`/040/?01@@4@0B3Pl03@T:01HB4`0A3@h05a<D020L7@0?2``040`=
00`82@0=2@X040`=01DA4P0;20P04@d>01TE5P0F4Q<01`0?2``600l>300B00/:200C4Q0020L501DD
4P13@T00:bXX00d9200<20L05A4@00d92@0M6AP0>3@c01@@3`0A3@`03`/:00h:2@0@30/040`90P0@
30P05@0A3@T04@d:010>2`0@3P/02PT701LG5`071`L04A4B010@4@0<30X04A4801dM4P1lO740a/Jn
03<b;@0@3`X03`h;014?400@3Pl03P`?00l=4003010>4@0>00X82`0;2@`04a4D03Tg>P1CDE@03`d@
01@B5@0>30l03`d@018@4@0?3@d04A0>018A3`0A40h2010?3@1Y014@3P0@3`d03`h<010?3@0A40h0
4Q0?01DA4P0@3Pl05A<D018@4@0<30`04Q8B010@400B51<06A/J01@F5@0@51<05QPH00h>3P0A4A40
8b<S01DE5@0?3`l051@D01<C4`0E5AD06ATI01DE5@0C4a<04a<G01HE700@4AL05QXO00H;400C6Ah0
3ADI00`C600B5a`05APN01<C6P0B4QT03`lK01DG8`0O8R/0FEaS038e>P0G6Ql04aLK018E6@0D5ah0
6ahW01dP:@0J72P06APW01hM;@0G5RD071/Y02TY=@0H62806a/S01/L8@0I6Ql05QLK01DF6@0H6A/0
51DJ01LH7@0F5a`07AhT01PH7`0G5ah04Q<I01/K8P0L72<061PO01LG7`0K6b@06aPS01XG8P0H6280
5aLQ01DH8@0C5b006AdV01LJ8`0F6B806QPS01XG8P0F5Ad04Q<H01@F6P0B4aL0C4eA028R9`0G5Q/0
51<H01DD6@0J61d061HK01DB5`0I51P061HI01LE5P0I5aP061HG00804@l@00<05Q@E014?400A3a00
0P0D4Q<0200H5QL05A@B01LF500H5aD05aHD01<B400A40h06QTG0P0C4Q00100G5Q@051<A010?3@0J
5QL201HB4`804`l@00@06ADF01<?400D4140510A0`0E4A801`0E3a<050hB01@>4P0C3A404P`@014;
3`0C3A400P0B310201@>4P0J02<N8P0B41<0518E01<A500D4QD040/?01D@500C3A404P`@01<;400C
2Pl050/@01<;4@0=1Pd05@hE01@=500;10/040T@014:4@0F3aH050dD014:4@0H4AP050dD00`5300>
20d2014:4@0:00l83P0H3QL06a0H01873P0C1a0050L?01@63P0D1Q004PH?01463P804PL?0P0C2105
01463P0Q01463`0@1Q40Bd=@01dF8P0@21D030@A00d64@0;1@l03`LC01<:5@0700X05`hH01<85P0B
21d05@`S01@;800D2al05`hQ01886`0=0a@040HE00l44P0=0Pl040HB01054@0B21006`lI00h52`0D
2A404`T?00/01P0F3A40308600804@L:00h03@<601<8300B1@/040@:00h11`0C1Ph05PT@00d21P0:
00D04PH<00h21`0W6R805`/A01@83ACooooo000Kooooo`0801DD4P0B4@l04a8@018A3`0>3@/04A0>
01<B400=30X2018A3`8030/901`04A0>00l>300510802`X800P71@0T8b404a8@010?3@0<2`T03@`:
010?3@0B4@l04@d<00`81`0?2`X040`;00l;2P0@30/04@d<00l;2P0;1`H03@T8014=300E4A00510?
01XF5@0>2PT0510?0P0>2PT6010<2`0801<=3@0?2`X03`/:014=300=30X030/900l>300>3P`200d=
2`08010@3P0X9bD06APF01hM6`0W9R@04a8@01LF500?3P`200d<2P0;018A3`0C4Q003Pd;00d:2@0A
3@`04`l>01DA400D40l04Ph=014=300@30/00P0?2`X01P0B3Pd05A4@01@@3`0@30/04@d<018>3@80
4`l>0P0B3Pd01P0E4A0061@C01HB4@0D40l04@d<018>3@8040`;01@04`l>010<2`0>2PT040`;018>
3@0A3@`040`;018>3@081`D03`h<00h=2`0@3`d03@`:014@3P0@3`d03@`:01@C4@0;2PP07ahL00/:
20H03Pd;00H040l=00l>300?3P`03Pd;00l>300@3`d600h=2`0>00P71@0@3`d051<A00@30@0B4@l0
0P4000`:2`0?3@h03@/<00`:2`0;2@X01P@500/92P0<2P/200d;300;00`:2`0;2PP04@`9010<1`0>
2`H03PX700h<200>3@T03@`:00`<2`0@41000P0D51@02@0>3Ph02PP;00/9300D4QD00P03038`<`07
1@P03P`?00l=400400h<3`0300h<3@0=2``030X;00<02`T:00<03P`=00d;300<2P/0100<2P/01P0;
2@X03P`=00d;300<2P/03`d>00h<3@803@/<00L03P`=00l=3P0@3Pl02`T<00`:3@0=2`h03P`?0080
3`d@020030X=00/930091`X03@/>00T72P0>2`/03PX9014=300G4a804`l>010<2`0<20L03PX901DA
400>2`X01@4000`81`0?2`X04@d<00l;2P0F4Q402`L6014=300C3`h04@d<018>3@0@30/03@T800h:
2@0A3@d040`=00h:2`8030P900H03@T:00h:2`0?2``040`=00l;300>2P/9010<3@0700P41@0@30d0
2`L800h:2P0A3@`04@d:010<2@02010<2`0Q010<3@0;1`P03@T:00T4200B3A406A@H00X62@0?2Ph0
2`H:01D@50060@D04`hB00`72`0@2`l03PT=00/62P0>2@d03`X>00/62P0:1@T03`X>00/62P0:1@T0
3PT=00d8300?2Ph03PT=010;3`0C3Q8050lC01<>4P0?2Ph03`/=00@03`/<00L040`=00l;2`0@30/0
4@d<010<2`0>2PT02PP900802`T<0`0<2Pd01P071@P02`T<00P62@0C4A@0;2X]00X82`<040/?0`0@
2a40200G4QT0DTeD069MI00B31H01`4;01D@5`0;1Pd050lE0P0>2@l01@0C3Q@04@`B00l:400>2@l0
3@P>00803PT?00h03`X@01483@0>20`030H:00d8300C4AH05QDJ00@52P0E61d05a`P01dS:@001`d0
5AXN00l=3P8040`=0P0A3@h06@0<20T0510A00`82@091@H061@E01HB4`0F41<04@L?0188400A2A00
40T@014:4@0A2a406A@J01@B5`040`L01`D:00l=4P0A3A<040/A014<4P0@2a403PT?00l:400@2a40
1@0>2@l0300?2Q0030L=010;4@0B3A<01P4700`73@0C3Q@03`X@010;4@0>2@l03@P>00h93`H03`T=
00<03PP<01D?4`0F41@00P0=1`/00`0B31003`X>00l:3P03010;3`0K014<400C3Q8040/?00`72`0?
2Ph04@`@00l:3P0810D05A4B00h:2`0<20T03PX;00l;300B3Pl04@d>01<?400@30d07QXK00`82@0;
1`P04@d>018>3`0<20T020@5014=3P0?2``04@d>00803@T:00<04@d>00l;300=30X01@0=30X03P0<
2`T04A0>00h=2`0F5A<04a8@01LF500E4A0061@C00P40`0B3Pd03`/:01dI600B3Pd04@d<0`0@30/0
1@0A3@X03``700l<1`0@3@P04@d:00803`h:00d040l=010@400000004Q8D06EVJ01VJ6D07AdC0082
000M7A40<C4W00L7000C4Pd03Pd900802`T:01003P`?010>4@0@3Q403P`?01LE600<2Pd04Q0C00<1
10081PT01P@701@B5@0?3A006ALJ00d;3P0K6AX040l=0`0A40h05@0@3`d04A0>014@3P0@3`d03`h<
010?3@0A40h05Q<C01LC500C4A802`T:01PF5`0820P03`l?010@400A4a8061XI01DG5P0?4a804Q@D
01`L700201@D500f01XJ6P0A4A404Q8B00l?3`0C4a<071`L01TI6@0E5AD05QHJ01TI8@0=41L04ADL
02DZ<01>EE/05ahT014H7P0?51X04aHM01@G7P0A4AX06Q`X00T;600b=3l0j>_b09>FW@0L7b@082<X
01TL8@0E61l06A`U01TK9`0J72T06a/W034a>`0K6bH05ADO01<C6`0H6Al061TN01XK800K72005aPJ
01HG6@0J6ah05AHK01PI7P0N7b@0;2`d028R:P0K6b<05aLO01`L900L72H061PR0P0D51h0:`0K62<0
6QPS01PH8P0G5b405APQ01@H8@0R9Rl06QdV018E7P0E4ah061HQ01TH800M7R<05aXM01/L800J6al0
410D00`;400C4QL05aDJ01TG700G5AX05Q<H01PC6@0E4aH05A<D01@B4`0E4a@06QPI024O800h=SL0
928S01/I6P0E4a@04a4B014?400G5Q@05QDC01@C4@0C4Q005A@B01PG5@0I61H00P0B4@l00`0G5Q@0
5A@B014@3P0201DA4P0:018>3`0H51D05Q8C018>3`0C3a005A4B01HB4`0E4A805a<D01PD5@L05@lC
0P0C3A405@0D3Q805Q0D06AOH`1IEeX08R0S01<A500K6A`03`X>00h93@0A2`l04P`@01@<4@0C2Pl0
4@P=01<;4@0<1@`03PL>018;4P0E3QD05PlF00l83`03018;4P0<01D>5@0C31<03PP?00h9400@2A40
30D=00L0200D2Q<06PlH0186400C1Q0050D@0P0D10l01P0E1Q004`P@01<8400D2A405@XB01@94@D0
4PL?03404PL@00H01`0=1A802`<@00D02P0N5R<0:20[01L?6P0<1@d040P?00X0200B1Q003P8=0103
500E2Q/05``L01<86@0;01006@hM00h34@0A1Q@03`@B00d2400A1Q@04@HE02/O:`0700D050XA01X?
5`1ZGfH06@hD02HK8@1MDUL050T=00L0000H3A401`0000`0100B1PX04@D900l31`0=0@D02@0100P0
000A1@T02@0101862P0;0@<040@801Cooooo000Kooooo`06014@3P0B4@l051<A010?3@0<2`T04Q4?
0P0=30X0800>3@/040l=00l>300;2PP03@`:018A3`0<2`T03`h<01LF500D4a404A0>00h=2`0<2`T0
3@`:010?3@0A40h040`;00h:2@0F4Q406QHE00l;2P0;1`H04@d<010<2`0O6aX04`l>00X61@0F4Q40
30P701/G5P0>2PT04@d<0P0?2`X6010<2`0I01HA3P0@30T03PX700l;200<2`L02`X6010?2`0>3`X0
3@h900`=200?40/0GUiJ065PGP030P004Q4?03`k>@0M71X04A0>00d<2P0<2`T040l=01<B400?3P`0
3P/:010<2`02014=300E00d9200<20L03PX900l;2P0>2PT03`/:018>3@0D40l04`l>010<2`0A3@`0
4Ph=01<?3P0D40l04Ph=014=300C3`h05A4@01@@3`0C3`h040`;00804Ph=00`03`/:014=300A3@`0
3`/:014=300D40l04@d<00l;2P0=2@P04A0>00h=2`0C4Q0200`;2@0700h=2`081`D02@P6010?3@0?
3P`030/9014@3P0800h=2`<03`h<1`0>3@/03P0J6AL02@P601LF50081`D030/901<B400<2P/040h?
00/92P0:20T03P`=00X82@0<2P/03@/<0P0>30d0200=2``030/9014<2@0@30L03P/600h:1`0>30P0
3Pd90P0=30X02`0=3@/03`l?014A4@0@4100:bT/00P62@0<2Pd09R@W00`:3@0J61/030X=00803`d@
00<030X=00d;3P0@3Q400`0=2``00`0<2P/02PP900T7200400d;300800/92P0:20T030X;00X82@0?
3@h03P`=00`:2`0@3Pl200d;300800h<3@0?3@h03`d>00l=3P0;2@`030X=00d;3P0>30l300l=4009
00`:3@0:20/03@/>00L5200?30`03@T600h:1`0C3``03`/800803PX700@04Ph;01LC400=2@H03`/8
0P0D40d0300:1P<03@T601LC400B3P/03@T600l;200>2PL03`/800h:1`0<20D03@T6010<30803`/<
0P0>2P/01`0?2``040`=014=3P0B3Pl040`=00l;300A3@h01P0@30d01`0=2@X05Q8C018>3`0B3Pl0
4`l@00h:2P0?2`X00P0@30T2010<2`0Q014=300>2P/04Ph?00`82@0C3Q8030L;01hI7@0c;S800`02
00l:3P0<1`/06QDI01@?4`0B3A403`X>00d8300@2`l03`X>00`72`0;1PX040/?00h93@0=20`04@`@
00l:3P0A31003`X>010;3`0B3A404`hB018=4@0?2Ph03`/=00@03`/<018040`;00l;2P0@30/04Ph=
014=2`0=2@P020H700X82`0<2Pd03@/>00`:3@0;2@`04a4D00`:3@0Q7b804Q0C00@21@0E4aH300l:
3P<03`X@00/030L>00l94`0M5b402@@=00<01`0P6b804`hE018=4`0=20h02PD;00`73@0200l:400H
00h93`0=20h03PT?00h93`0?2Q004`X?014;3`0@2Ph04@`@01DC600G5Q/04Q<H00001@011PX04aTO
00XA5`000@D03P`<00h:2@0=2@P03`/:014=300?2`X04`l>0P0;1`H00`0D40l07ATH01XD5`020147
3`0@0149400A2Q404@XA00X52`0=20h03`dB00h<4@0C4AH05A<H00T52`0@2a804@`C010;4P0>2A00
3`XA010;4PD03PT@00D03@P?00/6300B3A<04`hD00d83P0201@?5@0300h93`0=20h03PT?00803`X@
1P0?2@d01P0<1PX04P`@018<400=1`/040X>01<=4@803PT=0P0?2Ph2010;3`0401<>4P0A310040/?
018=4@804`hB00L02PH701<?400>2P/03PX;00`82@0D41404@d>00802`L800<020@5018>3`0810D0
0`0@30d01@0D41405a<D018>3`0>2P/04@d>008030P900<04@d>00h:2`0=30X01@0=30X03@0I61H0
4Q4?00d<2P01000051<A00@30@060P403PX9014=300D40l05Q8A00@0000@30/00P0A3@`2018>3@05
014=2P0?30H03``7010=200A3PT00P0?3PX0800<30X02`/;00X:2P0_<380e]OK0=cNg@0[;20030`0
01<C1`0B4PP04Q8:00h=200A40`0518C01<A4P0?3A003`dB018@5@0B41<040hA00H41`0B41<02PP;
01@B5@0F51L02@L:00h<3`0B41<00@02010>3`0B4@h04A0<0P0@3`/0@00A40`04Q4=018A3@0@3`/0
3`h:010?2`0B4@d05Q<C00`82@0D4Q<03`d>01XH6@0=3@d051@D018B4P0A4a806A/J01LI600A5A@0
418B018B4P0=3@d03`l?01@D500>3Ph03`l?00h>3P0?3`l05QHF01DE5@0B4Q805aLK01/K8`0>4AP0
4QHM055FG02FWZ@0624V01DL8P0B5ad051LN01DH7`0D51d03@lK018F8P0T:380JVme03]0AP0W;300
82DY01LL800E6R0061`U01HJ9@0H6bL09bLa04I6CP0T92d08b<[01<D6@0M7R<05QLL01LH700H6Ad2
01HG6@0;01PI700K72406a/S020P:00];CD08R8Z01/K9@0L72H06QXT01LG8`0E5B400P0F5R8201TF
8@0I01LG8@0F5R004aLP018F7`0O8b`05a/T010C700C4A`061DP01TH800@4AH06A/P01@E6P0G61d0
51@J02TX;P0D4aT061HL01PE700F4aX061@K01TD6P0M6ah071XK01DC5002010>3`0>01<A4P0J61T0
6ALH014?400E4a@06ALH01HD5@0F5A805QDA01DD400C4Ph05QDA01TH500G5Q8201<B3P0@01HE4@0E
51004a8@01PD5@0M6AX04@d>01TE5P0K5aP0510A01<?400G4a@05Q8C01DA4P0G4a@06QHG01<=4@80
50hB0P0F41@0400G4AD05Q0D01<=4@0B310050hB01H@500L5a/02@L:01DC5P0C4A@02@L:00/62P0G
4QH04`dA018<400C2a0201<:3`0701<;4@0<1@`03`P?018;4P0G41L06Q<J018;4P0200l83`0501@=
500A2Q404@XA014;4P0;1@l00P0;0`h03P090@`03P@?01<84`0B1Q804`DB01<44@0C0a00508@01D6
400C21004PL?01@94@0E2Q804`P@1@0A1Ph01`0A1Pl060dK00X24@0?2AD01P0<01@>6P0F4AX00P0>
1`l05@0E2Q<05`XC01H94P0=0@X03`<A01H96P0T62L0:1//0186500J3Q`040@B0186500@1AD03P<C
01875`0B1aP01`0701hB700E2Q801`04028G7P0200L00P0=01H;400;00@02P0300P00@0L4AD02`01
00l31@0C1`T04PH801041P0D20X040@601451`0200h2100300d10`0?0`Gooooo01?ooooo000Koooo
o`0D014?2@0B40/04a0>010>300?30/04Q0?010<3`0D4A003``;00d;200B40X040h900h<2@0=2PP0
4Q0=00d:200>30T03P/901<A3P0@3@/2014>300=00d:200>2`T04@d<00h:2@0J5QD06ADD01LC4P0:
1PD040`;01DA400U8B006ADD00/71`02018>3@0501<?3P0?2`X03`/:014=300J5QD0100A3@`2010<
2`0901<?3P0C40h03@X800d:200C4Pl03@`9010?300<30T03Ph:00803@d900<061@B01PB4@0E3`h0
0P0C3@/01@0C3`d040`:00l;2@0>2PP04@h<00805A<@00D04@h;00h:200@30X04Ph<010<2P03014=
2`0;018>300@30X03`/9014=2`0A3P`02PL600d;200C40h03``:010=2`0?3@X00P0>30T200l<2P07
00l=2P0@3@`05A8B018?3`0C41003``<01HC4`02014>3P0;010=3@0>2`/03``<018?3`0B4@l02`X8
00h=2`0?3P`07QdK01HE4`0@3`d00P0=30X07`0D4a402`X800h>300E5Q<02``8010@300<30T051@A
00d<2P0>30T03`d:014>300A3@/040`:010;2@0B40h03`h<010?3@0C4Q0040l=00d<2P0K6QP0:BPV
00d<2P0F5A<03@`;00X91`0<2PX03P`<00/92@0<2PX00P0@3`h02`0A3`l03@/;00`;2P0>3@`03`d=
00/:200?3@X03`d;00`91`0=2PP03P`;00803@`;00l030X:00X9200<2``04A0@00l>3P0;2@/03`d?
014?4@0H5QP03@/=00L51`0<2P`03`d?010>400=2`d00P0<2P`00`0?3@h02PP900h<3@03014?4005
00d;300:20T03@/<00h<3@091`P00P0=2``01@0<2P/03P`=00h<3@0=2``03`d>00802`T:00@030X;
00d;300=2``030X;0`0<2P`0=P0=2`d03P`>00h<3P0I5aT0518D01<A4`0K6A/01P@601lM7@0>2`T0
2@L4010=2`081P<040h;00l<2P0>30T03``:01DB400P7A/061HC00/81`0>2PT05a<A00/71@0@30X0
3`/900`81P0:1P@03PX800`91`0:1P@04`l=00`:2P0920P03Pd>01PE5P0:1`L07APJ018:3@0F3a40
:20S024L7P0D3a0061@E01<?400D414030P9010<3@0B3Pl04@d>00`82@0B3Pl03@T:00T51P803PX;
01804Pl?00T6100Q7Qh02`P801@A4@0@3@d02@H701LD5@0f<c@04PhA00T6200i=SP0OGUk02DQ8`0>
2@`04@`?00/62@0:1PP200d92`0:01<?4@0J5AP06ADG01@@4P0>2`h030P<01DB5@0=2Pd03``?00h:
3P<03P/>00H03``?010<400?2`l04PdB014<4@0?2Pl300h93P0O018>4@0@2`l0510C01LC5P0X8bH0
2PH900/72`0?2`l04PhB01<?4`0@3A003PX>00h;3P0>2Ph03@X=00l<3`0D41@01P<600P52@0B3Q<0
2PH;00h;40091P/03``A014=4`091@/030T?014=500F4QX0<blf01dH7P02010;4@0:01<>500>2@h0
2`H;014<4@0>2@h03`X=010<3`0A31404`hB00l93@<03PT=00/03``@010>4P0:2Pd030`A010A5P0>
3a@01PL;010A500@30d04@T;00h92P0201092P0U010:2`0>2@X03`L901092`0>2@T05@h?014;3P0?
2@l040P>00h83P0?2@l040X@01D?500:1@X030P=01<?50091@X04`lD00h:3`0@2a003@P>010;4@0;
1P/04@`C010;400?2Pl03`XA00l:400>2@h03@P>00/6300C3Q@03`X@00`83@0A318030L=00h93`02
00d83P0:00l:400@2a4040/A010;3`0@2Ph03`T=00h8300>2@d03`X>010:3P804@`@00D040X>014;
3`0@2Ph040`>00h9300200l:3@0>00d82`0=2@/03PT<00l:3@0>2P`04`hA01LB5@0@30h04Ph?00h:
2`0?2``05a<D00h:2`0=2@X2014=3P0<01LC500>2P/03@T:01DA4P0<20T040`=00/7200@30d0510A
00`82@0?2``04@d>0P0=2@X0100A3@h03PX;010>300@3P`2010=30803`d;00h05a@C00d:2@0I5aD0
30X900h;2P0?3@/0510?00h:2@0G4a802`L6014=300<20L03`/:014=30804`l>06X04Ph=00l;2@0>
30T04@l<01@B3`0>2`T03Pd:00h=300?3Ph040l@014@400E51H0JfY/06IUIP0D4`d04A0901DE3P0;
2PH05A@A00h=2@0B4@l06QPI01PF600D4QD04@lD00l=4@0A3a004a8A00P61P0A3`l040l>00d;2`0@
3`h06ALG014@3`0?3Pd05A@C010?3P0A40l040l>010>3P0A3`l04A0?01<A4@0B410040l>00l>3@0A
3`l04a4A01DC50061@D03`h>01@C4`0?3Ph020P801HF5P0D51@04A8A01HG5`0G61L051DE01@F4`0D
5A403Pl;01TJ5P0M7Q/04a@B01<D4`0D5A@04a@B01HG5@0F5aH05AHF01@F5`0F6Ad05APL01/O8`1;
D580Jg9e018I700B61d04aLN018D7`0A51l0414O02ha@P0X;3d07B8_01LK9@0N8R/04aPN01LK800B
5Q/06QhW028S;`0G6RL05QLV01@G8`0V:S@05QTS028V;P0G6b405aTN01DH6`0E5a/05aPL0P0J6b00
1`0G5ah05QLP01HH800G6B407QlW01XL8`0H6B000P0K72D0300G62<03@lI02d^>@0L72L05QDO01TI
7`0F5ad04Q8K01DF7`0G6b<06a`V01`N:080:2Pc00L05aHS01TH900G5Qh04Q8G01XJ800F5Q/06QXP
008051<I01<05aHL01TG7@0E4aX061HM01<A5P0D4QD05aDG01PF600F51D05A@D01<B4@0E51<07A`I
01HE4P0G5Q<05QDB018A3P0B40`061<@00805Q<@00D06ADB01TG4`0G51405a8?01DC3`0201PD4@0Y
01LC400E4A805A8C01<@4@0L6AX05a@F01<@4P0A3Q004a0B01TF600F4QL05a@H01TF6P0B3Q804@/?
014>4@0F4QD05A0D014=4@0C3Q8050hB010<400B3Q805A0D01HA5@0A3A405@lC010<400J51P05@lC
01<=4@0D3Q804P`@018;400D31405@hB01<<4@0E3a@07QPM01XC6@0A2a000P0C3180B00B2a404@/@
01@=4`0?2@h040X?01@>5@0=1`h030@>01@=5@0@2A4040LA01<;500>0``04`PC01874@0O4a`09QTT
01@94P0C1a0040D?01863`0C21404PL@00d32P0C21003`D;01463@0C20l04@D=01053`0D2aH03PD?
01074@0<0`d03`H?00d4300D2Q8040H=02lS;00`92`05PXC01@95@0<11408AHT02TM:`0E2QP04PLB
01454P0G2aP04@DB00`23@0>10l04`HC01H:4`0>0`X03`@;01463@0?10X04PL=00h32@0?1@T02P44
01072P0@1PX040D901472P0=10H03@<500`2100<0PD04PH9014520804@@700<0408601841`0;0040
5?ooool001_ooooo00P04a07018?200B3`X04@d<014=3@0@2`l04PdA018>3P804Ph;0P0B3`P04P0J
5a806QHC00L3000F4Pl04Ph;01dI5P0?2`P030P501DA3P0H51405A4>01HB3`0?2`X04@d<00T5100A
3@`01P8101TE50H04@d<00L03`/:00d9200>2PT04Ph=01@@3`0E4A004`l>00<04Ph=0P0A3@`0300C
4Q002PT701<B400J6AL01`H400/:200@3`d02`X800l>300@3`d03Pd;01@>30@05@/:00<050`:01<;
2@0B2PP00P0@2`P200h:1`804Ph;0P0@30T00`0A3@X040`900l;2002010<2@0:00l;200>2PL040`9
01dK5`0C4Ph030/7010?2`0<2`L04A0<010?2`D03Pd900H03@/:010>3`0A3a002`T:081nO`1ZJ6T5
00h<3@0700l=3P0:2@L02`X800l>300B4@l08R4O01LF500300h=2`0f00`;2@0;2PP02@T700010009
3PP0>C/f01PI500@4@`05aHB010<2@0A3@X04`h;010;200?2PL04P/9014=300<2`T040l=01HE4`0B
4@l040l=00X91`0M71X01`H401XI5`0>3@/040l=00`;2@0;2PP030/900d<2P0@3`d04A0>00d<2P0A
40h040l=00d<2P0>3@/04a8@01DC500X9RL07Q`M00h<3@040P<02@L800h<3@0<2P/020H700`:2`0?
3@h01P@500X82@0<2P/03@/<0P0>30d01P0=2``03`d>00l=3P0A3a004Q0A00h<3@8030X;00X071XK
03<a<P020@402`T:00l=3P0;2@X040h?004000091`P02`T:1`0=2``01`0>30d04@l@01<A4P0:20T0
81hO03hl?@0>30d00`0<2P/300d;300D01TG600G5AH0Cde>01hL7@0D4a803@`:0040000:2@L020L5
00`;2@0@3`d02`X800X91`0@3`d04a8@00l>300<2@P03PX9010<2`0C3`h2018>3@0H01HB4@0C3`h0
1000018>3@0F4Q409b<R00`;2P0K7A`01PH600L51P0810D0NG1c038X;00B1`/08QTL01L?4P080P@0
510A00<0000@30d05A4B00X61`0C3a001P<30`0?2``300h:2`0B00L51P0=2``0N7Ig00h<3@081PL0
4@l@01@B4`050`@08R0Q00l=3P0I5aP030X;01hJ6`0;1`P01`@401<?400@30d05A4B0P0?2``02`0D
41406QHG01PD5@0>2P/02@L:01LE600H5QT01`D800X82`0?3A003@/>00<03P`?0P0?3A00100@2a40
40/B00h9400>2A0200l:4@0800`73P0:1@`05A0G018=500R7B@040/A00`72`0>2@d2010;3`0300h9
3@0<1`/03`X>00803PT=00L03`X>00h93@0;1PX04@lD00P62`091``03P`A00803@/@00l030X?00X8
3@0:20d030X?010>4`0B41D05Q4H010;4@0<1`d03@P>014<400C3Q804@`@00`82@0?2``00P0A3@h0
1P0C3a003`X>00d8300<1`/03@P<00l:3P8040/?00D03`X>00h93@0?2Ph03`X>010;3`0301<:3@05
0189300@1`X05@`?01482`0<0`H00P0F3A000`0C2Pd04`d@00l:3P0300h93@803`X>00d02PD901dH
700/9b/06A@H010;3`0910P04@`@00L21P0@2`l030L;00T4200A31003`X>008040/?00`03@P<00`7
2`0B3A804`hD00H11`0@31402@@:00H11`0C3Q@030L=00h93`0?2Q02010;4@03010;3`0?2Ph03PT=
00803@P<0P0>2@d00`0@2`l04PdA010;3`0200h93@0>014=3P0>2P/040`=018>3`0?2``04@d>01HB
4`0A3@h03PX;01LC500O6a`05a<D010<3@0<20T200h:2`0300H20`0A3@h04@d>00804Ph?0`0?2``0
1P0M6AX02@D601XF5`0A3@h040`=00d92PH03`/<0P0@30/200l;2P0800h:2@0=2@P00`0002/W9P1I
EE@0920O01@@3`0A3@`200l;2P05010<2`0A3@`04Ph=018>3@0@30/00`0B3Pd09`0@30/03PX900<1
0P0610D03`d>00h<3@0E4a@04a4B010>3`0?3@h030X;00/92P0>30d04A0>014@3@0>3@/04A0>010?
3@0?3@h04Q0A00`:2`0>30l071XM03@b=@0W9BX040hA00l>2`0H5a<02`X601hM6@0R8Ad010<000l>
2P0=30P02`X600d<200B4@d051<A00l=3`02010>4@@04@lB00L040hA014?4P0A3a804Q0C01@C500B
4Q804A4A00@04Q8B0P0?3`l0100F5QH06ATI01@D500@4@h201DH4@0:01HH4P0?4@`030h901DG4`0D
5Q<05ALD01DG5@0E5aH05QPG01@G5`805ATJ05L041@D01@H5`0L82404aLJ01<F6`0D5R004aDR01DG
9P0L7S00^;[?09jS]`0P9CL020/J028V<@0>4Q/04aHM01@G7P0S8bd08b<_01TH9P0H62P041<R014G
9@0E72L05a/V01DJ800F6b005ATL01<G6P0F5a`06a/S01`L900F5R008R@`02<U<@0M82T05QTP01LJ
8@0D5a`05aXO01@G7@0I72<020/D02HY<`0>4AX030dB01TJ7P0@4AH08B8W00`=4`0X:3007AdW07Mg
PP0`<3`0FeYX01`K:P0H62@06aXR01LF700D4aT05A@J01PG7@0G5Q`051<I018A5`0I61h06QTO02<R
:00F5AX0928U01TG6P0C4A@05Q@E01HE500B4@l05A@@01HE4@0F5A0051@<014A2@0@3`X0510=01/F
4`0M61D06aHC01TD4@0H4a000`0G4Pl201PC400I01LC4P0D4Q<06aTJ01TG600A3a002@L:01@B5@0E
4aH05Q@I00L52P0F51T04PlF00l=4P0H5QX05A<F01LE600@3Q404Q0C020N8@0@3Q404Q0C00l=400A
3a804Q0C018>4@0201D?4`0401@>4P0C3A4050hB01@>4P<04P`@0`0C3A402@0>20`03@L;00d72`09
0`L03@L;014;3`0@2Ph04`dA01@>4P02018<400b01093`0F3aH03`P?0109400_:2l09QlV01094007
00L040T@00d63@0N5ah0:24X01@:500F2QH04@DA0186400C1a404PH@00`12@0B1`l03`@:0146300C
20h050T?01@94@0C21004@H>01053@0C21005``D00T01P0D2A402`4802DJ8P0Q5Qh03P@<01<95021
NHH07AHR01<85P0<0@l040LA01P<600700L03@<;01/>5`0>0@X04PD>00h32@0?10X201052`0900l4
2P0>0`T02`0600T0100I3Q@05@X@00d4200C2Pl03@@700802`D700T03@@700h41`0>0`L0200001H:
3@0:00008Q4G01@62@0/6b405?ooool001_ooooo00P04Pl6014>1`0A3PT040`;010<300?2``04Ph?
018>3P804Ph;0P0B3`P02P0F4`h08alL00`81@0O6aP03@T701lK600D40d04@d:01DA3P0D40d200l;
2006018>3@0N6QT02PH501HB4@0:1PD040`;1P0A3@`01`0C3`h03PX901<?3P0L61L05a<B010<2`0C
3`h00`0B3Pd2014=300C03Dd<P0100001`H401DD4P0100006APF00l>300<2`T03`h<014@3P0@3`d0
50h=01H<2`0G3@`05Pd<01@<2P0B2PP04@/8014<2@02010;20803PX700D04Ph;010<2@0<20D03PX7
01<?3002018>2`0;01<?300B3P/04`l<01@@3@0C3``081hJ01DD400;2PH030/700d<200A40`01P0>
3@T01P0@3Pd02`T:01`J6`0610D0M79c06i/K@<03`d>0`0>30d01`0920H02PT701@C4@0?3P`04Q4?
00l>300@3`d00P0?3P`05P0>3@/03@`:00d<2P082PD04A<>03do>P0C50l0004000P71@0@30T04@d:
018>2`0@2`P03`X7014<2@0A3@`030/900h=2`0=30X02`X800l>3001000200`;2@0;01HE4`0=30X0
3Pd;00l>300<2`T02@P600P71@0:2@L030/900/:200=30X00P0?3P`09P0@3`d04A0>00T7200C4A80
4Q0A01@B4`0B41403@/<00X82@0;2@X030X;014?400H5QL04a4B00P61`0<2P/03`d>010>3`0>30d0
30X;00h<3@0<2P/03@/<00l=3P0>30d030X;00l=3P10?Sl0Kfe^01hL7@0F51D02`T:00d;300@3Pl0
5Q@E00h<3@071@H02`T:200=2``01@0C4A8020H7028P8@1;BDX03P`=00<03@/<03003P`=00l=3P0=
2``08b4R01DC500=2``00@0000L61P0?3P`04a8@00d<2P0O7Q`030/900P71P0<2`T02PT700h=2`0A
40h03`h<00l=2`0:1PD030P7018>3@070`802PH5014=300J5QD02`L600d9200810<05A4@00P81`05
1`H030`<01<A4@0O6a`0M6]^02hT:00C20`04@P;00X31@070@<03@T:010<3@0E4A8061@E00<0000?
2``2018>3`804@d>01@03`/<00h:2`0>2P/0518C00h<3@0J61T00@0000d;30040P<04@l@00L51P0<
2P/02PP900h<3@0:20T02PH700T51P0<20T03`/<00d92P804Ph?00/040`=00l;300A3@h040`=00X6
1`0;2@`01@@600400P0C4A@05A<F00<1100200l=40<03P`?00@03@/>00d83P0?2Q003`X@0`0@2a40
100H4aT02@D:01@?5@0I51X2018=4`D03PT=00@03@P<00h93@0>2@d03@P<0P0<1`/02`0>2@d06aTN
00D3200E4aP03@/@018@5@0<2Pl02PP=00`:3`0=2a003P`A008030X?00d04@`C00h93`0<1`d03@P>
014<400C3Q803PT=00/7200?2``040`=00h:2`0@30d03PT=00803`X>00H040/?014<400A310040/?
00l:3P0>2@d200l:3P03010;3`0B2@`04PT<00804`X=00D04PT<034X:`0h;c804`X=00/31@0200H0
0003018<3`0?2Ph040/?008040/?00h03`X>014<400<1`/061<G020K7`0C3Q8040/?00d8300B3A40
2`H:018=4@0E41@00`02018=4@<03`X>00T03@P<00`72`0?2Pl03@P>02<N9018@dT08QdS00L2200:
1@/00P0=20h0100>2@l03`X@014<4P0>2@d200l:3P803PT=0P0=20`06P0?2Ph04@`@00h93@0=20`0
3PT=010<3@0>2P/040`=018>3`0?2``04@d>02dY:P0P71d04`l@014=3P0>2P/020@500l;300:1PL0
3`/<014=3P0300004Ph?010<3@0>2P/03@T:0P0@30d02@0=2@X00`00014=3P0A3@h01@4204M3A00G
4a@03@T:00h:2`0200l;3003010<3@0A3@h03PX900803`/:00l03PX900d9200<20L030P701@@3`0U
8B00100000/71P0D40l03`/:010<2`0A3@`04Ph=01<?3P0D40l00`0@30/300l;2P07028P8@0?3@h0
40h?00d;300C4A802`T:00`:2`02010>3`0@00l=3P0>30d03`h<010?300>3@/040l=00l>300>30d0
4Q0A014?400@3Q403P`?014?4P0>31401`D8018@408040l=00D02`X900X91`0B4@l05QDC010?3@02
00h=2`04010?3@0B4@l040h@010>4@@04@lB00<040hA014?4P0B41<00P0B41<01P0A41405ADE01@D
500=3@d051@D01DE5@804A4A00`0410@014A4@0B4Q80410@00h?2`0520403a8;01TK5@0;3@P03Q0;
01DG4`0F61D301DG5P1F01@F5@0D5aL05QXM01TM7P0E6AT04aLF02P/;@0C5aX05APM01@G800C5B80
6Q`[02/]?`0d=dX0BTmR01hS=01DF6@05QXU01HK8P0?4QT051LN01/K9@0G5b<051<Q01PI9`0E62L0
5Q`Z01TO:P0I7BP061dS01PM8P0F6Qd051PK01DF6`0I6B406a/S01PH8P0J72P071hZ01TL9@0E61l0
5QTP01@G700L7b@04QDK01/N9@0C5Ql04aHP00hA6P0Q8RL061TM00/<4@0?41D0=SHm00001`0N7RP0
7alZ024Q;@0L6bT092<a00H64P0K6R805aHK01@C600E51T05QDJ01DD6@0L6b004a8G01DD6@0G5Q/0
81lT010?500/:Rd06aTL014?4P0F51D061LF01<B400G5Q805QDA01DD3`0C4Pd04A49014@2`0G4a42
01TE500301LC4P0F4Q4061@C00805A4@01l05Q8A01LC4P0G4a805a<B01@B4`0F51D02`T:01HD5@0C
4A@0518E01DC5P0R82D030X?01LE6P0=2Q40=C<h01@B5P0@3Q403`d@014?4P0>30l02@L:014?4P0B
41<040hA014?4P0B41<040`?018<400D3Q804`dA00804P`@0P0C3A43018<4009014;3`0C3A403`T=
014;3`0I4aL03`T=010:3P0C3A4040X>008050hB01@04@/?00l93@0A2Q004``C00/42`080`P040T@
01D>5@0H4AP02P<:014:4@0>1`h04@XA01XC6P0B2A805@TE0104400D21805`/E01<74@804@H>01h0
4@H<00h32@0;00H03`@:01873`0A1Ph040D=01463P0C21005``D00X01`0G31@0308901463P0<0@T0
3PD<01@:5@2;Pi008ATV01/A700B21<050XE0186400800H05PXD01853P0<00P03P<:00h32@0?10X2
01052`0:00l42P0>0`T04@H<01P=4`0:00D01`0201D:400H3a@03@@700`51`803@@700P03P@700h3
1`0G2`l0304301H7300;00004`D801D42QCooooo000Kooooo`0>014>1P0A3PP040d8010<2@0?2`X0
3`/;014=3@0A3@`04@d:014>2@0A3PP04@h7010=2`0B3P/201PD4@0301@@3@0F4Pl04@d:00804@d:
00T040`900h:1`0=2@H071TH01DA400F4Q404@d=01HB4@0C3`h01P0@30/01P0B3Pd03`/:01<?3P0I
5A@05A4@010<2`804@d<0P0@30/200l;2P0@04I5@`0@3`h04Q4?00d<2P0<2`X04a8@00d<2P0;2PP0
30/9010?3@0A40h04`d<01H<2`0H3`d05`l=01@<2P8040X70P0A30T2018>2`0301<?300@30T03PX7
00804@d:00l040`9014=2P0C3``04@d:00l;200C3``05A4>01<?300C40d02`X600h=2@0B4@d03Pd9
010?2`0=30P01@0>3@T01P0=30X04a4B018@4@0E4a@04Q0A01TG608040h?00X04@l@010>3`0?3@h0
3@/<010?3@081`D04Q4?00d<2P0;2PP03`h<0P0<2`T07@0=30X03Pd;00l>300B4@l0@D8m010A3P0;
3@P02``701<D3`0=30T03`d9010>2P0B3P/040/800l:1`0@30T03PX900/:200<2`T02PT701<B400U
92806APF00`;2@0C4Q003@`:00`;2@0B4@l03@`:008030/900h03`h<01HE4`0K6QP06QTG00d<2P0>
3@/06QTG01TH5P081`D040h?01HD5@0@3Pl03`d>00h<3@802`T:00T03@/<00`:2`0?3@h0518C010>
3`0A3a0040h?00l=3P0>30d00P0?3@h04P0=2``02PP900X82@0<2P/03P`=00d;300?3@h02@L801DC
50091`P02PP900l=3P0<2P/02`T:00`:2`0=2``04a4B00X82@H03@/<00L040h?00/92P0=2``03@/<
00h<3@0B41403P`=00803@/<03803`d>010>3`0@3Pl0<Bl`020N7`0G5AH02PP900d;300G5AD01PD3
018A3`0J6AL03`h<00P71@0C4Q0040l=00d<2P0>3@/040l=014@3P0A3Pd030P700X61@0=2@P030P7
00l;2P0B3Pd02`L701@@3`0F4Q40>3@c00X61@12@D003@l>01HF5P071@D03`/<014:2`0D2Pd05``@
00d41`0D30l0618D00h:2`0@30d02`L800d92P0e<C803PX;00`82@H03`/<01d03@/<01TG600@3Pl0
2`X:01@B4`0<2P/02PP901HD5@0<2P/03P`=00@30`0C4A803PX;01<?400B3Pl03@T:00h:2`0=2@X0
4@d>00l;300<20T03PX;010<3@0A3@h030X=00d;3P0>30l02@L:01HD5`02010>4@0700l=400>30l0
3P`?00d;3P0<2Pd03@P>00l:4002014<4P0K00l:400=20h0?cY001DA5P0<20d091lU01/F700>2@l0
4PdA014<400@2`l04@`@01@?4`0G4QH03`X>014<400?2Ph030L;00h93@0C3Q803`dB00h<4@0@3Q<0
3@/@00/93P0=2a0030X?00<03@/@00X02`T>00X83@0?2Q404PdC01D@5P0C3Q@03PT=00/62P0?2Ph0
30P90P0A3@h01@0>2P/03`/<00l:3P0@2`l04PdA00<04`hB00<040/?00l:3P0>2@d00P0?2Ph0100@
2`l03`P;0149300B2Pd2018;3@0I01P@4`0Y8B@06A8D01TB500K51H03`L:01D@4`0?2Ph04@`@018=
4@0A31003`X>010;3`080`L030L;00d8300910P040/?018=4@0>2@d04`hB00`72`0F4AD03`X>00h9
3@0300l:3P0:00d8300>2@d04@`A00X52`0?2Q008AdR010;4@0910X03`X@00h93`803@P>00@03PT?
014<4P0=20`03PT=0P0@2`l0200>2@d030L;00d8300>2@d040/?00d8300<1`/03`X>0P0@30d01@0?
2``03PX;00d92P0=2@X05A4B00802PH700`04Ph?00l;300B3Pl04Ph?00/7200A3@h06ADF00T51P0@
30d03`/<010<3@0A3@h200h:2`0800l;300D41404`l@00`82@0E4A80EE5B01<?400<20T200h:2`0G
010<3@0A3@h04Ph?00l;2P0@30/04@d<010<2`0?2`X03@T801@@3`0:1PD04`l>018>3@0C3`h02@D4
00h:2@0?2`X040`;014=300B3Pd04`l>010<2`0?2`X00P0>2PT02@0?2`X040`;02/Y:P0?3@h03@/<
00h<3@0G5AH02`T:00l=3P02018@4@8040h?01X04A0>010?300=30X040l=00l>300>30d04Q0A00l=
3P0=2`h03P`?018@4`0C4AH04a4D00h<300=30X02@P6014@3P0>3@/040l=00h=2`0<2`T04Q4?01<B
400@3`d04A0>010>4@804@lB0P0B41<2014?4P1I018@4`0D4QD0518E018@4`0C4Q<04a<C01LG5`0J
6QX051@D01<C4`0D51@05QHF01LG5`0@41004a<C028R8P0i>SL05aTC00T;1@0C5Q004aD@01PJ5P0E
5a@05QPE01HH5`0E5aH051HE01@F5P0F6A/051PK01<G6@0C5aP041@D02P/;@0D61/05aXO01PK8`0C
5B405aTV02PZ>P0G6RX03Q@S01@J:01=DE`092Pa014F700G6R0061/Q01@E700D51d06a/V01/L:00L
82d06b4_01/R;@0H72L05Q/Q01DJ7`0H71l05QXM01HG700H62006QXR01XJ900C5B4061XV01dP:@0M
82L07b8Y01TL8@0G6Ql05QTO01@G7P0J7BH05QPS01hQ:P0E5A`05AHJ01HG700R8bP0CTmE02d]=@0F
5R009RH`02<S;P0h>4D06a/X01XJ9@0G5Q`00P0D4aP0100E51T05QDJ01DD6@0L6b0201TH7@0E01HE
6P0P7b@06QTN01XH6`0F51H04a4C01@B4`0G5QD05aHD01@C400D4`l04a8>01@C3`0E51005QDA01LC
4P0E4A005Q8A01DA400H51<07a/J00805A4@01<05Q8A01LC4P0G4a8061@C018@4@0P7Ql02`T:01HD
5@0D4QD04@lB01DC5P0M6b0061HK01LE6P0a;SD0_kg209FCU`0C4A@05A<F008040hA00<05aDH018@
4`0B41<00P0C4A@0200B41<04PhB010:3P0?2@d05a4E01dG6`0I4aL050hB0`0C3A40400B310040X>
010:3P0=1`/06Q@H02hX;00G4AD030H:018<400C3A4050hB018<400@2Ph04@/?010:3`0E3QD201<<
4`0401D>5@0@2A004``C00l83`804``C02P030D<014:4@0B2A8040@@00l33`0G2aD06`lI01P<5P0B
1`l03@8:01P=4`0B1`d03`@:01D:400B1`l04@H>00l4300>0`/03`@<01873`0@1@d04`P@00d22P0G
31@05P/C00h4300E2aH02P@?01H>6P0600L0?cE00107400?0`d06`lI01863`0@1P`050L@01<63`0>
0`T03`@:0P0@1@/02`0?10X03P<900T0100A1``03`D:01<83P0=10P03`@:00d41`0=1@L03@@70080
3P@700L03P<700/10`0C1PX03P4500h00`0N3a@04P@701Cooooo000Kooooo`09018?200A3PP04@h9
010<2@0@30X03`/:010<2`0@30X040`900<040d800D0HUiK01TE4P0F4Pl03PX702PT8@02014=2P0;
01HB3`0C3``04Ph;01@@3@0C3``0RHF407QdL`0<20L04`l>010<2`0>2PT01P0A3@`4010<2`03014=
300C3`h040`;008040`;01003`/:00h:2@0>2PT05QDC01@C4@0I61H030/901HE4`061@<04A0>00l>
300=30X04Q4?01@C4@0D3P`05P`;0P0F3P`01P0D30X040/8014<2@0B3@X040`900l;20<03@T600<0
5a<@01hJ5`0I5A800P0=2@H0300A3@X03`/800d91P0?2`P04`l<01DA3P0A3`/02`X6014@300=30P0
20L300l>2PH03Pd900H03@`9014?400>30d02@L8018@4@0D4Q<200l=3P804@l@00/040h?00h<300D
4a402PT700h=2`0<2`T03Pd;01<B400G5Q@05A@B018A3`02010?3@0G014@3P0S91l010D000h?2P09
2PD051D@01LF4P0>3@T03`h:018>2`0?2`P03PX7010<2@0?3P`03@`:00/:20081`D03`h<020O7@0>
3@/020L601@C4@0>3@/00P0<2`T200d<2P0800`;2@0>3@/04a8@01HE4`0@3`d04Q4?014@3P0?3P`2
00d<2P0E0040000?3@h04Q0A01<A4P0?3@h02@L800d;300?3@h030X;00/92P0>30d02PP9014?400>
30d02`T:00d;300C4A8061HG01<A4P0?3@h03P`=008040h?00d03`d>00X82@0?3@h02PP901LE5P01
00001P@5010>3`0>30d0BTQ902`Z:`0E4a@02PP900L03@/<00D05Q@E00/92P091`P03`d>00X82@03
00`:2`0A00h<3@0?3@h040h?010>3`0=2``02@L801/I6P0L6Q/01@@3014@3P0I61H0<2l]018A3`0=
30X02@P600h=2`0<2`T00P0;2PP0100<2`T02PP600d9200A3@`200l;2P0B00`81`0@30/00`0001`H
5`0M6AP0DDe<00X61@0H5aH00`D40000000I5aL03PX;020G6P0B20/05P/?00X1100@20/0618D0P0B
3Pl05`0=2@X06ADF06MSI00R7Ql040`=00`82@0=2@X03PX;00l;300@30d04@d>02DS900a;c003`d>
00d;300F51D03`d>00X82@0G5AH01`D601DC500:20T03P`=00803PX;010030P900d92P0A3@h04@d>
00l;300>2P/03@T:00`82@0=2@X03`/<01`J7@0:20/01@<6020N8@1OGF00518E0P0?3A0300h<3`04
00d;3P0@2a4040/A010;4@803`X@00L03@P>01XE6`0F4AL02PD;01`G7@0F4AL01`8800<03PT=00@0
40/?01<>4P0F4AD040/?0P0A31004@0@2`l04@`@01<>4P091``030X?01@B5`0>31402`T>00P62`0?
3A803@/@00/93P0<2Pl03@/@00h<4@0E41L04@`B00803PT?00@040/?014<400B3A403PX;0P0B3Pl0
1P0?2``040`=00`72`0<1`/03@P<00h93@803`X>00<040/?00l:3P0>2@d00P0?2Ph00`0@2`l03PP:
010:3003014;3@08010:300Y8bD09R0R01H@4P0E3a402@<500/5200?2Ph3010;3`0A00l:3P0A3100
3`X>01@?4`0A31002`H:00h93@0?2Ph02@@8018=4@0D3a<00`0201hI7@0<1`/03`X>00h93@0=20`0
0P0>2@d01`0<1``04@`B01<>500C3Q@050lE014<4P0?2Q000P0>2@l0100=20h03PT?00l:400>2@d2
00l:3P803PT=0P0=20`01P0>2@d03`X>00d8300=20`040/?00`82@<03`/<0P0C3a002@0F4Q<04`l@
01<?400@30d02`L800T51P0I5AH04`l@00h:2`0200d92P0<010<3@0?2``0510A01HB4`0=2@X030P9
01<?400U8B802PL701XF5`0E4A802`L80P0=2@X01`0>2P/03`/<00l;300@30d04@d>00l;2P0A3@`0
0P0C3`h0200@30/03@T801@@3`0=2@P0100000/71P0<20L06ADD0P0>2PT200l;2P8040`;0`0?2`X3
010<2`0600/92P081PL04Q0A00l=3P0A3a001`D60P0>30d02@0=2``03P`=014?400C4Q003`h;00d<
2P0?3P`03Pd;00d;3002014?400A00d;3P0>30l030X=00X83@0=2`h04Q4@00d<2P0H5aD020L600l>
301<BdT06QTG00d<2P0@3`d04A0>018A3`0G5AH00P0A3a84018@4`03014?4P0B41<04a4D00804a4D
01@051<E00l?3`0F5QH08b<S010@400>3Ph04a<C01HF5P0O7al06ATI01<C4`0K6a/0:b`Y01TK5P0A
4`h051HA00h@2`0A4a005ALD01HH5@<05ALF02P051DG01<E600@51L04aLJ01HJ700A5AH041@E014E
600E6A`05QTQ010B7P0?4Ah051HU01XM;00:41`04aTT01dQ:P21QX`0;34e01XM8P0E61d04a@I01HF
7P0I6B405QPP01@H900C6BL051/V01@H8`0D6Al05Q/P01LK7P0F6Qd05aPM01LG7`0I6B406a/U01HH
900L7RX082</0P0P8bX06P0J7B804QDJ01LJ800;3QD03a8K01LI900N8BX07alW01dN8`0G61d0414F
01`M8`0E5Ad06ATS02`/=P0S8bd03`lI030`>`0L72H04a8H018A5P0C4QL05A@I01HE6P0E51T04Q4F
0P0G5Q/03@0?3Q<06APM01XJ700A3a806ALI01/I6P0F51D04a8A01DD4P0G5Q@05QDC01DD400C4Ph0
0P0A40`01P0B3Pd06QHE02DQ800Q7A`061@C01`H5`H05a<B00d0518C02DS900H5QL07adN01PF6@0C
4A@04Q0C01LE6P0C4AH05aDJ02DR:@1kNGh0HV1T008061HI01/03`d@02`Z;@0100804a4D018@4`0E
4aH0518E018@4`0F4QD04@/?00h8300H4QH081XN01/E6@0D3Q804`dA01@>4P0E3a<04`dA018<400E
3a<040X>00d72`0B31002P@800l93@0E3a<00`0@2Ph03`0D3Q806A<G01hH7@0F3aH03PL>00l93`0@
2A004@XA01<<4`0?20l03PL>00l83`0<1@`03@H=01<94`0201864P8050PB00X04`LA01P=5@0?10`0
5P/A00P00`0=0PP03PD901D:4P0D2A404PL?0P0@1@d05@0?10`040D=01463P0A1Ph02P0700T01P0@
1@h02@0:00`44@080@/01P0702XP:`0900P03`<=00L01@0>1@/07Q4J00P0100>0@X03P<900l42P02
01052`0800l42P0>0`T01`0200`31`0>0`T07Q<I00`31`07008300d41`<03P<700H040@800`2100V
6Qh03P0405]<D@0^7b@Dooooo`006oooool00`0C40/04Pl;018>2`02014=2PD040`90P0@3@P04P1P
G5T08AdJ01@@3@0A3@X07ATF014=2P0E4@h06QHC01@@3@0A3@X04`l<014=2P27Ph80PWim00/71P0G
4a80510?00D100H04@d<00<04Ph=01<?3P0C3`h00P0C3`h00`0D40l04Ph=018>3@02014=308040`;
00`02PT700H50`081`D02`X800h=2`0E51804Q4?014@3P0=30X04Q4?01@C4@0B3@/201@<2P0=01<=
2P0B3@X04Pd:018=2P0B3P/04@d:00h;200;2PH02PT500d:1`0E4@h06QHC01HB3`0200l;20804Ph;
0P0A3@X0200E4@h06QHC01LE4@0<2`L04A0<00h=2@0=30P04Q4=1P0>3@T05@0C4Pl02`X801DD4P04
0`4020L501<B400=30X03Pd;014@3P0B4@l04A0>00l>300@3`d030/7014@300:2@D03`h:01<B3P0K
6QH06APD01DD4002014@300>018A3@0;2PH00P4001PG4`020@001`H200/:1P0>3@T03`h:010?2`0?
2`P03PX7010<2@0B4@d200l>2P0500T8100510002PT500/:1P0>3@T00P0A40`08P0:2@D01PD1014@
3P0?3P`02`X800T81P081`D01`H400T81P0=30X030/900P71@0920H03Pd;01@B4`0=2``020H701<A
4P0B41400@0000T7200?3@h03@/<00h<3@0D4Q<04a4B00d;300<2P/02`T:00d;300B41405A<D01@B
4`0@3Pl200l=3P0400h<3@0<2P/04a4B00X82@802@L800P01`D601DC500@3Pl04a4B065OH00]:b`0
40h?00/92PH03@/<00H02@L8014?400<2P/01P@500d;300C4A8300/92P0400d;300?3@h040h?00X8
2@80518C00T00`4200`:2`0=30/09bHT00<2000R8Al03`h<010?3@081`D00P0=30X08@0<2`T02PT7
00/:200=2`T03PX9014=300>2PT01@4000l;2P0E4A003`/:01`H5`0@30/07ATH00<0000<2`X061XI
00410@091`L00`0001@;3P0@1PX060dA01482`0A2P`050h@01<?400>2P/00`0000`82@0X92D03PX;
010<3@0200l;30@040`=00/00`0003Lc=00C3a006aLH014=3P0?30`02@D601/G600A3@h0510A00X6
1`02018>3`0B010<3@0?2``03PX;00`82@0@30d03@T:00h:2`0?2``03@T:00`82@0=2@X020H901@B
5@040PD00@0201TG6P0100803@/>0`0>30l200l=40803`X>0P0>2@d2010;3`0600@00`0?2Ph04`hB
01LB5P0>2@d020<7100>2@d2010;3`803`X>00/040/?018=4@0B3A4040/?00d;400R82D0GUaQ00l=
4P0A3a@01`D:00l=4P0300h<4@0700l=4P0@3Q<04`hE00h93`0;1P`030L=014<400201@?4`0600h:
2`0@30d040`=00l;300A3@h03PT=0P0<1`/01P0=20`03PT=00l:3P0@2`l03`X>00h93@803`X>00<0
40/?00l92`0@2P`00P0A2`d02@0@2P`05@lA01/E5`0B30h01@0100d72@0D3Q004`hA00l:3P0300h9
3@0600l:3P0B3A404PdA018=4@0:1PT01`860`0?2Ph01P0N6Ad0BDA800<00P0K5QX03@P<00h93@80
3@P<00P03PT=00l:3P0@2a003@P>00l:40091@X02`H<014<4P803PT?0P0?2Q0200h93`03010;3`0?
2Ph03PT=00803@P<0P0>2@d01P0?2Ph040/?00h93@0>2@d04PdA00/720<03`/<00@0510A01<?4008
10D03@T:0P0@30d02`0D41405Q8C01<?400L61T07ATJ00/7200B3Pl03PX;00l;300A3@h04`l@0080
3`/<00L04Ph?00H20`0?2``04@d>00@00@0?2``03PX;00H03`/<00d03@T8010<2`0B3Pd04Ph=00l;
2P0;1`H04Ph=010<2`0<20L081`K014=300>2PT04@d<00<040`;0P0?2`X00`0>2PT040`;018>3@02
018>3@0U010<2`0?3@h05A<D01XH6@0<2P/03P`=00d;300;2@X03P`=010>3`0B41405Q@E01TH5P0?
3P/030/900l>300>3@/03@/<010>3`0;2@X04Q0C014?4P0;2@`07adR03Dc=P0=2``01@<402LU9P0D
4Q<09bDV092>S`0T8R<04@l@01<A4P0A3a003@/<01<A4P02014?4P804Q0C0P0C4A@3018@4`0F01<A
500D4QD04Q4C00l?3`0D51@05aLG00d=3@0>3Ph05ADE01LG5`0I6AT05QHF00l?3`0=3@d02@X800d?
2P0B50l06adI01@F4`0<3P/04aDC01@F5@<05AHH01l05QLI01<E600E61d06AdP01TM7`0J7Ql061`M
01@H6`0F6Qd05aXR01@F8P0B52004QDR01TM:@0=51h05A`U00T=5P0_=3X05a`P01HI7P0C5Q/06AXO
01PI7P0A4QL04aDL01LK9`0F72X05ahY01PL9`0H7B<06b0U00805QXM01l06AXO01PH800I6B406a/U
01@F8P0H6RH06A`U01TL8`0N8BP07R4V01TL8@0H6b4051LN018E7P0G6B@07R4Z02HV;P0I6Ql0824V
00X;401;Be804A4I010@600F5Qh04a<K01`L900G5b002PXB01<B5`0B4Q@04a<E00805ADG00h04Q8D
01<C5@0D51H04a<E00/;3@0B4Q@03@d?01@B5@0I5aP06QPI01LE5P0C4A804@l@01DC50805QDC00P0
51<A014@3P0@3`d04@l@01PF5`0S8B807Q`M01@B4`8061HG0P0G5AH07P0F51D05A<D01@B4`0E4a@0
518C01HD5@0]:b`081hQ01<A500>30l061HK01HD6@0G5AX030T@01LE6P0G5AT05Q@G00D31P0/:Rd0
ZjV/061NH@0D4QD04Q0C01HD5`0D4QD04Q0C01DA500C3A404@/?018<40@04`dA01P05@lC01LA5@0F
41@050hB01PB5P0D3Q8030H:00X4200>20`06A<G01XD600?2@d040X>014;3`0C3A405a4E01LA5P0=
1Pd09b0W04Q1B00C31<010040109400A2Q4200d63@0>0109400>1`h040L@01864P0D21@04@D?0104
3P0B1Q007Q<K01873`0B1`d01`0201D:400E2a0201<8400701873`0A1Ph040D=01053@0A1Ph040D=
01@94@0200X01`0?01063P0;0@`0610K00P22`0F31D02`4:01073`0=0PX01`0401L<500A10/09APO
00/01@0>0`T03`@:008040D;00P03`@:00h32@0O51X02`8606QMH`1oM7X030<701`A5`@03P<70P0?
0`L01P0A1@T06@lA00P0000=0@D040H800P001Cooooo000Kooooo`0A00h:1P0E4@h02`L601@@3@0Q
7AT0510<010=2@0A3@X04Ph;014=2P0B3P/03@T501LC400A3@X04Ph;020L6@0A3@X00P0>2PL04@0E
4@h04@d:01<?300G4a00510=01HB4@0E4A005Q8A010<2`0=2@P05a<B018>3@0@30/04@d<01@@3`0C
3`h04Ph=00803`/:02<04@d<01<?3P0@30/03PX9014=300H51<040`;018>3@0;1`L04@d<010?3@0<
2`T03`h<01<B40071PD04A0>01<B400:2@L03`h<010?3@0:2@L05Q8@01@>2`0C30X04P`9018=2P0C
3``050l<01@@3@0A3`/040h;00`;1`0?3`/03@X700h:1`02014=2P8040`90P0?2`P0200A3@X04Ph;
01<?300F4Pl0514>00/:1P0n?CT0CDa80P0H5a<2010?2`803`h:0P0=30P0200>3@X03`h<00h=2`0D
4a405A@B00`;2@0>3@/04A0>0P0B4@l02@0E51804A0>00d<200=30P040l;00`;1P0?3PX040l:00d<
200200l>2@0700`;1`0E51003Pd8014>2`0;20D04a0=00/:1P02018A3@0800l>2P081`D04A0<00/9
1@0?30T03`d900h=200=30P2010?2`0600h=2@0?3PT03@`8014@300>3@T040l;0P0>3@T01`0A40h0
30/9010?3@0D4a403`h<014@3P0@3`d00P0<2`T02`0?3P`04A0>00h=2`0>30d03@/<014?400D4Q<0
8AlP030^;`0>30d04@l@00803@/<00D040h?00`:2`0@3Pl03@/<00`:2`0200h<3@0B00d;300A3a00
3P`=00/92P0=2``03P`=00/92P0?3@h020L701DC500;2PX03P`=00`:2`0;2@X0518C010>3`0920P0
518C100=2``02@0>30d03`d>00l=3P0:20T0518C00`:2`0A3a0030X;00X82@0300`:2`0@00h<3@0=
2``03@/<00h<3@040P<03P`=01@B4`0<2P/03@/;01dL6P0P7ad0[JbZ030_;@081`D040l=00l>30@0
3Pd;00<040d<00d9200<20L00P0>2PT0A@0Q7A`08alN018>3@0<20L03PX900d9200?2`X030/:00lA
400;2`/03P`=00h:2`0?1`T050X=01462P0C2Pd04P/=00`6200A3@h03PX;00`82@0E4A8020D500d9
2P0C3a004@d>00d92P0@30d03`/<010<3@0?2``040/<01PC5@0<1`T02PD600l:2`0B3@h040/<01D@
4P0@2`d04Pd?00l:300?2P/02`L8014=3P0?2``03PX;010<3@0D41403PX;00T51P0B3Pl02PL701/G
600?2``03`d@00h<3`0@3Q403`d@00/9300B41<040hA00`:3@0?3A003@/>00h<3`0A3a803@P<010;
3`0200l:3P<04`hB00D03PT=00l:3P0@2`l03PT=010;3`0400l:3P803PT=00`04PdA00l:3P091@P0
3`X>018=4@0>2@d03P`A02XX;@1RH6D03`dB018@5@0>314600l=4P0800d83`0?2Q0050lE010;4@0@
2`l03`X>014<400;1`P2018>3`0500d92P0@30d04@`@00l:3P0@2`l00`0A3103010;3`0@00l:3P0>
2@d03PT=01<>400;1PL04@`>010;300@2`d03@P900/61`0B3@h04Pd?00l:2`0A30d03@P:00h93@<0
3@P<01D03PT=00`72`0@2`l03@P<00l:3P0<1`/04@`@00/62P0E41@09B0T04i9C@0A310050lC00d8
300H4aL0CdY>00l:3P0;1PX05A0D010;400=20h00P0C3Q@03P0>2@l040/A00h93`0:1@/04@`B00d8
3P0C3Q@03@P>018=4@0N6Ad0>SDi010;3`0B3A4030L;0`0?2Ph200d8300@00l:3P0?2``05a<D02HR
8`0A3@h03PX;00l;300D41405A4B01<?400:1PL04Ph?010<3@0:1PL06QHG02XV9`805a<D00D03`/<
00`82@0=2@X04Ph?014=3P02010<3@<04@d>00<030P901@@4@0710@00P0@30d3014=3P03010<3@0@
30/040`;008040`;00P03`/:00d9200D40l04Ph=00T5100F4Q402PH601<?3P8040`;00D04@d<018>
3@0B3Pd040`;00d92002014=300A01<?3P0?2`X04@d<00d;300?3@h04@l@00d;300I5aP08AlP014?
400H5QL02PP901@B4`0=2``03Pd;014@3@081`D00P0>3@/0500=2``04@l@00l=3P0=2`h04@lB010>
4@0?3A8040hA01<A4`0;2@X040h?00h<3@0:20T061HG010>3`0;2@X03`d>018@4@0?3@h040h?0P0A
3a802P0B41<04a4D01<A500D4QD05Q@G01DC5P0B41<05A<F01HD5`0C4Q@201DE5@0C018B4P0D51@0
5ADE01HF5P0>3Ph061PH00h>3P0Q8B405QHF01HG5P0J71P04Q@@01<E4P0G6AH051HD01HH5`0D5QH0
5AHH01HG6@0201@E600n01HH7@0H6b004A@I01@H6`0E6A/05QXK01@H6`0F6Qd05aXP02DX<@0D5b40
4aHR01DI900?5Ql06R4Y030d?00F6R8051PO01@G7@0I72808R<X01`M8@0G61d07R0U01TM:@0H7R`0
6b4/01dQ;00K82H05a`Q01HJ7@0W:bh08B8W01PH800J6R806ATS01hP;00L7RX061/T01LJ8@0I72<0
6QdR01TL8@0G6R006ahU01@G800M82X0=cY301LG7`0H6Al05aPN01<D6@0R8bP05QLM018B6@0P82L0
4a<J00l?5P0G61h071dR01HE6P0F5QP201DE5`0301<C5@0A4A<04Q8D008051@F00@04Q8D01TI6`0H
61X05Q@E0P0C4A803P0G5AH061HG01@B4`0E4a@04Q0A01@C4P0F51D04a4C018@4@0F51D05aDF01XH
6@0F51D04a4B0P0G5AH0100E4a@06QPI01XH6@0E4a@201<A4P<05aDF01P05A<F01LE600A3a808R0U
05=AEP0A3a@06aPO01HD6@0D4QH05aDH01`J7@0E4aH0CD]>02DS9P0C4A@03`d@01<A500E4aH05aDH
01@@4`0F41@0618F01D?4`0A2`l201<=4@03018<400C3A405@lC008050hB01404P`@014;3`0B3100
4`dA01D?4`0G4AD05Q0D00d72`0<1`X04`dA014;3`0>20`040T?00T32@0<1@`071DL01D>5@0200l8
3`0A018;4P0>1`h03PL>014:4@0?20l03`H?0104400C1a<04PH@01043P0B1Q004`P@00h32`0A1``0
5P/A034V;01SF5h00P0?10`401053@0B00d22P0<0`T03`@<01D:4P0M4QX060hE00d3300?21403PL@
00h43@0B21403@<;01873`0?10`03@<901L:4@1WFV405P/?100@1@/200l42P0B00l52P0B1`d06PlE
02LL8P0C2@h02P4500/2100>0`L04@H:00l31`0@10P06@dA00`1100D2@`04PP:00l41`0B1`/03P86
5?ooool001_ooooo00X0<Rh[014=2P0D40d02PH301DB3@0;20<03``701<@300>2PL01`<00P0@30T0
4@0C3``01`@2014=2P0K5a@02@D401/G500@30T0510=014=2P0C3``0510=010<2@0?2`X040`;00d9
200A3@`05A4@0080510?0P0A3@`0400B3Pd040`;00h:2@0A3@`03`/:014=300B3Pd040`;00l;2P0F
4Q409R8Q01`H5`0<20L08AdL01PD4`0?3P`2010?3@0H00h=2`0;2PP02@P600X91`0P7ad05A@B01PG
5@0I61H02`P701@?300B3@X04@`9018=2P0C3``04Ph;00d<200<2`L03Pd901XI5@0N7aX030/7014=
2P0C3``04Ph;0P0?2`P0500>2PL03`/8018>2`0D40d04Ph;010<2@0@3PX01`H203<b;P16AD404Q4=
010?2`0=30P040l;00l>2P0>3@T03@`800`;1`0=30T03Pd;0P0?3P`200h=2`0B00X91`0=30X03@`:
00@30@0@3`d051<@00l>2@0<2`H02`X500h=200?3PT03Pd801XI500>3@P03@`702HU8011@3/081lJ
0P0@30T04`0A3@X03`h:00l>2P0@3`/0B4M302PW8`061@806APD00`;1`0@3`/04A0;010?2P0?3PT0
3Pd800l>2@0@3`X020L200X9100<2`H00P0;2PD01`0<2`H030/900l>300>3@/02@P6014@3P071P@0
1P0>3@/01@0=2``030X;00<10P0R82408AlP00804@l@00d03P`=00@20`01000071XK05YHF@0C4A80
3`d>00`:2`0=2``03P`=00/92P0@3Pl03`d>00802PP900P030X;00X82@0A3a003P`=014?400<2P/0
40h?00`:2`H03@/<00@03P`=00d;300<2P/030X;0P0=2``01`0A3a000@00014?400A3a004a4B01HD
5@0>30d00P0=2``0300>30d030X;00X82@0>30d030X;00d;300>30d03@/<00h<300A40h03Pd;05IE
D`8040l=0P0>3@/01P0<2`T03@`:00l>300?3P`03@/900`81`803@T800D03`/:018>3@0A3@`03@T8
00h:2@0300l;2P0@010?3P0O8B00:BTY01@B4`070`@071<F00l52@0?10P03`H901<;3P0O6A/09b<T
00d92P0>2P/040`=00h:2`803@T:0P0E4A80500<20T0100100H20`0E4A8030H8018<3P0<1PP071HH
01dG6@070P<050h@01PB500K5AL05Q0B01<=3`0F41802`L801@@4@0@30d03@T:0P0?2``02@0:1PL0
<2`]03di>P0F4Q<0;BTZ01hJ6`0@3Q403`d@00h<3`0300d;3P0800<1100:20/03P`?010>4@0200<0
30X=00d8300B3A4200h93@03010;3`0:1@T03`X>00D03`X>00@040/?014<400A31004@`@0P0B3A40
1`03008040/?02<N8P0E41@02`H:00h93@0;2@h00P0A3a@200/93P0/00h<4@0:20d02`T>00/93P0<
2Pl03@/@00h<4@0<20h00`0400/6300=20h03`X>00P31`0=20`04Ph?01`H6@0F4Q<030P9010<3@0=
20`02`H:00d8300?2Ph03@P<00`72`0@2`l04@`@018=4@0C3Q804@`@010;3`0>2P/020@501@@4@0A
3@h03`/<01LC500A3@h02@D600`82@0A3@h0510A018=400>2@d300l:3P0E00h93@0=20`06A@H00h9
3@0D3a<01`8600H11@050@@02`H:010;3`0B3A403PT=00/62P0?2Ph02`H:04E0A00>2@d02@@800H1
1@0=20d03`X@00803PT?0P0=20h0300?2Q0020<901HA5`070PP04PdC00/6300910P0BDA807MbMP03
00802`H:010;3`803@P<0`0>2@d08@0?2Ph00`0000H20`0G4a@01P8300l;300>2P/030P900d92P0C
3a002`L801<?400;1`P040`=00`82@0D41403`/<01<?400I5AH061@E018>3`0?2``01`<4018>3`0J
5QL03PX;010<3@0A3@h040`=00l;300=2@X03PX;010<3@03018>3`03010<3@0E4A004`l>00804@d<
0`0B3Pd01P0>2PT03@T801TE500=2@P03PX9010<2`<04@d<0P0@30/01`0=2@P0510?018>3@0E4A00
3PX901<?3P0@3Pl00P0=2``03@0>30d04@l@018@4@0>30d05A<D00<10P0C4A802PP901@C4@0];2T0
5A@B00d<2P0>3@/00P0D4Q<0100B414040hA00l=400>30l200h<4@0700l=3`0C4A80518C010>3`0E
4a@03`d>014?400200l=3P0301<A4P0D4Q<04a4B008040hA00@04@lB018@4`0B41<04a4D0P0H5QT0
200C4A@05Q@G01HD5`0D4aD051@D01<C4`0F5QH061PH0P0G5aL0200L71`0:RXZ01PH600>3Ph04Q8B
01LH5P0C5A8051HC0P0E5a@0;P0E5aH051HF01@E5`0F5aT05aPK01@E6@0E5QX051HL01PK8P0A51/0
71lT018F6@0G6a`09BT/01<G6P0H6b0030lF014D7@0Q92l07B4Z01@K8`0Q:300E5QQ01HJ8`0I7BH0
5QTR01XM900K72805aPM01TJ7P0J72406al[01LM:`0G7BP0720[01`Q9`0H7B8061`O01LK7P0I6Ql0
71`T014A6@0F5R006Q`X01PJ9P0H6b@201/N9@0C01LJ7`0C5Q/05aXP01XM900C5Ql0418M01`O:00D
51h061PP01<C6`0B4aP06AXO01XK800F5a`07AhS01LH7@0A4QL04a@I01<D600201LG6@0C01DE5`0D
51H051@F01<C5@0?3a404a<E01DE5`0F5QP08R8T02l_;`0J61T04a4B014?400F51D06ALH01HD5@0G
5AH04@lA01@B5@0201LE600=01TG6P0C4A<030X;00h<3@0H5QL06QPI01HD5@0H5QL0518C01LE5P0J
61T061HG01LE5P0401DC500E01PF6@0J61/040hA024O901QGf@05A<H014>5@091``071XN02PV:@0K
6A`02`T<01TG6P0;2@`04a4D01LE600L6Qd040hA01@B5@0D41<04P`@00@04`dA00<04P`@014;3`0A
2`l0100B31003`0A2`l04`dA01<=4@0C3A404@/?01@>4P0?2@d04`dA02DO8`0P6Qh0618F01D?500@
2A003`P?014:4@0200h73P04014:4@0<1@`030D<00l83`8030D<00<04@PA01864P0B1Q800`0B1Q00
1P0R5al050TA01873@0D2@l0200302LL8P803`@<0P0@1@d201463P0?00h32`0A1Ph0308901053@0K
41P05@/C01@:4`0=1Ph03PL?00`22`0800L05`dE02/P:00Y7R@06PlE0080200200<050P<01052`0@
1@/00P0?10X200h32@0;00T0100:0@D04`P>01P=4`0F2a4050T?01452@0?0`L04@D900l31`0>0PH0
0P0E2@d01@0F2`l04PL;01052@0@1@T0304501Cooooo000Kooooo`0H09FAT00H518081`I00/80`0D
4@`03@X300/80@0A3PP0514<00h:1`0C3`d05Q8A01XF4`0H51403@T600l;200L61D02`L400l;200B
3P/03`/8014=2P0B3P/03`/80P0@30/0100810<04@d<01HB4@0=2@P201<?3P0[018>3@0@30/03`/:
010<2`0B3Pd040`;014=300C3`h04@d<00l;2P1EDE002`L601TE50091PD06QHE00`81`0=30X03Pd;
00l>300>3@/02`X800T81P0A40l03@`:014@3P0h=cD051<A014>2`0C3P/04Pd:014<2@0A3@X04Ph;
010=2P0C4Ph05A@@01hO6P0H6A@030d801<A3@0B3P/0510=018>2`03010<2@804@d:00@04Ph;014=
2P0@30T040d:0P0?3PX00`0C4Ph040l;00d<200600h=2@803`h:00h03@`800`;1`0=30P040l;014@
300B4@d05QDA00P70`0L6aL09bHR00h=200=30L030/600h=20803`h900P00`8000H5000;2PD02@P3
01TH4`0=30L03`/8010;20<040`900X03`h:0040000100001@H201PI500:2`H05aPC01<B3@0B4@`0
4A0;0`0?3PT0100;2PD03@`700d<1`0>3@P200d<1`0600`;2@0;2PT00`8001LF500<2`T01`H41P0?
3P`01@0:20T0=S@e00h<3@0F51D03@/<00804Q0A00L03@/<01TG600F51D03@/<020N7`0B41403`d>
00803@/<00@03P`=00/92P0>30d04@l@0`0=2``01`0;2@X04@l@00/92P0A3a003@/<00l=3P0:20T0
1P0=2``0100>30d03@/<00`:2`0;2@X200X82@0703lm?P0J61T02@L800H41@0L6Q/00@0000h<3@02
00d;300B00h<3@0<2P/02PP900d;300C4A802@L8018@4@0C4A802`T901<B40081`D030/900/:200E
518030/900h=2`0<2`T03@`:0P0?3P`01`0>30X03PX900l;2P0>2PT03@T800`81`0=2@P00`0?2`X0
3P0@30/04@d<01PG5P0620L02@T900P61`0<20T05Pd@00`41P0D2@d03`H900h72@0Q6ad07a/L0P0=
2@X08`0>2P/040`=010<3@0>2P/01001014=3P0?2``06QHG018>3`0810D0208401TC5@0A2`d02084
00h82P0O6A/04@/=01@>400G4A<04`d?014;3@0D3Q003PX;018>3`0E4A803`/<00`82@0=2@X04`l@
01lK700W8b@07QXK01`H6@0J5QL03P`?00<03`d@00P03P`?00`:3@0=2`h040hA00X82`0E4aH04Q0C
01DC5P803PX;00@03@T:010<3@0D41403PX;1P0?2``300h93@803`X>00d040/?00l:3P0B3A402@@8
00`72`0C3Q804@`@00`:3`0@3Q<03`dB00X83@091``02`T>00<030X?0`0>31403@0A31<040/A01HA
5`0A31804@`@00`72`0>2@d06ADF028N7`0H51D03PX;018>3`0A31000P0>2@d01P0@2`l03`X>00h9
3@0?2Ph040/?018=4@804`hB00X04PdA00/92P0;2@X04Q0A00l=3P081PL03P`=00`:2`081PL03`d>
0P091`P00`0D41<03`X>010;3`02010;3`0600l:3P0<1`/050lC00H11@0>2@d03@P<0P0E41@01@0=
20`02PD900l:3P0910P020<700803`X>00D050lC014<400J5AT030L;01D@5@0200l:40<03PT?0P0@
2a405`0M61h030L=018=4`0>2@l05Q4E00D0100D41<07QTM03<^<P0;1`X030L;00d8300?2Ph04@`@
018=4@0D3a<061@E01@@4@091@H01`<401HB4`0=2@X030P900804`l@00D030P901<?400=2@X04`l@
00T51P0200/7200<01<?400I5AH0100101@@4@0F4Q<00`0001TE5P0300003@T:00l;300@30d04@d>
0P0@30d0100>2P/03`/<010<3@0A3@h2010<3@0401@@3`0C3`h04@d<014=30804Ph=00D04@d<010<
2`0C3`h08AdL01DA4002010<2`0>01<?3P0A3@`03`/:014=300E4A002@D4018>3@0?2`X0510?00l;
2P0C3`h04@l@010>3`0?3@h200h<3@0?00d;300;2@X0518C00h<3@0C4A803@/<01PG5@0?3P/040l=
00d<2P0@3`d020H70040000C4A804@lB00803`d@0P0?3A80300?3A004a4D018@4`0B41<06ALJ00d;
3P0B41<040hA014?4P0E4aH05Q@G01DC5P804@lB0`0B41<0100D4QD05aDH01LE600D4QD201HD5`0E
01DD5@0E5AD051@D01HF5P0H61P05aLG01DE5@0?3`l00`<301PH600E5AD07QhN01HG5@0D5Q<061XI
01/M700I6aX05QLI01@E5`0F5aT061TM00805aPL03L061TM01DG7@0K7RD04aHM01hQ9P0B5QT06QhO
01PL7@0:3Q405QTN01LJ8@0X:c80@TE>00022`0M92`03QDM02X^>@0G6bH041@O020R;P0K7RL06a/T
01XK800G61d05ALK01XN:P0G7B/061hY01/O:P0L8BL06QlT018F6@0C5aX05aPM01PH800V9Rh08R8/
01<E8@0D5R8061/T01TL8`0H6b805QTN01XM8P0M82H092L^02<V;`0H6bD04QDN01@D7P0F5Qh04a<K
01<D6@0K72407b0U00806Q/O00H051DI018C5`0D5AP04Q<E01PH6P0F5QH201<C4`@051@D00d04Q8B
014A4@0K6a/09bLW01XH6@0D4a804Q0A01DC500F51H04a4D01TG6P0C4AD05A<H00805aDJ00@06ALJ
01HF600A4A<04Q8D0P0F5QP0200D51H05ADG01DE5`0B4Q@04a<E01@D5P0B4Q@05aDF0P0D4Q<05@0F
51D05Q@G01HD5`0G5AP02`T>01XH7@0C4AH040dD014?500B41@06aTL01HD5`0N71l09bDX00h<3`0?
3A004Q0C01TG6P0>30l04Q0C01DA5@02018<40804@/?00<04P`@01<=4@0C3A400P0C3A45018<400:
01<=4@0B31004P`@00h830080PH030H:01TC5`0B31002`D900h73@<03PL>01@02`@;00l83`0B2a80
30D<00h73P0B2a803PL>00`5300A1a404PHB01454@0@10h04@D?01@84P0;00P01`0400l42P0G3180
5@X@00d420803`@<0`0@1@d0500A1Ph03`@<01873`0<0PT0304901<8400=0`X050XC00H01`0>1`l0
4PP@00T01`0`9Rh0JEiT02dR:007004060`@01D93@0;00<03`@:0`0>0`T200d2200B00P00`0C20h0
40D;00L00P0M51P0CT=901L;3`0@0PH040460104200>0PH02`0300d21P0700004PL;00`31P0=10L0
2P445?ooool001_ooooo01@0GEUI010<2`0B3P/02@H300d:100?30@03P/300`91@0N6aH0510=00l;
2P0h=3<0DTi;01HB3`0:1P@05A4>02HR7`0C3``04@d:010<2@<03PX700P03`/8014=300A3@`04`l>
00l;2P0@30/05a<B014=30805A4@01004Ph=01DA400H51<04`l>014=300B3Pd0510?018>3@0@30/0
@3`k018?3P070`<061@C00`81`0A3@`03Pd;0`0?3P`200h=2`0B010?3@0F5A<0?C`j08f<RP0;2PP0
518?018>2`0B3@X04@`9014=2P0A3P/03`d900/:1P0C50l0QHJ108N8P`0J6aH03`l;0P0B3P/00`0@
30T03PX700l;2002018>2`0;014=2P0@30T03`/800l;200>30P05QDA00l>2P0?3P/03`h:00X91@0A
40`00P0=30P0100>3@T03`h:010?2`0?3PX500h=2@0400X91@0920@040l;00P70`806APD00`03Pd8
00h=1`0=3@H03@d600l>200@3`T03@`601/K500T91d020P300d<1P0F5@l3018=2P804@d:01T040h:
01HE4@0=30P06Q/F00d>2@1@DD`0QXN2018A300A4@X04A0:00l>200>3@L030`5010?2@0>3PL03Pd7
00h>1`0=30H02@P3018A3@0=30X061LF05EDDP0A40l04A0>00<03`h<0P0>3@/0300=30X020H701/I
6P0A3a002PP901<A4P0@3Pl02`T:00/:2P0;2@X030X;00h<3@<03@/<00@03P`=00l=3P0?3@h040h?
0P0<2P/02P0>30d061HG01HD5@0>30d04@l@00P61`0?3@h02`T:00d;300<2P/800d;30803P`=0P0=
2``01`0a;c00;R`]014?400:20T04a4B018@4@0>30d00P0=2``01@0>30d030X;00X82@0=2``04@l@
008030X;00@03@/<00h<30061@<03Pd;0P0B4@l01@0:2@L040l=00h=2`0<2`T03@`:00803`h<00<0
4@l=014=300?2`X00P0?2`X00`0>2PT03`/:010<2`0200l;2P0?010<2`0B3Pd0:RTX00/=30092@T0
3`d=01XF5`0;0PD060hA01@93@0<0`H040T;010:300C3a003PX;008030P901804@d>018>3`0>2P/0
2`L801DA4P0A3@h0=C4b02hZ:`0<20T050h@00d6200<10L06a@F018;3@0F3a403PL901082`0A2P`2
00l82P0?014:300C3a002`L801<?400>2P/040`=014=3P0>2P/02`P800h:2`0@30d04@d>00`82@0=
2`h03`d@008040hA00h03`d@00d;3P0?3A00GeeP06ESIP0D4QD04a4D00l=400T824061@E010<3@0A
3@h04Ph?00h:2`H03`/<00@03PT=00l:3P0?2Ph03`X>0`0@2`l05@1?BTh05Q8E01<>4P0>2@d04PdA
010>4`0B41D04@lD00h<4@0<2Pl03@/@00`:3`0;2@h030X?00h<4@0=2a002`T>010;4P0Y92X0:RD[
010;4@0200h93@09010;3`0C3a0061@E01DA4P0?2``040`=01<>4P0>2@d03@P<00803`X>00<03PT=
00l:3P0?2Ph0100?2Ph03@0>30d030X;018@4@0C4A803@/<01<A4P0B41402@L800`:2`0B41402PP9
00`82`0>2@d00`0?2Ph0500>2@d03@P<01PC5`0:1@T04@`@00/62P0?2Ph07APL01XE6@0@2`l05A0D
00d8300;1PX03`/>03@_<`0V8BD030P;014<400D3a<03`X?0P0?2Q003P0>2@l03`X@010;4@0?2Q00
4PdC01PC6@0=20h04PdC00h93`0>2@d03`/>018=4@0<1`/03@P<0`0>2@d03P0@2`l04@`@018=4@0C
3Q80:BDV02DQ8P0>2P/05a<D00/7200A3@h040`=01LC500<20T03PX;0`0A3@h02`0<20T0510A00l;
300@30d03`/<01@@4@0>2P/0=C8b02XW9`0@30d04Ph?00804@d>0`0@30d00`0?2``03PX;00h:2`02
00l;308040`=1`0@30/04`0?2`X03PX901`H5`0D40l030P700X61@0?2`X040`;00h:2@0F4Q408QhM
010<2`0D40l02@D400l;2P0@30/04Ph=00l=3P0@3Pl00P0A3a003`0>30d03@/<014?400R82405Q@E
00l=3P0C4A801`H401@C400920H040l=01@C4@0C4A805Q@E00l=3P0200l=400:014?4P0B41D04a4F
014?4P0B41<03P`?010>4@0J61/03P`?01@B5@804@lB00<05A<F01@B5@0C4A@01@0B41<00`0D4QD0
5A<F01DC5P0301DC5P0401DD5@0E5AD05ADE01DE5@805QHF04<051@D01LG5`0M7Ad04a<C01XJ6P0>
3Ph05AHE01<E4`0E5aH061XI01LI600E5QP05AHI01XK7P0J6al05AHK01LH700I6Qh06A/R01PK900A
51d06A`R010C600F6Qd05ATJ01`P8@0G6Qh0<3<j01DH7`0F6R<07B4[01<J8`0D6bD07B4]01hR;`0X
;3T08bDc01PJ:00I6BD08B4Y01`M8P0I6b0061`X01PN;00K8Rd07R8]01dR:00J7b@06AdP010D5`0M
7R<06a/S02HV;P0X:3804aDQ01`N:P0U:3406A`S01<F7@0I72405aXO01@G7@0C5Qd04aHO01<E800A
51d05QHP00805aLO00l061TN01hO900U9R/07b0T01TJ7@0D5AL05QLI01LI6@0D5QH061PH01DE5@0B
4Q804A4A01<C4`0F5QH00P0G5aL03@0D51@04Q8B01<C4`0G5aL05aHD01@C4P0D4Q805A<D01HD5P0E
4aH06aTM01HC600E4QP00P0C41H02P0G51X061LJ01LG6@0I6A/051@F01<C5@0H61X05ADG01XJ700F
5QP201DE5`0K014A4`0H5QL04a4B01@B4`0G5AH05A<F014?4P0E4aH06QPM014?500E4aP05Q<J01TG
700G5AT040hA01@B5@0C4A@04Q0C01PF6@0E4aH04a4D014?4P0@3Q405Q@G014=4@0E3a<04`dA0080
4P`@00@04`dA01@>4P0D3Q8050hB0`0C3A46018<400401D?4`0D3Q804P`@014;3`802`D900L03`P>
00d63@0@2A004@XA0109400H4AP06Q<J00803`P?00l04@XA00l83`0?20l04@LA0104400C1a<050PB
01<74@0B1Q0040D=01D:4P0E2Q002`8601L<4P0?1PX01`0@1@d04@0B1`l040D=01463P0E2Q804@L?
01063`080`T03@H=00l53@0:0@P08APN02XO9@0E2Q0040H901D93@0<0P@04@D800H03`@:018040L;
01883@0@1P/03`@:02PN8`1?@TT04`@90182200B0`P04`@901852P0?0`L04PL;00l5200B20/03`H9
00`51P0<1@LDooooo`006oooool04`050@8061@D00X60`0H51405A8;01LD2`0=2P4040d601HC3P07
0`80:BDU08Z6Q`0]:BP01`<1010<2@0H51405A4>01dI5P0H51400P0C3``2014=2P0701@@3@0?2`X0
2`L601DA400?2`X07QXI03di>00201HB4@0@01DA400B3Pd04Ph=01<?3P0B3Pd040`;014=300C3`h0
4@d<00l;2P0E4A003PX900<0001@C4/06QHE00<000803Pd;00X03`h<010?3@0A40h04A0>00l>300=
30X01`H4024P7P0E51803P`9100@30T0200>3@T02`X601DD400F5a806Q/F03dn>@0:30L03@d80P0@
30T01@0>2PL030P500h:1`0A3@X040`900@03`/800L04a4=00`;1`05100040l;018A3@0:2@D02`X6
00803@`800D03Pd900l>2P0?3PX03Pd900d<2002010?2`0D00l>2P0=30P040l;018A3@0@3`/04a8>
018A3@0;2PH03@d500h>1P0?3`L03@d500h>1P0A4@T051@<014A2@0B4PX02PX201<C2`0@3`L301@?
30<04Ph;00L01`H201HE4@0=3PX051HA028T7`0Z;2H03Pl900803`l701803Ph600d=1@0;2`<030`4
00X:0P0=3@D04A4901<C2`0?3PT01`H2018A3`0D4a409B@R014@3P071P@03`h<00h=2`0=30X200`;
2@0?00/:200E4a@0:BLX04E3A00>30d02`X:01@B4`0610D0:RPY01lM7P0:20T02@L800L51P081PL0
3@/<00803`d>00h040h?018@4@0=2``02@L800/92P0D4Q<040h?00D3100@3Pl030X;01DC500;2@X0
30X;00l=3PH03@/<00@02`T:00h<3@0@3Pl040h?0P0?3@h01@0`;Rl0I69S01<A4P0E4a@04a4B0080
3P`=0P0=2``00`0>30d030X;00X82@0200d;3004010>3`0;2@X02`T:01<A4@802`X800L01`H400l>
300=30X04Q4?00h=2`0<2`T03@`:00803`h<00@040d<00d920091@@02`L60P0@30/400l;2P0>010<
2`0A3@`03Ph=010B4@0l?3`030X:038^;`0B2@`040H901@93@0:0@@05PlA00L10`0A3@h200d92P0A
00h:2`0@30d040`=00h:2`0?2``061@E00h:2`0F4Q<04Ph?010<3@0<0`H04`X=01L>4@0800801P00
05YAE00C2Pd00P0B2@`201482`0?014:300L5QP02PH7010<3@0>2P/07ATJ00h:2`0@30d02PH700`8
2@050@8030P901<?400<2Pd03P`?00<03`d@00@03P`?01<A501kNG`0S8Z=0P0A3a80100<2Pd081`M
01<?400>2P/200l;3003014=3P0?2``03`/<00@03`/<00<03PT=00l:3P0?2Ph00`0@2`l01P0910P0
7APL01<>4P060@D07aXN059=D@803P`A00@03`dB00h<4@0<2Pl030X?0P0;2@h03@0@3Q<05Q@I01DC
600B41D03@P?010;4@0A31803`X@01<>4P0910P04@`@00X61`0;1`P00P0@30d0100>2P/040/?00d8
300=20`200l:3P0400d8300D3a<04PdA014<40<040/?01`03P`=00X82@0@3Pl03`d>020N7`0J61T0
2`T:018@4@0?3@h03@/<01<A4P0<2@/030L;00d8300>2@d03@P<00`72`0K5QX0;BP/01@?4`0?2Ph0
2PD901@?4`0K5QX04@`@00X52@0@2`l03PT=0P0=20`01P0F4AD061<G00X62@0300803@P<00X62P<0
3`X@00h040/A014<4P0>2@l04@`B00h93`0=20h05A0F01HA5`03008030L;00h93@0910P01P4501<>
4PD03`X>01d03PT=00h:2`0C3a0030P901@@4@0300004`l@00X61`0@30d03`/<02PT9@0H51D03@T:
00l;300;1`P04@d>00P41@0:1PL040`=01DA4P0<20T06QHG00L310050@805Q8C01DA4P0C3a0040`=
00l;300200h:2`803`/<00H03PX;00l;300A3@h04@d>010<2`0B3Pd301<?3P0F018>3@0?2`X04Ph=
00P40`0B3Pd03PX900/71P0>2PT040`;00l;2P0>2PT04`l>01`H5`0V8R40920O00l;2P0B3Pd04`l>
010<2`0<2P/03P`=010>3`804@l@014040h?00h<3@0L6Q/03@/<014?400i=cP07ahL01@C400L6aT0
?3/i038a;`0A3a0040h?01HD5@0D4QD04a4D018@4`02018@5@07014?4P0D4QD05A<F00h<3`0E4aH0
4@lB01@B5@02014?4P80518E100C4A@2018@4`0401@B5@0C4A@04a4D01HD5`80518E00l05A@E01<C
4`0E5AD051@D01<C4`0D51@07alO018B4P0G5aL0;bl_07EeM@0a<C406AXJ01LI600F61L00P0G6AP0
:00I6Q`061TL01`M8@0K72004Q<H01LH7@0I6Ql05ALO01<E8@0M82T051LN02lb=`0E6A`04aLH00/?
400F6Qd04A@I02<V;@0e>4402@dH00XA6`0E6bP05aXY04Y=GP1=D6406Q/]01<D9P0E52807AdW01hN
9P0L7R@0720/01TO;@0G7BP05ATT01HK8@0K82D05ATL010D5`0I6Ql201HF7P0D01/K9@0F62@08B<_
02P[=00G6R4041<J01TL8@0H6b0071lU01TL8`0G6R<061/U01HI8P0D51h051@L01LG7`0G61d06AXO
020Q9@0N7b<201HG6@0501PJ6@0F61L05ALF01DE5@0D51@00P0B4Q80200D51@05ADE01DE5@0G5aL0
6QXJ01TI6@0G5aL051@D0P0E51804P0F5A<05Q@E01LE5`0G5AP06ALL01HC6@0G51/05Q<J01/H8@0Q
7RD0<S4e00d=3`0>3Q006QXL01PH6P0F5QP061PJ014A4`804Q8D01d051@F01TI6`0F51D0518C01DC
500F51D04a4D014?4P0C4A@07adR01LE6P0<2Pl03P/B01@B5`0D4QH0518E01<A500O7B00518E010>
4@081PT06QPK01LE600@3Q406ALJ01@@500F41@05@lC01@>4P0201<=4@<050hB00<04`dA014;3`0A
2`l00`0B31001@0A2`l04P`@018<400?2@d030H:00803`T=00@02`D900T31`0=1P`03PL>0P0?20l0
0`0<1@`040T@01@=500200d63@0;0109400=1Pd03@H=0107400C1a<06PhJ01`@6P0J3QP05@TC0146
3P0700@00P0D2@l0100700806@hD01463P0A1Ph301053@0600l4300A1Ph04PL?01873`0A1Ph040D=
0P0>10`0300B2a8040T@00l53@0C2A4030@800d2200>0`T02`0401D93@0M4AD03`D600l42P<040D;
0P0A1P`04P0900@02P4501D:400K41H04`P>00`01P0@0@H06PT?01H52`0@0@H040<7010420070000
3@<700H0000U71l01P0101LA4aCooooo000Kooooo`05014<400=2PX00`00018>2`0?30D00P0;2000
300@3@H03``701DA4011?Cd0L6a]00<0000H51404@d:01LC400E4@h02PH301TE4P804`l<00X04@d:
010<2@0E4@h040`;00h:2@0C3`h03`/:01/G5P0`;2/0510?0`0B3Pd03`0@30/03`/:014=300?2`X0
4@d<018>3@0@30/03`/:00h:2@0A3@`04Ph=01LC4P0B3Pd03PX900`;2@0200d<2P0900l>300A40h0
4A0>00l>300C4Q005A@B00X91`0@3`d040d;008040`900X04@d:010<2@0>3@T0410<00d>2@0>3`X0
?Slj0:V[YP1EEe80410;0P0A3@X0100>2PL03@T600l;200@30T300l;208040`900L04@l;00d<2007
1P803@`801DD400?3PX02`X600D03Pd900l03`h:00h=200>3@P03@`700h=200?3PT01PD000l>2@05
100040l:00D4000?3P`03@d500l?1`0@40P00P0=3@D02P0A4@T04Q8:014A2@0D50`01PH000`<100>
3@D04`h;01D=2`0C3P/2018=2P09010<2@0;2PH05A@@010A300?4@`00P@000lC300=3PP03`l70080
410800`03`l700d=1@0>3PH030`4010@200F5Ph06ATA01DD3`071P803@`:00P71@01000200T81P80
40l=00L03Pd;00d<2P0<2`T02`X800/92P0510@071XK00804a4B00X01083010>3`0D4Q<02@L800L5
1P0B41405A<D00X82@0?3@h040h?0P0>30d03@0?3@h030X;00h<3@0<2P/03P`=00d;30081PL03P`=
01@B4`0Q7b004@l@00/92P0?3@h01P0=2``03@0<2P/03P`=00l=3P0?3@h03@/<00`:2`0?3@h081hO
01@B4`0;2@X00@0001DC500>30d00P0=2``01P0>30d030X;00X82@0=2``03`d>00h<3@805Q@E00X0
3`h=01@C4@0@3`d03`h<018A3`0C4Q003@`:00h=2`0<2`T03@`:0P0?3P`01P0?3@/030P700X61@0?
2`X04`l>010<2`803@T801@03PX900l;2P0?2`X03`/:00l?3P1OHF00emOG038`<@0=2@X050/>01lE
6@0N4aL03PD801@=3`090`D02PH700d92P0>2P/040`=00h:2`803@T:00H00`0000/7200?2``02PH7
00D10P070`@20189300F00l62@0D2`h03PD801H=400D2`h04PT<01072P0?1PT040L:00l82P0L5QP0
20@5010<3@0F4Q<0;RX[00d92P0F4Q<00`0001@@4@0810D01@42014=3P<03@/>00l03P`?00l=400@
3Q403`d@02HT9`0^;2l00@0200T72P050`H03@T:00/7200@30d04Ph?014=3P0E4A801P0?2``200`7
2`803@P<0P0>2@d01P0G4QH02PH901LB5P0H4aL03`X>00`72`802`T>01@03@/@00h<4@0=2a0030X?
014?500@3Q<04a4F01TG700F51T04@lD00l:4@0;1P`030L=01@?5@0J5AT03@P<018=4@0>2P/030P9
00h:2`804@d>00P04@`@010;3`0A31004`hB018=4@0@2`l04`hB014<408040/?02H04@`@018=4@0C
4A802PP9018@4@0N71d0JfUZ06QVI`0O7Ah071XK01PF5`030@80518C00l<3P0=20`03PT=00l:3P0>
2@d03@P<02TT:012?D407QTM00X52@03008020<700h93@0;1PX02@@800`72`0?2Ph03PT=00`72`03
00803PT=00l:3P0>2@d04`hB010;40<03`X@00h040/A014<4P0?2Q005a8H014<4P0?2Q006A@J02HQ
9`0N6Ad040/?01LB5P0J5AT01P4500`72`H03`X>00H03PX;01LC500A3@h03@T:018>3`0@30d200l;
300E01<?400k=cP07a/L010<3@0C3a002`L800h:2`0;1`P03`/<01<?400=2@X06aLH01HB4`030000
6QHG010<3@0D41404Ph?010<3@0?2``040`=00804@d>00l040`=00l;300?2``04Ph?01<?400@30/0
4Ph=01<?3P0D40l04`l>018>3@0@30/061@C00h:2@0E4A000P0A3@`02@0B3Pd04@d<00h:2@0>2PT0
4@d<01<?3P0O6aX08QhM010<2`0201@@3`0E00d9200=2``03P`=00l=3P0@3Pl04@l@010>3`091`P0
4a4B018@4@0E4a@0@T1102PW9@0B4@h01PD301@C4@0E51804@l@01PF5`0E4a@04a4D00804@lB0P0A
3a@02P0@3Q<06ALL028P9@0B41D040hC018@5@0C4AH04@lD018@5@0G5AX201PF6`80518E00@04a4D
018@4`0B41<0518E0P0B41<02`0G5AP0518E01@B5@0E51H051@D01HF5P0E5AD04a<C01DE5@0D51@0
61PH00806QXJ00<0:b/[00P8200E5QD00P0I6aX0100J71`06a`N01/L7P0H6A`201/L800k01<D6@0K
72407b0U01PJ8P0A4al07R4Z02@W;P2>TIH0:2`_02@X:@0J7Ql07B4T018E6P0R9BX0<SHn02T]>00<
4ad05Q`Y02/^?`0C5RT05aX]01PI;@0H6B/05aHU01TI9@0N7RH06Q`R01XN:P0K8Bl07R@_01`P:`0H
7B<05a`Q00hB5@0O8bH05aPM01DE7@0Q8BT06ATS01DG8`0I6bL06QdV01@G7P0@4aX04aHK00`?500B
5A/04QDL01@G800G6R@041<L01DE7`0D51`06ATQ01PI7P0E5Q/06a`P01XK7`0D5AL00P0G6AP00`0C
5A<051HC01<C4`0501<C4`805aLG01d05QHF01DE5@0B4Q803Ph>01LF500I61H061LE01LE5P0F51H0
5aDH01PF6`0E4aT05a@K01HC700M6R<09B8Y03<b=`0A41D04Q4F01XI7P0G5Q/061LL01DD6@0>3A80
6QTN01TH7@0A41D05aLI01<A4P0201HD5@0E01@B4`0C4A@04a4D01LE600@3Q<020H;01`J7`0?31<0
518G01<A5@0=2`h02`T<01<A500G5AP0<2ha01XH6`0<2Pd0518E014?4P0E4aH05Q8F00805@lC00@0
50hB018<400A2`l04P`@0P0C3A401@0B310040X>010:3P0A2`l04`dA00<04@/?0P0C3A402@0D3Q80
5@lC01D?4`0E3a<04P`@010:3`0<1@`02`@;00d63@0200X32P0B00h73P0=1Pd04@XA01L@5`0A2Q40
3@H=00l63`0C1a<060`H01X>600I3AL05PXD01dB6P0<0@T060dC01X?5@0700804`P>0`0A1Ph0200@
1@d03`@<00l4300?10`040D=01873`0@1@d03P<;0P0<0PX02@0?20l040T@0188400H3QH04`X?00X0
0`0K41@06@hB00d10`0201D92`803P<90P0?10X201052`0B00/01P0B1`d05@X@00d2200:0@D040<:
00l01@0J2@l05@@:00l01@0?0PH03@4500/0100C2@`04`X=05UCE@0D3Q00>C<e5?ooool001_ooooo
01h0:RHT00/71@0K61@04a0:00l<1@0U8QX04a08014>1`0<2@<06aPD02TV8`0E4Pl04`l<01@@3@0>
2PL0510=00h:200D40d05A4>010<2@0D40d04`l<00h:1`0@30T04@d;010<2P0C3`d04Ph<00d91`0E
4@l200l;2@1B010<2P0A3@/04@d;014=2`0>30T0518?014?300J61H04Q0=00l=2P0A3P`04a0>01DC
400Z9bD0E55?01`I5`0=30T030/800h=2P0@3``03`h;010?300A40d03`h;00`;200B4@h03Pd:010>
2`0F4a002PP5010>2`0B3`l020L601<B4@0G5QH03Pd=075aKP2j_;L0DE5=018A300B3`/04@d9010<
200?30P040d900l;1`0A3@T04Pl;010=2@0@30P04@d900h:1`0B3``05A8?010>2P0H5Q8071TF014?
2`0F4a004@h;00`:1`0A3`/040h:018@300?3@L02`T300/9100?3@P04@l:00/91@0D4@d03P`801DB
400=2PH071XF00h=200=3@H03Pd700l>2P0@40T0410:01@C3`8040l900@03Pd901@D3@0E4`l04Pd:
0P0B3@/01P0A3@/040`:00l;2@0A40d01PD400l?308030d902L03a4=01XK5P0:30H051H@00`<1`0@
40/02`/600l?2P0?3PX04Q4=01@C3P0B40`04a0=00h;300>2Pd04Pl?018@400=30/0410>00l?2`0?
3P`040d<014<2`0A2`/040/:00d;300?3Pl03Pd=00`;2`0;2PX05aHF014@4@0;2PX04Q4B00X92P09
20T02`X:00`;2P0>30`00`0=30/200`;2P0:014?3`0?3@d03P`<010>3P0@3`h02`X9018@400K6QT0
?C/k00X9208030X:01803@`;00h<300=30/03@/;00d<2`0=2`/02`T900d;2`0A3`l03P`<00/92@0?
3Pd02`X900X9200>3@`02PT800`:2P0?30`200h;2`0600l<300>2`/03@X:00h;2`0?30`03P/;0P0H
5AD02@0?3@`03Pd;00T81P0@3`d03@`:00h=2`0<2`T02`X800d<2P0200l>301i00X91`0B4@l04@l=
018?3P0?3@/03P/:01PF500;20L03@X900d;2@0>2`X03`d;00h;2P0>3@/0<C4^07QhM`0Q7Qd020@2
00l:2`0D3@d0614@01492`0B3@`04`h=018>3P0=20P03`X:014;2`0?20T03@P900l92P0D30h03PT:
01092`0@20X040/;014;300;1@H05A0@00`61`0E3@l050l?00h82@0B2``04`h?018;3@0A2@/04`h>
01<<3P0D41402PH7010<3@0H51D0:2@U00l;3004004071PI05UEEP0B3Pl05a<D00/7200B41003`h=
00`;300920/040hB018@500A3a<020H900d:300B3`l03P/:018=2`0?2PT03`/;01<?3`0B3Ph03@X:
00d:2`0>2``030T;00d<3@0@3@l03`d>00l<400>2Pl03``@00l<3`0C41804Q0?00h<2P0@3@`03P`;
00T6200=2Pd02PL;010<4`0;2@l02PP=018@5@0U8bP04Q0D00T72`0?3A4030X>010>400@3Q402@L;
00/:3@0;2Q004Q4F00h=4P0K6Al03P`B00d<400K6Ah06aPL00`83@0<2@d03PX?018?4`0200l:3P80
40/?00@03`X>010;3`0=20`03PT=0`0?2Ph06P0>2@d040h?00`:2`0B4140B4I70=;@d@3Zj>T0De5B
01<A4P0A3a002`T:01TG600<2@/040`@01@A5013@4<040`@01<@4`0;20/040d@00`8300@3A003PX>
00l<3`0>2Ph040/@0P0>2@h0300E41D08A`Q00/62`0<1``04@`A010;400=20d03`X?00/62`0A3140
40/@00l:3`<040/@02P05A0E010;400;1P/04@`A028M8P0;1PX04`hB01D@500?2Ph04@`@00l<3`0>
2`h03@X=010>4@0W8bL03`hA01PE600;1`P04@d>00l<30060P<08QhO00d92P0G4a@02`L801HB4`0Z
9RL0510A010<3@0J5aP02`P900l<3@0L6AX09b@U00h;300?30d02PL8010=3P0A3Pl03P`<0`0@3@h4
014>3`0i018?400@3@h04Pl@014>3`0?30d05Q<D00l=2`0A3``040h;00h<2@0=2`P03``:00d;200E
4Q0040h;01TG500D4@l03@/8014>3@0@3@`03``;00l=2`0@3P`040d<00d;2@0B40h04a0?00h<2P0@
3P`04@l=00l=3P0A3a004Q0A014?400E4a@030X;00h<3@0@3Pl05A<D00l=3P0M6a`03P`=01DC4P0A
30d04Pl?01<?3`0B3@h03``=010<3P0A2`h040d?014=3`0C3A004@h@01<@4@0G51D07AXK00804PlA
00/05a@F01<@4P0@31404PlC01TE6P0J5Q/05aDI01@C5`0C4QH05A<G01@C5`0201<B5P804Q4E00D0
5QDI01DC5`0E51P05QHG01HF5P0201LG5`805ADE00L05QHF01hN7P0D51@06QXJ01HF5P0E5AD06a`L
00805APH0P0E61T0@`0E61X051LJ01XL800K7B405ALL01hP9P0R92X07R0X01@G7`0F6B40;C0f096D
V@0_<SH061/O01PL800D5a/071lT01@G700G6R4051PS01/O;@0L82l0;C1001lR<`0N8C806A/Z01TL
:`0I72P06a`V01XN900I72404QLQ01`S;P0Y<3X09B/c01`Q:P0C6Al061hS018F700@51/07R4Y01DH
800C5b0061XV01LH900F5b805aTS01PI8P0E5ah05aTQ01DG7P0@4AT0:R`d02DW;`0?41T05ADM01@D
700J6R<04a<L01DF7P0J6b805aPO01DF6`0G61/05QLJ01<D5@0D5AH00P0C4a@301@D5@0;01<C500B
4Q<051@E01<C500E5AH061PI01@D500M71`061LF01/K6P0G5QH00P0C4Q<0=`0G5QL051<G01<B5P0E
4aP061LK01`K7@0H5aT05ADF01HF6@0C4QL051<H01XI7P0J6Al05A@I04E4B@1=C4l05aLG01@D5@0C
4QD04a4E018A4`0E4aL04a4E01PF6P0G51P0510F01LC6@0d<CH06A<J010=4P0C4A@061HI01dK7P0=
2`h0G5UL0<W5b@13@4<02@@801@>4P0H4QH04`dA01@?4`0/:2`030L:01LB5P0B31002@D8018<400A
2`l04P`@01L@500B2Pl03`P<01@=4@0D3Q400P0@2Pd02`0A2`h040X=01TC5P0H4QD02`D800h82`0=
1`X04`d@018<4@0?21003PL?008040TA03004@XA02HO9`14?DD06A8I01PA6@0C31<04``D00l63`0@
10l04@HA01H:5`0C1a@050PE01L;5`0D21804@H@00l42`0>1@T03P@900l42`0@1@`04PL>01<83`0A
1Pd040D<00d22@0B1`h050T@00l42`0E2Q403`D;01473P0:0`P04`X@00/1200@1Pd03@<800l42@0F
2a004`P=00d21`0B1`X04`L<01lD6`0:0@H050T@00`2200>0`X200`21`0A02HL8@0b9b`07A8G00d4
1`0I3A40300201/:3P0?0@<04@8601<5200?0P<04PD801851`0E2@X0@cLj00l51@0T6AT05?ooool0
01_ooooo00L0XIjG01dJ5@060`003P/401TF3`0D4@X04@h7008040d600<04Pl801<@2@0@3@H0100B
3P/201<?300?00/7100G4a006ADB00l;200=2@H04@d:018>2`0=2@H03`/801@@3@0M6AH0=C4^014=
2P0C3``04Ph;00<040`902@04A0<0040000=30P0ATE1038a;@0L6aL02PT700L60P0;2PH02`X701dL
60061@403Pd900d<200C4Ph05A@@01<B3P0E510030/700X91@0H5a<03Pd901@C3`0<2`T04a8=00l>
2P0B4A0030X;02DS9P1kNG`03P`?0040000X9RH05QDA028Q700G5A02014>2@03010=200?30L03``7
00803``70P0>2`H0100@3@P0514<01`H500B3P/200l;200J01<?300F4Pl06aLD03<_;00T81d04@d:
00l;20060P003@X501PE3P0I5Pl040d800h;1P0@3@P07QXG01HB3`0C3`h03@T800T5100Q7A`05aHB
018A3@0=30P04A0<01<B3P0A40`200l>2P<03Pd900<03`h:014;2`0B30`00P0A3@`0<P0@30/03@`:
014@3P0>3@/030`:00/;2@0=3@/07b0M0=7Cd00L8Ad0004002DW900J6aT02`/900h>300@40h051<A
018A3`0?30/0510A00h8300?2@l040/?00l=3P0=3@`030`:00h?2P0?3`/04@d<018<300E2``050/<
00h<3@0<30`03Ph>00/;2`0:2PX05ADE00820P0D51@020P801<C4`0G5aL03@d=010?3@0?3P`02@P6
00P71@0=30X04Q4?1P0=30X03`0A40h05aHD01XI5`1FEE<03@`:00h=2`0<2`T03`h<010?3@0?3P`0
3Pd;00l>300<2`T020L500`;2@0201HE4`07018A3`0>3@/01`H400X91`0<2`T02`X8018A3`0300h:
2@<03`/:01804Ph=01LC4P0=2@P03@T800h:2@0=2PT03@`:00`;2@0?3P`03Pd;00X91`071P@06aXH
01DD4P061@@05A@B01HE4`0510<201XI5`0401LF500100006APF00d<2P803`h<00T02PT700/:2009
20H02`P601<?300E4@h03`/800T50P0;1`@00P0=2@H300h:1`03010<2@0@1`P040L800@04@P90`0E
30d02@0D2``04`X;018;2`080P8040`;00/71P0<20L03@T800T5100301DA400600l;2P0810<02@D4
01HB4`0C3a004Ph?0P0F4Q<05@0@30d06ADF00d92P0S7b001001018>3`0@3Pd04A0<00d>2P0820H0
10@600T82`0E4aP03P`A00d93@0=2@P03`/8018>200A30H040/700l;2@0200h:2@0C00l<300>30d0
9B<T010?4@0820X02`/=00d=400>3A801@8901@B5P1BD5405Q@E00T81P0920<03Pd800d<2@0=30X0
30X=00`:3P0200/83`0N00l=4`081P/04Q0E00<1100J61/03P`?010>3`0K6AX030X;00X82@0<30h0
4Q@H00P;400L7b@0UIJK01@E6P0E5Q/04a8H01DD6P0@3aD03``C00X73P0?3A804`hB00<00P0<1`/0
61<G00`72`0;1PX03`X>0P0>2@d200l:3P0E010;3`0F51D081hO01hL7@0`;Rl0R8J70:VWZ00b<340
3@/<01@B4`0;2@X04Q0A010>400A3a8030X=05IDE`0:20/02`T<00d;3P0;2@`030X=00803@/>01/0
30X=00X72`080`T01P47014<4P0U82H0@Se301@?5@0R7B<01`8800/630070PP01@06018=4P0B3A40
4@`@010;3`0?2Ph030L;00h93@0910P03PT=018=4@0@2`l030L;00h8300?2@d00`0>2@d0400=2`h0
108501@B5@0B4Q@06ATK03Xj?00O7b408AdN00X61`0C3a005Q8C00D10P0K5aP02PH700L3100G4a@2
00/7200L01@@4@050`@03@/<00/92P0>30d04@l@01LE5P0L6Q/02@L801/I6P0>30d05aDF00d;300?
3@h040h?014?400@3Pl03P`=00`:2`0@3Pl030X;00L51P0<2P/04@l@00`:2`0<2`T03`h:00h=2@80
3@`800<03Pd900/:1P061@800P0C4Ph00`0=30P05A@@00l>300500l>300<010?3@0F5A<04Q4?018A
3`0N7A/04Q4?028P8@0>30d07A/L00H41@0;2@X081hO0P0B41402P0C4A80518C01DC500E4a@04`h?
01@>400E3a4050h@014;3@0@2P`501@>400?01<?3P0C3`d0510=01@@3@0F4Q406aLF01lK6P0E4A80
40`=018>3`0H4aL05a8F018@4`0@3a@04A0E00@051<H0P0C4QL0100D4aP05QDJ01LF6`0F5QP201@D
500301DE5@0F5QH05QHF00805aLG00H061PH01XJ6P0I6AT061PH01LI6@0D61T301<G600]01@H6`0C
5a/05aXO01PK800E61h06A`S01`O9P0K7R@061/P01HI7P0L7b@08RDZ01HI7P0I72404aHK01LJ7`0A
51T051LL01LJ800D62@05aX[01`O;P0R9C@09b/g030d?`0J7RT05a/V01`P:@0O92X06b0V01`Q9P0D
6b<05A`T01/R:P0N9Bd06b8Z01LN9P0I82P061lW01TP:00=51`020lG02H/=00F62@061PT00<06ATU
00/061PR018B700F5Ql071`T028R:P0Q8RP05AHK01DE7@0@41T05aLQ014A7@0201`L:00601PH900G
5b005QLL01DF6P0D5AL04a@F1P0F5QP02P0B4Q@05QHH01<C5@0C4aD05aLI014A4`0J6QX04Q8B01PH
600D51@201PH600:01HF5P0C4a<04Q8B01DE5@0F5QH05ADE01XJ600G5aL05QHH01@C6@804a8J02`0
6QTQ00l>500L6b009RHW01LG5@0:2PP06aXN010?500K6Ql0?ce201LE6P0:20d07QTO01PC6@0G4QP0
6A8I01<<4`0=20h07a/O00l=400>30l05A<F01lJ7P0T7b<06Q@H01<=4@0I4aL05@`A01T@5@0d;c<0
_[bo02/Y;00>30l04Q0C01TD600L5QX07ALK018<400A2@h04PT>020G700W82<05a4C014;3@803PP:
00<02P@600h82P0D3Q000P0B30h0700F418050h@00X42@0>1`l03@H>00h73`0B2a<05@hF06URJP39
`/X0<2Ta01<<500K51`03PL?018:4P0B1Q006PhJ01@85P0@0a@07A0Q0186500?0a402P0901873`0K
41H060dA00l42P0@1@/20146300A00l42P0>0`T04@H<01L<4P0M4QP04PL=01P=4`0;0PH01`0202LL
8P1MDUP06PlE00L00P0G318040D;01873@0A1P`00P0>0`T05P0C20h01`05028F800A20h02P0701<8
3`0D2@l030470189300:00<01`0001lD601SEe/0GDiA01@61`0V5QL05@D601H61`0;00004`<401H6
1`0G1`P201D51P0301H61ooooooooooo01;ooooo000Kooooo`0`02/X8@0=2P@06aPA00`90P0:1`40
514:00l<1@0@3@H04Pl801@A2P0C40T03P/401DA3P0D40d04Ph;014=2P0C3``0510=00/7100H5140
510=018>2`0E4@h04Ph;014=2P0>2PL03@T6010<2@0K5a@0=30]018>2`0@30T04@d:018>2`0A3@X0
40`900h=2@0I61@05A@@010?3@0510004a8>010?2`0=30P051<?00X91@0F5A403`h:0P0>3@T09@0E
51005aHB01<B3P0D4`l02`X600h=2@0R8Ad03@`801@C3`0I61<020L20040000C4Q404Q0A00L5200l
>Sd03@/>00X82@0F5A@01@@001PG4P0A3`X0514<01HC3P0C40/040d8014>2@0I5Q404a0;00d:1@0A
3PT03``701<@2`0T8Ad05a<@00l;200B3P/00P0A3@X0500?2`P06aLD01@@3@0@30T06ADB01DA3P0C
40/07AXC028O600A3PT030T4010=200A3@X01P8000d9200B3Pd040`;03Pd<`0L6aL05QDA0P0?3PX2
014@30803`h:0`0@3`/00`0?3PX04@/;018<3002014=3004010<2`0=30X03`h<00`;2@802PX800l0
30`:01/L6P0];b`041DA01HH5@000@00IFIS01hN700=3@/03Pd;018A3`0A40h03P`:01<?400?2@d0
0P0?2Ph06`0>30d03@d<00`>2`0?3`d040l=018>3@0B30`04``=018<3P0>30d03Ph>00l?3`0;2`/0
20P800h>3P0C4a<03Ph>00820P00000010@4018B4P0;2PP03Pd;00d<2P0920H02`X801<B400600`;
2@0900h=2`0:2@L00P40020O7@0510803`h<00`;2@0?3P`040l=00803Pd;00T03`h<00d<2P0920H0
3@`:01DD4P0D4a4040l=00/:20061@<00P0<2`T01@0:2@L030/900d9200=2@P03PX900<03`/:00H0
4Ph=01lK6P0=2@P04Ph=01DA400=2`T200`;2@0C00h=2`0=30X02@P600/:200920H00@0001PG5@01
00001PD300l>30081`D081lM00T81P061@<030/900P71P0C4Q0051<A00d<2P0200T81P0300`:1`0?
2`P030P500803@T60P0;1`@01@0=2@H030P500h:1`0>2PL03@T600804PT:100A20T201D<3@8050/<
00l04`X;018;2`0?2@T05A4@01LC4P0;1`H04`l>018>3@0810<0100000h:2@0C3`h02`L601<?3P0F
4Q<00P0C3a0201HB4`0E014=3P0I5AH01@4200X71`0>2P/0510A00h;2`071P803@h:018B400@4180
3@`?01DC600D4QL04@dA00l;2P0@30T04Ph8018=1`0A30P040`:00803PX902X03P/;00d;300^;2d0
51<D00P82P0<30h03@d@00/:3`0;2@h08AlS0>k/k@24PX<05QDB00d<200>3@T03Pd:00h=2`0=2`h0
3@/?00d;400200H040dC00h<4@0C4AH0:2HY06=QI00<2Pd02`T:028P8@091`P03`d>00X:300;3A40
00<601LK7P1JFel071/P0000100<2a003`dB01PF6`0?3A8200/93P0O05]FFP0F4AD04`hB018=4@06
0@D03PT=01@?4`0?2Ph03@P<00h93@0B3A4050lC00l=3P091`P040h?014?400Y9bP0@T1101DC5009
1`P0518C00/92P0<2P/020H802DS9P0K6A`05Q@G014?4P0?3A001`D800`:3@0200d;3P0@00`:3@0;
2@`05a<G01LB5P0?2Ph03PT=00l:3P0O6Qh050lC071[K`12?D403`X>02@O8`0?2Ph02`H:014<40<0
3@P<00L02`H:010;3`0F4AD081/O01D@500=20`030L;008040X>02803`X>00h93@0>2@d030X=00T7
2P0<2Pd05ADG065QH`3Zj^`0G5aN00X61`091@H030P901<?40091@H02PH700h:2`0?2``04Ph?00P4
1@0>2P/02PL701HD5@2:R8T0:BLX01LE5P091`P030X;0040000?3@h00`8200L51P0N71d061HG0`0@
3Pl0400>30d030X;00X82@0E4a@06QPI00d;300<2P/04Q0A00H41@0>3@/03@`:00h=2`0?3P`03Pd;
00`;2@0L6aT2014@3P0300P71@0C4Q001PD300H03`h<00`040l=02PW9@0A40h051<A02@S8@0?3P`0
O7Yk00@20`0:20T07Q`M00l=3P081PL2010>3`@04@l@00H04Ph?01<?400C3a004`l@014=3P0@30d5
01@@4@0=01@@3`0?30X04Q4=01@C3`0C4Q00518C01DC500C4A803`d@014?4P0F51L05aDH01DC5P03
018A5P0300l>4`0=314040lD008051<H00@05A@I01HE6P0G5Q/05QHH0P0C4a<01`0D51@05aLG01TI
6@0H61P05aLG01PH600J6QX00P0I6AT03@0G6AT04aLH01<G600B5QL04aLH01@H6`0B5QX051LL01LJ
7`0E61h05aXQ01PK8P0H6b400`0G6Ql01@0B5AX051LL01PK800E61d071lT00804aHK00/05aXP01XN
:P0H6bX05aXY01`P;00R9S80:2`h01TM:00G6b@06QhW01`Q9`0201XO9@0702`c>`0N9Bd06B0X020W
;`0L8b/05QdU00P?5`0200L>5P0500/B6P0U;3@0MG^301LI9@0I6BD00`0J6RH04`0I6B<07alW01`L
900X:3003@hC01<D6@0A4QL04a@I01TI800J6R8030`F014A6`0J6R@05aLQ01HF7`0E5Q/051DI01<D
5P0B51<01P0D51H09@0E5AL05aLI01@D5P0C4aD051@F010@4P0J6QX051@D01<C4`0>3Ph061PH014A
4@0G5aL051@D018B4P0E5AD051@D01<C4`0G5aD05QHF01DE5`0F5AX05QDM01LF7P0H5al04A0F01@C
600;2``0410>01LG5`0M72000`8700H52P0B4AH02PP=01@B5`0G4QP00P0E41H201H?5P0J01D@5P0:
1`X06ALJ01HD5`0E4aH04`hB00d8300=1`/06A<G01XD600E31406a8G01@>4P0k>C`061HI00X82`0J
61/01`8600`72`0C3A403PP<00d62P0:0@H04PT>01dF6@0E3a42010:300P014;3@0?2@/040X<00d7
2@0C3@l02`D701D?4@0?2@/03PL=00l83`0>1`h040T@01<<4`0E3QD0:24X04i7CP0400@0204800l8
3`0D3A@02`8:01T=5`0M4Ad03`<A0186500E21T05`/I01X>700@10l03`@<01P=4`0=10H201052`80
3`@:01`04@H<01<83P0A1P`040D;01L<4P0@1@/04PL=00d3200C20h04@H<02/P9P0C20h04PL=00L0
0P0>0`T040D;0146300?10X03P<901052`1QEEl0YYZT03@Y<@0@1@d04`P?01dB600D2@l03PD80P0<
0@D02`0C20`0:AdQ01T:3@0N4A802`0001X:3@0D10L070`?01821@0E1@P05PH9008050@700<05@D8
ooooooooool04_ooool001_ooooo00L04@h:00`91@0B3`T03P/5018?2@0@3@L04Pl9008040d70100
4Pl901<@2P0A3PT061@A01DA3P0A3@X040`9018>2`0D40d04Ph;01<?300=2@H081`I028N6`0B3P/0
4`l<0`0B3P/01@091@804`l<014=2P0<20D03PX700804Ph;014040`9014@300920D03`h:01DD4009
20H03`h:00/:1P0F5A4051<?00d<200E51003Pd9010?2`0?3PX051<?01<B3P0300d<2003014@300U
92002`X6008040l;01d04Q4<01HE4@0>3@X07Q`M06ESIP0P7R403`d@00H41@0J6AH040l;01@C3P0?
3@X05A8=01TF4@0E4Pd04@h901@A300S81/07AXE01DB3@0J5a803P/600`9100H51002`L400d91P0E
4@h030P500l;2002018>2`07010<2@0?2`P04`l<010<2@0;20<0514:01LD3@0200d:1@09018?2P0A
3@X04@d:01@@3`0A3@`03@T8018>3@0C4Ph04A0<00D03@`800L03Pd9010?2`0@3`/03`h:00h=2@0A
2`/04P`<00804@d<01h040`;00d<2P0@3`d03Pd;014A3`0@40h02`/900`=2`0>40d01P/7034c<009
2`P0414?00/;2P0>3P`030/900l>300@3`d03``;018>3@0A2`d040/>00d;3@0>30d03@h>00h@3P0=
3Pl03Ph=00h=300?30`2010;300400`:2`0>3Ph0410@00h>3P8030`<00X01`L700P8200F5QH0410@
00`<300;2`/03@`:00/:200?3P`04A0>200=30X0100@3`d03`h<00/:2@0;2PP200h=2`0B00`;2@0=
30X03@`:00/:200<2`T03@`:010?3@0;2PP030/900l>300=30X02@P600h=2`0=30X030/900d<2P0D
4a401PD30P0=2@P09`0>2PT03`/:00l;2P0@30/07a/J01/G5P0A3@`040`;00l;2P0:20H02@P600X9
1`0<2`T03@`:00`;2@0>3@/04A0>00`;2P18AdD040l=01@C4@0i>3H08R4P03@c<@0R8Al04A0>00H5
100C4Q005QDC01TH5P0@3`d030/900h=2`0@3P/04@d:00l;200@30T03`/800h:1`02010<2@0500d9
1P0?2`P04@d:00d91P0?2@T00P0@20T300l720804@X:00X04@T:01082@0@20T03`P8014=300E4A00
7a/J00d9200I5A@071PG0P0A3@`0FP0?2`X04Ph=01HB4@0=2@P04@d>00l;300>2P/040`=014=3P0?
2``030P901HB4`0B3Pl03@T:00l;300=2P/040l=00`<2P0<30`03`lA04M6BP19Ad`07A/P01LD600A
3@h040`<010;2@0@2`L04Pd:014=2`0?2`X03PX900d:2P0<2P/0518C00h=3P0@41804Q8D00`<3`09
20d04@lD00`:3P15@d@04Q0A01DD4@0;2PH03@`800d<2@0=30X03@/>00d;3`0=2a0030T@00/93`0@
3Q<05A<H01HD5`0o?D005Q@G081nO`30_[l0@Cm000`:2`0?3`l03a0D01`O8P22Q8P05aPL00h=4P08
1``02`T>00h<4@0A3a@03``A01`H7P0>2a003`/>00h:3@0B3A404@`@00/62P0>2@d04`hB010;3`0>
2@d03`X>014<400B3A404@l@00l=3P804Q0A00h04a4B01DC500E4a@03`d>010>3`0=2``02@L8010>
40081PT02`T<00h<3`0A3a8030X=01@B5@<03@/>0P0;2@`0600B3Q802`H:00/62P0@2`l03PT=010;
3`0;1PX06aHJ00P41`0S7R804@`@00/72P0E41@04@`@00h93@0B3A4040/?00`72`0D3a<040/?00d9
300A31005Q4E00l:3P804P`@00<040/?00l:3P0>2@d00P0<2Pd0300=2`h0410B04i>D02`/;40>SXl
010<3@0H51D040`=01<?400:1PL04@d>018>3`803PX;00l03@T:00`92@0A3@h030X;051>C`0I5aP0
3P`=00L51P0@3Pl09B<T07QfM`0G5QH0518C014?400<2P/01P0@3Pl02`0B4A4040h?018@4@0>30d0
30X;01HD5@0I61H04Q4?00d<2P0?3P`040l=00803@`:00D03Pd;00P71@0?3P`0A4=1014@3P0600l>
300<00`;2@0`;bd05QDC00l>300B4@l04a8@014?400I5aP04a4B014?400C4A804Q4A0P0B4144014?
40H04Ph?1P0E4A804@0E51405QDB01DD4@0B4@l040h?014?400B418040hA014?4P0E4aL05Q@H01DC
5`0C4QL04Q4F020O900V9BX07A`Q008051<H00H04a8G01@C600D4aP05A@I01LG6@0F5QH201@D5003
01HF5P0H61P06ATI008061PH00@06ATI01XJ6P0J6QX06Q/L0P0G6a`01`0E6AX051PI01<G6P0C5QX0
5APM01PK800H6b400P0F6B001P0H6b4051LL01HI7P0M82D05APM01XM8P806A`Q00X08bH[01LJ7`0E
61d06A`R01`P;00H72T051PU01LK9`0J7RT06AdX0P0L82T02P0J7RL061dS01PM8`0H7B<0;38i01dS
:P0H7RD07R@[01TO9P0F72<2010F7@0M01HL8`0G7B@05A/R01/P:00G6BD06QXV01`L:00L72L06a/V
01XJ900O7bL05aLO01hO9@0I6Ql061TN01DF6`0F5a/04A8F00d>500C51X061PQ00l?600F5Ql05QLL
01@E600C5AD04aDC018D4P0E5AH01@0E5AL0100D51H05aLI01LG6@0E5AL201@D5P0A01DE5@0F5QH0
5ADE01DE5@0R8R805QHF01PH600E5AD051@D01DE5@0B4Q804A4A01HF5P0E5AL051<H01DD6P0E51`0
0P0F5Ad07P0I61h061LM01@D5`0E5AH06QXK06m_L`0N7B8030/@01HE6P0@3Q<05Q@I01LC6@0I51X0
5Q4G01<=500F41H06A@J018@4`0C4A@07A/N00l=400O6Qh0AT5502HP900C3A405a4E01T@5@0J4AH0
5@lC01`J7@804Q0C03D05aDH00/72P0E41@05Q0D01<=4@0H41D05@`A00l62`0H41@07ALI01H@4P0C
3@l04P`>00h82P0C3@l03PP:01H@4P0B30h04`d?00h82P0D3A804P/B014:4@0@2A003`P?0109400D
3A@0100401XC6P0>1`h081TP09VBV@1?ADh05PXD01464@0G2aT0;20^01/?7P0H3AX04PHB01874@0F
2a<04`P>01872`0@1@/03`@:00h32@0A1P`05P/A01dB600D2@l02`460146300200d2200901L<4P0?
10X02P4501@:3`0900@04@H<01873@0=0PP03P<900@040D;01P0ACU306YNJ00N4a/01`0400d22@0G
318050T?00d31`0>0`L040D901062@0E2@d04`H803h_<@0C0`H06P`>01851P0J2Pd03`0201821@0C
0`H04@4401000`0A0@@Dooooo`006oooool02P03000040d801PE400E4Pd03``700`9100D4@`040d8
00h;1P0@3@P201<@2`0301HB3`0D40d04@d:008040`900H04@d:00`81@0G4a004@d:010<2@0E4@h2
01<?30802`L400L05Q8?010<2@0C3``0510=010<2@0>2PL03`/800803PX702X03`h:01HE4@0D4`l0
0P4000<2000@3`/04Q4=01<B3P0Q81`061LC00d<200K6QH03`h:00d<200B4@d04a8>014@300C4Ph0
1`H400P70`0B4@d03Pd900l>2P0K6QD02PT400P70`0?3P/0;Rd[0:RVY`0V9BL09bDV01@C4@0D4a00
2PT40040000=2`H03``7014>2@0?30L03@X500l<1`0D4@`2010=200801PE400B3`X040d8018?2`0:
1P<0510=01PD4@0<20D2010<2@0C00L3000=2@H04@d:01DA3P0K5a@04a0;018?200>2`@03@X5014>
2@0@3@P01@4000d91P0<20L040`;01dI600I5A@03@`800h=2@0300l>2P0300h=2@0<2`L030/700<0
3@`800<030/7014;2`0B30`00P0A3@`0100@30/03@`:01<B400>3@/200/;2@0K00X:200>3`d03Q0=
00/@300A4a004Q@A01HG5@030`403`l=00X:200=30X040l=010=300C3`h040X:014<3@0?3@h03Ph>
00d?3`0>3a404A8D010A4`0@41003`l?014>3`0A3@h02PP900803Ph>00l03`l?018B4P0>3Ph01`L7
00l?3`000000410@01TI6@2ZZZX0:2LU010?3@0;2PP03`h<00h=2`0?3P`01P0>3@/03`081`D03Pd;
00l>300;2PP03Pd;0081000?3P`040l=00h=2`0<2`T03Pd;00l>300=30X030/900d<2P02014@3P80
40l=00D01PD300`;2@061@@05A@B00T81P0600l;2P0U01PD4`0810<03`/:00h:2@0<20L03@/900d<
2P0>3@/030/900T81P0:2@L01PD401DD4P0<2`T04A0?010?3@0I61H03`h=092?S@0`;bd02PT70040
000C4Q003`h<00h=2`0A40h03@`:00`;2@0>3@/03@/8010<2@0A3@X03PX700/7100<20D04@d:018>
2`03014=2P0300l;200=1`L03@L700803PP80P0?2@T00`0B30`04@/;014;2`03010:2P0=00T5100<
20L04Ph=00/71P0?2`X04`l>00@0000>2PT02`L601LC4P0`;2/09B4P00l;300300h:2`0F00l;300@
30d03`/<01/G600A3@h02@D601PD5@0B3a0051<A00h>3@0@41001PH804a;CP0i=c`05Q@I018>4`0@
2`l04@d>01<>400C3@d04@`9010<2P803PX903<03P/;00d;300?3@h03`h?010@4P0=3@l02`/>014@
5@0M6b0020H900X82@0G5AH01@@302@S7`0<2`L030/800`:2`0=2``03@/?00d;400;20l03P/A01PF
6`0G5AX07A/N02l]<00D4QD0LW1a0;Fc]00e<c@00`4200l?3`0O7b8010D903<d>0082@d06aXO04m>
D`0<2Pl05aDJ00h<4@0@2a405A0F00<0100@2`l01P4500<00P0<1`/061<G01@?4`0?2Ph00P0@2`l0
0`0?2Ph030L;00/62P0200/92P0B00@20`0;2@X04Q0A00`:2`0C4A804Q0A01<A4P0A3a0020H700L5
1`0H5QT05aDH00L5201BD5<0@T1300T72P0=2`h030X=0P0;2@`0100<2Pd04@hA00h93@0E41@2018=
4@0C00D0100:1@T05Q4E00l:3P0?2`h05Q4E01`G6`060PD040/?01LB5P0W8RH071LK00/62P0=20`0
6A@H01/F6P0=20`03PT=010;3`02014;3`06010;3`0?2Ph03`X>00d;3P030@@03@/>0P0<30h04@08
20X06QXL014=3P0A3@h01`<403hj>`0B3Pl05A4B00<0000;1`P04`l@00l;300;1`P0Ad=402<Q8P06
10D04@l@008040h?00L03@/<00P61`0L6Q/0518C00/92P0=2``030X;00<040h?00h04Q0A01@B4`0F
51D0DDm@01lM7P0F51D06ALH00X82@0=2``05QDC014@3P0=30X03Pd;018A3`8051<A00D04Q4?01LF
500=30X05aHD00`;2@0600l>3003010?3@0D4a403@`:008040l=00L03`h<01@B4`0@3Pl01@<400`:
2`0?3@h06aTJ00<04@l@0`0B41401P0B3Pl04@d>014=3P0B3Pl04`l@01@@4@D05A4B00<04a4B01@C
4@0D4a400P0C4Q003`0F51D061HG01<A500C4A@04Q0C01@B5`0E4aP051<H01HE6P0A41D08R4V02/Z
;`0O7R<04a8G01@C600201<B5`8051<H00<05aLJ01PH600G5aL00P0E5AD00`0F5QH061PH01TI6@02
01TI6@0<01XJ6P0K6a/06ahN01XN7`0I7Ah061`M01DI6P0C5aX05ATM01LJ7`0H6b006QdS0P0E61l0
400I72805APM01DH7@0J7B805aXO01HI7P0G6Ql05APM01hQ9P0F6Ah05APM01HI7`0J7RT061`W01HJ
9P0G6bH201PL9`0801/O:00L82T05a/T01@I7`0G72806AhT01dR:00K82H301TN900P01HK8@0X;C<0
9R/a01XO9@0;41H0314G01dR:00G5b4061PT01`L:00L72H06a/U01PH8@0A4AT06a/R01@E6P0F5a`0
4A8G014B5P0G61X09RLZ01TJ7P0F5a`05AHL01TJ7`0G61d05QLJ01DG5P0D5Q<04aD@018D4@0F5QH5
01HF600=01<C5@0F5QP06ATK01HF600C4aD06ATK01HF5P0B4Q805QHF01LG5`0P82005ADE01LG5`03
01DE5@03018B4P0?3`l05ADG008051<H02h05A@J01HE7@0F5Ad071/S024P9P0a<3H051<H00h>400H
61X03PlC01HE6P0I61d06QTN01PF6`0T8RL05Q@I01/F700I51X05A0F01LB600I51X0;R`_00/9300?
3A006QPK01HA5@0B3A406Q@H01@>4P0L5QX04`X?01D<4@0>2Pd03@/>01<A500=2`h05Q@G018=4@0;
1`X04@/?00L11@0?20`06A0E01893P0D31006A<E0P0C3@l0800E3a404P`>01<=3`0J51H03PP:00X4
1P0=1`T0618D00/5200=1Pd03PL>00l83`0@2A004@XA00h73P0G41L03@H=00X32P0;10/08Q/R01XA
6@0B1Q0040@@01D95`0T62H08aLU04m3D@0V6RH02`8901H;4@0>0`L020010P0@1@/200l42P0?0146
300C20h04`P>00h32@0E2Q00304700T0100?1PX04@H<00T0100<0`L0304701T>500<0`L03`@:0080
3P<901/04@H<01873@0A1P`050PB00L01@0C210050TA00l42`0700802@0401@93P0H3A404@H:00T0
0P0800006P/>00/0000W5aX03@00020@4`0?00804@4401@41`0E1@P04`<601821@0C0`H05?ooool0
01_ooooo00L06aPC018?2`0<2@@05Q<>018?2P0<2@@04Pl:008040d800<04Pl:01<@2`0A3PT00P0B
3P/04P0A3@X040`9010<2@0?2`P030P501HB3`0E4@h02`L400d91P0B3P/03`/800X60`0810404Ph;
010<2@0E4@h04`l<018>2`8040`901404`l<01HB3`0;2PH02`X600h=2@0D4`l061LC01@C3`0;2PH0
1@@0014@300D4`l02PT501LF4P0@3`/02`X600l>2P02014@300C01<B3P0G5Q803Pd900T8100A40`0
2@P401<B3@0>3PH05A@?014@3@010000;2X[01TG601mNg`0BDQ600l>2`0F5A0010<001<B2`0200d:
1@803P/600@03``700d:1@0=2PD040d80P0B3`X04`0C40/0510<010<2@0G4a005Q8?018>2`0E4@h0
510=00h:1`0D40d03`/800X60`0A3@X03@X5018?200@3@H040d801<@2`0?30L00P0H5140100B3Pd0
3@T800l;2P0?2`X2010?2`0400l>2P0=30P03Pd9010?2`803Pd90`0=30P00`0>3@T04@/;018<3002
014=300J010<2`0=30X03Pd;00T81P092@L02`/900X:200>3``03Q0=00D:1P0>40d0418?00P91P0H
61H0410>00X91`0=30X040l=014?3@0D40l03`T9014<2`0@3Pl0410@00h?4P0:3Q4200lC5P803a0B
00X03`l@00l=3P092@T03Ph>00/;2`0=3@d04A4A00`<300820P0410@0P0<30`0200:2PX0EeMG02<R
800@3`d03Pd;014@3P0<2`T040l=1P0=30X01P0C4Q004Q4?00/:200=30X05A@B00l>308040l=00P0
3Pd;00`;2@0=30X03`h<00/:200<2`T03@`:010?3@804A0>00L030/900H50`0/:bT05A@C00`;2@0:
2@L04Ph=00804@d<00T040`;00l;2P0>2PT030P700T5100>2PT05A4@01@@3`0?3@/00P0?3P`0300<
2`T02@P600/:200@3`d04Q4?00T81P081`D02@P600l>300U9280`;nm05ACD@803`h<00P06aXH00D4
0`0<2`T03@`:00X91`0=30X030/900`91`803`/800l03PX700`81@0=2@H03`/8014=2P0B3P/040`9
00l;200@30T03@L700h8200?2@T04@/;018<300C3@d00`0A2`/2010:2P0=00l92@0>2PT040`;00h:
2@0C3`h03@T800h:2@0F4Q406QHE014=300@30/06aLF01DA400300l;300G00h:2`0?2``04Ph?00l;
300B3Pl05Q8C01LC500H51D03``=00d<2P0A4@l07alM00P8200R8B<03@/>010>4@0?2`l03`X>014<
400D3Q804`d?010:2P0?2`T00P0>2PT0:00?30`03P`=01@B4`0?3Pl03Ph@00d=3`0;2Ph03PdB0040
0P0G5AP01083010>3`0?3P`010<100`;2@0=30/03@/<00h<3@0?3@l03`dB010=500B41H05A<H00T7
300D4QD04@lB00/:300H5QL0?cdn00X82@091`P02`/;00d>400F5aT0004300410`0Q7b808b4T01<A
500H4aL200l:3P0800`72`0=20`02`H:00h93@0C3Q805Q4E00d830070PH2010;3`0G00l:3P0>2@d0
30L;00`72`0D4Q<01`D600X82@0E4a@04@l@00/92P0<2P/03`d>018@4@0?3@h030X;00d;3@0@3Q40
1@<601LE600^;2l0:2HY010>4@0<2Pd00P0;2@`06P0<2Pd03@/>00/82P060P<04@d>00`82@0H51D0
2@D601<?40070`@00`0001@@4@070`@04@d>00h:300?2Ph04`hB02@O8`0J5AT02`H:014<400[9RX0
<2/_00`72`0500@04PdA0P0@2Ph3010;3`0L00l=400H5QT02`T<00T92`0G5aT02PX<00L72@0Q7Ah0
0`0003lk?02h];D0;RX[00d92P0U8B80<Rh_02<O800>2P/00`0001hJ6`0:20T071XK00P71`0E4a@0
6aTJ00`:2`0@3Pl00@0001HD5@803P`=00X02PP9014?400@3Pl03`d>010>3`0C4A80518C01lM7P05
10@01P@50P0A3a003@0D4Q<03`d>014?400@3Pl03P`=00l=3P0A3a0020H700T7200D4Q<040h?00`:
2`0L6Q/01P0?3P`03`0>3@/03@`:00/:200:2@L05A@B010?3@0A3a006QPI01PF5`0F51D00`4200l=
3P0=2``03P`=00l=3P02010>3`07014?400@3Pl03`d>00h<3@0@3Pl04Q0A01<A4P06018@4@0E00l?
3@0A4@l0410>010@400C4aD05ADG01HF600F5AX05A@I01@C600E51T05QDJ01TI7@0A4QH05QLK01TJ
7P0B4aL04A8F01HG6`0E5QX051DI00805AHJ00<05QLJ01DF600E5QP00`0F5aT03@0H6A/06AXL01PI
6`0H6A/06AXL01XK7@0I6ad05QXK01LK700H71d05QXK01DI700H6al00P0H6b00;P0I72804aHM01DH
7`0H6b4061/P01LJ7`0C5Q/05APM01HI7P0H6b0051LL01/N8`0F6Ah05aXO01LJ800N8R/0720Y01LK
9@0A5Ah041@M01<G800E6B805a/T01<G800B5ad06AhT01`Q9`0O92X08BH/01/P9P0H7B<07R<Y01DJ
80083A<04AHL01/P9P0F6b4051TO01HK8@0F5R005aLQ01/K9@0L72H06QXT01LG7`0I6B4201XK800@
00h?4`0P8BD030dA01<D5P0d=SH08B8T014B5P0;31007AhS01PI7P0G61/05QPG01DG500D5Q404aD@
01@D50D051@F00`05QHH01PH6P0K6ad05QHH014A4`0H61X09RHV01@D500E5AD04Q8B01DE5@0>3Ph3
01DE5@1101HF5P0B4Q80410@01DE600E51T05QDJ01PG7@0J6Al06aXP01hM8`0P7bD0A4=9020O9009
20d07QdR01XK7`0;31006AXN02//<00Q82D02PT>014?500D4QL05Q@I01XE6`0K5Q`071LM01`J7@0G
5AP05A<F01TG6P0I51P050lC00l93@0I4aL06aDI01483@0H3a@08A`P00400P0L6Qd03P`?01HD5`0G
4QH05Q4E01LA5@0D3Q807aLL02DL8@0J4AH04@X=010:300=1`T04@/=01H@4P0E3a405Q0B01PB5004
0000:R@V00T31@0J51H03@L:00h8300?2@d00`0A2`l0500<1PX071HJ00L11@0D3Q806A<G00P21P0>
1@/04PL?01<74@0A1A403`<?01@85P0^8Rh050PD00T01P0E2Q005P/?01L<400?10X040D;0P0A1P`0
4P0?10X03P<90146300?10X04PL=00T0100@1@/07A8H00h32@0C20h050T?00L00P0;00H05``B0146
300?10X03@88014630804`P>01<0710J00L01@0@1Pd04`P@01<83`0B1`d03P<900d31`0900802001
00h41`0F2Ph02P0001`=4P0H2@h070dB01T<3`0B0`P04@87008050D:00<04`@90183200C10T05?oo
ool001_ooooo00L03@X8014>2P0D40`05a@@00l<2@0<2@D030P40080514=00@05a<?01<?2`0>2`L0
4Ph;0P0A3@X2018>2`0>010<2@0C3``040`9014=2P0B3P/03`/8010<2@0B3P/04@d:00l;200B3P/0
3`/8014=2P0@30T2018>2`0@01<?300F4Pl06ADB010?2`0>3@T040l;018A3@0D4`l04A0<018A3@0@
3`/02`X601@C3`0B4@d03Pd9018A3@8030/702@03@`800h=2@0?3PX0;bhZ01hM6@0=30P03Pd900X9
1`0B4P/04A4900d<1`0@3`X05aHC00/92@0>3@`07QdK01XI5`0=30L02`X500l?1`0>3@H04Pl:01@A
300B3`X0514<01DB3@0A3PT04a0;01@A300@3@P04Pl:01<@2`0@3@T02`L400`81@0>2PL201<?3009
018>2`0=2@H040`9018>2`0>2PL05A4>01<@2`0A3PL04a0900804Pl:00/04@h9010<2@0B3P/040`;
00h:2@0:1PD0510?00l>2P0B4@d040l;00/:1P0200h=2@0600l>2P0@3`/03Pd900d<200?3PX040l;
0P0B30`09`0A3@`040`;014=300?3P`04A0>00d<2P0?3`d06ATG018B400<3@/02@/800lD400V:2D0
418?01HG500=3@/04A4?00/:200<2`T03`h<014?3@0B3Pd03PX700l=2P0<30X0410B00d?4P0;41<0
3A8G00lF6P083A005AXM00d@4@0;30d02`/;00l?3`0<30`02`/;00d=3@0200`<300?00/;2`0C4a<0
>CTi08B4Q00E5AD03@`:00`;2@0B4@l04a8@00d<2P0>3@/040l=00`;2@0=30X03Pd;00803@`:00H0
3Pd;01<B400=30X03Pd;00`;2@061@@300h=2`0300d<2P0>3@/03Pd;00803`h<00`04Q4?00l>300<
2`T03Pd;00d<2P0F5A<0>CPf028Q7`0@3`d05A@B01PD4`0B3Pd3010<2`803`/:01<0510?010<2`0@
30/03`/:00`9200<2`T03Pd;00`;2@0;2PP03@`:00h=2`081`H05QDC010?3@0:2@P030/900d<2P0I
61H03`h<008030/902@02PT700l>300<2`T04A0>00/:2@0?3P`030/900h;2@0>2PL030P500l;200B
3P/03`/800/7100B3P/03@T600`81P0?2`P03PX700X51@0J5AD03@P801<>3P0A30/07APG00X51@0B
3@`03PT800`71`0E40l03PT800l;2P0A3@`03@T801@@3`0A3@`200l;2P0R010<2`0A3@`03PX900h:
2@0B3Pd030P9010<3@0=2@X05Q8C00d92P0@30d03`/<014=3P0I5AH04@d>00P41@0@3@h03`h<014A
3P0F5a<00P<0010@3`0A40l040h>014>400?2`d040/?01<>4P0@2Pd030H6018>300>2PT05a<B00`9
2P8040h?00`03@`=01@D5P0P82804Q4E00L72P0>30h03@/<00l=3P0@3Pl03`d>00h=300?3@l300l=
3P04010>3`0@3Q002@L<00/83P8030X?01D04Q0C00L5200B41<0:bTZ03dk?00E4a@02`T:014?400=
3Q0030`>00T92`0B4A<02PP;00l=400@3A004@`@010;3`0C3A4050lC028L800B3A400P0=20`03`0;
1`X03@P<018=4@0C3Q803`X>014<400D3a<03`X>00`72`0;2@X030X;018@4@0;2@X03P`=010>3`02
00/92P0500d;300;2@X03`d>01TG6@0N71l00P0;2@`04@0=2`h03P`?00/9300<2Pd03@/>00X82`0<
2Pd03`d@014>400A3@h0510A00`82@0B3Pl02@D600X61`0E4A804@d>00803`/<034040`=014=3`0A
31003@P<01<>4P0>2@d030L;01D@500I51P05A0D00l:3P0B3A403PT=010:3P0A2`l03`X>00h93@0A
31003`d@018@4`0>30l03`lA00X:300B4Q@030`>00/8200G4a@03`/<024M7P0>2P/04`l@00/7200D
41403`/<01@@4@0>2`/05A4B010>3`0>30d03`d>00`:2`091`P03`d>010>3`091`P06QPI01PF5`0<
2P/04Q0A008040h?0P0?3@h2010>3`0400/92P0A3a004a4B014?40<03`d>00<04Q0A014?400?3@h0
0P0<2P/03@0H5QL0518C010>3`0A3a002`T:010>3`0=30X03Pd;00d<2P0?3P`04Q4?00h=2`0<2`T0
0P0B4@l020061@@05aHD03He<`0A3a004a4B00d;300C4A803P`=0P0A3a02018@4@804a4B01L0518C
018@4@0A3a0040h?018@4@0C4A80518C014?400C4A805A<D01<A4P0B41405Q@E018B4@0I6AP07AdL
00l?400K6ad04A4C01HF6@0I61d05aHK01DD6@0201DD6P804a@H00d04A8F01<D600J6al06a`P01DF
6P0I6Qh05QLK01TJ7P0H6Ad05AHI01@E5`0F5aT061TK00806AXL01L061TK01DF600J6ad08b@V01TJ
700L7Al05aTK01@H6@0E6AX061`M01TM7P0G6ah06A`P01TL8@0J7B806A`R01DH7`0G6R405aXP01LJ
7`0H6b004aHK01HI7P0201XM8P0H01LJ7`0I72405APM01LJ7`0K7R<06b0V01XN9P0G72<05ATQ01HK
8P0M8BT04ADM01hR:P0G72<06QlV02T]=@1>DeX06QhU01/O900D61h06alT02HZ<00J7R@06alT0P0F
6Ql05`0K7bD06alT01DI7`0F5R006ATS01dM9P0H62406ATQ01DE700L7B803a0D01LH700D5AT0;c0d
01LH6P0I6Q`06a`M01LH6P0I6Qh061TN01DF6`0E5QX05QLI00805ALD00@05QPB01HH4`0F5QH051@F
0P0G5aT02`0D51H06ATK01PH6P0H61X06a/M01LG6@0C4aD06ATK028R8P0F5QH061PH00806ATI00<0
61PH018B4P0D51@00P0E5AD201@D500901HE6P0H5a`06aXO01dL800N7B8081lS01TH700H5a`05aHK
008061LL00P03`hC01@E6@0G6Ad04Q@H02<T:00E5AX04A4E01HD6@805A<H00D05Q8H01DB5`0E4AL0
5Q@G010>4@0201HD5`0E01<>4P0J5AT05a4E01TC5`0D3Q805@`A01T@5@0@2Ph07A/N00d;3P0E4aH0
20H9018=4@0F41@0;RP/01<=4@0A2Ph05@`A01P?500B2`h04`d?00804@/=00T040X<00h82P0?2@/0
3`T;00h82P14?T0050h@01<=3`0A2`h00P0?2@d05`0E3a<03PP<014;3`0@2Ph0208601@>4P0=1`/0
4`dA01PB5P0;0`T0<bP`0187400P52004@DA01864`0>0Ph040@>01<73`0?10X03P<701061`0@1@T0
4@H<00804`P>00P04PL=01052`0B1`d04@H<00l42P0<0PL060dC02HK8@<04`P>00L03@8801052`0<
0PL04@H<01052`0>0`T040D;00804PL=01P04PH@01@84P0>10/03`@<00h42P0>0`T03`@:00l42@0?
10P040D900l4200:0@<040@801852@0=0P@05@L<01041`0E1``04@@800l21P0F2@d040<700l31P0A
0`PDooooo`006oooool0100?2`P03PX700d91P0>2PL3010<2@0800L30@0@30T03@T600X60`0H5140
4Ph;010<2@0?2`P2014=2P0400h:1`0B3P/04@d:010<2@803`/800L040`9018>2`0>2PL03PX7018>
2`0A3@X03`/800H04@d:00P03@`800l>2P0=30P02`X600X91@0;2PH03Pd900l>2P8040l;00<03`h:
00h=2@0A40`00P0=30P03@0?3PX040l;00l>2P0G5Q802`X600@3000<2`L03Pd900P80P0:2P003Ph6
010?2`0?3PX00P0<2`T03`0>3@/03Pd900h=2@0>3PH03Ph4014?200A3PT03``700/80`0<2@@04a0;
014>2@0=2PD03``700h;1P02014>2@07010<200?2`P03`/801<?300F4Pl05A4>018>2`0200T50P04
01DA3P0@30T03@T6014>2@804@h70`0B3`X02@0>2PL04Ph;01@@3`0D40l01P8101<?3P0B4@d020L3
00d<200201DD400700X91@0C4Ph05A@@014@300=30P03`h:00d<200201@>3P0U018>3@0@30/040`;
00h=2`0:2@L051<A01<C4@0?3`d02@T7018C400A4a0000<003Li=P082PL030d;014A3`0?3`d03@`:
00`;2@0=30X03`d;010<2@0=2PD03`d800P81P0?41802@dB00XA5`042a408bX`00hE6`0?5aX010X;
00@82@0<3Pd0410@00l?3`0200`<300900h>3P071`L03Ph>00d=3@0B4Q806QXJ0000000=30X03`h<
00@040l=00H051<A00d<2P0?3P`03Pd;00`;2@0>3@/200d<2P0500X91`0<2`T03@`:00/:200>3@/0
0P0=30X09@0>3@/03`h<00l>300?3P`03Pd;018A3`0?3P`02PT700d<2P0>3@/051<A018A3`0>3@/0
4A0>01LF500E4A003PX900`81`0?2`X040`;00l;2P0<20L040`;01HB4@0C3`h040`;00h;2P0>3@/0
3`h<00d<2P0;2PP03@`:01@C4@0=30X030/900T81P061@<00P0?3P`200/:200<00`;2@0=30X03@`:
018A3`0100004a8@04M6A00l>cT061LE00L50`0A3@X04`l<0P0@30T04`0?2`P030P5010<2@0C3``0
6aLD01PD4@0<20D05a<B00<0000M6AP02PH503Hb<@1;AdH0510?010<2`0;20L01P8100/71P0A3@`0
0P0D40l200l;2P0d01LC4P0I5A@02PH500d9200?2`X03PX900d9200>2PT03`/<01@@4@091@H0510A
00H20`0@30d03@T:01HB4`0N6Q/0510A00h:2`0A3Ph051<?00l@2P0E5Q002``6010@2`0<2`H03Pd9
01<A3`0@30d03`/<014;4@0<1PX03@L7010<2P0?2`X04Ph=01HC4`0>30d08b4R01DD5@1bLW@0^[Zl
04e<D00M7Al040h?00l=3@0>30d03@/<00d;3@0=2`h03`d@00h<3`803@/<00@03Pd;00l=3P0<2Pl0
3`dC0P0C4AH03`0>30l040hA01<A500@3Pl0518C00X82@0D4Q<0:RPY034a<`0@418030`>00d;3P0:
20/03P`?00h93@02018=4@8040X>02/04@/?01@?4`0?2Ph03PT=01PC5`0K5QX05Q4E00D0100G4QH0
6QDI01LB5P0M61`09b8V00d;30071@H03P`=00/92P0C4A802PP900/92P0?3@h05Q@E010>3`0<2P/0
5Q@F01<A500<2Pd03P`?00T72P0:20/040hA018@4`0A3a802`T<00`:3@0>30l03``>014=3P0@30d0
3`/<00h:2`0=2@X03PX;00804@d>01h03`/<014=3P0D414050lB01@?4`0G4QH05Q4E00h93@0=20`0
4@`@00h93@0?2Ph04PdA00h93@0?2Ph04P`@01D?4`0@2`l02`H:00l:3P0@3Q40<c4d08N5R00@4180
0`<500h>40092@/03@T:00`82@0=2@X200h:2`0E00/7200A3@h04@d>010<3@0A3@h040`=01<?400>
30d03@/<00l=3P0C4A805A<D01<A4P0B41403P`=01PF5`0>30d040h?01<A4P0>30d03`d>008040h?
00<03`d>00h<3@0>30d01@0>30d2014?40<040h?00<03`d>010>3`0>30d00P0=2``02P0?3@h040h?
00d<2P0@3`d03`h<018A3`0F5A<04Q4?01LF500;2PP2014@3P0800h=2`0O7Q`040h?00h<3@0@3Pl0
4a4B010>3`0>30d6018@4@0401<A4P0B41404Q0A018@4@804a4B01h04Q0A01<A4P0G5AH05A<D01<A
4P0G5aL06QXJ00/;2`0A4A40?Si001@D5P0K6ad040lD014@5@0B4AH05A@J01HE6`0D5AX0414E020Q
9@0I6Qh06Q/O01LH700:2`l06Q/O01HG6`0N7b<03PlC01<D600N7b8201TJ700H01PI6`0G61X05aPJ
01LH6P061`T07AhP01HG6@0=3Q005aPJ01PK700E6AX05QXK01PL7@0J7Ql061`O01PL800K7R<071lT
01TL8P0E61l05QTP01HI7`0E61d05aXO0P0I724201PK800501TL8@0J7B8061/P01TL8@0L7b@00P0F
6al04P0F6b405a`R01PM8`0J7bD05AXP020U:`0A5Q`05ATR028V;`0c=cl06QdT01/N8`0H6b006A`Q
01hQ9P0I72406QdR01LJ7`806A`Q01/04aHK01@G700I6B407AdW038b>P0W9bl071`T01PI7P0I6Ql0
5AHK01LH700K720071dQ01PI6`0D5AL04Q<D01@E5`0>3a<04Q<H01DF6`0D5AX05QLJ01DG5P0D5Q<0
51HA01<E400M7Ad00P0G5aT00`0C4aD05QHH018B500201DE5`0E01PH6P0F5QP051@F01XJ700E5AD0
5QHF01TI6@0K6a/06QXJ01LG5`0D51@05aLG01HF5P0B4Q804A4A018B4P0E51P05A@I01PH6P0K6a`0
6a/K008071`L00`030`<01LG6@0A4A@081lT028S9`0D5QX020`?010D5`0P8BD0414E01HG6`0D4aP2
018@5@0:01HD6@0L6Ql07adR01hL7`0D4QD05aDH01HD5`0<1`/05A0D01LA5@805Q0D01@05PdB01<:
3`0B3A404a4D018@4`030P@020H901LB5P0J51P0>cDi018<400B2Pl03`H;01XA5P0A2@d040X<014;
3@0C3@l04P`>014;3@8040X<01d04P`>01@>400B30h04@/=010:3@0=1`/03PP<014;3`0E3a<04`dA
01hH700=1`/02`D900d72`0;1@T01002020H7P2n/k/0>2le00X0200N4Qh04PHB01454@0A1@l04@H=
01052@0@1PL040H601052@0201052`0300l42P0>0`T03P<901803`@:0P0?0`d200l4300400l42`0?
10X03@8800d21`8030450P0>0`L600l31`0600P0000A1@T020000104200C1`/0A3Pl5?ooool001_o
oooo00l04@d<01<?3P0?2`X030P701<?3P0P71/0GUYI01HB4@0J5QD06aLF00l;2`070`804`l<010<
2@0?2`P00P0@30T0100=2@H04Ph;014=2P0A3@X2010<2@0700l;200A3@X03`/8010<2@0B3P/040`9
00l;2006014=2P0701@C3`0L6aL05A@@010?2`0B4@d03Pd900l>2P03010?2`0E00h=2@0=30P03`h:
00d<200>3@T040l;00l>2P0>3@T05QDA014@300;2PH05A@@01HE4@0@3`T03Ph4018B2P0B4@`04A0<
01<B400B4@l03Pd;00803Pd901<03Ph600h>100A3`P03@X500`9100@3@P02`P300h;1P0B3`X040d8
018?2P0A3PT0514<01<@2`0B3PX04Ph;014=2P0C3``05A4>0080510=01<040`901<?300S7a`07ATF
01DA3P0@3@P03``5010=1P0A3PT04Pl:01<@2`0A3@X0510=00h:2@0B3Pd03`/:01LC4P0G5Q803@`8
008030/700D051<?00l>2P0H5a<06APD01@C3`0200h=2@0a00/:1P0D3Ph050h>01<?3P0A3@`040`;
00`;2@0;2PP04a8@014A3`0D51803Ph<00@50`0B51407R<O01HH5@0h>SL0?d0n00h>300=3@/03`h<
00h=2`0=30X03`d;018>2`0=2P<03`d700P81P0>3a402PlC00dD700D6b<0GVM^04I?E00I8bD031DE
014G5`0=3`h0410@00l?3`0>3Ph03@d=00l?3`0>3Ph04A4A00P820010@402`/;01`L7002010?3@07
00l>300@3`d04A0>018A3`0@3`d03Pd;00l>300200d<2P0?01<B400?3P`040l=00`;2@0?3P`04A0>
00h=2`0?3P`030/900X91`0;2PP03@`:00l>300>3@/02`X800803Pd;00T030/900d<2P0?3P`03Pd;
00`;2@0:2@L03@`:014@3P0?2`X00P0<20L200l;2P0D00h:2@0=2@P03`/:018>3@0D40l040`;00/9
1`0>3@/040l=00h=2`0=30X03Pd;00`;2@0920H02PT701HE4`0B4@l010<100H5100:2@L200/:2080
30/901h03`h<00@30@0?3P`0A4=1034`;P0B4@l030T701DA3P0K5a@04Ph;00d91P0@30T04@d:00`8
1@0G4a00920M01PD4@0?2`P04Q4?00X91`0i>3H020L501PG5@0H5aH02`X800X91`0A40h03`h<018A
3`0G5Q@2014=308030P70P0B3Pd00`091@@02`L600h:2@0200d9200]00h:2@0>2P/0510A00d92P0D
41402@D601PD5@0=2@X0510A01/G600C3a003PX;010>3@0?3PT03@h701`M5@0G6@h061T?01lO5@0;
2`<04Q0<014=300?2``040X@00d72`0G4A403`/9018>3@0300005a@D00@20`0@3Pl05A@E0:JVZ03o
ool0GeiR00`<3P0A40h03`h;00`:2`0;2@X03P`@010>4`0>31403@/>008030X;00X03@`:00h=2`0C
4AH02@L=00H42@081P/03P`?01<A500>30l02PP90P0;2@X02@0?3@h05Q@E01@D50040P<01@<4010>
3`0=2@X0100100h:2`02018<3P0D010:300A20/040X<00h93@0=20`03PT=01LB5P0J5AT05A0D00l:
3P0A31003PT=00d8300910P02`H:010>3`071@H03P`=00`:2`0?3@h200`:2`0:018@4@0H5QL04@l@
00/92P0:20X020H900/9300A3a802@L:00X82`8040hA00`03P`?00X82`0=2`h030X=00d:300A3@`0
40`;00l;2P0>2PT03@T800l;2P0>2PT200d9200900/71P0?2`X03`X=010;3`0G4QH04`hB00l:3P0@
2`l04PdA00802PD901@040/?00/62P0=20`040X>018<400=20`020<700/62P0<2Pd06ALJ07ajO@0<
30h020P:00d=3`0:2P`03PX;00l;300A3@h040`=00l;308040`=00D030P900l;300?2``06ADF00h:
2`0200/92P0<00d;300A3a004a4B014?400E4a@04Q0A00h<3@071@H05A<D00/92P0>30d03`d>0P0@
3Pl00`0?3@h03P`=00h<3@0500h<3@804Q0C0`0A3a800`0@3Q404@lB01@B5@0200d;3P04014?4P0=
2``03@`:01<B40804A0>00h05QDC01DD4P0D4a402`X8010?3@0F5A<04A0>00P71@0A3a003`d>010>
3`0B414040h?00h<3@H04Q0A00<04Q8B014A4@0@41000P0A4A400`0B4Q8051@D018B4P0201HF5P0?
01@D500E5AD06Q/K02@U9`18BD/0OGj0018C5`0;31004A8F00h?500A4QL05QLL01LG7`0F5a`071lR
00804aLJ01803Q8E014E600L82<06QhQ01@H6`0W:bh03Q8E01`P8`0K7b80720S01XN8@0F6Qd051PK
01<G6P0L82<01PX=01XN8@0E6A`2024U:00B01TM7`0F6Q/05QXK01PL7@0J7Ql061`O01PK7`0K7R<0
71lT01XM8`0E61l04aHM01HI7`0H6b006A`Q01XM8P0I724061/P0P0K7R<05@0M82D07R4V01dP9@0J
7B8051TM01@I700D6Ad05AXN01HK7`0H7B406AhT01@I7`0N8bT0720Y01XN9`0B5A`05APO01`M8P0J
6b004a@I01@E6P0201TJ7`0901/L8@0N7b@05aPM01<D6@0K72405QHN01LG7`0`<3P09RL/00804a@I
00<04A8F01@E6@0F5a/00P0G61X01P0E5QP04a@F01<D5`0A4QH0414F01DE70805AHK00X05AHI01HH
5`0E5a@051HA01<E4P0A4A4051@F01HF60092@/05aLI0P0E5AL04@0D51H05QHH01DE5`0C4aD06ATK
01DE5@0F5QH061PH01/K6`0J6QX05aLG01PH600J6QX061PH01@D500B4Q804a<C00804a<E014051@D
01`L6P0O81/071dH01XK5P0B4Q00:b/Y018B4`0C4aD04Q<E018E600K7b807b<V038f>@0^;c<06AXN
01DF6P0201<B5`0301LF6`0O7B808b4V00805aDH00D040hA01@B5@0?2Ph061<G01LA5@0201H@500A
01H=4P0D2a003@P<00h<3`0N71l061HI01@B5@0H4aL03`T=02/U:@0>20`04PX?00X11P0D2a004PX>
010:300A2`d00P0C3@l2018<3P<04@/=0P0@2P`04P0?2@/040X<01TC5@0>20X04`d?00@0000910D0
1P02014;3@0>20X04P`>00D00@0F3Q80>Rle01X?5`0E2A<050PB01P<60804`LA00X04PL>01462P0A
1`P040H600h31`0?10X04@H<01052`0?10X03P<94P0?10X200l33@803`@<00P03`@;00l42P0;00H0
2`0500/0100<0@D03P<700l420H03`8900H07a8I01062P0G2Q402`0501@73P0H2a8Dooooo`006ooo
ool04`0D40l05A4@010<2`0>2PT05A4@01hJ6@1RGUd071PH01<?3P091PD04`l>014=300E4@h04`l<
018>2`0C3``04Ph;010<2@0A3@X00`0B3P/0100@30T03`/8010<2@0B3P/201<?308040`91P0A3@X0
1`0;2PH04Q4=00/:1P0C4Ph05A@@00P70`0A40`00P0@3`/04`0?3PX03Pd900h=2@0>3@T03@`800h=
2@0@3`/03Pd900`;1`0A40`03`h:01@C3`0<2`P02PT500l?200B4PP04A4900/;100?3PT00P0I61D2
00h=2@0A00h>1`0>3PH03Ph4010>1P0=2PD05A8=02@Q700E4Pd03@X500l<1`0A3PT04a0;014>2@0D
4@`04a0;00l<200@30T01@0?2`P01P0:1P<02@D201@@3@0C3``03@T600d:1@8040d60`0@3@P0500<
20D05A4>00l;2P0B3Pd04`l>018>3@0A40`01`H301<B3P0;2PL05aHB014@300E51005aHB018A3@0=
30P03Pd900`;1`0A2`/04P`<0P0C3`h0100B3Pd03`h<018A3`0?3P`200d=2`0700L71P0Y:RP0?3dk
00lD400;3@X0?T0m04A5@P0200`<2P804A0>01003Pd;00l=2`0D40d03``4010>1`071`@03@h@00hD
6P0J8b`0CEIP0=OOi`3@f^00GFM/020[;00A61P0418A0P0@410300l?3`08038b<P0l?3`05ADE00@4
100B4Q802`/;014@3P0@3`d200h=2`0800l>300A40h030/900h=2`0?3P`030/900l>300F5A<2014@
3P0600d<2P0>3@/03`h<00`;2@0@3`d03`h<0P0>3@/200d<2P03010?3@0=30X03@`:008040l=00L0
3`h<00`;2@0:2@L02`X800h=2`0=30X030/900@03`/:00P03@T800`81`0B3Pd04@d<00`81`0A3@`0
4Ph=00l<2`D03@`:00L03Pd;00`;2@0C4Q003@`:00P71P0C4Q003`h<00D03@`:00/030/9014@3P06
1@<040l=00X91`0>3@/02`T701DA3P0I5A804Ph;00h:1`02010<2@0J00d91P0:1P@05Q8?00d91P0A
3@X020L5010?3@0S8R002PT800/:200=30X020L501<B400@3`d020L5010?3@0;2PP05A4@01<?3P0A
3@`03`/:00h:2@091@@030P700h:2@0@30/200l;2P0]014=300?2``05Q8C01TE5P0E4A802PH701@@
4@0<20T040`=01<?400@30d03PX;00l=300B4PT05QP;01TK300W:AX0<C<T01TJ300C4`L04a8901@A
3@0D40h050lA01@>4@0D3Ph04@`:01HB4@0?2`X03``<018@4@0H5QL04Q4B03De=`1FEUP0:2L[014A
4`0>3@/03Pd:00h=2`0>30l03P`@00h<4@0?3A803`dA00803@/<01D03`h;00l>30091``03``B00d;
400>31404a4D00L5200>30l04@l@00h<3@0?3@h03P`=00T8200:2@T030X;00X82@0G51D06ADF00h:
2`0A30d00P0A2`d07`0C2`h04`X=018<3P0>2@d040/?00h93@0B3A404@`@00`72`0>2@d05a8F00d8
300A31003PT=018=4@0=2``02`T:00h<3@0=2``030X;018@4@0>30d02`T:00`:2`091`P030X;010>
400:20/01`D800h<3`0@3Q400P0>30l01P0=2`h02`T<00l=400I5aX05Q@G010=3P8040`;0P0?2`X0
4@0>2PT04@d<010<2`0@30/04@d<00`81`0=2@P03`X<010;3`0A31003`X>01<>4P0D3a<040/?01D@
500C3Q803`X>008040/?02H04`dA014;3`0>2@d05A0D01XE6@0>30l04@lB00L6200?3a4030`>00l?
4@0=3@l03PX;018>3`0E4A804Ph?014=3P0D41404`l@00P41@0@30d04Ph?01PD5@0G4a@06QPI01HD
5@0@3Pl03P`=00l=3P0@3Pl04@l@00/92P0A3a003P`=00l=3P071@H03P`=00l=3P8040h?00<03`d>
00h<3@0?3@h01@0?3@h7010>4@0B018@4`0F51L04Q0C00l=400H5QL03`d>01DD4P0@3`d030/900l>
300@3`d03@`:01DD4P0A40h03@`:014@3P0C4Q004@l@0`0B4142014?40H04a4B00<04Q8B014A4@0@
41000P0A4A40=`0B4Q805QHF018B4P0D51@05aLG01@D500@410061XJ00/<3P0G61X05AHI010A5@0G
61`05AHJ01@E6P0H6Ah05aPN01HF7P0J6b007R4U01TM800B5QT06QhQ01lS9P0F6Qd01PX=01hR9@0C
5aX03Q8E01`P8`0J7R406alR01PL7`0D61/04aLJ01@H6`0C5aX09RX]01lS9P0K7b805ATL01HJ7@0F
6Q`05a/L01HJ6`0H71d06QhO01XN8@0H72006A`Q01/N8`0L7bD06A`S01LJ8@0H6b400`0I724201LJ
7`0701hQ9P0K7R<06A`Q01/N8`0L7b@061/P01HK7P0201DK700i01HK7P0G71l061dQ01lT:P0?51X0
>3e3024U;P0C5b006AdU01XK800K720061TN01<D600B4aL05aPM01DF6P0F5a`06AXN01/L800M7R<0
92DY01`L900D51`061PO01XK800R8bP06Q/P018C5`0F5aX05AHI018C5@0E5QP06a`N01@E600E5Q/0
4Q<I01/K8P0E5Ah04A4J01@D7@0@4AH051DH01LH6@0E5aD05QPF01PH6@0G5aT07QhP00d=3`0D51H0
820R01PH6P0F5QP05aLI01DE5`0D51H06a/M00804a<C00D05ADE01LG5`0H61P05ADE01LG5`0201XJ
6P<061PH03005aLG01XJ6@0K6aP07R0H02HW7`0Y:R407b4G01lP6@1VIf00:b/Y00l?3P0Q8R<05QXM
00T>4@0Q9RT0][Zm0:na]@0W:Rd05aPL01LF6`0F5AX05A@I01HD6@0F5AX05aDH038`<`0D4QD05Q@G
01TD600F4AD05Q0D01LA5@0F41@060lD01D<4@0H4QH040hA00l=400N71l0518E010;3`0A31006A<G
00d72`0E3A802P4601483@0D3A02014;3@06018<3P0C3@l04`d?01@>400B30h040X<0P0?2@/02@0@
2P`04P`>00X41P0D3Q0030H801dG6@0E4140O7Ih03Xd=P0200l92`0D01D?4@0A2`d03`L;0148300C
2@l07Q8L02`P:P0I3AP05@TC01@94@0D2@l04PL;0147200@1PH03`@801052`0C20h050T?01873@0@
1@/B00l42P803`<=0P0?10`01P0?10/03`@:01052`0?10T03P<700d21P803P<71P0?0`T01P0@10X0
5``A01L;4P15>cl0<RP]02/O9ACooooo000Kooooo`0=01<?3P0?2`X03PX9010<2`0A3@`03PX900l;
2P0<20P02`L600<0000E4A005Q8A014=2P0200l;20804@d:00P03`/8014=2P0C3``0510=01<?300@
30T03`/8014=2P804`l<00<04Ph;014=2P0B3P/01P0A3@X00`0C4Ph04A0<018A3@02024P700301DD
400A40`03`h:00803Pd90P0?3PX04@0>3@T030/700`;1`0?3PX03Pd900`;1`0A40`03@`802h]:@0]
;2P06APD00`;100@40@04Q8800l>200:2@@02`X600803Pd900h03Pd800h>1`0>3P@03Ph2010?1P0=
2PD03``701PE400A3PT030T400l<1`0C40/04Pl:010=20804a0;00P040`8010<2@0A3@X03`/800h:
1`0?2`P0510=01DA3P804Ph;00<0510=01HB3`0E4Pd00P0B3`P04`0@3@P03``700l<1`0F4Pl030P5
018>3@0A3@`00`0004Q4@`1XIf<061LC00d<200E510040l;01<B3P0=30P03`h:00d<200;2PH00P0?
3PX0200>20P03`T9014=300B3Pd04`l>014@3P0=30X02PT70P0@40h07@010@00:2TV02/]:P000P00
4A<@00lA3P0>3``03@d;00`<2P0?3P`040l=00l>300?3@/04@d:00l<0`0@40L01`T400`@4@0@5Q`0
7RHa03M1C@2c_/T0[kc404UDFP0>6A/00@/:010A4`0?3`l03Ph>00803`l?00L030`<00/;2`0H61P0
51@D00H61P0410@02PX:00803`h<0`0=30X01P0>3@/04a8@00l>300?3P`02PT700T81P803@`:01/0
3Pd;00`;2@0@3`d051<A018A3`0>3@/04A0>018A3`0A40h03Pd;00`;2@0=30X04A0>00d<2P0<2`T0
3Pd;00d<2P0:2@L030/900h=2`0A40h03Pd;00`;2@0A3@`04Ph=014=300>2PT00P0=2@P02P0>2PT0
30P7014=300?2`X03PX900h<2P0<2`T02PT700`;2@0=30X200`;2@0701PG5@11@3h0>CPf01XI5`0N
7A/03Pd;010?3@0200l>30803Pd;00L04A0>00H50`0:2@L05A@B0040000M71X03@X8008040`901`0
3`/8010<2@0>2PL020@101<?30091@804`l<00d91P0=2@P00P4003Xi=`061@<010<1010?3@071P@0
2@P600L6100@3`d06APF00P71@0=30/09B4P01`H5`0B3Pd03PX900d9200A3@`03PX90P0?2`X200`8
1`0700l;2P0@30d03`/<01<?400@30d0510A02PT9@02014=3P804Ph?02804`l@01<A3`0F5PX051L6
034d8@27RWL0[:jK05IGA@0`<B407ahA01HC300F4Pl04`h?014;3@0;1@D03PX8014=300D40l01P<3
00h<3@0=2``03Pd>01hN800?3a40410C00@41P0;2PP03Pd:010?3@0A3a803`dA00`:3`0@3Q<040hB
0P0>30d02P0@3``040l=00l=4P0=2a404Q0E00T7300D4QD040hA00l=400?3@h200X82@09010>3`0C
4A804@l@01@B4`0>30d04@d>01@@4@0?2``03`T;008030H800H04@P;01072P0=1`T03`T=018=4@0@
2`l2014<400=00d8300B3A406QDI00d8300H4aL02PD900H11@0;2@X061HG00l=3P0=2``02`T:010>
3`0200X82@0@00`:2`091`P02@L800/92`0?3A004Q0C00X82`071@P04Q0C01HD5`0=2`h02`T<00h<
3`0E4aH04Q0C00d:2PD03`/:00@030P700d9200A3@`03`/:0P0@30/02P0>2PX030L;00h93@0B3A40
3@P<00T4200:1@T04PdA010;3`0:1@T2010;3`0?01@>4P0A2`l03`X>01`G6`0R7B403`d@00`:3@0T
8RD020P:00`<3P0D51H02`/=00/7200=2@X040`=00803`/<01004@d>00/7200=2@X02PH7018>3`0>
2P/081`M02DS900O7Ah0518C00l=3P0@3Pl04Q0A01@B4`091`P04@l@0P0;2@X00`0D4Q<03P`=00l=
3P02010>3`0300l=3P0>30d040h?00D040h?0P0>30l300l=400=010>4@0?3A003P`?018@4`0@3Q40
30X=010>4@0E4a@05aHD010?3@0=30X040l=00h=2`02010?3@05014@3P0E518051<A00T81P0A3a00
0P0C4A800`0B41404@l@018@4@0601@B4`0301<C4`0B4Q804A4A00804Q8B01L04a<C01HF5P0E5AD0
4a<C01@D500B4Q803Ph>00`=3`0F5aT02``>01HG6`020`L07AhR01HG700@4AH05AHK01DE7@0F5Qh0
6QdR01HI7@0=4A@0=3Pk010D5`0201DI700H020T9`0D61/06QhQ02<W:P031`X06alR01DI700D61/0
4aLJ01@H6`0F6Qd05ATL030d=`0U:B`04QHI01@H6`0O8bH06QhP01PL7@0F6Q/061`M01XN7`0J7R40
6A`P0P0H6b00200L7bD07B0W01`O9P0J7B<06A`Q01PK800G6Ql05QTN0P0G6Ql201DH7@0301PK800K
7R<07B0T008061hN03805adM01LL7`0H7B006AhR020U:`0G72807b@Z01<G800O8b`051PP01hO900I
6Qh05aPL01PI7@0F5a/05aPL01XK7`0H6Ad05AHJ01dN8P0T9BT07QlS01hO900K6b<06AXO02X[<015
AT/0;Rlc01LH700F5aX04Q<E010A4`0F5aT07b0R018C600E5A`04a<K01dM9`0C4ad0;bli024Q:`0D
51d05AHK01HG6`0B4aD05ALF01dM7`0<30h02PX<01@D5P805ADG00<06a/M01PH6P0G5aT00P0E5AL0
2`0L71h05QHF01DE5@0E5AD061PH01TI6@0H61P05QHF01PH600G5aL04a<C00804A4A01@06Q/G01/L
5`0N7aT0828F0494=`1UIeT0@D<f02T[7P0j?34061TD028S7P092`X05Q/M020U:00E6Qd0?41304A8
B`0K7b804Q<G01@C60@05A@I00L07Q`O03`j?@0K6A`05Q@G01LB5P0?2Ph05Q0D00805a4E010060lD
01H=4P0C3A403@/>01/I7019AdX0<Blb018=4@0A310040X>018<400E3Q804PT>01@;400E3A404`d?
0`0B30h0100C3@l050h@01<=3`0A2`d200l92`8040X<01`01@01010:300@2P`04@/=01D?4@1nN7X0
=2h`00l92`0>20X030H801D?4@0F3A40304701H;4@0F2a<03`<=01dA6`0C1a404`P@0187300A1PX0
4@L601061@0=0PH03P<901052`0A1P`040D;4`0?10X200l33@803`@<00H03`@;00l42P0E2Q004`P=
01052@0>0`L200d21PH03P<900H01`0200X11@0;00H0LVM]04@i?`0=0PPDooooo`006oooool04@0D
40l04Ph=014=300D40l04`l>010<2`0H51<04`l>01@@3`0I5A@061@C00L30P0?2`P03PX700l;200A
3@X04Ph;00804@d:00/04`l<01@@3@0C3``040`900l;200B3P/0510=018>2`0@30T04Ph;01@@3@06
014=2P0700`;1`081`<02PT5018A3@0@3`/030/7010?2`0200h=2@0400l>2P0@3`/04A0<00l>2P80
2`X600d03@`800h=2@0=30P02@P400d<200Z:BD08R4M00l>2P0<30@04A4501<C2@0D50d040l:0080
3@`800T03Pd900h=200>3PL03Ph400h>0P0A3`L040d800`9100=2PD00P0?30L04`0B3`X05Q<>01DB
3@0@3@P05A8=01HC3P0A3PX040`9018>2`0@30T03PX7010<2@0?2`P03PX700l;200<20D02`L400d9
1P0@3@P00P0B3`P3014>2@0>01TE4P0>2PL030P700l;2P0;1`H0BdM606i]J@0M71P02`X600T8100;
2PH051<?00/:1P0=30P200`;1`8040l;0P0A2`/03`0@30/04@d<018>3@0A40h030/900d<2P0?3`d0
6QXH00l?3@020`401`T601<H50082PP061XG018C400200`<2P0B00d<2P0>3@/040l=00l=2`0=2@H0
30T0018B2@0<3PT03Q8C00`B6@0D72L03ALS04=@FP14DET05R<Y00HB500640l03a0B0P0=3@d200h>
3P0500/;2`0E5AD01PH6014A4@0C4a<00P0:2PX0500?3P`040l=010?3@0?3P`03Pd;00d<2P0B4@l0
30/900d<2P0<2`T02@P600/:200?3P`04A0>00l>300D4a405aHD01HE4`0=30X03Pd;0`0?3P`200h=
2`0301HE4`0A40h02`X800<03@`:0`0>3@/06P0=30X03Pd;00l;2P0A3@`040`;00d9200>2PT040`;
01lK6P070`8040`;00`81`091@@03P/:00`;2@0;2PP03@`:00l>300=30X030/900l>300L6aT03@`:
00<2000>3@/030/90P0?3P`04@0>3@/03@`:00d<2P0>3@/09B@R00l>300=30X00@00018A3`0A3``0
3PX700l;200=2@H03`/800h:1`0:1P<05A4>00804@d:00L03PX700`81@010000@d90018A3`0P7ad0
61LE008040l=00L04A0>00l>300<2`T00@0001DD4`0L61L05A4@00804@d<00X03@T800l;2P0A3@`0
4Ph=010<2`0=2@P030P700l;2P0<20T020@50P0?2``0700I5AH0;BTZ018>3`0A3@h040`=01<?400E
4A80518@01@D200P8a00IFQC0=OJa@3mo^X0XZB?0493<@0T91H05A8901HC3P0C3Pd040X<014;2`0>
2@L04Ph=00/71P0L6AT0108301HD5@0;2P`200d=3`0700d=400D51H030/700h=2P0>3@/03`d@00l=
4@0200l<4`0?00l=4@0=2``03@/<00l>2`0?3P`0108701TF701NG640=cDj00d;3P091`X03P`?010>
3`0B41403P`=008020H70`0:20T0100=2@X02`L800L3100?2@/200d41`8040L:01H03@L900h8300@
2`l03@P<00h93@0@2`l03@P<010;3`0A31004PdA03lj?P0/9b/06QDI00h<3@0W9BH04Q0A00d;300:
20T03`d>00/92P0=2``04@l@0P0=2``03@0:20X03@/>014?4P0;2@`020H9010>4@0A3a803@/>00`:
3@0;2@`03`d@00`:3@0:1`L01@0?2`P07P0=2@H05A4>01DA3P091@8040`9014=2P0<20P02@@800/6
2P0@2`l01P4500l:3P0Q72004@`@00`72`0A310030L;00h93@0A2`l040X>00`72`0A31005A0D00/9
300100807Q`O00D51`0@41804a<E00X:30803PX;00h03`/<018>3`0C3a004Ph?00`82@0U8B802`L8
010<3@0<20T05Q8C01HD5@0C4A803P`=00d;30803P`=00P04Q0A00h<3@0@3Pl020H701<A4P0D4Q<0
3P`=00l=3P8040h?00<03`d>00h<3@0@3Pl01@0@3Pl0100?3A003`dB010>4`0@3Q<2014?5008018@
5@0F51T03@/@01HD6@0R82D02`T<01LE5P0F5A<200l>300901@C4@0@3`d04a8@00`;2@0B4@l06QTG
01PG5@0@3`d04@l@0080518C0P0A3a000`0C4A80518C01@B4`0401@B4`0401@D500C4a<04a<C01<C
4`8051@D00<05aLG01XJ6P0E5AD00P0C4a<0700?3`l041<D01HJ6`0<41406alR00/?4P0G6ah09BP]
00/>5@0=41L04aHM01@G7P0H6b004aLK020U:01nPhH07b@W00hC5P0B5aX07R<V00X?4P0i?T4051TL
01HK7P0F6al04aPL01@I7@0E6Qh201HK7`0J01@I7@0C61`0EEYN01`Q9@0H7B406QlS01@H6P0H71d0
5QXK01PL7@0J7Ql06alR01XN8P0H6b005aXO01XM8`0L7bH06QdT01XM8`0J7B8061/P01LJ7`0H6b00
6A`Q01HI7P0H6b0301/N8`0301dP900I7al061hL00<05adM05H061dP01PM8@0J7b<041DK01DI8P0S
9c005QXT01/L8@0G61`06AXN01XK7`0F5a/061TM01`M8@0K72005aPL01`M8@0R8bL06AXN01`M8P0H
6Ah06Q/P02<T:@0c=3T092DY01DF6P0D5AP04A8D014C4P0E5aH06a`N01DF6`0I6B805ADO01/K9`0L
72P0IFEa02/[=`0H62405aPM01PI7@0D5AL06AXL01HF600T92H01`L900l?4@0F5QP05aLI01/K7@0G
5aT05QHH01@D5P0C4aD06a/M01HF5P0D51@05ADE01LG5`0I6AT061PH01DE5@0H61P05aLG01@D500B
4Q804a<C01/K600H6A<08B8J02la9@1jO6h0_l:a09jPTP0b=2L0Ce5601hO600J6aH08bDR01HK7@0<
4A@03A8E01dQ900H71l08RHY01@E6@804Q<G00D05aHK01/J7`0M72405A<F01lM800201LE600301<>
4P0F4AD05Q0D00805a4E00<06A0E01L>4`0D3a<00P081PT04`0H5QT05aDH01D@500D3a<040X>01H@
500D314060lD01H=4P0D31005@lA01<=3`0B30h04@/=018<3P0C3@l050h@018<3P0A2`d00P0@2P`0
4P0>20X03@L901@>400C3@l01@0100@0000=1`T02`D701TC5@0=1`T05Q0B010:300@20/01`0001L<
4P0:00L04@H>01P>5P804@H>00H04@H;01052@0@1PD040H500h31`0>0`T200l42P8040D;4P0?10X2
00l33@803`@<00H03`@;00l42P0C20h04@H;00l4200>0`L200d21P0300h32@0>0`/03P<;00<03P<;
00H06PlG01L<500<0@T01`0400d32P0H3ADDooooo`006oooool0<P072`l04QDF00T;3@0B51H02`/=
028R8@0=30/04A0>00l<2P0>2PP03@P501HB3P0>2PL040h:014>2`0=2`L04Q0<014?2`0@3@X04@l;
018?300A3`/03`d900l<2@0B3``04Q0<01<@3@0>30P05Q<@024O6`0L6QH030X600h<200C40d040d:
00l=2@0@3`/03@`800h=2@0?3PX040l;00T8100@3`/03Pd900d<200?3PX04A0<018A3@0B3``040d:
0P0?30T0@`0@3@X040h:00l<2@0K6AD0?c`i00d;1`091`<04Q0;00l?1P0;2`804Q4;00l>2@0A40/0
3`h:010?2P0?3PT03@`600h>1@0?3`H04A4900h>200C4@`03Pd8014A300:20D040l:00`<1`0D4Pd0
40l:00`<1P0:20H04@h:010=2P0A3P/03`d900h;200?30T03`d9014>2`0C4@d04@h;00l<2@0?3@T0
30`701PI4P0?3`X03P`7014>2P0C40`030P5014=2P0?2`T04A4=018C3`0>3``04Q8>00X:200>3PX0
20P400h>2P0<30T03`l;00/;1`0>3PT03`l:014A3@0G5a800P0?30X02`0?3@X03``:00l=2P0?3P/0
2PT601@C400A40d03Ph;010@3@0<30T0414?00803Pl<0P0<30X0;@0?3`d03@d;00`<2P0=30X03`h<
00l=2`0<2PL030`700l@300<3`d03A4A00dC5@0C6Ql03A@J00hE6P0B6Qh04a/M00/C500;4A003@l>
00d=3@0;2`X02@T800h>3@0=3@`04A4@00/;2P0>3Pd03@d<00`<2`0?3`d040l=010>2`0C40h04a8?
010@3@0?3``03@h:00T:1`0;30T02`h:00/=2@0=3P/03Pd<010?3P0200l=3@0400h=300<2`X03Pd<
00d<2`8030/:02H03`d=014@3`0?3`h051<B01LF5@0?3`h020L6010?3P0A40l03@`;00X:2@0=3@`0
2`/:00d=300>2`/03``<00/8200<2@T040d=00l<300V8b<03@X:010=3@0>2`/03@X:00h<2P0@3`X0
3Pd:00l>2P0=30P040l<00T81@0@3`X040l<00d<200=30L03@`9010?30D03@`:02l03Pd;034`;P0?
3P`03`h<01@C4@0920H03@`900H60`0A3P`02`X800d;20081@@040d;018?3@0D40h03@T800/71@0?
2`T05a<A010=2`0:20H040h;00D30P0<2@L01`D401XG5@0<2@L02`P603@a;`1nNgT03`/900h;1`0B
3``05A4?018>2P0?30T04`l=01<?2`0A3P/03`/900h;1`0?2`T04@d;00h:200=20L03@P900h:2002
018=3P1J010<2P0>2@T03`X;014=2`0D3`d06aX>03Dd901ZJeL0blbh0?Geh@2@TG`0>CLV024N400A
3@H04Ph:01<>3P0C3@l050h?00l:2`0F4A403`X;02hY:P0D4A802`H800l<3P0;20X04PlA00/82P0=
2P/03@`800l>2P0>3@X030/:00d<300@3Q003`d?00h=3@0=30/03@`900h=2@0>3@/04@lB00h<400e
<cL071XN00T72P0E4aH07adP00`:300>30h030X<01LE5`0@3Q00JfYZ018A4@0?3Ph040h?014>3`0=
2P/040`>00l:300=20T05@d@01@<3`0<1PP04Pd@014<3`0?2`d040`>00l;3@0<1`X03@P;010;3P0?
2Pd07QXL018=400<1`/04@lB020N8P0A3a4030X=00T72`0;2@`04Q0B00X8300=2`h04a4C00d;3`0@
2`d03PT80P0A30`2014>3P0c00X82P0C4A@04a4E01XJ7@0m?D005AHI00`;3@0?30X03P/;00d;2@0>
2`T03``<01DB4@0S81h07Q/K00/91`0B3`d04Pl?00l:2`0?2Pd040T<014;3P0<1`X06Q@G02`W:P0H
4aH04Pd@01LD5P0?30h04PhA01<=4@0D3Q804@/?00h8300?2@d03PX>01lJ7P0300<04@hA00d:3@07
10L04a0C00d92`0;20X030T;00l<3P0A3Q003@X<018?4@0/:B/04PlA00804@h@00@040d?00h<3@0>
30d03`d>0P0@3Pl02@0?3@h030X;018@4@0@3Pl03P`=01TG60081PL03`d>010>3`0200h<3@03010>
3`0<2P/040h?00803`d>01<040h?014?400B41403P`>014?4P0A3a4040hB014?4P0C4A<040hB01HD
5`0>30h06QPL02/Y;00E4aD0514B018@3`0>30/03`d<00804a4@00l05aDD010>3@0B3`l04a0@00l=
300>3@`051<D01dL700C4Q<03@`=01<B4P0C4Q<04a8B018A4@0B4A800P0E51@0100D51@051@E018C
500B4a@201@E5P0701@D5@0E5QL06ATJ01@E5P0A4A804a<D01<D5@02018D5`0>01@G6@0=3a<06A`O
00lB5@0X:Rh04A<H018D600H6Ql05ALM018E6P0G6al051PL03Xn@P0E6Ad201HJ7P0701XN8P0b=SX0
E5QL01<G6`1OHfL0<cPl01HK7`0301LL800501HK7`0G720092T]07^0Q00i?T800P0F6al0F@0J7b80
7B4S01`P8P0L828061`N01HK7P0I7R406alS01@H700F6Qh06QhR03Tm@P0V:Rl06B0S01TM8@0J82@0
61hR01XO8`0M8BD06R4T020U:@0R9R/06b4U01HK7`0G71l05QXM01XN8P0O8bL03Q8F01/O8`0G71l0
6alS01HK7P0I7B805ATN01HJ7`0F6Ad04A<G01LJ7@0N82@04QDH01HH700D5aX05aXM024T9`0I71l0
71lR01LI7@0L7B406QXM01XJ7P0D51T05ADH01PH6`0H6A`05aPJ01HG6@0G61P06AXK01XK7@0G61d0
61XP01@E700E5Ql071dV05AEGP0V:3807b4Z01PJ8P0L7R@05aTO05=EFP1jOH00@DA501TM7P0?4A<0
5aTK01/K7@0G5aT061PJ01DD5P0G5QT051<F01HE600C4a@04a@E018C500C51D05QHG008051@E0300
71dN01XK700F5aP071dN024R8`0M7A/06Q/F02<T7@0o@CD0YZRJ0?ool@3Ce<D0CU1302@V6`0R8ad0
>CTg018D500E6A/04QLF024T8`0Q9B40=3Pb03Li<@0J71H06a`H01`L6@0I61T06aXN01/I7P0J61d0
1`H:01<B5P0I61`04a0C01TF6@0D41@05a8D018=400H4Q@05PlB01H@5@0?2a004@dC010=4P0C4AD0
5aDK00d:400B3a<2014?500;01@B5P0E4aP040`@01D?4@0D3Q003`T;010:300C3@l05@lA00l92`0@
2P`00`0B30h05@0>20T04@/<010:2`0@2P/04P`=01H@4@0@2P/04`d>00h82@0A30`03`T:00H10@0E
30h03@@601472P0E2`l02`8501@93`0@1@X04@H;01872`020147200D01061P0C20d0:b0W01883P0E
2Q4040D<01873P0>0`X04@H=01873P0=0PT030880105300E2Q003`@:00d3200B1`d04`P>00h42@0A
1P`201052`<03`@:00P040D<00l42`0>0`T03`@;00l42@0>0`P03`@900l420@03P<700`03`<800l3
2@0?0`P03`<:00l32@0?0`P03P@:01042`0>0`L05@TA01052`0?0`PDooooo`006oooool04P074QP0
214F02Pb=00@61/03Q8D0414A@0A4a803`l<00d<200A3PT05a<>01XG400B3P/05aHB01hM6@0M71P0
4Q4=00d<20L03Pd901@030/7010?2`0<2`L05A@@02@S7`0R8Ad03Pd9014@300B4@d03`h:01<B3P0@
3`/051<?00`;1`0=30P05A@@01PG4`0@3`/03`h:00h=2@803`h:00@040l;018>2`0C3``04Ph;0P0@
30T0800A3@X06QHC00T50P0W8b004Ph;01DA3P0E4Ph04a8=01DD3`0>3@P03@`700h=20071P@00`80
00`;1P0B4@`04A0;010?2P0<30L03Pl9010A2`0<3@L05AH@01/L5P0<3@P04a@>00T:100720D061TC
0083000;2`H03@`80P0<2`L200/:1P0C00d<200>3@T03@`800d<200>3@T03`h:018E40001@0030h9
01DD400K6QH05A0=018=2P0@30T03@d900d>2@0=3`X03A8<00P:1@0200P9100=024R7@0R8ah030d8
00h?2P0A4Pd03Pl:010A300:2`H06a`G01HE4@0E51004A0<00h=2@0200d<200600l>2P0@3`/04A0<
010?2`0A40`040l;0`0?3P`200h=2`0300d<2P0>3@/03Pd;00<03Pd;01D03@d;01PJ6@0A5A@02@d<
00L;2P0830/02`l>0001000N8R4010P70045100@51<020X900P81P0/;2X01`L500l?3@0=3@/051@B
00l?3@0<30X00P0>3P`03`0<30X040l=00l;200<20D03`/800`;1`0920@030d800d>2@0A4`h03A8<
00H<1P083`P03A8>00d<3@0200l=3P0300h<3@0=2``03P`=00803`d>01H03P`=00d;300>30d040h?
00`<30092@T04a<C00L71`0410@04Q8B00`<300;2`/03Ph>010@400?3`l04A4A01TG600H5QL03`d>
010>3`0C4A803@/<0P0>30d0300?3@h03P`=00h<3@0C4Pl02`X500H5000=30L051<>00D4000;2PD0
0`8000X9108030/600<04a8=00l>2`0=30X00P0<2`T0700=30X03Pd;00d<2P0=30X03`h<01@C4@0E
51804a8@00P81`071`D05QHD00L71@0H61H051<A00`;2@0=30X04@d<00h:2@0;1`H03`T900@0000=
2@H03`/800d91P0Q7AX05A4>01HB3`0D40d200l;200800H2000Q7AX04a0;014>2@0?30L03P/600l<
1`0B3`X2010=200<00l<1`0>2`H03@X500`9100@2`P05Q4>01@?300400004`h;010;2P0B3@X04@`9
0P0?2PL04P0B3@X05Q4>01hJ4@0S7a<06QL8048o<01bKeh0?c`[01hK300H50T04Pd7018=2P0C3@l0
4P`@01@>400C3@l04@/=010:30804@/=1@0?2@/01P0>2P/03@`:00l>2P0>3@T03@`800`;1`<03@`8
0P0>3@T06`0?3PX03`h<00l=3P0=2`h02`T<00`:3@0>30l03`d@01DC5P040PD02`T<014?4P0]:bh0
71XM02@T9000000030`<00L71`0:20T05Q@E01<A4P0E4A804Ph?01/G600L5QP04P`>010<3@0200l;
300:010<3@0>2P/030P900l;300=2@X040`=00l;300;1`P03@T:014?4`8040hC02403`dB00h<4@0?
3A805A<H00`:3`0?3A800@0400`:3`0g<C<03@P500d50`0C3P/02@D200`81`0>2``01`D800/:3`1D
EET0ZJZ^0452AP092@`03P`=00`:2`0;2@X030X;00h<3@0?3@h05A<D018@4@0:20T04@l@018@4@0>
2@/00P0A20/01P0B2@`04@P;00l92`0?2P`040`=014=3P803`d>00D03P`=018=4@0B31004P`@014;
3`02010:3P0C00@00P0E3a<05a4E01@>4P0J51P06aDI01HD5`0:20/030X=00h<3`0H5QT04@lB00l=
400200<02@L:01<A50091`X02`T<010>3`03014?4003010>3`0?3@h03@/<00804Q0A00<05aDF01lM
7P0B41400P0@3Pl01`0<2P/03P`=018@4@0=2``030X;00h<3@0A3a000P0B4140100A3a004a4B01DC
500D4Q<201<A4P0401@B4`0>30d040h?01<A4P80518C01@04a4B018>3`0D41409B4R02<O800B3Pl0
510A01XF5`0G4a@05Q8C014=3P0@30d06QPI02PX:00`<30061PH014A4@0J6QX04Q8B01DE5@804Q8B
00H04a<C018B4P0A4A403a0B00d>400>3a42014B500:00l@4P0B4aD04Q<E018C5@0@4A<04Q<E01<D
5P0F5a/05aPL01PI7@806AXN01<061TM01XK7`0E5QX051DI01LH700F5a/051DI01LJ7`0E61d071lT
01DH7@0A51T051LL00`?500D5a`061/P00<62`0Y;340720T008061dQ00h05AXN01PM8@0G720051TM
01TN8P0M8RH051TM014F6P0K82@092T/01HK7P0;41<041DH01PM80805a`O01X082DX010E600O92L0
;34d05EJG@0/<SD05QhQ01@L7`0I8B@05QhQ01LO8P0D71l04ATL01HN8@0J8RD05AdP01@L7`0S9Rd0
4aHM018E700:3A80=STn00L:3`0D61/05ATL01LK70<061`M00X03a<F02DY;00K7b802`lB018F6@0N
8RD06alR01`P8`0Z;S406QhQ0P0M8B@01P0C4aD05ADG01LG6@0E5AL04a<E014A4`@05QHH01`061PJ
01PI6`0?41@061`O01LK7P0F6Ah05APN00T<4`0M82L041<K00lB6`0A51d09RTb0823RP2e^[d0;cLf
01HL700:41003a@D01<G600C51H04a<E00h<3`0E4aH04Q0C01PF6@0B4Q@05AHH0P0C51H0E`0E5QP0
4A8D01LH6P0R8bD07AhP01@E5`0G61X06a`N01XJ700N7Q`0824K02`^8`1KGDl0VYf<08nAPP0/;R40
5QP=01`M6@0K6ad03@h@020R9@0H6QT06adH03<g:`2c]JL0_L2_05aOC`1CDdT0CTi601DD4P0B3A40
8R0U030^=00K6Ql04a8G01DD6@0F51L03`d@01@B5@0D414020@5010<3@0A2`d04PdB00h9400A31<0
5Q8I00T63@0B4AL0;Bdb010A5P0B5AX0=STn051EF@0G72004Q0D01H@4P0G4A<050h@010:300?2@/0
3PP:00X41P0?2@/04P`>01<=3`0F41803PP900h8200@2PX04@/;010:2P0>20P030H600T30`0;1@D0
4@/;01@>3P0C3@d03PL700h41@0H3Pl02@0000P0000D2P/03`D601061`0301882@0C01462@070080
;B8Z00d42P0C21002`0800h32`0@1@d02@0600X11`0I3QH07A8J01053@070080200301L<4P0A1P`0
6@hD00`21`0300h32@0400l42P0@1@/04PL=00l420803@8600<03`@801462P0@1@T01P0>0`L600l3
1`0400d11@0D20`02@0101@8308040@85?ooool001_ooooo01802A8G04UBEP3Dg=d0Ifia01DJ6`0:
3Ph0<C<a01hN6`0@3`/0514<01LC3@0B3`T03@X701DD400=30P071/G00l>2P0A40`700l>2P0C00`;
1`0@3`/040l;014@300H5a<04A0<00l>2P0B4@d03Pd900/:1P0A40`03`h:00X91@0>3@T092<O00d<
2@0>3@T03`h:010?2`02014@300500l>2P0>3@T03`h:010?2`0?3PX00P0=30P200h=2@0:00l>2P0;
2PH051<@00d<200?3PT010<002TX8`0920D040l:00d<1`804Q4<018040l:00l>2@0<2`H03@`701DE
3`0720<03Pl903Hg<@061`4051D?00h?2P0A4P`06Q/E00h?2@0B4`d01PL3010@2`0A40`3010?2`0=
00l>2P0>3@T03@`800d<200?3PX040l;014@300?40/0=S/e0822O@0H5a<04A0<010<2@0200l;2004
00d=200<3@P02`d800/@2P803a0;00d03Pl:02@U800T9B004Q<>00/<1`0A4Pd02P/6010A300D5A00
30d:01HE4@0C4Ph03`h:008030/70P0?3PX200h=2@0900l>2P0=30P03`h:00h=2`0?3P`04Q4?014@
3P0?3P`03@`:00D03`h<01D03Ph<00`=300;3@`02`d<00`>3@0>40l03a4@014C4P0f>3L051HE00H8
1`0B51<03a4@00h>3017AdD020P601TI5`092@L03@d;00h>300<30X00P0?3`d03`0<30X03`h<014=
300B3@`0510?014=300@3P`06ATG00d>300C5180418?00P;200:3PX04A<@010?400200h<3@803@/<
01<030X;00d;300@3Pl040h?00h<3@0=2``03P`=00l?3`0:2PX05ADE00d=3@0D51@01PH600L71`08
20P04A4A00X:2P0=3@d030`<00804@l@00@02PP900h<3@0B41403@/<0P0>30d04P0?3@h03P`=00h<
3@0;2PP03Pd9014@300920D051<?00T81P0?3P/040l;00h=2@0=30P03Pd900d<200=30T03Pd;00d<
2P8030/902803@`:00l>300?3P`03Pd;010?3@0B4@l04A0>010?3@061PD0;Bd[01LG5@0?3`d040l=
00/:200=30X040`;00l;2P0=2@P03`T9018>300:1P@04Ph<02/W901FDTl05A4?00d91P0=2@P04@d:
01dI5P0H514030P601DA3P0D40d04@d:0P0?2`P0100A3@X030P500d91P0>2PL2010<2@0O018>2`0L
61L01P8201<?3P0=2@P03`/;014=300F4Q405A4@018>3@0@30/04@d<01@@3@0C40L05A<701/I2`0O
7@l081h@01lM3`0C4@<04Pl501<@2`0D40h04`lA010;3`0A3@h04Ph?014=3P0@30d03PX;00`82@06
00l;300:00l>300<2`T030/900h=2`0@3`d03Pd;00`;2@0=30X03Pd;00l>30804A0>01/03`d?00d;
3P0;2@`030X=00h<3`0?3A0040hA00L5200=2`h040hA01hL7`0@3Q404A4A00P820071`L04Q8B00P6
1`0A3a005aDF01@@4@0>2P/040`=014;3@0:10H03`/<018>3`0A3@h00P0>2P/03P0?2``040`=01<?
400G4a@04Ph?00h:2`0A3@h040hA00d;3P0<2Pd03@/>00l=400>30l04Q0C0P0?3A0060050`H05aDH
030^;`0<2PP02PD601DB4@0F4a<0514B00`:2`071@H040lA00h>3`0T92D03@`>00d;300>30d030X;
00/92P0<2P/03P`=00/92P0=2``03P`=00/92P804@l@00@03`X;01482`0A20/04@X<0P0?2@/00`0?
2P/040`=014=3P0200l=3P0400h<3@0C3Q804PdA018=4@803`X>00X03PT=00l:3P0C3Q802PD901<>
4P0A31003PT=010>4@0<2Pd0:bT/0P0?3A001`0>30l04Q0C010>4@0T8RD04Q0C00`:3@0?3A000P0@
3Pl2014?4007010>3`0?3@h03@/<00l=3P0=2``040h?01LE5P02014?4007018@4@0=2``03`d>01@B
4`0?3@h03P`=014?400201DC500501<A4P0A3a005Q@E01<A4P0B41400P0C4A800`0?3@h03P`=014?
400201DC500E01<A4P0A3a00518C014?400T8R<08R0Q010>3`0G5AH04a4B018@4@0H5QL04@l@01LE
5P0k>CX092@T028R8P0B4Q80410@01@D500>3Ph051@D00804Q8B00P051@D01<C4`0B4Q8051DG018C
5@0C51H05QLI01DF608051DG00H04Q<E01@E5`0F5aT051DG014B500D5AT301DF6P0H01@E6@0C51P0
7AhR01HG6`0C51P051DI01HG6`0G61d07R4X020S:P0?4QT05aXQ01/N9@0E61l04aHM018E700L7bH0
4aHM01XM900G6b4061dQ01LL800D6Ad061dQ0P0J7b<05`0M8RH0724U01LL800H7B408RL[02@Y;00K
82<082DX01PM800E6Qd07B8U01LL7`0T:B`05AXM01`Q900F6ah08bP[01TP8`0G7b80620S01dU:00L
92L06R8U00804a/N0P0H82<00`0G7b8072@W01LJ8@0201/N9@0501XM8P0f>Ch08RDZ01DI700F6Qd0
0P0G6a`201HJ6`0E024U:00D61/0720S05aPH`0`=3L05a/N01XN8@0G6ah06QhQ018F6@0E6A`061`O
01PH6P0I6A/071`N01lO8@0L71h051@F018B500D51H05aLI008061PJ01/05aPJ01LH700F6Qd05ATL
01DH7@0F6Ah05APM01PK8P0B5A`06ahU01PK900B5Ah05QTP02X^<@0@4a@051PI01HI6P0A4a@06AXL
01DF600A4Q@061PJ02<S9@0F5aT06ATK018C5@0F5aT00P0D5AL0>P0F5aT04Q<E01HG6@0L7Al061TK
01LH6P0F5aT051DG01/J7`0I6AX06a`H024R6P0R91L0;BlR03Hh:P0J71805QL@020P800F5QT071dQ
01`O8@0H6QT092HQ06Y]I03cmNP0oooc09>EQ`0Q8AL0:2LR01`K6@0K5QX061HK02h/<P0R8BH04Q4F
014@5@0F51L03P`?02XX:`0R7Ql0510A01DA4P0C3@l050hC01D@5P0A31805A8G00<11P0M7240IfI[
01<D60092Ph0LWIi0=3De`0n@TD04@lB010:300?2@/3010:3007018<3P0?2@/050h@014;3@0?2@/0
5a4C018<3@0600l92@804P`<00/03@L700l92@0@2PX040T901@<300@1`L060h?01@:2`0@1PL03`D6
01061`0301882@0C01882P0<0`L05P/A01<83P0E2Q003P<901873@0D2@l03`@:01<83P0R5ad091TO
01D:400H3A<0308701<93P0=10P0@SLm01lD6P0201052`<03`@:00L040D;01052@0>0`L03P<70105
2@0C20`04PL;00H03P<71P0?0`L01P0>10H04@H901<82`0>10H0714D00d31ACooooo000Kooooo`0?
00@<3`0g?d80UibO03m4A`0@5AD061XI01LG5@0?3``02@P400`9100?30L040d801XI5@0_;RX020L3
00<040l;1`0?3PX00`0<2`L03`h:018A3@02010?2`803`h:00`051<?01HE4@0B4@d04A0<01<B3P08
1`<061LC03Th=00@3`/030/700h=2@0@3`/2014@300700h=2@0=30P03Pd900l>2P0>3@T030/700/:
1P0200d<200B018A3@061@4030/700P70`0^;BP09RDP059AC00F5A0030/600P70P0F5A0040l:00P7
0P0?3PT040l:00/:1@092@@02``60P0>3`T03@0<3@L05QLA07amM`0U9R001PL100h?2@0@4@/05AH@
00/;1P0=30P03Pd900l>2P0>3@T00`0=30P02P0>3@T040l;014@300A40`05aPC00X?2@0e=c8030/7
00H50@0:1P<2010<2@0D00h>2@0=3PT030h900T>200;30L04Q<>00X;1P092PD01@H100P9100A4Pd0
2``7018C3P051P405aPC00d>2@0920@02PT500`;1`0=30P200h=2@0;00`;1`0;2PH04Q4=01DD400>
3@T030/700`;2@0>3@/04A0>018A3`0?3P`01P0=30X00`0<30X02`/;00`>3@0200h@3`0@00d?3P0;
3@`03a4@00d?3P092`X03a4@00`>3@0E5aH00@4001HF50061P@030`:00/;2@0=3@/03`l=00h>3080
4Q8@01P03Ph<010?3@0=2@P03`T9018<300?2@T040`;01XI5`0?3P`03@`:00`<2P0=3@/030`:00X:
200>30d030X;00d;300?3@h02`T:00P61`0=2``040h?014?400>30d200d;300B00T92@0;2`/03`l?
00d=3@0B4Q802`/;00d=3@0820P03Ph>014A4@0@41002PX:00/92P0>30d02@L8010>3`0G5AH04a4B
0P0>30d04`0?3@h03P`=00h<3@0?3P`05A@@00L60P0@3`/03@`801/J5P0920D0O7]g079aK@0B4@d0
4a8>00L60P0@3``03Pd;00d<2P0<2`T00P0=30X0100?3P`03@`:00X91`0;2PP200`;2@0G00h>301I
FEL0k^k/03lo?@0000000`8000l>300<2`T03@T800h:2@0?2`X03`T901DA3P0;1`@00`0001DA3P0<
20D02`L400l;200G4a004@d:00T50P0G4a000`0@30T300l;2004010<2@0=2@H03@T600l;208040`9
00X04@d:010<2`0;1`H0I61O02TU900H51<05a<B01HB4@0E4A004Ph=0P0?2`X03`0?2`T04a0900l=
0@0C4@D061H:01XH300M6`l05186014>1P0?30L040`;014<3`0?2Ph03@T:00l;3002014=3P0300l;
300=2@X03`/<00D03`/<00D040l=00`;2@0<2`T040l=014@3P0700h=2`0F00l=400=2`h02`T<00`:
3@0>30l03`d@00/9300:20/03P`?00l=400B41<02@L:00T92@0G5aL0410@01<C4`0@3Pl0518C00`:
2`0=2@X030P901DA4P8071HH00<03PX;018>3`0A3@h00P0>2P/02`0A3@h030P9014=3P0E4A803`/<
00`82@0@30d05Q@G018@4`0?3A003P`?00803`d@01L06QPK01DC5P0:20/04@lB00L520091`X02`/;
00/9300a<3805aDF0040000A3a000@0000L51P0?3@`04a8@00`82@081`L03P`=00`:2`0;2@X030X;
00h<3@0200d;300:00l=3P0>30d040h?00h<3@0?2P/04`X=014;3@0B30h04@/=010<3@804@d>00@0
3@/<00`:2`0=2``03`h?0P0B3A400`0A310040/?00l:3P0200h93@0A010;3`0H4aL00`0201<>4P0R
7B4040hA01<A500o?D005Q@G00l=400A3a802`T<014?4P0U8bH030X=00l=400=2`h00P0?3@h3014?
400=010>3`0E4a@0518C010>3`0?3@h04Q0A010>3`0C4A804Q0A00d;300>30d04@l@00/92P0201@B
4`0501<A4P0D4Q<05A<D01DC500@3Pl00P0=2``01@0A3a004Q0A00h<3@0D4Q<04a4B008040h?00L0
4Q0A01<A4P0D4Q<0518C00`:2`0:20T04a4B00805Q@E00`02`T:01<A4P0C4A803@/<01HD5@0K6a/0
3@d=01DE5@0B4Q803Ph>01LG5`0A4A4200l?3`<04a<C00<04A8D00l@4P0@4A<00P0C51H0200A4Q@0
51DG018C5@0E5QP061TK01@E5`0@4A<05aPL0`0H6Ad201HG6`806AXN00H061TM01HG6`0E5QX05AHK
01DH800G6R<2010C700<01@G800E62406ahW01`O:00N8BX06QdV00lB6`0G6b4061dQ01LL800D6Ad0
6AhR100K82@04P0J7b<061dQ01HK7`0G7R403aLJ00dE600K8bH09Bd`02@/;`0G7b806b<V01@L7`0I
8B@04a/N01PP8`0I8B@05alR01`T9`808BT/00d0620S01@L7`0C6ah05AdP01XR9@0L92L051`O01HI
800Q92/06A`S01`O900K7R<041<H00805a/N00T05a/L01HJ6`0E6AX051PI020T9`093A0041@G051D
E`0;3a800P0G6ah00`0H71l05QXM01LK7P0201HJ7@0301/K7@0H61X05aLI00806ATK00@051@F014A
4`0D51H05aLI0P0I6A/0600G61X04A8F01<G6P0g>ch0>3`o01HJ7P0C5Q/06ahS02@W;@0<3aH08B@[
018E7@0F6B007QlS020Q8`0A4Q@05ADG018C5@0L7Al05aPJ014B500J7Ql0;2d_01`O80804a@F02L0
5aPJ01DF600E5QP05aPJ01<D5P0E5QP04a@F010A4`0G61X06a`N01LH700N7B<05aLI01LG5`0O81X0
:BXR02HX7@0R91X06Q/E01@E400I6AX030/A01LH7@0E61X08B<R02T[:00h>c80SHn20;bn/@15AcX0
8B4G02TX8`0C4A4061<G01`J7`0E4aX030/@01<B5`0E51T00P0D4QD04P0?3A003PX;00T51P0A3@h0
3`T;01<>4P0L5ad040/A00l;4@0=2a006QPM051?E012@DH06Q/O01PI7@0`<CD01@H:01<@4`805@lA
00X050h@00d72@0?2@/04`d?00`6200A2`d04`d?01`F600/9RP081XK0P0?2@T04`0>20P03`T900l9
2@0?2@T02P@400`61P0=1`L0208201TC4`12>SX06a4B01882@0=0`@0200001L=3P0D2P/04`T:0188
2@0@1PL00P0?1@H00`0E2Q00200301<83P0200`11`0@00l42P0;00H03@8801052`0=0PP02`0600`1
1`0>0`T081DK01873@1BAdd0l^O]06mTJP0B1`d04@H<01052`<03P<900<050T=01872`0?10P00P0@
1@T700h31`H03`<700H03@4500T00@0Q5AT0200003HZ;P0G2`lDooooo`006oooool04P0>4aL0314D
028X:0083Ph020/;01<E500A4@l04a<@01<B3P0E4Pd061D@01`I500:2@D09B@P00`;1`0>3@T04A0<
00d<20H040l;01803@`800/:1P0=30P03`h:00h=2@0=30P040l;00d<200@3`/05QDA018A3@0>3@T0
4Q4=00X91@0=30P04a8>00P70`0L6aL200l>2P8040l;00D03`h:00h=2@0>3@T03`h:00h=2@0200`;
1`0300d<200;2PL051<?008051<?01l01@@001LF4`030P009bHQ00d<1`0K6QD0;B`W04M6@@0a<2/0
4Q4<00L60@0:2@@04A0;01LG4P0<3@L03Pl901PI4`0?40X03Pl90:2QV`0c=2h01`P201<D3P0A4P`0
4Q<=00L7100>3@T03`h:014@300@3`/03`h:00803Pd901h03`h:014@300A40`04A0<01XK5P083@L0
3a0;00/<1`0E510061@A018>2`0A40`04A4<010A300>40/03@l:01<D3`0F5a803a0;01HG4P0C50l0
30d800X;1P0720<04a@?00H70P020`004A8=00`;1`0=30P200l>2P0=00h=2@0=30P03Pd900`;1`0F
5A406QTE014@300=30P030/900d<2P0?3P`040l=00l>300700d<2P0D00`<300=3`h03a4@00lA400>
40l030h=01DG5P0>40l0008100X<2`072@P0004000h>30071`D04A4?00X:200?3`d02`/9010@3P0?
3`d201<C4@0V00l?3@0A40h040`;010:2P0A2`/03PP800/61P0B3Pd03`h<00X91`0;2PP03`l=00d<
2P0920H030X;00T7200<2P/040h?00l=3P0<2P/03@/<010>3`0?3@h03P`=00d;300>30d0410@01DE
5@092@T00`<30000000D51@03`l?00X:2P030`<04A4A00`<300;2`/2018@4@0400`:2`0@3Pl05A<D
010>3`803P`=01003`d>00h<3@0>30d03`h=00h=2@061@403`h:0040000<2`L0:BPT0=gLf03Cd/h0
9RDQ01LF4P0:2@D02PT60`0<2`T06P0=30X03Pd;00h=2`0:2@L02@P600`;2@0?3P`040l=00/;2@0I
6AL0Ph>101dM6`0E5A<03`h<00d<2P0;2PP030P700h:2@0@30/040X:00`81@0>2PL0510=02/W9006
0P002`L40P081040100?2`X02PH300h:1`0F4Pl200h:1`@03`/800d04`l<018>2`0A3@X03`/800h:
1`0=2@H00`0001LC4P1/J6L0=c<b03hj>@0k=cH040`;00803`/:014040`;014=300B3P`03P/401HC
2P0C40L040d401@A200F4`X05Q<<014>200=2@H03PX9010<3P0@2`l03PX;00l;300:010<3@803Pd;
00@03`h<010?3@0@3`d03@`:0P0?3P`200h=2`0800d<2P0=2``03`d@00d;3P0;2@`030X=00h<3`0?
3A0200X82`0600d;3P0@3Q403`d@00`:3@061PH04A4A0P0820P02@0S8B802@L800/92P0>2P/03`/<
01DA4P0L5QP07QPJ00d92P02010<3@803`/<030040`=00/7200>2P/04Ph?00l;300<20T03`/<01@B
5@0A3a803P`?00d;3P0<2Pd020H900D31P0:20/040hA01<A500D4QD04a8D01@D5P0B4Q@061PJ01DE
5`0?3A005Q@E01<B400I5A@03@T800@0000A2`/04a0@00h<3@0<2P/02`T:00`:2`0>30d03@/<00/9
2P0>30d040h?014?400@3Pl04@`>01<:3@0B30h04`d?018<3P0@30d2018>3`0600l=3P0>30d03`d>
010@400?3A004@`@0`0@2`l05@0?2Ph05Q4E00<00P0>2@d040/?00/62P0?2Ph03`d@00D31P0K6A`0
30X=010>4@0:20/04a4D00400P0?3A005aDH010>4@0;2@`03P`=00l=3P03014?4007010>3`0B4140
4Q0A014?400@3Pl04a4B01@B4`02018@4@803@/<03T04@l@00`:2`0E4a@04a4B014?400B4140518C
01DC500?3@h03P`=00l=3P0A3a004a4B018@4@0D4Q<04@l@00h<3@0?3@h0518C01LE5P0>30d05aDF
00`:2`0:20T05A<D014?400F51D03P`=01@B4`0J61T04Q0A00P61`0K6a/03@d=01TI6@0D51@030`<
01LG5`0D51@04A4A010@400C4a<04Q8B014A4@0B4aD0414C014B500D5AL04a@F018C5@0D5AL04a@F
01@E5`0E5QP051DG018C5@0H6Ad00P0I6Qh0100J6al06AXN01PI7@0F5a/201/L800601PI7@0E5QX0
5AHK014D700C5Ql061/T0P0B5Ah0500H6b@07B0Y02@W<00P8b`08RD^01DH8@0K7bH06AhR01PM8@0F
6al06AhR01XO8`0N8bL082DY01`Q9@0N8bL08BHZ020U:@0M92L06b<V0P0C6ah03`0=5AP04a/N02/c
=P0E7B002A4D01@L7`0I8B@0620S01@L7`0F7R406R8U01dU:00N9RT05AdP01PP8`0201LO8P0M01`T
9`0O9bX051`O01`Q9`0I72<05QTP024T:@1gNWl0:bhc01@H6`0E6A`05a/L01PL7@0I7Ah061`M00/?
4P0T:2/09RX]02lc=P0K7b804QHI00hB5@0D61/041@G01@H6`0>4QD041@G01TJ700H61X00P0D51H2
01DE5`0P01@D5P0F5QP05aLI01PH6P0I6A/061TK020T9`0M8B@0?D5403a0@`0K7R8071lT02d`=@0f
>Cl02PdD01hQ:0082a<05aLO00d<4@0C4aD030`>01@D5P0I6Q`06a`N01LH6P0A5AH03Q8C01/O800F
6a/041@E01@E5`0H6A/201HG6@1401PI6`0D5AL061TK01@E5`0>3a405AHH01TJ700F5a/07A`R01XI
7P0L71h06AXF024R700L7AL07b0J01LH4`0B4Q005QDI01<B600H6Ah04ADG01LI600M7a`05aXB038d
:@1EEdX0;BlT01HF3P0J6A@08AlO01PC5`0:20d05Q@J00d<4@0I61d061LL018@4`0D4QD05A<F01LC
500D41406ADF018<3P0C3A006QDK01<>500B3Q@04@lD00`:3`0l>Sl0E5=H01DD6@0<3A405QLK01@E
6@0?3@l030H800l92`0H4Q@04@/=010:300E3a403@L900l92`0>20X05@lA028L7P0I4a@500l92@0@
010:2P0:10@030H6014;2`090`<06aDE06aTI00c:BX02@4100l51P0K4A8050`<01H<3@0E2``04PP9
00l51P803P@500@04`P<00L00P0@1@/02P050P0A1P`0300F2a404PL=00l42P0C20h05@X@01873@07
00804@H<00`11`0/8BL0TXN=040e>`<03P<900D03`@:01052`0B1`d050T=01872`0300l4200300`1
1@0>0`L03P<700@03P<71P0?0`L01P0;00<05P/>00T00@0C1`/0710D01P<41Cooooo000Kooooo`0B
01XN800?4a@04QHF018E5@0B51<03a4?00l?3@0>3P/03Pd900h=200?3@P03``7014@3@0>3@T05QDA
01<B3P0>3@T03`h:1P0@3`/02@0>3@T040l;00h=2@0?3PX04A0<018A3@0A40`03Pd900d<2002010?
2`0@00h=2@0?3PX03Pd9014@300?3PX0?chj06a[I`0A40`03`h:00h=2@0?3PX040l;014@300>3`X0
3a0;00h?2P8030d800P03@h901<D3`0A4Pd04A8=02HW8`0<3@P04A4<010?2P803`h900H02@P400h=
200C4Pd03@`700`;1P0B4@`200/:1@0?00h>2P0J6aD03Pl:00d>2@0:2`P03Pl901hO6@0;30H030d:
00h?2@0C50h02P/500h>2@0?3PX04A0<00804a8>01T04A0<010?2`0@3`/04A0<018A3@0A40`040l;
018C3P0:30T04a@?010A300>3`X03@d900h=2@0>3PT03a0;00h?2P0<3PT02``700X;1P0A4Pd02``7
00`=200:2`H03Pl:00803@h900T051D@05QIE00A4Pd03@h9010?2`0?3PX03@`800`;1`0=30P00P0?
3PX00`0:2@D04Q4=01HE4@0200d<200400/:200<2`T030/900`;2@803Pd;1P0?3P`00`0<30`03@d=
00h>3P0200l?3`0900h>3P0<30`02PX:00T92@0B4Q8030`<01<C4`0>3P`030`:00803`l=00@03Ph<
00/;2@0>3P`03Ph<0P0C4a402`0>3P`03`h<018>3`0?2P`04@`>018<3P0=2@X03PX;014=3P0B3Pl0
4@d>008040`=00L03``=01XH6@0=2``02PP900h<3@0?3@h03P`=00803`d>01003P`=00`:2`0>30d0
4@l@00X:2P0820P03Ph>04A4A00F5QH0=SHf028R8P0S8b<00P82010@40030`<0410@0P0G5AH0100>
30d040h?018@4@0=2``200h<3@0?00l=3P0>30d03P`=00h<300920H03Pd;00l>301XIfD05A@B014@
3P1=C4X0E5=A01<B400=30X040l=00<02`X800@03@`:00l>300A40h03`h<0P0;2PP06`0=30X03`h<
00h=2`0=3@/03`l=00`<2`0=3@/02PX800L6100>3@/02`X800/71P0?2`X04@d<010:2P0B3P/03PX7
00`91P0:1P<06QHC00h:200B3P/05a<@00h:1`0:1P<05A4>00h:1`0301<?3P06014=300?2`X03PX9
014=300@30/04@d<0`0@30/01P0B41401`D6018@4@050`@07A/L04Q6A`<03P`=01403`d>010>3`0@
3`h030/600`<1P0A4@X051<=010@2P0=30H04A0<00h=2P0>30`03`d>010>400?3A004Q0A014?4003
00h<3@0300l=3P0>30d03P`=00@03P`=00D02`T:014?400D4Q<04@l@00d;300200`:2`0300d;300>
30d03`d>008040h?00D03`d@00d;3P0;2@`030X=00h<3`0200l=400<00h<3`0=2`h03`d@00/9300>
30l03`l?01<C4`092@T092@T07AbL`0E4a@03P`=0`0@30d03P0C3@l05Q0B00h:2`0=2@X03`/<018>
3`0@30d03PX;00l;300<20T04@d>01<?400@30d04@d>0`0>30d06@0=2``02`T:00l=3P0<2P/03@/<
00h<3@0?3@h05A<D00l@4`051`/03a0D05QIG@0j>ch020H900X8200A3@d03PX8014;200@2@L04PX8
00l;2@0>30d030X;00/92P0<2P/00P0>30d200`:2`0400l=3P0>30d03P`=010<3@804@/=00T04Pd>
010<3@0@30d03P/<00l=3P0D4a<051@D018B4P0=3@d00P0=2`h200h<3`0F00l=400@3Q406QPK06]Y
K00f=3L03@/>01<A500=2`h03`d@00X82`0@3Q404@lB01LE600>30l03@/>00h<3`0@3Q404@lB00/9
300@3Q403P`=00l=3P@04@l@0P0>30d3010>3`0901<A4P0?3@h04@l@00h<3@0@3Pl05Q@E01<A4P0>
30d040h?00804@l@00D03`d>00d;300@3Pl04a4B018@4@0200l=3P04014?400E4a@0518C018@4@<0
4@l@0P0A4A401P0C4a<04Q8B010@400C4a<0410@01LG5`804a<C00`05aLG00h>3P0C4a<04Q8B00l?
3`0A4A40410@00d=3@0C4a<04Q8B01<C4`0H61P201TI6@0?018C5@0@4A<04A8D01@E5`0C51H04Q<E
01@E5`0E5QP04a@F014B500C51H05QLI01HG6`0G61`061TM00<06AXN00<05AHJ01XK7`0K72000P0H
6Ad04P0I6b0061`V01/O:P0N8Rd082@_01/O:P0I7BP04ADP01hR;@0G6bH092Pc01HJ9@0G72<06QlS
01/P900H7B406AhR01PM8@805a`P00H05Q/O01hS9`0T:Bd07b@X01LN8@0V;S4201TQ900J024Y;01B
FUd0O8B701dU:00L92L06b<V01XR9@0O9bX06b<V01`T9`0I8B@05AdP01/S9P0I8B@05AdP01TQ900F
7R405AdP01XR9@0H82<0724W01hS:@0E6R004AHJ03Xo@`0J7b<201LL7`806AlO0P0H7Qh03@0C5aX0
7R8U01LK7P0B5QT05a/N01TM800G6ah082@W01PL7`0L82<04aLJ01`P8`0F5a/00P0G61`2018C5`08
01@E6@0H6Ad05aPL01HG6`0G61`06AXN01XK7`0D61T201HJ6`0;01LK7P0F6Qd051PK01DH7@0K7R<0
4QDJ01DH7`0C5Qd061TN01XH7@0J5aX00P0J61/02P0M7Al04Q<E00/?400Q9BH051XJ014H600@61P0
4ALG01<G600I6Q`201HG6@0501TJ700E5QP051DG01HG6@0C51H00P0G61X07P0C51P05QLM01PI7P0U
9R/06Q`M01dO7@0G6AD06A/H01dN7`0N7b805AHK01/K8`0C51T04aLI01@F5@0C5A<071lJ01DF3`0M
7aD06a`E01/J5P0?3P/05A@D00l:3P0M6al04a4G01PG700D4aP04A0E01LE60805A<F0240510A018>
3`0E4A803PP:01HA500A3a804a4D01@B5@0>30l040hA01HD5`0C4A@01P@701LF6@0:2P`03`hA028O
8@0L5QP030H801<=3`0E3a404`d?01H@4P0>20X040X<014;3@0@2P`04@/=00/51P0>20P040X:018<
300@2PX00P0>20P02@0@2PX04P`<010:2P0>20P03`T901L?400E2``04PP901<92P020147200H01@:
2`0C2@X04@L800l51P0@1PL04@L800l4200<0@D040H900d21P0I3Q803P@701462P0@1@T040H900h3
1`0=0PH03@<600l62P0@1@/040H;00l52P0M4QP03`@:0P0@1@/300l42P0601052`0A1PX03`@800d2
1P0>0`L03`@81`0>0`L600l31`0301462@0>0PH03@<500803`D700<03@<5ooooooooool04_ooool0
01_ooooo00P0418A01TK6P082PL02`/9010@3P0?3`d04Q4?02@S7`8010<001X04Q4=01DD400A40`0
3Pd900d<200>3@T04Q4=01DD400@3`/03`h:00H50@0<2`L04a8>010?2`0:2@D030/7014@300@3`/0
51<?00d<200C4Ph05A@@01@C3`0>3@T02`X600d<20H03`h:00d04A0<010?2`0?3PX03`h:00h=2@0=
30P04A8=00d>2@0F5a801`P500P9100I6QD03a0;00802@X500D03Pl:00l@2`0D50l00@0000l>2@02
00h=200500@3000>3@P03`h900l>2@0<2`H00P0@3`X01`0:2PD04A8<00l@2P0@4@/03@h801<D3P0;
30H01@0<3@L01@0<30L03`h:00l>2P0;2PH03Pd9008040l;0P0>3@T04@0A40`03@`800d<200=30P0
4a@?01@E400720<020T401DF4@092PD03a0;00X;1P0=3PT01PL200`=200:2`H02@X500803@h900/0
2@X500h?2P0<3@P03Pl:018C3P0@4@`03Pl:00d>2@0>3@T02`X600`;1`02010?2`07018A3@0A40`0
40l;018A3@0F5A405A@@00h=2@0200l>308040l=00P03`h<00h=2`081`D05aHD04A3@@0[:RP02PT8
010?3@802`/;00H0000000X:2P0@410020P800l?3`0<30`200T92@0300`<300?3`l030`:008030`:
00d03@d;00l?3@0?3`d02`/900l?3@0820H01@D300`<2P0A4@l01P@500`92P0F51D00`0000804@d>
00P040`=01DA4P0?2``03PX;01HB4`0810D040h?00h<3@<03@/<00l03P`=010>3`0P7Ql061HG014?
400C4A803`d>018B4P0G5aL03@d=07inOP0J6QX07AdM01<C4`0>3Ph00P0:2PX03P0<30`03@d=00X8
2@0=2``030X;010>3`0;2@X04@l@00T7200?3@h040h?00h<3@0<2P/03@`;0P0?3P`02@0A40h04Q4?
00h=2`0?3P`01`H400H50`0G5Q@020L500h=2`0600d<2P0700`;2@0;2PP03@`:00l>300>3@/03@`:
00`;2@0200P81P1300`<2P0?3`d030/900`;2@0>3@/040`;018>3@0A3@`03`T900L3000=2@H04`l<
00`81@091@803@T600l;200@30T04@d:00h:1`0=2@H03`/801LC4P0>2PT04@d<01@@3`0<20L04Ph=
01XF5@0@30/04Ph=00`81`0;1`H03PX900T7200@3Pl03@/<01DC500<2P/0?C/l01<A4P0I5aP03@/<
01DC500;2@X03@/;00d<200D4`l05A@@00d<200;2PP04A0>00T7200?3@h06aTJ010>3`091`P04@l@
05mMGP0B41406QPI01TG600>30d03`d>018@4@0@3Pl03P`=00d;300200`:2`0600h<3@0<2P/02@L8
014?400E4a@01P@50P0<2P/02P0200406QPI00`:2`0R82403P`?00l=400>30l03@/>00h<3`0@3Q42
00h<3`0800`:3@0>30l03@/>00P62@0?3`l04A4A01HF5P0C4a<200d;300900`:2`0B3Pl04@d>00`8
2@0=1`T03`T;00/7200=2@X03PX;00<040`=1P0=2@X01P0>30d040h?00h<3@0@3Pl03`d>00`:2`D0
3P`=00d03@d@00T<4@0L7B40<C8f01hO8`0B41<03P/<00d9200F4@h0614?00T1000=1@804`h<00D0
3P`=01l02`T:01@B4`0C4A806aTJ00T720081PL030T:00`82@0B3Pl03PX;010<3@0D4Q<03P`=010>
3`0?3`l03@d=00840`0D5AD05aDH00400P0?3A002`T<00400P0E4aH07adP0:f[[P1;BD`02@L:00l=
400B41<04a4D008040hA01P02@L:01LE600Y9bX04a4D00400P0?3A007Q`O00H41`0=2`h05A<D00/9
2P0?3@h04Q0A01TG600B414061HG00/92P0=2``05aDF01@B4`0J61T01@<4018@4@0?3@h201LE5P03
01@B4`0B41404a4B00804a4B0P0D4Q<01@0C4A804@l@018@4@0E4a@05Q@E00804Q0A01@05A<D00d;
300?3@h05Q@E00l=3P0D51@061PH01<C4`0=3@d03Ph>01PH600?3`l07AdM01@D500C4a<0410@01HF
5P0I6AT061PH00/;2`80410@00L04A4A01hN7P0410@07QhN018B4P0[:b/03`l?00H051DG00L092DW
03<d=P0I6Q`06Q/M01HG6@0E5QP061TM00804a@H01H05aPL01@E6@0@4AD07QlS01@E6@0M7R804a@H
01HG6`0L7b@05Q`U02L^>01MI6h0QhjH02H]=`0J8B/02Q4K01PO:@0R:C<04QTS00T@6P0A5ah07R<W
0P0I7R801P0O92P0:Bhb01TN8P0P9BT092T]020U:@808BHZ01P06b4V01HO900D7B805b0U01`U:P0N
9b`08R/`01hW;00H8BH06b@Y01hW;00K92T07BDY01TQ900C6ah05alR01TQ900H82<05QhQ01/S9P0I
8B@05alR01/S9P0L92L201PO9@0?01@K8@0E7B0072@W01@L7`0K8bD05AdO01DN7@0G81l04a`K018I
6@0E6A`05a/N01XN8@0K7b806AdP00<05QXM01807B4T01`P8`0D61/04QHI01PI7P0J6b005QLL01<D
6@0H6Ah05AHK00h?500N7b@05aPM01<D6@0G61d07QlS01HJ6`0F6QX201DI6P0:01@H6P0D61/04ADH
01LK7`0E61d03a8G01PK800=3Q<07A/P01/H6`8061HI00T05ADG014B500G6a`07b@U02X`<00F7ah0
3QLF010F5P0E6AX00P0F5aT02P0G61X06AXL01TJ700L7Al04a@F01PI6`0J6ad04A8D010A5@0L7B<2
01TJ7`0F01`M800L7Al06adL01PI6`0F5aT061TM01/L8@0D51`03PlD01DI6`0F61L051HE018D400F
5a8061TC01<D3`0J6AD05QDC00l=3P0G4QH07Q`O01@B6@805A@I02L04a8G018@4`0C4A@05A<F01LC
500E4A804`l@01D?4@0F4Q@04Q0C00l=400=2`h03P`?014?4P0B3a802`H:01`G6`0c;S802`T<00H1
1@0J5AP050h@010:300C3@l05@lA018<3P0?2@/04`d?01H@4P0C3@l03PP:00d72@0?2@X05a4A00X4
100D3Ph0100001@>3P0A2`/00P0>20P03`0=1`L03PP800h8200B2P/04@L800l51P0D2P/05@/<00h4
1@0=0`@04PP900l61`0N51D03P@501D;300201052@804@H:02004PL;01<8300>0`L040D900h31`0E
2Ph040D900l4200?10X03@8800`11`0A1P`060dC02<H7P0A1P`040D;00h32@0=0PP03P<90146300F
2`l02P0301L<400>0`L040D900l4200F2`l0304501H;3`0J3a<03`@800d21P803`<70P0@10P20145
2@060104200?0`L03P8600h21P0?0`L040@85?ooool001_ooooo00<02@T900X;200?3`d00P0>3P`0
1`0A4@l0<S4]04E4@00Q81`051<?00`;200100000P0=30P01@0>3@T03`h:014@300A40`02`X600<0
4a8>00`030/700@3000@3`/03Pd9010?2`0=30P04A0<00/:1P081`<01`H200T8100<2`L2010?2`H0
3`h:00@040l;00l>2P0?3PX03`h:0P0>3@T04P082@D010D002HW8P0E5Q408B8M00P910092PD03@h9
00h?2P0<3@P03a0;01<C3P0510005A@?00l>2@0K6QD051<>014@2`8040l:00T03@`700l>2@0?3PT0
3`l900X;1@0310001PL100d>20082@<01P0=3PP07P0=3@P04Q4=01@C3`0@3`/04A0<01<B3P0B4@d0
3@`800`;1`0@3`/03Pd900l>2P0C4Ph03Pd900l?2P0B4`h03Q0;018D3`0C5A00418=00`=2P0H6A@0
5QLB01@C3`0@4@`030d800d>2@0@4@`03Pl:010A30803@h9010030d800T:1@0A4Pd092DP014@300>
3@T030/700d<200<2`L02`X600D400061@4030/7018A3@0D4`l04A0<0P0<2`T200h=2`0@00d<2P0<
2`T05QDC00/:200J6AL02`X800L6100K6QP02PX:00h>3P0G5aL0410@00X:2P0D51@03`l?00h>3P80
30`<00@03Ph>00l?3`0=3@/03@d;0P0<30X200h>300?00L71@0<30X05aLE01@D4P0820H030`:01@D
500E5AD04a<C00L51P0H5QL01@<400l;300<20T03PX;00805Q8C00<020@5010>3`0>30d00`0=2``0
4`0>30d04a4B01hL7@0E4a@03`d>010>3`0<2P/030`<010@400Y:BT04A4A01TI6@051@D03@d=00X:
2P092@T02PX:00h>3P0?3`l00P0D4Q<05P0@3Pl04@l@00T7200>30d040h?014?400>30d030X;00d;
300=30/03`h<014@3P0@3`d04a8@01LF500B4@l061LE01/J60071PD03@`:01hM6`0B4@l400h=2`0?
00l>300=30X030/900d<2P0?3P`03Pd;00d<2P0?3P`03@d;00T91`0820H03@d;014@3P0C4Q004A0>
008040`;03404Ph=01<=3@0;1`@04@d:01LC400B3P/03`/8014=2P0?2`P040`9014=2P0>2PL03@T6
00l;200@30/03@T8014=300C3`h04@d<01dI601mNGP0<bl^00d9200I5A@03`/:00X61@0R82400@00
01HD5@010000518C00X92@0200404@l@018@4@091`P04@l@00h<3@0;2PP03`h<00<10P0:20T04Q0B
00X82`0@3Q404@lB00D31P0100803@/<00807A/L00D03`d>00L51P010000518C00L51P0500h<3@0=
00d;300D4Q<04Q0A010>3`0G5AH06QPI00d;30050`@03@/<00l=3P0;2@X04@l@03Hd=@0200h<3`07
00d;3P0<2Pd03P`?00l=400;2@`030X=00X82`0200h<3`0800T72P0>3Ph03`l?01@D500B4Q803P`=
00l=3P0=2``2014=3P0600l;300>20X03`T;00`82@0=2@X03PX;200?2``01`0>2P/02PP900/92P0:
20T03@/<00h<3@0=2``01@0>30d03@0>3a403PlC00/<400C51P03`lA00/9300C41403PX901D?3`0J
5A804`h;01H>300C3`d01@0>30d0?P0@3Pl02`T:00/92P0:20T04@l@01<A4P0A3Pl04Ph?01@@4@07
0`@06ADF01TG60081PL03`l?03Hf=P0C5A@05QPG00/=30092@/061HI01@B5@0b<3<05aDH00/9300B
41<04a4D01HD5`0E4aH01@<6010>4@0<2Pd01`D800l=400>30l0518E01TG6P0@3Q405Q@G010>4@02
00<02@L:01HD5`0?3@h081hO01@B4`0J61T03P`=04U7B00X9RL06aTJ01DC500G5AH040h?018@4@0K
6AX06ALH00/92P0C4A805A<D018@4@0@3Pl04Q0A0`0C4A806P0B41404@l@018@4@0E4a@061HG01HD
5@0@3Pl0;B//01/I6P0E4a@061HG01@B4`0=2``05ADE01hN7P0O7al061PH00l?3`0;2`/07QhN01PH
600@410061PH010@400:2PX04Q8B0P0P82002@0C4a<051@D01TI6@0G5aL07QhN01LG5`0>3Ph0820P
010@400601@E5`0701hO8@0Z:bd05aPJ01XK7@0F5aT05aPJ01LH700301TJ7P0Q01XK7`0L7B405AHJ
01<D600L7B405aPL01`M8@0M82D07b@^01DL9P2^]K`0dm[T03a3C@0D6bD09B`f02<Z=00B6B<0<CQ2
030g@@0G7B@0;c@h020U:@0F6al0724U02/`=00M8RH082DY028W:`0O92P08BHZ028W:`0N9RX072DZ
00806B8W00<06R<X01/T:@0K92T00P0J8bP301`U:P0301hV:P0K8bH05alR00806b<V01T06R8U01TQ
900I8B@06R8U01/S9P0M9BP08BT/00lF700I82H06R4W01PP8`0D71l06b<V020X:P0L92H06R<R01LP
7`0D7A`06R<R01/O8P0L82<07B4T01`P8`0I7B0051PK00807B4T0180720S01hR9@0O8bH07R8U01DF
6`0G61d04a@I014B5`0D5AX04Q<H01/L8@0<3A80:R/`00D62`0J6b004Q<G01PL7@0H71`201LK7009
01LK7@0F6Qd04aLJ01PK7`0G6Ql04aHK024T:@0K72005Q@I00805Q@G00/05aDH01LH6P0I6Q`04QHG
02T];P1cNGT02a4A028Z:@0B61P05a/L01PI6`0301LH6P0S01PI6`0W:2X05aPJ01<D5P0G61X06AXL
01dN8P0J6b0061TN01LH7@0I6Qh061TK01LH6P0L7Al06Q/O01`M8@0O82D061TN018C600E6AX05QPG
01@F5@0B51405QHD01PI500G61<06QTG01HE4`0?3@h050lC01PF6@0E4aT051<H01<B5`0B4AH00P0C
4A@06`0?3A004`l@01@@4@0E4A806Q@F01XG6@0F51L04a4D00l=400=2`h03P`?01HB5P0@2`l02PD9
01@?4`0@2`l03`X>01H@4`0C3@l03`T;014;3@0D3Q004@/=00l92`0B30h05@lA01<=3`0200h82P07
00h82@0@2PX01000014;2`090`<05Q0@014;2`0200h8200500d71`0>20P03PP801082@0@1PL00P0A
1`P0200@1PL03P@500L0000O5AH03P@50147200:00404@L80P0?10P301462P0>01052@0D2@d04`P<
01872`0?10P03P<700d21P0?10X03P<900`11`0?10X050T?01/@5P0@1@/200l42P0?00h32@0?10X0
40D;00X00`0700002P4301L<400C20`01`0001T>4P0@1@T06@hB01dB5P0C20`04@H:00804PH:00H0
4@D90104200@10P03`<70104200?0`L200h21P0300l31`0@10Sooooo01?ooooo000Kooooo`0?01TH
5@0?3`X092<O01@C3`0C4Ph03`h:00<2000G5Q802PT500h=2@0D4`l05QDA00/:1P0>3@T03`h:0080
40l;01<03`h:014@300A40`030/700h=2@0C4Ph051<?00l>2P0=30P040l;00d<200B4@d030/7028Q
7@0@3`/030/7014@300D4`l030/700H03`h:00<03Pd900l>2P0?3PX00P0@3`/05P0@40`04Q@?03Xl
=`33aL00DE=>01@F4@0E5a803a4<010B3@0<3PT0418=02`^:@0W9b8030/601DD3`0:2@@05QD@01@C
3P0<2`H04Q4<014@2`0>3@P200l>2@07010@2P0<3@P0414;00h?2@0V9b400@80010A2`0500h?2@09
00/;1P0>3@T04A0<014@300D4`l04a8>010?2`0<2`L02`X600803`h:00l04A0<01LD4@0A3`/03Ph9
00`=20092`H0310;00X?2@0C61802`d800X:200:2@D04a4=00d=2@0:2`H00P0>3`X00`0;30L03@h9
00`=200200h?2P0C00`=200B4`h09RLR018A3@0A40`03Pd900d<200?3PX03@`801DD400G5Q806APD
01@C3`0?3PX03Pd900/:200<2`T03Pd;00l>3003010?3@0300/:2@0@3`d03Pd;00804A0>00H0IVAU
01<A4P0@3Pl05A<D01`J6`0C4A8200l=3P8040h?0P0?3@h200l?3@0300d=2`0<30X03@d;00803@d;
01<03Ph<01/K6@0H61H02PX8010A3`0<3`l02`d?014D5@0<3Q002`/=01<C5@0=30l01PD800/9300<
2Pd02PP;01<A500@3Pl03P`=00<03@/<02003P`=01HD5@0F51D03`d>00h<3@0=2``020H700l?3`0C
4a<0E5AD00d=3@0E5AD03Ph>01<C4`0@41003`l?010@400B4Q804a<C01@B4`0C4A803`d>010>3`08
1PL03P`=014?400?3@h03@/<00l=3P0C4A805Q@E00l=3P802`T:00X030X;00d;300@3Pl02@L800`:
2`0A3a003`d>00X82@0B4A004A0>0`0?3P`0100@3`d03Pd;00d<2P0=30X300l>300P00`<2P0:2PP0
30`:018B400C4a404A0>01@C4@0F5A<04`l>018>3@0E4A006A<C00`81@0?2`P04Ph;010<2@0?2`P0
40`900l;200@30T04@d:00h:1`0=2@H03`/800h:2P0@30d03`/<00d92P0?2``06ADF01`I6@0>2P/2
010<3@0N01@@4@0@3@h04@lB01LG6@14A4H03@d?00T92`0>3Q004A4C00@41P0?3a404Q8D00l?4@0<
30d03@d=00X:2`0J6Ad02`/>010?500=3A802@P?018A5P0<2`l03Ph@014A4P0;2`/05aLG00P8200E
5AD04a<C0P0<30`0300:2PX03@d=00l?3`0@41003Ph>00`<300@3Q403@/>00`:3@0@3Q404Q0C00/9
30804a4D00P030X=00@21@0C4A@02@L:00l=400=2`h02`T<00d;3P803P`?01<03@/>00l=400>30l0
518E01HD5`0A3a80410@00h>3P0A4A403`l?00h<3@0A3a003`d>00h:2`0@30d04@d>010:300=1`T0
40`=00@03`/<00<03PX;010<3@0B3Pl00P0C3a002`0@30d03`/<00h=2`0?3P`030/900l>300C4Q00
4A0>010?3@0?3P`03Pd;00803@`:00d02PT:00`<3@0=30h03`l@014@4P0=2`d03@/<00L61@0:1`L0
40d<01<@3`0E41003P/<00D03P`=010030X;01<A4P17ADH07Q`M018@4@0<2P/04@h?018>3`0?2``0
4Pl@04I4A@13@D8040l@01@D502?T8l0@4910P0=3`h03@0<30h04A4C018B500O7b4061PJ00l?4@0B
4Q@04a<E00l?4@0=3@l05aLI02XZ;00V92L00P0>30l0800B41<03`d@00l=400<2`d05Q@G00d<3P0M
6ah05aDH00l=400H5QL020L701DC500610D02`T:020N7`0M6a`04a4B00h<3@0@3Pl03`d>01<A4P1G
EEH0>3Hg00l=3P0>30d04@l@01DC500=2``040h?01<A4P0D4Q<04Q0A0P0?3@h0200C4A805aDF01TG
600E4a@03`d>01dK700<2P/03`d>0P0F51D06@0H5aP03Ph>014C4P0H6QT071hM01dO7P0J71/07AlN
01@F5@0=3`h0418A01<E500`<S4092@T01@D500U9BD04a<C018B4P0A4A406a/K01PH600F5QH05aLG
010@400E5AD00P0D5AL301DF60805QLI02806a`N01HG6@0J6ad061TK01XK7@0J6al07QlS01`M8@0I
6Qh06Q/O01dN8P0G61`06Q/O01TJ7P0F5a/06a`P014D6@0W;C@09Rde0499D@1lPh/0<cY201`S:`0C
6R80:C0h07=jPP0P9bl06B0X020V;00_=3P08BHZ01/P900M8RH0:2da0P0O92P201`Q9@07024V:P0P
9BT07bL[024Z;`0O:2d06b@Y01TR9`0201XS:00601`U:P0N9b`07BH[01/T:@0L9BX07BDY0P0I8B@0
100L92L06R8U020X:`0R:Rd201PP8`0Y01/S9P0E7B006b<V01HM8`0M92X05A`R01dU:00>5QT05AdP
01<K7@0D71h06b@S01XS8P0E7Qd05b0O01PL7`0I7B006alR01XN8@0H71l05ATL01@H6`0I7B006alR
02<W:P0[;c806QhQ01LJ7`0I724061/P01DH7@0F6Ah051LL018E6P0J7B8061/P01DH7@0N8BH07R8U
01LK700G6aX00P0F6QT05P0F6QX05ATJ01PL7`0I7B0061`O01@G700Q92T071lR01/K7P0L7Al05aLI
018B500C4aD06AXL01@E5`0K7Al0:Bd^01TK7@0K7b00828T01TJ700H6A/401HG6@0J028S9@0H6A/0
5AHH01PI6`0I6Q`06a`N01LK7@0D61/05ATL01HJ7@0E6AX04aLH01PL7@0F6Qd061`O01XN800E6A`0
4ADG01DI600F61L051HE018D4`0F5QD061PF01HF5@0E4a@201<A4P0601HB4`0E4aH05Q@J018A5P0A
41D04Q4F0P0E4aH06@0@3Q40510A01@@4@0E4A806A<E01PE5P0C4a<04a4B014?400?3@h040`=00d9
2P0@30d05@lA018<3P0G4A<050d?00l92`0A2`d03`T;014;3@0C3@l04P`>010:300A2`d00P0B30h2
014;3@06018<3@0B30`02`D5014;2`0=1`L04@/;0`0>20P04@0=1`L03PP800h8200?1`L040H70188
2@0@1PL03`D601061`0I3a00AS`m024G600C2@X03`D601061`0A1`P04PP9008050X;00T04PP90106
1`0A1`P0308301D;3008000060h?01`B500?10X00P0>0`T200d2200300l42P0>0`T03`@:00804@H<
00h040D;00l42P0?1PP04PL;00l5200B1`/03P@701062@0B1`/0304501<8300E2Ph03P<700`21@80
50P<00H04PH:01452@0@10P03`<701452@0@10P200l31`030104200A1@Wooooo01?ooooo000Koooo
o`8040d801@06aPC00/80`0M6aH03`h901TH500H5a<02`X601<B3P0D4`l03@`8014@300?3PX03@`8
00h=2@0@3`/04a8>00`;1`0A40`04a8>00`;1`801PD100`02`X600d<200A40`03`h:018A3@0:2@D0
7ahJ00X91@071P8040l;01HE4@0=30P600l>2P803Pd900P03`h:010?2`0@3`/0414<00d?2P0;3@P0
AdU401`N6@802P`700l01@L3010B3@0B50l030h900H80`0:2`H02@P300/:1@0A40/03`h901DD3`0>
3@P04Q4<014@2`0>3@P00P0@3`X02@0C4`h03@h800/<1P0M7QP0HV=M028S7@0=3PP02``600`=1`03
00d>200V014A300A40`03`h:01HE4@0P7a/06QTE014@300>3@T03@`800l>2P0=30P03Pd900d;1`0A
3@X03`l;010A300G6A@03Q<=010E3`000P00:bdX05iMF@0E51001`@300X91@0@4@`06a`G01DF4@0<
3@P0414<00h?2P0=3PT03Pl:00d>2@0:2`H010D100h=2@0@3`/200d<200<018A3@0@3`/030/7010?
2`0C4Ph03`h:00d<200@3`/030/900d<2P0?3P`040l=0P0A40h0100=30X04a8@00T81P0920H200l>
300702HT9@081PL040h?00@20`0@3Pl00`4200`:2`0400h<3@0400`:2`0?3`d03`l=00d=2`<030`:
01@020P6014A3`0820H010@200/;2@092`P01@/;00`B4P0010@0318B00/?40062P/030l@00P92`0C
4aD06ATK00T92`0H61X040h?00h<3@<03@/<00@03P`=018@4@0>30d02`T:0P0?3@h02`0;2@X02PX:
01LG5`051@D0;Bd]00`<300410@0410@00d=3@0<30`02`/;008030`<0P0<2P/01@091`P03@/<00T7
200@3Pl02`T:00803@/<00P03`d>018@4@0;2PX02@L801@B4`0G5AH030X;00h<3@<04Q0A00H01`D6
01/I6P0100002PT8010?3@0>3@/200d<2P0500h=2`0?3P`03@`:00d<2P0>3@/00P0?3P`05@0?3`d0
3@d;014A3`0Q8Al08b<Q01DD4P0;2PP030/900`81`0=2@P03PX900h8200C3``04@d:00l;200@30T0
4Ph;01@@3@0>2PL03`/8010<2@0200h:1`0H010<2@0<20T02`L800d92P0C3a005a<D01PD5@0Q7Ah0
2PH701TE5P0M6AX02PH700/82@040PD03`lA010@4P0F5QP02PX<00l?4@0D51H061PJ028R900P8280
2`/=0P092@/06@0L6al01@@901/J800=31@04a8J01<A70081`h04A0E02<S9@0@414030`<00H61P0G
5aL03@d=00P8200=3@d03`l?00d=3@0?3`l0410@00l?3`0<30`020P800l=400=2`h00P0>30l01P0=
2`h03P`?00d;3P1?CE000@0201lM80803@/>00L03`d@00`:3@0<2Pd03`d@00h<3`0<2Pd03P`?0080
40hA01405aDH01TG6P0D4QD04Q8B00h>3P0?3`l02`/;00X82@0=2``03P`=00d92P0>2P/04@d>00l9
2`0;1@L04Ph?010<3@0400h:2`0<00l;300@30d04@d>014=3P0?2``03PX;00l>300@3`d02`X800X9
1`0=30X03Pd;0P0?3P`03`0>3@/03@`:00d<2P0?3P`02PT7010<3@081PD02PP901<A4P0?3@h02PP9
00/92P0=30d020P800`:3@0600h<3@09014?400100007adN00L61P0M6a`03@/<00T8200I5aP081hO
00803`d>03<05ADE01<C4`0G5aL04aDD00H:2@0Q9B@07R4P00T92`0@41807AdO00@41P020P@04A4C
00@41P0=3@l030`>02@T9P071`T0D51B03@b=@0F51L030X=010>4@0?3A004a4D01lM80010080<Blb
08f;SP0V92L03@/>00<10P0L6Q/03P`=01@B4`0C4A804@l@028P8@0K6AX0518C010>3`0>30d040h?
00T7200?3@h04@l@01XH6@0C4A804Q0A00/92P0?3@h00P0C4A809P0A3a003@/<010>3`0B41404a4B
018@4@0A3a0040h?01<A4P0V92D06ALH00h<3@0E4a@051@D01PH600?4A0030h=014C4P0F61L05ALF
00d?3P0D5QD04aDD00h@3`0D5QD0AdU803<c<`0<30`07alO01<C4`0F5QH04A4A03Lg=`0:2PX0410@
00`<300R8R80410@0P0D5AL00`0E5QP05QLI01HG6@0301LH6P0501XK7@0I6Q`06Q/M01TJ700K7200
0P0H6Ad07P0I6Qh05aPL01DF6P0H6Ad07QlS01/L800P8BD0<34e02<V:`0N9R`04AXO01<L8@0h@DH0
5b0U014J7`0C7240;SLl07^4R@0B6b003AHK014G700I7R804QLK01TN8P0K82@08BHZ01XO8`0K82@0
5a`P01TN8P80724U02H06B4U01TT:P0K9R`06bH/01XU:`0L9bd09S4g02D`=P0M:2h06RD[01`W;@0K
9R`07RHZ01dU:00K8bH07RHY020X:`0]=CP0;SHi024Y;00P:2/08b/^01XR9@0M9BP04a`Q01PQ9P0B
6b007RPZ01LQ8`0Q:bd08B//01/U9P0K9B@082XY01`V9@0E7ah05AXM01LK7P8061`O01H05a/N01HJ
7@0F6Qd07b<V024U:00X;2l0;c<f01LK7P0E61d05QTP01PK8P0E61l04QDL01<F7@0J7B@02PdD02HY
<00=41L06QdT03@g?00F6QT05QXH0P0E6AP0500D61P051PI01LK700G6ad06AdP018F6@0F6Qd03a<F
010D5@0F6AX05ATJ01DF600K71h09bPZ01`M7`0D5AL0824S01DE5`0H6A/051DG0P0B4aD01P0C51H0
51DG01HG6@0G61X051DG01LH6P806AXL00P05AHH014B500F6QX05QXK01PL7@0L82406alP01TM7P80
6QhO01d06alP01`P800I7Ah05a/J01DI600F61L051HE018D4`0F5QH061PH01<C500A3a004Q0A01DC
500G4a@0518E01HD6P0@3a@03`hC01<B5`0F51L05A<F01@B5@0F4Q<0510A018>3`0C3@l04@h?00h>
3P0300l=3P04014=3P0H4a@06Q@F01D<3`803PD800<05@X>01L@4P0D3Q000P0B30h201<=3`0;014;
3@0?2@/03`T;014;3@0B30h04`d?00l92P0;1@D040X:00l92@0C3@d00P0B30`200h8200?00d71`0>
20P03PP8018:2P0A1`P040H701D;300F30d04@L800L0000U6a`03PD501@:2`0=0`@03`D600804PP9
0P0C2@X02P0A1`P03`D601882@0<0P<06@l@00`20`0Q5aP09adN00d2200>0`T201052`0400h32@0=
0PP03@8800h32@804@H<00D040D;00h32@0<0@D06a0D00l4200200d21P0701T>4P0B1`/040D901<8
300D2@d040D900l4200801452@803`<70P0A1@TDooooo`006oooool03P0?30L0514<018?2P071000
61HA00/:1@081`<02@P500/:1P0F5A404A0<00L60P0C4Ph040l;0P0=30P0100A40`051<?00l>2P0@
3`/201<B3P0>01PG4`0P7a/03`h:010?2`0C4Ph040l;018A3@0:2@D051<?00L60P061@4030/7014@
300;2PH600l>2P0H00h=2@0?3PX03`h:00l>2P0@3`/03a0;00/=200F61<05aTD01XL5`0>40/01`T4
00d?2P082PD01`T400d?2P0H6QD06AXE010?2P0920<04A0;00L60@0B4@`030/60P0A40/03@0>3@P0
4A0;014@2`0;2`H030d700/<1P041@40;BhX00`=1`082@<02P/500/<1P0<3@L00P0=3PP01`0A4@`0
40l;00`;1`0C4Ph07QdI01LF4P0?3PX00P0>3@T08`0A40`03@`800`;1`0?3@T03`/800/;1P0D5A00
6A/F0045000D6A<02a0:010B3@0P7a/00@0001DA3P0920@03a0;01XK5P0D5A002``700h?2P0<3@P0
2@X500X;1P0B4`h05QLB01@E400=30P04A0<00`;1`0:2@D04A0<00d<200920@02`X600<03Pd900@0
40l;00X91`0;2PP03@`:0`0>3@/00`0<2`T05aHD00/:200200`;2@0600h=2`030@804a4B01/I6P09
1`P04Q0A1`0=2``200h>308030`:0P0=3@/050061P@05aLE00`<2P0820H04A4?00H81`0A5aL0CeQG
01DN7@0740l03Q@D00lE5@0<41401@H801PI6`0c<cD04A4C010@4P0@3Pl03P`=0`0=2``03@0>30d0
3`d>00d;300=2``03`d>010>3`0?3@h03`l?00H61P0O7al06ATI01LG5`0>3Ph00P0;2`/03@0<30`0
3Ph>00l?3`0@41003`d>00h<3@0:20T03@/<00T7200A3a0030X;00l=3P0>30d00P0<2P/03`0@3Pl0
4Q0A00d;30030@807A/L05iLG@1EDe@02PP9010>3`0<2P/05aDF0040000I61L04A0>00h=2`0200`;
2@0300h=2`0?3P`03Pd;00803Pd;01L03`h<010?3@0B4Q003@d;00X:200D51806QXH018A3`0;2PP0
30/900l;2P0A3@`040`;00d71`0A3@X03PX700d91P0A3@X04`l<014=2P0=2@H03`/8010<2@0200h:
1`0U010<2@0B3Pl02`L800d92P0A3@h030P9010<3@0H51D01P8300T51P0>2P/040`=01@A4P0>30l0
2PX<01LG6@051@L05ADG010@4P0>3Q0061PJ07emO`2?Si408R8T00X:300@41801PD901<B60020@T0
CD]F02DS;P0;2A@03@/E02TX;P0o?T<05aLH00d=3@0201@D500400L71`0@41003Ph>00H61P<03`l?
02T03Ph>00/;2`0820P040hA00h<3`0@3Q403P`?00`:3@0A3a804Q0C01`J7@0I5aX00@02055?DP0T
8RD03`d@00d;3P0>30l04Q0C00h<3`0:20/030X=00h<3`0=2`h04a4D01@B5@0?3A004A4A00d=3@0>
3Ph02`/;00T7200<2P/03`d>00l;300@30d04@d>010:300>20X04`l@010<3@0200h:2`0300l;300@
30d03PX;00D03PX;00D04A0>01@C4@0>3@/02`X800d<2P0600h=2`0=010=300?2`X050h>018>3@0<
20L03PX;010>3`0;2@X030`>01HF60061PP01@D700h=3P0500h<3@0?00l=3P081PL08R0Q00T8200C
4A805A<D01TG600200400@0000h<3@0J61T051@D00820P0B4Q803@l>00801@T800/04QHE00`<3P0D
51H020P:03/k?@0i>C/04A4C01<C5@0H61X051@F0082100200`<3P0301hL7`0;2@`030X=008040hA
01404@lB01DC5P040PD01@<602HT9`0610L03@/>01<A4P0J61T0518C01PF5`071@H040h?01lM7P0L
6Q/05aDF018@4@02010>3`0801<A4P0G5AH05aDF01/I6P0?3@h04Q0A00d;300?3@h2018@4@05014?
400?3@h04@l@01<A4P0B41400P0@3Pl0600B41405Q@E03<a<P0O7Ah03P`=01@B4`0?3`l051HE014C
4P0@4Q404A<B010B4@0:30/03Q0?01<E500G6AP06Q`K014C4P0P8R406QXJ010@400L71`03Ph>01@D
508061PH00H07alO07YjNP12@T808B4Q01PH600D5AL201DF60<05aPJ02H06AXL01/L7P0M7R0061TK
01hO8@0G61X06Q/O01DF6P0H6Ad07QlS01`M8@0I6Qh06Q/O01dN8P0J6al071dQ02TZ;P0O8bH051`P
020Y;P0M9R/05QlT01<L8@0S;34082T^014J7`0Q:Rl04Q/P02D^<`0K8RL08BHZ01HK7`0L8BD07b@X
02P]<@0O92P06QlS01LL80<06AhR00<05b0U01LR:00K9R`00P0K9R`03P0O:S00:cHl02Pc>@0M:2h0
6B@Z01hY;`0M:2h07RL/01/S9P0H82<06b<V01hV:@0X<3<09Rha0P0M9BP0300R:Rd07RHY01dU:00@
6Ah06B8W01dV:`0A6ad04adO01/U9`0d?Sl09Bl`01LQ80806B<R00H05R0O01dR9@0M8B@07B4T01XN
8@0H71l201LK7P0C01/O8P0F6Qd051PK01TM800B5QT05aXQ01PK8P0L7bH061/R01<F7@0E61l092L^
0454B`0<3aH01`XA01`O9P0@4aP061`K01PM6P0201LK6P0=01LK6`0F6Q/05ATJ01DI6`0K7b805ATL
01LK7P0A5AP04aLH01DJ6`0E6AX051PI01XM7P02028S9@0501DF600X:2X0410B01/K7@0@41800P0A
4Q@0400B4aD051DG01LH6P0I6Q`061TK01XK7@0E5QP05aPJ01XK7@0H6A/05QXI01LK6P0J7Qd07B4R
01/O800I7Ah201PL7@806AdL0P0G6aX09`0E6AP05QPG01@F5@0B51<05QHH01PH6P0F5QP0518C01<A
4P0D4Q<04`l@00l=400E4aT03`hC010?500E51T05Q@G01@B5@0B41<0510A01<?400B3Pl050h@01@A
4P0A4A404@l@00l=3P0>30d04@d>02DP8P0Q6ad040L:01L>4@0J4A@05``@01L>4@0E3a4050h@01<=
3`03018<3P03010:300>20X040X<00804`d?00H04P`=00h8200E3`l03PP801D?3`0;1@D300h8200@
00d71`0>20P03PP8018:2`0A1`P040H701L=3P0I3a004PP900P0000A1`P02P4201<92P0=0`@04@L8
01061`803`D60`0>10D0200D2P/03`D601@:2`0800004`T:01@:2`0>0`L03`@:0`0A1P`00`0?10X0
3P<900l42P0201052`803`@:00H02`0401D:3P0:0@<03`@801H=3`0<0@D201872`0401<8300B1`/0
4@H:01052@803`<70P0@10P401452@8040@80P0A1@TDooooo`006oooool0300C3PT04`l901<@2P0C
40/03@X5018?2P0E51005A@A018A3@0C4Ph030`800l@2`D03`h:00d03Pd9014@300=30P03`h:018A
3@0P7a/0;RdY01DD4@0@40d04Q8=01<B3P0N7AT06QTD00<04A0<00<03Pd900d<200?3PX01P0?3PX0
2`0A40`040l;00l>2P0?3PX03Pd900d>2@0<3`T02@`700`?2P0O8ad020X60080310:00X03a<=00hB
300:3@P01`/600X<200G5Q403@`700l>2@0G5Q40:bXU0`0@3`X02P0?3PT04a8=01@C3P0@40/0414;
00h?2`0?40/01PL200`=1`0A4P`200`=1`0700h?2@0?40X0414;00h>2@0?3PX03Pd900`;1`02010?
2`0J00d<200;2PH03Pd901@C3`0@3`/03Pd901LE4@0@30T03Ph:010@3@0=3`X0<SPb08F;Q@1BEe40
3a4<00h=2P0B4@d03PX8018A3@0<3@P03Pl:014B3@0>3`X02``700l@2`0>3`X200`=200;00l@2`0E
5Q402`X6014@300?3PX040l;01XI5@0H5a<051<?014@300?3PX00P0@3`/00`0<2`L03Pd;00h=2`02
00l>300:00h=2`0=30X030/901@C4@0>3@/05QDC00`;2@0=30X04@d>01<?408030P90P0>2P/01P0C
3a004@d>00h:2`0>2P/04@d>014?40803@d;01P030`:00d=2`0?3`d03`l=010@3P0D51804A4?00d=
2`0>3P`03a4@01TP801nR8P05R0P00H?3`0P:2T01Pd>00`A4`052@/01`X<01/L7`061PT0410B010>
3`0>30d300d;30803P`=00/03`d>014?400?3@h03`d>014?400D51@04A4A00@4100F5QH04a<C014A
4@0200d=3@0N00h>3P0?3`l03`l?010@400?3@h03P`=00X82@0>30d02`T:01<A4P0=2``03P`=00d;
300;2@X03@/<00l=3P0<2P/03P`=010>3`081PL030X;01LE5P091`P05Q@E00/92P0;2PX04Q0A040o
?P0D4a404A0>0P0>3@/00`0@3`d04A0>00l>300200h=2`0;00l>300A40h04A4?00h>300<30X02@T7
00X:200=30X03`h<00h=2`0?2`X00P0A3@`01P0?2@T02`L400/7100B3P/06aLD01XF4`803@T600L0
3PX7010<2@0>2PL03PX7014=2`0C3`l02PH600804`l@02H020D402HR8P0L61T04`l?018>3P0<20T0
4@d=00l<3@0<2Pd04a<F00T93@0:2@h04A0D00/;3`0<2Pl030/?020O8`0A41D02PT=00d<4@0A41D0
2PT>01HE700>3AD0P7j:02LU<P0>31P05Q@N010?5@0L6b002@T:01@D500A4A40De=C02`/;00B4Q80
3Ph>014A4@803Ph>0`0=3@d03@0=3@h04Q0C010>4`0B41D03P`A00/93P0D4QL06QPM00h<4@0<2Pl0
4Q0E02l]<P0B41D00P0>30l01`0C4Q@05QDH00h=40071PT03Pd@00l>400=30h00P0@3Q40<@0:2@`0
2`/<00X:2`0>3`h03@d>00`;300?3Ph04A0A01DB500E4Q<04@h@018=400D3a004Ph?00l;300>2P/0
3`/<014=3P0B3Pl04@d>00h:2`0<20T03@T:010<3@0A3@h03`h;01HE4@0A40`03Pd900l>2P0>3@T0
30/700d<200?3PX040l;014@300>2@H06A@A00/5100E3`d05A4?00L30P0W92D040hA01@C5`0d=3P0
61TM00P93@0@41<01`0>30d08@091`P03P`=00d;300<2P/040h?00`:2`0?3@h03`h>00`<300?3`l0
3Pl>00/=300<3Pd041<B00<5100A51<03`lA00H6200C4aD0AdM903lo@@0;2`d051@F00@41P0B4Q@0
2`/=01@D5P0>3Q004Q0C00l=400D4QD030X=010>4@0201<A50804Q0C00d03P`?01<A500C4A@0:RPZ
03Le=`0C4A805Q@F010>3`0D4Q<040h?018@4@0C4A8040h?00804Q0A00@03`d>00h<3@0C4A807adN
0P0E4a@2010>3`0<014?400B41404Q0A018@4@0A3a005aDF01TG600F51D04a4B018@4@0E4a@061HG
0P0B41404@0G5AH04a<C01<E500A5A@041@C010C4P0?4a803A4@014D4`0F6AP04QHE01XM700@51<0
2P`;01<D4`0D51@0410@008051@D0P0C4a<0A@0N7Qh0LW9b03lo?`0Q8B406QXJ01@F5P0E5aL05QLH
01LH6P0H6A/06AXL01TK700P8b@071lP01@F600S9BL05API01TK7`0K72006A`O01TJ7P0J6al06QdP
01/M800M7R807R4T01PJ7@0J6al04QHI01PQ900E7R404adO014K7@0Q:bd05R0R010J700D7R005b4S
01XT9P0H8BD06B4T028W:`0F6al07R<W01lT:00W;3007R<W01`Q9@0M8RH07R<W01LL800I7R8072@Z
01`W;@0P:c407bX`01/V;00N:Bl092le028]<`0N:Bl06bH/01hY;`0Q;3809Bhc01lX:P0K8bL082P[
01hW:P0201/S9P0A01TR9@0H82<06b<V01`U9`0D71l072DY01<M800O:2`072HX03U3A00F82808R`]
01XT9@0F81l0628Q01LQ800H8B000P0L8B@02P0L82<06QlR01TN8@0I7B007R8U020T9`0Q9BP061`O
01<G6P0H71l201PM8P0=01hS:00J7bD04aPM01HK8@0a=S`0RHjC020U:P0I7R@06QlT01XO8`0G6a/0
5a`I01HK600201HJ6@0901DI6@0I7Ah051PJ01TM800C5aX061`O01HJ7@0F71`051/K008051XJ00T0
51TJ01<G600D5AL051@F014@4P0P7R405Q@G01`J7@0F5QP00P0E5QP04P0F5aT061TK01TJ700F5aT0
6a`N01HG6@0H6A/06a`N01TJ700G71X05Q/I01LM6P0H7Ad051TI010F5P0E6Q/05Q/K01HL6`805AXH
00P05Q/I01DJ5`0F61L051HE018C5@0F5QP061PJ01<C5@805A<F01h04a4B01<@400B4140518H00l>
4`0A4A@05aHK01HD5`0B41<04@lB01@@4@0C3a004Ph?01@?4@0D4A804Q4A010?400A3a005A8C01TE
5P0J5AL050h@01@;3P0N5AP08ALK01P=4@0C2`d05Q0B01D?4@0B30h200h82P0E018<3P0A2`d03PP:
010:300C3@l04P`>01H@4@0=1`L050`=01@=3@0[9BD05a0@01092@0>20P03`P800h71`0>20P03`P8
0108200@1PL04PP900<04`T:01<05@/<01882@0C2@X02`<30147200M4a@04`T801881`0@1PD03`D4
01471P0E2`X040H501471P0@1PD04PP700h4100>10D040D900804@H<01D04PL=0146300@1@/04@H<
01052`0?10X03P<900l42P0A1P/04PL;01052@0D2Pd0@3Di04Xo@`0;0P@03@8600l4200>0`L03045
00d21P0<0@D00P0@10P01P0?0`L03P8600d11@0=0@D04PH:01452@8040@800<04@D901862_ooool0
4oooool001_ooooo01006ADB01hM6@0F5A4020L300`;1`0@3`/03`h:01HE4@0@3`/03@`8010?2`0;
2PH051<A00d<2P081`D06APF0`0?3P`01@0>3@/020L500l>300=30X05QHD008041@C01@04aDB00H6
0`0B4@`05Q<<01<@2@0;20403@X501<B3@0?40/02P/601HF3`0A40/03Ph600h=1`0@3`X04A4900h>
1`0>3@P03Ph600h>1`803Pd800X04a@?0001000>3`X0@44l01HG4P061`803a0;00`=200=3PT0414<
0P0>3`X02P0=3PT02@X500d>2P0L7AP0EUMB01PI500:2`H04Q<>01<D3`0<3@P200l@2`0<00d>2@0<
3@P02``700d>2@0?40/03Pl:00/<1`0<3@P04A8=018C3P0=3PT02`/60P0@3`X0@@0>3@P040l:00h=
200<2`H04A0;01DD3`0K6QD05aHA010?2P0H5a@09RDS014A400@4100BTY804Q:B03SiN@0Ngej020P
7`0I6AT03Ph<014@3`0?3PX02`X600h=2@0;2PH04A0<010?2`0A40`02`X600d<200D4`l04a8>018A
3@0920@05aHB00l>2P0I61@020L3018A3@0>3@T02PT500T8100@3`/04Q4=00X91@0<2`L04A0<010?
2`0<2`L03@`800/:1P0@3`/071/G02l^:P0X9b<04a8>01@C3`0>3@/03`h<010?3@0?3P`03@`:00/:
200A40h040l=00803Pd;0P0?3P`00`0E5A<03@d;00d=2`0200h>300@01<C4@0>3P`0410>014A3`0@
40h04A4?01<C4@031@@06QdL014C4P0B51<030h=00H81`0?4A00418A00l?3`803Ph>00@0410@018A
3`0B4@l040l=0P0=30X01`0>3@/040l=00l>300B4@l02`X80040000?3P`00P0>30d03`0;2@X04a4B
01<A4P081PL01`D600d;300D4Q<02`T:01<A4P0G5AH03Pd;00l>300B4@l03Pd;018A3`0300d<2P0?
00h=2`0=30X03@`:00/:200?3P`02`X800d<2`0=30X01`H400/:200?3P`040l=00d<2P0:2@L02`X8
00803`h<00X03Pd;00l>300A40h03`h<00h=2`0<2`T00@0001<B400f=C<07QdK0P0<2`T0400@30/0
3@/900`81`0=2@P040`;01DA400F4Q403`/:00/71P0:1PD04`l>01@@3`0C3`h03`/:00`81`0=2@P6
010<2`0L00/:200>3@T04a8?014@3P0>3@T04a8?00d<2P0=30P03Pd:00l>300A40`04a8@00/92P07
1@H03`/>00/62P0B414030T;010;3`0:20T05A4D00`72`0D4Q<020D801HC6P0B3aP020D>00L43@80
3P/D00d030T@02dZ<@0J61d05Q@G01<A500D4QD0=CDg0>CTiP1<C4h05ADG00d=3`030`D030`>0080
410B00D03@d?00`<3P0>3Q003`d@00h<3`0200d;3P0S00h<3`0?3A0040hA00l=400F51L061HI02d[
;P0=2`h01PH800d=3`082@/05QPJ00@82@0:41004AHF00<7200720X05aPJ00L72@0@41801@P900`=
4@0A5AH02@X=00L8300C51H03a0C08>4R02?T9806a`O01@E6@0820X03P`=00`:2`0:20T00P0?3@h0
10091`P03`d>00`:2`0<2P/200d;300300`:2`0<2`T03`h<00802`X80P0:2@L500l>300C00l<2`0?
2`X040`;018>3P0?3@h03P`=00l=3P0A3a0040h?00d<3@0<30h03Ph@00h=3`0B41405aDF01@B4`0;
2@X02@L800h<3@02018@4@0N010>3`0=2``02`T:00/92P0D4Q<05Q@E00L61P0?3@h0518C00L51P0K
6a/0;B`/01DE5@051@D03@d=00d=3`0?3a404A4C00d=3`0<30h04A4C00T92`0820X061PJ00L72@0I
6A/030`>00/:3`0B4AH03PdB0P0A41D0100@3a@02`X?00`;400?3Q<3014@5@0600X93P0b<CH030/?
01LF6`061PP04A4C0P0=3@l0:P0A4A405ADE01@D500B41403`d>014=3P0D41405Q8C01DA4P0B3Pl0
40`=01DA4P0D41402@D601HB4`0I5aP04@l@01LG5`0E5AD051@D01DE5@0B4Q803`l?01HF5P0E5AD0
51@D018B4P092@T05QHF01@E500E5aH04a<C00l@3`0B51<05QHF01XK6P0D5QD04a<C01@E500A4a80
51HE01DG5P804A<B00`051HE01DG5P0A4a8051HE01PJ6@0L7Qd05aTH01<E500H6QL071hK01dO700I
7A`201LK6P0a01@I5`0J82004QPH01dS8`0C61/07B8U01PM800J7R405a`O01/O8P0I7B004aPK014E
600R9RT02a0C01TM800M8B@041DH01HM7`0B5aX04a/M01PP8P0H82<0<CXn03Dn@`0K92T05AlS01dX
;00H8bT04a`P02@/;`0>5QT07bLZ00XB5@0S:bh07RHY01dU:00C6ah082P[01hV:@0@61/06b<Z02Tb
>`0J8b`06b@]01dV;`0N9c008BXc020Y<P02024Z<`0D020Y<P0O:3408BXa01/V:P0E7RD05R0T01`W
:`0L9R/07bT[01`W:@0N:BX06bDV02Da<@0F824082X[01DM7`0K8bD08RX/01PQ800J8R<201XS8P04
01lX9`0J8b804a`K01@M70807BDW02@05AdO01`T9P0I8B<05Q/N01LL7`0X;C00:2`_01@H6`0F6Qd0
61`O00lC5P0D61/06alS01XM8P0G6ah04aLK01@G700L7b<05a/N01HI7P0K7b<06alR01PL7`0E6AX0
6QhO00dA4P0C5aT041@G01DI700H71l06AdP01XN8@0H71l04ADH01<G6P0E6A`201HJ7@0>01DF6P0C
51P06AXN01PI7@0F5a/06aXO01<B5`0L6b006a`N01PI6`0E5QP051DG01HG6@0H6A/201LH6P805QLI
0P0E5QP0900J72005QLK018F6@0D5aX06AXN01XN8@0F6Ad05aPL01PL7`0F6A`05AHJ01PI7@0A4Q@0
5QHH01`L7P0B4Q@04A4C01hN800^;S006a/M01`L7P0G5aT03`lA014?4P0F51L06ALJ01PF5`0F51H0
5A<D01HD5@0E4a@04Q0A01@B4`0B41404a4B01HB4P804`l>01804@d<014;2`0C3@d0618B00d71`0D
3Ph040X:01TC4`0600005Q0@014;2`0@2PX050h>00h8200?2@T050h>00d71`0:10@2014;2`0<00d7
1`0?1`P04@P901D;300B20T030<401882@0D2P/04@P901<92P0C2P/04@P90P0@1PL60147200500L0
000H3Pl060h?01@:2`0?1PL00P0@1PL0100D2P/06@l@01P>3`0A1`P600l51P0=01052@0C20`03@<6
00l4200H3A403@@600h31`0=0PH04PL;00T00P0L4AD03P<70104200201041P0300l31@0>0P@03P84
00803P840P0?0`D201041P0600h21P0@10P03P8600h21P0@10P03P861P0?0`LDooooo`006oooool0
100@3`/030/700P70`0@3`/300l>2P0S01@C3`0?3PX03@`8010?2`0=30P02PT7018A3`0C4Q002PT7
00`;2@0@3`d020L5014@3P0?3P`02`X800D40P0?3`d01`h>010D4`0<4@d0410<01`I500=2P<05148
010=1P0C40T06APC01XK5P0H6A<05AD>014A2@0>3PH03`l7014A2@0B4PX01P0>3PH0600<2`L01`H2
00H50@0K6QH02PT501<B3P0>3@T04A0<010?2`0>3@T03`h:01<C3P0E5Q402``700X;20061`80;BhY
00d>2@0H6A@030d800P9100>3`X01`P300`=20803@h901803Pl:010A300A4Pd03a0;014B3@0D5A00
2``700D60@0>3`X04Q8=00h=200=30L04A0;01XI500G5Q403`h900d<1`0?3PT2018A300g00h=200<
30T03@d=00P820061PH06a/K01HF5P1nOWh0MGEe03dm?@071`L0410@00h>3@0B4@d02`X601@C3`0?
3PX00@0000`;2@0>3@T02`X600d<200>3@T030/7014@300=30P04a8>00/:1P061@401`H200X91@0?
3PX040l;01TH500T8al08R4M01@C3`0@3`/04a8>014@300=30P03Pd900T8100?3PX04a8>020O6`0L
6aL03@`8010?2`0>3@/03`h<010?3@0?3P`03@`:00/:200300l>3008010?3@0B4@l04a8@01`L6P0C
4a403`l=00d=2`0820H200X:20803@d;0P0<30X03@0>3P`02PX805eMF`0H61H04a<A01/K6@0@40h0
3Ph<00l?3@0@40h03`l=00`<2P0;2`T00P0@3`d04P0>3@/030/900`;2@0>3@/040l=00`;2@0>3@/0
4Q4?014@3P0C4Q003P`=010>3`0?3@h04a4B010>3`0;2@X040h?00h<3@803@/<00P04Q0A00H41@0G
5Q@05A@B00h=2`061@<02PT7018A3`803@`:02<03Pd;00d<2P0=30X03`h<014@3P0?3P`01@@300l>
300G5Q@03@`:00l>300@3`d03Pd;00X91`0<2`T03`h<00h=2`0=30X03`h<010?3@0?3P`03@`:00L6
100/:bT05QDC0040000J6AL020D400l;2P0@30/03PX900`81`0>2PT030P700l;2P0201<?3P0801HB
4@0E4A002`L600d9200>2PT03@T800h:2@0B3Pd6010<2`0600`;1`0>3@T03`h:00`;1`0:2@D02`X6
0P0@3`/02@0?3PX03Pd900h=2@0?3P/071PI01/G600?2``02PH7014=3P0200l;300M00L3100<20T0
2`L801dI6P0J5QP06aPO014>5`0D4AX05a@M01<@600@3A@02@L<01PF6`0A3a@04a4D00X82`0?3A00
61PJ06EUI`0U9BL03@d?010@4P0G5aT03@d?010@4P0?3a403@d?00`<3P0?3a401P0=2`h200H41`04
01@B5@081PT04a8D00l=408030`>01/02@X<00dA4P0;4A404AXI00P?3`0>4Q<01PX;00P92`020P@0
4Q8D00`>4P0830l02PhA00L;3P0A5AP08RHY02DY;03IgN00em_N028U:00010L0414C00l>3P0?3@h0
3@/<014?400B41400P0>30d200/92P0800`:2`0;2@X02`T:00/:200?3P`030/900l>300@3`d600d<
2P0500d<2`0>30d03P`=00l=3P0<2P/00P0;2@X0300=2``03P`=00/92P0:20T02`T:00h<3@0@3Pl0
4Q0A010>3`0;2@X02PP900`:2`803@/<0P0>30d08P0?3@h020L7018@4@0C4A8061HG010>3`071@H0
40h?01HD5@0O7Ah04a4B00/92P0?3@h02PX<00`<3P0@41804Q8D01DE5`0K6ad0?Cdo01DE5`0?3a40
DU9D05QHFP0I6A/04A0E01<B5`0A41D03@`A00`;400>3A8030/@00d<4@0@3a@2014@5@06010?500b
<CL0D4mE01lN8`0M72402PT>0P0C4aD0;`0A4A<03`l?014A4@0A4A403`l?00l=3P0A3@h04`l@01@@
4@0C3a0040`=01PD5@0=2@X0510A01LC500J5QL02PP900/;2`0?3`l03Ph>010@400D51@0410@01<C
4`0=3@d01`L700T92@0B4Q806QXJ01DE5@0B4Q804a<C018B4P0?3`l0410@00`<300D51@0410@00d=
3@0@41004Q8B01<E500D5QD04Q@C014C4P0B51<04aDD008051HE00P05aTH01XL6`0E5aH04Q@A01LI
5@0J71T06adJ01LL60805a/J00T03Q@B01dV9@0=5QD072DT01dU9`0?5aT08BHY02@Y;00O92L00P0K
82<01@0I7R407b@W028W:P0F6ah05AXM008061dP0P0G71l0A`0I82806R8T01TQ901HH6@0DU]P01TR
9`0H8RP04ahT018M8`0V;c@0GfMZ03]3AP0J8RD05QhQ02@/;`0I8B@08RX]01HN8@0J8RD07BDX01DM
800H82H07RL`01DN9`0J8b`0:34j03@mAP0^=d007RL`01lX<@0N9c006b@]01`U;P0N:2l06bH/01TT
:P0J9BX072L[01/V:P0O:R`09S4c02Te=@0E8B406bLW01/V9`0`>CP072DT01XS8P0L9B@06R<R01LP
7`0f?ch0:S<b01/T8`0F7ah05AhM01TR8@0<5QL04Q`M01TS900Y<C<08RX/01LO8@0K82<09R/^02@X
:`0H71l06alR01LK7P0C5aX05QXM00806QhQ00@061`O01DI700J7R406AdP0P0A5AP03`0F6Qd04ADH
01`P8`0J7R405QXM00`@4`0D61/07B4T01PL7`0F6Qd05ATL01HJ7@0G6ah051PK01DF6P0201HG6`80
5AHJ0P0C51P01`0B4aL04a@H02HW:`0T9BT05QLK01TJ700G61X00P0E5QP0100G61X061TK01DF600G
61X401PI6`0401PI7P0G61d05QLL01LH7@8061TN01<0C4eB01hO900B4aP051DJ00d>4`0720`07QhP
01TI6`0J6Q`04a<E01/K7@0/;2h0XJ6S01`L7P071`T03@d?010@4P0O7b40518C00805Q@E0`0C4A80
1`0B41403P`=01@B4`0H5QL04@l@010<300B30`00P0C3@d01@0B30`050h>01/E5@0X8R806Q@D0080
4P`<00D04@/;01<=3@0B30`040X:01<=3@0200h8200A01@>3P0@2PX03PP801<=3@0B30`03`T901<;
300G3@h04`T:00l51P0H3Pl05P`=00l51P0B20T04`T:01@:2`0B20T01`0A1`P01P0=0`@0;bDV00L0
000:00404`T:01X@4@803@<400@04@L801@:2`0C2@X03@<41P0?1@H0300700004@H:01@93@0;00@0
3P<701X?4`0P5AT01`0000P00@0A1PX0200100d31P<040@600@03`<500h2100>0P@03P840`0?0`D2
01041P8040@80`0?0`L00`0=0@D03`<700l31`0400l31aCooooo000Kooooo`0A00d<200E5100>STe
00`;1`0<2`P030/700l>2P0A40`03Pd900`;1`0A40`04a8>018A3`0>3@/03Pd<00l>300>3@/00P0=
30X0300@3`d02PT700d<2P0K6QP0<c<a06adL`0830/010P400l@300>2`H0514:010=10804Pl800T0
4A0;01<D3`0E5Q404Q4;010@200>3PH04108018B2P0C4`/01@0>3PH06`0>3PL040l;014@300:2@D0
3`h:00T8100G5Q803Pd901<B3P0B4@d030/700h=2@0?3`X04a@?00P9100B4`h01`P401DF4@092PH0
3Pl:00/<1`0A4Pd03a0;00P9100>3`X03@h900h?2P0500d>2@0S00`=200A4Pd04a@?00l@2`0>3PT0
3`h900`;1P0A40/06QTD01HE400>3@P030/600/:1@0=30L040l:014@2`0>3PX02`/8018B3`0E5A<0
2`/800h?300B4Q002PX701<C400C4a403Ph;00/;20061@<05aHB00/:1`0B4@d040l;014@300B4@d0
0P0@3`/0300<2`L02@P4018A3@0E51002PT6018A3@020@004Q4=00l>2P0=30P02`X600h=2@805A@@
00T030/700h=2@0?3PX03Pd901<B3P0F5A403Pd901<B3P0<2`L00P0@3`/00`0;2PH03@`800h=2`03
00l>300A00h=2`0=30X03@`:00h=2`0?3P`04A0>01@C4@0F5A<04A4?00l?3@0@40h03`l=00`<2P0@
40h03Ph<010@3P0?3`d00P0=3@/200h>300;01XJ6@0?3`d051@B00L71@0>3P`03@d;00/;2@0>3P`0
4A4?00`<2P061P@00P0>3@/06`0=30X030/900h=2`0@3`d06QTG010?3@0>3@/030/9014@3P0;2PP0
30X;014?400F51D03`d>00X82@0?3@h01`D6010>3`0?3@h02PP9014?40081PL04A0>00P71@0B4@l0
<S4_01DD4P0300d<2P0=00h=2`0=30X03@`:018A3`030P404Q4?03He<`0C4Q002`X800l>300>3@/0
3`h<00h=2`0200d<2P0A00h=2`0=30X030/900d<2P0>3@/03@`:00`;2@0>3@/02`X800d<2`0>3@/0
3@`:00h<2P0?2`X040`;00l;2P0>2PT00P0?2`X2010<2`03018>3@0H51<0510?00@040`;00<04Ph=
01PD4`0@30/01@0@30/01P0>3@/040l=010?3@0?3P`040l=00h=2`803`h<0P0>3@/0800?3P`040l=
00d92P0E4A802`L801`H6@0A3@h0510A00h:2`0=2@X04Ph?014=3P0G4a@03PX<01dJ8@0<2A80KFYc
07=`M`0C41L05a@K014?500<2Pl03`dB01DC5P0=2`h04Q0C014A4`0B4Q@061PJ00<31@0F5QP04Q8D
0P0@41801P0=3@l030`>00d=3`0@41802`T<00d;3P803`d@02@03@/>00/9300F51L03@/>01@B5@03
0P@05Q@G059@D`0J61/03@d?00T:300<41401P`<03<i>@0X;Bd0310A00dA4P0L7Al03Pd@018A4`0@
4A<03@h@00h?4@0:2P`04Q8D01dN800>3Q00>c`n03dn@00B4aD02PX<00`=3`0<2P/040h?00d;300<
2P/200h<3@803`d>0P0>30d200d;300300`;2@0>3@/03@`:00803Pd;00<03@`:00h=2`0>3@/00`0>
3@/02P0>3@`03P`=00h<3@0>30d030X;00/92P0<2P/040h?018@4@0@3Pl200h<3@0600l=3P0=2``0
2`T:00d;300?3@h03P`=0P0=2``200`:2`0A00h<3@0@3Pl05A<D00800@0I5aP0;B//01@B4`0E4a@0
3P`=00l=3P0<2P/03P`=014?400@3Pl06ATK01DE5`0B4Q@00P0A4A<00`0>3Q0061PJ00H6200201@D
5P0801DE5`0>3Q004Q4F00/:3`0B4AH03PdB00l>4`0B4AH200l>4`<040lD00/03`hC00T83P0Q82H0
2`X?01@C600<2a0051@F018B500?3a403@d=00l?3`02018B4P8040h?00P04@l@018@4@0@3Pl030X;
01`J6`0B414081hO01/I6P805A<D01P04a<C018B4P0A4A405aLG01hN7P0I6AT03Ph>014A4@0T92@0
9BDU01DE5@0D51@06a/K01<C4`0E5AD061PH01DE5@0B4Q804a<C01TI6@0F5QH051@D01LG5`0H61P3
01DG5P0401@F5@0G6AP06Q`K01HH5`805ALF01@05QPG01DG5P0D5Q<05aTE01TK600H6QL05Q/G01PL
6`0I7A`06R0N010F5P0I7al041TH01XR900K8bD06QlR020U:00I7R405AXM01TN8@806b0S02D06QlR
01lT9`0H7B005a`O01dR9@0J7b807b@W01hU9`0K8bD06b<V01`U:@0N9b`07bP]01lY;`0R;C<082/a
01LP9P0`>3/06b<V014I700K8bH0;3@g01TQ900N9RT072@W01/S9P0P:2/07RHY01dU:`0O:3406b@]
01hW<00^=d008b`e01lX<@0K92d072D^00806b@]00T072D^01`U;@0N9bh08R/b024Z<00M9R/07RL/
01hX:P0J92H00P0J92D06P0[=CH08B//02Pa<00G81l0624P01TR8@0M9RD06R<R03U2@@0X<C00624P
01/T8`0M9RD06B8Q024[;00O:BX0628S01hV:00I8B<072@V01`Q900O92L07B4T01XN8@0K7b805ATL
0P0F6Qd0100H71l06QhQ01TM800F6Qd201PL7`0D01HJ7@0H71l05a/N010D5`0D61/05QXM01`P8`0/
<3<082@W00hB5@0L82<05ATL01<G6P0D61/05QXM01LK7P0G61`05QLK01@E6@0C51P201DF6P07014B
5P0P8BD04Q<G01`M8@0T9BT05QLK01DF600201HG6@0601LH6P0F5aT05QLI01@E5`0G61X06Q/M0P0K
71h00`0J6ad061TM01TJ7P0201XK7`0E01PI7@0G61`0ATM;01dN8P0A4QH05AHJ01`M8@0P8BD051@F
01dM7`0T92H06a/M01@D5P0I6A/0;Rh`010@4P0D51H05aLI00l?4@0A4A<04Q0A0080518C00X04@l@
010>3`0A3a00:bTZ01TG600J61T07A/L010>3`0=2@T04P`<0P0D3Ph02@0C3@d05@l?01LA4@0`:RX0
6A<C014;2`0>20P06Q@D010:2P0200l92@0401<=3@0B30`050h>01D?3`8040X:00X04P`<00h8200?
2@T050`=0147200=0`@05@/<0147200>1@D05@/<0`0C2@X00`0B20T04@L80147200501472006034W
:01gKFh060h?0147200C2@X03`D60P0A1`P00`0C2@X050X;01<92P0700l51P0<01<8300=0PH03`D8
01462P0<0@D04PT;00X10`0E2Ph04@L:00l4200A20X03P@70`0@10H00`0?0`D03P8400h2100200l3
1@8040@60P0A1@L20104200301862P0A1@T03`<700L03`<75?ooool001_ooooo02D020L3018A3@1;
BTH02PT501@C3`0E51003`h:00h=2@0=30P030/700l>2P0E51005QDC061OG@0=30X030/901lN700H
5aD020L500l>300E51804A0>00L6100E5A<07B@T010D4`0730P0410<01TF4@0>2`@0514801HC300C
40T02`X500`=200?40/03`h900803Pd800<040l:018A300C4Pd01P0>3@P0600A40`02@P400`;1`0G
5Q803@`800P70`0@3`/03Pd900l>2P0@3`/03`h:00`<1`0A4Pd01`P3014B3@0720<01PL2018C3P0;
30L04Q<>00L81@0N7aX0<34/00d>2@D030d800L04A8=00/<1`082@@0824L02d^:@0J6aH02PX50080
4Q4<00<030/600d<1`0>3@P00`0=30L06P0A40/04a8=018A300@40/03Pl900`=1`0310000@8000X;
1@000@002``6018C40041@00414;01DF4@0>3@T030/7010?2`0P7a/04Q4=07UhM00I61@04A0<00d<
200?3PX03Pd90P0@3`/02`081`<04a8>014@30071P8020L301XI5@0E51003@`800h=2@0B4@d051<?
00<030/700T051<?01XI5@0B4@d04a8>00`;1`0=30P040l;00l>2P0<2`L01@0>3@/01`0?3P`03Pd;
00d<2P0=30X03Pd;00l>300@3`d00P0?3`d0600A4@l03Ph<00/;2@0?3`d02PX800`<2P0;2`T02@T7
00P81P092@L02`/901<C4@0B4Q002PX8014A3`0?3`d04A4?00T91`0:2PP03`l=00h>300;2`T03@`:
00l>30803Pd;01X040l=01<B400920H020L500l>300920H03Pd;01HE4`0B414061HG01hL7@0D4Q<0
3`d>01TG600M6a`02`T:018@4@081PL03@/<01PF5`0D4a403@`:00L6100H5aD02@P601PG5@803@`:
00X03Pd;00d<2P0=30X01`H500h=2`0=30X04A0?014@3P071P@02@P60P0>3@/300l>300=00h=2`0;
2PP02PT700`;2@0=30X030/900X91`0=30X04A0>00`;2@01000010<1018?3P0300l;2P08010<2`0?
2`X03`/:00h:2@0<20L040`;01dI600P71/2010<2`0300d920091@@02PH500L040`;00D02@P600h=
2`0=30X02`X800h=2`0500d<2P0@00h=2`0@3`d02@D600`82@0J5QL0BTI7038^;`0n>S/04@d>01HB
4`0>2P/020@500X61`0D3a803P/B00/940805a@K01H03@`A01HD6@0<2Pl04@lC00d;3P081PT03`d?
00h<3@0820X04Q8D00`<3P0;2`d0K6a^09:BU00B4Q@03`lA00/;3@0<30h03Ph@00l?4@0<2Pd03`d@
0P0A3a807P0?3A0030X=00H41`0=2`h04@lB00X82`0;2@`07adP00X82`0G5QT01`P:00dA4P0Y;bl0
_/C408jDU00>4Q<01`/<01XJ700;2@`030X=010?4@0C4A@04Q8D00`;3@081PT02PX<01LF600F51L0
4a<E018A50802@L:00@0518C01LE5P0B41403`d>0P0@3Pl00`0:20T03@/<00d;300200T7200300X8
2@0=30X030/9008030/900<02`X800h=2`0?3P`0100?3P`0100?3@d03P`=00h<3@0?3@h2010>3`0X
00h<3@0=2``03`d>00h<3@0;2@X02PP900d;300;2@X02PP9014?400E4a@04@l@00h<3@0?3@h03@/<
00`:2`0>30d04@l@00/92P0G5AH03`d>01TG600C4A800@00018@4@0>30d030X;00h<3@0?3@h03P`=
010@4P0=3@l02`/=00l?4@0A4A<03`lA010@4P0B4Q@02PX<00P82P804A4C00H06APM00h=4P0?3Q<0
40lD00h=4P0:2@h2010?50@03`hC00H04a8H01dL8P0F5AX061LL018A5P0>3Q0200d=3`0K00l?3`0C
4a<04a<C010@400C4A804Q0A01<A4P0D4Q<04Q0A00d;300610D06aTJ03`j>`0Z:2T040h?00l=3P0F
5QH04Q8B00h>3P0D51@06QXJ01<C4`0J6QX04A4A01XJ6P0I6AT03Ph>00805QHF01403@d=010@400D
51@04A4A00h>3P0D51@04Q8B014A4@0F5QH06QXJ01<C4`0C5A@0418A01<E500D5QD06Q`K02<U9003
01@F5@0401DG5P0G6AP06A/H01TI5P<06A/H00h06QhM01`P7`0c=cH0<CLg01PN7P0N92@0?DE701/S
9@0I7R4061dP01DJ7@0I7R40724T01XO8P80724T04D05a`O01/P8`0J7b805AXM01dR9@0O92L06b4T
01PP8P0L92L0;CDi020Y;P0E7R<08R`b01XU:`0H8bT08R`b01PQ9P0M9R/0;3Dj07N0Q@21RXl06b@Y
01PQ9P0L9BX06R<X01`U:P0O:2d06R<Y028/=@0[=Ch05R0Y02<]=P0L9Rl0:38k01/U;P0G8BX07BL`
02<]=P0Q:c@07BH^020W;`0S:S807bH]01XQ9`0Q:2h0620S02H^<@0_=cT05QhP01/S9@0P:2X05b0O
01`U900[=3<09c0_01hW9P0Q:RT06b@S01HO7P0J8b808BXY01hW9P0I8R405R0Q01TS900K9BH082PZ
01@L7P0E7Al00P0L8B@07P0N8RD06alR01HJ7@0F6Qd04QHI01<G6P0H71l06QhQ01PL7`0C5aX061`O
01TM800E6A`04ADH01DI700P92L06alR018F6@0830l06QhQ01@H6`0>4QD06alR01HJ7@0J7R406alR
01HJ7@0G6ah06Q/O01PI7@805AHJ00X05aPL01PI7@0@4AD0:BX^01XK7`0H6Ad07AhR01hO8`0E5QP0
5QLI0`0G61X00`0E5QP05QLI01PI6`0201TJ700301LH6P0F5aT06a`P00<06AXN00T06Q/O01/L800M
7R806AXN01DF6P0?41@06AXN02LX;00C4aD00P0B4Q@0600>3Q004A4C01LG6@0N7R004Q8D00/;3@0C
4aD05QHH010@4P0B41405A<D01@B4`0B41404@l@018@4@0E4a@04@l@01HD5@0J61T05Q@E01@@4@0D
3Ph05Q0@01@>3P804@/;00L040X:00d71`0F410040X:01@>3P090`<05a4A00<04`d=01005@l?01LA
4@0D3Ph03`T9010:2P0A2`/03@L700l92@0H41007A<D0147200F30d06a4B00h41@0B20T04`T:0P0B
20T80147200601H<3@0U6a`04`T:01061`0B20T030830P0>10D0100?1@H03P@500h41@0>10D600l5
1P803P<700@04PL;00P00@0?10P0DdQ<0P0?10P0100>1@L0:b0T01052@0F3@l301041P0400l31@0>
0P@03P8400l31@<040@60P0A1@L01P0=0@D0304401@8300E2@d04@D901<72`H03`<75?ooool001_o
oooo00T04a8>00L60`0J6AD04A0<01<B3P0<2`L03`h:00d<200?3PX00P0>3@T06P0D4`l03Pd;03He
<`0100002@P600D40`0C4Q003Pd;00d<2P0A40h03Pd;00L6100H61H0;C@d00`@3`0<4@d04A4=01TF
4@0B3`P04Pl601@A2P0B3`P03@`700d>2@0@4@`03`h90P0>3@P00`0@3`X04A0;018A300600h=200H
00l>2P0;2PH02PT500d<200?3PX03Pd9010?2`0=30P03Pd9014@300?3PX03Ph9014B3@0<3@P03Pl:
00X;1P051P402``700X;1P0F5a802P/603Tj=@14AD002P/60P0<3@P0100=3PT04A8=01@E400B4`h2
00/<1`0<01DF4@0L7AP05aPC00l?2P0C4Pd05A@?00h=200=30L04A0;00l>2@0;2PD03@`70P0A40/0
800?3PT03`l:010A2`0B4`d02``600`=1`0>3`T07b0J038c;@0Z:bD02P/5014B300;30L05A@@00l>
2P0>3@T02`X60040000m?3P05QDA00h=2@0:2@D03`h:00h=2@0=30P010<001<B3P0=30P07A`H00L6
0P0C4Ph02`X60P0:2@D03`0=30P03Pd900h=2@0@3`/04A0<010?2`0B4@d05A@@00h=2@0?3PX030/7
00d<200@3`/03`h:00/:1P0200h=2`803@`:00D03`h<010?3@0?3P`03`h<00d<2P0200`;2@0400d<
2P0:2PP02`/900l?3@803@d;00@05QHD00/;2@0=3@/030`:0P0;2`T03P0<30X01@D301DE4`000000
2PX800`<2P020P004Q8@00X:20092@L03@d;00l?3@0>3P`03Pd;0P0?3P`0300>3@/04A0>01<B400B
4@l03`h<018A3`0F5A<02@P600X91`0>30d0518C01HD5@8040h?00d05Q@E044o@0071@H03`d>00`:
2`0:20T04a4B010?3@0;2PP01`H4010?3@040`4030/900803@`:00d03Pd;00d<2P0=30X03`h<01`K
6@0B4@l03Pd;01@C4@0?3P`04a8@00h=2`0=30X03`h<008040l=01803Pd;00`;2@0;2PP030/900d<
2P0<2`T03Pd;00d<2P081`D05A@B00h=2`061@<040h<00l;2P0>2PT040`;014=300@30/200h:2@04
00/71P0:1PD04`l>01LC4P<03PX900<030P700d9200B3Pd01P0@30/02@0<2`T05A@B01<B400:2@L0
3@`:00`;2@0A40h040l=00h=2`0200`;2@0W00/:200H51D03`/<00X61`0L61T0100100/820070`@0
4`l@00l;300<20T01`<400X6200100D040dE01HC6P0C41L04@hD00d;400;2@h0518F010>4@050`H0
40h@00d;300D51H04Q8D00`<3P0K6ad0GEeO08J6R00B4Q@03Ph@00`<3P0=3@l03Ph@00d=3`0>30l0
40hA00804@lB02L040hA00h<3`0?3A005aDH014?4P0D4QD04@lB00`:3@0>30l03`hA00L72@0G6A/0
5a/L08N=S@1VK6`020`=00d>400?3a401P@700X82`0A3a804PdA00l=400>2Ph03`X>010>4@0B3a80
1P4500@21@0C3a<061<G01HD5`0B4140518C010>3`0>30d03`d>00d;300>30d00P0C4A801`0>30d0
3@/<00l=3P0<2`T02`X800h=2`0@3`d00P0A40h500d<2P0:00h<300>30d03P`=00l=3P0A3a004a4B
014?400>30d040h?00h<3@8030X;00H03P`=00`:2`0;2@X04Q0A01DC500A3a0300`:2`0K00h<3@0A
3a00518C00l=3P0H5QL03`d>00`:2`0?3@h01@<400h<3@0?3@h04@l@00h<3@0=2``03P`=00h>400<
30h03@d?010@4P0B4Q@04a<E00000P0S8bD03Ph@01XJ70030`D03`lA00803`hC00H01`H;01<B5`0@
3a@061LL010?500?3Q<200h=4P0800l>4`0@3a@03`hD00d<4P0:2@h030/@014@5@0F5QP2014A4`0H
018B4P0D51@04Q8B00d=3@0C4A804Q0A01@B4`0E4a@0518C00l=3P0E4a@04a4B02@R8`0M6a`0518C
00h<3@0C4a<04Q8B00h>3P0A4A405ADE00l?3`0H61P03Ph>0`0?3`l01@0J6QX05ADE00l?3`0A4A40
51@D00804A4A0`0G5aL02P0M7Ad08b<S01`L700A4a803a4@01@F5@0C5A@05ALF01hP7`0D5QD201DG
5P0501HH5`0I6aX06adJ01PI5@0J71T00P0K7AX02`0J7Qd0720O01PL6`0P9RH041HF01LM7@0S:bd0
2Q8D01dR9@0J7b805a`O00806QlR00D05AXM01PM800G71l041DH01TN8@0201lT9`0I01hS9P0M8RD0
6R0S01TQ8`0L92L06b<W01HO900J8bP07bT^01TT:P0H8bT06bD[01dV:`14CE809Bhc01hW;00h@DH0
6B8W01`U:P0M9R/072DZ01TR9`0P:Bh08R`c024[=00202/e?P0Z04E?F00M9c006bD^01`V;`0H8R/0
7RPa02H`>@0T;SL082P`01lV;P0P9bl06b8Y01PO9@0Q:2h0620S024Y;00Z<S@0620R01hV:00L92H0
7bPW02`e=00kA4<0;CHe01hW9P0R:bX06b@S01PQ800J8b8072DT01XS8P0M9RD07bTZ01hX:@0M9bP0
8RX/01PP8P0T;2h08bP[01lT9`0R9RT082@W0P0H71l05P0B5QT05ATL01XN8@0H71l05QXM01@H6`0H
71l05ATL010D5`0?4aH092P[04=7BP0Q9BP0:blb028V:@0J7R4051PK01hR9@0J7R405QXM01lS9P0P
92L201HJ7@0301XK7`0I6Qh05aPL00<05aPL00H05AHJ020Q9@0M7R807QlS018C5`0A4QH201PI6`80
5aPJ0P0F5aT00`0I6Q`061TK01LH6P0201LH6P0J01HG6@0K72006AXN01PI7@0I6Qh06Q/O01/L800C
51P061TM01lP900J6al030dA00P93@0@41806ATK01dM7`0H61X0410B00d=3`0A4A<02@T;01HF600H
61X0410B01DE5`0C4A8201DC500I01<A4P0B41404Q0A01hL7@0D4Q<03`d>00T7200:20T04Ph>01D?
3`0G4A405@l?014;2`0?2@T040X:00H0000G4A404P`<01PB4P0400006A<C01PB4P0G4A404P`<01<=
3@02018<3003010:2P0A2`/05Q0@00804P`<00T04PX;020F5`0:004040H7048h>@0[8B8040H701<9
2P0B20T00`0A1`P00`0B20T04@L8014720030147200701061`0700003`D600L0000B20T040H700l5
1P0201061`803`D600<04PP900l51P0?1@H0100?1@H0300<0@D03@8601@93@0?10P040D903/`=00<
0@D081DI01hC5`0700002@0201@93@<040@600<03`<500h2100>0P@00`0@10H201451`070186200>
0PH0304401D93@0F2Ph040@801@8300600l31aCooooo000Kooooo`0?00X91`0D4`l051<?010?2`0?
3PX04A0<00h=2@0=30P04Q4=010?2`0<2`L04A0<01PG5@0:2@P04a8@008030/:01<02PT8010?3@0?
3P`040l=014@3P0R8Al0A4A20=?KfP0[;bh05Q/G00d>2P0A3PT03@X3018?1P0A3PL040d600d<1`0=
3PT03Pl:00@03`h90P0@3`X600h=200O014@300@3`/04A0<00d<200?3PX02@P500l>2P0B4@d04A0<
00h=2@0?3PX03`l;00/<1`0C50l03@h9018C3P0>3`X02``700l@2`092PH04Q<>00P91P0J6aH0=3D`
014B3@0>3`X030d800h?2P0B4`h04A8=00/<1`0200X;1P0900`=200>3`X0410;018A300A40/03Pd8
018A300C4Pd040l:00803Pd800P03`h9010?2P0?3PT0410:00D6000=3PL05aP@00T:0P803a0800P0
1`P400h?2@0A4PX0414900d>1`0?3PX02`X600l>2P8040l;0P0A40`03@0>3@T040l;010?2`0<2`L0
40l;01/J5`1@Cd/03@`901@C3`040`403`h:00h=2@0=30P00`0>3@T200d<2005014@300B4@d040l;
018A3@0?3PX00P0>3@T200d<200:00l>2P0>3@T03Pd;00h=2`0<2`T03@`:00l>300A40h040l=00l>
30<03Pd;00P03`h<00/;2@0;2`T03@d;00/;2@0=3@/06ATG00/;2@803Ph<00T03@d;00h>300@40h0
2PX800h>3@0>3P`03@d;00l?3@0:2PP00P0=3@/08P0<30X02`/900/;2@0<30X03Pd;00l>300>3@/0
30/900h=2`0@3`d03Pd;00d<2P0;2PP0D4m=03Lf=00C4Q003@/<014?400<2P/03`d>01DC500C4A80
8R0Q00X82@0C4A803@/<00`:2`0>30d03Pd;00`;2@0@3`d04a8@010?3@0:2@L200d<2P0U00h=2`0=
30X03@`:00h=2`061@<03`h<018A3`0510803@`:014@3P0=30X030/900l>300B4@l04A0>00h=2`0=
30X030/900d<2P0>3@/03@`:00l>300:2@P05aHD02h]:`0L6aT04Q4?014>3@0@30/03PX9010<2`0B
3Pd04@d<00l;2P0D40l05A4@010<2`0200l;2P03010<2`0A3@`04Ph=008040`;00<04`l>010<2`0@
30/0100@30/01P091`P061HG01PF5`0:20T03@/<014?40803`d>01403P`=00`:2`0<2P/03@/<01@@
4@0F4Q<03`/<00T61P0F4Q<04@d>03/g>00f<S<04@d>00l;300=2@X04`hA00l=4P0200`9400600h<
4@0@3Q<04a4F014?4P0:2@/061HH0P0=2``0100B4140518E00h<3`0;2@`200l=400701PF6@0B41<0
3`d@00l=400A3a8040hA00`:3@0200l=40803P`?0P0?3A009@0>30l04@lB00d;3P0D4QD030X=010>
4@0B3A402`T<010@4P0=3Q00310A00dA4P0?4a@03@h@01DF600=30h0514D00h93@0?2P`04`d?018=
3`0B30h04@/=00l:2`0@2``050h@01HA4`0=20X050h@00d92P0<2P/02`T:00X82@0?3@h040h?00/9
2P0@3Pl00P0F51D01@0@3Pl03`d>014?400=30X02PT700803Pd;00<03`h<014@3P0>3@/0100>3@/0
1P0?3Pd03`d>00h<3@0=2``03`d>010>3`804@l@00P040h?00d;300<2P/03P`=010>3`0=2``02`T:
00d;308040h?00<03P`=00`:2`0=2``00`0?3@h0200A3a002`T:01@B4`0@3Pl020H7014?400<2P/0
3P`=0P0?3@h09P0>30d040h?014A4`0B4Q@04A4C00d=3`0<30h03`lA01<C5@071`T03`lA00X:300Y
:B/0<30b01<B5`0X9b`040lD01PG700@3a@0=C@i00l>4`0>3A803@`A00h=4P0@3a@04a8G01XI7`0=
31804A0E00`;400B4AH0410B01@D5P0B4Q@04A4A01<C4`0E5AD051@D0P0?3`l01@0B4Q8051@D01<C
4`0?3`l06ATI00804A4A01403Ph>01LG5`0@41003@d=01<C4`0A4A40410@01<C4`0?3`l0410@018B
4P0A4A404Q8B01DE5@0D51@05ADE01<C4`0201HF5P0?01<C4`0F5QH05ADE01dM7@0I6AT04Q8B01@D
500F5QH05ALF01TK6P0R92<06Q`K00lA400E5aH05aTH00806Q`K00L05aTH01PJ6@0I6aP05ADB01XJ
600L71X06a`J00806adL04X05QXI01TM7P0H71d06R0P00hC5P0G71l06AhQ020U:00L8B@06QlR01`Q
900K82<09BX]02db=@0l@D@08RLZ01HK7P0P9BP07b@W01dR9@0O9RP07bLY01`T9`0K92P092db02L`
=@0M9b`06bH/01lZ<00P:Rl06R<X02L`=@0X<CH082T^01dV:`0V;c@05b0U028[<00e?T<09Rld02D^
<`0S;C@06bD^02Pb>`0Z=3d0DUaU02H`>@0K9Bh072H_01hX<@0L9Rl07BL`028/=@0R:S807B4Z01hR
:`0L82P06QlU01hS:@0Q9RX07B8V01dR9@0L8B@0:Rlb01hS9P0K8bD07bLY02Ta<`0J8R@06b<U024Y
:`0R:R`06b<U01LO8@806R8T00h07BDW01/U9P0I8b@06B<T01lW:@0H8280;cLi02X_<P0L8B@07B4T
02@X:`0K7b804aLJ01PL7`80720S0P0C5aX00`0N8RD0720S01LK7P0201PL7`0?01lS9P0_<cH05QXM
01/O8P0P92L04aLJ01DI700G6ah06alR01@H6`0M8B@07R8U01DI700G6ah05QLK00<061TM01/05QLK
01@E6@0D5AT061TM02HW:`0R8bL06Q/O04e>DP0O828071dO01LH6P0F5aT05aPJ01PI6`0K71h061TK
01HG6@0H6A/071dO01hO8@0F5aT061TK01XK7@0I6Q`05QLI01DF600I6Q`00P0E5QP01@0D5AL05AHH
01/L7P0G5aT05ADG00804Q8D00H051@F01DE5`0C4aD05aLI01<C5@0A4A<201<C5@0=01<A4P0E4a@0
5A<D018@4@0A3a004Q0A00d<300C4A806QPI01LE5P0?3@h03`/<01<=3@0201H@400<01<=3@0A2`/0
3`T901XD500=1`L03PP8018<300C3@d03`T901@>3P0C3@d03PP80P0C3@d03`0A2`/03PP800h8200G
4A405Q0@014;2`0@20P060h?00L0000G3@h0<2HW01X@4@0F30d050X;01882@02014720804PP91@0A
1`P0300E2``03@D501<92P0700006a4B0147200?1@H04@L801882@0@1PL04@L801P>3`H03`D600`0
50T=01052@0@1@T040D900d21P0=10H03PD701052@18?D40;R@W01892`0E30h301041P0300l31@0>
0P@03P84008040@60P0A1@L20186200601@8300?0`L060`@01L;3`0=0@D040@81P0?0`LDooooo`00
6oooool0300B4@d05aHB01HE4@0B4@d03Pd900l>2P0>3@T02`X6018A3@0>3@T04Q4=014@308040l=
02803Pd;00l>300A40h04a8@018A3`0A40h051<A00d<2P0J6AL092@R05ELG00C5aH05a`H014B3P0:
1`806AH?01@A200A3PL040d600l>2@0@4@`04A8=01DD400G5Q80D4m;02HU8@0?3PX030/701<B3P0<
2`L02`X600l>2P0@3`/03Pd90P0?3PX07P0@3`/03`h:00/:1P0920@03@`801@C3`0@3`/03@`800/:
1P0=3@P030d800h?2P092PL02@X5020Q700720@0414<00`=200=3PT04A8=01@E400H6A@04A8=00l@
2`0;30L02P/600h?2P0A4Pd04Q<>014B3@802``700/03@h900`<1`0@3`X051<>010?2P0A40/040l:
00T80`0A40/04a8=00`;1P02014@2`0E00X:100?40P04a@<00h?1`0<3@D041490001000W:20020T1
01HG3`020`003a0800T8100<2`L03`h:00`;1`0;2PH040l;00/:1P0C4Ph05A@@00804A0<00T030/7
020O6`0h=c<04Q4=00P70`0A40`040l;00d<200?3PX00P0>3@T02@0A40`03@`800T8100?3PX040l;
00l>2P0C4Ph030/700h=2@02010?2`0600h=2@0?3PX040l;00H50`0?3P`04a8@0P0B4@l03P0?3P`0
40l=00d<2P0;2PP03Pd;00l>300920H01`L500`<2P0:2PP02`/9018B40051@<03@d;0P0>3P`01P0=
3@/03Ph<014A3`0=3@/03Ph<00`<2P802PX800@030`:00h>300=3@/030`:0P0=3@/0500>3P`02`X8
00h=2`0B4@l02`X801LF500=30X040l=00h=2`0=30X03`h<014@3P0B4@l02`T:00h<3@0:20T02`T:
00d;300;2@X030X;0P0?3@h01P0;2@X02@L800X82@0>3@/03@`:00`;2@803@`:00d03Pd;01HE4`0B
4@l03`h<00T81P061@<04A0>00`;2@0:2@L03@`:00P71@0;2PP03`h<00803@`:00X03Pd;00d<2P0=
30X03@`:018A3`0@3`d01`H400h=2`0A40h03Pd;0P0@3`d0100?3P`03@`:00h=2`0>30X200h:2@09
00l;2P0@30/040`;00h:2@0@30/04@d<00d9200A3@`030P700804Ph=01l040`;00l;2P0?2`X03`/:
01HB4@0>2PT040`;00X61@0=2@P04@d<00/92P081PL02`T:00d;300:20T04@l@00h<3@0=2``05A<D
014?40071@H04a4B01HB4`0@30d03@T:00l;300>2P/04Ph?02l[;00V8R<05a<D00803`/<00T03PT<
01<A5P0610T04Q0E01PF6`0610P02`T<00`:3@0=2`d00P0>30d0900?3P`040h?014?4P0B41<020H9
00d;3P0<2Pd03`d@018@4`0?3A0040hA00d;3P0?3A007adP03hl?`0A3a802`T<014?4P0:20/0518E
01<A500A3a8081hQ02<Q900D4QD03`d@010;3`0?2`l030`>00`=3`0;3a00310A00T=3P0;30h030`>
00d;3P803`X>00L030H800l92`0A2`d04P`>00l92`0>20X04`d?00805@lA00L04`d?018<3P0B3Pl0
3P/<00T720081PL030X;00803`d>01P06ALH00`:2`0<2P/03`d>00D3100:20T02PT700L6100;2PP0
4a8@014@3P0?3P`02PT700l>300>3@/01PD300`;2@0A40l00`4200D3100>30d01P@500h<3@0A3a02
00h<3@0400`:2`0;2@X03@/<00d;30802`T:00h030X;00d;300=2``03P`=01hL7@0:20T030X;00L5
1P0<2P/03@/<01<A4P0A3a003P`=018@4@803`d>00L04a4B01TG600@3Pl030X;018@4@0A4A<04a<E
00803`lA01h04a<E00/;3@0>3Q003`lA010@4P0?3a40410B01<C5@0S8RL09RDZ01LF6`081``03PdB
00l>4`0A41D02`X?051?E0081``00`87018A5P0=31805aHL00d<4@0A41D06aXO00L72@0A4A<0410B
010@400?3`l2014A4@803Ph>00<030`<00/;2`0=3@d00P0@4102018B4P09010@400A4A404Q8B00d=
3@0F5QH04a<C01HF5P0B4Q806ATI00@051@D00@04a<C014A4@0@41004Q8B0P0E5AD03P0B4Q80410@
01LG5`0H61P04A4A010@400C4a<04A4A01@F5@0O8B00<38a02DW9P0C5A@06Q`K0`0G6AP02P0I6aX0
6Q`K01/M6P0L6aP05QDC01PH5P0F5Q@051HE01XL6`0H6QT201PL7@0301TM7P0I7B006QhQ00<082DX
01T07R<V01/P8`0J7b80LgQk03m4A`0X;C007b@W028W:P0D6A`082DX01hS9P0M92H06B4S028Z;@0W
;c<072DZ02Xc>00T;S@06B@Z02<^=00H8bT092le01TT:P0N:Bl08bhd00807RT_00<092le024/<P0O
:S000P0V<CL0500U;cL09C8j02@a>@0R;cL08Bhf028_=`0I9Rh07R/c01l/=00Q;SH08c0h01XW;`0L
9Bd07R8[01lS;00O8b/07R<Y024V;00P9BT06QlS0P0M8RD0900F6ah08RLZ01/S9P0`>3/0<SXm01TQ
900K8bH0Ri>F06ifN@0O9bX06R8U024Y;00M9BP06B4T01dW:00O:BX05R0Q02H^<00M9BL05QhP01`Q
900M8RD07B4T01TM800G6ah061`O01lS9P0@51L06QhQ01dQ900G6ah07B4T014E600F6Qd09b/^02HZ
;@805a/N01h05QXM01LK7P0C5aX05QXM01/O8P0G6ah05ATL02DY;00>4QD082@W01PL7`0g>ch07AhR
01DF6P0C51P05aPL01/L800I6Qh05QLK01LH700D5AT05QLK01/L800H6Ad05QLI01@E5`0F5aT05aPJ
01PI6`0M7R0201PI6`805aPJ0P0F5aT0100B4aD05AHH01/L7P0J6ad201@E5`0401LH6P0E5QP051DG
01<D5P804Q<E01805ADG01XJ700H61X04a<E01DE5`0I6A/0410B018B500C4aD051@F01<C5@0B4Q@0
5aDF01PF5`0A3a005Q@E01LE5P0<2P/500l=3P0301<?3`0E3`l04`d=00804P`<0P0C3@d2010:2P09
01@>3P0F41004`d=01D?3`0?2@T02`D501D?3`0A2`/030H600<03PP800T03`T9010:2P0@2PX06a<C
01dC500C2@X06a4B01061`0J41400P0B20T0200@1PL04@L801<92P0C2@X050X;01H<3@0<0`@02@00
0P0C2@X04P0A1`P03@<400l51P0=0`@06@l@01`B4`0=0`@050X;00l71`0B20T01`0001@:2`070000
6Q0A01H<3@0900004@L800h41@`03`@800H03`<501D92`0?10D02P0001@82P0>0P@600l31@0500h2
1P0I3A408ADI01T=4@0>0PH00P0@10P01@0D20`040@800l31`0?0`L02@0101Cooooo000Kooooo`09
00h=2@0A40`04A0<00l>2P0=30P030/7018A3@0?3PX05QDA00803Pd900<030/7010?3@0?3P`00P0>
3@/03`0A40h04Q4?00L6100B4@l01`H401@C4@0@3`d00000024X:0031`H000<001<C3`0F4`h03``5
01<@1`02014>1`0<00l>2@0@4@`0414<018A3@0A40`0=SDa01TH500E510030/701HE4@0@3`/03@`8
0`0>3@T06`0<2`L040l;00l>2P0<2`L03`h:01<B3P0>3@T03@`800T8100>3@T04Q4=00l?2`0<3@P0
4A8=01@E400K71L0=3D`01HG4P0D5A003Pl:00X;1P0;30L02P/601<D3`0?40/030d800h?2P02014B
3@0700l@2`0>3`X03Pl:00d>2@0<3@P02P/600d=200201HE400A010?2P0A40/04A0;00/:1@0C4Pd0
5QD@00h=200A40/04Q4<00`<1@0?40P04a@<00h?1`0<3@D0414901<D300m?SH00P0D5@d01@082@40
3Pl800/:1P0<2`L03Pd900803@`800h03`h:00d<200A40`03Pd900/:1P0@3`/051<?00h=2@0Y:2@0
51<?00h=2@0@3`/01PD100`;1`802`X60P0:2@D0200<2`L03`h:018A3@0>3@T02PT500h=2@0:2@D0
3@`80P0?3PX200d<200700l>2P0B4@l040l=00/:200:2@L030/900h=2`0300X91`0:00d<2P0?3P`0
30/901<C4@0B4Q00410>00l?3@061P@05aLE00`<2P803Ph<00/030`:00h>300A4@l030`:00l?3@0>
3P`030`:00/;2@0<30X03Ph<00d=2`0200`<2P803@d;0P0?3P`01@0@3`d030/9014@3P0=30X030/9
00<02`X800D030/900d<2P0>30d03`d>00h<3@02014?400400d;30091`P03@/<00h<3@803@/<00@0
3P`=00h=2`0=30X030/90P0=30X02`0>3@/01@@300L610071P@03Pd;00/:200>3@/02`X801TH5P0S
8R0051<A00802`X80P0=30X02@0>3@/03@`:00d<2P0>3@/04Q4?01<B400?3P`03Pd;00d<2P0200h=
2`0500X91`0<2`T03Pd;00d<2P0=2PT00P0>2PT0300?2`X040`;010<2`0>2PT0510?01PD4`0>2PT0
1`<200/71P0B3Pd04@d<010<2`803`/:00/040`;00l;2P0:1PD040`;00d9200A3@`05Q8A01@B4`0@
3Pl04@l@01@B4`0200l=3P0800/92P0?3@h05A<D00X82@0<2P/0?3Xk01hJ6`0H51D201<?400?014=
3P0C3a005a<D01<?400?2``04@d>01DA4P0I5AH00P0502XX;@071@X040hC010>4P0C4A@03@/>0080
3P`=00X03Pd;00l>300?3P`061HI010>4@0>30l02`T<01HD5`1HEUT061HI0P0C4A@03`0A3a803@/>
018@4`0N71l030X=014?4P0C4A@02PP;00l=400>30l02`T<01LE600I5aX03@/>00/93002014<4005
00h<3`0=3@l02``>00P<3@0:3@h00P0<30h01@0=2`h03`X>00l:3P0A2`d04P`>00804`d?00<04P`>
014;3@0@2P`00P0C3@l2014;3@05014=3P0>2``02@L800X82@0=2``00P0>30d02P0K6AX04@l@020N
7`0=2``040h?00l=3P0;2PP02PT700`;2@0A40h2010?3@0<018A3`0=30X03`h<01dL6P0J6AL040h>
00h<3@0E4a@04@l@018@4@0E4a@03P`=0P0B41401@0@3Pl03`d>014?400@3Pl03@/<00803P`=0P0?
3@h04P0<2P/04a4B00T7200B41403@/<01@B4`0=2``040h?00h<3@0A3a005Q@E00h<3@0?3@h061HG
01/I6P0D4Q<040h?01@B4`805ADG00h03@d?00`<3P0B4Q@04A4C00h>400?3a40410B00h>400?3a40
4Q8D014@5@0G5Q/040lD00P730803`hC00`051<H00l>4`1>CE806APM01PG700C4QL01`H<01HE6`0B
4AH01`H;01@C600F5QP2014A4`80410@00T04A4A018B4P0;2`/04A4A018B4P0?3`l04A4A01LG5`0@
41000P0B4Q802@0@41004A4A018B4P0M7Ad03`l?00X:2P0>3Ph04Q8B00d=3@0201<C4`0601@D500C
4a<04Q8B010@400F5QH061PH0P0K6a/0100I6AT05aLG018B4P0D51@2014A4@0701LG5`0F5QH04aDD
01TK6P0S9B@06adL014C4P0301HH5`0>01LI600I6aX06A/J01XL6@0M71T061LE01XI5`0H61H06ATI
01dO7P0J71/06alP01`P8@0K7b0201TM80<07B8U01H0724T01XO8P0J7b80<3Dh01<H6`0P9BP06AhQ
01XO8P0T:B`07B8U01hS9P0Q:2X092`^030h>`0_>3`0624V01hW;00J92X06B@Z02@_=@0P:c409S4g
0P0L9bd0300O:S0082/a01hY;`0Q;3808Rdc01dX;P0Q;38092le02Lc>P0X=Cd09C8j02@a>@809C8j
00L08Bhf02Hc>`0P;CD07b`d024^=P0I9Rh07BD^00807b</01D082@/024V;00Q9R`08BHZ02<X;00h
?D00?D9502db=@0R9bX08RX]020X:`0N9RT06R8U020X:`1IHF@0@DU<024Y;00G7b807RHY01/S9P0Q
:B`00P0P:R/0500I8b@07RHX01XR900J8R@06QlR01/P8`0L82<061`O01HJ7@0H71l082@W01TM800H
71l04aLJ00dA500P92L05QXM01TM800O8bH07R8U0P0F6Qd0100C5aX06AdP01DI700C5aX201LK7P03
01lS9P0A5AP082@W008061`O00L0[K6d02PY;@0M7R805AHJ01@E6@0B4aL03@hB008061TM00L06a`P
01PI7@0B4aL05QLK018C5@0E5QP04A8D008030d?00<03PlA01/L7P0K71h00P0K71h201TJ700302X[
;@0G61X051DG00805AHH0`0G61X0300F5aT05AHH01<D5P0B4aD05ADG01TI6`0G5aT04Q8D01<C5@0F
5QP04A4C018B50804a<E00P04Q8D014A4`0E4a@02`T:01@B4`0I5aP040h?00h<3@D04@l@00<04`l@
01@>3P0C3@d0100B30`200l92@07018<300D3Ph04@/;00l92@0>20P03`T9010:2P0200X4100400h8
200?2@T040X:010:2P804@/;00H04@T901D;300900003`D600`20`0D2P/20147200400l51P0@1PL0
4PP9014720803@<401H06a4B01H<3@0800003@@401<92P0B20T05P`=00d3100@1PL030<401<92P07
00004PX:01@:2`0<0P<04@P901dC500900002@0101dC500B20T03@<4300?10P01P0J3Q007Q8D01H:
300>0P@04`L900d10`H03`<500`02P020104200E2@d040@800X00P0B1PX04@D900T00@0>0PH04PH:
01452@0G2`lDooooo`006oooool00`0?3PX03@`800h=2@02014@300500d<200K6QH03Pd901<B3P0>
3@T00P0@3`/0100?3P`03Pd;00d<2P0>3@/200l>300:01PG5@0@3`h01PD401DD4P0920H04Q8@034g
=`0F6QT01PX700h>2`804a0;01/04a07018?200B3`P040l:00l@2`0@4@`03Pd;00X91`0C4Q002@P6
01/J600<2`T04Q4?014@3P0?3P`03@`:018A3`0F5A<040l;01<B3P0A40`030/7014@300F5A404a8>
014@300>3@T00P0A40`0200=3@T03Pl:00/<1`0:2`H020T401PI50082@D04A8=0P0=3PT09`0?40/0
3Pl:01@E400>3`X02``7010A300E5Q404a@?014B3@0>3`X02``700l@2`0@4@`03@h9010@2`0D4`h0
4Q4<00h=200?3PT040l:00`;1P0B4@`05aHA00l>2@0>3@P040l:00h>200?40X04A8=00h?2P0=3PP0
3a0;00L8100X:B<02``700/<1P0:2`D03a0;00l>2P0200d<200400l>2P0@3`/03Pd900`;1`803`h:
00T03@`800h=2@0@3`/030/701`K5`0920@01`H200/:1P0B4@d00P0=30P0200J6AD06aXF00h=2@0@
3`/071/G01XI5@0C4Ph03@`80P0?3PX00`0<2`L03`h:00h=2@0200d<200400h=2@0B4@l03@`:00d<
2P@040l=00D03`h<010?3@0?3P`030/900/:200200d=2`0C00X:200B4Q002`/900T91`0<30X03Ph<
00d=2`0<30X03Ph<014A3`0<30X0410>014A3`0?3`d03@d;00`<2P0@40h03Ph<00d=2`0300`<2P07
00h=2`0;2PP020L500l>300:2@L04A0>00h=2`0300l>300400d<2P0<2`T030X;018@4@8040h?00<0
3`d>00/92P0<2P/00P0>30d200`:2`0400h<3@0>3@/03@`:00`;2@803@`:00X03Pd;00`;2P0@3`d0
3`h<010?3@0920H03@`:00`;2@0>3@/04Q4?0`0@3`d200h=2`0400d<2P0>3@/03Pd;00h=2`802@P6
00X03Pd;00l>300F5A<06APF00d<2P0:2@L03@`:010?3@0>3@/03@X9100?2`X02P0@30/04@d<00l;
2P0?2`X04`l>010<2`0C3`h04Ph=014=300@30/200l;2P0H014=300B3Pd03@T8018>3@0<20L03@T8
00h:2@0?3@l030X=00h<3`0@3Q403P`?00`:3@0@3Q402`T<00h<3`0A3a802`T<00X82`0E4A803`/<
00d92P0?2``03@T:0`0?2``0200A3@h04Ph?018>3`0@30d03P`@03@b=`050`P04@lB0P0<2Pd00`0@
3Pl03`d>00h=2`0200h=2`0W00d<2P0B3A005a8F010;3`0?2Ph07QTM04e8C00>2@d03`X>018=4@0C
3Q803PT=00d8300:20/03`d@010>4@0=2`h030X=00d;3P0A3a8030X=014?4P0B41<03@/>00l=400B
31004PdA018>4P0>3Q002@X<00L82P0;30h030`>00d<3P0?2`h040X>010:3@0D3Pl04P`<00804@/;
00T04P`<01<=3@0=1`L040X:014;2`0@2PX04@/;014=300=2``00P0<2P/0300?3@h03@/<00`:2`0H
5QL040h?00H51@0;2@X03@/<00/92P0=30X03Pd;00l>30803Pd;00/040l=00l>30081`D04a8@00@3
0P0;2PT0;2/Z00d;30091`P04@l@00/92P0200l=3P803P`=00@03@/<00`:2`0=2``03P`=0P0=2``3
00h<3@0@010>3`0=2``01P@500X82@081PL06aTJ02XX:@0e<c@05aDF00X82@0C4A804@l@01<A4P0B
41404a4B014?408040h?01403`lA010@4P0?3a40410B014A4`0@41803Ph@00l?4@0@41803@d?00h>
400A4A<03PdB01DD6@0F5AX04Q4F01HE6P0201@C600>014@5@0Z:Bh05A@I01`K800@3a@05aHL00l>
500G5Q/03`hC018A5P0G5aT04Q8D014A4`0A4A42010@4004014A4@0C5A@03Q0?00h@3`804A<B00@0
2`d<010B4@0B51<04Q@C0P0@4Q403`0B51<03@d=00d=3@0K6a/02`/;01<C4`0:2PX04A4A018B4P0C
4a<04Q8B014A4@0@41003Ph>010@400301<C4`03018B4P0H61P06QXJ00805QHF00/06ATI01LG5`0F
61L05aTH01@F5@0E5aH061XI01LI600E5aH05QPG01LI600201PJ6@0301TJ5`0N7AX06QTG00806QTG
00<06QXJ01dM7@0I6aX00P0M7R001@0H71d05a/N01TM800J7b806AhQ00806QlR0P0K82<07`0E6Qd0
6AhQ02<X:`0Q9RT06b0S02@Y;00R9bX07b@W01`S9@0J8R@082P[02</<00K92T07RL/024[<@0T;cD0
9C0f020[<@0J9B/09S4g028]<`0J9B/07BP^01hY;`0P:c408bhd01dX;P0L9bd082/a02Ld>`0U=3/0
0P0P;cH3028a>00H02He?00K:S407B`c02He?00M;3<082/b01lV;P0L8b/082L^02@[<@0P9bd09Bd`
01hV:@0O9bT08b/]01hV:00M9BL09Bd`01LO8P0L92L0620S01hV:@0O9bX0;cLj0P0N9RT0;00X<3<0
7BDX01lW:P0N:2T06R@U01dW:00D71h06b<U01hV:00F6ah061dP01XN8@0G6ah05QXM01PL7`0F6Qd0
:2`_01LK7P0C5aX08RHY038f>@0J7R407R8U01DI700B5QT05a/N01HJ7@0D61/07B4T01XN8@0E6A`0
61`O01/O8P0D61/06alR01dQ900F6Qd06QhQ01TM800L7B405QLK01<D600E5QX05aPL0P0F5a/0300I
6Qh07b0T01XK7`0C51P061TM01PI6`0D5AL05QLI02LX:P0`<C<061TK01XK7@8071dO00X06a`N01TJ
700G61X0:bd/01HH5`0C5A@051HE01<E500D5QD05QPG0P0H6QT0200F61L051HE018D4`0G5aT061PJ
01HF600B4Q@04A4C1@0C4aD0200A4A<0410B014?400F51D030X;02TW:00`;Rl04a4B1@0@3Pl01P0B
3Ph04`d=01@>3P0D3Ph04P`<014;2`<04P`<0P0C3@d0200B30`03`T901TC4`0N61P04`d=00l92@0C
3@d04P`<0`0A2`/2018<300401L?400e:b`07Q@E01@:2`8040H700@04PP901061`0?1@H040H70P0A
1`P05P0F30d03P@500l51P0=0`@030<404Hl?@0E2``04@L801882@0900403P@501@:2`0A1`P06Q0A
0107200E30d0JEmP01dD500O5AH060h?01@;2`0<0`@201061``03`@800D03@<401451`0>0`@02`01
0186200700l31@<04PH:00T03`<701452@0N4QH091PL00l41`0?0`L04PH:00/00`0?10L05?ooool0
01_ooooo00`040l;00d<200>3@T04Q4=01DD400B4@d0>3Lc01HE4@0A40`03Pd9010?2`0?3PX500h=
2`0>00d<2P0<2`T0HV5O02l^;00<2`T040l=01LG5@0=5A@05ATH01DJ5P0A4Ph02`P3014>1`0B3`H2
018?200Y010?2P0?40/03a0;00l>300<2`T051<A00/:200C4Q003Pd;00/:200>3@/03@`:00`;2@0B
4@l05QDC01@C3`0B4@d04a8>01HE4@0C4Ph03`h:00T8100>3@T030/700l>2P0B4@d0410<01<D3`0=
3PT03a0;00X;1P0E5Q403@h901LH4`0B4`h03a0;00`=200720<0414<014B3@0?40/00P0<3@P0200>
3`X04Q<>00h?2P0?40/06a`G01PI500@4@`03@d80P0920<07`0>3@P040l:010?2P0=30L04A0;01DD
3`0@3`X03Pd800l>2@0>3PT03Pl:00l@300>3P`03@h900h>2`0=3@/04Q<>00d>2P0A4@l01PL200X:
1`0A40`03Pd900d<200@3`/04A0<00h=2@0<2`L03@`8014@300?3PX00P0=30P05@0920@04A0<014@
300?3PX01@@000P71@0;2PH02@P401PG4`0I61@02PT500d<200B4@d040l;00l>2P0=30P02`X600X9
1@0>3@T040l;00l>2P0200h=2@03010?2`0A40h02`X800803@`:00d020L500T81P0:2@L01PD300/:
200=30X02`X8010?3@0<30X051@B01/K6@0=3@/02PX800802`/90P0=3@/02`0;2`T03@d;010@3P0:
2PP03`l=014A3`0@40h03Ph<00d=2`0?3`d03@d;00<030`:00T03@d;01lN700G5Q@03`h<014@3P03
0P0030/900/:200<2`T00P0=30X04@0:2@L02@P601<A4P0Q7b006aTJ00h<3@0?3@h04Q0A00l=3P0@
3Pl03P`=00`:2`0;2@X03@/<00h=2`0=30X030/900803@`:00L03Pd;01XI5`0?3P`040l=00H50`0A
40h030/900802`X801405QDC01`K6@0B4@l02`X800l>300>3@/03@`:00h=2`0?3P`04a8@00l>300;
2PP02PT700D40P0>3@/04a8@00l>300201DD4P03010?3@0?3P`03`d;00D03`/:00P030P700l;2P0F
4Q403`/:00<0000>2PT04@d<010<2`803`/:00T040`;014=300>2PT02PH501DA400D40l06ADD01`H
5`0;2@`00P0>30l02P0:20/02`T<018@4`081PT02`T<010>4@0<2Pd02PP;01HD5`0B3Pl200d92P09
010<3@0?2``04@d>00d92P0@30d05A4B01HB4`0C3a0040`=008030X=01405Q@G00d;3P0?3@l03P`=
010>3`0?3Pd03Pd;00h=2@0=30P030/900L3100E41@03@P<014<400<1`/0100300d83002018=4@05
010;3`0A31004`hB014?4P0B41<00P0:20/00`0?3A0030X=010>4@0200`:3@0Z00/9300<2Pd04@lB
00h8300A2`l04PdA010?4@0;30h02P/=00/<3P0<30h03@/>00l:3P0@2Ph040X<01@@400@30/03@T8
00h:2@0@30/04@d<00`81`0@30/04@d<010<2`0A3@`04`l>00h<3@0<2P/03@/<00l=3P0=2``02`T:
00H41@0:20T06ALH010>3`0200403`d>00l>300@3`d03`h<0P0=30X04@0@3`d03@`:00<2000A40h0
0@0002HU8`1UI6<07A/L00P61`0D4Q<03@/<00h<3@0?3@h03P`=00l=3P0>30d03@/<00803P`=1@0=
2``03@0@3Pl02PP900H41@0B41406aTJ03@b<`11?d00@T1101dK700;2@X04Q0A014?400D4Q<00P0?
3@h01@0B41404a4B018@4@0;2`d02PX<008030`>00D02`/=00`<3P0>3Q003`lA010@4P0200h>400C
014A4`0A41D051<H01<B5`0?3Q<040lD014@5@0B4AH06APM010?500;2Pl03`hC01<B5`0C4QP03@`B
018A5P0F5AX03@`A01/K7@02010@4P0;00l?3`0=3@d03@d=00h>3P0<3Pd05aTH01DG5P0;3@`02P`;
01DG5P0@4Q400P0B51<02`0@4Q404A<B018D4`1HF5P061PH00/;2`0?3`l0:2PX00d=3@0@41004A4A
00804Q8B00@04A4A010@400D51@05ADE100F5QH05P0M7Ad07alO01TI6@0G5aL05QHF014A4@0F61L0
6A/J01<E500K7A`08R@S01/M700E5aH05QPG01LI600H6QT06A/J01XJ600T8Al08AdL01dI600J6AL2
01XJ6P0701dM7@0N7b407AhP01/L7P0P8BD08bLZ01XO8P0201TN8@0T01/P8`0L8B@07B8U01TN8@0N
8bH05AXM01lT9`0M8RD082DX01/P8`0O92L07RDW01hV:00N9RT072@X020Y;P0T;C809Ble020[<@0L
9bd07BT`01LT;00d@DT0:3Dm01h[<`0J9bl08c0h028_=`0Q;SH08Rlg01l/=00M:S808Blf020_=P0J
:C006BP_0`0K:S40A@0O;SD05RD/01l^=@0/>d8082lf020/<`0P:C007BH]024Z<00U;S<07bP]01hX
:P0J92H072HW028/;@0P:R/07BLX028Z;@0L8bT09Rdc01LN900M92X072<Y01/R:00/<cT092/a01PO
9@1`Mgd0=3a001dW:00D7Ql07BLX01LO8@0M9BL0620R01DJ7@0F6ah061`O01HJ7@0E6A`05a/N02X^
<@17Bdh07b<V01LK7P0b=ST04aLJ01LK7P0N8RD05ATL01@H6`0L82<06AdP01@H6`0H71l05a/N01TM
800M8B@061`O020T9`0B5QT0=SXm01lS9P0A5AP0;C4d01TJ7P0F5a/051DI01DF6P0201HG6`0N018C
5`0J6al04A8F014B5P0J6al051DI01XK7@0F5aT06a`N02h_<@0_<3803PlA01LH6P0H6A/06AXL01PI
6`0F5aT05AHH010B4@0D5QD06A/J01LI600C5A@05ALF01<E500D5QD05ALF01@F5@0B51<04A<B0P0I
6A/01`0G5aT051@F018B500C4aD051@F01<C5@0B4Q@00`0A4A<01P0C4A8020H701PF5`0A3a000P01
00d;30D03`d>00L040`=018<300C3@d050h>018<300@2PX04@/;00804P`<0`0A2`/0200?2@T05@l?
01LA4@0?2@T04P`<01<=3@0?2@T040X:100?2@T0100=1@H0:b4R01D;300=1@D200l51P0?01@:2`0B
20T040H70147200C2@X04PP901061`0?1@H05@/<01@:2`0<0P<02`8200/10P08000050X;008040H7
00d03P@500l51P0@1PL06@l@00L0000U6a`02`8301D;300700005@/<02TO800B20T06@l@00`03`@8
00H04`L901@82P0A1@L03@4300h2100:000600l31@0301862P0@10P04@D900803P8600L05PX>01D9
3@0C1`/0300401862P0J3Q803@4501Cooooo000Kooooo`0400d<200<2`L030/700l>2P804Q4=01h0
:2LS00`;1`0?3PX030/700d<200B4@d03Pd;00l>300@3`d03`h<00h=2`0=30X03`h<02PW9@051080
5A@B010?3@0000001@X900hB4@042@D03Ph:01<@2`0>2`@04Pl6018?200C40T04A0;00l@2`0>3`X2
010?3@0?01XI5`0@3`d03`h<00h=2`0=30X03`h<00h=2`0=30X030/900d<2P0@3`/03@`8018A3@0J
6AD05QDA008040l;014030/700L60P0:2@D03Pd900P8100<3@P010D000`=20082@@04A8=00X;1P0A
4Pd03Pl:00d>2@0;30L01`P300h?2P02014B3@0A00d>2@0:2`H030d800h?2P0;30L04a@?02@U800J
6aH03a0;00h>2@0;2PD02PT4018A300C4Pd04A0;010?2P0B4@`00P0D4`h0100B4@`04A0;00l?300=
3@/300h>300:00d=2`0C4a402@T7018B400F5Q@02@T700`<2P0@3`/03`h:00h=2@803`h:00<03Pd9
010?2`0<2`L00P0;2PH05@0<2`L05QDA00/:1P0:2@D040l;01@C3`0>3@T081lK014@300<2`L03@`8
00/:1P061@404A0<00`;1`0;2PH03`h:014@300<2`L02`X600h=2@02010?2`0:00h=2@0?3PX040l;
018A3`0:2@L02`X800`;2@0A40h08R4O01dL6P803`h<01@040l=00X91`0<2`T04a<A00D5100;2`T0
3`l=00X:200?3`d02`/900d=2`0<30X02`/900`<2P0?3`d02PX800h>300@40h03Ph<00d=2`803Ph<
00l03@d;00`<2P0=3@/03@d;00h>300E51804A0>00d<2P0?3P`02@P600d<2P0<2`T03@`:00h=2`0?
3P`00P0>3@/0200B414081hO01TG600;2@X03@/<014?400<2P/03P`=0P0=2``01@0?3@h04Q0A00h=
2`0=30X030/900803@`:00L03Pd;03ln?00O7Q`05QDC0040000G5Q@03@`:008030/901L05A@B01dL
6P0B4@l02`X800l>300>3@/03@`:00h=2`0?3P`03@`:00/:200@3`d03`h<00P71@0:2@L030/900l>
300G5Q@05QDC00h=2`0?3P`04@h=010<2`0300l;2P0700h:2@0@30/03@T800T5100C3`h07a/J018>
3@02010<2`803`/:014040`;018>3@0>2PT02PH5014=300?2`X04`l>01HB4P0<2Pd040hA00h<3`09
1`X030X=00h<3`0C4A@040hA00X82`0200D31P0500L5200F4Q<04@d>010<3@0B3Pl00P0?2``03`0@
30d04`l@01LC500E4A804Ph?010<3@0I5aX08b4T02PV:@050`H040h@00P61`0?3@h03`d=00h=2`02
00h=2@0@00d<2P091@H03@P<01HA5@0K5QX05A0D02hY;@0C3Q8050lC00h93@0<1`/03@P<00/62P0=
2`h03P`?00d;3P8040hA00h020H9010>4@0@3Q403`d@00d;3P0?3A0050lC00h8300@2Ph04@`@010>
4@0=3@l030d?00`<3P803@/>00X03`X>010:3P0@2P`0510?014=300?2`X040`;018>3@0C3`h03PX9
0P0B3Pd0100A3@`04Ph=01<?3P0?3@h200d;300:00h<3@0=2``030X;01HD5@071@H0CD]<03Le=P0G
5AH04Q0A010?3@<03Pd;0P0?3P`03@0I61H04a8@00d<2P0100001@@2024O7`0@3Pl01`D600P61`0J
61T06ALH00P61`0=2``00P0>30d200`:2`0400l=3P0@3Pl040h?010>3`803`d>0P0>30d02`0<2P/0
7A/L01lM7P0Z:2T05aDF00`:2`030@803`d>01LE5P0@3Pl04@l@00803@/<00H03`d>010>3`0A3a00
4Q8D00d=3`092@/200L72@0L010@4P0>3Q003`lA010@4P0?3a40410B01<C5@0@3a@04A0E010?500=
31403PdB018A5P0:2@h05aHK00l>4`0<2a002`X?010?500=31800@0601PG702ZZJh0<C0e00l?4@0A
4A<0410B00l?3`<03@d=00T04A<B00H81`0;3@`06A/J01PJ6@072@P0418A01<E500B51<00P0A4a80
2`0C5A@0FEUI028R8P0C4a<06QXJ02l_;`0K6a/0410@014A4@0B4Q804a<C00804Q8B1P0D51@0300F
5QH06ATI01HF5P0E5AD05aLG018B4P0D5QD05QPG01@F5@0L7Qd0828Q01XL6`<05aTH03D06A/J01XL
6`0L71X09b@R02@P7`0O6aX07A`J01hN7P0L71`06a/K01dN800J6ad05aPJ01dN8P0Q9BP0720S01XO
8P0I7R406b0S01dR9@0N8bH07B8U01<H6`0I7R407b@W01TN8@0/<C@06QlR01lT9`0O9BP082PZ01lW
:P0O9b/0:S<h02H_=00R;3807bX`01`W;@0T<3L06bP`030mA@0M:S809C8j01PU;@0T<CT08c0h02@a
>@0Y=Sh0934i01h[<`0P;SH08C0g01d/<`0201PW;P0J01XY<00L:c8082lf01TX;`0Q<3L0:cY101h]
=00O:c808BXa01lX;`0Q:S008b`a01lX;@0F82805b4S01/U9P0N:2T07BLX01XT9@0S:S006b8X01`S
:@0K8RP08RT_020W;@0V;C<202T`=P0G01dT:P1hOhD0>D55028/;P0I8b@07BLX01/S9@0J8R@06b<U
01HK7P0G71l06AdP01HJ7@0E6A`05QXM01LK7P0`=3L06alR02DY;016BTd09BT/01DI700K7b800P0I
7B000`0M8B@0720S01<G6P0201DI700;01PL7`0K7b804aLJ01XN8@0D61/05ATL01LK7P0U:B`00044
01TJ7P0H6Ad0100F5a/0200C51P06Q/O014B5P0>3a<05QLK01<D600@4A<05QLI0P0L7Al01@0G61X0
3a0B01XK7@0J6ad06AXL00<061TK00L03a4@01DG5P0I6aX051HE01DG5P0K7A`04aDD00D04Q@C00@0
6ATK01PH6P0G5aT05QHH0`0D51H00`0B4Q@04A4C014A4`02018B500601@B4`0C4A807adN01LE5P0D
4Q<08AlP1@0A3a001P0B3Ph04P`<018<300B30`04@/;010:2P803`T900<040X:00l92@0?2@T00P0A
2`/01P0@2PX03`T900l92@0A2`/040X:00h820<03`T90P0>20P02P0;10@0718C00`20`0=10@03P@5
0147200C2@X04PP901061`0B20T301<92P0G01@:2`0=0`@040H701`B4`0K4A808ALH01882@0@1PL0
308301061`0J41406@l@00L0000>10D060h?01dC500D2P/04@L800L0000J4Q801`0000P0000=1@D0
300?10P00`0A1@L04PH801451`0201041PL03`<500`04@D90104200B1PX03`<700`0100@10P02`03
01@8300<00@04PH:01lC5`0<00@Dooooo`006oooool03@0;2PH03Pd900d<200<2`L03`h:01<B3P0B
4@d05A@@02TX900J6AD030/701DD400@3`d00P0B4@l01P0A40h03`h<00d<2P0?3P`030/900d<2P80
51<A00/03Ph=00lE500>4Q00310<01XK5P0A3`X04Q09014?1P0C40T04a4:018A300200h?2P0500h=
2`0B4@l04Q4?010?3@0A40h00P0=30X0<@0>3@/04A0>01<B400>3@/02PT700h=2P0<2`P03@`8014@
300B4@h04Q4=010?2`0>3@X05QDA02HU8@0J6AH02PX601DF4@0:2`H04A8=00T:1@0=3PT02@X600l@
2`0>3`X0414<00l@2`0:2`H03Pl:00d>2@0?40/05AHA01@E400?40/03Pl:00`=200=3PT051D@00h?
2P0@4@`07AdH01HE400>3@T04A0;00h=200<2`H03Pd800`;1P0;2PH00P0A40/02`0=30P030`900d=
300>3Pd03Ph>00h>3@0=3@`04Q8B00L71P0?3`l030`<00803`l>00P03`h:014@2`0B4@`03Pd900`;
1`0?3PX04A0<00d<20803`h:00X03@`701DD3`0B4@d020L300l>2P0B4@d02@P502DT800?3PX040l;
0P0=30P02@0?3PX040l;00h=2@0;2PH040l;018A3@0=30P03`h:00d<200200l>2P0=00d<200>3@T0
3`h:010?3@0=30X04Q4?00d<2P0?3P`09B@R02XY9`0A40h03@`:014@3P0200`;2@0B00/;2@1?Cdd0
5ADC01<C4@0>3P`03@d;00/;2@0=3@/030`:00/;2@0<30X03`l=00X:200=3@/030`:00/;2@0=3@/0
3`l=0`0<30X02@0>3P`0410>014A3`0;2PP030/900l>300:2@L04a8@00`;2@0300h=2`09014@3P0D
4a405A@B00h<3@0B41403P`=00d;300>30d03@/<00803`d>00L03P`=00`:2`0?3@h04@l@00h=2`0=
30X030/900803@`:01P03Pd;01HE4`0;2PP03`h<00L6100G5Q@030/9010?3@0>3@/020L500h=2`0@
3`d03`l=010?3@0>3@/03@`:00h=2`0@3`d02`X800h=2`0D4a403@`:00`;2@0?3P`200`;2@<03@`:
00D03Pd;010=300@30/040`;00l;2P0300h:2@0601TE500K5aH05A4@024M7@0C3`l040`;0`0?2`X0
8@0@30/04Ph=01DA400>2PT040`;00T5100<20L040`<00l=400?3A4040hB01XH7@0O7B404Q0D00d;
400>31003`dA014?500A3a<03P`@018>400=2@X03`/<018>3`0?2``040`=014=3P0C3a00510A00l;
300=2@X03`/<00X92`0200d;3P0@00`:2`0=2``04@l@00d;2`0>30/03Pd;00h=2P0?3P/040l=00l;
300C3A402`D9014;3`0A30l05A0D01@>4P803`T=00D071HJ028M8@0A31004a4D010>4@02014?4P05
00`:3@0?3A002PP;010>4@0?3A000P0=2`h01@0?2`l04`dA018=4@0?30l03P`?00<030`>0P0=2`h0
4P0?2`h040X>010;300>30T03@`900`;1`0=30P03`h;010?2`0>3@X040l<010?2`0?3PX03Pd:00l>
300B41403@/<00`:2`<03P`=00T05A<D05UGF00_;Bh071XK00d;300k>CX04A0>00`:200<2`T00P0B
40h03P0>3@/03`h<01HD4P0G5A<04A0>00h<2P0;2PT03@`;018A400@3`h05aHE01/I6P0>30d03`d>
0P0A3a0200h<3@<040h?00l03`d>00h<3@0>30d03`d>01/I6P0=2``06ALH01DC500A3a003P`=01<A
4P0A3a0061HG018@4@0;2@X00P0C4A80200A3a003P`=00d;300?3@l04A4C010@4P0G5aT05ADG0P0>
3Q001P0=3@l03`lA014A4`0B4Q@04a<E01LG6@804Q4F00T04a8G018A5P0?3Q<04A0E00l>4`0C4QL0
4A0E00P7300@3a@00P0C4QL01@0@3aD0410D01hM8P0B4QD06QXL008051@F00/04Q8B010@400@4100
410@01@F5@0=4A007B4P030d<`0X;2/020`;00lC4P02014E500700lC4P0@51<04aDD01PH600C4a<0
3Ph>018B4P0201<C4`03014A4@0C4a<051@D00<051@D00@071`L01/K6`0I6AT05aPH0P0F5aL02@0E
5QD06Q/J01PI6@0I6AX06a/L01HF5`0H6QT051HE01DG5P0201TK6P1;01PJ6@0K7A`05aTH01HH5`0I
6aX07AlN020Q7`0N7AX07a`K01TG5@0K6aT081lO01dL700O8200:2PY02HW9`0L7Qh06Q/N01/O8@0L
8R<06QlQ01TN800I7b80724T01`S9P0W;C008BP[02H]<00Q9bX0728U028Y:`0O9RP07b@X01TQ8`0N
9RT07bLZ01hV:`0Y<cL08BX_02H`=P0V<SP06R@/01l/<`0I9bl09S<k024^=P1;F600934i01h[<`0Q
;SH0:SLo030mA@0U<SX08Bhf02<a>00R<CP07bhe01LV;@0B8BP062L^01h]=00U=3X07R`c02<a>00[
>D008Blf020/<P0P:c408B`b020[<00N:Bd07bX^01`W:P0P:bd08bl_00807b/[03@07bX[020X;00Q
:Bd06b<X02<Z<00N9RX082L/028Y;`0K8bL08BT^020W;@0W;c<08BT^028[;P0P:R/06R<T01hV:00I
8B<0?TI801TN8@0J7b806alR01LK7P0E6A/05QXM01`P8`0J7R40720S01XN8@0M8B@05a/N01TM800F
6Qd06alR01XN8@0G6ah07b<V01LK7P0O8bD07B4T01TM800G6ah05ATL01<G6P0H71l07R8U01/N8P0L
7b<061`O01TJ7P0J6al06AXN0`0G61`07`0F5a/06a`P02`]<@0O82@0414E02l`=00/;Bl061TK01`M
7`0O828061TK01/L7P0M7R006a`N01LH6P0H6A/06Q/M01/L7P0F61L05ALF01PJ6@0G6AP051HE01LI
600F61L04Q@C014C4P0B51<05ALF01LI600F5QP00P0D51H0100E5AL051@F01<C5@0C4aD2014A4`09
018B500D51H05ADF01PF5`0J61T04@l@00h<3@0A3a003`d>00D040h?00<04Ph?01<=3@0A2`/00P0@
2PX02`0A2`/04P`<01<=3@0D3Ph04`d=01@>3P0H4Q805a4A00h8200@2PX05@l?00803`T900@04`d=
018<300A2`/04@/;0P0@2PX01P0B2P/05@/<00d3100G3@h03`D601L=3P804@L800L03`D601061`0B
20T04PP900l51P0C2@X05@/<008040H700H040L802XP8@0H3a004PT90108200@1`P200h41@0;01@:
2`0D2`/03PH600l71`0@1`L03P@501@<300c:BX03`H701hD5@0@1PL0300?10P200h3100401041P0A
1@L040@601451`H03`<500L04PH:0104200C1`/04PH:00l31`0B1PX040@800804@D90P0B1PX00`0?
0`Ooooooooooo`0Booooo`006oooool0:@0@3`d02@P600T81P0?3P`04a8@00l>300K6QP02PT801dL
6P0A40h040l=01<B400@40h03`l=014A3`0E5A<04a<A00L71@092@L03@d;00h>300;2`T020P6014A
3`0F61<03a4<014B3@0B4`d03Pl900H70@0>3PP04Q4<00X;1@0;30H0414;00/<1`0>3P`030`:00/;
2@0=3@/03Ph<0080410>01@02`/9010@3P0J6QP05ADC00d=2`0:2PP07alO014A3`0820P0:RXZ0000
000=3@`06a/K0000000P81l01PH600l?300A4Pd03Pl:00X;1P803a0;00@02@X500X;1P0=3PT03Pl:
0P0<3@P00`0=3@X030`:00h>300201LG5@0U010@3P0>3P`0410>00P81P0<30X05QHD0492@01<C4X0
2@X500`<2P0;30P07QlJ00@40P0>3P/03@h900l?3@0@4@d03a0;00d=2`0>3P/03@h900/<200=3@/0
3Pl:00h>2`0=3@/03@h900`=2@0<30X03@h900h?2`0=3@D0514800l<1@0@3@P06AHA01<?300200d9
1P0L00l<1`0C40T0514:010?1P0E50l03@h800/<1P0<3@L02P/500d>200;30H030d700l@2P0E5Q00
3@h800/<2@0D5A000000014A3`020P0051@B00L71@0o?cd051@B014A3`0F5Q@030`:018B40803@`:
0P0>3@/2010?3@0U00X91`0F5A<010<1010?3@071P@03Pd;00H6100n?S`07QhL01HF500<30/03Ph<
014A3`0=3@/030`:00l?3@0@40h03@d;018B400=3@/03`l=00d=2`0;2`T04a<A02TY9`0A4@l0410>
00`<2P0A4@l06QXH01<C4@051@<020P600d=2`0B4Q003`l=00X:200200d=2`0=00/;2@0=3@/0410>
00d=2`0A4@l01`L500`<2P092@L01`L5018B400@40h02`/900P81P0200T91`0301<B400?3P`030/9
00<02PT7018030/900/:200<2`T03Pd;010?3@0B40h030P700T81P0=3@/01PP500X?2`0l@Cd0QHZ6
014C400;2PP040l=01TE500>2`X2010?3@0400/:200>3@/03Pd;00X91`8030/900D03@`:00`;2@0;
2PP030/8014@300201@C4@0A00d<2P0:20T02PP900d;300>30d040h@00l=400>30l04@l@00`:2`0:
20T04Q0A00<10P0N71d04@l@010>3`0>30d00`0=2``0@@0<2P/00`4200h<3P1PGV40QhF600h<3P0<
2Pd03@/<00h<3P0>30l03@/<00d;3P0;2@`04Q0C01DC5P0;2@`020H9010>4@0;2@`01085010>4@0<
2Pd0518E00T72P0<2Pd03P`?00d;3P0<2Pd03`d@01<A500?3A0030X<00H41@0D4Q<030X;01/I6P0=
2`h03@T=014?4P0A31005A8E02l]<0080`L03``?01HD5`0<1`/0Ad=701PF6@0D4QD05A<F014?4P0=
2`h06ALJ00X82`0<2Pd04Q0C00@21@0J61/02@L:01<A500>30l02PP;018B500A4A<02PX<00803@d?
0140410B00/;3@0:2@`05A<F00X82`0=30/040h?00d<2P0;2@T03@/<00h=2`0A3`l03P`=00h=2`0?
3@d040h?00d;300200h>3P0500/;2`0=3@d03@d=00P8200J6QX00P0C4a<09`0>3Ph030`<024O800>
2PT03`T900l;2P0@2`/04@/;02XU900K5aH03`T9018=300<20L050h>00h:200@30T04@d:010<2@0C
3``04Ph=00`81`0C3`h06aLF01HB4P0=2@X040`=018@4@0>3Ph030`<00d=3@0?3`l03Ph>00d=3@0@
41004a<C00l?3`092@T02`/;00l?3P0200l?3@0>00d=300=3@d0410@020P8@0?3a4020P:01@D5P0:
2P`040lC01HF600410@07QhN00X:2P0C4a<2014A4@0Z00`<300B4Q80<C4a01@D500=3@h06APM00P7
300C4QL00`8701/J7`0F5AX07A`Q00H52P0D4aP04Q4F02<R9`0H5a`0410B01HF600A4A805QHH01<C
4`0>3Ph04a<C00l?3`0B4Q80410@00`<300B4Q804a@F01@E5`0f=cT06AXL01DF5`0B51<04A<B00lA
3`0@4Pl03Q0=01PJ5`0_<Bh0410>0P0A4@l00`0@40h04A4?01<C4@0201HF500A014A3`0D51804a<A
00L71@0E5AD05aPG01LI600D61L051TH01DK6`093`l0Ff1P06AXJ@0I6Qh07AdQ01TH7@0E61T00P0A
5AH0900D61T05QXK01HJ6`0C5aP06alP00P<3@0K7b0082@U01@H5`0O8Ad07AlJ02la;00J71L051HA
01HH4`0L81`0<C<`03<h=00Q9R806QlK024V8P0D71H06B8M01LP7@0I8R<072<Y01PQ9P0/=C`0:SDi
02<^<P0X<cD07RXZ02@`<00J92H06B0V01`V:@806B8W04X07BP^038oA@0P:c409c@l01XY<00P;CH0
7Rdd01X[<P0V=C`0>4M>03=2B@0_?TD0;Sa402Tf?P0U<SX09S4j02H`>@0S;CH07R`b01/Z;`0H9b`0
5B@Y01PW;00P;C<08Bhd01l]<00U<3H09c8g02<^<P0N:Bl06R@[02D^=`0N9c008b`c02@]=00Q:S00
8b`a01hW;00J8bL07BLY020Z;00O:B/092h`01/W9`0M:2T082X/01LS8`0I92D07RPZ01l[:`0P:b`0
72HX01XV9P0O:B/08BT/01XR9@0K82<0724T01LL7`0G7Ad06b4Q01XP800I7ah06AlO01XP7P0M8b<0
5a/L01/O800H71d08RHW020T9@0H71d06QhO01/O8080720Q01406alP01XN7`0K7b007R8R01PL7@0D
61T05a/M01TM800L7b@061/P010C600B5A`07R4X01LJ7`0P8BD061TK01XK7@0201<D5P0301TJ700E
5QP05AHH00806a`N00L05AHH01/L7P0Q8RH06AXN01hO8`0R8bL071dQ00D061TM00T05QLK01DF600C
5aP05QXK01@H6@0I7Ah030d?010A4`0D5AL00P0?3a401@0G5aT071`N01dM7`0C4A80518C00805A<D
0P0D4Q<0100P7Ql0:BLX00L51P0G5AH201@B4`0D01<?3`0D40l04`l>010<2`0?2`X040`;01<?3P0G
4a804@d<01HB4@0J5QD03@T801DA4012?Sd02PL601PD4`0B3Pd02PH5010<2`0A3@`200h:2@0B014=
300F4A805Q0B01@>400B30h04@/=018<3P0>20X06aDG00/51`0G4A<0100001dG6@0@20T040H700l5
1P0F30d05@/<0P0B20T00`0>10D03@<401882@0200l51P0601@:2`22O7`0<2PX00h51P0@1`P02P82
0`0A1`P30186200601T?400700004PP900/10P0F30d040H70P0B20T200d3100501061`0;0P804@L8
01061`0?1@H00P0A1`P01`0@1PL0308301L=3P0C2@X05@/<01<92P0;0@801P0>10D04P0;0@802P01
01061`0B20T03P@500X00@0:008040@800l31`0@10P04`L;00X00P0C1`/040H800P0000Q5AT03`D7
01452ACooooo000Kooooo`0501TH5P0C4Q003`h<014@3P0@3`d00P0=30X02`0?3P`00P400040000L
6aT03@`:00/;2@0:2PP030`:018B400E5A<04A4?00<03Ph<02d06ATG02TY9`061P@01`P301LH4P0H
6A<051D?00P90`0F5a403@h800l@2P0=3PP0414;014B300=3PT03Ph<00d=2`0<30X03Ph<010@3P0A
4@l03`l=00/;2@0?3`d05QHD018B400<30X04a<C09RHV01FEUH05ADE00L71`0>3Ph04Q8B00410@0>
3Ph05QHF010@400=3@/030d8010A300?40/0414<00/<1`0720@00`0<3@P07P0>3`X04Q<>018C3`0=
3@/030`:018B400D5180410>00`<2P0A4@l0410>00l?3@030`404Q8@014A3`071`D061PF00L71@0;
2`T01PH400l?3@0<30X03@d;00h>300=3@/030`:00h>2`0=3PT02``700d>2@@03Pl:01403@h900`=
200<3@P03@h9010@1P0F50P04Pl7018?2P0J5a80510=00d91P0>2PL04@h9014>1`0A3PD040l400d>
1P0200/<1P0E00h?2@0A4P`04A8<018C3@0L7AL04A8=00D6000E5Q002P/50082000F5Q@02`/:00d=
2`0>3P`04A4?020P7P0;2`T030`:00h>30071`D03Ph<00<03@`:0`0>3@/03@0;2PP03@`:0040000B
4@l05aHD00H50`051@<02@T700@40P0A4@l0410>00D50`0@40h00P0<30X01@0>3P`03`l=00d=2`0B
4Q0030`:00803Ph<01403@d;018B400U9B<030`:00L71@061P@01@D300l?3@0410804Q8@02PX9P09
2@L08B4O0000000<30X03Ph<00d=2`0200/;2@0A00d=2`0>3P`030`:00l?3@0C4a403`l=00X:200@
40h030`:00X:200=3@/0410>00l?3@0>3@/03@`:00`;2@0=30X00P0>3@/04P0=30X02`X800`;2@0=
30X03`h<014?3@0<20L02`X8014A3`0<3P/03a@@07MmN@3DfMD0BD]800d>30081`D03@T800h;2P80
4A0>01`030/900l>300?3P`030/900d<2P0?3P`040l=00d<2P0;2PP02PT600d<200?3P`040l=00l>
300@3Pl03`d>00`:2`0>30l040hA00l=400?3A401P@7018@4@0=2``030X;00l=3P0A3a003@/<0P0>
30d200d;300900l=3P0:20T04Q0A00l=3P0A3a009bDV00`;2`0<2P/03@/<00803P`=0P0=2``05P0<
2Pd040hA01<A500<2Pd02PP;010>4@0A3a801`D800h<3`0<2Pd05aDH01<A500=2`h03P`?00d;3P0<
2Pd03P`?014?4P0:20/040hA01hL7`0=2`h200`:3@0F018@4`0?3A004Q0C00d;3P091`X06ALJ00d;
3P0;2@`05Q@G00/9300[:B`03`d@00D31P0;2@`04Q0C01HD5`0[:B`08b4T00P62@0@3Q4030X=00X8
2`802@L:02L03Ph@01@D5P0=3@l01`L900T92`0:2P`0410B018B50051@L02@T;00X:300G5aT02PP9
00D3100;2@X06ALH01LE5P0?3@h0518C00X82@0;2@X03`d>014?400:20T03@d=00h>3P0=3@d0410@
014A4@0=3@d0000000D51@0C4a<04A4A00`<300A3a003`X900l92@0@2PX00P0A2`/03@0F41004@/;
014;2`0C3@d04@/;00l92@091@<04@h9018?2P0@3@T04Ph;014=2P0>2PP00P0=2@P01`0@30`04@d>
010<3@0?3Ph03`l?00d=3@0>3Ph00P0?3`l200d=3@0F010@400B4Q803`l?00/;2`0;2`X03@d;00h>
300>3Pd03Ph>00l?3`0B4Q<05ADG01LG6@061@X02`X?01HE6@0h>3X03`l?00d=3@0<30`05aLG014A
4@803`l?00d09RHV03dm?@0T92@04A4A014A4`0C4QL03`hC01TH7@0E51T01PH:0000100B4AH05A@I
00804A0E00T06QTM014A4@0G5aL0410@018B4P0?3`l0410@014A4@0C4a<00P0N7Qh01`0@410030`<
00`=4@051PT07AhP018C5@0@4A800P0<3Pd01@0?4@l05ALD01<E4P0@4Ph05aTD00805ADC01X04a<A
018B400B4Q004a<A018B400@40h05aLE01<C4@0D51804a<A01HF5P0F5aH04aLF01@H5`0C6QT04AXI
02L`;`2b^KX0]KZm03Xk?`0D51T05AHJ01TL7P0E6AX051PI01HJ6`805a/L04L06QhO02T];P0N8R<0
5a/L00hB4`0R9RD05a`G02ld;P10ACl07B8L01<H4P0I7QP06b0J020U7`0R9b40724K01/P6P0Q:240
7BHN01`U800J8b00628R01TR9`0L9B`0MX2909bY[`0nC4l09C<e01l];@0J:2P07bP]01dV:`0P:Bh0
7RL/01dX;P0R;S@09C8h028_=`0R<3P06bTb02Hd?@0P<3P07Rlf02<d>`0[>d809SDl024`=`0X=Sd0
<Sm702hk@`0Q;CD06bD^028/=@0R;cH07B`a01l^<`0S<SL08S4f020]<`0O:c007bX^020[;`0R;340
92db02D^<`0Q:S40;SM002L`>@0P:C40:S<j02D^=@03020Y;P807RPZ00@08B/]01`X:00F8R8062@T
0P0R;Rh03@0O:b/07BTY01l[:`0P;2`07BTY01/W9`0N:BX07RHY024V:P0U:Rd07B8U01DJ7@0K8B40
0P0J820201TO7@0;01XP7P0L8R006QhO01dQ8P0K7b005a/L014E5P0_<c@06AdN01XN7`0K7b000`0L
82404P0D61L061`K01`P7`0L82407R8T02<W:P0L7b@08RD[02HY<00T9bh0=3Lo00`?5P0J6al04Q<E
00H72@0A4Q@05aPJ020Q8`805AHH00L06Q/M01TJ700D5AL06AXL01LH700E5QX05aPL008071dQ00@0
5AHJ01@E6@0F5a/05aPL0P0H6Ad02P0F6Qd05a`M01lS900Q9BH0:2`]01DF600D5AL061TK01HF600C
4aD2014A4`03018B500D4Q<0518C00@0518C00@0>3Hg03Tg>00G5AH061HG0P0;2@X0500M6AP0510?
00l;2P0?2`X05A4@01LC4P0<20L03`/:01TE500=2@P030P7018>3@0U8B00Ge]J01@@3`03000040`;
01PD4`0@30/04@d<0P0>2PT01@0A3@`05A0@01<=3`0B30h04@/=00803`T;00T05a4C00@0000;1@L0
O7Ih01PB500400004PX;01061`0?1@H00P0D2P/01@0C2@X04PP90147200F30d05@/<00802P0100H0
3PD602TS8`0<1PH05@`=00`3100F3@h301061`<04@D700D03`D600d3100D2P/03083014720020106
1`804PP900H04`T:01H<3@0?1@H04@L801061`0?1@H20147200701061`0>10D03P@500h41@090000
308301P>3`0600h41@0B01P>3`0F30d0MVa]079XJ@0@1PL06Q0A00h21P0E2@d040@800l31`0A1@T0
3P8601862P0?0`L0300401P<400J3Q8020005?ooool001_ooooo00@05QDC01DD4P0B4@l03`h<0P0>
3@/2018A3`0M01@C4@0;2PP03`h<01@C4@0H61H0410>00d=2`0?3`d0410>014A3`0@40h03Ph<010@
3P0U9B<0@T9001<C4@0P8A`0P85l05mPF`0J6aH030d800l@2`0@4@`020T400h?2P0@4@`030d800d>
2@0>3P`00P0=3@/00`0?3`d04Q8@01<C4@0200h>30803`l=01D03@d;00`<2P0A4A40GemO02d];@0C
4a<04Q8B00`<300:2PX05QHF04U9B@0o?cl03`l?010@3P0?40/04A8=010A300?40/03@h900h?2P0@
4@`00P0?40/01P0C50l06Q/F01PI5@0=3@/02PX800`<2P80410>00d03@d;00l?3@071`D02`/901LG
5@0X:2H04a<A00d=2`0>3P`030`:014A3`0D518020P600D03@d;00@03Ph;00d>2@0;30L03@h90P0>
3`X2010A300900h?2P0<3@P030d800`=200>3P@04A4600h>1P0<2`H04A0;00803@`801d03`h:010?
2`0;2`<02PX1010@1P061`404A8=014B3P0:2`L0414<00h?2P0=3P`01@H1018C3`051@<0414<01TJ
5P1PH5h04Q8@00d=300=3@/02@T700l?3@0:2PP03`l=010@3P0=3@/02`/900d=2`0300d<2P8030/9
00h02`X800X91`0>3@/02`X8010?3@0Q81h04Q4?01<C4@0>3P`05QHD00l?3@071`H05QHD00h>3080
3@d;0P0>3P`0300<30X04A4?00X:200;2`T0410>014A3`0@40h04a<A00P81P071`D0410>00`<2P80
4A4?00D02@T700H6100F5QD02`/9010@3P0200l?3@0=00h>300<30X02`/900`<2P0?3`d04A4?01<C
4@071`D03Ph<00d=2`0>3P`02@T700X:200200`<2P0300d=2`0=30X03Pd;00803`h<0P0=30X04P0>
3@/03@`:00d<2P0=30X03Pd;00l=2`0<20L02`X800l?3@092`P020d901/P700i?SX0418?00`<2P0P
7ad02`P700h;2P8040l=00H03Pd;00l>300?3P`030/900/:200<2`T200d<2P0B00/:200=30T03`h:
00d<2P0<2`T03@`:014?400@3Pl02`T:00d;3P0?3A0040hA014?4`091`X05aDF00`:2`081PL05Q@E
0P0:20T03@0>30d04@l@00h<3@0=2``040h?00P61`0?3@h05Q@E018@4@0=2``02`T:00`:2`0=2``0
0P0>30d200d;300300d;3P0>30l03P`?00803`d@01D040hA00d;3P091`X03`d@01<A500E4aH02PP;
00l=400A3a803`d@00`:3@0=2`h03P`?010>4@0;2@`04@lB00H41`0E4aH02@L:00l=400<2Pd00P0A
3a805P0<2Pd040hA00l=400:20/05A<F01<A500>30l03`d@01<A500B41<04@lB00/9300C4A@02@L:
01<A500:20/04Q0C00`:3@0B41<03P`?00L72@0@418200X:300:010@4P0>3Q003@d?00H6200@4180
2PX<010@4P0<30h03`d>014?40805A<D00d03`d>00h<3@0C4A801`D600/92P0@3Pl06QPI00d;300@
41003`l?00`<300?3`l051@D00804a<C00D051@D01<C4`092@T05ADE00D41006010<2`0601PD4`0A
3@`03PX901<?3P0>2PT040d:0P0A40/01`0>3@T040l;00l>2P0>3@X040l=010>3`0?3@h00P0>30d0
200@3`l0410@00h>3P0?3`l04Q8B014A4@0@41003Ph>0P0=3@d200`<300@00`<2`0=3@/03@d;00l?
3@0@40h0410@01TI6@0=3@d03Ph@00X93P0B4AH040lC01@D5@0<30`051@D018B4P803Ph>00<04Q8B
00/;2`0J6QX00P0B4Q809@0?3`l061PJ010@4P0C4aD06ATK04=3A@0U9BL03@d?01dM7`0>3Q00Bd]=
04A4AP0>3Q003Ph>01<C4`0>3Ph051@D01<C4`0@41004a<C01HF5P0N7Qh07AdM018B4P0=3@d05QLK
010A500=3Q0071dO018D500B51<04A<B00lA3`0B514051HC010B3P0?4@`00P0E5A<201<C4@0F018B
400@40h0410>01@D4P0N7Q`01`L501<C4@0F5Q@061PH01<D500A5A@05ATH01@K6P0>5aH03aPG04iE
EP1?E5L06Q/O01hN8`0F5a/06Q`O01LK70805ATJ02d05QXK01LK700I7Ah03A4B02<W:020Q8D0ATY;
01`P7`0N8al051TE01lT800J7a/06AhJ01@I5@0J7a/05Q/G01`Q7@0O92006b0L01XQ6`0L91d0624L
020Y9P0N:2T08R/`02hg?02HXjL0bMKL055OHP0W=CL082h^01/Y:@0S;34082T^02<]<`0Q;3808Rdc
02Te?00J9bl0:CHn02@b>P0Z>4408Blh01h_=`0T=Cd00P0W>4005@0/?DD0;C]402Pf?`0W=3d0934j
02Td?P0Z=3h09Bli01l/=00Q<3D08c8g028a=P0O;S<07R/a024]<P0S;S8082/_020Z;`0S;3409Rld
02</<P02024Z<`0<02</=00O:2l08BXa01lX;@0Q:Rl08b`a01lY:`0N:2X08bd_01dY:@0Y=CD0;3Ph
0P0O:b/0400R;Rh072PX01hZ:P0Q;Bd07b/[01dY:@0M:2P072@W01hS9`0T:B`09b`_028W:P0L8R80
6R0P01TO7`0I7ad201XP7P0701`R800M8B806AdN01XN7`0R9RL07b<T03i2@`0201dQ8P806alP0P0J
7Ql0;@0K7ah05a/J01lS8P0N8R<05a/M01hR9@0E61d0:Rdc02X]=00G6R406ahV02<V;@0S92P05QLI
01`M7`0O828061TK01HG6@0E5QP05aPJ01PI6`0F5aT04a@F01HG6@0?41@05aPL018C5`0G61`07b0T
01@E6@0H6Ad06Q/O01/L800N7b<08B8V020T9`0C61T05QXK01LK700V:R/05AHH014B500D5AL0820R
01hN800201@D5P0301TI6`0D4Q<0518C0080518C0`0C4A806@0F51D030X;018@4@0>30d05aDF01@@
3`0A3@`04`l>01HB4@0@30/02`L601HB4@1bKVd0/Jf/01hJ6@0P71/03PX900H20P0N6QT030T801@@
3`0@30/03`/:014=300@30/00P0?2`X00`0A3@`04`h>01<=3`0201<=3`0?014;3@0@2P`04@/=01TC
5@0;1@L071HH00h82P0F418040P900l51P0@1PL04`T:01882@0F30d05`d>00804PP900T0308300l5
1P0T6Q/09AdM00/51@0?2@T02P420107200D30d00`0@1PL301451`0?01@:2`0A1`P0L6IW01H<3@09
00405@/<00`20`0@1PL04@L801<92P0F30d04PP90147200@1PL03`D600804@L800L040H700l51P0D
2P/0>S0a01`B4`090@4040L800H03P@50180200002TO802l/[<0/jVZ01X@4@0:0@4030040104200>
0PH03@850104200A1@T02@010106200E2@d050P<03<W:`0?0`LDooooo`006oooool00`0<2`T03`h<
00l>300200h=2`<040l=01P00@0001DD4P0U92800@0000d=2`092@L03Ph<010@3P0?3`d04Q8@00h>
300?3`d02PX800d=2`092@L0:2PV07IgLP3ooo/0iNKQ02//9`0J6aH0414<01lP6`0>3`X2014B3@03
00d>2@0A4Pd03@d;00802`/901P03@d;010@3P0A4@l03`l=014A3`0@40h03@d;00`<2P0>3P`03@d=
00@4100A4A402@T901lO7`0410@05QHF0000000D51@05aLG000000092@L02``700d>2@0<3@P200P9
10802``700L030d800/<1`0;30L03Pl:00l@300=3@/030`:00803@d;00d030`:00h>300E5A<03`l=
01DE4`0P81h0:2PV00l?3@0=3@/02`/900l?3@020P00410>00H03`l=00@03a0<00d>2@0;30L03@h9
0P0>3`X2010A300X00h?2P0<3@P02``700/<1`0C4`/05AD;01@D300A40/04Q4=014@3P0=30X040l;
014@2`0:2P802@T1010@1`0;30L07QhL01lO7P0<30`03Ph<010@3`020P802PX800d=300D51@0DU9@
034a<00F5Q@061PF00`<2P0@40h02`/901<C4@0;2`T0410>00/;2@0:2PP03@d;00H610803@`:0P0<
2`T03`0;2PP02PT7014@3P0?3P`04A0>00P71@0:2@L03`h<014A3`092@L01`L502<S8@0C4a401PH4
00d=2`0200l?3@0E00h>300<30X02`/900l?3@0;2`T02PX8010@3P0C4a403@d;00<30P071`D01@D3
00`<2`0E5A<0410>00X:2@092@L05ADC00L71P0D518010@2008030`:01403@d;00h>300>3P`03Ph<
00T91`0B4Q003Ph<00l?3@0C4a402@T700h>300A4@l051@B00d=2`092@L03Ph<00l>3002010?3@03
00l>300<2`T02`X800@03@`:00h030/9010=300A3@`03`h<014A3`0=3``02@h:00L<200@5A404A<@
00d=2`0O7Q`040`;01LE4`802`X801H03@`:00`;2@0<2`T03@`:00/:200920H02PT700h=2`0B4@l0
4a8?014@300@3`d03@`:00X91`0;2@X03@/<00`:2`0=2`h03P`?00l=400A3a<05Q@G0P0<2P/04@0N
71d03@/<010>3`0>30d040h?014?400=2``02`T:00`:2`0;2@X03@/<01HD5@0?3@h00P0100h<3@0<
2P/03@/<00803P`=0P0=2``06P0>30l030X=00`:3@0?3A004@lB00l=400D4QD040hA00H41`091`X0
3P`?01HD5`0?3A004@lB010>4@0=2`h02`T<00`:3@030@@07Q`O00l=400G5AP00`4400l=400H5QT0
4@lB0P0@3Q40600<2Pd02`T<00H41`0@3Q403P`?01DC5P0>30l0518E00X82`0;2@`040hA00/9300D
4QD04@lB01PF6@0;2@`01P@701@B5@0A3a80CTa?03De=`0@41802PX<00h>40801@D701l02`/=01/K
7@0?3a405QHH014A4`0410H01`D6010>3`0E4a@03@/<00`:2`0D4Q<03`d>00`:2`0@3Pl01`D601PF
5`091`P03@d=00h>3P0;2`/05ADE02LW9`0];Bd0IFEU0000000A4A401PH600/;2`0G5aL04@d<00D0
40`;00H0510?018>3@0U8B006QHE00D1000=2`P2014@300=00d<200@3`/04A0>00d<2P0;2PP02`T:
018@4@0C4A803@/>00`;3@0?3`l03Ph>00l?3`02018B4P0_014A4@0E5AD061PH010@400820P02PX:
014A400@4@`03@h900l?300C4a405ADC01DE50061PH05ADG010@4P0;2`d051@F01@D500A4A402PX:
00d=3@0H61P030`<01<C4`0?3`l08B4Q014A4@0G5aL051@D00L72@061PP04a<E00P82P1=CDl0BDU;
00H6200C4aD04A4C00d=3`092@/05ADG00`<300?3`l04Q8B02LW9`0U9BD00P0A4A4201<C4`0Y010@
400A4A404Q8B01@E6@0N7b800P<501`M7`0?41407R0O01PJ6@0@4Q0030h;010B3`0F61@05QPC014A
3`0@40h04Q8@01DE4`0D51804A4?01/K6@092@L03`l=01TI5`0n?S`0410>01TI6@0B4a<04ADD01HJ
6@0E71/03QLF01PQ800@5aP061dP018C5`0I6Ah04a@H01HH6`0F6Q/00P0E6AX0300I7Ah0720Q00X>
3`0R9RL06QhO05=GF00Z;Rl0720O01DJ5`0N8al082DQ01@I5@806QlK0P0L8Ad07P0P9B407B8N01TN
6P0J81`08RXU01hW900W<2d07RPX01PQ9P0S;340<Se1041>D@0^?3l07B//02Hd=00Y=cL092db024/
<P0T;cD08bhd02@a>@0b?dL0;ca402`j@`0^?4D0?TaE01`]=@0[?4@0;d990352BP80:CY202L09C<l
01l]=P0M:c@082df03E2B`0mBU<0;CY302<a>@0/>d80;Ca302<b>00L:c00934g02Lc>00T;c<09c8f
02Xd=`0W<C<092h`02@^<`0S;CH09Blh02<^=@0R;C<0;STo02@_<`0P:bl06bHZ01`W:@0O:R`082/]
01DP8P0U<380:3<e01PS9@0J9BL082/]01/V:00L9bT00P0O:R`0200M:2X06RDW01XR9@0P9BT09R/^
02DZ;@0R9bX06R0P0P0I7al01`0J81h06b4O01/Q7`0K8Al07R8S024U9P0E6AX00P0K7b000`0@51D0
7B4R01`P8@0201XN7`806alP01H09RX[01/O800K7b006AdN01@H6P0K7b807R4V00lB5`072Pl082<Z
028U;02JWJ80UiRL024R900S92H02P/=01/L7P0I6Q`05AHH01LH6P0E5QP04a@F0P0D5AL01`0B4aL0
71dQ01DF6P0F5a/07b0T018C5`0E5QX00P0D5AT04@0F5a/061TM01LK7P0I7Ql0720Q01XN7`0/<340
7b0R01LH6P0M7R00:b/]02HV:00E5AL0410B01DE5`0E4a@04a4B00<04Q0A01X04a4B01TG600H5QL0
5aDF01<A4P0=2``0518C03Xf=@0N6QT04@d<010<2`0E4A005Q8A01dI600N6QT0?CTh018>3@060P40
3`/:014=300S7ah04Ph=00D1000?2`X061@C014=30803`/:020040`;014=300A30d04P`>01<=3`0D
3Q004P`>014;3@0=1`T05a4C01@>400N61X03@L900/51`0A2P/03PD600l61`0A20T040L801D<3@0C
2P/02`8301482@0D2``03PD60107200A2@X0100000h8200F3@h02@0100l820<03`D60`0@10H03`0:
00406@l@02LM7P0O5AH05P`=00d41@0?1@H04@L800h41@0;0@803P@500l51P0A1`P040H700l51P02
0147200401061`0Q5aP01`0000l71`804PP900<03@@500h41@0>10D0100>10D04P0B20T040L801X@
4@0H3Pl03@D501061`0A1@T03P8601452@0E2@d050P<00l31`0@10P04@D900l31`0=0@D04`L;00d1
1ACooooo000Kooooo`8040l=0P0A40h02P0@3`d03Pd;00/:200F5A<040l=01DD4P0H5aD081lM01<C
4@0@40h201LG5@0J010@3P0C4a400P8000`<2P0A4@l061PF014A3`1@D4h0PH9m09ZKUP2?T8/05aPC
01@E40061`806a`G00h?2P0<3@P03@h900h?2P0A4Pd03Ph<00`<2P0;2`T030`:00h>300?3`d2014A
3`0P010@3P0>3P`03Ph<00l?3@0>3Ph04Q8B01PH600<30`03@d=018B4P1YJFT030`<00h>3P061PH0
6QXJ00`<2@0=3PT051D@01PI500>3`X02P/600`=200>3`X04A8=010A300=3PT030d800`=2@0=3@/0
3Ph<00l?3@0=3@/200`<2P0=018B400<30X0410>014A3`0I6AL02PX800<30@0820H02`/900H61009
2@L03`l=010@3P0300l?3@05010@3P0@4@d03@h900/<1`0=3PT00P0>3`X00`0@4@`03a0;00h?2P03
00`=200?014A2@0C4`T04a<<014@300@3`/04Q4?00`;2@0>3@/040l;00`;1P0;2`<0410700L71@0E
5AD061PH00802PX:01<03Ph>018B4P0V9RH0;Bd]01PH600_;bl05ADE00T91`061P@051@B00`<2P0:
2PP04A4?00h>300<30X02@T700`<2P0@40h02`/900<03@`:0`0<2`T0100?3P`03@`:00d<2P0C4Q02
01DD4P0:01<C4@0>3P`01PH402l_;@0R8R0020P600d=2`0@40h04A4?00l?3@8030`:0P0=3@/04`0;
2`T03`l=018B400<30X03`l=01PH5P0C4a402`/:028R800@40h02`/:00<30@0;2`T0:BTW01@D4P09
2@L030`:00/;2@0<30X00P0@40h0400?3`d03Ph<00X:20092@L05QHD00D50`00000030`:00/;2@0@
40h02PX800H6100>3P`03@`:00h=2`0?3P`2010?3@0300l>300<2`T03@`:00803Pd;00h03@`:00d;
2@0;2PP02`X800h>300?4@h03Q0=00dB3P0G71P071hK018B400<2`T00`0000/91`802@P600<03@`:
00X91`0;2PP00P0>3@/200`;2@08014@3P0F5A<04a8?00h=2@0?3P`03Pd;00`;2@0=2``200h<3@80
3@/>00/03P`?010>4P0B41<01@<4018@4@0]:b`030X;00h<3@0C4A804Q0A00l=3P0200`:2`0900/9
2P0@3Pl030X;00`:2`081PL01@<4018@4@0<2P/03@/<00803P`=0P0=2``0200>30l03@/>00d;3P0>
30l03`d@00h<3`0@3Q405A<F0P0=2`h01P0610L02PP;00h<3`0A3a8040hA00h<3`8030X=00X03@/>
00h<3`071@P04a4D00T72P0A3a804Q0C00h<3`0;2@`030X=0P0?3A000`071@P04Q0C00/9300200l=
400b00h<3`0D4QD04Q0C01<A500:20/030X=00T72P0B41<03`d@00400P0=2`h06QPK08F3QP1ADE<0
6ATK00h>400C4aD03Ph@01DE5`0@4180H61R0410@P1CDeD04A4C00d=3`0>30d01P@500d;300?3@h0
2`T:00d;300<2P/02`T:010>3`040P<071XK00`:2`0?3`l03Ph>00P8200=3@d06a/K020P800?3`l0
0@4101@D500?3`l030`<00H61P0@3P`2014=308040`;00L04`l>00/71P0810<07ATH01@@3`0810<0
3Pd:008040l;00d03@`8014@300B4@l05A@B00l>30091`P07adN02h/;@0O7B003`h?00h>3P0=3@d0
3`l?00804Q8B00X03Ph>01HF5P0Q8B406a/K00`<300;2`/04A4?010A300=3PT0414=0P0F5Q@06@0@
40l04A4A014A4`0>3Q0030`>00H6200>3Ph01`L700/;2`092@T05QHF00d=3@0>3Ph02`/;014A4@0<
30`04A4A01PH600G5aT0=3@f020P8P0C4aD05ADG01LG6@0N7R000`0=3@l07@0B4Q@04a<E010@400C
4a<05QHF02`/;00Z:RX051@D00/;2`0A4A405ADE018B4P0C4a<0410@010A5@0A4QD0414C05EFF00l
?Sh03a4@01DG5P0C5A<03a4>014C400C5A403@l:018B400A4@l051@B00806ATG01D051@B00l?3@0A
4@l04A4?018B400`<2h051@B01PH600E5QD04QHE01HJ6@0E71/041TH00`E500=51D06b0S01HG6`0G
5a`07AhR01HJ700I7Ah00P0H71d08P0M8B808BDV02T];P0T:2T05a/L01XN7`0:3Pl08BDV01XN700J
7a/05a`H01HK5`0Q9R807R<O020U8@0L8Ad06QlK01DJ5P0J7a/08BLS01hW8`0O:2D09Bh]01lY:P0K
9BL08BX_024/<00W=CP0;3Xk01`Z:`0]>c/0:CLh02La=@0S;S@202Ha=`0]02Ld?00a?TH0:SLo01l]
=P0U<c`0;Sa501`]=@0Z?4@0;d990352BP0[?4@09SLo028`>@0O;CH08Blh02Hc?00[>440;3U202Xg
@00V=3d0:SU002lnA@0Y>3l07Rdb024^=00R;S<08B``02Lb=P0/=SP0:S@f02D_<@0P:Rl092hg02Tc
?00F8BP08Rdc02/f?00U<3@07bX^01TT:00M:2X08B`^01lZ;00W<S@09C0b008082/]01008Rd_01/V
:00N:B/07BPZ01hY:`0O:R`07RT[01/V:00H82<0:c0d038g>P0K82<04aPK01`R8P0H7Qh06AlO100K
8Al0100A5AH08bLX01dQ8P0M8B8202@X:@0L01TM7P0H71d061`M01XN7`0N8R<08BDV02hb<`0T:2T0
6QhO01PL7@0I7Al06AdP01LJ7`0S9R/06ahS02@W;P0Z;C@0f=_P0<k?d`0b<cD0:BX/00l@4P0O8280
3@h@01DF600H6A/051DG018C5@805QLI01X051DI01/L800F5a/05QLK01TJ7P0A4QH05QLK01DF6P0C
51P051DI01HG6`0E6A`051TI01hR8`0L8240;30a01/L7P0@4A<06AXL028R900P82805ADG018B500E
5AL05Q@E01<A4P804@l@0P0B4140200;2@X03`d>018@4@0B41404a4B01HD5@0/:2L06ADD0P0@30/0
4@0D40l05Q8A00`9200D40l08alN014=300;1`H061@C00X61@050@003`/:01LC4P0B3Pd03`/:014=
300>2PT03`/:008040`;00@040/;00l92`0@2P`040X<0P0?2@/0600=1`T07aTK00h82P0400006Q@F
018<3P0=1@L03`H70107200B2@X040L801<:2`0E30d03PD600l61`0C2P/03PD600X10P0=1@H04`d=
00T4100K4Q<08aXK00d41@<040H70`0A1@L03`0=0`@03P@500P0000?1@H05@/<00l71`0D2P/05P`=
01061`0:00403@<401061`0A1`P040H700l51P020147200401061`0D2P/0308301T?40801`0000<0
7A<D00h41@0>10D0100>10D04P0A1`P040H700h41@0@1PL04PP900/10P0B1PX03@4500l31`0A1@T0
3P8600`0100B1PX040@800d11@0A1@T02P0201<72aCooooo000Kooooo`05014@3P0>3@/040l=01@C
4@0C4Q000P0=30X02`0@3`d02PT700d<2P0E5180DU5?01TI5`0C4a406ATG01PH5P0?3`d05QHD0080
410>018020P600h>300=3@/04Q8@01DE4`0R8R009BDS00h>300@40h04Q8@00h>300B4Q003`l=01@D
4P0K6aT061PF014A3`0?3`d200d=2`0300h>300?3`d0410>00803@d;0P0?3`d04P0>3P`0410>00l?
3@0>3P`03`l=010@3P0B4Q00=SHd01HF50092@L04a<A00X:2@0?3``03a0;01HG4P0H6A@03@h900`=
2080414<00D04Q<>014B3@0>3`X03Pl:00l@300200l?3@0300h>300=3@/03@d;0080410>01@02`/9
00l?3@061P@05QHD010@3P0D5180>SXh01PH5P0F5Q@02PX8014A3`0@40h03Ph<00d=2`0>3P`0410>
010@3@0=3PT02``700d>2@@03Pl:01403@h900`=200=3PT03Pl:00`=1@0>3`H0414:00h?2P0<3@P0
410>00X:200;2`T03@h:00l@2P0@4@X03a0800l?3P0200X:30803`lA00l02PX<00T92`0;2`d04Q8D
00h>400<30h09BDV05QHE`0I6AL02@T800`<2P0@40h02`/9010@3P0<30X00P0?3`d0100;2`T03`l=
00d<2P0=30X200h=2`803`h<00d04Q4?03Pg=@0B4@l04a8@010?3P081`D04A4?00h>300;2`T0410>
00X:200=3@/03Ph<008051@B00D04A4?00d=2`0=3@/02`/9014A3`0200d=2`0?010@3P0<30X02PX8
00h>30092@L04Q8@08B4PP1nOW`04A4?01@D4P0H61H0=3@b00/;2@0<30X0410>00803@d;0140410>
00h>300<30X03Ph<00P81P071`D03@d;01@D4P1MGE/07QhL00L71@092@L03@d;00T91`0<30X04Q4?
010?3@0400h=2`0300/:200=30X03`h<00803`h<00d03Pd;00/;2@092@L02`/900l@3@0>3`d03@h<
00l@3@071`D03@d;00P81P0A4@l040l=00802PT700L03`h<00`;2@0<2`T03`h<00d<2P0>3@/03`h<
00803Pd;00T03Pd:00h=2@0=30X030/900/:200>30d04@l@010>3`0>30l00P0=2`h03@0?3A402`T<
010>3`0A3a005Q@E018@4@0<2P/05aDF010>3`0:20T03@/<010>3`0>30d00P0?3@h00`0>30d030X;
01@B4`0200`:2`0300d;300>30d03P`=00803@/<01003@/>00l=400?3A003@/>00/9300=2`h030X=
01HD5`0<2Pd040hA014?4P0`;S403@/>010>4@0A3a803`d@0`0=2`h03P0H5QT0GeeP00T72P0A3a80
2PP;00d;3P0?3A003P`?00d;3P0@3Q404@lB01@B5@0<2Pd040hA0P0=2`h0:@0>30l030X=00/9300A
3a802@L:00h<3`0?3A002`T<00l=400C4A@03`d@00`:3@0D4QD06a/M00d=3`0:2P`02`/=00X:300>
3Q003`lA01lO8@0A4A<071`N00h>400=3@l04@l@00/92P0?3@h030X;014?400N71d05Q@E00/92P0D
4Q<04Q0A03Le=P0T8R<030`<014A4@0<30`02@T900803@d=00@03`l?01<C4`0;2`/02PX:0P0<30`2
010?3@803`h<00P03Pd;014@3P0;2PP03`h<00d<2P0<2`T04a8@00d=2P803Pl:00d030d9018B400D
5180410?00/;2`0:2P`04A4C01@D5P0?3a4030`=00d=3@0<30`03Ph>00804A4A01<03Ph>014A4@0E
5AD04A4A00d=3@0?3`l04A4>00d>2@0>3`X05QLB01TJ5@0D51803Ph<01DE4`092@T05QHH00X:300c
<cD0C4a<00804A4A0`0?3`l0300B4Q804a<C00h>3P0I6AT03@d=01<C4`0820P06QXJ00/;2`0A4A40
5QHF01XJ6P803Ph>0280410@01HF5P0>3Ph02`/;01<C4`0G5aL0410@01LG5`0E5AD04A4A010@400F
5QH051@D00l?3`0C4a<0410@010A5@0@4A@0:b`^08b=S`1^L7004Q@C01HH5`0G6AL03a4>00h@3@0D
5Q80418=01@D4P0B4Q0051@B01PH5P0G5aD0410>0P0D51801P0J6QP05QHD014A3`0E5A<061PH01PI
6@805QXI01T05A`K01@M700D7A`072<T018G6P0H6Ad0:2P]01`M8@0G71h06R0P01PN7P0E6a/06AlO
01hT900T:RX05A/K024W9`0F71`082HV01PN7P0G7A/07B<Q01LM6`0K8Al08bTW00807B<Q01`06R0N
01dS8@0L8R00728P020V900M9BD07bLX01dU9`0O:BX092h`02H`<P0P:bd07bd^01LU9P0K:BT06RPX
028`<@0U<3D08B`b02<_=P0S<3P09S<k02/i@@0L:S<0=TA=04IFH00Z>dD0A5EO0`0V>4801`0Y>dD0
8cDo02@e?`0Z>T@0938m024_>P0V<cl00P0^>TH02P0[>4809cDn02Le?P0Y=cl09cHm02<`=P0S;c@0
9C0d02@_<@0S;Rl2028/;@0K028]<@0F82T0<Sa504UCF`0S;S@07RT_01dX;00P:bl092lc02<^<00Q
;2h07bX/02Pc=@0V<C<09c8d024/;P0K9RP09S4c02@_<@0Q;2h07bX/024/;P0R;Bl082X/01dU:00W
;30092T/00806AhQ00/06b4Q01PN7P0I7al06b4O01`R800K8Al06R0O01LL7P0M8RD0724T020U:002
01TN8@0E01dR9@0K82<061dP01PM800J7b80724T01/O8P0P92L05a/N01/O8P0Y;C008BDX01TM800F
6Ad04QDJ01LJ7`0S9R/0?D140493AP0H6A/06Q/M00805AHH00D06AXL01@E5`0I6Q`051DG01<D5P02
01TJ700J01LH700H6Ad06a`P01XK7`0F5a/05aPL01PI7@0G61`05AHJ01LH700J6al06AdP01@I6@0F
6Q/02Ph?01PL7@0F5aT051DG01HG6@0E5AL05QHH01LG6@0F5QP05ADF01HE500C4Q02010?3@03014@
3P0B4@l051<A00805aHD01404Q4?01DD4P0=30X04Ph=01HB4@0G4a805Q8A018>3@0@30/05A4@00l;
2P0F4Q40510?018>3@0A3@`0510?014=300201<?3P0301HB4@0D40l04@d<00803PX900<04@d<010<
2`0@2``00P0@2P`06`0?2@/040X<014;3@0A2`d05Q0B01<=3`0J51H05@lA00@0000F3a004PT:0107
200D2``04PT:0107200B2@X03PD600d41@0@1`P03PD60107200B2`/020<300h8200B2@X0;2<T01L>
3`03014720<04PH800l060h?00`3100C2@X03`H601L=3P0?1@H04@L801D;300C2@X03@<400h41@0@
1PL04@L801061`0?1@H00P0A1`P01`0@1PL03@<400l51P0<0`@03P@501061`0=0`@01P0>10D04P0E
2``03`D600h51@0?1@H03P@500l51P0=0@D040@801452@0<0@@040D802HJ7P0A1@T03`@701452@0E
2@d03`@701462ACooooo000Kooooo`0U014@3P0?3P`03@`:00d<2P0?3P`04Q4?01HE4`0;2PP04A0>
01<B400>3@/05A@B01PH5P0<30/0820N00/;2@0A4@l02@T701@D4P0>3P`051@B00h>30030`40410>
00h>300@40h04Q8@00l?3@0=3@/03`l=018B40000000?clm024Q7`2j^[P0>SXh00l?3@0200h>3009
00X:200H61H0410>00T9200D51804Q8@01LG5@061P@04Q8@00803@d;00@03Ph<00l?3@0?3`d03`l=
0P0>3P`01@0=3@/02@T701/K6@0Q8Qh0414<00803a0;00`030d800d>2@0A4Pd02``700X;1P0?40/0
3@h900`=200>3P/0410>00l?3@0;2`T2014A3`04010@3P0?3`d03@d;00h>3080410>01@03@d;01dM
6`0n?S`071`J018B40051@<04Q8@0000000e=C<071`J018B400A4@l03a0<00h?2P0<3@P0414<014B
3@0;30L030d800d>2@803a0;01<03@h900/<1P0@4@T04149014B300<3@P01`L500`<300E5AD04Q8@
00X:1`082@<04Q<=00/<1P0=3@d04A4C00`<3P0@418000020080410B01l020P:00T92`0?3a4030`>
00h>3`0C4a<030`:014A3`071`D02`/900X:200>3P`03@d;00l?3@0A4@l03Ph<00H6100920H04Q4?
00@30@0;2PP04a8@018A3`0N7A/0<2l]00T81P0P7ad030/9018A3`0=3@/03`l=0080410>00L03Ph<
00`<2P0>3P`04Q8@01LG5@0Y:BL05QHD00<03Ph<00/04Q8@00h>300<30X061PF00P81P092@L04Q8@
02TY9`1ZJVP06QXH00h>300300`<2P0P00/;2@0:2PP01`L500h>300<30X05aLE00P81P0A4@l02PX8
00d=2`0@40h03Ph<01<C4@0=3@/030`:00l?3@0@40h02@T700P81P0>3P`02`X800h=2`0B4@l03`h<
00`;2@0D4a403@`:00l>300=30X040l=014@3P0?3P`201HF500?018B400000004a<A00l>300F5Q@0
410>00/;2@0?3`d05aLE00P81P0?3P`02@P600l>30071P@03`h<00802`X800H03Pd;018A3`0:2@L0
30/900l>2`0>3@T2010?3@0>00d<2P0=2``04@l@00T720071@P030X=01HD5`081`X020H901DC5019
AdP08b4R01dK700920P200/92P0:00d;300>30d03P`=00h<3@0=2``03`d>010>3`0>30d030X;00d;
30803`d>00@03P`=00d;300>30d03`d>100=2`h00`0>30l040hA00l=4002018@4`0500`:3@0=2`h0
6ALJ00h<3`0<2Pd00P091`X01@0<2Pd03P`?00h<3`0=2`h04@lB00805A<F00<03`d@00d;3P091`X0
0P0A3a803P0<2Pd05Q@G00h<3`0C4A@02@L:00P62@0B41<03P`?00X82`0<2Pd03@/>00l=400A3a80
4Q0C0P0?3A0400`:3@0E00d=3`0>3Q003Ph@00h>400<30h02`/=02DU9`0@41804Q8D01<C5@0820X0
10@6010>3`0;2@X040h?00`:2`0=2``06aTJ01@B4`0=2``03`d>008030X;00/04Q0A01@D500410@0
30`<00X:2P0M7Ad030`<00l?3`0;2`/02PX:00`<300200h>3P803`h<0P0<2`T01@0A40h03Pd;018A
3`0A40h040l=00803`h<00d03Pd;00l?3@0A4@l03`l=00d=2`0@41004a<D00h>400A4A<04A4D00P7
300000@0410A00803Ph>01X03@d=00`<300<30`03Ph>01<C4`0410@04Q8B00@4100D51@03@h:00h?
2@0<3@L03@h800l@2`0@4@`03Ph;01DE4`0=3@/05aLG00l?3`1LG5`0RHV902@T900D51@01`L700l?
3`8051@D01804a<C014A4@0@41004A4A01@D500>3Ph051@D00l?3`0;2`/051@D010@400G5aL0FUYJ
01LG5`0:2PX06QXJ00l?3`0>3Ph2018B4P0c00P8200B4Q805QHF018B4P0>3Ph04A4A00/;2`0E5AD0
4A4A014B5P0D5AP05aPJ01PI6`0G6AT05QPG00X<2`0L7Q`0828O010B3`0F61@03a4<01@D4P0C4a40
4Q8@01@D4P0F5Q@05ADC00l?3@0B4Q005QHD01LG5@0F5Q@051@B01DE5@0T9BD03a<B020T8`0Y<Bl0
6B8Q01hW9P0E71d051TL01TJ7P0K6b007QlS01/R8`0L9B@04Q/J010I600J8b806b@S00806B8Q0`0F
7ah05P0D7A`04a`I01LP7@0F7a`082TV01PQ7P0S;2T06R<P020Y9P0A6QL06R<P01@M6P0V;bh0:S8e
038j?@0P:2/0628S020Z:`0M9bP07BTY01XX:00X=SH201h/;00a020^;`0T<CP08Rlg01/X<00R;cL0
:cU202Tg@00V=3d0EfQb09^//`0eAe40:C]703E7DP0Y?DH08CDn01lb>`0V>480;3i802TkA@0[?4H0
9cE002@b?@0S<C`0=49=04UGHP0jB5<0>4IA02Le?P0S<ST0:CHl02Lc>00O:Rh07BPZ024/;00W<C00
:38a02Lb=@0gA4`0@DiF0:6^]@0S<3H082dc024_<P0O;C008S0c02<a<P0P;Rl09S@e024/<00202<^
<P0L020[;`0Q;3009S4e02Xe>@0R;C409S4e02Td>00O:Rh082X^02<[;P0Q9RX0724T01dR9@0O92L0
7bDU028X:00E6a/05Q`J01hT8P0I7ad08bTX01lW:@0L92L0D5QK04aDE`1oQhX0<c/n01hV:@806R8U
00l04QXM01hV:@0=4QH0=cXo07]nP`0W:Rl04aHK018F6P0G6ah07B4T01/O8P0G6ah061`O01XN8@0F
6Qd01P0H6A/0?P0F5aT061TK01<D5P0B4aD05aPJ01DF600M7R805QLK01PI7@0M7R806AXN018C5`0H
6Ad05QLK01@E6@0E5QX05aPL01HJ7@0E6Q/041@E014E5P0C5aP06Q/M024R900K71h05aLI01PH6P0E
5AL04a<E01LG5`0J61P02PT700l>300E51803@`:01LF500N7A/071/I01<B400F5A<05aHD00l>300D
40l05a<B01/G5P0D40l04@d<01LC4P0B3Pd040`;00l;2P0@30/03`/:010<2`0H51<02PH501TE500G
4a801P8101@@3`0@30/03PX90`0=2@P00`0@2`/04P`>018<3P03018<3P0701@>400A2`d04P`>01LA
4`0@2P`03@L9018<3@0200h8200901<=3@0=1`L03PP8010:2P0;1@D05@l?01H@400;1@D02P@40080
3PP800@03@L700H0000@1`P050/<0`0@1PL00`0A1@L04PH801@82P0600l51P0301D;300U6a`091XK
00803P@500d04`T:00l51P0?1@H040H70147200B20T05@/<01882@0@1PL03P@500l51P0@1PL03`D6
00@03@<400<03`D601061`0>10D00P0<0P<0100=0`@03`D601882@0:008300h21P0801L;3`0S5a/0
3`<70104200A1@T040@800h21P0<00@Dooooo`006oooool0200F5A<03@`:00T81P0C4Q00<C0^04U8
AP0>3@/02`X80P0D4a409P0C4Q0081lM0000000b<S00000000`<2P0B4Q00410>00/;2@0=3@/04A4?
018B400>3P`02PX8010@3P0A4@l0410>00h>300@40h051@B00X:200;2`T030`:00D50`0N7Q`08b<Q
00h>30092@L02PX801TI5`0>3P`04a<A00h>300D51800`<100`<2`0@40h01`L50P0=3@/02P0>3P`0
3`l=00l?3@0?3`d0410>00P81P092@L06QXH04I6A00k>cP2018C3P04014B3@0>3`X03a0;018C3P80
3a0;00@04a@?010A300A4Pd04A8>0P0?3`d01`0<30X0410>014A3`0?3`d03@d;00`<2P0=3@/00P0?
3`d04P0<30X04A4?01hN700>3P`02PX800P81P0C4a403`l=02@T8P0Q8Al05QHD00`<2P0C510030d8
00L80`082@@030d8010A30803@h902<03Pl:00l@2`0?40/0414<00d>200C50`04A8=00d=2`0A4@l0
3Ph>00D51@0820P04A4?01`M600>3`T051D?0000000>3Q0030`>01HF60092@/03Ph@00/;3@0<30h0
4A4C01<C5@0?3a403@d>00H6100A4@l02`/:00D50`0D51<061PF00h>300200`<2P0A00h>300=3@/0
2PX801TH5P0=30X03`h<00h=2`0;2PP03Pd;00@30@0H5aD010<101PG5@0>3@/04A0>00`<2P0>3P`0
0P0?3`d0200>3P`03@d;00`<2P0?3`d03Ph<01@D4P0<30X01PH40P0?3`d02`0A4@l03Ph<00l?3@0K
6aT03`l=00`<2P0;2`T03Ph<03<c<@0000003Ph<00<030`:00h02`/900X:200@40h03`l=00D50`0K
6aT03@d;00P81P0;2`T01`L5010@3P071`D030`:018B408030`:02803Ph<00/;2@0@40h061PF01<B
400:2@L02`X8018A3`0<2`T040l=00h=2`0?3P`02`X800h=2`0=30X01`P500`>2`0410801`L601`L
6P0:2@L03Pd;00<2000@3`d030`:00P:1`0;3@X020T601TH5P0<2`T02@P6010?3@0N7A/04a8@0P0?
3P`01@0A40h02`X800/:200>3@X03Pd900803`h<00h03@`:00h<3@0?3@h06ALH01@B5@0E4aH00@02
01DC5`0A3a8040h?01PF5`010000108301DC508030X;0`0>30d200d;300600l=3P0@3Pl03P`=00`:
2`0=2``03P`=0`0=2``01@0>30d03`d>00X82`0:20/02`T<00<030X=00P01`D8018@4`0K6A`040hA
00P62@0:20/03P`?00d;3P802`T<00<03@/>00h<3`0=2`h00P0>30l03P0?3A004Q0C01DC5P0>30l0
3@/>00l=400=2`h02`T<010>4@0L6Qd09B<V01LE600>30l03`d@0P0;2@`01`0<2Pd03@/>00l=400@
3Q404@lB00l=400>30l00P0<2Pd200d;3P0N00d=3`0>3Q003Ph@00h>400<30h02`/=018B500:2P`0
20P:00L72@061PP07alQ00P61`0=2``05Q@E00`:2`0>30d00P01010>3`0>30d04@l@00l=3P0:20T0
3P`=00@4100V9RH010@4010@40020P8000000`0=3@d02P0<30`02`/;00/;2`0:2@L03`h<00X91`0=
30X040l=00h=2`0@3`d400l>300>014A3`0C4a404Q8@00l?3@0=3@/03`l?014A4P051@L03`lA00h=
4@0>3A804A0E00`<3P0>3Ph400d=3@0G00P8200C4a<04Q8B00h>3P0?3`l05ADE00`=2@0<3@L02P/5
00/<1`0=3PT030d800`=2@0@40h04Q8@01HF5P092@T05ADE02h^;P0000003Ph>00/;2`0G5aL00`0A
4A43010@400D014A4@0E5AD07AdM01DE5@0;2`/04A4A01@D500;2`/07QhN00P8200A4A404a<C00l?
3`0G5aL05ADE00h>3P092@T0410@01@D500O7al2010@400500l?3`0D51@051@D00h?4`0@4A@00P0B
4aD02@0C5AD04aDD01@F5@041P@01`T601DG500@4Ph04Q@?01@D4P0201<C4@0301@D4P0E5A<05ADC
008051@B02405ADC01HF500H61H06ATG01@D500N7ah05a/J024U901lPh80[[Nf02Xc<P0K8R<05a`O
01hO8`0L724061TM01DL7@043@`03aPG01LP7`0A6QT04a`K01PQ800G81l06B8Q01XS8P0K92<072DT
01hW900L9B8051dJ01XS800E7Q/00P0O:2D02@0H8Ah0;CHc020Y9P27T8d0<c`k028Z;@0Q:B`07bLZ
01lY:P02020Z:`08028^;P0N;2`05bDU02hl?00K:BT0;3Xk01dZ<@0V<c/202Pe?@0@02@b>`0J:340
7c0h03Y;E@0nD5X05BLa02LiA@0R=Cl0:3a502TmAP0[?TP0:ce702XlAP0X>D<09SM101h/=`80:CM2
01X0938m02lmB00`?TT0<d5<02/i@`0Z>D00;3U102Te>P0T;c408B`^028];00S;B`08R`[02Pe>00O
;3@06RL_04UFG@0Y=S`0;ca2024_<P0O;C008Blb020^;`0M:b`08Bl`02D`=0809S4e0P0T;c<0100Y
=3P08B``01XU:@0H8bL201HQ9@0U02hh?00]=CP09R/_01dR9@0P9BP092T/020V9P0V;2`07R@T01hT
8P0P9R@06b4O020V9@0M9BL05QhQ03Lo@P0b>Sd0CEEH02D]<00O9bX09Bd`01TQ900N9RT04QXM01dU
:0041``0<C@i01XM8P0A51T0720T01HJ7@0M8B@06QhQ01LK7P0H71l06AdP01LK7P0201HG6@805aPJ
00@061TK01TJ700L7Al07QlQ0P0J6ad0200N7b4071dO01LH700M7R8071dQ01HG6`0A4QH05AHJ0P0F
5a/201DF6P0A01HG6`0D61/04QLG00lC500C5aP05QXK01hO8@0T9BL06a`N01LG6@0H61X05ADG01@D
5P0G5aL04A0>01XI5`0F5A<00P0G5Q@04@0J6AL04a8@01PG5@0A40h051<A014@3P0I61H05Q8A01@@
3`0H51<05A4@014=300D40l04Ph=010<2`0A3@`0510?00804`l>00D07ATH01DA400E4A00510?00X6
1@02014=3005010<2`0?2`X03`/:010<2`0A30d01`0B30h05`0C3@l04@/=00/51`0=1`T040X;00l9
2@0@2PX04@/;00d71`0?2@T04@/;04]5A@0F41002@@401PB4P0E3`l02`D500L10@0?2@T04@P901L>
3`0=1PH04@L8008040H700<04@D70186200D20X01P0@1PL01@0?1@H06Q0A01P>3`0=0`@040H700<0
3`D600T03P@500d3100=0`@03P@500l51P0=0`@0308300d3100?1@H00P0>10D200d3100500h41@0?
1@H040H70147200?1@H00P0F30d02P0?1@H040H700l31`0C1`/040@800d11@0A1@T06@dA00h21P0@
10P301452@0300l31ooooooooooo01;ooooo000Kooooo`0900/:200=30X03Pd;00l>300@3`d04A0>
00/:200<2`T04a8@008040l=00L07ahL01`L6P1SHf403Ph<01<C4@0<30X0410>00803Ph<00/02@T7
014A3`0?3`d02PX8014A4@0D51@03`l?00/;2`0@41005ADE010@400200d=3@0?01DE5@0820P03Ph>
00h>300820H06QXH00`<2P0C4a403@d;010@3P092@P0BTY8024Q7`010@0061PF00803@h901T03Pl:
00l@2`0?40/03a0;01<D3`0@4@`03a0;00`=200<3@T03Pl;00h?2P0@4@`030d800/<1`0<3@P03Pl:
010A300B4`h0414<00`=200?40/04A4>00h>300?3`d03Ph<0080410>00@03Ph<00d=2`0;2`T03@d;
0`0@40h04@0B4Q002@T701XJ600=3@/04a<A00d=2`0D518010@3014A3`0820H05QHD00h?2`0A4Pd0
4Q<>00h?2P0=3PT04Q<>008030d803L02``700`=200<3@P030d800X=1P0D5a00418=00P:1`0@4Q00
3Pl@010A4`082@X03Pl=00lA30072P@030h901TI5`0];B`03@d<00X:2P0<30/03@d=00L71`0=3@`0
3Ph>00/;2`0=3@`03Ph>018B40092@L030`:014A3`0U9B<05ADC00h>300<30X02`/900`<2P0?3`d0
3Ph<010?3@0=30X03`h<00T81P0R8Al02`X800P71@0B4@l03Pd;010?3@0>3@/01@@200X:200;2`T0
3@d;00<03Ph<00L03`l=014A3`0=3@/01PH401LG5@0>3P`030`:00803@d;00@02`/900h>300F5Q@0
30`:0P0=3@/00`0:2PP02@T700`<2`0300d=2`0J00`<2P0;2`T030`:00d=2`0>3P`010@201/K6@0=
3@/01`L500/;2P0<30X03Ph<00d=2`0B4Q002`/900`<2P0:2PP02`/900d=2`0F5Q@0820N010?3@05
10<02PT701HE4`0<2`T200h=2`0B00l>300=30X040l=010?3@0=3P`020d900X<2@0?40d061LE00X6
1P0D40l07A/I00D40P0D5180Q8J303e0?@0@4@h06APF0P0>3@/02P0K6QP08b8P01@C4@0C4Q003Pd;
00l>300=30X030/900d<2@0=30P200h=2`0?00d<2P0@3Pl03`d>010>3`0=2`h06QPK07EcMP0T8RH0
5aDH00X82@0Q7b00928S010>3`0A3a003P`=00803`d>00T03P`=00d;300=2``03@/<00l=3P0@3Pl0
3P`=00`:2`0=2``0100<2P/01`0=2``03`d>00/9300<2Pd03`d@010>4@0?3A000P0=2`h01P0G5AP0
81hQ01DC5P0<2Pd03`d@00h<3`@03`d@01<03P`?00/9300>30l03`d@010>4@0I5aX08b4T00`:3@0A
3a802`T<00X82`0?3A003@/>00`:3@0I5aX0518E00h<3`0A3a804Q0C00@03P`?0P0?3A001`0>30l0
3@/>00d;3P0=2`h03`d@010>4@0=3@l00`0>3Q009P0<30h02`/=00l?4@0?3a4020P:00h>400:2P`0
3`lA014?400N71d05Q@E00P61`0L6Q/040h?00`:2`0?3@h04Q0A010>3`0:20T02@L8014A4@0:2PX0
0`<301@D500:2PX04Q8B00`<300A4A40410@00/;2`0<30`03`l?00/;2@0C4a401`L500l?3@0@40h0
3`l=0`0=3@/03`0>3P`03`l=01@E4P0D5Q<03a4@00d?3P0>40l03@h@00h?4@061`T030dA00h?4`0=
3Q8061TM00X:300200d=3@0300h>3P0?3`l03`l?0080410@00d030`<00P8200B4Q800@4101<C3`0=
3PH03@h8010A2`0B4`d04Q<>00h?2P0C50l030`:00803@d;00T04a<C00l?3`0D51@04a<C00H61P0I
6AT092@T00l?3`0@41000`0A4A409@0@41005ADC01/K6@0E5A<02`/9010@3P0G5aD061PF00`<2P0A
4@l03`l=01@D4P0A4@l05ADE014A4@0E5AD08b<S01`L700A4A407alO014A4@0C4a<04Q8B01DE5@0D
51@04Q<G018C5P0A4Q@04Q<E01@F5P0F61L051HE01<E4`0F61D03Q0=018D400F61<00`0D51801@0C
4a405ADC01HF500E5A<051@B00804a<A06L05QHD01PH5P0M7Ad061TI01TM700G6aX0LGQg09fVY@0Y
<S406B0Q01LL7`0O82@07QhS01PI7@0G7Ql06b@S01<L6`0F7ah06B8Q014J6@0K92<05QlN01/T8`0G
81l051dL01/T8`0@6AP092d/01lX9`0M9RD05QlN01TR8@0N9bH05QlN02D^;@0M9RD0Hfa[02@/;P0N
9B/07B@[02@/<00T;Rl082XY028/:P0O:bP04b8O020_;01gQHD0;3Xj01PV9`0W=3/0934i02Hc?00Z
>4409C<l02Xj@`0[?4H0<T=@07:4T010DUh07Blk02Dh@`0Y?DP0:cm:02e1C00[?dX0:ce902PjAP0U
=d<08c=002XjA`0U=D808c4n02XhA@0Y=d@0:3I202Hd?`0X=cl0:CHn028^<`0N:B/07b//02@_;P0X
<S00:3<_02@a<P0a@4L0H6mf03]:D00`?d@07B`a02@c=P0S<SD09SDh02De=@0O;bl08C4a02<^<P0T
;c<08bhb024/<00R;C409C0d00<08bhb0P0K9RX05P0g@DD0;3@g02DZ;P0L8B@08BHY02@Y;00N92@0
728R020V9P0Q9bD07bDS020V900Q9bH06b<U01LO8P0J8RD06B4T01HN8@0M9BP06R8U03a4A`0841<2
01dU:00:01HN8@0L82L06QdT020S:P0H6b007R4V00lB5`0M8B@05a/M01DI6P<05QXK0P0I6Q`01P0H
6A/05aPJ01LH6P0F5aT061TK01/L7P805aPJ00<06a`N01TJ700J6al00P0I6Qh0100L7B406a`P01@E
6@0E5QX301LH700401HG6`0C5aX05Q/K01@H6@805a/L00h06AXL01dN800I6Q`05ADG01HF600D51H0
4a<E01LG5`0];2T05aHB01XI5@0C4Ph06aXF010?2`805A@@00d071/G08n>RP1UI6006QTE01HB4@0D
40l05A4@01<?3P0@30/04Ph=014=300?2`X040`;00804`l>00L040`;00l;2P0B3Pd04@d<01<?3P0E
4A004Ph=00<04@d<00<04Ph=01@@3`0C3Pl01@0B30h02@0@2P`04P`>01@>400>20X03`T;018<3P0A
2``04`d=01D?3`0200l92@08014;2`0G4A40I5iN04I0@00H4Q801000018<300L5QH2014;2`0900d5
1P090@405@`=01882@0A1`P040H701451`0B1PP050P:00H04@L800H03@<401061`0>10D040H701H<
3@0@1PL200h41@0300d3100>10D03`D6008040H70P0>10D00`0A1`P04PP901882@0200l51P803P@5
00/03`D601061`0C2@X040H7020F5`0O5AH03P@500l51P0?0`L04PH:01452@0200h21P0401452@0=
0@D03P8600l31`8040@800<03`<7ooooooooool04_ooool001_ooooo00P04A0>010?3@0@3`d04A0>
01DD4P0G5Q@04Q4?00d<2P<03Pd;02D040l=01dM6`0=3@/04A4?010@3P0?3`d01@D301dM6`030`40
71`J04e=B`0F5Q@01PH4010@400F5QH0410@00/;2`0=3@d030`<01<C4`010@403`l?01@D500A4A40
7QhN01<C4@0000002PX801TI5`0?3`d04a<A010@3P000000:2PV00`<2P0;2`T05QHD00803@h900@0
3Pl:00l@2`0?40/03a0;0P0<3@P06@0=3PT04Q<>01HG4P0B4`h051D@01PI500A4Pd0414<018C3P0C
50l061TD01TJ5@0B4`h03@h900l@2`0@40d030`:00d=2`0@40h03`l=00h>300@40h03`l=00d=2`0?
3`d00P0B4Q00500?3`d0410>00L71@0R8R0020P600h>300<30X03@d;010@3P0C4a407AdK06EUH`0Q
8Ah05aPC014B3@0>3`X06AXE03@e<00<3@P03Pl:0P0A4Pd08P0?40/030d800/>1`0;3PL03a4<00T;
20051`H06Q/M00D6200720X0C4i<01HH4`000@0030h:00l@2`0Y:RD051DA00l?3@0B4`h00P<100l?
3@0@4@`03@d:00`<2P0?40/03@d;0000000H61H04a<A00D50`1@D4h03`l=00/;2@0>3P`2014A3`0>
010@3P0?3`d02`X8018A3`0A40h030/903Dd<P0C4Q002PT700T81P0?3P`020L5010?3@0:2@L200X:
200;00/;2@0<30X03Ph<00l?3@0<30X02PX800`<2P0:2PP08B4O00d=2`0:2PP00P0=3@/0300<30X0
2`/900X:200=3@/02PX800h>300B4Q00000001LG5@0<30X03Ph<00d=2`802`/900/03@d;00/;2@0>
3P`02PX800D50`000000820N01lO7@0=3@/04A4?00/;2@0200`<2P0?00h>300;2`T03@d;00`<2P0=
3@/04Q8@00l>300B4@l07A`J01@C4@061@<030/900h=2`0?3P`030/900803`h<01003a0=00<81007
2@H02P/900d<2P1WHf80>SHe00<0000J6AL03`l=01`N6`021`<03Pl=00h=2`081`D06QTG0P0C4Q00
2@0>3@/03`h<00X91`0:2@L03`h<00h=2`0=30T03Pd900h=2`0200d<2P0<010>3`0=2``03`d>01dK
7P0?3A00JfU/010>4P0:20/05aDF00X82@01000030X;1@0?3@h01`0>30d03@/<00d;300?3@h040h?
00h<3@0<2P/00P0=2``200`:2`803@/<00T03`d>00l=400@3Q404a4D01@B5@0B41<03`d@00h<3`0=
2`h00P0<2Pd00`0=2`h03`d@00h<3`04010>4@<03P`?01004Q0C01LE600K6A`06QPK010>4@0F51L0
30X=00X82`0A3a803@/>014?4P0@3Q402`T<00`:3@0@3Q403P`?0P0?3A0300h<3`@03@/>00@03P`?
010>4@0A3a803@d?0`0>3Q00100<30h02`/=018B500820X201TI6`09024Q8`16ATP02@L8014?400?
3@h04@l@00/92P0B41403@/<00803P`=01D03@/<00`:2`0;2@X03`l?01TI6@0M7Ad04Q8B00d=3@0D
51@03@d=00l?3`0=3@d02`/;01<C4`0J6QX0410>01<C4@0410804A4?00d=2`0@40h00`0<30X03`0=
3@/03`l=014B4@0>40l02P`;00/=300>40l03PlA00T:3@0@4AD00`@801HG700:2a004Q<H01<D5`02
00d=3@803`l?01/0410@00`<300:2PX09RHV00d=3@0S8b<05aLG00/<200<3@D02``400`=1P0=3PP0
30d700X;1P0T9B003Pl:01LG5@030`402`/900D51@0B4Q80410@00d=3@0@41006a/K010@400A4A40
0P0C4a<0700B4Q804A4A018B400B4Q00410>018B400E5A<04A4?00<30@0D51806QXH00P81P0=3@/0
410>01HF5P0;2`/02PX:01LG5`0=3@d04a<C00T92@0?3`l05QHF00h>3P0I6AT03@d=010A5@0?41<2
00d>401@010A4P0A4a804A<B00d?3@0F61D05aTF01LI5@0=3`X051@B01HF500D51804Q8@01<C4@0F
5Q@04Q8@01@D4P0E5A<05QHD01DE4`0C4a405aLG01`M700A5A@06alN01TQ7`0D7A`06R<R01DL7@0G
71l06a`P01/K800O82@092d^01PR8@0A6aX0=d5003i8A`0M9bH0628Q01DO7P0L9RD07BLV01lY:00V
<2l06bDT02D_;P0L9RD051hM01dW9P0Q:bX06bDT02D_;P0F81l09Bl^00@>3@0Z=3D07bH_038i@@0X
;cD07RPY02D_;P0V<Bd0:SHa02@c;P0P;bX072/X01h/;00iAdP0938j02Xh@@0e@d`0<d5:020a>`0Y
>T@0;3e703U;E`17FVH0:Ce802m2D00V>TH202a2C@0_02a1C00_@dh0<dMB02e0C00U=d<0:c]802<c
@00J:SL093A102hmB`0[>DH0:3I302/iA00X=Sl08c0h024]<P0T;c40930`02@_;@0S;RX092l[01PU
9@0eA4/0Hg9i03]:D00K:Rl072/`01d/;`0N;C008c8e02@d=00N;Rh07bl_02Pc=`0W<SP09C0f02@_
=@0U<3H09c8h01dX;P0O:S008bhd01hY;`0G8RP05b4W01/S9P0N8bL00P0P9BP02P0O92L0728R01TO
7`0N92@07bDS01hT8P0R:2H08RPW01TQ900Q:Rl201TR9`0D01XS:00K92T07bP]069[L01:DeP07BH[
01TR9`0I82H051PQ024T;00>4AP06A`S01HI7`0O8RL0720S01<G6@0C5aP04aLF018F5@0E6AP301TJ
70<061TK00h05QLI01XK7@0G61X061TK01/L7P0H6A/05QLK018C5`0A4QH06AXN01dN8P0=3Q805QLK
01PI7@806Q/O01@05aPL01@H6`0I7Qh05QXK01LK700B5QL03a0B014B500E5QP04Q8D01<C5@0A4A<0
410B01@D500M71T03@`801<B3P0;2PH06APD00X91@804a8>00/061LC0:ZYY@1iN7@05A@@01@@3`0I
5A@05Q8A00l;2P0@30/04`l>018>3@0200l;2P07014=300?2`X0510?00`81`0=2@P05Q8A010<2`02
014=30803`/:00@040`;014=300B3Pd04Pd>1P0A2`d03P0B30h04@/=00l92`0A2`d03`T;010;2`0F
4Q404`l>00d9200>2PT040`;01@@3`0810<04`l>0P0@30/01`0H51<0RXF5061JFP0A2`/071<D01<:
2`0<0`@00P0B20T0100A1`P04@D701451`0C1`T60147200600h41@0A1`P04PP901882@0D2P/04`T:
0`0?1@H0100A1`P04PP901D;300A1`P200l51P0301882@0D2P/050X;008040H700H03`D600h41@0?
1@H040H700l51P0;0@8201P>3`0400d3100A1`P02`0300h21P@040@800@04`L;01862P0@10P03`<7
0P0>0PHDooooo`006oooool06P0F5A<04A0>00/:200920H02`X800d<2P0D4a403`h<00h=2`0@3`d0
4Q4?014@3P061P@05aLE014A3`0=3@/02`/902PX9P0M7A/02PX801HF500];B/020P601<C4@0>3Ph0
51@D0P0?3`l0500@41002`/;010@40051@D071`L00h>3P0410@02`/;00/;2@0S8b40>SXh07emN`04
10801`L500h>3@0C4a407alM01HF500E5A<02PX80P0=3PT00`0>3`X03a0;00l@2`0200l@2`0300h?
2P0:2`H02P/6008030d800H05aPC01/L5`0A4Pd0414<018C3P0A4Pd201LH4`0900l@2`0=3PT03Pl:
00h>2`0;2`T03@d;014A3`0>3P`03@d;00804A4?02`03`l=010@3P0B4Q004A4?00h>300;2`T020P6
01DE4`071`D03Ph<018B400:2PP05ADC00d=2`0C4a40Fe]I010A3@0720<02P/600P9100:2`H05QLB
00T:1@0;30L03Pl:00l@2`0>3`X030d800`?20062@803a4=00lA40072@P08B8T09fNX00O828020X9
00`>2`0I6aH02Pd60001000=3PT01`P300P910804a@?00H030d800/<1`0?40/03Pl:00P9100720<2
00d=2`0G014A3`0@40h051@B00L71@0:2PP03`l=01<C4@0A4@l03`l=00d=2`0D4a402@P6018A3`0=
30X06APF00l>300>3@/02PT700d<2P0920H040l=00h=2`0<30X00P0;2`T0700<30X03Ph<00l?3@0>
3P`030`:00d=2`0A4@l06a/I00T91`0<30X0410>00l?3@0>3P`03`l=00/;2@0?3`d02PX800`<2P0A
4@l00000014A3`0<30X03`l=00h>300:2PP02`/900d=2`0<30X200l?3@0?00T91`0F5Q@0C4a:09VI
U`0:2PP02@T7010@3P0820H030`:00d=2`0<30X03`l=00`<2P0820H02PX800802`X800@05aHD00l>
3@0;2PP04Q4?0P0?3P`05@0;2PP030/900/:20092PP041DA00lA3P0=3P/06aXH07UeM00R7Qd01`<2
018A3`061PD092HS01<H500@4@h03Pd;00D40P0G5Q@02@P600l>300200d<2P0I00/:200920H03`h<
00l>300>3@X03`h:00l>300=30X030/900h<3@0C4A802@L800400P0D4QD08b4T01LE6@050`H040h?
01@B4`0M6a`02PP901<A4P0>30d03`d>010>3`0200l=3P0700h<3@0=2``03`d>010>3`0>30d030X;
00d;300200l=3P0600h<3@0=2``03P`=00l=3P0>30l03`d@0P0A3a800`0?3A003P`?01@B5@02018@
4`805aDH00<040hA00l=400?3A00100?3A002P0B41<040hA014?4P0E4aH04Q0C00T72P0G5AP061HI
00l=400<2Pd200h<3`0601@B5@0<2Pd020H900`:3@0@3Q403@/>1P0>30l01`0?3A003P`?00h<3`0>
30l03`d@010>4@0=3@l00`0>3Q009P0<30h02`/=00P82P0V9RP02`/=00d=3`0>3Q004a<E014?4002
00404a4B018@4@081PL04a4B00h<3@0?3@h02`T:00d;300?3@h03@/<02@T900>3Ph00P8200l?3`00
00004a<C00d=3@0<30`02PX:00/;2`0D51@06a/K010@3P0?3`d01@D301HF500:2PP03Ph<0`0=3@/2
00h>300=00h?3@0;3@`02P`;00`>3@0>40l03PlA00/<3`0D5AT00@86018C5`0310T03a0E00`<3`02
00h>3P<03`l?01P09bLW01/K6`0S8b<03@d=00410@0A4A4051DA01DF3P0@4@T030d600X;1@082@<0
3Pl:02<T7`0>3`X0820N014A3`0@40h05QHF01<C4`0@410030`<00H61P0820P2018B4P<04a<C00@0
4Q8B01PH5P0D51804A4?0P0E5A<05@0<30X02`/901dM6`0];B/092@R014A3`0G5aD03`l?00/;2`0G
5aL06a/K00/;2`0C4a<03`l?018B4P0F5QH03@d=01LG5`0<30`04A8F014B5@02010A4`0@014B4`0A
4a805QPG010B400A4a007R0M00d?2`0I6aH04a<A01LG5@0E5A<04A4?018B400F5Q@05ADC01PH5P80
6QXH03H061PF01HF500D51@07b0O00hB4@0J7Qd04APG01lX9`0K92<06R4R01`Q900K72006ATN020Q
9@0K92D02Q@C014K6P0Q:bX07BLV01LQ800J92<0628Q01LQ800I8b807BLV01hX9`0Q:bX07BLV01lY
:00K9B@07bTX01PR8@0P:RT09Bl^020Z:@0J92<08bd/024[;@0l@Td0BU5K038i?`0N:2T08R`[01lZ
9P0J9b004B0K02Th<`0W=S<09S@d01d[;00X=cl0:SQ103=1BP0`?TL202Hg@@0?03Q9D`0[?DT0:ci9
02TmB00[?T`08cQ402DkAP0Z@4/0;45<02/oBP0]@D`0<DA@02XlB00^?T/0:c]800809SI300L08c50
02PeA@0]>dP0=TA@02hlA@0T<CX082`a00808Rh^01408bh[02@_:`0X<bd09c@d02@c>P0R<CP082le
01`[<00U=3T07Rd`01l^<@0W=ST0:3Ph028b<P0P<300:3<i02Ha=`0202<^=0809C0f00l0:SDk02Pc
>@0W<SP09S4g02@_=@0P:Rl061lU01hS9`0S:2/08BHY01lT9`0P9RH0:S0`02H/;00R:2H00P0Q9bD0
;00P9bH06B4T02</<@0L9BX06B8W020Y;P0E7R<0214F0:F^/P1jPhP031DJ020Y;P0<4aT06AdV03Hi
@@0I72<08RD/018E6`0J7B807R8U018F600C5aP051PG014E500G6aX051DG01HG6@0G61X06AXL01/L
7P0L7Al05AHH01XK7@0H6A/06AXL01`M7`0I6Q`04a@H024R9P0K720051DI01HG6`0E5QX05aPL0`0H
6Ad08@0G61`05ATL01DJ6`0C5aP05ATJ018F5`0B4aD05AHH01@E5`0A4A<04Q8D014A4`0@418051@D
00h=300O7QX07A`H01@C3`0R8Ad071/G01DD400H5a<030/7038a;@0L6aL030/7018>3@0I5A@05Q8A
018>3@0C3`h04Ph=01DA4003018>3@05014=300@30/030P700/71P0@30/00P0>2PT00`0A3@`03`/:
00l;2P0200l;2P03010<2`0A30`040X<00@040X<00X04`d?010:300>20X040X<00/51`0:10H05a8B
01PD4`0@30/03`/:0P0>2PT03`0<20L03PX901`H5`0:1`H05Q8A00P40`2KUYD0K6IV010:2P0B2@X0
30<401482@0C2@X04PP90147200201451`030186200@1PL040H700@040H700T03@<40147200C2@X0
3`D600h41@0@1PL04@L801061`0?1@H00P0>10D200l51P0300d3100<0P<03`D6008040H70P0A1`P0
2`0@1PL03`D600l51P0@1PL0308300/10P0?1@H040H700h41@0A1`P03`<7008040@80P0?0`L01@0=
0@D060`@01H:3P0C1`/04@D9008040@85?ooool001_ooooo01P030/900h=2`0A40h04Q4?014@3P0?
3P`04A0>01<B400?3P`02`X800d<2P0@3`d0410>01<C4@0H61H05QHD014A3`061P@03`l=010@3P0=
3@/02PX9014A3`0@40h200l?3`0?00/;2`0F5QH07AdM01DE5@0h>3P0410@00l?3`0=3@d071`L010@
400>3P`02PX800`<2`0V9R@03`l=00803Ph<00D04A4?00T91`0=3@/01`L500h>300200d>2@0300h?
2@0?40X03a0;00803a0:00h061TD01@E3`0B4`d0414<00d>2@0I6QD07QlJ014B3@0?40/0414<00h?
2P0B4`h0414<00d=20804Q8=00H03@h:00X:200<30X04a<A00h>300<30X2018B40<03`l=00h03Ph<
010@3P0820H04a<A00h>300D518030`:01<C4@0H61H02`/9010@3P061PD0410?00l?3080414<0340
3@h900l@2`0D5A007QlJ01/L5`0C50l03@h900/<1`0<3@P03a8<00/@2@0;3`/030l>00X>3@0=4100
9RTZ00dA4@0=4A001`X800@9100@4`h04a@>00X;1P0?40/02P/501DF400V9b803@h800P90`0?40/0
2``700D60@0W:2<07QhL00T91`0b<S00=3@b00h>300D51802`/900h>300=3@/02`/900X:200=3@/0
3`h<00d<2P071P@02@P600802`X80P0?3P`0100=30X040l=00d<2P0@3`d200l?3@0:00d=2`0<30X0
3Ph<00l?3@0<30X03`l=00`<2P0F5Q@03Ph<010@3P803@d;01T01`L500X:200D51804a<A00`<2P0>
3P`03@d;00`;2@0?3`d03@d;00`<2P0@40h03Ph<00T91`0:2PP03Ph<00T91`0A4@l03`l=014A3`0B
4Q00<c<a06MWI@0A4@l02PX800803Ph<0P0;2`T030092@L03@d;00d=2`0;2`T03Ph<0450?P0D4a40
30/900l>300B4@l03`h<00d<2P803`h<020051<A01DD4P0=3P`04QHB00840P0>3P`03P/:01/G5P0?
2PX05a<B00d<2P0=3@/02@/800L:1`092`P04A0>00P71@0<2`T01`H4014@3P0:2@L03`h<014@3P0<
2`T03Pd;010?3@0>3@X040l;018A3`0@3`d030/900/92P804Q0A00P02`T;014?4@0A3a803P`?00h<
3P0L6Q/02`T:00d;30804@l@00<03@/<00h<3@0@3Pl00`0@3Pl02P0=2``03`d>010>3`0>30d030X;
00d;300C4A804Q0A014?4@0?3@l200h<3P8040hA00D03P`?00d;3P0=2`h03@/>00`:3@0200/93080
30X=00<03@/>010>4@0?3A000P0<2Pd00`0?3A0040hA00l=4002018@4`0500l=400<2Pd02PP;018@
4`0>30l00`0@3Q401P0J61/03P`?00h<3`0?3A003P`?00d;3PD03P`?0P0?3A02014?4P0500l=400>
30l03`d@00l=400=3@l00`0>3Q001P0<30h02`/=00l?4@14A4H07QhP00d=3`803`lA00h040h?030^
;`1]Jf`040h?00d;300>30d03`d>014?400=2``03`d>014?400=2``0@T9202@T90803`l?00l07alO
00L71`0>3Ph02PX:00T92@0;2`/03Ph>00l?3`0>3P`03@d;018B400W9bD0410>00h>300@40h00P0?
3`d200h>300=00`=300;3`h03a8A00hA4P0;3a0030l@00hB4`0830h030hB01PK7`0/<3@0FE]O00l@
5002010@4@0K00l?400?3`l03Ph>03/k>P27QhH07alN00l@3`0d=C@03Pl?01`M6@0J6a@051@=00l?
2@0?40T0410:014A30092PD071dH00L6100C4a4051@B01DE500:2PX04Q8B00l?3`0F5QH04a<C0080
4Q8B0`0@4100;@0B4Q805ADC018C3P0@4@d04A4>010A300?40`03`l<014B3@0I6QH051DA014C3P0B
4`l051@C014A4@0N7Qh04a<C00`<300c<c<0@D5101/K6`0@41004Q8B00d=3@0E5AD04Q<F01<D5`0D
5AH051DG01<D500A4a804aDD010B400G6AH07b4N05YLF00B50l04a<A01LG5@0F5Q@04A4?018B400G
5aD06QXH01TI5`0201PH5P0?01TI5`0J6QP06QXJ01@E500M81l061`K01/R8@0F7ah082PW01XP8@0K
82807R0T01`L8@0K7R406R8R00807RLV01005AlN01@N7@0H8R40628Q01`V9@0E7ah08B/Z02dg=`0X
<S40JWAd024[:`0L9RH08B//02Tc=00H8R<08bd^0P0R;2d0C00N:2T09Bla01TR9P0nADl0<CQ202T`
>00S;C008B/[01lZ9`0Y=S40:cXf02He<@0U=3809S@d028a=@0X>4009cHo02`lA@0W>D00:ca502Hh
@@0Z?4L09CM202e0C00S=T@0:ci<02DhAP0Y?TT0;D9=02XoBP0U>D@0:3]60312CP0W>D@0;Cm:02/m
B00^?dX0=DEA02XiAP0X=D@0:3I302`jAP0T<S/08Rlg028^<`0R;Bh08Bd]024/:P0T;b/0:cHa02dj
>`0K:S408c4h01l^=00P;c@07R`b02Hd>@0W=SX0;Se102hm?P0U=CH08c8c02Lc>@0T<3H08Bdc028^
=00U<3H08bhd01hY;`0Q;3808Rdc028]<P0S;S<08B/`02<Z;`0R9bX201hS9P0P020U:00P9BL0@4E7
02dc<`0R:2L09B/Y020V900O9RD072DZ01/S:`0M9Rd05b0W01XS:@0K92X08BX_02Ta=P0V;S804QXP
01hV;00O9R`05Q/R01XN9@0N8BL06ahU01PK800J7B808bLZ01HJ700H71d061`L01@H600M8B4201HG
6@<05AHH0P0D5AL201TJ7@0;01XK7P0M7R4061TL01<D600Q8RH06Q/O01@E6@0H6Ad051DI01HG6`0E
5QX00P0D5AT0100F5a/051PK01@I6`0B5QP201@H6P0501LH6`0K71h05AHH01<C5@0E5AL00P0C4aD0
200G5aL0F5QC00h>2@0K6aD051<>00/:1P0I61<07ahJ0P0A40/00`0G5Q404a8>01XI5@02018?3P0B
01<A3`0L6QP05a@C00/81`0@3P`03`/:010<2`0C3`h04Ph=01<?3P0j=SD0<bl^014=300E4A0040`;
018>3@0A3@`040`;0`0?2`X00`0@2`/040X<010:3003010:300H014;3@0;1@L03`T;01<=3`080P@0
5a4C03<^;P0J5QD02PH5018>3@0=2@P02`L601<?3P0710<040`;00l<2`0@30/040d<01@?3P0>20P0
40X:00l61`0=10D03PD60P0C2@X0100A1`P04@H701461`0A1PP601061`0400h41@0=0`@03`D60106
1`803P@500D03`D600h41@0>10D03P@500l51P020147200500l51P0=0`@03P@501061`0?1@H00P0B
20T01P0@1PL03`D600l51P0?1@H03P@501<92P80308300@04PP900`20`0C1`/04@D90`0@10P00`0?
0`L050P<01862P0200l31`030104200A1@Wooooo01?ooooo000Kooooo`0500X:200>3P`03@d;00h>
300A4@l00P0>3P`01@0=3@/03`l=00d=2`0:2PP0410>00803@d;00X03Ph<00l?3@0A4@l04Q8@00P8
1P0?3`d05QHD00X:200@40h03`l=0P0A4@l04P0@40h03`l=00`<2P0<30X04Q8@01@D4P0E5A<05QHD
02TY9`0L71X04A4A00L71`0E5AD03@d=018B4P071`L03`l?00d=3@<030`<01<030`:00d>2P0=3@/0
3Pl:00l?300?3`d03a0;00l@300@40h0414<014B3P0A4@l03A4=04iCC`3=d/h0?T8n01XL6@0F61D0
2PX800803`h<01<040h<014=300A3@`030T601DF4@0>3`X03Ph<00h>3P0H61P03Ph?00d=3@051@D0
3`l=00`=20092PD05QHC01LG5@0B4Q002PX800803Ph<00L02`/900T91`0?3`d04Q8@00P81P0;2`T0
3Ph<00803@d;0P0:2PP09P0H61H051@B018B400=3@/02`/900d=2`0@40h04Q8@00lA3P0=3P/030`:
00/=2P0>3`d03Ph>00h@3@0@4@l0410>00d?300;30P03Ph<00l@2`0@40d03`l=00h?2P0<30T01@D3
018C3P071`D06ATG00h?2P0>3Pd04Q8@00D50`1=CD/0IfMU00/;2@0C4a402@T70P0@40h200/;2@07
01<C4@0820H02@T700`<2P0>3P`03@d;00T91`0600h>30802PT700`03`h<01DD4P0B4@l02@P600X9
1`0>3@/03`h<00h=2`0?3P`040l=00d>2@0?40/200/<1`0300l?2P0=30P03@`800803@`80P0?2`P0
200=30P020X7018D4@0D5Q<06A/H00X:200G5aD0410>0P0A40h3018A3`0700d<2P0?3P`03`h<00`;
2@0;2PP030/900h=2`0300l>3005010?3@0A40h051<?00d<200<2`L00P0?3PX06`0=30P03`h:00h=
2@0B4@d0;bhZ02LV8P0=30P030/700d<200@3@X04@d:014=300=2PT03@`:00T7200;2`/03Ph>00`>
3@0?3`h02PT700d<2P0?3P`03@`:00`;2@0:2@L02`X800d<2P0200l>300400d<2P0<2`T03@`:00d<
2P803`h<0P0@3`d02P0?3P`04A0>010>3P0<2P/08AlP018@4@0?3@h02`T:01`J6`0S8B8200d;3080
30X;00/03@/<00l=3P0B41406ALH00l=3P091`P03@/>00h<3`0@3Q404@lB010>4@02010>4`0:018@
5@0D4QL02`T<00h<3`0?3A002`T<00T72P0:20/02@L:00/930<03@/>01L040hA00l:400@2a403`X@
00d83P0>2@l04@`B01PC6@0J5A/04PdC010;4@0C3Q@030X?01@B5`0B4AH03`hC00d<4@0;2Pl02PT>
01@C600F5AX051<H010?500200d<4@0800d;400?3A804@lD014?500@3Q<03P`A010>4`0>314200`:
3`0900h<4@0@3Q<02PP;014?4P0;2@`030X=018@4`0A3a8040hA00803P`?0P0:20/02P0?3A003Ph>
01LG5`0K6a/04Q8B00X:2P0=3@d03`l?010@400<30`200l?3`0l00T92@0<30X01`L5018B400:2PP0
6a/I00d=2`0>3P`02@T700`<2P0@40h04Q8@00@40P0;2`/03Ph>01@D500B4Q804a<C01XJ6P38b<P0
:b/[00D51@0C4a<05QHF00d=3@0>40l03Ph>00h?3P0=3`h03@d=00`=3@0?4A004A4C00T:300j>cd0
VYZL00l@5P0M7BD02PT?00d<400B4Q8051@B01lP6`2:S8L061XE01DK5`1MHf401@/900d?3P0>3@T0
5Q8?00d:2@0@3`/05a<@010>300E518061HD01<?3P0>3@/0518@1@0?3`d00`0?3`l08b<S01dM7@02
01HF600>01DE5`0>3Q003Ph>00h>300?3`h03`l?010@3P0?4@l051HE0001000D61D061XI014F4P0F
6QP6014C400U01DG500:30T07R0M01`N6`0G6AH04A<@014A4@0G5aL051@B018B4P0E5A<04a<A01TI
5`0B4Q0061PF01`L6P0/;2X0410>018D4@0C5A804A<@01@F4`0J71T05QPE028T8@0D5Q<05aTF01TK
600E5a@07R0M01dM7@0D51@07AlN00/=300C5aH06AlM01XN7@0201XP7P1V01XP800J7Ql061`M01LM
6`0I7ad0728P01dT8P0M8b<06b@S01HN800K9BH0:cDf01lY:P0a>cd0:cDf02lk=`0P;2P07b/W01hZ
9`0N:RP08bl]01hZ:P0P:bd08Rd_02Ha<`0Q;30072DZ02Xa=`0U;3808bX`02/d>@0/=cT09S4c02<_
<P0S<C@07Rd`02@d=`0Q<3D08C8i02PlA00W>T4093Ln01T^<`0N<CL09CPn020c>@0R=C`0:Ca402Li
A@0T=T809SQ602LiA`0Y>dT0;T1>02`nBP0X>4D09cQ202Df?P0T=Cd09SLo02@e?00X>D00;Si702Le
@00Q;cX0<Cm802Lf?@0O;3@0;c]0028];`0M:2X09C0`024[:P0R;2/0:3<e02Ld>P0N:Bl09S4i01l/
=00T;cP092hg01h[<`0R;CH0:cDo020]=P0V<CX09cHk024`=@0L:c006bX_01/X;P0Q;c806RP[028`
<`0V<C@0:3<e01dX:P0J92H07BHU01/T8`0H8240620R0P0K8bH0<@0N9RT07BDX01`T9`0M9RD07RLV
024Z:P0K8S@061hf02@[@00Z<400728`01DL9@0N9B/06b0T01lT9`0O92P06AhR01dR9P0G72006B0S
018G6P0@5AT051TL030e>011ADP05ALK01lP90061`/07b0S01PI6`0];S007QlQ01LH6P0F5aT051DH
01@E6@0L7B404a@H03@e>P0=3Q<08b@Y01DF6`0C51P05QLK01TJ7P0J6al061TM01HG6`0I6Qh00P0F
5a/02P0H6Ad05AHJ00lC5P0<41D020/@01@G700L7b@061TN01hO8`0A4QH2018A5P804Q8D01004Q8B
01hP700?4@h06adH00h?2`0E5A<07AhI09RIU@0K6QP03@`801DD4@0>2PT04A0>01<D4P082PL030h;
0P0K6aT03@0?3`d02@T700h=2`0C4Q003`h<00`;2@0<2@P061@C01hJ6@0>2PT04Ph=01LC4P0A3@`0
0P0?2`X0100@30/04@d<014=300C3Ph201<=3`04018<3P0A2`d04@/=010:30804@/=02403`T;01@>
400E3a404@/=018<3P0=1`T040X<00d72@0H4Q@02@<5010:300G4A<040X<00d72@0A2`d03@T900h:
2@0@2PX04PT:01482@0B20T04@L800X00@0A20T02@0101D?3`0<1PH06a8C01<92P0B20T03`D601<9
2P0>1@D01P0>10D01@0=0`@04`T:00`20`0?1@H03P@500804@L80P0@1PL00`0C2@X04PP900d31006
01061`H03`D600`04@D901D93@0<00@0300401H:3P0B1PX030040106200C1`/02`0301<92`08000D
ooooo`006oooool01@0:2PP03`l=00d=2`0>3P`04A4?00803Ph<00@02`/9018B400E5A<0410>0P0=
3@/00`0>3P`03`l=010@3P02014A3`0800d=2`13@d40410>014A3`071`D03Ph<010@3P0?3`d200h>
30803`l=00h04A4?010@3P0=3@/03Ph<01HF500>3P`03Ph>00D51@0B4Q803Ph>01<C4`0;2`/0410@
00h>3P@03@d=0P0=3@/04@0>3P`03`l=00l?3@0?3`d02`/900h>300?3`d0410>00h>300H71P0N7ei
0??hm01AEU80008000`>2`0C4a403`h<00@04@d<00l05Q@@010A2`0310004Q<@00/;2`0<30h03@d?
00X:300A4A402`/900h?2P0C50h0410<01<C4@0D51800P0A4@l04P0?3`d04A4?00X:200=3@/0<30^
03Lg=@0O7ad030`:00l?3@0B4Q005ADC00h>300410804A4?010@3P0=3@/02`/900`<2P@03`l=0P0>
3P`00`0=3@/03`l=00d=2`0200X:200@00/;2@0?3`d03Ph<00h>300@40h03`l=00h>300<30X03Ph<
00l?3@0<30X04a<A00L71@0?3`d03Ph<00`<2P8061PF00d01`L600h>300C4a4020P600h>300E5A<0
410>00`<2P0=3@/03Ph<010@3P0C4a404A4?00L03@d;01<03Pd;00d<2P0A40h05A@B01@C4@0=30X0
30/900l>300@3`d03Pd;00d<2P0>3@/03@h9010A300;30L02P/600l?2P0<2`L03Pd900<040`900<0
4@`9010<2@0C5Q<00P000@00101bM740IfMU018B400;2`T300`;2@803@T800D03Pd;010?3@0?3P`0
3@`:00`;2@0200d<2P<03Pd;00D03`h<010?3@0C4Ph03@`800`;1`0200h=2@0900d<200:2@D02`X6
00/:1P0L6aL061LC00d:1P0@2`L040`900804@d:00`03Pd;00/:200@3`d03Ph>018B4P0@41001`L7
00X9200<2`T03Pd;00l>300<2`T200X91`8030/900@03@`:00h=2`0>3@/03@`:0`0<2`T300/:2005
00X91`0<2`T03@`:00P71@0D4a400P0=2``03P0:20T040h?01PF5`0A3a003P`=00d;300<2P/03@/<
00h<3@0A3a00;R`]024O800C4A803P`?0P0<2Pd03`0?3A803P`A00`:3`0<2A003@XA00l<4P0=2a00
40hA014?4P0=2`h02`T<00`:3@0:20/030X=00h<3`0200d;3P0=010>4@0?2Q0040/A00l:400=20h0
3PT?014<4P0@2a404`hD00h93`0=20h04@`B00`:3`0300d<4@<03PdB00H020L<00/:3`0<2a0030/@
00d<4@0@3a@200d;400600h<4@0=2a003@/@00`:3`0@3Q<03P`A0P0<2Pl0100>314040hC00X82`0A
3a8200`:3@0N010>4@0?3A003P`?00d;3P0?3A003@/>00h<3`0C4A@0410@00d=3@0>3Ph02PX:00/;
2`0@41002PX:00/;2`0:2PX03`l?010@400;2`/051@B01PH5P0D518010@201HF50092@L030`:020P
7P0O7ad02`/90P0>3P`0300>3Ph04Q8B01DE5@0>3Ph0410@00h>3P0g=cL05ADE01PH6000000051@D
00T92@803@d=0P0>3Ph07`0=3@d0410@00l?3`0H61P04A4A02DU9@1]KFd04a<H00X:500;2Q8051<G
014A4@0?3`d051H@02<V7`0E5a8010X5014G4`0L8R002`d;018>3@0E4A003`/:018>3@0I5A@0510?
01<?3P0D40l040`;00h:2@0@3P`00P0?40/300l?3@0:00l?3`0G5aL04a<C010@4P0C4aD051@F010@
4`0?3a403`l?010@40804A4A00P0418A00h@3`0W:BP02`l>00T=300G6aX03A<A01<E4P804Q@A01h0
4A<@010B3`0@4Pl0418?02HX9@1@DTl051HC00<50P0I6aP04A4?01<C4@0@40h04A4?01LG5@0D5180
6a/I01`L6P0820H05ADC01XJ600H61H04aDB01HH5@0C5A804Q@A01HH5@0D5Q<06Q`I010B3`0B5142
01HH5@0901PJ5`0M7Ad071`L01dM7@0D5QD06ahM01<G5P0I7A`06AhL00806AlM0P0K8Al0100I7A`0
6alN01dQ800M8b4201dS8`1]01hV:00K9BH082X[01LQ8`0V<3808bd^02Te<00M:BD07b/W028^:`0U
<Bl0:SHf02Lc=00Q;2h04A`P01TT:00T;c<06RDY01lW:`0S:S0092/a02Tb=`0V<CD082/_02<`=P0S
<SL07bhc02@f>P0O<3L083<i020f?@0T>3l093To01db=`0O=3L093Pl028e>@0S=S`09SU102Li@`0U
=D807Rhm024a@00Y>DP0;Ce<02dmBP0^?dT0;Ci702Tj@P0]?TH0<D9902Li?@0T=C`0:SY202Xh@`0X
=Sl0=49:02dl@`0V<cT0<Si302Pc=`0M:2X092h`02@^;`0S;B`0:cHh03U4BP0O:S008bhd02Xd?@0V
<3T09S0j02Xd?P0R;3H0:C<o024[=`0U<3/08c8i01la=@0P<SH08C0e01d/<@0P;S409C<f02@b=@0J
9BL06BDU01LS8`0R;B`06R<R01PQ7P0G81l06R8U01hV:@0P9bd08BP^020W;@0O9bT07BDW01dV9@0M
9BL06R0f01PM>P0T:D@0:Rm301hT<P0I82X07B8V01/P8`0201dQ900?01/O8`0L8BD082DX01dU9`0I
8B<08BHY01`Q900I7R4051PK00T;3`0@4AD0:2T]01LH70092Ph06a`N00<05QLI01/05aPK01hO8`0B
4aP08R<X069SJ00/;3@07AdU02LX;@0M7R<07AhR01`M8@0I6Qh05QLK018C5`0E5QX051DI01DF6P0I
6Qh061TM01<G6P0N8RP03a8I01XM900V:C00LW=h00d>4`0B4aL00P0C4QL201<C5@0C01<E500=40h0
71hK00L91P0E5a@06QXH00`<2P0o?cd05QDC01<B400F5A<04Ph=00l>300?4`l02a0<00dB3P0B5140
3Q0=00H81@02010@3P0400l?3@0A40h04a8@00l=2`802`L600@03@T8010<2`0>2PT03@T80P0?2`X0
100@30/04@d<014=300B3@h4018<3P07014;3@0?2@/04@/=014;3@0<1PP03PP:00l92`02010:300=
00/51`0B30h0208401D?4@0<1PP0208400d72@0:10H02084014;3@0?2`/02`X800l92@0201482@0=
0147201CBDX08QPI00d41@0;1@D03PX900d9200@1`P02`4200d3100800003`D601D;300600h41@06
0147200O5AH04`T:00l51P0E2``050X;0P0?1@H0100A1`P05@/<01H<3@0C2@X<00l51P0<0104200B
1PX03P8600h21P0A1@T03P8600d11@0?0`L02@0101lC5`0?1@L060`@5?ooool001_ooooo00/02PX8
00l?3@0>3P`03`l=018B400?3`d03Ph<00/;2@0E5A<06a/I01@D4P0200`<2P0<00h>300A4@l04Q8@
014A3`0?3`d04A4?03hn?00J6QP04a<A00X:200B4Q003Ph<1@0?3`d03`0C4a40410>00`<2P0E5A<0
30`:010@3P0F5QH030`<018B4P0?3`l04A4A00`<300@41003`l?00h>3P0300l?3`803@d;01403Ph<
00l?3@0?3`d03`l=00`<2P0>3P`03`l=010@3P0>3P`030d:01/M6P15AT<07b0M00H71@0H61H02`/9
00h>300400l>300A00l@300B4`d04a@?01<D4@0?3`l01`L9038b=00@418030`<018B400:2`H04A8<
00X:1P0?3`d04Q8@00h>300=3@/00P0@40h2014A3`0:010@3P0=3@`030`:00l?3@0<30X04a<A01@D
4P0A4@l051@B00d=2`<03Ph<00@03@d;00`<2P0=3@/03Ph<0P0@40h01@0?3`d03@d;00/;2@0=3@/0
410>00804A4?00<0410>00h>300>3P`00P0?3`d200h>300701<C4@051@@04A4?00P81`0@40h08B4O
00/;2@0200l?3@0900T91`0B4Q002@T700X:200B4Q005ADC00l?3@0:2PP03Ph<008030`:00@03Ph<
00l?3@0>3P`02`/91P0<30X04`0@3`d03@`:00h=2`0A40h04Q4?00l>300>3@/04A0>010?3@0>3@/0
30/900d<2P092PD030d800X;1P0<3@P04Q8=014@300?3PX00`0A3@X02@0B3@X04@d:00/>2`0E5a@0
4A<@01TK600P81h0:b/Y018B4002014@3P04010?3@0A3@`040`;00l>30804A0>00H03`h<00h=2`0>
3@/03@`:00`;2@0=30X300h=2`03010?2`0=30P030/700803@`800T030/7010?2`0@3`/03`h:00d<
200>3@T04@h:01<>2P0A3@X00P0@30T03P0=30X03Pd;014@3P0;2`/03`l?014A4@071`L02`/:00h=
2`0?3P`03Pd;00`;2@0:2@L02`X8100=30X300h=2`0@00d<2P0<2`T02`X800/:200<2`T03@`:00h=
2`0@3`d03@`:00`;2@0;2PX04Q0A01`J6`0C4A804@l@00`:2`803`d>0`0>30d04P0?3@h08R0Q01PF
5`0>30d03@/<00`:2`0?3A003`dB00h<4@0<2Pl030T@00d:4@0?31804@lC014?4P0C4A@040hA00l=
40803P`?00d040hA014?4P0>30l03@/>00l=400=2a003P`A00d;400;2@h030X?00l=4P0;2@h03@/@
008030X?0P0@3Q<00`0<2a003@`A00`;400300d<4@8040lD00L03@`A00X93P0;2Pl03`hC014?500@
3Q<03P`A00<03@/@00/040hC00l=4P0=2a003@/@00l=4P0@3Q<03@/>014?4P0?3A003P`?00d;3P02
00`:3@0900d;3P0@3Q403`d@014?4P0G5AP03`l?00X:2P0?3`l04A4A00803@d=0P0>3Ph0200=3@d0
410@00l?3`0;2`/03`l=00P81`0=3@/03`l=0P0A4@l05P0>3P`03@d;00l?3@0;2`T04Q8@00l?3@0=
3@d04A4A01<C4`0<30`04A4A01<C4`0G5aL02`/;010@400C4a<030`<018B4P0?3`l04A4A018B4P0A
4A42010@400H00820P0E5AD0410@00@4100N7Qh03PlB00l?5P0?3Q<03@d?01<C4@0M7QT03a0;00D7
0`0>40T0:bdX010C400F6AL03Pl=00T81P0D4a406aXH014@3P0B4@l03`h<1@0@3`d03@0A4Pd0414<
010@3P0@40h03`l=00l?3`0B4Q80410@010@4P0C4aD051@F010@4`0A4A<00P0A4A42018B4P07018D
4`0=3`h051HE03Hj>@0>4Q404QHE00lD4P02010B3`0<014C400B51404aDB01@F4`0F61D02``:01PJ
5`0B51806adJ014C400A4@l051@B0P0A4@l02P0F5Q@05ADC02TY9`0d=3804a<A01hN700@40h06ATG
01PJ5`0J71T201DG500F01HH5@0A4a005ALD01DG500C5A8071hK02@V8`0F61D0418@01/M6`0E5aD0
6A/J01TL6`0E6AL06alN01TO700H7Q/06AlM01`S800M9R<0728P01dS8`807R@T0P0L92H05P0L9BL0
82X/01/U9`0P:bd08bh`02<^;`0[=cD08bl^024];00Q;Bd08bl`02Ha=00a?400;3Ll03Q3B@0/=ch0
6bH]028/=00O9bd09Bhc02</<@0S;C8202Ha=@1602Db>00V=CX08S4f02Pg?00Q<cL08C@i024e?00W
>d80:Ce2024f>@0P<cL093Lk02`o@`0]@4H0:C]40394C`0`@Tl0:CY803=4C`0iBEH0<T9>02Lh@`0[
?4H0;Sm902XkA00/?DH0;Ci702Tj@@0Y>T<0<3m9041>F@1@GVL0>dUA02<b>@0X=C/0<Si302dh?00Q
;2h092l`02H`<@0U;bh092l`06QfN02d`<40BUQK03=0A@0f@dT0@TmF04QEG@0O;3@09S<k02@a>P0[
>44082le02<b=`0[>Sl0:CPk024`<`0Q;c8082h_02<a<P0S;S009c<c024];@0R;2`072DT01XS800I
8R406b<V01dU:0<07RD[0P0P:2X09`0P:BP07bLW01PO<@0G7C<07bHi02@Z>@0M8bh06R4X01PM800K
82<05a/N01PL7`0M82@06AhR01PM800W;c407bLY01DJ7@0H7B005Q/N01DI700J7B00414E04U:CP0Q
8RH0824U01TJ700J6ad07AhP01TJ700E5QT06Q/O01PI7P0Q8RL0?Sm401LG7`0J6R80:BX_01LH7@02
01LH700301PI7@0I6Qh06AXN00805QLK00/05aPL01PI7@0F5a/04aLJ01LK8P0<3aH05QTP030c>01l
OH807QlT01@E6@0201DD6@0D01DE5`0D51H04aDD00lC400F61D03a4>01TK600D51805aLE01DE4`0E
518030/9014@3P0I5A@04A0>01<G4`093PX02a0<010B3`0A4@l200h>300500h=2`0920H04a8@01DD
4P0?3@/00P0A3@`0100E4A0040`;00l;2P0B3Pd4010<2`04014=300A30d04@/=014;3@804P`>0280
4`d?018<3P0G4A<0618D014;3@0?2@/040X<014;3@0C3@l050h@01`F600;1@L05Q0B018<3P070@<0
3`T;01HA4P0:1@H03PP:00h:2P0;2PP03`T901482@0@1`P04@L801hD5@0<0P<03`H701@>3P0B3Pd0
3@T800l61`0<0P<050X;0P0?1@H00`0B20T03`D600l51P0400l51P060147200S6AX05@/<00l51P0G
3@h04PP90`0@1PL201882@030147200>10D03P@500@03P@51P0?1@H01P0B1PX040@801L;3`0G2`l0
3P8600l31`8040@800@040H801862P0h;3005@/=5?ooool001_ooooo00D02`/9010@3P0>3P`03`l=
018B400300l?3@0V01<C4@0B4Q003Ph<010@3P0<30X03`l=014A3`0B4Q00410>00d=2`0:2PP030`;
01dM6`0@40h04a<A00h>300=3@/04A4?01<C4@0A4@l02PX800H6100=3@/02`/900X:200F5Q@02@T7
018B400>3Ph01`L700T92@0?3`l04A4A01<C4`0@41003`l?00h>3P0?3`l2010@40803@d;00/03Ph<
00l?3@0?3`d03`l=010@3P0>3P`03@d;00h>300A4@l04a<A01@D4P0201LF50030000000D51804A4?
00803Ph<02T03Pl<00d?300>3P`03@h900h?2@031000414>01LG5`0B4Q@0A4A6018B50051@D051@B
00L80`0=3PP02PX600h>300C4a404A4?00/;2@0<30X03@d;014A3`0<30X03`l=018B40092@L02`/9
00P81P0>3P`04Q8@00d=2`0820H030`:00h>300@40h04A4?010@3P0>3P`03`l=00h>300200d=2`08
00h>300@40h030`:00l?3@0E5A<05QHD018B400;2`T500h>300D00l?3@061P@010@200X:200V9R@0
QHF3028R800B4Q0010@200/;2@0:2PP03Ph<00l?3@092@L03@d;00P81P0L71X0<30^00h>300?3`d2
00h>30803`l=00<030`:00h>300>3P`0100>3P`0100?3P`03@`:00`;2@0=30X200l>300300/:200>
3@/03`h<00803Pd;00P040l=00T:1@0<3@P02P/600/<1`0B4Pd04A0<00d<20<03`/800`040/800l;
20072`L0004000<50P0<3P/051@B02<S8@0@40h040l=00l>300>3@/200h:2@0400l>300A40h04A0>
00l>30803Pd;00H040l=00d<2P0>3@/040l=00l>300=30X200h=2@0<00d<200<2`L030/700d<200>
3@T020L300h=2@0;2PH02PT5014>2P0C3PX040`90P0?2`P0200=30X03Pd;010?3@0820P02PX:00d=
3@092@T03Pd<0P0=30X200h=2`0800d<2P0<2`T030/900h=2`0@3`d03Pd;00`;2@0;2PP200`;2@0?
00d<2P0>3@/03Pd;00l>300>3@/030/900d<2P0@3`d03@`:00d;300F51D09B<T01lM7P0E4a@04Q0A
00D03P`=00d03@/<01XI5`0F5A<0518C01<A4P0?3@h03P`?00l=400>30l03P`A00l=4P0A3a@0518G
00<040hA00@03`d@00h<3`0<2Pd040hA0P0A3a802P0>30l03@/>00h<3`0=2a003P`A00d;400;2@h0
30X?00l=4P0@3Q<300l=4P04010>4`0B41D03@`A00d<4@8030/@0P0;2Pl02P0920d02PT>00T83@09
20d03PdB01@C600C4AH04@lD00h<4@0=2a0800h<4@803`d@00L040hA00l=400<2Pd02`T<00`:3@0=
2`h040hA00803@/>00/04@lB00l?3`0?3`l061PH01`L700@41002PX:00P820092@T03Ph>01@D5002
01HF5P0<00P81`0A4@l00@4001HF500A4@l00`<100T91`0G5aD07QhL00l?3@0@40h04Q8@0P0<30`0
1@0@41003Ph>01<C4`071`L0410@00805QHF02403Ph>01dM7@0=3@d030`<00l?3`0>3Ph02`/;00`<
300@410030`<01PH600?3`l03Ph>00X:2P0C4QH04A0E00H6201UIF@03@h900/<1P0=3@H05AD=00h=
200g=S808b8N00l>2P0C4Q0030/901XI5`0V9B<05aHD01@C4@0@3`d00P0A40h02@0B4@l04a8@018A
3`0B4`h04A8=014A3`0@40h03`l=00l?3`0201DE5@0501@D5P0C4aD04Q8D00h>4@0?3a400P0@4102
014A4@07014C4P0/;Rd08R@S08N;RP0>4Q4061`K01/Q7`04018D4@804aDB02/02`d:01TK600o@Ch0
7R0M01HH5@0@4Pl03`l=01hN700L71X051@B018B400D518030`:00h>300A4@l03`l=01HF500B4Q00
71hK01LI5P0E5a@071hK01hP7@0A4a003a4>01HH5@0B51407AlL02PZ9`0C5A80828O01lQ7@0G6A@0
61dI00dB3@0H7AL07R@P01`R7@0I81T05b0K01TS700L9B007R@S008072DT0P0M9BL0200L9RL09S0b
02Pa=P0L9b/07bX^01/V:P0H9RT072X[0P0M:b`0A00S<C@0:SPk02dj@00^>d80<Sm7055NIP0lBE80
6BH_02Tc?00W<3L0<CY102`g?@0V<CL09c8h02Db>00W=CP09SDh024`<`0W=ST08C<e02<e>@0U>3l0
;3m602`oA00X>cl093Pi024e=`0[?T80;3m502Lj@P0fB5@0=TQF02hoBP0a@TX0<D9<02hoB00/?DL0
;Sm90393C@0dADl0<D9<02hoBP0dADl0>d]H03Y:E013DE`0EVA]03]9D@0V=C`0;S]102Te>P0W<SH0
92la02H`<P0U;c009c4`02<_;P1YMgL0]L?404QFE`0_?Ch09C<e0;K4a`2Q[[@0>4E;020]<`0M:S00
934h0P0U=3T08`0[>Sd0:CLj02<a=00T<S<08B`^028];`0K9bL08R`]01hX:@0P:RX072DT01XS800I
8R406b<V01`T9`0K8RP072<Y01dT:P0P:2/08BT[024Z:@0P:2P07BH_01`T<@0M9S007RD]01XQ9`0J
8R@05a`O01/P800I7Ah06AdP01`O8`0G72007B8U00804QXL02P0724T03Hk?P0P9BP07B4T01DH6`0H
6Ad07AhR01LH700M7R805aPJ01@E5`0J6ad07QlQ01/L7`0J6al06AXO01DF6`0L7B805aLO01hN9P0>
3a@06a`Q01TJ7P0F5a/051DI01<D600B4aL05aPL01PI7@0G61`05QLK01@E6@0B5QT04ADL01@G700>
4AH06ahS00`=4@0T9BT051DI0P0D51H05P0C4aD04Q8B014C4P0E61D030h;03m1?P0Q8b004A4?01LG
5@0@40h04Q4?01HE4`0I61H05A4@010?3@1OH5h07R0M00`>2`0A4a004a<A00l?3@0=30X201<B4009
02LS8P0V8R404Ph=01@@3`0C3`h04Ph=020L6`0M6AP04@d<00D040`;00@040/;00l92`0@2P`04@/=
0P0B30h00`0?2@/04@/=01@>400200l92`0C010:300?2@/05Q0B01H@4P0C3@l02`D701XD5P0@2P`0
4P`>030Z;016@4809R0R01@>40091@D02`X800l92@0A20T040L80147200201D;300:01@;300?2@T0
2@D400h:2P0H3a002P0100h41@0C2@X050X;014720L03`D600P04`T:00l51P0B20T0308300h51@0?
1@H040H700l51P803P@500<03`D601061`0@1PL0100@1PL600l51P0<0104200>0PH06@dA01X>4P0@
10P04`L;00`0100>0PH05`/?0104201JCU808ADI5?ooool001_ooooo00d02`/9010@3P0?3`d0410>
01<C4@0@40h04A4?00h>300?3`d03Ph<00`<2P0B4Q003Ph<00@0410>01T03`l=00`<2P0B4Q004A4?
01DE4`0?3`d02`/900d=2`0A4@l04Q8@010@3P0:2PP01`L500l?3@0<30X0410>014A3`0<30X03@d;
020P800E5AD03@d=014A4@0:2PX0410@00803Ph>00@03@d=00l?3`0@4100410@0P0=3@/0100>3P`0
3`l=00l?3@0?3`d300h>300300l?3@0@40h040l=00803P`:00@05Q@B00l>300;2PP03@d;0P0=3``3
00`@300D00d@2P0@4@/0:b`W07]kN@0?3`l04a<E030`<P0A4A<051@D00`<2P0<3@P051D?00d>2P0>
3P`05ADC01XJ600@40h02`/900l?3@0L71X200h>300:01@D4P071`D0;Bd[030`;P0>3P`03`l=01<C
4@0>3P`03@d;00h>30<0410>0P0?3`d0100>3P`03@d;00d=2`0>3P`2014A3`0400l?3@0<30X02PX8
00/;2@<03Ph<0P0=3@/05`0>3P`04A4?00/;2@0E5A<03`l>03Xj>02MWI/06ATH010@3P092@L0410>
00D50`0D51803@d;00L71@0B4Q002@T700`<2P0H61H020P600h>300<30X02`/9008030`:00<02PX8
00h>300>3P`0100>3P`2014@3P8040l=0P0A40h03@0;2PP03Pd;010?3@0>3@/03`h<010?3@0?40/0
4A8=00/<1`0:2`H03Ph900/:1P0>3@T00`0@30T02@0A30T040`900`@2`0:30X04Q@@00d?2`092@H0
3Pl;00l?300300l>2`8040`:00l03`h;014@3@0@3``03Pd:00d<2@0>3@X04A0=00d<2@0>3@X04A0=
00l>2`0;2PL03Pd9010?2`0?3PX00P0>3@T04`0?3PX03Pd900/:1P0?3PX04Q4=00l>2P0@3@T04Pd9
010<2@0>2PL03`/800l>300=30X04Q4?00l?3`0>3Ph030`<00T92@0?3`h0100>3@/200l>30<03Pd;
00<03@`:00`;2@0<2`T00P0<2`T200d<2P0500h=2`0@3`d051<A018A3`0?3P`00P0C4Q002@0=2``0
30X;00d;300@3Pl03`h>03Dc=00<2P/03@/<00l=3P02010>3`0>00l=3P0@3`d03Pd;01<A4@0E4a<0
40h>00l=3`0A3a8040hA00l=4@0>31403`dB018@5@0@3Q4200h<3`0A00l=400>30l02`T<00h<3`0?
3A0040hA00d;3P0<2Pd03P`?00d;400>31403@/@00/93P0<2Pl03`dB014?500=31400P0?3Q<00`0=
2a0040lD00`;400200d<4@<03PdB00H04Q4F01<B5`0@3a@03PdB00d<4@0?3Q<300h<4@803@/@00<0
30X?00h<4@0>31400P0?3A8200h<4@0A014?4P0<2Pd03`d@010>4@0=2`h03`d@00d;3P0>30l04@lB
00d;3P0;2@`03`d@01<C4`0;2`/03Ph>014A4@0?3`l00P0@41003`0=3@d0410@00h>3P0:2PX02`/;
010@3P0>3P`0410>00d=2`0Z:RP0S8b:024Q7`0>3P`0410>00/;2@02014A3`0Y018B4@0J6QT06QXI
010@3`0D51<0<S8a01`L6`0D51<0OWim02/[:P0?3`h04Q8A01DE500F5QD04A4@00d=300@40l051@C
01DE500?3`h030`;010@3`0=3@`03Pd>01HE5@0;2`X0?3di014B3@0;3@L03Pl801LF400A40`05Q8>
014=300K5a@04Q0=00l>300C4Q0040l=00h=2`0C4a400P0>3P`0100?3`d03Ph<00h=2`0@40h201<D
3`03018B400@40h0410>00803`l?00P04A4A01<C5@0C4aD04A4C010?4`0@4180410@014A4@804Q8B
00L04A<B01HH5`0>40l0RHf<0496A@0B5QD0318@00805QPE01/051HC018D4@0A4a00418?01<E4P0J
71T0?Cll020R7`10@Sl07b4N01DF500N7ad06Q/I01@E4`0C51804a@A01XK6@0B4a004a@B010A3`0G
61H051HC01PJ5`0G6aL05QXF01/O6`0M8Ad00P0C5a<08@0I71T061/H01lR7`0U:2D05aXG01hR700D
618071lJ03Hk=@12B48082HP01hU7P0L91d06b@L01XT700J9Ad06bDO01dV9@0M9RH07BHX01hW:@0P
:R/082/^024/;`0Q;34082`a01TV:`0Q;S<07B``02<`>00U<cX08Blf028`>00202Hd?00V02dj@`0^
?4H09S<m02Hd?P0/>DD0:CI002<_=`0a?D<0<3a202Xf?00R;cD07BX`02Xh>`0U=3L07Rd`02@c=P0R
<c@09cLj02Hg?P0[>d80:Sa002i1A00^@D<09STl02@g>`0U>3l09SQ302i0C@0^@4l0;T1:02`m@`0V
=cl09CHn02Pi@00X>D80:ca603A5C`0gAe@303=3D@0Z02lnB`0]>dH0:cU202lmA@0eA4/0;ca202@`
=@0V<CD09S4c02D_<@0U;c00:38a02Tf=@1BHF00?Te;02Xi>00I:2P09C@d03A3A@0eA4H07B`_02Le
>P0R<3@08Blc02/i?@0U=3P09C<f02Le=`0U<cD09C8c01/W:00R;Bh0:3<c038l?00W<C406R<S01XS
800I8Ql06b@S01lW:P0Q:B`082L]0P0R:Bl0:@0Q:B`082PZ01lX9`0O:2H08B/^020Z;P0M9RT072@U
01`U9P0N9bH07B<S01/P8@0T:2T092P[01TM800I7R807B8U01TQ8`0R:R`051TL020U:00C61/061`O
01PK7P0_<3@09BHZ01dN8P0F5a/07AhP01DF600F5aT05aPJ01DF6@0F5a/07QlT01HG700O82D07QhV
018B6P0P8BH05QLL00<061TM00l06AXN01PI7@0B4aL05QLK01PI7@0F5a/05aPL01LK7P0C5a`06ahS
01<F6`0?4aL051DI01HG6`0E5QT00P0E5AL08@0D51D04a<C014C4P0?4`l092HS09BFT`1HFUL03Ph<
01@D4P0C4a405QDC01TH5P0B4@l05Q8A01hM6`1GF5H06Q`I00`>2`0@4@h04A0>00h>300D4a403``;
00d;2@0G4a806ADD01DA400C3`h02`L601DA400^:RT09B4P010<2`02014=308040`;00@03`/:010;
300A2`d040X<0`0A2`d08@0@2P`04@/=018<3P0D3Q00618D01H@4P0A2`d03`T;010:300N61X02`D7
01<=3`0@2P`030H8010:300?2@/02@<5018<3P0@30`03@`:014;2`0C2P/04PT:01<92P0>1PH03P@5
01482@0:10@02PH507YfM@0g;Rl07Q@E01882@0200l51P030147200@1PL040H700@040H700`03P@5
00l51P0?1@H05@/<00d3100A1`P03@<400l51P0@1PL03`D601061`0E2``601061`H03`D600`040@8
01452@0A1@T04@D90104200?0`L04@D90104200900406PhB01<82`0@1PPDooooo`006oooool0300<
30X0410>00l?3@0@40h04a<A010@3P0A4@l02@T700h>300D51804a<A00l?3@80410>0P0>3P`02@0?
3`d0410>018B400B4Q0061PF00/;2@0=3@/04Q8@00d=2`0200`<2P0?00d=2`0>3P`03Ph<00/;2@0:
2PP051@B00/;2@0C4a4030`:01LG5`0?3`l01PH6010@400:2PX04a<C00<030`<00<03@d=00h>3P0?
3`l00P0=3@/00`0>3P`03`l=00l?3@0200l?3@0<01@D4P0G5aD05QHD014A3`0D4A004`d=00l;2P09
1@@06aLF00X91`0A4@l03@l<0`0;40`0400:40`03A0;018C3@0?40/0J6QV014A4@0G5aT061PJ01lO
8@0A4A404Q8@00X;1P061`404a<?00/;2@071`D200/;2@0700d=2`0;2`T04Q8@00D50`092@L05QHD
00T91`0201<C4@04014A3`0?3`d030`:00l?3@8030`:0P0=3@/01@0>3P`03`l=00X:200<30X03`l=
0080410>00P03Ph<00X:200<30X03`l=014A3`0@40h03`l=00h>30<03@d;00/03Ph<014A3`0E5A<0
1PH401DE4`0@40h02PX8010@3P0C4a40000001@D4P0200/;2@0:014A3`0@40h01PH400h>300A4@l0
2`/900h>300C4a403`l=00h>30803`l=00<03@d;00`<2P0<30X0100<30X0100<2`T03`h<00l>300>
3@/200d<2P0=00h=2`0@3`d040l=00h=2`0<2`T03@`:00T:1@0<3@P02P/600/<1`0B4Pd04A0<00l>
2P03014=2P09018=2P0A3@X03Q8<00h@2`0<3PT0418=01PI500>3`X03@h900<03`h:00<04@d:018>
2`0=30P00P0?3PX05P0<2`L02`X600`;1`0@3`/02PT500/:1P0@3`/03@`800P70`0>3@T04Q4=014@
300>3@T03`h:014@300<2`L04A0<00h=2@0B4@d040l;00h;1`0A30P200h:1`0<010<2@0@3`d03`h<
01<B400=3@d02@T900d=3@0E5AD071`K014@3P0?3P`03Pd;0P0<2`T2010?3@0400`;2@081`D02PT7
00h=2`804Q4?0P0A40h200l>300600`;2@0A40h04a8@00`;2@0=30X02`X80P0?3@h01`0<2P/03`d>
00`:2`1?CDh02PP900/92P0>30d00`0@3Pl02P0@3`d03Pd;010?3@0@3`d030/900l=3P0H5QT05Q@G
018@4`0?3A8200h<4@09014?4P0?3A003P`?010>4@0?3A002`T<00`:3@0=2`h03P`?008030X=01/0
3P`?00`;400=314030/@00X93P0;2Pl03PdB014@5@0<2a0040lD014@5@0?3Q<051<H01<B5`0B4AH0
3`hC00d<4@0;2Pl02PT>00/:3`0>3A803`hC00d<4@0<2a003@`A00d;400?3A800P0A3a@0100@3Q<0
3P`A00d;400>314200l=4P0U00h<4@0=2a004Q0C00X82`0=2`h03`d@00h<3`0B41<030X=00l=400C
4A@040hA00h<3`0A3a804A4A00/;2`0=3@d030`<00X:2P0<30`03@d=00/;2`0B4Q8051@D014A4@0D
51@04A4?018B40071`D051@B00@40P0b<S0061PF02PX9P0`<2h051@B00d=2`02014A3`0l02PX9P0W
9bD04A4?01/K6@1NGU`0<c<a018B400[:bT05ADC01TI5`0<30X04a<A018B400:2PP01PH400/;2@0@
40h04a<A00H6100B4Q002PX8018B400G5Q@01`H201dL600:2`P06Q`G00`>2@0@4P`05aPB00L60P0?
2`P06aHC02HN700I5Q<051@B01TI5`0?3`d04Q8@01HF500<30X03Ph<014A3`0<30X02`/9014A3`0D
5A004a@?018B400A4@l0410>00l?3`0A4A404a<C01HF600D51H04A4C00l>4P0B4Q@04Q8B0P0C4a<0
900D51@04aDD01/M70082PT0<CDd00`@3`0F6QT03aDC00lA3P0@4Pl04Q@A01@F4`0E5a@05aTF010B
3`0H6QL03a4>018D4@0R92406A/H01dO700F61D03Q0=018D4@0H6QL04Q@A00`>2`0L7Q/0418?02<U
8P0>40d06A/H00hC3`0I7QX061dI01<H508051TE00<04QLC01@I5@0F6aL00P0I7QX01P0D6AD03a@>
01lT7P0Y;RP0Ada606Q^I`806B0I02406B<K01/U7@0M9al07BLO01`W8@0L9RL06bDW01`V:00N:B/0
8B``028]<@0S<3<0;S]103i;D@0U<cT08c8g01DT:`0U=3l0:cU602<d?P0T<cl0:3I102@e?`0Z>T@0
;ce802XkA@0Y>4D0;C]802hlA`0X=cl0:CHn02@a=`0U<SP00P0Z=cd0@@0Z>C`08c8e01XY;00Q<C80
8c<c02Ti>@0/>d00:cXo02Lf>P0/?T00;Cm102i0@`0]@4H0:ci50312CP0_@Dl0;d1@03A5D00a@dL0
;3i202Tk@00/?D@0;d1802m0B@0dADl0=DED02loCP0`@4l0<41@02hmB`0c@D`0:CM002Tg?`0U=3/0
7R/a02di?P0/=c/092la024/;@0V<3409S0_02Ld<P0L;2T0=DE202Hf=00^?Sd07Bd/01l_;`0Q<C40
9CDe02Dd=`0K:Rd0:STl02`j?@0S<C@082ha02Le=P0V=3D08bh`02@`<00U<C408bd^02/e=00T;Rd0
7BHU008082TV00X082TX028Z;@0R:Rd07bH/020W;@0O9R`07RHY01lW:@0P:BP08b`Y0P0K9R805`0F
8Ad05AhK01TR7`0N9b@08bTY01/P800^<S<0;30c01HJ7@0K82<092T/01<K7@0R:R`04QLJ01hS9P0J
7b807B4T01PJ7P0?41@0;Bhb01HG6`0H6Ad05aPJ00805AHH00X051DG01PI700V9b/0414F01hO900C
51T06a/S01PH800B4aP05QLL0P0H6Ad0100G61`04a@H00l@500E5QX201TJ7P8051DI02X04aLJ01DI
7@0F6Ah06ahS00hB5@0E5QX051DI01PI6`0G5aT05aLG01HF5P0D51@04aDD01LJ5`0<3P/071hK01LI
5P0A4@l0410>014A3`0@3`d04A0>01XI5`0E4A002@P601@E4`0:30T04Q@A018B400B4@l05aHD04A3
@@0V8R405a<B00h:2@0?2`X0510?014=300C3`h0510?00T5100:1PD3014=3004010<2`0?2`X03`/:
014<30804@/=00<040X<00l92`0?2@/00P0?2@/04`0>20X04P`>01TC5@0C3@l03`T;00L10`0L5QP0
Dde?01`F600=1`T030H8014;3@0F41803@P900T31@0=1`T030P800h=2`0B30`00P0D2``03@0D2P/0
308300l51P0=10D0618B00X61@0E4A406Q4B00X00@0>10D03`D600`20`0A1`P01P0@1PL01@080000
5@/<00l51P0?1@H04PP900803P@500D040H700l51P0;0@802P0100l51P0600h41@H03`D600D05`/?
01X>4P0=0@D02`0301452@0200`010050106200C1`/02`0301<92`0800005?ooool001_ooooo00@0
4a<A018B400A4@l04A4?0P0@40h03`0C4a403`l=00P81P0;2`T04A4?00/;2@0<30X03`l=00h>300<
30X04a<A01hN700/;2X03Ph<018B4002014A3`0800l?3@0@40h02@T700L71@0H61H04A4?01LG5@0?
3`d200d=2`0R00h>300?3`d03`l=00d=3@071`L05ADE01@D500000006ATI014A4@0:2PX02`/;00X:
2P0820P02PX:00/;2@0K6aT09RHT01LG5@0A4@l03Ph<010@3P0J6QP0:2PV01TI5`0;2`T04Pl>01D?
3`0E4A003`/:01DA400920H03Ph<00d?30<02a0<01@02Q0<00`?2P0A4P`05AHA01DE4`0?3`l02`/=
00X:30071`T02PX:018B400>3`X03Pl9010@300=3@/0410>018B400A4@l03`l=00h>30D03@d;0100
3`l=010@3P0@40h03@d;00`<2P0;2`T03Ph<00T91`0?3`d03@d;00l?3@0:2PP02`/900`<2P0K6aT0
71`J0P0>3P`0200=3@/030`:00d=2`0;2`T02PX800d=2`0?3`d0410>0P0A4@l3010@3P0600l?3@0>
3P`030`:00`<2P0;2`T09RHT0P0<30X07`0A4@l030`:00d=2`0;2`T03`l=00d=2`0:2PP0410>01XJ
60071`D04Q8@00`<2P0];B/061PF00h>30071`D04Q8@00T91`000000410?018B400G5Q@020L500X9
1`0E51803@`:01HE4`0B4@l040l=00d<2P0<2`T00P0=30X01`0720<03a0;00L80`0>3`X02`/600l>
2P0;2PH00P0=2@H0600?2`P040/800d91P0=4@X00`H001/N5`072P<04A8<01DF400=3PP02@P301LF
4@0?3PT03P/600l<1`16AD0051<>018A300;2PL02PT4014@2`0=30L030/600/:1@8030/600<03@`7
010?2`0?3PX00P0>3@T200`;1`0700d<200>3@T04A0<00d<200<2`L03``800l:1P0300h:1`0/00`;
2@0F5A<00@0001DE5@0820P0410@04E5A@20P7l05QDC00d<2P0@3`d02PT700T81P0<2`T02PT700d<
2P0?3P`03@`:00X91`0<2`T01`H401@C4@0@3`d02`X800`;2@0=30X03Pd;014@3P0>3@/04A0>00l>
300A3a003`d>00d;300>30d03`d>00h<3@071@H03@/<018@4@0<2P/02@L800d;300H5aD200/:1P0?
018A3`0=30X03Pd;00X82@0@3Pl04Q0C00h<3`0?3A003@/>00X82`0=2`h04@lB010>4@0>30l03@/>
00<03`d@01D03P`?00d;3P0=2`h05QDJ00/:3`0a<3D05A@I00D52@0M72402@P=01PG70061@X06aXO
00l>4`0100D02`X?01PG700>3A804a8G01@C60040`P00P0?3Q<0200@3a@04Q4F018A5P0?3Q<03`dB
00`:3`091``05A<H0P0?3A807P0>31402`T>00X83@0=2a005aDJ01lM8P0;2@`03@/>00`:3@0:20/0
30X=00d;3P0?3A002`T<00d;3P0B41<00@0200l=400A4A404a<C00h>3P0820P030`<014A4@0<30`0
2`/;00d=3@0A4A403@d=00X:2P803@d;01003Ph<010@3P0A4@l04Q8@010@3P20P7h0Ng]i01dM6`0I
6AL01`L5010@3P0J6QP01`L501LG5@0S8b4051@B200?3`d01P0@40h04A4?014A3`0C4a405QHD01@D
4P803Ph<01D03@d;00`<2@0?3PX040l;00d>2@0:30L02`d800hC3P0@4Pd05ADC010=300=1`L0610>
01HC4@0820H01`L500T91`0S8b40000001DE4`0B4Q000P0@40h0200B4Q004A4?00/<1`0C50l051@B
00l?3@0A4@l0410@0P0=3@d01@0@41803`lA00h>400L71l071`N00802PX:00l0820P01LG5`0F61L0
6A/J01@F5@0C5aH0310?00hB4@0D6QP05ALD018D4@0>40d0418?018D4@0@4Pl00P0B51401@0A4a00
3a4>01DG500I6aP071hK0080418?00l05ALD01LI5P0I6aP04aDB018D4@0C5A805QPE01TK600H6QL0
4AHB01TO6`0C6AD01P`801TO6`0E6aL00P0G7AT0G@0H7QX06R0L01TO6`0F71P05Q/E01LL5P0R9b40
7RDN028Y8P0L8a`05b4I01TS6`0M:2006B@L01LR6P0S;RP072PZ01`W:`0O:Rh07RT]024/<P0R;cD0
:cTo05i]M03Ij>l0;Si501`]=00T=Cd0834m02LgAP0Y>dL0:ca902`lB@0/?TX0:ca802Hf@`0S=D40
:S]702@d@@0Y>T@07c0g02Xi@00_?TD093<j0391AP0kBTl0:STl02@d=00X>3P07Bd]02Lg=`0Q<C40
9c@j03=0AP0a@4<0EFAW04EDE`0eAdX0<D9902e0A`0Z?4P0=4EE03M:F`0`@Td0;T1402Li?@0W>Ch0
;Sm60393B`0a@T/0<D9<03A4D`0a@E00;3a;02/kB`0c@U00<3i902Hd?@0O;SH093<j02/h?P0^>Sl0
9c8f024/;P0O:R/08bd^02H`;`0U<S00:SXg02Hf<`0V=S@09SHe01h^;@0202Ti>@0502<c<`0U=3L0
8S4d02Th>`0U<c@00P0V=3D01@0X<cD09S4c01/W9`0Q:b`082X[00<08BXY02407RLT01/T8@0L9B80
72DT01/S9P0]=CP0;SDk01DL8P0Z<CL09Rha01@L7P0M9RD072DQ01/V800J9Ad07BPQ01/T7`0F7aX0
6R<P01PN7P0M8R<082@U01lS900M8B806b4Q01XO8P0G7b405QhP01PM800F6ah04QLJ01PL7`0I71l0
100J6al03P0J6ad05AHH01<D5P0F5aT06Q/N01TJ7P0D5AX07b0U01DF6`0G5al06QXR014B5`0E5Q/0
61TM0P0E5QX00`0H6Ad05AHJ01LH700201<D600801PI7@0F5a/04ADH01HJ7@0G6ah051PK014E600E
5QP201TJ700D01HF5P0A4A404A4@01<C4@0B514041@@00d?300>40d04aDB018B400>3P`04Q8@01@C
4@0C4Q004A0>01<?3P0B4@l04Q8@014A3`0?3`d200h=2`0:00l>300F4Q40510?01<?3P0B30`040X:
01<>3P0D40l04@d<010<2`803PX900l04Ph=01<?3P0E4A0061@C00h:2@0=2@P050l?00`6200B30h0
50h@00/51`0A2`d04`d?00@0000A2`d00P0E3a400`0=1`T05@lA014;3@02010:3004014;3@0C3@l0
FUAF00@000805Q0B01<040X<00P2100=2@T04A0>00l92@0=10D04@P90147200?1@H04`T:0107200<
1PH03`/:00d920070000200001061`0>10D05@/<00804`T:00X04PP90147200?1@H03`D600h41@0D
2P/0308300h41@0A1`P02`421`0?1@H03`0900004`T:01882@0E2``03@@400P0000<0P<05@/<00P0
000;0@803PD500h41@0K3a<06PhB01@8300200l31`0301<72`0A1@T04@D900@04@D95?ooool001_o
oooo0P0@40h400l?3@0L00/;2@0=3@/02`/900`<2P0A4@l03Ph<018B400D51804A4?00d=2`0?3`d0
51@B01DE4`0<30X0410>00l?3@0C4a402PX800d=2`0D51805aLE02@T8P0A4@l03`l=014A3`0?3`d0
3Ph<00d=2`803Ph<0P0B4Q801`0?3`l02@T901LG5`16ATH05QHF00d=3@0>3Ph00P0=3@d01@0@4100
3@d;01<C4@0H61H03Ph<0080410>00`03Ph<010@3P0C4a403Ph<00T91`0C4A000`4001XH5P0@3P`0
40l=018A3`0>3P`200lA3P0B00d@3@0;3P/02Ph:00h@2`0?40X030d800`=2P0>3Ph03Ph@00l?4@0N
7R008R8R014A3`0@4@`04A8<00`<200=3@/03`l=0P0@40h200h>30D03`l=0P0@40h200l?3@803Ph<
01803`l=01HF500<30X030`:00X:200@40h03Ph<00`<2P0C4a404Q8@00X:200@40h02PX800`<2P0=
3@/02`/900X:200<30X200d=2`803`l=00<03Ph<00d=2`0>3P`00P0>3P`300d=2`05020P7P0A4@l0
4A4?00h>300@40h00P0=3@/05`0@40h03@d;00/;2@0?3`d05aLE014A3`0@40h010@201PH5P0<30X0
2PX8018B400:2PP06QXH00T9200>3P`020P601dL6`0B4@l02`X800H50`0B4@l03@`:008040l=02<0
3`h<00h=2`0=30X030/900d>2@0<3@P02@X500/<1`0=3@P03`h:014@300?2`P03PX700l;200B3@X0
4@d:00/?20082`@03a8;01@G401<CDL0H65K02HW8@0F5A004A0;00d<1`0C40/03P/600l>2P0:2@@0
30/6010?2P081`803Pd800d<1`0300`;1P803@`700@040l;00l>2P0>3@T03Pd90P0<2`L01`0=30P0
30/7010?2`0<2`L02`X600h;1`0?2PH00`0>2PL02`0<2`T06APF00d<2P0>3Ph03@d=010@400=3@d0
6a/J00X91`061@<03Pd;008030/90P0>3@/02P0@3`d04Q4?010?3@0>3@/02`X801<B400E518040l=
01@C4@0@3`d200l>300500h=2`0<2`T04Q4?00l>300>30d00P0=2``01@0@3Pl04Q0A018@4@0?3@h0
3P`=00<03@/<018030X:00/:200@3`/02`X601<B3`0510403`h<02/Y:@0S8B404@lA00/92`0@3Q00
3`d@00d;3P0?3A004a4D014?4P0@3Q4400l=40803P`?01H03@/>00X93P0<31003`lD00h>4P0>3Q<0
3PhB01`L800M7B40LW9f03De>@0C4aP04Q8G00l>4`0=31402PT>01<B5`0J6Ah0@T5600h=4P0=3140
3PdB0P0@3a@0800=31401`D:014?500610T04a4F010>4`091``04Q0E010>4`0>31403`dB01@B5`0H
5Q/030X=00l=400@3Q403P`?00d;3P0>30l03`d@00d;3P0K6A`02@P:01PF6@0A3a803Ph>00l?3`0=
3@d02`/;00`<300>3Ph03`l?0P0=3@d00`0A4A404Q8B018B4P0300h>300?010@3P0A4@l04Q8@018B
400F5Q@04A4?05]KF@0820H05QHD00l@300F5Q<01PH300h>2`0D51403@h:00H0414=00<0410=010A
3@0@4@d00P0@40d06`0A4Ph05ADB01<D400?3``04A4>014B3P0A3PX04`l;01@@3@0?40`02a0=00`A
3P0<4a802a8A010D4`0D51D05Q@D01HB4P0F51<05AHD00`=2`0F5a@03@h;00`=2P0F5a@051DB014B
4002018C4@0400l@3P0E5Q406Q/F01TI5`804a<A0P0B4Q804P0A4A4051@F01<C5@0?3a404a8F01TI
6`0B4Q804a<C01DE5@0A4A404Q@C01@F5@0C5A@041@C00hB4@0C5aH0728P01@F4`804Q@A01`05QPE
01PJ5`0I6aP03a4>01@F4`0E5a@04Q@A01DG500C5A803Q4>01@H500I7AT051PD00lC3`0F6QH05QTF
01@H500E6AD05QTF01@H500?510061hJ01@J5P0E6aL04QPD01@J5P0J81`051XF0`0F71P0QP0I7a/0
728N024W8`0H7QX06b0K01PN6`0O9b806R@M01XS7`0F8A/06bHO01dY900N:R<08BdZ028]<@0Y=CX0
9c<h02Db=P0K:C008S4g0391B00gAdh0=DI=02Hh@00G:C80:C]5028d@P0W>DP0:C]:02PkB@0W>DH0
9cY702TlB00U>4808cI002TlAP0S=T009cY302@f?P0[?DD0<TA;02Pi@00Y>Ch09cLl02hm@00Q<C40
7Bd]024`<00T<c<09C<c02Hc=`0^>Sh0:cPk03e;C@0_?T40:SXo02Pi@@0[?DL0:3Y70312D@0hBe`0
<dEA02`n@`0U=Sh093Dl02Tj@@0]?TL0;Sm902dnB00[>dP0:3Q602TiA`0^?T`0<D1=02/iA00W=Ch0
9SDm02Th?`0[>3h0:cLl02Lb=P0S;S008bd_02La<P0X<S40934_02@e<`0R=3408cDc024b<P0T=CD0
:c`m02Tj>`0S=3H093@h02Df>@0Y>C`0;C/l02Xf>00T<3808Rd^024/;@0N:BX07bPX01lX9`0N9bH0
82LV01lW9@0N9R<07bPU01hW900U;Rd08BT/02D]<00S:S008BP^02/b>00[<cH08RX/02</:`0N9b<0
7BPP01XV700L9al072DP01PQ7@0N9bD06AlP01dR8`0M8B806alO01XN7P0J81l061hO0P0F7R0201XO
8P0301LL7`0G6ah06Q`P008071dQ01006a`P01TJ7P0H6A/051DG01<D5P0E5QP061TL01PI7@0Q8RL0
EUML01LH7@0I6B4061PP01@E6P0E5Q/061TM0P0E5QX0300H6Ad05AHJ01DF6P0F5a/05AHJ01HG6`0E
5QX04aLJ01@H6`0C5aX04QHI014E5`804a@F01804aDE018B4P0D51<061PF01<C4@0=3``03a8?01<E
4P0A4a003a4>014A3`0C4a40410>01<B400B4@l040l=018>3@0A40h201<C4@0@014A3`0?3P`04@h=
018@3P0C3`h05A0?01HA400I4a<06Q<C01@?3P0A3@`04Ph=010<2`0C3`h040`;00d9208040`;00l0
4Ph=01<?3P0C3`h04`h>00d72@0A2`d04P`>01<=3`0E3a4040X<01<=3`0A2`d040X<00T31@0L5QP0
0`0?2@/06`0@2P`04@/=014;3@0E3a406aDG00X51P0B30h02`D700d72@0@30`020L600X4100@1`P0
3`H70147200?1`L03`D601D<3@080P804Ph=07EaL00i<3405P`=00h51@0A1`P02P0100h41@030147
20<040H700H03P@501061`0A1`P03P@500d3100>10D600l51P804`T:010030830147200=0`@05`d>
01882@0D2``060h?0147200?1PL03@<400l31`0A1@T03`<700d11@0>0PH04@D91P0@10PDooooo`00
6oooool05P0:2PP030`:00h>300?3`d04Q8@01<C4@092@L02`/900`<2P0B4Q005QHD00d=2`092@L0
3@d;00l?3@0>3P`03`l=018B400?3`d02`/901@D4P0<30X2014A3`07010@3P092@L00000014A3`0@
40h05ADC00l?3@0200h>30803`l=00d0410>00d=3@0C4a<05ADE01<C4`061PH05aLG00l?3`0;2`/0
3Ph>00d=3@092@T02PX:00803@d;01003Ph<00L71@0@40h03`l=014A3`0@40h02`/9014A3`0C4a40
3@d;01TI5`0?3P`03Pd;00X:200I6AL0410>0P0?3`d04P0>3``030h;00d=2`0=3PT030d700`=200C
4a405QHF010@4P0;2`d05aLI01XJ6P0<30X03Pl:010A2`0;30P02`/900d=2`803Ph<1`0=3@/200h>
300400l?3@0@40h0410>014A3`803@d;00/08R8P03lo?@0820H04A4?00l?3@0=3@/03Ph<00d=2`09
2@L0410>00/;2@0200l?3@0300/;2@0<30X02`/900803`l=0`0@40h00`0?3`d030`:00d=2`0300d=
2`0600h>300;2`T030`:00l?3@071`D05ADC0P0?3`d0100@40h03@d;00/;2@0=3@/2014A3`0Z00h>
300<30X04Q8@00l?3@0B4Q0030`:00d=300F5Q@00P8001HF500Y:BL0TY6?01PG5@0M71X06aXH00/:
200C4Q003Pd;00l>300@3`d03`h<00d<2P0;2PP04a@?00d>2@0E5Q402``7014A3@0?3PX03@`800l;
200@30T04@d:01@?300E4@h0310901@G40062@80;c8[0<[;a@3oooX0Kg1Z0P0E50l02P0?3PT01P<0
01<@2`0@3`/05A@?00T80`0>3@P02PT4018A300>3@P300`;1P0400d<1`0>3@P03`h:00l>2P803Pd9
0P0=30P00`0;2PH02PT500h=2@0200/:1P0300l<200@2`L03`/800803`/801P03@`:00L61@0=30X0
3Ph>00`<300>3Ph0:b/[01HE500>3@/030/9014@3P0>3@/030/900h=2`0?3P`04A0>018A3`0A40h0
3`h<00d<2P0H5aD030/900h=2`0=30X200/:20<030/900L03Pd;00l>300=2``030X;00d;300@3Pl0
4@l@008040h?00D03`d>00d;300=2``03P`=010>3P02018A3@0300L60P0P7a/02@P400805A@B00/0
4a8@00d;300?3@h05A<D018@4`0;2@`03@/>00l=400=2`h030X=00d;3P0500h<3`0F00h=3`0F5AX0
3PlC00d>4P0720`07QlS00`=4@0D5AT0FU]O0?3am@2EUYX06Q/O02<T:00;2Pl05A@I00T83@0F5AX0
3PdB00401@0=314030/@00d<4@803`hC00T03@`A01PF6`0:20d020H;01@B5`0:20d04a4F00l=4P0>
31400P0<2Pl200h<4@803P`?00<030X=00/9300>30l00P0@3Q40300=2`h07Q`O00l=40030@@02PP;
00d=3@0<30`03@d=00l?3`0=3@d030`<00l?3`803Ph>0`0@410300h>300600l?3@0@40h04A4?00d=
300>3P`02@T70P0?3`d01`0;2`T030d8014B3@0<3@P0414<01<D3`0@4@`01P0A4Pd2010A30<03a0;
03003@h900l@2`0?40/03@h9014B3@0B4`h04Pl;01H>2`0D3``03`l>00/A4@0<5A@04QdN014L7P0>
61X051XM00P<3@0:2`d061TG01DG500A4a0020X700lA3P0I6aP06Q`I01DG500=3``030h;00d?300?
4@h03Pl:010A300A4@l0410>014A3`0A4A404a<C00l?3`0B4Q@05QHH01<C5@0B4AD0000201LG5`0H
61P02@T901lO7`0P8R4202la<00401/O7P0A5A@0310?00hD4P803a4>00D04A<@01<E4P0E5a@05aTF
01PJ5`02028T8@0601/M6P0G6AH03a4>01@I5@0C61@05AXF0P0D6AD0N`0L8Ad04QLC014F4P0B5a<0
51TE01HK5`0E6QH03A<?014G4`0K8Ad02Q0<01DK5`0I7a/04QPD01XP700L8Qh06AlK01`R7P0S:BD0
7B<Q01XP7`0M8b405A/K01/R8@0J8b00628Q01LQ7`0I92006RHT01dY9P0O:b/09C8g03A1A`0I:2d0
9C@i02<b>@0X>D00FV]c051QJ@0^@DP09CM102doB@0G:cH09SU802/nC@0]@4l0;3m=02/nC00[?dX0
:cm902PlA@0V>T<0;41902Di@P0Y?DH093I002<f?@0W>T4093Ln02Tk?`0R=3P08c8e020`<00I:BP0
9C<c01/Z9`0T<300:38e02/d>@0Y=3L0:C@f01h/;`0[>Sl09cQ002XlAP0]?dh0>4]L04EGJ`0jCE/0
:ca402Df@00Q<S/08c@n02Hg@@0Z>dD0;3e702hoB@0^?TX0:S]502LgA00X=d80:SQ302dkA00c@DT0
<d99030m@`0X=3T08B``020[;@0R;Bh09Bl`02H`;`0U<c809CPf02Dg=`0R=3@07Bl_02@f=`0P<S@0
7S0d02Dg>`0V>3`0:Sa001h^=00S<C808Rd_02<^<00R;Rh07BTY01/U9P0K92<072DT01`U8P0201dS
8@0L01lU8`0V;b`08BXW02df=@0U;C007bLZ020W;@0R:Bl07bH/020X:P0Q:B/07BHU01XS7`0N:B40
6RDM01/V7`0M9R<06b@S024Y:P0M8RD07R8T01`P8@0I7A`06AhJ01XP700I7al05QhP01LO8@806b0S
00<061dP01HJ7@0I71l00P0L7B40100J6al061TM01LH6P0F5aT201DF600:01LH6`0G61`051DJ01<D
6@0K7240;blg00h>5P0U9R/05AHK01PI7@805AHJ02L061TM01DF6P0C51P061TM01LH700D5AT05AHJ
01HJ7@0B5QT041@G018F6@0H71d06AXL01HG6@0E5aH03`l=010@3P0A4@l0410>010B3`0>4Ph04Q@A
014C400?4@h04A4?01<C4@0@40h051<A01<B400A40h04@d<018>3@0C4a4051<A018A3`0@3`d04`l>
01DA400C3`h00`0D3Ph03P0E30d050h>01HB4@0B3Pd030P701DA400K5aH05A4@01@@3`0C3`h04@d<
01DA400B3Pd040/;0P0@2P`0:00:10H040X<01H@4P0?2@/04@/=01<=3`0D3Q002`D701D?4@080`@0
3@L900l92`0@2P`03`T;00h82P0=1`T07ALI00D00@080`@0618D00T31@0Z9RH08B0N018<300B2@X0
2P4200h41@0Q5aP05`d>01482@04000061@C09VEU012>CX060h?00h61P0E2``0308301D;300?1@H4
01061`060147200;0@805@/<01@:2`0<0P<040H71`0?1@H200d3100<0147200K4A803@<401@:2`0f
;2d0V8j?01H<3@0H3Pl05`d>00l51P0=0@D03`<7100@10P600l31aCooooo000Kooooo`0G00d=2`0>
3P`03`l=010@3P0A4@l04Q8@014A3`0=3@/0410>01/K6@0N7Q`03Ph<00/;2@0@40h04a<A01@D4P0F
5Q@05aLE00X:200@40h01`L500D5100C4a400P0;2`T01@0A4@l030`:01PH5P0>3P`030`:00803@d;
01403Ph<010@3P0B4Q004a<A010@400J6QX04Q8B00/;2`020P804a<C014A4@0B4Q805aLG01DE5@0=
3@d030`<00d=2`0200l?3@0300X:200A4@l030`:00803`l=00X02`/901DE4`0G5aD03`l=05EGE00@
40h04Q<A00H6100D51803Ph<0P0=3@/0400?3P`03`l=010?3@0?40/02``600/<1`0B4Q005ADE010@
4P0;2`d020P:00L71`0<30X030d800`=1`0<3@T200`<2P<03Ph<200=3@/200l?3@07010@3P0A4@l0
410>010@3P0T9280?clm00L71@0200l?3@0600h>300?3`d03`l=00`<2P0?3`d02`/90P0@40h01@0=
3@/04A4?014A3`0>3P`03`l=0080410>0P0?3`d00`0<30X03@d;00d=2`0200d=2`0700h>300:2PP0
3Ph<01<C4@0;2`T06ATG018B400200l?3@0800d=2`0<30X03@d;00l?3@092@L02`/901LG5@0B4Q02
00l?3@0>00D50`0=3@/02@T701/K6@030`804Q8@01hM6`0510<02PT70040000A40h040l=00d<2P0?
3P`2010?3@0N00h=2`0<2`T06AXE00L81@0@4@`0004000d=200C4Ph03`h:01DA3P0F4Pl0510=01D@
3@0F4Pl02`l701LJ4@0C5Pd0=3L^0;Nh/03cm>`0FeaD014A2@0G5`l04A4900P5000E4P/01`L201@D
300@40P04Q8:0P092@401`0>3PH03@d500`<100=3@D03Ph600h=200?3PX00`0>3@T200d<200700/:
1P0920@03@`800/:1P0<2`L040d9010;1`0300l;200400d<2P0A40h04a8@00820P802PX:01D0:2PX
014@3`0A40h040l=014@3P0>3@/030/900d<2P0>3@/03`h<010?3@0?3P`03Pd;014@3P0F5A<00P40
00`;2@061@<05A@B00l>300:2@L00P0>3@/01@0;2PP03`h<00h<3@0=2``03P`=00803`d>0P0<2P/0
3`0?3@h04@l@00d;300=2``05A<C01DD400A40/02`X501PG4`01000051<?008100071P@02`T:00d;
3002014?400600/9300=2`h03P`?00`:3@0;2@`03@/>1@0>30l05P0>3@l03`hC00/<40051PX051DI
07MhO00J6al04A8F02<T:027R8`0BDY>00X;3`0D5AT05aHK010?50030PL020L<01LF6`0H5a`03PdB
00d<4@0>3A82010?500700h=4P0C4AH03@/@01<A5P0G5AX04Q0E00L52P04010>4`804Q0E01T04a4D
010>4@0;2@`02PP;014?4P0E4aH04@lB01HD5`1HEUT09R@W02DS9P0K6A`03`l?00h>3P0?3`l04A4A
00l?3`0=3@d03Ph>00l?3`0>3Ph03@d=00/;2`0:2PX03`l=00803Ph<00d03`l=010@3P0A4@l030`:
01/K6@0G5aD05QHD00L71@0C4a402@X500/<1`0=3PT03a0;0080414<1@0A4Pd00`0@4@`03a0;00l@
2`0400l@2`804A8=01h03a0;01<D3`0E5Q40510<01H<2P0C3P/03`d>00/@4`0;5AL041hP02dl?`0X
=ST03aXL01<K7@0@5AP061/K00840@031@8051HC03<e<P0>40d04Q@A00h@3@0A4a005QPE01@F4`0H
6QL051D@018C3P0C4a4201@D4P0F01DE5@0F5QH04A4A014A4`0C4aD04A4C018B5@0L71h0:b/[00L7
1`0/;2`0Ogmo03Li>00N81l092HU014E500C5aH04ADD01HL6P0?4@h0418?018D4@804A<@0P0B5140
3@0L7Q/07AlL01LI5P0D5Q<030h;01<H500D6AD02Pl;00dB3P1FFeL0];Ve01dR7P0G71P00P0A5Q80
2`0C61@04QLC010F4P0?61<07BHQ00lH4`0b>cH05b0K014J5@0J8ah07BHQ00806R<N06T07bPU01HL
700Q9RP0:Bl_01XR900L92D07bPW01TS900N:BT07BTW01TU9@0L:2L08B`^02/i?`10CeH06bXa02Ph
?`0U=Sh0834i045CFP0nD5X09SQ201`_>@0[?dX0730k02DjB00Z@4h0;D=A02e3D00/@Td0;D=>02Hl
AP0S>T808STo02PoA@0P=cd08cY002Di@P0W>d@0:Si502`oAP0eB4`0;d960312A00W=cL07bl^02Pg
=@0S<Rl0=41002Tb=00]=CP0:cHh02Ha<`0N;2l0=DA902/lA00W>D<0:ce<03M:F`11EVT0>deM0352
C00/?4T09cM302Hg@@0X>D<0;3e702hoB@0`@D/0<D9;02dnAP0Y>T@09cM102Xh@`0_?DH0=DA<03A3
BP0_?4809c<h024/<00P:bd08bh_02H`<@0V<2l09C<c020b<P0R=3H0:cdo02i0@P0H:Rd0;d5502Pi
@00[?4<09SLn02m0A`0M;C<08S0a024];@0S;bl092h_01lY:P0P:RT06R<R01/T8`0N92800P0L8R00
6P0Q9b<08R/X01`U8P0U;Rd07RHY01XR9@0O9R`09B`b01hU:`0M9BP08BT[01hW9P0P:BD07RTQ01XU
7@0K9R407RLV01`T9P0P:2X07R<W01lT9P0M8B806QhM01XO6P0K8Ad06R0P0P0G7b401@0K82<06AhQ
01HK7P0G6ah06A`O00806a`P00<06Q/O01TJ7P0H6A/00P0H6A/02`0G61X061TL01PI7@0B4aP071dR
01/L8@0<31@04a<K014B5`0E5Q/061TM00805AHJ00<061TM01DF6P0D5AT00P0H6Ad0200D5AT05QLK
01LK7P0D6AX04ADF018F5`0G6a`061XI0P0E5aH0300D51805aLE018C3P0A4Pd05QPC010D400>40d0
3a4>018D4@0A4@l03`l=014A3`805QDC01H04a8@01<?3P0C3`h04a8@01@C4@0B4@l04Ph=01@@3`0E
4A005@l?01@>3P0C3@d04`X;01482@0>20P0510?01XF5@0G4a8040`;00`81`0;1`H03`/:0P0A3@`0
3@0D40l04Ph=00l:2`0?2@/050h@014;3@0C3@l06A<E01H@4P0=1`T02`D700d72@0A2`d00P0@2P`0
4@0=1`T03`T;00l92`0>20X03@L9024K7@2QVid091hP01@>400G4A<05@lA01XF5P0B4@l02`D50189
2P0<0`@040H70080200000L03`H700T30`060P407a/J024H6@0=0`@030<300803@<400<04@L800l5
1P0@1PL00`0@1PL01`0A1`P03`D601P>3`0E2``03P@501882@0A1`P01P0?1@H0200<0P<03`D601@:
2`0M4a@03P@50147200I3a00OG=d0P0700000`0;0@801`000104200201452@0301862P0A1@T03`<7
00H04@D95?ooool001_ooooo0P0B4Q001@0@40h03`l=00h>300<30X03Ph<008030`:00<04Q8@01DE
4`092@L00P0>3P`04@0?3`d0410>014A3`0A4@l04Q8@00`<2`11@Cl08R8P00<30@0A4@l03@d;01<C
4@092@L05ADC00l?3@0>3P`0410>00803`l=0100410>014A3`0B4Q003`l?00/;2`0<30`0:RXZ01LG
5`092@T03`l?014A4@0G5aL05ADE00d=3@0<30`03@d;0P0A4@l08@0>3P`04a<A00X:200<30X03@d;
00`<2P0A4@l04Q8@00X=2P0o@cl020/8010D400420@03a0>00l?3@0=30X03``;014>3@0B3`h04Q0>
018A3@0=3PP02@X500P91P0=3@d03`lA014A4`0;2`d020P800d=2`0>3`X03@h800h>2P0300h>3080
3`l=00<0410>00l?3@0?3`d00`0?3`d00`0>3P`03@d;00h>300300h>300701<C4@0J6QP03`l=00d=
2`0:2PP03`l=010@3P0300l?3@80410>00@03`l=01DE4`0@40h020P60P0>3P`00`0;2`T030`:00d=
2`0200d=2`0400`<2P0>3P`03Ph<00h>30<03@d;00H03Ph<00d=2`0C4a402`/9014A3`092@L200h>
30803@d;0P0>3P`2010@3P0402LW9@0A4@l03`l=00l?3@803Ph<00/03`l=00D50`1JFUP05ADC00/:
200@3`h04A0>00L61@0?3P`040l=00l>300500h=2`0Q00T:1@0<3@P0=3D`00d>2P0@40`01PD200d<
200B3P/040`900d91P0B3@X05A8=010D30021@005AP?00hA2@0_<2P0A4Dm01`M5@0C4`/04A49010@
200F4``04Pl801DE3@0>3PH01PH100l?200=3@D04A4900l?1`0>3PH03@d500803Ph600<03`l700h=
2@0>3@T0100>3@T01`0=30P02PT500h=2@0=30P03Pd9018?2`0A30P00`0@30T0200>3@/03@`:018A
3`092@T04Q8B00P8200@410030`;0P0>3@/500d<2P<03Pd;02<03@`:00h=2`0F5A<03Pd;01@C4@0B
4@l0=C@b01TH5P0A40h03Pd;00l>300=30X03`h<00l=3P0>30d040h?018@4@0A3a003P`=00/92P0?
3@h04Q0A00h<3@0=2``04Q4@00d<200?3PT04Q4<00H50@0I61D03`h:00d<2P0@3`d03P`<00/92P02
00h<3@0600h<3`0?3A0040hA00h<3`0=2`h03`d@0P0=2`h200h<3`0G00l=400?3Q0051DI00X=400>
4A@02Pd@03Hh?00:3A002@`?00/=400J7200<cHi00lB5@0?41@030/@01<B5`11@4D07A`Q00`<400;
2Pl03PdB00d<4@0>3A800P0@3a@03`0=31403`dB00l=4P0J61d00@0401<A5P0:20d03`dB00h<4@0=
2a003P`A010>4`0A3a@0518E018@4`0200d;3P08018@4`0F51L0?S`o01`J7@0?3A004@lB01HD5`0>
30l2014A4@0>010@400>3Ph03`l?014A4@0@41003`l?00d=3@0<30`03`l?018B4P0@40h03`l=00h>
300?3`d2010@3P0<01@D4P092@L03@d;010@3`0>3P`0410>018C3P0<3@L051D@00l@2`0=3PT04A8=
1@0@4@`0C`0>3`X03@h800d>2@0?40/0414;010A300B4`h05QLA01DF400B4`d05AHA01HG4@0F3``0
5P/;01D<3@0?3Q002a<F00dH7@0X>3h0^lkB0<OGf@0iBDd06BHY01/W:@0?5QD05APE01/O6`0H6aP0
Ngmk04iACP0<3``0310<01HI5P0D5a@02Pd:010C400J6aH051D@01<C4@0D51804Q8@018B4P0G5aL0
5ADE01DE5`0B4Q@03@d?010?4`0@41803`l?01<C4`0F5QH06ATI01PJ6@0O8B00:bd/01<G5P0G6aX0
4ADD014G5@0B51405ALD01HH5@0D5Q<04Q@A01<E4P0@4Pl05ALD01HH5@0D5Q<05aTF01DG500>4`l0
51TE01XO6`0G71P0724M02hc;`0F6aL00P0D6AD0300G7AT06b0L01/Q7@0F7aX03QLB018K5P0H8A`0
>D8m014J5@0I8Qd06b@O01XS7P80624L07806R<P01lT9`0T:Rh0:Blb01`T:00P:2/08R/]01dV:P0T
;c4082//01`W:P0P;2h08Bla02Dc>@0Z>T40;cm602Xk@`0Y>d807c4h01la>P0Z?DL09SU404MKI@0d
B5<0:Ce802HlBP0[@Dl0;D=@02e3C`0/@Td0;DA<02a3BP0Y@4H0:41502i6BP0U?D40:41402XoB00_
A4d0:Sm802Di?`0jCE<0?4mC02Pj>`0K:b/0;3`k0391?P0S<Rh09c<a02H^<@0/=3L0;3Dh02Td=P0P
;S40=dI;02`mA@0W>480:3]902e0D@0cB5d0=dQJ03Y:F00iBEL0<d=A02`lB@0[?4H0;Sm802dnAP0Z
>d<0:ca402i0A@0_@4L0;3a502Xh@`0/>T<0;Se502dl@`0Z=cd0:3@i02Lb=P0U<3809S4b02Tc=00Y
<c809C<d02<e>00Z?3l0>Ta?05e^M010DEL0A5EM03E6C@0`@DT09CHo03Q9DP0U=Cd08c4b024];@0W
<S809c4b01hX:@0P:RT06b@R01dV900P9R@07B<P01hT8@0V;2P08BXW01hW900S;2/07RHY02@/;`0V
;C<201lV;00A01lW:@0N9RP07RLV01dV8`0M:2<06B@O01/U8`0P:2X07BDX01/S9`0K82D07R<V01lS
8P0M8Qh06b0J01`S700I7al00P0F7R001@0J7b806AhQ01HK7P0I7B006Q`P00806AXN0P0K72003P0H
6A/06a`N01XK7@0H6A/05aPK01TJ7P0/;C805aPM01HG700C4a/0:RXb01HG700E5Q/061TM0P0E5QX0
0`0H6Ad05AHJ01LH700401LH700D01DI700F6a/04QHG010D5@0@51@04aDD01DG5P0D5Q@03Ph<01DE
4`0D5A003Pl:010B3@0@51003Q0=00lA3P0B51404Q8@00l?3@0B4Q0201LF500301@C4@0D40l04`l>
00804Q4?00L04A0>018>3@0C3`h05A4@01@>3P0D3@d05@d>00805Pd>014050h>00l;2P0B3Pd04`l>
00`81`0M6AP0:2@S01<?3P0B3Pd04@d<00P40`0<20L06A@D00X41P0;1@L050h@014;3@02018<3P06
044k?@0A2`d04`d?00`6200I4aD04@/=0`0?2@/300h82P0302PS900<1PP03@P9008040X<01805Q8B
00H50`0=1`L05Pd>01892P0>10D0=B//02PN7`0B2P/03PP801@@3`0?2`X03`H700h41@0C2@X03@<4
01882@0@1PL3014720<040H700H060h?01D;300@1PL040H70147200@1PL600l51P0B01H<3@0L4Q<0
4@L80147200@1PL04PP90107200C2`/05`d>01061`0?1@H03PH601<72`0?0`L03@4500l31`0@10P0
3@451P0A1@TDooooo`006oooool0100;2`T030`:00d=2`0=3@/200l?3@0400d=2`0E5A<04A4?00d=
2`<03`l=0P0=3@/04`0?3`d04Q8@014A3`061P@05ADC00h>300=3@/061PF00L71@0?3`d05QHD00X:
200F5Q@04A4?00l?3@0D51804Q8@010@3P0?3`d00P0=3@/0200?3`l03Ph>00L71`0U9BD071`L014A
4@0?3`l02`/;0P0?3`l02@0<30`03@d;00h>300@40h03Ph<00d=2`0D51802@T701HF5002018B4009
010@3P0A4@l05APE0002000?51004QHB00L91P0:30T03@d;00803`h<00L040h<014=300A3@`03`d:
00h?2@0@4@`0410=00803@d=00T030`<01HF5P0F5QH02@T6018C3P0E5Q003`l<00l?3@0>3P`00P0?
3`d00`0@40h03`l=00d=2`0500d=2`H030`:01<020P6010@3P0@40h04a<A00l?3@0A4@l03a4>00/<
2P0;2`T03Q0=00l@3P0`<2h0<S@a028S8`0A4A404Q@C00l?3P0=3@/03Ph<00803`l=0P0>3P`00`0@
40h03`l=00h>300200`<2P0300/;2@0B4Q002PX800<04Q8@01/030`:00d=2`0<30X030`:00h>300?
3`d03@d;014A3`0;2`T08R8P00<30@0:2PP04A4?00T91`0A4@h00P<001HG4P0@4@`02``701DD4P0=
30X040l=01LF500:2@P03@`:00l>300>3@/00P0<2`T06`0?3P`040l;010A300>3`X0=3D`0083000?
3`X040l;00l>2P0A3@X03`/801<?300Q7AX0:bPS00D70@0E6140CE1702<V7P0@4``082<J04I9@@0B
4`d03@h600`<1@0A3PT03Ph600T90`0200`<100601lO6P0A4@T04a<;00l?1`0>3PH03@d50P0>3PH0
3P0?3PT03Pd900h=2@0>3@T03Ph900h=2@0=3PT030d800X:200>3P`030`:00h>300B40`040d80`0@
30T200h=2`0801@C4@0820H020P8018B400:2PX04A4?014@3P0?3P`200/:200300`;2@0>3@/03Pd;
00@03Pd;00l02`X8014@3P071P@03@`:06IVI03GemD0N7Uf01`L6P0:2PP03Pd;018A3`0>3@/03P`=
00l=3P0B41400P0F51D05P0C4A8040h?00l=3P0>30d03`d>00d;30081`H04Q4=00d<200:2@D04A0<
06ETH00F5A<03@`:00h=2`0@3`d05Q@E01TG600=2``02`T<00`:3@0=2`h200X82`<03@/>0P0>30l0
5`0?3A003`h@00D62P0C51P01PL;01HG6`0=3Q80414E00d>4P0:2`l030dA010A5@0>3a<00004018A
5P0A41D0=cHk00/:3`0O7R<01`H;00/:3`0:2@h030/@00803PdB00T02`X?00d;400>3A40J6I[02h/
<@0;2@h061HK01DC600B41D00P0?3A800`0A3a@04a4F00X83@0200d;3P0I00`:3@0;2@`030X=020N
8@0100804@lB014<400@2`l03`d@014A4@0C4a<03Ph>00P8200<30`04A4A01DE5@0@41002`/;00d=
3@0J6QX08R8R010A3@0?40/03Pl:00h?2`0200l?3@0;01LG5@030`403@d;018B4P092@T01PH400h?
2P041@00414;00T:1@0720801P0?40X09@0=3@P030/600d<1`0>3`T0414;014B300B4`d051D?01<D
3P0>3`T03Q4:00h@2`0B3@X05`h?01@>400@41<03a@H014J7`0X=S/0[/340;[<d00c@TH05R@W01PS
9@0G7ah041DA018F5@0A5A<06AhJ030d<`0B5Q@03a@@010E4P0<40l0314=02hc<00F61D00P0?3`d0
;`0F5QH051@D01HF5P0<30`03`l?01PH6P0E5AL03Ph@018A5@0?3`l0410@018B4P0G5aL04Q8B018D
4`0?4A008B<R00/?3P0H71/04QHE01<G5@0?4@h04aDB01HH5@0C5A804A<@01<E4P0J71T06A/H01DG
500?4@h04aDB01@F4`0A5Q804aTE01DK5`0A5a<041HB01TO6`0D6QH05adI01/Q7@0M8al06R0L01DK
5`0G7QL08bdU00804adE00@03QLB01XS7P0Y<Rd07bPU0P0F7a`0S@0I8b0072DT02`c>@0L8bX05QdS
014H800K92X072DZ01XS:00L9b/05R@W01`W:`0R;c8072X]04QFG00M;3<0BU]R02@e?00W>4009cY1
02@g?`0_@D/04bL`02XnB00W>dH0:Si902e3D@0aAeD0<TQE02m5D@0]@dh0;DA<02e4B`0/@dT0:d=7
0359C@0W?d<0:D5502]1B`0`AU40:D1803Q<E01gRY00Sj:V06AfN@0M;Bd09cLf02Hd<`0S<Rl08Rh/
028X:`0X<3<09c0b02Pc=@0O:Rh0;C]202Tj@P0]?d/0<4=B02e2E@0gC640>4]O03Q:F00jC5X0=DEC
02/kB00W>480:3U102Tj@@0Z>d80<3m402hm@00W=S/0:3Po02`mA`0Z>d<0:cU202Xi@00Y=Sh0:CDk
02Pc=`0U<3@092la02H`<@0W<C80:3Dg02Xl@00[?D40;Sm505IWKP0Y>D00;Se402<b>@0_?TD0:cU2
045?F00S<SX0938e02Pf=`11CDd0@de>02dg=P0N9bD072DR024W9@0R:2H07bDS020V900Y;bd07BHU
01hX9`0Q:R/07RHY02/c=P0T:c406b8X02@/;`0V;S4082TX01lX9`0G81d07BHS01TR7`0L9B<08BXY
01`T9P0H7B005Q/O01/P8P0N8R407B8N01/P6@0J7aT051XH01<I700F6ah06AhQ01XO8P0H7B006alR
01TL7`0201LH700@01XK800M7R805QLK01XK7@0I6Q`05QLI01DF6@0G61`03@hC01`M8P0C51T071dR
01TJ800F5a`05AHJ01PI7@805AHJ00<061TM01DF6P0I6Qh00P0E5QX00`0J6al061TM01DF6P02018F
5`0M010D5@0C5A@071hM02<U900c=C<03Ph>00d=2`0E5A<051@B01HF500?4@h04aDB018D4@0?3`d0
410>01@D4P0@40h05A@B01HE4`0C4Q004Ph=014=300@3`d04A0>010?3@0@30/04Ph=01@@3`0C3Pd0
100C3@d06`0E40l03@T8014=300D40l00`0001LC4P0/:2L02PH500T5100C3`h03PX9024M7018@d@0
8Q`N00P2100?2@/03PP:018<3P0P6Q`0U8j@01@>4P0@2Ph0618F07E_L`0l=SP04@/=00l92`0200h8
2P0?00l92`0:1@H081XL00@0000F41804@/=01LA4`0=20T03`/:00h61`0=10D04PT:01D;300J4140
5P`=00804PT:00H03`T901@?3`0E30d030830147200@1PL20147200301<92P0B20T04@L800803`D6
00D03P@501hD5@0?1@H02P4201061`0200d310H03`D600D05P`=02@J6`0C2@X03@<401882@0200X0
0@0;01@:2`0900003P@501<92P0D2P/050P<00h21P0<00@03`<701862P0A1@T01P0?0`LDooooo`00
6oooool0300G5aL030`<00d=3@0B4Q803`l>00/;2@0C4a4030`900X;1P0>3`X0414<00`=20802`/9
00@03@d;010@3P0A4@l03`l=0P0=3@/200h>308030`:01403`l=018B40071`D03`l=00h>300<30X0
2`/9014A3`0B4Q002`/900X:200A4@l02`/:01@D4P0Q8Al07alN01hN7002010@3P0600h>300?3`d0
4A4?00l?3@0=3@/03Pl;1@0>3`X04P0?40d04A8=00@5000F5a8010D001<D400>40d030h;00`=2P0<
30X02`/900d=2`0C4a405ADC018A3`0=30X03Pd;00l?30803@h901T030d800d=2`0=3@/030`:00/;
2@0=3@/03a0;00h?2P0=3PT04A4>018B40051@<03@d;024Q7`0D51802PX801<C4@0B4Q002@T700d=
2`0@40h03Pl;00d>2@0G61<01@H100804A8=0`0:2`H0500<3@P03a0;01<D3`0<3P/03A8>00d@3@0B
51<00@D401@G5P1`LW40nOgl05EHF@0>3a4010P900d>3`0>3P`06AXE02TZ9@0N7aX03@h90P0>3`X0
0`0@4@`04A8=00h?2P0200`=201900@3000K6QH040l;01TH500?3PX0BTU5024P700<2`L051<?00/:
1P0>3@T02PT5010@3P0;2`T061PF00l?3@0;2`P04A8=01@E400;30H01PL1010A2`0:2`D02``601PG
4`0D4`l05QDA00<2000A40`020L3014@300920H06aXF00@3000@3`/02PT500T8100>3@P04A0;010?
2P0<2`H02`X500T80`0A40/040l:00/:1@0A40/061LB00T91P0G61<0ATU2038h<@0I81T0>48i0;S0
^00H7AL00@@0018C3@0;2PH02`X500d=20061`40004001`M5`061`403a0:00h?2@020`003Pl900`=
1`0>3`T06Q/E00`=200200T:1@0?00/=200@40h0418?00lA3P000P402`h=00H:2@0@51<02@T700l>
2P0>3@T030/700L60P081`<040l;008030/700H030/800`;1`0<2`T030/700/:1P0<2`L300h=2@0H
00d<200>3@T03`h:00d<200;2PH03`h:00`;200N7A/020P601`M6`1eNWH0mogi07f5P00<4Ph04AHB
00l@3P061P@05QDC06ETHP0D4a402@P701dL6P040`403Pd;0P0<2`T200d<2P803Pd;0P0<30X0600@
40h00P8000l?3@092@T02`/;01@D50092@T0410@00@4100=3@d03`d>00h<3@0<2P/02`T:00`:2`0?
3@h04@l@00h<3@0?3@h06QPI00h<3@0;2@X03Ph@00T92`804a<E00h02PX<00l?4@0>3Q003Ph@00`<
3P0;2`d030`>010@4P0;2`d020P:01<C5@0A4A<051@F00`<3P803@d?00X020P:00/;3@0?3a401`L9
00d<4@0G5Q/0JVU^03<b=`0C4QL04A0E100=3140100?3Q<040lD00d<4@0?3Q<2014?500@018=4@0A
310040/?01`H6@0A3@h04`d?01PB500>2P/03@`=01DE5@0B4Q8020P801`L70061PH03@d=00l?3`80
4Q8B00T02`/;00L71@0B4`h04Q<=00l@2P0=3PT03a0;014B3@0A4@l00P0A4A40>`0?3a4030`>00/;
2`0?40T02P/300L8000<3@D03Pl700d>1P0@4@T04A8:00@50@0A4PX010D001@B2`0@3@H0514:014@
2P0:2@@04a8=01LH4`0?4@`03@l:00X<200?50h041DA018B400F5A<0518C014A4P0F5aT051PK01HK
7P0`>3/0BE5D028Z;@073a8072@V01@K700?5A<02Q0@00hD4`0T:RP092XZ00lE500;4@l051XI00@:
2P001P@0Jg1_00`>3@0J71/04A<B00`=3`0=3Q005AHH00l@4P0@4A<04A8D00803PlA00<04A8D01dO
7P0G6AH00P0@4Pl05P0?4@h04aDB018D4@0@4Pl04A<@01<E4P0D5Q<04aDB01<E400G61<061TD01<D
3`0A4Pd05ADC024Q7`0F5Q@04Q8B01/K6`0I6AT04A<B01@I5@0I7QX201@I5@0401HK5`0@5A4051TE
01DJ5P806b0L0:805AXF01<J4`0D6a<0620F01/R6P0G8AP05R0I01HO6P2LYj<0H6YZ01hX:@0V<380
92h`020Y;P0M9Rd0>45902</<`0L9Bh0628Z01DP9P0C7R@07BX`020_=00N;2l07bd`024_<P0Z>3/0
:CPm028a=P0R<cL08c@k01l`=`0V>3l083<j0395C00]@4P09c]402i2C@0[@E00<4EF0398EP0aAe@0
;49?02Y0B`0bB580;4=;02LnA00[@TP09ci402i5B`0^AU008cU402U0B00_@d/0JGb3055TJP0b@dT0
8c8g020_<P0Z>3X09C0b01TS900X;S808BHZ01`U:00T;c40:SDi02`j@@0hBE<0?E1N049GJ00dBV40
;TAL03U?H@0dB5<0<dMB03A6D@0V>48093Dm0310A`0W=S/0=DA9049@D`0W=CH09S@g02hnA00/?TP0
;T1:028c>`0]?TD09C@k02Hd>@0V=3L0:3<g02Pc=@0V<C<09S0b02Hb=P0W=Sd0:SU002Pg?@0V=CX0
:SPn02/h?P0Z=cd0:3Dk02dh?00a?400=dA70353A@0V>3X0V:NW0=;NgP0oBDP0:C0]02<Y9@0T:BD0
8RLT02P/:`0M8B80=3Pj01lY:`0O:R`082X/02@]<P0X<CH08R`^024[;@0M9bP08BT[024Z:@0J8b80
6b4P028X900P9R80728N01dS7`0P9R807b@P01HJ6@0G71P07b@P01hS7@0H7AL06b0J01`P7`0J7b00
6QhO01`P8@0L82806QhQ01HI7P0K7R<071lT01XM8P0L7bD08R<X01PI7@0M72407QdR01/J7`0G5a/2
01@E6@0T030c=P0420/05a/N01DI7@0A5AP03a0D01DF600H6A/05aPJ01TJ700M7R00824S018C5@0H
6A/05QLI01DF600C51H04Q<E01XK7@0G61X05ADG018B500=3@l04Q8C00l?4@0D51@05ADE01<C4`0D
51@03@d;00/;2@0F5Q@04Q4?01`K6@0C4Q004Q4?0P0C4Q001@0A40h04Q4?01<B400D4`l04a8>0080
4Q4=00/04A0>010?3@0=2PT03PX;00d92P0R7Ql03@T:00d92@0A3@`03`/:00h:2@0200d9208040`;
00T03`/:01<?3P0F4Q404`l>01@@400M6AX04Ph?00T51`0B3A400P0=20`04`0400<07QTO01<>500L
5ad0_k[0085lO`0F41004@/;00h8200:10@03@L7010:2P0Y8b<03PP800d71`0?2@T0:bDU01092@0@
1`P0100A1`P401<92P804PT:1P0@1PD0800W7A`03`D400l5100E2`X02P0001<9200=0`@040H701hD
5@0A1`P0308300l51P0700002`420147200D2P/060h?0147200A1@L040@600h2100=0@<03`<50145
1`0E2@/02@0000l31@0D20X03@<400d10`0B1PX04@@;0P0@0`X0200A10/04PD<01442`0@0`X03`89
00P00P0C20d04`H=5?ooool001_ooooo00d04Q8B00h>3P0=3@d030`<018B4@0P81h0:BTW01XK5`0=
3PT030d800d>2@0<3@L0410>00803@d;00@03`l=010@3P0?3`d03@d;0P0>3P`300l?3@07020P7P0F
5Q@02`/900/;2@0?3`d071`J01TI5`0200/;2@0600h>300=3@/03`l=04Y:B00@40l0410>0P0?3`d0
1`0>3P`03@d;00/;2@0<30X0410>00l?3@0=3@/01P0>3`X02@0E5Q40G5eH010A3P0<3@T061TD00h>
2`0=3@/03Ph<00l?3@0200d=2`0400h>300=3@/03@d;00h>30803@d;00@03Ph;00d>2@0=3PT030d8
0P0=3PT00`0>3`X03a0;00l@2`03010A300V00h>2`0C4a40410>00h>300:2PP020P600l?3@0=3@/0
3`l=014A3`0<30X03@d;014A3P0@4@`09BHQ00l@3@0;30P03@h9010A300?40/04Q<>00h?2P0:2`H0
4A8=00P:1`0:3PX041<@00T<2P0F6AL04A@C03Hi>@28Rh/0:B/]00D72`0>4A@02``?00`<2P0;30L2
010A300400/<1`0<3@P0414<00h?2P803@h902T030d800T:1@0>3@T04A0<00`;200F5A403`h:01HE
4P0B4@d03`h:018A3@0:2@D040l;018A3@0<30X03`l=02@T8P0M7A/0414=00/<1`0<3@L03a0:01DF
400O81P04a@<00h?1`0@3`/03`h:00d<200D4`l02`X600d<200:2@H05A@@02@S7`15A4009B@P00`;
200;2PD03Pd800l>2@0300d<1`0400h=200=30L03@`700h=20803`h901T03@`800T:1@0A4`h02Q0:
00LA2@0D7QH0<3Xb00P?20083@L02@X500X91@0E51003Pl901PI4`0j>cD03@h900T:100=3PP030d8
010A2`0C50h03@h8018C3@041@003Pl:008030d800l02``700/=2P0;3@X0310>018F5@093@`04aTH
00@92@0D5QD0;bhZ02XY9@0@3`/04Q4=00h=2@0;2PH01@0>3@T00`0=30P030/700d<200400h=2@03
00d<200>3@T03Pd900803`h:01<03Pd:01HE4`0;2`T03Q4>01/Q7@1;E4l09S0Z00`E400D6QH02`l;
014A3`0G5Q@0:BPV01DD4P0?3P`02@P600h=2`0?3P`030/900803@`:0`0>3@/02P0=3@d030`<01hN
7P0F5QH02@T901<C4`051@D06QXJ00X:2P0<30`200/;2`H03`d>00L03@/<010>3`0?3@h040h?00T7
200G5AH08AlR00804Q0C00H04a4D00d;3P0A3a803`d@00h<3`0=2`h200l=400C00d;3P0<30h0410B
00/;3@092@/05ADG00l?4@0=3@l03`lA00/;3@0=3@l05ADG01@D5P0A41D030/@01PG70071P/02`X?
00`;4002010?500H00h=4P0=31403PdB00h=4P0?3aD03@dB00/:3`0<2a0040`@014>4@0F4QH08QdO
01`G600B3@l05A0B01PC500?3`l03@d=00820P0A4A400`<301HF5P0A4A4051@D0P0@4100A00A4A40
3Ph<014B300B4`h04A8<00l@2P0?3``0414=00l?3@0>3Ph03Ph?00d=3P0<30d03@d<00/<1@0D5@d0
4Q<;00l@200>3`L04A8:014B3@0<3@H05QL?00`=1@0C50`04a4:018>1`0C40T0518<018A300H6180
6Q/F00T;1P082PL03Q4>01LL6013B4@0C51<020Q7@0I6QH04A4@01<C4P0A4a403a4A01DG5`0?4aD0
51PJ03Di>`0E6a`04QLH01@I600@5AD0314A01DJ6@0C61L0314A014F5P0<4A004aPH014F5P0?51@0
51HF01TJ6`0@4A8051DF01HG600Z;2`04Q@D0P0C5AD02@0A4Q<0418B01<E5@0=3``04aDB01HH5@0C
5A805ALD01@F4`0301<E4P0601HH5@0E5a@04Q@@01HG4P0F5a405QLB0P0E5Q400`0E5A<05aLE01HF
500201TI6@0401@D500E5aH05aTF01HK5`804AHB00@06AhJ01PM6@0I7QX05a`H0P0K81`04@0G71P0
6AhH01LO5@0I8AL06B0H01DO5P0F7aT05b0K02dg=P0f@4008R`]02Xe=P0H8bH0>dI;02lh?`0W<3P0
92de00806RD/05L07RT^01`Y;P0H9R/06bX^020_<P0P;c405bHX020^<@0T<cH08c8e02Dd>@0S=CT0
7c4e02/l@`0]@4L0:Se402`oAP0]@DP0:cm802m3DP0fBUX0=DYH0315D`0^@U00;T=@02i3CP0Z@4P0
9Sa402Y0AP0V>d80:d9:0358D`0[@D`0;TA?02e1BP0iC5<083<j02/m@P0]?440:cXm02lm@00b?Cl0
;cTk02he>00W;C00:C8d02Lb=00X<cH0:CPn03E7D00mD5d0@5IX03A:H00]A5`0=daN04MJH`17FV@0
;d9;02m2B@0a@TX0:CY102Hf?00_?D@0?4]?0391@`0]>Ch0<45702XmAP0[?DL093Dn03=4C00[>T40
:SPn02Pe>`0Y=CT0:SDi02Td=`0Y<cD0:3@i02Pg?P0Z>D00:CPn02Lf>`0[>3h0<ci2030k?`0[=SX0
0P0X<S@06P0[=CL0<dE902Tm?P1ZNg/0RING03i9A@0U;BT08bPT024V8P0T9b@08BDV028V9`0T:B`0
92db02<^<P0O:Rh07RT/02<^<@0S;Bl08b`^01hW:@0N9RP07bLV01`S8`0P9RD07B8N0P0M8Qd201lT
7`0801XO6P0R9b807R<N01hS7P0L8A`06QlJ024V8P0L81l201XN7`0401/O800L82806AdP01PK8080
6QdR00@061/R01XM900N8BH06APN0P0J6Ah0300H5a`06ATM01/L800L7B40:bda01`P8`0D61/05AXM
00hC5P0F5aT05aPJ01PI6`805aPJ01P05AHH01@E5`0J6ad08B8T01XK7@0L7Al06Q/M01XJ700C4aD0
5aLI01HF600D51H06ATK01/K7@0B4Q@04a<E018B500A4A<051@D01DC4`0920H04Q4?010?3@0E5182
018A3`804a8@00<04A0>018A3`0C4Ph00P0@3`/2014@30<040l=00/04@l@01HD5@0A3a0071XK014>
3P0D40l04@d<010<2`0D40l061@C01HB4@02010<2`0B01<?3P0E4A004`l>018>3P0=2@X02PL701DA
4`0;1`T01P85014<4@0L5ad08QdS040k@@0F4AP08ahU01TD600>20P03@L70P0@2PX00`0C3@d06A<C
02TS8`02014;2`0300L20P0I4a<030@500/04@L81P0@1PD04P0I3`h0=2XY01<92@0<0P809alN0106
1P0?1@H05P`=028H6@0>10D02P420147200`9RL06a4B00`3100?1@H02`4201061`8040@60P0?0`D2
01041P0702DI6`0I3@l03@8300/10P0>10D04PP900l22@0401032P0700l22@0@10X040@:01D83`0?
10T05@X?01<63@0Dooooo`006oooool200/;2`0>00h>3P0=3@d04a<B028R80092@L02@T600`=200@
4@`04Q<=010A2`0D51803`l=00`<2P0=3@/200l?3@803@d;00/03Ph<010@3P0B4Q004Q8@00L71@0:
2PP04A4?018B400?3`d092@R020P7P0200/;2@0:014A3`0B4Q004Q8@06EUH`0I6AL04A4?00/;2@0<
30X03Ph<018B40803`l=00<0410>00l?3@0>3P`01P0>3`X02@0;30L07b0K0001000B4`h0414<00/<
200<30X02@T700`<2P02010@3P0700l?3@0=3@/02PX800h>300A4@l0410>00h>2`0200d>2@0<00`=
200=3PT03@h900h?2P0=3PT030d800/<1`0=3PT03Pl:018B3`0?3`d020P60P0I6AL0300=3@/04a<A
00H610061P@03`l=0082000410804A4>0042000<3@P03Pl:01/L5`803@h901@02P/600h?2P0@4@`0
2``7014B3@0A4a0010H300/=2P0A4a00?d4n014C4P0D5QD04Q@C018C5@0F5a/01`P<00/<3`0G5aD0
4A8=00/<1`803@h901@030d801<D3`0?40/03@h9018C3P0C50l03@h901HE4@081`<02`X600L60P0?
3PX02PT501@C3`0B4@d03Pd901`K5`0@3`/0;2/W01TI5`802`/901`010@200`<2@0D5A004Q<=00d>
20082@<03Pl700X;0`0A4PX02PT501DD400H5a<0>3Lc010?2`0F5A4030/700`;200H5a<0EeIB038a
;@0:2@D03@`700h=200<2`H02`X500`;1P0@3`X04A0;0P0>3@P2014@2`0C00l>2@0D4`l0414<00d?
2P0D5a805ahG018L50094@X02a0:00hC3@0@4@`030/700/:1P0;30H08R<M075bK00L7AL00P<0010A
2`0200h?2@0800l@2P092P@06a`F00T:10092PD02``700`=200>3`X200d?300600`A3@0]<C005AXH
04iDDP0O9BD01@H40P0>3@T0100B4@d02`X600T8100C4Ph500l>2P0400h=2@0=30P03Pd900l>2P<0
3Pd90P0<2`L05@0@3`/04Q4=00h=2@0<2`P03Pd;014A3`0@4Pl03A8>00L=2@0:4`h00`T500/@3007
2PL030`:00`;2@0=30X020L500T81P0<2`T04Q4?00l>300200d<2P<03Pd;00@03`h<00@4100820P0
2PX:0P0E5AD02@15ADD09BDU030`<00E5AD04A4A00h>3P0@41003@/<00h<3@02010>3`0V00l=3P0>
30d040h?01DC500@3Pl03P`=00/92P0O7Ah09R@W01<A500>30l04@lB00l=400=2`h040hA00`:3@0=
2`h04Q0C014?4P091`X03@d?00H6200=3@l05ADG00`<3P0D51H02PX<00l?4@0=3@l02PX<00`<3P0@
41801PD:014@5@071P/06QTN01@C60071P/200l>4`803@`A0P0>3A804`0?41D030dB00X;3`0:2Pl0
3@d?00h>400>30l040h?01HB4`0=2@X030P901@B4`0E5AD03@d=01PH600B4Q804a<C018B4P0@4100
0P0000001`0A4A4051@D00L71`0>3`/04A4?018C3P0?3`d00P0>3P`0A`0@40h03`l=00h>300@40l0
4Q8B018B400?40T03a0800/<100<3@D04A8:020Q6@2CU8`00`@001XK4`000@009bPP00l>1`0D4@X0
4Pl8018@2P0A40/04A8<00h?2@0:2`H04aDB010C400;40`0B4e905MJEP0K71L05QLB014B3@0E5A<0
5ALD01<E4P0<3Pd0:Bd/00lC4`0L82404ALG00dB400B5a<05QPG014D4P0B5a<051HE00X=2`0F6aL0
4A@B00H81`093PX05aTG00H81`0I6aP03Q0>00X<2`0?4@h03a4?010B4@0A4a004A<A00h@3`0>40d0
4A<A00lA3P0G6AH04Q@A00h@3@0E5a@04aDB00805aTF00X06A/H01/M6P0I6aP04aDA01PI500E5Q00
4a@?01HG4P0H6A@051@B0P0G5aD01@0K6a/061PH01DE5@0K7A`04aDB008051TE00D04aPD014F4P0=
4Ph06b0L01LL600201TN6P0301LL600K81`05ahG00806R4J06D05QlJ01DN6@0F7a`05B0L038l>`0A
6aX04alO01TU9@0A71h09Bhc01hW;@0b>d00G6M]02Pc=`0S;S8062HY01l^<@0Q<3<06bX]01TY:P0S
<c<07bd`028a=00U=3L0:3Ll02Hh?00T=SX0;3e4069eO014Eeh09SU003=7CP0mDEX0=4ME03U<F`0d
AeH09cY802@gA@0W>dH0;T9=02a0B@0Z?TL0;d=:02TmA00^@TT0;4=<02PnB@0V?DD0;D5902i1B00^
@DL0<41503E3AP0^?3l09S@e02@_<@0S;Bh0;C@e02Ta<`0e?cl0;c/k02di>@0]?3l0<T=:03I8DP11
EFD0?eIX03I<H`0gBeX0:Se402Lh@00aA4/0=DQ?03M8D00cA4`0;Sm6024b>@0R<ST0;Sm602hmA00`
@DP08C<m02Dg@@0V>400=DI>02/j@@0Y=ch0:3Dk02Le>00X=CP0:C@h02Td=P0Y=S/0:SU002/j@@0/
>d40:cXo02`i?`0b?D40;cXn02/f>P0202Pb=00F02Td=P0/?T806bl`024b<`0U<C4092l[02H]:P0R
9b<082DQ02T^:P0R9RL0:Bd^01hT9`0V;c@09c8f02<^<P0P:bd08Rd_024[;@0R:R`082PZ01lW:@80
8BLW00/08bTX020U8@0N8al082DQ024V8P0N8al07B8N01`Q7@0N8al07B8N01TN6P0201@I5@0601lS
900N8R<07B4R01lS900O8bD07B4T0`0E61d0200G6R406ahU01lR:@0J6Al071/P01/J7`0I61d06QXN
0P0K7200300@4QH092P[00X>4@0K7b804QLJ01XK7@0F5aT05AHH01PI6`0F5aT0414C01DF60806a`N
01H05QLI01/L7P0D5AL05aLI01DE5`0G5aT05QHH01<C5@0E5AL051@F01DE5`0L71h06ATK010@4P0>
3Ph030/:01<B400K6QP04A0>010?3@0G5Q@04Q4?0P0C4Q000`0A40h04Q4?01<B3P0200l>2P03010?
2`0A40`04Q4?00804Q4?00H04a4B00d;300<2P/03P`=018?3`0A3@`2010<2`0301<?3P0G4a805A4@
00804@d<0P0B3Pd04@0A3@`030P801<?400@30d02`L800d92P0?2Ph05a8G00/630060@L06aLM00<0
1@0D3aH05A0D00d71`0>20P04P`<00<040X:00H04@/;00H0000B30`0208201@>3P0@20P;014720H0
40H5018081HE08AjN@0M4a806a4@06eSHP0H3Pd03@<401@:2`0X7Ql06Q0A0147200@1PL08QPI0188
2@0<0P<03`D600T0000:0@8301041P0300l31@0@10H040@600802`010P0F2P`0100>0`@050P:00d0
1`0?0PT20185300800l22@0=00L03`8901P;4P08008040<:00l52@08008Dooooo`006oooool0400C
4a<0410@018B4P0B4Q803@d<00`<2P0;2`T03@h:010A300A4Pd0414<00d>200E5A<0410>00`<2P0=
3@/200l?3@0800h>300=3@/03@d;010@3P0B4Q004a<A018B40092@L200h>300:014A3`0Z:RP04a<A
00T91`0:2PP02`/900`<2P0?3`d04Q8@00D50`803`l=00<03Ph<00H6100A4@l00P0>3P`00`0A4@l0
4Q8@014A3`0600h?2P0B03Pi=0082@@02P/6014B3@0<3@P08B8N01LG5@0;2`T030`:01<C4@0?3`d0
3@d;00l?3@0;2`T03@d;010@3P0>3P`03@h:0P0=3PT05`0<3@P03@h900d>2@0>3`X03@h900`=200;
30L03@h900h?2P0?40`03Ph<00l?3@0];B/0:RXX00l?3@0@40h04Q8@01lO7@0b<S006ATG00d=2`0D
5A403@h900804Q<>00<0:2TT010A300D5A000P0@4@`05P0B4`h0414<00h?2P0A4`h01PP3010B3@0A
4a00>S`i00h@3@0=3`h00`D400P92`0:2`d0:2T[00420`0820H02@X500X;1P0;30L03Pl:014B3@0@
4@`200`=200W01<D3`0E5Q40414<018A3@0920@06aXF00<2000<2`L05QDA00l>2P0<2`P05QDA03Pg
<`0F5A40?3/g01<C4@0>3P`05ADC00l?3@0@40d030d800L80P0<3@L03@h8018C2`0720802``400L6
0P0?3PX040l;034`;00<2`L05A@@014@300<2`L01@@000/:1P0920@051<?00803Pd800H030/600X9
100=30L040l:00d<1`0?3PT200h=2009010?2P0C4Pd09B@P00h?2P072@@02Pd8010G400E71D02Q4:
00801``601<04Q<>01<B3P0>3@T02``701DF400P8A/030d800d>200:2`D0414;00X;1@0?40X01`P3
00l@2P0:2`D02PT400/<1P0<3@L03Pl:00803@l:00`0;c4^0>KZj@1EFEP03a<B00X>3@0<3@`03@`8
00`;1`0B4@d02@P400H50@0B4@d600l>2P0300h=2@0?3PX03`h:00<03Pd901003@`800`;1`0@3`/0
4A0<00h=2@0;2PL03Pd;014A3`092`P041DA0088100>51001@/700X?2`0A4a002`/90P0<2`T01@0A
40h040l=00d<2P0920H040l=00803@`:0P0>3@/200l>300>00D51@0L71`03@d=010@400820P05ADE
00`<300>3Ph010@400l?3`030`<02@T900`:2`0=2``200l=3P0V00h<3@0=2``03P`=014?400:20T0
3P`=00`:2`0D4Q<071XM00l=400=2`h04@lB00l=40091`X040hA00`:3@0=2`h04Q0C014?4P091`X0
6a/M014A4`030`D03@d?00/;3@0C4aD030`>014A4`0D51H0410B00`<3P0?3a403PdB010?50030PL0
61LL00d<4@0A41D200`;400I00d<4@0>3A8040lD014@5@0?41D03A4E00dA500=3a<03@h@00`=3`0C
4aD02`/;01<A4P0A3a0030X;01<A4P0C4a<04A4A01@D500A4A404a<C01@D500B4Q805aLG01DE5@02
01@D500601<C4`0=3@`04A4A014A3`0?3`h03Ph<0`0?3`d0500?40/04A4>018B400C50l04Q<=00`=
1`0:2`D04Q<=01@E3`0>3`T0;2dW01dN600720D0BT]50001000M71D0514:010@200@3`T04a8=0P0A
4P`0@P0=3PT03Q0=01@F4`0<3P/02a0<018E400B4`d04A8<018C3@0G61<05QPC018D3`0B5140=S/g
010E4P0;3`h05A/I010C4@0A4`h05ADC01@E4@0F61<06ATG018C3`0A4`h03a0=01@D4P0>40/03Pl;
00lA3P0E5a804aDA01XL6@0C5A0061XF01@F4`0E5a805ALC018D4@0B50l05ALD010B3`0D5Q<04aDB
01HH5@0N81d061XG018D4@0C5A805ALD01LI5P0E5a@03a4=01LH4`0D5@l04a@?01LH4`0H6A@05ADC
01LG5@0C4a404Q8B01@D500C4a<05QPG01XL6@805a`H00D05Q/G01DJ5P0D6AD06b0L01HK5`0201LL
601Z01HK5`0K81`05Q`H01/Q7@0M8al06B8O01LP7@0F7a`082/W01@O6`0N:BD072PV01dY9`0O:bT0
6bDW01/U:00d?T00G6M[02Pc=@0Z=CL06bTZ01`[;00P<30072`/01XZ:P0T=3@08S0c024`<`0S<SD0
9SDj02Dg>`0W>Cd0:S]2049EG00]@4L0<4=:03M;DP0^@T/0>4]H03]>G00fBEL0:3]902LkAP0[?dX0
;D5;02e1BP0/@4T0<DE<02XnA@0^@TT0<4M?02m3C00Y?DH0:Si602m2B@0nCeH0<T5603=1A00_?Ch0
;cXl02/g=`0W<C809bl]02L`;`0a>cT0;3Pf02Te<`0Y>3T0:Sa002Tl@`0kD5d0AU]/03Y?HP0eAe@0
:ca302Th?`0X>D408c@l02Df?P0Z>d<0<45902/lA00^@4L0=TU@0311B@0]?TH08c@l02/lA00`@DT0
>DYA02dl@`0Z>Cl09SDj02Hc>@0U<cL09S@g02Td>00Z>3`0;3]202dl@`0`?dD0;ci302hk@@0^>Cd0
;3Lk02Td>080:38d00P0:C@f02<e>@0P=3D0;Sm002hj>P0Z=C407bHS02<X9080724M00H0728R01lU
9@0S:B`09Bhc02Pc=`0X<cD202D_<@03020Z:`0O9bT08BT[00<092XZ00<08BLU028W8`0N8al00P0Q
9R802@0L8Ad07b@P024V8P0R9b<07b@P01hS7`0R9b<092TU01`P8@0201XN7`0F01/O800L82806AdP
01PK800G6Ql05QTN01LJ8@0I72<06QdT01/J800N7B<07ahT01dL8P0I6Al061TN01HG700b=3T0EUUN
01TL8@0=4AD03A8E01PI6`805AHH0P0H6A/00`0B4aD04a@F01@E5`0201TJ700?01hO8@0H6A/04Q8D
01PH6P0G5aT061PJ01HF600@41804a<E01HF600L71h06QXL010@4P0>3Ph05A@C00805A@B00@05QDC
010?3@0B4@l04Q4?0P0C4Q00100A40h04Q4?01<B3P0@3`/2014@300901<B3P0C4Q004a8@018A3`01
0000928S038`<@30_[l081dM00L04@d<0P0B3Pd2010<2`0@014=300C3`h02`L8018>3`0H51D02PD9
00H21@0>2@d0=C0f04a7C@0F4AL04PdC00`72P0>20P03`T9018<30803PP800L04P`<01<=3@0>20P0
5a4A00`61P0@2PX040P900/04@L81P0@1PD04P0<0P403P@301471P0700002P0001471P0@1PL03`D6
01`B4`0G3@h05@/<0147200700002`4200h41@0<0P<03@<400/10P8040@60P0A1@L201041P0800h2
100A1PL02P0000P0000@1PL03`<500h1200A10/201<63@0801442`0>0@P04`H=00`21P0I31<06PdD
05I9D00Y72<Dooooo`006oooool0200G5aL030`<00h>3P0C4a<04A4@00`<2P0@40h03Ph;0P0;30L0
500=3PT0414;01<C4@0@40h03`l=010@3P0A4@l03Ph<00l?3@0>3P`030`:00d=2`0@40h04A4?00l?
3@0<30X04a<A01LG5@0?3`d06a/I0P0>3P`03P0A4@l03`l=00d=2`0A4@l03`l<010@3@0=3PX030`9
01<C400A4@h03`l<00/<200<30T0410=0P0B4Pl600h?2P0B00l@2`0=3PT05aPC00/<200@4@`09BDR
01dM6`0A4@l03`l=018B400=3@/02`/900h>300<30X02`/900`<2P0>3P`03`l<0P0=3PT0100<3@P0
3@h900d>2@0>3`X200l@2`<0414<00X03a0<014A3`0=3@/03`l=014A3`0<30X0410>00/;2@0=3@/0
5aLE0P0:2PP06@0@4@d01PL2018C3P0<3@X05QLB00l@2`051P804Q<>014B3@0;30L04a@?014B3@0;
3@P02``701LH4`0A4Ph04a@@00/<2P082@L05aPF00h>3`0@4180J6QZ020Q8@0;2`T00P0@4@`01P0;
30L030d800`=200=3PT030d800d>2@80414<02<03Pl:00T8100?3PX09B@P00`;2@0;2PL051<?010?
2`0;2PL07QdI02DT800920@06APD01@D4P0=3@/03`l=00X:200?40`02@X600h?2@0?40X02@X400`=
1@0=3PH0824I00l>2P0<2`L02PT5018A3@0>3@T05A@@00l>2P0=30P05A@@00l>2P0200h=2@0300d<
1`0>3@P03@`7008030/600<040l:00/:1@0<2`H00P0<2`H0700>3@P03`h9014A3@0<3@P03@h900`>
2@0830H01P`600X>200<3`X03@l:00h?2P0?3`X03`l;00h?2@092P@03@h:00h?2@092P@04Q<=00h?
2P092P@02P/5014B30092P@0414;00l>2@0=3@L200`<1`8030d800X0;c4]0::UX`0o@d403a@A00T=
30092PP05QDA01@C3`0<2`L04Q4=0P0<2`L600l>2P<040l;00<03`h:00h=2@0>3@T00P0?3PX200h=
2@0?00d<200=30T0410>014A3`0?40h041<@00/>2`0<40d02`h;00X=2P0A4Pl02`/900`<2P0:2@L0
6aXH00807ahL00@01@@300l>300>3@/03Pd;0`0?3P`01@0@3`d04Q8B03De=@0?3`l04a<C00803@d=
00H030`<014A4@0B4Q809BDU018B4P0>3Ph600d;3003014?400C4A8030X;0080518C00@04@l@014?
4P0>30l030X=0P0?3A00100;2@`03`d@00h<3`0=2`h200l=400900d;3P061PP06ATK00T92`0A4A<0
2@T;01@D5P0>3Q002`/=00803`lA00@02`/=00d=3`0A41D03`hC0P0A41D0A00=314030/@00`;400<
2a003@`A00h=4P0A41D04Q<G00lC600@51P03a@G00hC5P0>41803@lA01HH6P0;30`03Pl?01@D4`0B
4A804a8B061PH02PX:00:2PX00h>3P0B4Q8061PH05YJFP0D51@02PX:014A4@0@41004A4A00d=3P0@
41403`l@00h>3`0?3`d04A4?00d=2@0?40/0414<014B300?40X03Pl9010A2`0?40X04A8<01XK5@0E
5Q00414;018C3@03104051D?01LH4P0O81X03Pl9014A2@0B4PX0414:01HF4@0G61804a@>01<D3`0B
4a003Pl=014C400B51403a4;0`0@4@X02P0D5@h04A@>01<F400e=c405Q/F014F4@0C61<0318=00lB
3@0B4Pd201<C3P0A01@D3`0E5A005QHA01HF4@0A4@`04Q8=00X:1P0C4`h051LA00`?2@0X:R@0?T0j
01HH4P0?4P`04Q@>01<E3`0C5Q000P0@4`d02P0C5Q0051HC018D4@0F61D05aTF01<E4P0F61D05ALD
01@F4`0E5a@201LI5P0?01@F4P0D5A0051H?01@F4@0E5a805QLB01HG500K71T051DC01DF5P0L7A`0
6AXJ01HH5`0J7a/051TE00805AXF00@05a`H01hS7`0K81`05a`H0P0I7QX0;@0G71P06b0L01TO7@0L
8R407B<R01XS8@0L9B807BHS01LR7P0N:BD07bXU018N6@0N:bD06BDQ02<^;00M9bL09S0`01`X:@0N
:BT0<cm003M5A@0N;Bd08C4`02dm?00X>3P0830`028`<`0P;c8093<f02Dd>@0T=SX0:3Xn02Pi@00S
=Sd08C@k02`oAP0eBE00=4QA02m2CP0a@e00;T1=02XlB00/?dX0<4==02XmA`0202e0B@0l03=6CP0Z
?DH0;T9:02e2B@0aADd0<dM>0354BP0dAD`0?U1D03=3A@0`?Sl0:cPi02/g=`0W<S408B/Z028Z9`0R
:bL08R`W02@_:P0Q;BX07Rd/02<e=P0P<CL0;T5:03eBG`0bAUH0;Ce9045?E@15De/0;3]302`kA00d
ADh0<D=<02/mB00/?TT0:Sa902]0C00bAe<0;d5;02<c>P0^?TH0<4170392B@0X=ch0:cY002He>`0U
<cT09C<h02Ld>@0Z=S/0:cU002`k@P0]?4<0<D160350A@0^>d40;3Lk02/f>P0W<SH09S0b0P0U;c40
<@0M;S80:3Xl02<a<`0T<3008RdY024W900Q9R807B8N02hd<01PIVH0=Sdm02D/;P0S;Bl0:3<f02Xd
=P0U;c0092h_01lX:P0N9BH08RTZ02<Y:@0P9B@08RLV01hS8P0O8b407B4O02@X9P0U:BL06b0M01dQ
7`0N8b007b@Q01PL6P0I7Q/0:2dZ030d<`0M8B80720Q01/O800M8B807B4S01/O8P0L7b@06QdR01TL
8@0J7B@061/R01<F7@0J6Al00P0N7B<02`0L6b4061PN01HG700A4QL07R0U03@g?00M82D05a/P01DJ
7P0G61`061TL00806AXM00T061TL01LH6`0E5QT05aPK01/L7`0F5aX0@T=606=TI`0h>3X00P0E5AL0
3P0K6ad05aLI01PH6P0I6A/04a<E01@D5P0C4aD0410B018B4P0B4A005aHD00L61@0E51805QDC0P0B
4@l201<B4003014@3P0B4@l04a8>00@04Q4=0P0B4@l01P0?3P`04a4B014?400M6a`0H5iO03Db<P<0
510?00H04Ph=010<2`0?2`X04@d<01<?3P0A3@`200l;2P0=01@@3`0C3`h04Ph>01@@400400006aHI
02hY;@0E41@07aXO020K8@0A3A802PD;014<3`0200`61P0:014;2`0?2@T04@/;014;2`0=1`L03`T9
010:2P0A2`/03`T901082@/04@L81P0@1PD04P0>10@06A0@00h5100@1PD060h>01071P0D2P/02`<3
00`310090@403P@501882@0<0P<040H700l51P0;0P803PD501<92P8040@60P0B1PP02P0A1@L040@6
01882@0A1PL0Ed]=05U=C`0C20T04`T:01032P0A10/20185300801442`0@0`X02`45020C6P0F2a00
200201@73P0@1@XDooooo`006oooool0500Z:RX05QHF00X:2P092@T02PX900d=2`0820H03`l<01<D
3`0B4`h03Pl900X;1@0@40h03`l=010@3P0B4Q004A4?00h>300@40h03@d;0P0;2`T01@0=3@/03`l=
01lO7@0>3P`020P600804Q8@00D061PF010@3P0<30X0410>014A3`0200d=2`<03a0;00T04Q<>00h?
2P0>3`X06Q/F01<D3`0?40/03Pl:00d>2@0<3@P01P0>3`X0200?40/02``700D60@0?40/05QLB00/<
200:2PP030`:0P0>3P`300l?3@05010@3P0>3P`03Ph<01@D4P0C51000P0=3PT0;`0<3@P03@h900d>
2@0<3@P02``700d>2@0?40/03Pl:00d>2@092@H030`:00X:200A4@l07AdK014A3`0:2PP030`:00/;
2@0>3P`03@d;01<C4@0`<2d04A8=00X;1P0<3@P02@X500h?2P0F5a80<c@_02X[9P092PD03a0;00d>
2@0D5A001PL200/<1`0T9B003Pl:00l?3@0;2`T00@40010@400J6Q`030`>00l?40092@L030d80080
2P/600<03a0;00`=200A4Pd00P0C50l01`0@4@`03@h900d>2@0:2@D04A0<010?2`0920@00P0C4Ph0
1`0J6AD03`h:01hM6@0100006QTE01hM6@0C4a400P0=3@/03P092@L03Pl;00H70P041@003Pl900l@
2P0@4@T01PL0014B2P0=30P03`h:01TH50081`<05A@@0P0:2@D01P0B4@d03`h:01DD40081`<04A0<
00`;1P803Pd8028030/600d<1`0>3@P05A@?00`;1P0=30L04a8=010?2P0:2@@03a0;00h?2P031000
1`T5014B3@0:30L03Pl:00@500092PD0414<00/<1`092PD03@h801LH4P0O81X02@X500d>20041@00
;c0Z01hO6@000@004A8<00@5000<3@L03@`70P0:2@@03`0=30L0414<014B3@0B50l05ALD010C400@
5A40004001<E4@0B4@d03`h:01PG4`0920@00P4000l>2P0500h=2@0N00l>2P0@3`/040l;010?2`0?
3PX03@`800h=2@0@3`/04A0<00`;1`0:2@D03@`8018A3P0:2PP00`<1018B400210403`l=00T:1`0B
51403Ph<00L71@0@40h03Ph<01TH5P01000051<A05ACD@0D4a4040l=0P0>3@/200l>308040l=01X0
0`<302d];@071`L04Q8B00H61P0@41003Ph>01TI6@0;2`/05QHF018B4P0>3Ph04@l@010>3`0>30d0
3@/<00h<3@0A3a002`T:014?400;2@X04@l@018@4@0A3a004Q0C014?4P803@/>0P0A3a8200l=400<
00d;3P0<2Pd03@/>014?4P0D51H01PH8010@4P0G5aT03`lA07IfN00P82804A4C0P0>3Q00200;2`d0
3Ph@01LF6`0=31403PdB00811P0P7b@05QDJ0P0>3A8200d<4@0400l>4`0>3a<04aPL00hD5`802a0C
03D03A4B00lC500>4Q<03a4@00h@3`0G6AP08B4Q02<S8`0L71`0<S8b01dM7@0:2PX03`l?024Q8@1V
IVH04A4A00h>3P0F5QH02`/;00l?3`0>3A803Ph@00d=3`0=3@h0410@018B400?40/04a@>01DF400D
5@d03a0800d>1P0>3`T030d700T:100>3`T04Q<=00T:1P0J6aD05aPB00T:1@0F5a40414;00d>1`0@
4@T04A8:00`=1P0@4@/04A8<018C3@0?40/03@d;014A3`0200l?3@0O018C3@0C5@X0414900`=1@0A
4PX04A@=00d@2@0n@CX00`P200hB3P083@L04APA01@G4@0E50l04A0;01<B3@0E50l05QD@01@C3P0H
5a8051<>01XI500I61<03`l:014B300F6A8030l8010C300B5@h05aXC01@G400201DH4@0501<F3`0B
5@h05APA01HH5@0?4@h00P0C5A800`0D5Q<0?d4n01<E4P02018D4@0901DG500F61D05ALC010B3@0C
5Pl05QPC01<E400B50l05aTF00804aDB00`06adL024S8P0H6QT051HE01LL600K81`09b`X02H[9`0H
7AT04aPD01/P700I7QX201`Q7@1W01TN6P0K81`07R@T01`R8P0I7al05b0O01lX9P0W<2d09c8^01DP
6`0I91h07R/T01<P6@0/>C80:cHb02`g=00L9RD07RXX02<_;@0^>SP0=TA4024`<00Q<C0093@c01`/
:`0M;Bd08Blb02<b=@0[>Sd0;3]002Li?@0[?D40:ca302Pk@P0hBe80:ci502@h?`0^@TT0<D==02i0
C00]?dT0;T1:0312C00a@dd0;Cm90353C@0bA4h0=dUC02m1B`0bA4h0?E5H03A8C`0hCE80<TE:03A6
BP0_@D<0;chn030l?00Y=C<09C4_02La<00V;bh07bLT028[9P0I8ah0:3<]02Pd<00O;2T0:3Pg02Dd
=`0X>T00<TA>02`nBP0]?DL09C8j028_=`0^?DD0<45902m0BP0a@dh09c]603Q;F@0gCEX09C]902]2
D00[?TT0:SU003=2B@0_?TD0;Se402Pg?P0`?dH0:3Ln02He>P0V=3X0:CHl02/h?P0/>T00:CPo02Xi
@00`?dD0<3m402/h?P0202Xe>@0C02Td>00Y<cD0:S@f02Xe=`18Ee`0F6MZ02Hc=00O:BX082TV024W
900_=3006b0L01lU8@1fOgh0=Sln02@/;P0Q:bd09c4c02H`<P0201lY:P07024Y:`0O9BD08RPX01`R
8@0H71/0720O01/O7P0201dQ800;02``;`0_<c808BDT01dQ800A5A@06alN01XN7@0H71/06AdL01<G
5P0J7Ql00P0H71d05P0I7Ah06QhP01PL7`0D5a`05APM01XM8P0N8BP07B0W01LJ8@0G5Q`061LM01LF
700F5A/05aLM01XK800;31405QPM01TL8@0N8BH04QHJ00/@500H6Ah201`M8@0A01PI7@0G61`06AXN
01HG6`0L7B407b0T02HW:`2SY:P0o_oo07AdMP0A4A<05ADG01PH6P0>3Q007alQ00l?4@0A4A<00P0G
5aT02@0A4A<04A4A020O7P1FEE<0;bh/014@3P0=30X05A@B018A3`0201<B4005014@3P0B4@l04a8>
018A300A40`00P0@3`/02P0?3P`03Pd;00l>300?3@h03@/<01@B4`0610D07a`L01<?3P0A3@`200l;
2P<04@d<01d0510?014=300=2@P03PX9018>3@0E4A003PX9014=300C3`h03`/<01<>4@080`L050lC
00d83@0A31804PdC00l:3@0=1`L030H600l92@0=1`L03`T9014;2`0@2PX05@l?00d71`0D3Ph03PP8
00l71`05014720H03`D61P0@1PD0500;0@002P0000l5100D2PT01`0001071P0<0P<02`4201D;300=
0`@0308300d3100I3a00308301061`0H3Pl03P@501882@0?0`D040@60P0C1`T02P0A1@L03`<500h2
100E2``050P:01P<3P0F2P`0200001032P0?0PT200h1200800l22@0@0`X04PD<00/01@0D1`h07A0G
01/A5@0C1PdDooooo`006oooool0400N7Qh02@T901XJ6P0H61P030`;00X:20051@<02`/8010A300E
5Q402``7018C3@0A4@l02`/900P81P0;2`T2010@3P0;01HF500:2PP04Q8@00l?3@0B4Q00410>00h>
300D51801@D300h>300F5Q@00P0B4Q004P0=3@/03`l=018B400<30X01`L500d>2@0;30H03a0:00`=
1`0:2`D03Pl901lP6P0I6Q@030d700d>200?40X01`P200h?2P803a0;00/03@h900h?2P0?40/05aPC
014B3@0=3PT030d800h?2P0?40`03Ph<00d=2`0200`<2P0400d=2`0?3`d04A4?010@3P<03Ph<00@0
3@d:00`=200=3PT03a0;0P0@4@`07P0A4Pd02P/600X;1P0>3`X01`P300X;1P0C51003Ph<00`<2P0?
3`d04a<A018B400?3`d0410>018B400>3P`02PX800d=2`0A4Ph0004000/<1`0<3@P0414<01<D3`0>
3`X0Q8F005MHD`051P407QlJ00l@2`802``601L030d700d>2@0>3`X0414<00`<2P0=3@/0410>00l?
3`0=3@d02`/;00h>300=3PT02``700X;1P0;30L03Pl:014B3@082@@02``700l@2`0:2`H03Pl:00d<
200200`;1`803Pd900<02`X600l>2P0?3PX00P0@3`/03P0?3PX03@`800P81P0;2`T02@T701dM6`06
1`<02P/600`=1`0=3PP02``600P90@0;30@04A8:1P0=30P02`0>3@T03`h:00l>2P0<2`L03@`801<B
3P0A40/030/600l>2@0B4@`04A0;00<03Pd80P0=30L200`;1P0Q00/<1`092PD02@X500`=200=30P0
30d800d=2@0=30P0414<00d>2@0;30L04A8=014B300H6A<04A8<00X;1P0J6aD01`P202DV800@4@/0
6Q/E00`=1`0C50h010D000h=1@0A3PL03@X300d<1`0?3PT02P/500`=200G6A@020T7008051HC0180
414=018A3@0>3@T05A@@00`;1`061@404A0<01@C3`0@3`/02PT501<B3P0?3PX02`X7014@300@3`/0
3Pd900`;1`0;2PH200d<200B014@300=30P05A@@00L60P0C4Pl020P601<C4@0:2PP00P80018A3`0>
3P`02PX800P71@0<30X03`l=01@D4P0>3@/03`h<0P0@3`d200l>300300d<2P0>3@/03`h<00803@`:
00d03`h<00d=3@0B4Q80410@00`<300?3`l02`/;00D51@0=3@d051@D00h>3P0;2`/03`l?00<040h?
00T03`d>00h<3@0>30d03@/<01@B4`0L6Q/05aDF010>3`0=2``01P0;2@`201HD5`0=01@B5@0B41<0
3`d@00d;3P051@L0410B00T92`0:2P`071`N08Z:S00S8bD05ADG00l?4@0201@D5P0I00`<3P0<2a00
3PdB00d<4@0@3a@05A@I014@5@0=31403`hC01DD6@0D4aP03`hC010A5@0I7R802Q4D00D:3@1WK6l0
3a<D01HJ6`0?4a@01PP700`>3@0;3@`02`/;01<C4`0400l?3`0500d=3@0<30`06ATI00l?3`0<30`0
0P0=3@d0200<30`040lD02h^<00Z:R`03@d>010@400A4@l03a0;0P0;30H03`0?40P0414900l@200G
61<05AHA00`=200G61<05QLB00L8100E5Q404A8=00`=200C50l04A8=018C3002010A2@0R010A2P0@
4@/0414;00l@2`0C50l04Q8@00h>300D51805ADC014B30082P004Q<;00h?1`0<3@D061/D018E3P0C
5Pl05AXD00lD3P0A5Q004aXC00/>200K6QD06QTD018A300F5A0010<001TH4`0=30L061LB00P70P0F
5A004a<=018C3@804QD>0P0?4P/03@0A50d08RDN01LJ4`0I71D061/D01/N5`0F6A804A<@01DG500D
5Q<04Q@A02DW901FF5D00P0@4Pl01`0C5A805ALD01HH5@0H6QH04A<>01<F3`0F61<00P0E5a800`0G
6AH061XG01PJ5`0201LI60806A/J04H07R<O01dR7P0J7a/061dI01HK5`0D6AD061dI01TN6P0F6aL0
51TE01HK5`0I7QX09B/[01TO7`0P9RH02Q<B01lX9P0G81d07BPT01dX8`0I91h05B8K01TV7`0P;BH0
7bXT01hY900O:RH082`X02Da;P0Y=C<0?Ta<02<b<P0R<S809CDe01d];@0O;bl08Blb01h]<00Q<3<0
:3Ll02Hh?00T=SX0;3e402e0A`0dAdh0:ci502a0A`0[?dH0?E1G03a>F00Z?D@0?E1G0=;Uk01JKG@0
;T1:0312C00oDE/0<D==03I8DP0/?TP0<dM=03M:D01NLGD0:C/o03Y9C00_?cl0;3Xk03A0@00Z=S@0
82/X0P0R:bP0>`0a>SL0:34^01hX900L9b408RlX02Ld<@0O;bh08C0c02Tk@@0X>D<09CI002dlAP0X
=Ch0<3i702`jA00W>480=4AA02m1CP0]@4h0?e9Q03=9F00^AED0>U5Q02PkAP0d@DL0>DI<02hl@P0[
>Sl0;ci5030oAP15E5/0NHR?0350A`0^?D@0:SU002Pg?P0/>d80;Ca302hm@`0b@DH0;S]102Lb=P0Y
=3P0;cXn02hh>P0Y<cD0;3Li04QEF`10Ce80:CHh02<];P0]=S<09B/X02H[9`0R9b<08RPT024Z:@0O
:2L08R`]00807BLX00/07RHX01dU9`0Q:B/0;C<c01`R8P0M8b<082@S01lS8P0N8al07B8N020T8`02
024U900301/O7P0H71/05QXI00<06alN01@06QhM01TM700G6aX09BTZ04A8B@0F6Q/0720Q01hR900N
8RD06ahS01HI7P0D5a`05QTP01DH7`0B5A`05QDM01LF7P0J6B407A`T01dM9@806QXR01L04a@L01@G
7P0M82L08RH]01hS9`0J6b0061TN01DF6`0D5AX05QLL01PI7P0K72406Q/P01LH7@0H6Ah0Jfaa0<O8
c014A4H04Q8D01LG6@0K6ad04Q8D01LG6@0201@D5P804a<E00P04Q8D018B4P0e<c<0dm;@03/j>00A
40h05QDC01<B40D040l=01@040l;01<B3@0<2`L04Q4=014@300D4a403Pd;00l>300;2@X06ALH00l=
3P0F51D05A8B00l;2P0A3@`03`/:014=300E4A003PX901@@3`<04@d<00X03PX901DA3`0C3``04@d:
010<2P0@30/04@d<01<?3`0B3Pl04@`@0P0@2`l04`0A310040X=00l92@0=1`L03`T901D?3`0F4100
6A<C00X4100<1PH050h>00h8200B30`04@T:01061`0B20T050X;01D;300G3@h00P0B20T04@0A1`P0
3P@500l51P0C2@X03`D401<9200E2`X03P@300`20@0A1`H01`0000`20@0H3Pd02P0000/1000?1@@0
2`4200804@L800T03P@501<92P0A1`P03`D600h41@0?1@H03P@500`20`0@1PL01P0@10H0300A1@L0
40@600l31@0?0`D040@601451`0:00@03@4701442`0B1@`040<:00/01@H040<:5?ooool001_ooooo
00P04A4A018B4P0;2`/03`l?00h>3@0F5Q@06ATG00d=2P80414<01404a@?00P90`0B4Q002PX801DE
4`0V9R@08B4O00P81`0B4Q0030`:018B400:2PP03`l=00h>300M7A/030`;00h>300201<C4@0H00l?
3@0B4Q003Ph<00d=2`0>3P`0410>014B3@0=3PT03a0:00`=1`0>3`T03a0:00`=1`0C50h04Q<=00/<
1P0?40X04A8<00T:100=3PT03a0;00h?2P0<3@P03@h90P0>3`X200d>2@8030d800T0414=01<C4@0A
4@l03`l=00d=2`0<30X03`l=010@3P0?3`d00`0>3P`0100=3PX030d800d>2@0?40/3010A300700T:
1@0:2`H061TD01DF4@0@4@`04A4>00l?3@0300h>30803`l=01h03@d;00`<2P0?3`d04A4?00h>300;
2`P0414<018C3P0;30L030d8010A300A4Pd0414>00d>2@0O81/04a@?00`=2@0=3@L030d600d=1`0>
3PT03`l:014A300=30T03Pd:010?3@0@3`h03Pd<00`;2P0=3@/500d>2@0800/<1`061`@05AHA00<4
000C50l051D@01LF4P0B4@d200d<2003018A3@0C4Ph040l;008051<?00`04A0<00d<200=30P05ADC
00/;2P0;2`T02`/:0492?`0G61D03a0:010A2`0>3`T200`=1@0300l@200=30P03@`800@03@`800@0
3`h:00`;1`0;2PH03@`80P0?3PX00`0=30L030/600l>2@02018A300300l>2@0>3@P03Pd800803@`7
0P0<2`H0A`0=3PT02``700/<1`0@3PX04@h;010=2P0?30P03`d9014@300>3`X03@l:018D3`0F5a40
4a@>02@U7`0A4P`02``6010A2`0B4`d0<c@^01LH4P0<3@L02``601<D3P0@3@D04@h700h;100?3@L0
3`h900`;1P0<3@P051D@00h?2`0>40`01PP4010A3@0@3`/030/701HE4@0C4Ph04Q4=01TH500>3@T0
3`h:01HE4@0@3`/03Pd9010?2`0>3@T03@`800h=2@0?3PX040l;00l>2P0<2`L040l;00`;1`0F5A40
3Pd9018A3`0I6QP02`/900l>300F51801@81018?3@0?30/04Pl>01<B400=3@/03Pl=00803Pd;0`0?
3P`0400>3@/030/900d<2P0>3@/030/900/:200>3@/04A4A010@400:2PX02`/;014A4@0?3`l02`/;
00`<300=3@d200`<300500l?3`0@3Pl040h?010>3`0?3@h00`0>30d01@0D4Q<061HG01@B4`0?3@h0
3P`=00H03`d@00<03P`?00l=400@3Q400P0?3A004`0>30l030`>00l?4@0>3Q006ATK00D51`0F5QP0
3Ph@00/;3@0=3@l04A4C018B500=3@l02`X?00d<4@0<2a003@`A014@5@0;2Pl00P0@3a@0400E51T0
4a8G010?500C51P04ADJ00`@500?4QD0Ada?01<E5`0?4A<030l@01LH5`0U9RD0820P00h=3@0;2PX4
00l?3`0600d=3@0<30`05ADE014A4@0?3`l03Ph>0P0?3`l01`0C4a@06a/L01PH6@0?3`l04Q8@00/;
2@0>3PX00P0E5Q40A00@4@/03a0:014B300=3PX03Pl;010@3@092PH08B8N02LW900U9B80;BhZ010@
3@092@H04Q8?018D3P0@50/04A<;014C300A4`d04Q<=010A300A4Pd04A0>00h>300B4@l0518@018B
3@0I6Q<0:b`U01hO600:2`@04Q@>014D3P0A4`d041D@00hC3P0E6QD06B0J01TL5`0D50l061PC018B
3@0O7aX04A4<01@D3`0F5Q404Q8=00T91P0J6QD03Pl:01<E3`0D5Q0061/E01`O6@0J7AL051LA01HI
4`0A50h05aXD010C3@0B50h051LA014C400C5A805QPE01DG500G6AH07b4N0`0E5a@201HH5@0601HH
500A5@l051PA01HJ500E61<04aHA0P0B5Q803P0E61D05aXI01DH5`0G6QT071lN01LL600F6aL051TE
01DJ5P0F6aL05a`H01PM6@0K81`06QlK0P0I7QX0I`0K81`04ALE01hT8`0Z<2l0D5UG01/T8P0R:bP0
51lK01`W8`0G8Qd05R<M01h[9@0M:B@08B`V020[9P0N:BD07BTV01l[:@0Q;B`09cDf020_<00S<S@0
9cHh02Dd>00T<cL08c4d01l^<@0P;c809SDj02do@`0bA4P0:S]202e0A`0cATd0:Ca302e1B00^@TT0
;T5802Xl@`0^@4L0;Cm603mAF@1AHf/0@E=L02XlAP0fB580;Sm903I7DP0eAe40=dY?04ULH01GJfd0
=4I80351@@0_?ch0;3Th02Xe<`0[=c<09c4^028[9`0T;BT09Bh/02@^;00Q;2P082/V028^:@0U<Rl0
9C<c02/i>P0fA4/0<T9:02hkA`0Y=d<0:3M302hmB@0a@Td0=DMD03A6D`0]@4h0<DAC03Q>G00aAeH0
;TAE03A:G00b@dh0=415030m@P0[>Ch0;C]002Th?P0Z>Cl0Q9>J0=?RiP1@H6L0830h02Ph@00/?4<0
;ci502hmA00]?480<3m402hk@@0`>cl00P0/=c/03P0`>S`0;3Hh02Pb=00W=3X09S@g02<]<00Z<S@0
<S/h02X`;@0V:bL08BLS028Y9@0R:bX07bTX0P0R;2d03`0S;2h09Bd_02P_<00Y<340:c4a01hS8`0N
8b807b<R01lR7`0L81`06ahK01LK6P0K7al082@T01lS8`0201hR8P0?01/O7`0L82007B4Q01dQ8@0K
7al06AdM01@H6@0R9RL05a/L01TM7P0H71h07b<V01dP9@0J7B8061/P00806A`S01h05QTP01PG7`0I
62007QdU024P:00O7bL06a/S01dM9@0I6R805QTP01LJ8@0G6b805AXP01`M8P0J6b005aPM01HG700G
61d061TN024R9`0A4QL07AhS01PI7P0P8BH0:2T]020O8`0:2P`04A4C01XJ700E5AL301@D5P804a<E
00P04Q8D018B4P0@3Ph0;B`Z010?3@0D4a4030/901@C4@D04a8@03<04a8>028Q700C4Ph04a8>00h=
2@0D4a404A0>018A3`0E4a@030X;01<A4P091`P04@h>00d9200D40l04`l>00l;2P0E4A006ADD02@P
7`0K5aH04`l>00l;2P0<20L04`l=018>2`0A3@X04@d;010<2P0@30/04@d<014=3@0@2`h03`X=00h:
300?2Ph040/<01LA4@090`<050h>00d8200S7Ad0DTa<01<=3@0<1PH04@/;00l92@0A2`/03`L80147
200B20T00P0C2@X05P0D2P/040H701882@0C2@X04@L801061`0B20T03`D401<9200D2PT040H500l5
100C2@P05@/:00T0000J40l05@/:00/30P0L4Q404@L801061`0?1@H200h41@0400d3100>10D03`D6
01061`803P@500<04@L801041P0@10H0100@10H02`0A1@L040@600l31@0?0`D040@601451`0C1Pd0
3`8900d01`0?0PT04@@;00L040<:5?ooool001_ooooo024010@400L71`0E5AD08B4Q00L71P0j>SP0
VYZH02@U8@0G61<030d800L8100D5@l02`/9020P7P0N7Q`02PX800<30P0C4a404Q8@00H6100820H0
2@T7014A3`0=3@/0X:2N02@T8P0>3P`02PX800l?3@0A4@l02PX801@D4P0F5Q@00P0B4Q001P0D5A00
414;01@E3`0;30H0414;01DF40802``600P03Pl900`=1`0@4@/0414;00/<1P0>3`X0414<00l@2`80
3Pl:00@0414<00h?2P0=3PT03@h90P0<3@P01P0=3@X03@d;00`<2P0<30X03@d;00h>30803`l=00L0
3Ph<00d=2`0>3P`03Ph<00h>2`0=3PT03Pl:00@03a0;00`02P/600`=200I6QD05aPC014B3@0?3``0
4A4?018B400>3P`02PX800d=2`0@40h200h>300A018B400C4a40410>00/<200B4`h03a0;01XK5P0=
3PT010D200/<1`0E5Q405aPC00H70P0<3@P03a0;00d<1`0=3@D00P0=30L0100>3@P040l;00h=2@0>
3@T200l>300400h=2`0=2`/030d800d>2@80414<01L03a0;00d>2@041@0061TD00`=2P0;30L04a@?
04E6@@0N7AT06APD010?2`0=30P03`h:010?2`0?3PX05QDA01LF4P0B4@d03Pd900l>2P0G5aD03Ph<
00410002014A3`04000100092P@02``600`=1`802``400<02P/300d<200=30P0100=30P2010?2`0:
00d<200>3@T04A0<00d<200=30L02PT401PG4P0/:bH09RDP00@300803Pd80P0=30L0<P0<2`H02``6
00d>2@0:2`H02``7014=2P0B3@X04@`901<>2`0B3P/040l;00`<200:30L030h901PI4`0U9R0061TC
00h?2@0?40X01@H000X;1@0M7QP030d701<D3P0;30H02PX2010=1@0@3@H03``5010=1P0>3@P03@`7
00h=200<3@P02``703dn>@0Q8ah03@d9010?2`0:2@D03`h:00h=2@0=30P04a8>00P70`0920@05QDA
01DD400@3`/03Pd90P0<2`L05`0>3@T03`h:014@300E51003@`800/:1P0B4@d081lK00X91@0B4`l0
0P@10000000F51806ADD01LA4@0C3@d04P`<00`81`0920H051@B038d<@0<2`T03@`:00803Pd;0P0=
30X00`0<2`T03@`:00h=2`0200`;2@0=00h=2`15ADD0=3@d01HF5P0;2`/03`l?014A4@0?3`l03@d=
00/;2`0>3Ph03`l?00d=3@03010>3`0900l=3P0>30d03P`=00h<3@0@3Pl04@l@00d;300:20T030X;
00L03P`?00<040hA018@4`0B41<00P0B41<00`0820X03Ph@00H6200200l?4@0K01DE5`0>3Q00410B
00l?4@0=3@l030`>00/;3@0B4AH051<H014@5@0B4AH04a8G00/:3`0@3a@03`hC014@5@0@3a@03`hC
01DD6@0720d041<G00P<3`041PX02@X<00`=3`0C4aD03@d=00804@l@00<03`d>018@4@0?3`l00`0?
3`l04`0=3@d030`<00h>3P0C4a<04Q8B00l?3`0@41004Q8B00h>3@0;2`/03Ph<01HF5@0M7A/04A4?
00l?3@0F5Q@05QLB014A3P0?3`d00P0@40h05`0;2`T061PF010@3P0A4@l08R8P02LW9@0N7Q`06a/I
01hN700B4Q004A<=00lE2`0A50/04A@<014D3@0B4`d04a@>01<D3`0C4Q004Q4?01@C4@0G4a804Q4>
00802``602D04Q<=01LH4`0F61<03Q0;00d?300?51004ADC00/?3P0`=S@0FeiL01/M600H61H06AXF
01`N6@0K6aT04A8>01DG4P0=3P/0410>02PZ9@0F5a<051HC01<E400H6QH08B<P020R7@0G6AD05QPE
018D3`0H6QH04aDB01HH4`0I6aP05QPE01@F4`0A4a004Q@A00804aDB1@0B5140100B51004aPB01@I
4P0E6Q@201<H4P0401HK5`0M8Qh06b0L01TM708061`K00T05a/J01PM6@0G71P05Q/G01LL600J7a/0
7B8N01HK5`0K81`00P0L8Ad201/P701M01HL600R:2@0=C/g06igM00R:bP03QLD01dX900L9b<08B`X
024]:`0P;2X09C4]020[9`0P:bH082/W020/:P0R;Rd092la01h/;@0U<cH08c8g028a=P0U=3/08C0g
02Le>@0T<cH08C0c024`=@0Y>cl0<49604MHG`0/?dH0:Ca302`oAP0^@TT08SLl02m1A@0iBU40:S]2
02m0A`0a@TX0RY^S061aN@0^?dT0;3e704=DGP0lC5T0:CY403E9C00bATL07S8a02m2@@0eAD@0<T4n
030l>@0X<bl0;cXd02L`:`0K9Ad08BXU02</;00S;Bh08R`[020[9`0O:bT08Rh/02Lc<`0]>ch0=T=:
03A1BP0`?4P0;Ce;03A7EP0[?Td0;3i>03Y=G00dAeH0;D1?03I9F00kDEl0?E9R03I;G00aA5D0>DUD
03M2AP0/>Sd0:cPm02ll@P0/>d00;Ca202Th?`0mCUD0:3U10080=4E=0280:CU002`k@P0]?4<0;ci4
03=2A`0`?D<0;cXn02/f>P0/=c/0<S`n030j?00_>C/0:SDk02/f>P0T;S407bLY028[:00P9R<09B/W
028X900R:bH08R`[01l[:@0Q;Bd07RPY020X:P0T;2h0:S0`02L];@0O9BD06QhM01/O7P0M8Qh0828O
0P0Q8b00200L81l082@U02DY:P0T:2T08BDV01lS900J7Ql07B4R0P0P92D02`0M8B806QhO01dQ8P0L
824082@U01XN7`0M8B<0720S01/N8`0I72405aXO00<05aXQ00l06QTQ01PG7`0G5Qh06APP01PH800E
5Ad05QHN01PJ8@0G6R405APO01DI7`0H7B<07AdU01/L8@0I6Ql00`0G61d0300b<cP061TN014B5`07
20d08R<X01HG700C4aH05ADG01LG6@0M7Al06QXL01<C5@8051@F0P0C4aD0200B4Q@04Q8B01XH600G
5Q@071/I00l>300>3@/03`h<1@0D4a401P0D4`l03@`800`;1`0C4Ph040l;01<B40803`h<00T05Q@E
00`:2`15@d@06ALH01TF5P0@30/04`l>01@@3`0@30/00P0E4A001`0L61L05Q8A010<2`0>2PT02`L6
018>300@30T00P0B3P/01@0@30T03`/:00l;2P0@30/03`/<00803PX;00D03PT=00d8200M5aL04@/;
00/51@0200@0000702<M7@0@2PX03@L700l92@0@2PX05@l?01<;2`050147200400h41@0A1`P050X;
01882@8040H701<03`D401471P0C2@P04PP701471P0E2`X03@<201/A4017?C`0:AlN00/1000l<S40
4`T:00d3100?1@H04`T:01061`0D2P/02`4200803P@500<0308300l51P0A1`P01P0@10H0300A1@L0
40@600l31@0?0`D040@601451`0B1@`040<:01442`0B1@`040<:00/01@H040<:5?ooool001_ooooo
00P051@D01HF5P0=3@d03Ph>01HF5@1hN7H0g]kL03Hg<`8030d802L03@h900/<1P0820H05QHD01hN
700I6AL03`l=00X:200<30X05aLE01`L6P0<30X04A4?010@3P0/;2X020P601DE4`0>3P`030`:01<C
4@0?3`d03Ph<00`<2P0A4@l09BDS038c;P0N7aP07b0H018C2`0A4PX04Q<;00L8000=3PH03a0800h?
1`0A4PX03a0800X;1@0@4@`00P0A4Pd02@0?40/0414<014B3@0E5Q40414<00d>2@0<3@P03Pl:00h?
2`0300`<2P0400d=2`0>3P`03`l=00h>30803@d;0P0>3P`00`0>3P/03@h900h?2P0200l@2`0<00h?
2P0=3PT030d800h?2P0B4`h03Pl:00d>2@0@40d04Q8@01<C4@0?3`d030`:0`0>3P`05P0A4@l0410>
00d=2`0>3P`05ADB01TJ5@0;30L03@h9018C3P1LGEP04Q<>00/<1`0?40/02@X500`=200=3PP03Pd8
00h>1P0=3@D03@`700h=200@3`X300l>2P803Pd;00<03@`:00`=200=3PT00P0@4@`02`0?40/03@h9
04E6@@25QX405aPC00@500082@@03Pl:01LF4P0D4`l040l;00803`h:00P03Pd900X91@0@3`/04Q4=
010?2`0>3@T03`h:00L71@803@d;00H07QhL00X;200M7QT020T300T:100;30H200d>1P0300`=1@0=
30P03@`800D03@`800/04a8>00h=2@0<2`L03`h:00`;1`0@3`X020L300D4000A40/06APC00X91002
00h=20803@`700`030/600/<1P0;30L02@X500X;1P0?2`P04@`9018:200B2`T04Ph;00h=2@0<30L2
00/=200801PI4`0[;2H0414;00/<1P0C50h01`P200l@2P000@02014B300@018C3@071`004@h6014=
100B3PD04@h7010=1P0A3PL03`h900`=1`0;30L0?Chi024R7@0=3@P04A0<00X91@802`X600T020L3
00l>2P0<2`L02PT5014@300N7AT05aHB00/:1P0>3@T00P0=30P00`0>3@T03`h:01<B3P02010?2`0A
014@300O7QX040l;010A3@072@H0:RXX04I4@P0B3Pd0100001482@0@2PX04Ph=014@3P0>3P`06A/H
00`;2@0=30X00P0>3@/200d<2P0300h=2`0?3P`040l=00803Pd;00H040l=03@d=00U9BD03`l?00/;
2`0?3`l2010@40803Ph>0P0C4a<01@0<30`040h?010>3`0@3Pl03`d>00803P`=0P0@3Pl0100?3@h0
30X;00`:2`0>30d600h<3`0;00l=400@3Q4040hA010>4@0?3A003@/>00410`0?3a402`/=00h>400?
3a400P0;2`d01`0=3@l030`>00`<3P0@41805QHH014@5@0D4aP00`0A41D03`0920d03PdB00d<4@0?
3Q<03PdB00`;400C4QL01`P=00`=4@0F5a/06a/O01XJ70051@L03`d@014?400201PD5@0300l;300:
20T03`l?00<03`l?00<03@d=00`<300<30`00P0B4Q803`0@41004A4A01@D50092PH030`:00l@2`0E
5A<071`J014A3`0B4Q00410>00l?3@0A4A004A4A014A3`0200h>300:01@D4P0?3`d00P8001DE500g
=cD09RHT02DU8`0F5Q@00P8001@F40803A<902d03Q<:00lB2`0@4@/04A8<010A300@3`d04@l=014=
300B3Pd04Q4>01PI500I6QD05QLB01<C4@0C5A805aTF010B4@0;3`h03a<C01/O801eNg/0fn3O04eB
CP0A4a804QHC01dR7P0I6aX03Q8?00P=2@0D61D03Q0?00X?2`0=3P`05ALF018D4@0C5A<06Q`K01`N
6`0F61H06A/J010B3`0D5Q@05ALF01TK600G6AL00P0E5a@0100C5A804Q@A01HH5@0O8Ah2010B3`0=
014C400B51404aDB01@F4P0K81X06QlH01DJ500A5Q004QLA01PM6@0Q9R806b0L01HJ6@0201/O7P03
01@H5`0K81`06QlK00806AhJ00D06b0L01`Q7@0D6AD06AhJ01`Q7@0201/P700G01`Q7@0O9Ql0:S4Z
02T`:@0W<2/06b@O02D^:`0K9R8082XY04E?CP15DE408bl_01dY:@0Q;2P08B`Y024[:P0Q;Bd092l`
02@_<@0S<C@09cDj024`=`0O;SD00P0S<CX0I@0W=CT0:3Lj02Lf>@0V=CX0:C/o02i0A00oD5L0<4=:
02i1B00`@dX0=DU@02a1AP0_@D@0;3i202Li?@0eAd/0<T=:04AEG00dADd0=dQB028c?@0b@dd0<T9?
03=4CP0bADP0?4i@02Xl?00a@D00<d5102Pg=00/>3D0:C@`030k=@0U;RP072<L02</9`0Z<cD09Bla
024[;00O:BP07RPY02@_;`0]>3X0<Se103E0A`0g@D/0=T1<0311C`0cB5T0;D9C0355EP0fBe`0<4EF
02m3D`0fBEP0>diM03e@G`0fBEP0<T=C03U7D@0c?T00:cHj02Hb=P0W=CP0;3To03=1B00U=3/0>DYB
03A5CP0Q<cd09cU302Xj@P0/>d80;ci50391A`0d@dP0;S]102Xe>@0Y=3P0;3Lk02`f>00Y<cD0;SPj
020[<@0U<3@09Bha01hV:00P9R@09BTW02@Z9P0R:2@08R/V02<];00O:bT08Bd]024[:P0T;B`0;38b
02hd=00Y;bl08RHU00807B4P00T0828O024S7P0R91l092HR01hR8@0Q9BH092PY024U9P0N8R<00P0L
82402`0N8R<082@U01lS900M8B806QhO01hR8`0M8B8061`M018F5`0L828041@G00806A`Q00H061/P
01LJ8@0H6b806A`S028P:`0L6RD201HD7`0;01PG8@0G5b4051@N01TK900I72D05QTR01LK900K82H0
71`T01/K8`0I6B400P0H62003@0G5al05QHN01HF7P0R8RX09RH^059BFP1;C5404a<F01PH6P0E5AL0
5aLI01HF600@41800P0D51H201<C5@08018B500B4Q805aDE014@3P0>3@/04a8@01LF50030P05018A
3`0D018A3@0F5A0051<?01PG4`0A40`040l=00`;2@0A40h05Q@E00/92P10?Sl0518C020M7@0E4A00
3`/:01<?3P0D40l05A4@00h:2@0B3Pd2010<2`0;00l;2P0;1`H04@d;010=200A3PT04Ph:010<2@0>
2PL03`/9014=300@30d00`0?2``03P0:1PH02`D501H@400F41007aTI01hH600;1@D02@<300l92@0=
1`L02@<3014;2`0B2P/04PP90P0A1`P201061`0400h41@0A1`P050X;01882@8040H700<040H50147
1P0B20L00P0B20L02@0D2PT03P@300d30P0P5QD04`T800L0000@1PD03`D600d3100200l51P0600d3
100@1PL04`T:01L=3P0D2P/03@<40P0@1PL601041P0:01451`0@10H03`<500l31@0@10H04@D700h1
200=00L03P4801032P804`H=1P0@0`XDooooo`006oooool0<@0e=CD0:2PX00/;2`0@41004a<B00h>
300X:2H04Q<?00l@2`0>3`X051D@00/<200C4a40410>00X:2@092@L03@d;010@3P071`D0:BTW038b
<00A4@l0410>014A3`0F5Q@020P700/;2@0@40h04A4?010@3P0>3P`04A4?010@3P0=3@/03`l=01<D
3`0>3`P03a0800d>1P0@4@T04A8:00h?1`0A4PX03a08010A2@0A4PX03Pl700`=1@0?40/00P0@4@`0
300>3`X03a0;010A300E5Q40414<00d>2@0<3@P03Pl:014A3P0A4@l0410>00l?3@<03Ph<0`0=3@/2
00h>300400h?2`0>3`X03Pl:00l@2`803Pl:00P030d800d>2@0=3PT03Pl:00d>2@0>3`X0410=010@
3P<03`l=0P0@40h200l?3@0@00`<2P0820H02`/900l?30092PD0414<01<D3`0>3``04a@@00L8100H
6A@04a@?00T:1@0>3`X0414;00l>2@803`h600L03P`600l=1`0@3PT04@h;010>2P0@3@X03``;0080
3P`:1P0=3PT02@0I6QD0;c0[00X;200C50l04Q<>00/<1`0<2`L02`X600d<2002010?2`0>00h=2@0<
2`L02PT500X91@0=30P03Pd900`;1`0=3@/03`l=014A3`0000004A8?00d>2@0@4@/200d>200300l@
200A4PX0414900H03@`800/02`X600h=2@0:2@D040l;01LF4P0:2@D01`H201dL5`0G5Q402`X500`;
1P0300h=20803@`700h030/600/<1P0<3@P02@X500/:1P0@30T04`/90189200D30X05A0=010<2@0>
3PX03a4<00d?2P803Pl902@03@h800h?2@0310003Pl900l@2P0720@05aPB00`=1`0A4P`04A49018>
1P0@30<05107014>1P0?30D04a0900d=1P0D50h03@h800`=2@041@803@d8014@300<2`L03@`800h=
2@0;2PH040l;014@300?3PX040l;01/J5P0F5A403Pd9010?2`0?3PX300d<200B00`;1`0?3PX05aHB
00/:1P0E51006APD04Q9A@0?4@h020P701TG5P0@2PX07aHG01<:2P0D2``04P`<014?3@0:2PP030h;
0P0>3@/300l>300C00h=2`0?3P`040l=014@3P0?3P`03Pd;014@3P0A4A4030`<00h>3P0D51@0410@
00/;2`0@41003`l?010@400C4a<04Q8B00d=3@03010>3`0600l=3P0>30d03P`=01<A4P0B41404@l@
0`0@3Pl6010>4@80518E00`04a4D018@4`0@3Q403P`?010@4P0;2`d020P:00X:300A4A<02@T;010@
4P0>3Q0200`<3P0700h>400A4A<05A@I01PG700F5AX05aHK01DD6@0300`;400A010?500?3Q<030/@
010?500>3Q<04a<H00`:3`0=31404@dA01<?4`0A3A403`X<010;300A30h040/<00h92`0?3Pl00`0?
3`l0600=3@d030`<00d=3@0?3`l0410@018B4P0C4a<04a<A00d>200A4P`0414<00d>200B4`l02PX7
01@D4P0>3Ph03@d>010@4@0F5QL061PI00l?3P0E5A<04A4?00`<2P803`l=03/05aLE00`<2P0A4@l0
5ADC00`<2`0A50h03A@:00hD2P0?50/041<<010B300D5@l04a<>018A3`0F4a804`l>01@?3`0D4Q00
4a@@00`=2@0F5QD06a/J00d?3@0@4Q806Q/L01<G6@0E6A/05a/M04iDE@2IWYl0;C8b00dB4@0A5QH0
3a@C010E5@0L8B0051TI01<H600F6a/0EEYI02X_;`0E5QL04aDE018C500D5AH05QLH01DG5`0M7Ql0
4aDE01LI6@0H6AX071dN01TK6`0A4a005ALD01XL6@0G6AH05QPE01XL6@0201@F4`0B01DG500F61D0
5QPE01LI5@0M8Q`06b4J01HL5@0@5Pl03aD?01@I5@0F6aL051TE01<H5`0G71/06QlN01PM700H7AT0
6AhJ0P0J7a/0100I7QX05a`H01HK5`0I7QX201/P700F01dR7P0P9Al07RDL028Y800H7aP04Q`D024Z
900H8A`082XY01/U9@0_>C/0<Cdn020[;P0R;C008R`/02<];00S;Bd08Rh_028]<00Q;340:SLm02@b
>P808c4k02T0938n02Xh@P0V=3P09cHi02Xi?00]?440;T1402m1A@0/?D@0>diE03U<D`0/?dH0<TI=
02i3B00Y>ch0:S`o0394A`0/?T80>T]B03U:D@0cA4`0>DYD04MHHP2P/;`0DF5^02/lAP0eAdX0@eEE
06]mO@0Z>ST09SDb02Th=@0S;b/09C0Z02Td;@0V<2P08bXR028[9P0[<cL08b`a024[;@02028/;P0O
02H`<P0^>C/0<3Y102dg?`0`>T@0<Sa802dnC`0/A5L0AUic05M/P00lDV<0=T]M03A8F@0_@U40=dUI
03I8E`0^?dh0=TME03I3C00`>S`0;3Lj02Xe>@0V<cH0:cPn02lmA00Y>3l0=DI>02dnA`0[?DL0>DaE
02doAP0203=2B@040350AP0`?d@0:CHl02/f>P80:C@h01P09c4c028/;P0W<C<0=d57034k?`0X<3<0
9BX]02<Y9`0R9R@092XV028X900S;BP09Bl^024]:`0P;Bd082TX02L_;P0]<c<0:Bl^02@Z:@0S9bH0
92PV02<W9@0R9242020R7@0=020R7P0L82007R8T01lS9@0M8B<0720R01dQ8`0Q9BL082@V01dQ8`0L
82806alQ01XN800201XN7`0701LK700O8b@06alQ018F6@0I72406ahS01XM8P0201PK8P0=01/N9@0M
6bH061HQ01DC7P0F51l061LQ01LG8@0I6B<071dW01/N9`0I72D061/T01PL9@0201PH800<01TI8@0H
620061PP01PH800I6B4051@L018B6P0D51`07alW01PI7P0F5AT05QHH0P0E5AL0100F5QP05aLI01@D
5P0D51H201<C5@08018B500B4Q805A<C01DD4P0>3@/04A0>01DD4P0G5Q@5014@3P05014@300G5Q40
4A0<01<B3P0<2`L00P0D4a400`0?3P`05Q@E00d;300201HD5@0302`Y:@0F4Q4030P700804`l>00<0
510?00d9200D40l00P0B3Pd00`0@30/030P7014=2P02010=200F010<200?2`P03`/8010<2P0A3@`0
40`<00l;2`0>2P/03`/<01@?3`080P8040X:014;2`0:10@05@l?00l92@0@2PX06Q@D01@>3P0<1PH0
4P`<018:2PD04PP900L040H701882@0C2@X04@L801061`0B20T04@L6008040H50P0A1`H0200@1PD0
5`d<01061@0?1@@030<301<9200D2PT040H70P0M4a@02@0>10D03`D600l51P0G3@h07A<D01L=3P0>
10D04@L800l51P0601041P0701451`0@10H03`<500l31@0@10H04@D700`01P020185300300l22@0D
1`h07a8I00H040<:5?ooool001_ooooo00`06ATI01LG5`0K6a/03`l?00T9200;2`T061PF00`=2@0:
2`H05QLB010A300?40/200X:200@00`<2P0>3P`03@d;00T91`0D51803Ph<00d=2`0A4@l05ADC00H6
100:2PP06QXH00P81P092@L06QXH020P7P803`l=0P0>3P`0300@40h04a@?014B300>3`T04A8<00h?
2@0<3@L03a0:010A2`0<3@L03Pl900l@2P803@h800/030d800d=2`0=3PT02`/800`<2P0=3PT030d9
00`<2P0<3@P030d900`<2P0300/;2@0400d=2`0>3P`03`l=00h>30<030`:00@03@d;00l?3@0?3``0
3Pl:0P0?40/03P0>3`X03@h900d>2@0;30L02P/6010A300G61<04a@?00h>2`0<30X02PX800d=2`0A
4@l0410>0P0D5180@@0>3P`03@d;010@3P0?3`d02``800X;1P0A4Pd01`P301PI500C50l02P/601DF
4@0?40d04a@?00H70P092PD03`h:00l>2@0?3@P03``700d<1`0?3@P04Ph;00l>2P0?30X03`/:00d;
300?30`03Ph<00d>2@0;30L02P/600/<1`0>3`X06AXE00H70P17B4<00040010A300?40/04Q4=00l>
2P0=30P030/700/:1P0920@06APD00l>2P0<2`L04A0<01<B3P0>3@T03Pd;00h>300:2PP05aHD00d=
2P051P405aHA010@2`0;30H03@`700h>1`0<2`H03@`700D03@`800`040l;00T8100920@071/G02PW
8`0>3@T030/6018A30071P401@@000l>2@0;2PD200h=20803@`70P0<2`H08@0=3PT02``700`;1`0B
3@X05@d;01@<2P0P61H07QTF01DA3P0=3@T02``700L80`0?40X01@H000l@2P0S91h02``600h?2@0:
2`L05AH@00<4000C50h01PL100X9100A3PH040/501<@1`0A3PL03``501<@2@0=3@D06APC00P81@02
014B3@0300T91@0A40`03@`8008030/700P01`H200d<200;2PH03@`8018A3@061@402@P4014@3080
3Pd901L03@`800h=2@0?3PX03@`800T8100=30P030/701HE4@071P803Ph;010@3P061P@03``;018<
300;1@D060l@00h8200;1`H03@d;00X<2@0;3@X03@d;00l>3002010?3@803`h<00<03@`:00h=2`0?
3P`00P0=30X01`0?3P`03`l?00/;2`0@41005ADE01<C4`0G5aL00P0@4100100>3Ph030`<00`<300>
3Ph3010>3`0400l=3P0>30d03P`=00h<3@803@/<0P0>30d00`0<2P/03@/<00d;300400d;3P1A00h<
3`0?3A003`d@00h<3`0>30d030X;00@41P0?3a4061PJ00X:300;2@`03@/>00T72P0;2@`040hA01DC
5P0H5QT05aDH018@5@0E51T04a8G01@C600C4QL02PT>00/:3`0=31404a8G014@5@0=31403`hC00h=
4P0>31400P0301XH700:1@T04@`@018=4@0A3@h040`=01@>400B30h03@T:00l>3P0?3`l03`l=00l?
3P0=3@d030`:010@3`0;2`/03@d;01<C4P0C4a<04A4?018A300A40/040l:00h>2@0G5Q803Pl:018B
400E5AD04Q8B010@4P0H61X0820R018B3`051@<020T400l?300A4@l061PE03Lh<`1:BTP03a0<0001
000D5180310:00lE2`0?50d041@=00804A@=02X04aD?010A300@3`d051<A00h=2`0A3@`04a<@028S
7P0K6aT0410>00X:200:30/051HE01/M700=4A003Q8B01HJ6@0>4Q<08RLU00P>300@51<04aPF01<I
5`0E6AP0;S<a00hD4P0O92800`L601lU8`0F6QT051HE01DG5P0G6AP051HE01<E500E5aH04aDD010B
4@0F61L03a4@010B4@0D5QD201PJ5`0<01LI5P0F61L051HE01<E500F61L05QPE01DG500D5Q404aD@
014E3`0=4P/03aL<0P0C6Q803`0C6Q<051XE018H500H7QX06b4O01<I5`0D6QP07B<Q01@H5`0H71/0
720O01dQ800J7a/05adI01TN6P0201XP700N01/Q7@0O9R0092/T01TS6`0]=bl03aPC02Tb;@0G8Ad0
8bhZ01/U900N:2P05b4S01/V:00X<cL08bhb020Z;00R;2h09C0b02Lb=P0Y=CX0:3Dk034nAP0S<CT0
9cQ002Pi@`0O;c/09SM102He>@0O<C<08C<e0P0V>3`08P0U=c/0;3e402Lj@@0Y?4<0<TE<03e@E`0`
@dT0;Sm00391A00Z>C`0<D1302Th?@0W=S/0?4]B03=2B@0`?TL0MXB=02@b>`0a@4L09CDe03=1@@2l
b/X0EFAQ02Hb<00M:BD09C0[024/9P0R;2@0:38[02<Z8`0G7AT08BT]01hX:P0S;Bl202Pb<`0X02Tc
=@0b?D40=3m502di@P0_>dL0<3a:02a0D00V?e<0Dfb006AlS`0^AEL0;T=D02m3E00U>4L0?U1N04=D
HP0a@Dh0=dMD02/h?P0V<S809c<c02/f>@0S<C@08Bhd02Dc>`0gADh0CUmW03i@FP0Q<cd0<dE?0312
B@0d@dX0<3m602/j?`0_?T<0;Sa002hi?@0W<SH09C0c02`f>080:cDg00X0JgEg04aDE`0R:Rd08BHY
02T_;`0Z;Rh092XX028X9P0T;BX09Bl^0P0Q;B/05P0O:2L0:2h^02dc<`0S:BL07R@R02DY:00P92<0
7b@P020R800N81d07b4N024R8@0S9bP08bLZ024U:00M8B@0720S01lS9P0T:2/082@W01XN8@0H71l2
01TM800K01`P8@0F6Q/08RHW03Lk?00E6A/061`O01@H6`0G6al05QTN01@G700E61d06a`Q01HG700H
5ah07A`T020N:@0P7b/071`X01PH900H6R@06A`U01XM900J7B<061/P01@D700F5Qh05aLO008061PP
00d05QTP018B6P0L72@06ATQ01@E6P0<3A8051<I01HE6@0B4Q@05ADG018B500?3a405ADG008051@F
0P0C4aD2018B5006018A400J6AL040l=01/J600C4Q0030/91P0B4@l08@0A40`04a8>01TH500?3P`0
40l=00d<2P0B4@l030X;01<A4P040`<04a4B024M7@0A3@`03@T801@@3`0>2PT040`;00l;2P0F4Q40
4@d<010<2`0?2`X03@T801@@3P0A3@X03`/800d91P0>2PL03`/:010<2`0>2PT03@T800`8200200`8
2@0J00l:2P0G4A403@@500/51@0C3@d03`H701092@0<1PH05@`=01092@0=1`L050/<0107200A20T0
4PT:01<92P0C2P/050X;01882@0A20T04@L800h41@0>1@H04`T:0147200@1PD300l5100;00d30P0B
20L02`4001<9200?1@@03P@301471P0700007aDF024G600:00400P0@1PL01P0700003@<400`30`08
00004@L801882@H040@600`04@D701041P0?0`D03`<501041P0A1@T02P02020C6P0X6b806`hE00d1
1`0=00L601032QCooooo000Kooooo`0300h>300?3`d03`l=00<03`l=01800P8001HF500A4@l0410>
01DE4`0=3@/03`l=00`<2P0820H02@T700l?3@0@40h03@d;010@3P0=3@/05ADC00<30@0A4@l200h>
30803`l=00@03Ph<00d=2`0A4@l03`l=0`0>3P`02@0?3`d03a4<00`>2@0=3`X02`d800X<1`0>40/0
51HA00h@2`0200/=200h014C3P0M7A/05QDC00/92P081`D04a4A01<C4`0;2`T02`/:01PJ6@031@80
4A<A0001000>40d030h;00h@3@0=3``03a4>018D4@0D5Q<0418?00d?300;3@X030h;00/=2P0@4Pl0
2`d:00L91P0@4Pl03a4>00d?300?4@h04A<@01LI5P0H6QL02`d:00T;200=3``020X700h@3@0C5A80
1`T601DG501VJ6D02P`9010B3`092`P061XG0043000:2`L03a0:00d>200:2`D02``601LH4P0?40X2
00d>20804A8<00l030d701LG5`0000004a8B00/:200<3@P030`9018A3@020`004a<A0040000;2`d0
3`hA00d=2`0;2`T00`0=3@/03`0G5aD02`/901`L6P0I6AL0410>00h>300820L03a0;00`=200H6A@0
1PL2020Q700I6QD03@h900`=200200/<1`0C00`=200>3@T04Q4=01<@3@0C4Ph040`900P60P0;2PH0
3PX700X71@0<2`L04@d:014>2P0A40/051<>00/<1`0<3@L0414;00P90`0500X;1@0;00/<1P0=3PP0
2PT400`;1P0:2@@04A0;01TH4`0>3@P08b8M00l>2@0;2PD00P0@3`X0400<2`H03@`700/:1@0;2PD0
3`d800l<1`0=2PD08b0K01hK5P0C4Pd051<>00T80`0E50l03@`700l>2@0=30L200h=200j00/:1@0=
30L02`X500/:1@0=30L03`h9010?2P0B4@/0104000/;0`0?3PT04A0;00T80`0>3@P03`h900h=200?
3PT03Pd800`;1P0:2@D040l;00/:1P0920@051<?01<B3P0H5a<06aXF01<B3P0A40`04Q4=00l>2P0;
2PH03Pd901LF4P0@3`/02`X600h=2@0@3`/03Pd900d<200C4Ph04Q4=00`;200:20T02@L800h<3@0F
51D040h?00P61`0C4A802@T900P92@0P8R4030h=00/;2@0>3@/02`X801<B40803Pd;00H02`X8018A
3`0@3`d02@P600d<2P0@3`d200/:200@00h=2`0@3`d04Q4?01<B400E51802PT700h=2`0A40h051<A
04i=B`0@3`d03`h<010?3@0=30X02`X801<B40<040l=01L03`h<00h=2`0>3@/02@T700d=2`0>3Ph0
3Ph@00l?4P0B4AH03PdB00/;3P0>3Q003Ph>00`<2P0@40h02PX:00l>3`0A3a0040h?018>3`0D4140
5a4C01TB500201XA500901`C5P0O5Q/030L=01dK800C4AH020H;00d;400B41D0518G00804a4F00L0
3`dB00/93P0B41D02`T<00d;3P0?3@h04@lA00804Q0A02/03`d>014?400A3a00510A018>3`0<2P/0
3@h:018B40041@003a0<00X:200<3@P0410=00L71@0:2`H05ADB01DE4`0A40`03PX701HB3`0G4a00
3P/9010<2`0G5Q@040l=018A3`0C4Q004Q8B00l?3`0>3P`03Pl900l@2`0?40X03@h900h?2P0?40/0
5aPB01PI500@4@`05AH@01<D3`092`D03Q4:00802`d800d02P`701XL5`0U9b805QPC00T:1@0A4Pd0
6AXE01DF4@0B50h05QTB01PK500E61404aH?00804QD>0P0A50d03`0C5Q0051L@018D3`0A50l04AH@
00lA300K7aT0<cPb02la;00J7QP05Q/E01DH4`0A4`h03Q<=01<E400401@F4@0301HH4`0G6A@06adH
00805ALB00H061XE01LI500I6aH041DA014F4P0A5A@200hB4`09014E5P0C5aP06alN00X?2P0C6140
3Q@:01HL400D6Ph05A/?00805adC0P0G71D01P0D6A<06AhH01LL600E6AP06QhM01HJ6@@06b4Q07P0
6b4O01TR7`0D6QH072DO01`V7P0G8AT05B0G01/V800X<S@0624V02dg>@0F828072LX024]:`0M:BL0
8Bd[01DQ8@0L:2P08Rd_02Ha=@0R;3D09c4j01PU;@0X=Cd09cDm01h]=00V=ch08c@k024d>P0S=S`0
8SHl01db=`0W>cd0:Ca002@g>`0U>3`0;D1602i1A`0U>3h0:3U103m@F00jBe<0V:Va05ASJP0gADH0
:CLh02/i>P0gADH0>TQ90390@@13DE80=dE602Pf>@0Y=cX0;ce002`h>00]>3<0:S<^06I_JP15CTT0
9RlZ02</9`0R:bH08b`W02L]:@0[<Bh0:Bl[02L]:`0R:b/06b<U028[:P15Cdh0C5QF03I1@P0b@4<0
;3]002lmAP0`?T/0<D5>03E9E`0[@U80>e9R03I=G00W?T`0>DmM0315DP0V>DL0>dmJ045DH00bA4h0
<D==02Xj?@0]>CD0:3@b02Hd=00V<cT08c0h02Xh@@0`?TT0;Sm902dnB00Z>dD0<T==03I6CP0^?D80
=TE:02ln@`0[>Sd0;C/n02Td>00Z=CL0:cHg02Tc=00X<S<0:S@e02L`;@0]<c409R`/02DZ;@0N8bH2
02@Y;@0602H[;P0T:R/08b`[02Pa;P0V;bX08RPX0P0S9bP0300R9RL08BDV024U9P0^<S<08bLV01XN
7P0h?3/08bLV02<V9P0F6Qd08bLZ01XN8@80720S00X092P[01`P8`0K7b8082@W01hR9@0G6ah06alR
01XK7@0G61X0824S0P0I6Q`0:`0K71h04Q<E028S9P0H6Ad06AXN01XK7`0L7Al06Q`K01PJ6P0H6Ah0
5QHN01dM:P0^;C/05A@R01HF8`0G5al05AHK01HH600H6A/07QdR018A600X9bl07AdW04Q:D`0K7bP0
4aHO01<D700D5AX061LL01LG6@0F5QP061LL01LF6`0I61d051<H018A5P0F5AX04A0E00X93P0A41D0
5QDJ018A5P0H61X00P0E5AD01`0C4a<04Q8B01DE5@0G5aL03@d=01@D500=3@d00P0C4a<0400E5AD0
5QHD00`<2P0F5Q@04A4A00T7200A3a0040h?018>3`0D41404@d>010<3@0D41404@d>00l;300@30d2
018>3`0701<?400;1`P03@T:014=3P0F4Q<06QHG018>3P02014=300R010<2`0?2`X03`/<00h:2`0?
2``03PX;00X61`0>2P/04Ph?01D>3`0A2@L05P`;01891`0@20H060h=01<:200A2@L0718A00/20@0A
2@L07A<B00d51P0@2P`04@T<01482`0>20X03`P:00X1100:10H040T;00L00@0C3@l04@X;01472080
40H700@03`D600h41@0>10D03`D60P0=0`@00`0A1`P04PP900h41@0301061`0;00l51P0>10D03P@5
01<92P0700005@d=0147200@1PL02`8300l4200=0PH00P0?10P01@0<0@D040D900/0100=0PH040D9
00804@H:00d040D900h31`0:00<03P<701052@0A1PX04PL;00/0100<0@D02`0400h31`0@1@T02@02
01Cooooo000Kooooo`0>00l?3@0A4@l04a<A018B400?3`d03@d;01HF500=3@/0:2PV00d=2`0B4Q00
51@B00h>300?3`d3010@3P0700d=2`0<30X03`l=00X:200B4Q001@D3014A3`0200h>30803`l=00@0
3Ph<00d=2`0A4@l03`l=0`0>3P`06@0?3`d03Q0=00`>2`0?4@h0418?00h@3@0?4@h06A/H014C400F
61D02P`9014C400?3`d04a0A010>3`0A3a0030X;00/;2`0@41003@d=00T:2@0>40l02@/:01DI600;
3@/00P0A4a000`0>40d02`d:00/=2P0300`>2`0300lA3P0@4Pl03Q0=00803Q0=03<030h;00X<2@0;
3@X03Q0=00lA3P0>40d0418?014C400<3P/03a4>01TK600A4a002P`900lA3P0A4a003Q0=01DG5008
2PL03@l=014C400:30T051HC00h?300:2`D0414<00X;1P0<3@P04Q<=00d>2@0<3@P03Pl9018C3@0C
50h0414<00T92`0D4aP051@E010@400<30X051D@014B3@051P403@d;0410@P0@418051@G010@400>
3P`03`l=00d=2`0:2PP00P0@40h02`0F5Q@0410>00L71@0A4@l03`l=01DF4@0720<04Q<>00T:1@0Z
:bH0>c`g00803@h90P0<3@P200d>2@0E00`;1`0>30P04a4=01<@3@0A3P/05Q<@00`:1`0@3P/04@l;
00l=2@0=2`L02`X600T:100M7QP02P/800h?300@4@`0LgA^01`M5`0B4`d03a0:00805QLA00X030d7
00h=200=30L03Pd800l>2@0=30L02`X500h=200920<02PT40P0?3PT200d<1`06010?2P0?3PT040l:
01TH4`0P7aX03@`70P0?3PT0200=30L03Pd800l>2@0@3`X03`h900X91@0=30L040l:0P0?3PT00`0=
30L030/600d<1`0200h=200Q00l>2P0;2PD03Pd800/:1@0?3PT04A0;00h=200?3PT030/600/:1@0=
30L03Pd801<B3P0T8al07ahJ00d<200;2PH02@P501@C3`0F5A4040l;00h=2@0?3PX03@`800T8100;
2PH04Q4=00l>2P0<2`L03@`800l>2P0<2`L02PT500803Pd901P02`T7010<3@0>30d03`d>01@B4`0@
41003Ph>01`L701/KVd0?T0o02HX9`0C5QD0410>014@3P0>3@/04Q4?01<B400A40h02`X800l>300>
3@/030/900l>300>3@/600d<2P0<00l>300>3@/03@`:00`;2@0A40h07QdK01DD4P0?3P`04Q4?01/J
600G5Q@030/90P0B4@l2014@3P8040l=00l03Pl:018B3`0B4Q00410B00d<400;2Pl03PdB00`;3`0@
41004A4A00d>2P0@4@`04A4A00h>3P0?3Pl00P0E4Q<04`0C3Q0071LH028K7@0N51P05P`?01<9300H
3a8040/?01lM8@0K6Ad04a4E014?4`0:20`02`T=00`:3P0@3Q803`dA00d;3`0B41<0100@3Pl01@0>
30d03@/<00d;300E4a@0518C00803P`=01<04@l@00d=2P0I6AH03a0<00d=2P0=3PX0414=00h?2`0@
4@d03`l<00h>2`0A4Ph05QDB01TD500B30`050h>01DA400D40l05Q8A00<040l=0`0?3`d00`0@4@`0
4Q<=014B3002010A2`0?00h?2@0A4Pd04a@?010A2`0G61805QLB014C3@0A4`h02`d8014C3`0<3PT0
5ALB02`^:@0K7AP0418=00804aD@00D03Q0;00hA2P0B5@`051L>018E3003014D2`803a8900`04A@;
01<F3@0B5@`041<;01@F400C5@l0418<01LI4`0D5Q003Q0:018E3`0D5Q02018E3`0301@G4@0C5Q00
4aD?00804aD?024051H@01DH4P0G6A<06adG01TK5@0C5@l051LA01<F400C61805AXE01HK6@0B5QL0
4ADG01HJ7@0@51D06QhM014F4@0K81P04QP=01@J3@0G7A005adB01HL4P0F6a<05Q`C01LL5@0F6aD0
61dG01@I500C61D06b0M01dQ800I7al00P0K82<0N@0K8B406R4P01LP7@0F81/05b4K01TT700L:1l0
7BXP01/W8`0<61h08Rdg01dY;`0Q;C<082d^04EBDP0S<Bh072TW028`;@0Q;Rh082`]02@a=00T;cP0
;SY402Tf?`0[>D8093<k02/l@`0U=Sd08C<i020c=`0R=cT09cdn02Pn@00V>cd0:3e002@i?00T>3`0
:3]002Lj?`0/?d@0:3To02Xk@@1PL7L0a]?F07n<T@0f@D80DeiN034l?00T;bh09c8b04A?CP0f@D00
:SDe02@_;`0T;bh09c8b02Td<@0]=Bd09B`U02he;P0]=2d0:S0/02L]:@0R:2@07bDS020V900V;2X0
:S0^02/a;`0Q:RT092d[02@^:`0X<bl09S8`02Hc<P0^?D00=dI;03a=EP0eAE80=4ID03U=F`0]A580
?UES03U@G@0gCUX0;dEA03U>F@0aAE00<dMA0313C@0[?DL0<D==02lo@P0a?CT0:STf02Hd=@0W=3X0
:3Ln02/i@`0]>dH0;cm<0351C@0[?4H0;3e603A4B`0gAT/0;Se204MFFP14DeH0:SPk02Lb=00Z=CL0
;SXj02`f=`0X<S<09Bl_024W900U:bL0;38a034f>@0Z;c<00P0V:c401P0X;C<09R/^02D[:`0W;B/0
8RPT02<W9P808bLX03L08RHW024U9P0Q9BH08BDV020T9@0V:R/0?D5202HZ:`0K7b007b<U01`P8P0N
8R@05a/M02HZ;00J7R007R8T01`P8P0N8R@06alQ01PL7P0L82806Q/M01hO8@0J6ad092DW024R900J
6ad07QlQ01/L7P0H6A/06Q/M01LH6P0Y:bX06Q`I01LH600H6Ad06ATQ020P;@0];3`071/[01PH9@0N
7RH05QLK01/M700F61H0518G01dK8`0L6b<0:BTc06a`NP0O8bh03a<L01DI7`0I6Qh05aHJ00805Q@E
00D05aHK01PG700J6Ah05QDJ018A5P0201HE6P0:01PG700<2a003`hC01PG700@41804Q8C018B4P0@
41003Ph>010@40804a<C00D03@d=01@D500@41003@d=010@400201@D500300h>3P0;2`/04@l@0080
4Q0A00D04`l@010<3@0C3a0050h@014<3@02014=3P09018>3`0C3a004@d>010<3@0A3@h06QHG01DA
4P0>2P/04`l@00<04@d>00@040`=00l;300?2``03PX;0P0?2``01@0A3@h05a<D01DA4P0B2``03`D5
00804`T900X04PP801H<300C2@T03@<300P0000D2PX04PX900l51@0D2`d03PP:0`0=1`T01`0>20X0
4@/=010:300>20X030H800l92`0a:bd00P0@1PL01@0?1@H040H701061`0@1PL050X;00804PP90P0D
2P/401061`0;00l51P0>10D03P@501061`0Q5aP0<BLX00T10@0=0`@04PT901052@0>0`L00P0@1@T0
100?10P05@X>01@93@0A1PX200d21P0>00h31`0?10P04@H:01<8300B1`/02@0201<8300<0@D03`@8
01<8300>0`L02P0300l4200A1PXDooooo`006oooool2018B40804A4?00P0410>00h>300<30X051@B
00l?3@0;2`T0;Rh/00X:20802`/90P0>3P`0200<30X0410>00h>300B4Q002@T700l?3@0:2PP0410>
0P0>3P`200l?3@0300h>300=3@/0410>00803Ph<00<03@d;00h>300>3P`00P0?4@h06@0@4Pl030h;
010B3`0H6QL0KFm/05YLF@0R92404A<@01@F4`0A4@l0514B01HD5@0@3Pl0518C01@D500;2`/04Q8B
028T8`0P8R401@L600/?3P0<3`d02`d:00h@3@0A4a000P0<3P/01`0=3``02`d:00/=2P0@4Pl04A<@
010B3`0=3``00P0?4@h00`0;3@X04A<@018D4@0400d?300700`>2`0A4a004A<@01DG500H6QL030h;
00/=2P0200h@3@0>01`N6`0620D04aDB0002000A4a004A<?00H70P0A4Pd01@H1010A300=3PT030d8
00/<1`0=3PT200h?2P0Q00h?2`0Z:R`0BTU>01XJ6`0H61P02`/900`=200G61<03@h900/;2@1;Bdd0
3@d?00l?4P0;2`/02@T700`<2P0?3`d030`:00l?3@0;2`T04A4?01@D4P030`403Ph<01lO7@0];RT0
0`@000@50P0F5a807AhI01<D3`0>3`X03@h9008030d801L03@h900h?2P0=3PT03@d8010A300A40`0
3Ph9010A300J6AD03`l;00T:1@0@3`/04a<?00P9100310003@h8014B300U9R003a0:02@U7`0I6Q@0
30d700X;1@02018C3@0:00H70@0=30L030/6014@2`0@3`X02`X5010?2P0:2@@03@`700h=20<03@`7
00d030/600l>2@0=30L030/6018A300H5a803Pd8018A300G5Q403@`701DD3`0:2@@01PD1008030/6
00H040l:00l>2@0;2PD03`h900h=200=30L300`;1P0401<B3@061@001PD0010?2P802`X500P030/6
01@C3P0E50l02`X500T80`0<2`L02@P400d<20802PT500D05A@@014@300?3PX04A0<00h=2@0200`;
1`0:00h=2@0<2`L030/7010?2`0B4@d04A0<010?2`0A40`040l;00`;1`803Pd9010030T8018>3`0B
41403P`=00d;300<30`0410@01@D501JG5/0?Cln020R8@031PD05QHD00l>30081`D01@@20P0;2PP0
1P0?3P`03Pd;00h=2`0B4@l04a8@00h=2`803@`:00X03`h<014@3P0B4@l04a8@00l>300>3@/02`X8
00d<2P0@3`d04A0>0P0:2@L0100A40h04a8@00d<2P0<2`T2014@3P8040l=0P0?3P`0200>3`X03a0<
00d=2`0;2`d02`/>00d<4@0>3A802PT=0P0<30`06P0;30P0414<01<C4`0A4A40410@018B4P0C4A80
4Q0A01HB4`0J5QL06A<E01<=3`0D30l0618D01PC5`0F51L03`d@018@4`0P7R408b4T00/9300<2Pd0
4Q0C01<A500A3a80518E0P0A3a00100@3Pl03`d>00`:2`0;2@X300l=3P1400`:2`0?3@h05A<D010@
3`0G5aL01@D301LG5P0>3Ph02PX800h>3@0C4a<04A4?00d=300C4a<06QTG02TT900F41004`d=010<
2`0<20L02`L6014@3P0=3@/030`:00d=2`0?3`d0410>010A3@0B4Q004A8=010@3@0@40h0410=014B
3@0A4@l03Pl;018C3P0B4Q003Pl:01<E40072@@051HA04A6@@0T9R402`d800X<1`0;3@P04Q@?014C
3P0B50l051LA01<F3@0B5@`04A@;00`?1P0>4@P04aH=018E300@4`X04A@;018E300A50/03Q4;01@F
4@0F61<04aD@01LI500J71L201DG4P0501HH4`0D5Q404A<>010B3@0D5Q40100C5A006@0D5Q405ALB
02<U800Q8ah05ALB01XL5`0H6QD03a@>01<H4P0E6QD03a<B00hB4`0E6AX05QXK01hR8`0?51405a`F
010E3P0E6a406QlH01TN5`0E6Q<051TC01DJ4`0H7AH00P0G71H201DJ501o01XO6P0L8Ad06b4Q01dR
9@0O92L07bDU01dU8`0J8b00:cHb01`W8@0G8Q`07R/R020]900G8b406RL]02Ld?02V/kT0?Ta?01/Y
:P16E5@0<T4n020_;00Q<2d072XZ024_;`0L:Rd0:CHn028_>00Y=Sl0;3Y3028a>@0T=C`08c@k024d
>00P<cL083Df02<h>@0T>CX093Tl02Pm@00U>Sd09cXn02Pk?`0T=c/0:ce002<e=`0jC4h0;C`o0350
@`0`?Sl0=T0n04QBD@0[=S809C0]02Xd<`0d?c/0;3Hd020Z:@0S;RX08B/Y020Z:@0X<Bh09RlW01lV
7`0R:B809RdV01`R7P0/<Rh0:Bl[02H/:P0W;B/0;38`030f=00a=cD092d/01XS800S;BT082/W01HR
800U<S40;3`l03Q7BP0nCeL0=4E?02m1C`0fBUP0;TEC03mFI00mE640Bf5^02i4C`0jCeX0=DUD03A8
D@0fBE<0<D==02doB@0[>ch0;c/i02dk>`0Y=cT0:3Dk02`k@P0b@4X0<Cm:02`lB@0X>D<09SM102Xk
@`0W=ch06RT^03=2A`0jBDd0;Se0028`<`0Y=3H0:cHh02di>@0Y<c@09Bl`028/;00`=S@0:2h/02/`
<P0Y;S80:2da02/`=P0202T^=00402<X;00Q9RT092XZ024W9@<08bLX04408RHW024U9P0Q9BH09RX[
01lS900I7Ah0720Q01LK700O8b@07B4R01HJ6`0Y;Bh061`M02hb<`0J7Ql07R8S01dQ8P0K7b006AdN
01PL7@0L82407b0R02//;P0A4Q@092DW01dN800F5aT06Q/M01dN800J6ad07AhP01<D5P0J6ad07b4P
01LI6@0G61d06ATQ01XJ9`0O7Rh0:2Lg01hN:`0V9Rh05aPM01hO800B51<08AlT01<A6@0N7RH05APQ
01<G8@0:3QT03a<L01DI7`0J7R407AdP01/I6P0I5aP05QDJ01LF6`0K6Ql05QDJ018A5P0E51T04a8G
020O900201<B5`0V01hM8P0C4aD05QHG01DE5@0C4a<0410@018B4P0D51@05aLG01XJ6P0;2`/06a/K
01lO7`0C4a<030`<014A4@0@41003`l?010>3`0=2``04Q0A01<?400<20T05a<D01/E5`0?2P/040`=
014=3P0E4A80510A014=3P0@30d05Q8C02DQ8P0N6Q/040`=01@@4@0B3Pl2014=3P0Q010<3@0?2``0
3`/<00`82@0=2@X03`/<00h:2`0A3@h03`/<01492`0?1@H04PP901@:2`0E2``05`d>0147200@1PL0
8ALH01H>3P0=0`@05`d>00/51P0?2@/03PP:00l92`0@2P`04`d?01@>400<1PP04`h?00@0000B30h0
3PP:00803P@500@03`D601061`0A1`P04@L80P0C2@X201882@0301061`0>10D040H7008040H700`0
3`D600h41@0>10D05@/<00L0000;0@8050X;01P>3`0<0P<03`@800d21P0>0`L200l4200501L<400E
2Ph04PL;00h31`0<0@D00P0=0PH02P0B1`/02`8401@93@0700004`P<00/0100=0PH04@H:00d21P0<
0@D201052ACooooo000Kooooo`0H01@D4P0A4@l03Ph<00d=2`0?3`d04A4?00D50`0H61H02@T701LG
5@0J6QP051@B00X:200@40h06ATG01DE4`071`D01@D300L71@0>3P`01PH400l?3@0B4Q004a<A0P0>
3P`200l?3@0400h>300=3@/0410>00h>30<03@d;02803Ph<00d?300B51404A<@00`>2`0J71T0:R`Y
0=SIe`2e]k@0=SPe01LI5P072@H02PX8024N7`0n?3d081hO00X82@0C4a<03`l?00L71`092`X01PP7
03Dg=P0830/030l=00D710092`P03a4>00X<2@092`P03a4>00h@3@0<3P/03@l<100?4@h200h@3@05
014C400>40d02P`900h@3@0?4@h00`0>40d02P092`P051HC01/M6P0<3P/02`d:018D4@0;3@X030h;
00d?30041P<200T;200601LH500?40/03a0;00@5000B4`h061TD0`0@4@`05`0>3`X03@h900h?2`0U
9BL0B4M<00l?400?3`l01@D3014B3@0B4`h02P/600P81P0K6ad01`L900X:3@0=3@d02PX800`<2P0?
3`d03@d;00h>300?3`d02`/9008030`:00P05ADC02/[:@1CE4l071dH00T:1@0?40/03@h900P91080
3Pl:0P0<3@P200h?2P0H00l@2`0;30L03@l:00h?2P0:2`H02P`70001000=3P/02`d800/<1`0?4@`0
3a0;00`=1`0?40X02``60001000:2`L030d700h?2@0:2`D02@X400`=1`0=3PP02P/50P0;2PD02P0?
3PT03Pd800/:1@0?3PT03Pd800l>2@0=30L02`X500d<1`0?3PT300`;1P0?00d<1`0<2`H02PT400`;
1P0?3PT051<>00X9100A40/010<001HE400E50l040l:00l>2@0>3@P02PT400<03Pd800L03@`700`;
1P0;2PD02PT4010?2P0A40/05QD@00800P4000T020L200`;1P0A40/030/600h=200B4@d02@P400h=
2@0B4@d00P0A40`01`0<2`L03`h:00l>2P0?3PX030/700d<200?3PX00P0=30P0100?3PX04Q4=018A
3@0@3`/2014@300H00`;1`0>3@T03`h:01@B400P71d07Q`M018@4@0;2@X02@T900H61P0@41002`d<
00X<2`051`H02`h=00l?3@0A40h081lM010?3@0=30X05QDC010?3@0<2`T03@`:0P0B4@l0400?3P`0
3Pd;00h=2`0@3`d04A0>018A3`0C4Q0040l=00X91`0?3P`04A0>00X91`0A40h06APF00l>300;2PP2
010?3@0400h=2`0?3P`03`h<00l>30803Pd;00T03@`:00h?2P0=3PX02`/900X:300A41@061LL01<B
5`0<2`l00P0:2PX06`0=3PX05AHA00`>3@0B51<051HE018D4`0G5aL07alO018@4@0@3Pl04Ph?01DA
4P0H4a@05a<D02DS9P0G5AP01`D800H41`0?3A004@lB00d;3P0:20/03P`?00l=400<2Pd03@/>00l=
3P03010>3`803P`=0P0;2@X04P0C4A805A<D00d;300;2@X04A4A014A4`0820P04a<D00L72@0H61P0
3`l@00l?4@0@41004Q8C01HF600J61T06QHE014=308040`;02004Q4?01PG5@0A40h03@d;00`<2P0=
3@/03Q0=00lA3P0?3`d04A4A010@3P0?3`h03`l?010@3`0@40h0410@00l?3P0A4@l04Q8B01<D4@0B
50l051HA00d?2P0H6QD020X501@F4@0A4`h04aD@01DG4P0@4Pd03a4<018D3P803A0900<03a8;00/>
1`0>4@X00P0G6Q<03P0C5Pl04QD>014D3@0@4``04aD?01HH4`0D5Q404Q@?01@F4@0C5A004Q@?01HH
4`0H6QD05QPC0P0C5A000`0F61<05ALB01DG4P0201@F4@0B01DG4P0=3`X06adH01/M600@4Pd05QPC
01DG4P0>4``04AH?01<H4P0?51003Q8A01DI6@0C5aP07R8S01<G5@0N8al05a`F0P0J7aT01@0H7AL0
5Q/E01DJ5P0F6aD06AhH008061dG0P0I7QL01@0H7AH05a`H01/Q8@0M8RD07R<V00807BHU01/06b@Q
03Q3?`0S;bT06BHO024^9`0V<b`07RXX02Hc>@0P;CH0IG9h01DS9P0T<S<06BLW02Lf<`0R<Bl07bd]
028`<@0[>C/08Bhd02Tf?P0S<3T0:cU202Th?`0S<cX0:3U001la=@0R=3P00P0T>3T0C`0S=cP08CHi
02<f?00X>d409cY002`n@P0/?T00:3Xl02`l?@0c@d<0;Shn02hl?00hATH0>TU603<m>00/=C80:C8]
02H_:`0_>3D072DP02Xc;`0Q:RL09BhY028[9`0N9b@092dX02<]900[=Bd09BlW02Tc:`0X<B`06R<N
02D^:@0T;BX09Bh[02Pa;P0W<2d09Rl/02</:@0L9B808B/X020[9`0S;b/0=45002Ph>00/>ch0=4E<
0393C@0`@U00<dQE02i6DP0jD5d0>4iK04AJI`0^@Td0<dMA03=7D00dAU00>deF03A7CP0Z>d<0:3Hj
02Xf=00[>CT0:cTk02Xg?@0/>d80<3i8034oBP0^?dT0:ca602hoA`0b@d/0=4A;03]:C`0c@TL09cHj
03I5B00S<C@00P0/=cT0400Z=SH09Bl`028/;@0T;Rl09bd]01`R8P0U:R`08BHZ02H[<@0a=S`0:Rle
02P]<`0P9BX07R<V02@Z:P0V;2`302<W:00>028V9`0Q9BH08BDV020T9@0O8b@09RX[028V9`0P92D0
720Q01/O800M8B80<CDf01`P8@0Y;Bh201dQ8P1?01hR8`0J7Ql061`M01TM7P0K7b007AhP02`];`0?
418071dO01TJ700K71h04a@F024R900D5AL06AXL01dN800H6A/07AlN01HG600F5a`05aLO01PG900K
6RP08b8`01XJ9`0O7bL05aPM01hO800F5aT040hC028P9`0C4a/03A0I01`O:@0G6bH051PQ01@H7P0G
6ah07AdP01XH6@0E4a@05QDJ01LF6`0J6Ah05QDJ01<B5`0G5Q/03@`A01HE6P0B4AH04A0E01<B5`0C
4aD04a<D018B4P0@41003Ph>010@400B4Q80410@01HF5P0J6QX030`<00l?3`0N7Qh061PH00`<300C
4a<04Q8B00/92P0?3@h04@l@01<?400=2@X06QHG01lI6`0B3@h04@d>018>3`0201DA4P03014=3P0@
30d04`l@00807a/L00<05A4B01HB4`0A3@h00P0A3@h02`0@30d03`/<00l;300?2``0510A01HB4`0>
2P/03@T:00l;300C2`d03PD600<04@P900T05Pd>0107200F3@h02@0100d41@0C2P/01`0000l82@0@
2P`00P0?2@/0200@2P`050h@048l?P0B30h0>S@f02<M7`0E3a403@L90P0?1@H00`0@1PL04@L80147
200201882@804`T:00<04@L800l51P0>10D00`0@1PL01@0?1@H03P@500h41@0F30d0308300804PP9
00@04@L800h51@0=0PH02`040`0>0`L0300E2Ph040D901052@0@1@T03`@800h31`0=0PH07A8F00X0
0`0F2`l03`@800h31`80304500D03P<700l4200E2Ph060dA00h31`0Dooooo`006oooool200h>300<
00d=2`0>3P`0410>010@3P0I6AL0Bd]901PH5P0@40h0410?00T91`0D51802`/90P0<30X0100B4Q00
:2PV01PH5P0P81h2014A3`0401<C4@0:2PP03Ph<00h>30803`l=00H03Ph<00d=2`0?3`d03Ph<00d=
2`0<30X200d=2`0O00/=2P0A4a004Q@A010B3`0M7a`0;2h[09VKV022Q8408bDR01<E4P082PL04A4?
01PE5P0R824040h?00l=3P0C4a<01`L7010@400>40l02@/:04=5A00D5aH06A`J00d?300B51406A/H
00h@3@0;3@X04Q@A014C400200h@3@803a4>00T0418?00`>2`0<3P/03a4>00X<2@0@4Pl051HC010B
3`0A4a000P0@4Pl07`0>40d030h;010B3`0?4@h03@l<014C400@4Pl030h;01lQ7P1=Cd`04Q@A01<E
4P0<3P/03Ph<00l@300K6aP09BDR00H60`0F5a<051DA01DE4P0D51403a0<00l?300A4Pl03Ph@01LF
6`0=3@h0?clo03/k>@0D5A000P0>3`X0200>3P`01@D7014A4`0B4AD05aLG010@3P0=3@/03Ph<0P0<
30X02`0?3`d03Ph<00h>300C4a402`/901hN700E5Q400P<000d>2@0?40/020T400803a0;00T03Pl:
00d>2@0=3PT03Pl:00l@2`0<3PT01`/500/?2@0=4@/00P0:3@P08`0G6QD02Pd900hB300/;bX0<CD`
00P:1@0B4`d03Pl;00`=1`082@H07b0K00P9100=3PP03Pl900d>200<3@L03@h8010A2`0920<03`h9
00X9100<2`H04Q4<00X9100>3@P030/600/:1@0<2`H03Pd8010?2P0=30L03`h9010?2P0A40/03`h9
00803@`700X02`X500d<1`0A40/040l:00h=200[:RD07ahI014@2`0<2`H03Pd80P0=30L300h=2007
00d<1`0<2`H04A0;01DD3`081`<03Pd800`;1P0201lN6@803Pd800`02`X5010?2P0C4Ph01`H200/:
1P0=30P03`h:01@C3`0@3`/03@`800`;1`0?3PX200d<200T00h=2@0=30P03@`800`;1`0A40`040l;
00/:1P0?3PX040l;00`;1`0>3@T040l;010=2`0C3`l04a4A00h=300@3Ph0410?00h>3@0V9RD02@/9
01@F500>40h04ADB059BD00J6AP020L500/:200@3`d03`h=010?3@0<2`T03@`:00l>300>3@/04a8@
0P0A40h0400@3`d03Pd;00h=2`0=30X04Q4?00l>300B4@l040l=00X91`0B4@l0:BPV01HE4`0;2PP0
6APF01dL6P0@3`d200l>30803Pd;0P0=30X0200?40/0410=00h>300>3Q005A@H01/J7`0E51T03`hB
0P0>3Ph05P0@4@d061TD00X<2`0C5A@051HE018D4`0I6QT09BHV01<D4`0?3`l03Pd>014@4@0B4140
3`d>02@R900L6Q`05A<E01<A4`0@3Q003@/=01XH6P0A3a42010>400400h<3P0?3@l03@/<00l=3P@0
40h?00H03P`=01@B4`0T8R<0928S014?400=2``200l?4P0B014A500E51P0FUYM03Ti?00A41@03@`@
00h=4@0C4QH051<G01<C5@0B3Ph04Ph=01<?3P0@3P`04a8@01XI5`0@3`d03`l=0P0?40d200h@3@03
010@4@0B4Q<04A4B0080410A01/04A4B00l?400?3a004A4B018B4`0D51D04Q<A03Pj=@1YJfH071hI
01HG500E5a8051HA00d?2P0?4@`04aD@00lA300>40/04aH@00lB2`0>4@X051L@01<F3`0I71D07b8K
01LJ4`0C5Pl00`0B5@h03`0C5Q004A@@00dA300A51005ATD01@G4`0B5A404QHA01DI500D61<05APD
01PL5`0F6AD05ATD01@H4`0201<F4P0P01@G4`0?4`h051PC01@H4`0B5A4051PC01DI500C6@l04QT>
01<I400C6A805A/E01HK600@5AD06b0P01<H5`0N8b805A/H01HL6@0F6a/05Q/J01HL6P0G71T061hJ
01XP6`0I7aT05adG01XP6@0L8QT05QdD01HM5P0I7ah201PO802001PQ800J8b806R@S02D_;@0J9R<0
5R<M01/Y8`0P;RP07B`Y01<P9P0U<cX07B`_02Lf>@0N;Bd08c8b01TX9@0S<S407Rd/02Dd=@0O;C00
@e5G02Le?@0V=3`0:CQ0020`=`0Z>T40;Sm501d_<`0S=ST09cXl02Lj>`0V>SX09c/m02@f?@0V>3l0
9cTo02ho@`0_@480:S/k02/j>@0Z>SP0:cPe03E3?@0[>C<0:SL`034j<P0U;BL0<CXb02D]9P0^=S00
82PP02D^9`0S:bD08b`T02@]9P0S:bD08BXR02La:00`>S80OXR004mID@0j@ch0:S<^02D^:@0T;BX0
9Bh[02Pa;P0V;b`09Bh[02</:@0X<Bd08R`X020[9P0b?SX0=dA202@d=00W=ST0<49803E6D00fB5@0
=DYG03M>FP0dBUL0=T]H02m4C`0nDUd0;d==03A7D@0_@DX0<TA<02doA`0V=cl0:SPl02Hb<@0V=3D0
;3Xl02ll@P0_?DH0:cU302`jA@0^?dT0;Sm80352BP0_@4L0;Ce301l^<`0_?T<0=TE905ETI`0X=ST0
;3Li02/f>00X=3@08bd^028/;@0T;Rl0:Bha024V:@0h?D00:Bhd02H[<@0/<CL0:Bhd02P]<`0Q9R`0
82DY02H[;`0X;S0302<W:00l028V9`0Q9BH08BDV02DY:P0P92D092PY01PL7@0S9bP07B4R01/O7`0V
:RX0;S8b01hR8P0O8b<06AdM01XN7P0P92@06alO01TM7@0K7al06AdM01XK7@0O82805AHH01TJ700J
6ad07AhP02@U9`0[;2h0414C01<D5P0L7Al05AHH01DG5`0E5QT06AXO01TI8@0I6B@081l/03LgA00^
;ST06a/S020Q9P0D5AP04a@F01PG700K6b803`lG01/N9`0H6bD051TT01HK900E6R004aLJ01@E600H
61P06QTJ01LF6`0F5AX05aHK0P0E51T05@0J6Ah0@T5602TX;@0C4QL05A@I00h=4P0G5aT051@E01@D
500C4a<04Q8B01DE5@0H61P0Bd];05EEE@0820P06a/K02l_;`2/[:`09BDU00d=3@02010@400D00h<
3@0D4Q<040h?01<?400B3Pl05a<D01/E5`0E41404`l@018>3`0D41405A4B01<?400@30d03@T:01DA
4P0F4Q<04Ph?01<?400>2P/2014=3P0Q010<3@0?2``03`/<00l;300B3Pl04@d>00h:2`0A3@h040`=
00h82@0?1PP05`h@01D<3P0@1`T05@`>01482P07000071<E03L^<00D2`d03@D601@<3P0@2P`03@L9
00`6200>20X04@/=01D?4@0=20T0618D00@0000<1`P03PP:00L04@L800D04`T:01D;300B20T04@L8
01882@0301061`0A00l51P0>10D03P@500X10P0D2P/030<400P0000G3@h03P@500d21P0<0@D040D9
01462P0=0PH04@H:00h31`0?10P00`0@1@T01`0?10P030<501472P0:0@<04@H:00d21P0C20`00P0>
0`L0100A1PX06@hB01`A5@0@1@TDooooo`006oooool02@051@<02`/9014A3`0B4Q003`l=00/;2@0F
5Q@03`l=01@D4P0200d=2`0=018B400;2`T03Ph<01/K6@0H61H03@d;01HF500<30X06ATG00h>300@
40h05ADC00T91`0200h>30803`l=00@03Ph<00d=2`0?3`d03@d;0`0<30X07P0=3@/03@l<00/=2P0>
40d03@l<00/=2P0>40d04Q@A010B3`0H6QL0418?00lA3P0A4@l04@h?00l=3P0A3a003P`=00/;2`0?
3`l04A4A00X<2`0>40l03@l>00lC4P0=40h020X700h@3@0G6AH02`d:00P:1`<03Q0=0P0A4a003@0?
4@h030h;00L91P0<3P/04Q@A00X<2@0R9240:R`Y014C400@4Pl03Q0=01<E4P0B51400P0<3P/04@0=
3``02`d:00L91P0;3@X03a4>0001000V:2D03@h<0001000F61D02``900d=2`13@d40K6aZ00X:200;
2`T03@d;00803`l=0P0;2`T0400@40l02`/=00d<4@0=3@h0410@00X:200D5A002@X5014B3@0<30X0
5ADG010@4P0;2Ph05aLG00l?3@0;2`T200h>300;010@3P0;2`T061PF00d=2`071`D092@R0:NWY@0C
50l00@8000`=200B4`h00`0?40/06@0>3`X03@h900d>2@0>3`X03Q0;010B3@083@L02a0:00dB3009
3PP01``600/@2P0@5@l00@H00003000;40X0314;00X;1@0=3PP020T301DF400>3`T04a@>00l@2P0<
3@L00P0:2`D02@092P@020T300L60@0B4@`02@P3014@2`0S8Qd04A0;018A300200l>2@0S010?2P0=
30L02`X501<B3@0F5A004Q4<00/:1@0>3@P04a8=018A300:2@@01@@0018A300920<04Q4<00`;1P0@
3`X03Pd800l>2@0=30L02@P300/:1@0=30L03Pd800l>2@0>3@P03@`700`;1`0;2PD030/602d/9`0C
4Pd040l:00l>2@030P000P0@3`X03P0=30L030/700/:1P0E510040l;00P70`0@3`/04A0<00/:1P09
20@03Pd900/:1P0<2`L03`h:0P0A40`08@0?3PX04a8>010?2`0;2PH04A0<01<B3P0?3PX04Q4=01DD
400D4Pl0510?014@3P0=30X03`h<00h>300<30X02`/900`>2`072@H04A<@00lB3`11@Cl03Pd;01DD
4P0?3P`00`8000l>300F5A<04Q4?01<B400A40h03`h<01/J6002010?3@804A0>00h04Q4?01<B400H
5aD06QTG00X91`081`D07QdK02h]:`061@<02PT701@C4@0C4Q003Pd;018A3`<040l=00/03`h<00h=
2`0>3@/030d8010A3@0@40h03Ph@00`<3`0<2a003@`A00/:3P0200l?3`0;00`=2@0?40/04Q@C010B
4@0<3Pd02P`;00/=300>40l03a4@014C4P0?4A000P0<30`0300?3`l04@l@00d;300=2``03`d>018@
4@0E4a@07A/L014?400=2``03P`=00`:2`803P`=00<03`d>010>3`0@3Pl00P0>30d06P0;2@X02@L8
014?400>30d030X;01@B4`0@3a@04Q4F0000100d<cP0knkc03Th?@0B4AH03`hC00d<4@0;2Pl030/@
00d=3`0A3Ph04@d<01HB4@0D4a404Q4?01<C4@0?3`d0418?0P0A4a000`0>40d03@l<018B500201<C
5@04014A4`0B4Q@05ADG01@D5P804Q8D00T03`lA010@4P0B4a804A<>03m1?00:30P05aTD01@F4@0?
4@`00P0@4Pd04@0E5a804Q@?014C3P0E61803Q4:00/>1`0?4P/02@`500hA2P0H6a@04QD>00lB2`0@
4``04aH?01@G400D61<04AHB00<041DA00H04AHB01@I5@0C61@04QLC00lD400@5A4301<H5005014F
4P0@5A4041DA010E4@0G71P00P0A5Q80GP0D6AD04QLC01<I500D714041P;00lG300E71@061lG01DK
5P0d>SP0=C/i01HL700E6a/03aDE01/Q8@0B5aX04aPK01HL700I7al06R0N01XP7@0J81`05A`E01LN
5P0I81P05alD01dT700J8b005b0O01DN7@0F7ah06R@S01hX9`0F8R006bLU01l[:@0N;BX07RdY01d[
:`0Q<3<05bH[02Pg>P0J:RX0:SXi01/[:P0L;2T08S8`01l_;`0_?T40;3/o0:Fd^@11D5L08S<j024b
>@0_@4L0AUQL02Li?@0S=CT09SPj02@f>00Q<c<0838b02@f>00W>3l09CHm02He>P0/>cl0;3`l02Pf
=P0Y>3@0:SHb02@a:P0S<2L07BXQ024]8`0R:R8061lG024X800W;RH08BPP02H]9@0T:b<0:2lW02@[
8`0[<RX0;C@/02D/900U;bH0;CL_09jXX01HHUX0DU]F02lh<`0T;BP2020Y9P0o02D^:`0Y<Rl0:S<`
02/d<@0Q:RD092hY030k=@0c?c/0934^02/k>P0eADD0>T]A03E6CP0gBED0>D]H04AJI`0hCU/0@eQS
0355D01SMh00>diG03U;E@0bAD`0<dE<02/lA00R<c/0;C/o02Da<@0R<340:CHk038oA`0c@DX0>TQB
041>F@0iBU@0;Sm702m0A`0]?TD0;cm502/j?`0W=S/0=DA804iMH00X=ST09S4c02Pc=@0Y=CD09S0a
02<];P0R;2d08RL[01XO8`0g?4008bP^028W;@0^<cP09b`b02P]<`0V:c409R/_02T^<P0U:Rd08bLZ
00808bLX06008RHW024U9P0Q9BH09RX[01hR8`0Q9BH04ADF02@X:@0K7b005QXI020T8`0N8R40720O
01lS8P0I7A`061`K020T8`0L81l06AdL01/O7P0F6QT08B8T01HG6@0N7b407AhP01XK7@0A4Q@051DG
01PI6`0E5QP07QlQ01XK7@0L7Al05aPJ01/L7`0N7b@06ATQ01LG800P82`0;Bdi02XZ<`0;2a<0824V
00l@500I6Qh04a8H01/K8P0G6R4092Pa00`A6`0I82X03A@L01PN900F6ah04A@F02@T900c<c<061LL
01@C600E51T04a8G01HE6P0L6b00QXF:04Y9CP0A41D05QDJ018A5P0G5aT03Ph?00l?3`0>3Ph03`l?
01<C4`0F5QH061PH01LG5`0E5AD03Ph>01@D500H61P03`l?014A4@0=3@d0410@018@4@0<2P/040h?
018>3`0E4A804@d>010:300E41804`l@014=3P0B3Pl201@@4@07018>3`0?2``05Q8C014=3P0;1`P0
40`=00l;3002014=3P0R010<3@0?2``03`/<014=3P0@30d030P901LC500S7b006ADF00X51`0D2`h0
91/N02<J7@0F3A0060lB0189300A20/03@@701TA4`0D2`h02@0301D>400D3Q0040X<00h82P0?2@/0
4P`>03/e=`0d;S002@@501/E5`0B30h02PD601<92P804PP900T04@L801061`0@1PL02`4200h41@0A
1`P03P@500d3100?1@H00`0@1PL00`0?1@H03P@500h41@0201<92P0401892P0;0@802@0000h51P80
3P<70P0D2@d0100=0PH03`@801<8300@1@T200`11@0>00h31`0A1PX04@H:03/`=00;00@040D900d4
1P0=0PH02P0300h31`0=0PH03`@801<8300?10PDooooo`006oooool00`0B4Q004A4?00l?3@0300h>
300<010@3P0>3P`030`:00`<2P0>3P`0410>01DE4`0;2`T02@T700`<2P0=3@`00`<10P0>3P`02P0J
6QP04A4?00l?3@0;2`T03Ph<00l?3@0=3@/02PX800d=2`0A4@l200d=2`0E00`<2P0>3P`01`L5014A
3`0?4@h030h;00/=2P0<3P/03Q0=00lA3P0A4a004aDB018D4@0>40d03a4>018B400A3Pl03`d>00h<
3@0?3@h03Ph>00803`l?00H04Q@C0001000D5QD051PG020S8@0=3``200/=2P0600d?300?4@h03a4>
018D4@0A4a002P`90P0@4Pl01`092`P02P`900h@3@0A4a002P`900/=2P0@4Pl00P0:30T0900T9R<0
51HC0043000:30T02`d:00X<2@0;3@X03@l<00lA3P0A4a005aTF00840@0A4a004Q@A00lA3P0<3@X0
3@d;014A3`0F5Q@05ADC00h>300J6QP02`/9014A3`0@40h02PX800`<2`0@41803`hC00l?400>3Ph0
3`l=010A300B4`h02@X500l?3@802`/=01003@`@00L71`0;2`T01@D300l?3@0A4@l03`l=00`<2P0@
40h03`l=018B400Q8Al0ADE300l@2`0=3PT030d80P0>3`X0700;30L00P<001@E40092PD020T400X;
1P0;3@P02@/600T<200F6aD01@X400@910062`D020d700X?2@0320801P/501<H4P0H7AL061TC00d>
200@4@/03a0:00P90`0A4P`05AH@00h?2@0<3@L300d>200f010?2P0<2`H02PT4018A300@3`X02PT4
01<B3@0B4@`03`h901@C3P0G5Q4010<000l>2@071P402`X5010?2P0B4@`020L200`;1P0D4`h02@P3
00h=200A40/03Pd800/:1@0H5a802@P303He<0081`8040l:00h=200?3PT040l:00l>2@0<2`H02`X5
00h=200<2`H04A0;01TH4`0G5Q404Q4<010?2P0=30L030/600d<1`0>3@P02`X600X91@0=30P02PT5
00L60P0920@03@`80P0A40`04@0>3@T04A0<014@300<2`L03Pd9014@300@3`/03@`800l>2P0A40`0
3Pd900P70`0A40`02`X601@C3`0?30X04@d<00803Pd;00T040l=00h>30092@L05QHD00L91P0=3``0
004000dA3@0?3`d00P0A40h0100?3P`03Pd;00d<2P0>3@/400l>3003010?3@0=30X03Pd;00803`h<
0P0>3@/02@0920H06aXH014@3P0D4a404A0>055@CP0B4@l03Pd;00`;2@02014@3P0G00/:20071P@0
40l=010?3@0E51804A0>00`;2@092PD03Pl;00d=2`0:2P`0410C01`K800H5a`051<G01PH600C4a<0
2PX701@E400B4Q804A4A010@400?4A000P0>40l00`0=3`h030h=010B4@0201@F5@03014A4@071@H0
3`d>008020H700D04@l@00/92P0;2@X030X;010>3`02018@4@06010>3`0<2P/040h?010>3`0>30d0
3`d>0P0B41407P0=2``04Q0A01<A4P0?3@h04@l@00h=4P0D4aP04A0E01/J7`0S8RL07A`Q00h=4P0F
5AX040lD00`;400B4AH051@F00h=300B4@l05A@B01<B400<30X02PX8010A3`0<3P/0418?010E4@0D
6AD03a4>00h>408051@F0P0@41800`0B4Q@04A4C014A4`03014A4`04018C4@0A4`h04A<>010B3@80
3a4<01D04Q@?01DG4P0C5A00418=00lA300A4`h05ALB01<E400D5Q403@l:010B3@0H6QD0418=014C
3P0?4@`04Q@?00lA300>40/05ATD00H<200;4@d00P0G7AT0;@0E6aL020h:01TO6`0D6QH03aDA00/A
3@0C6AD05adI00/A3@0A5a<06b4M014G4`0>51003aDA010F4P0B61@05A/G01LM6@0I81X06b8J01<M
4P0?6A003AL>00`F3@0C7AD031D@01TR7@0@6AL04a`K01<K7@0B6Q`07BDW00L?4@0S;2`04Q/J01TR
7`0H8Ad0624L018L500H8QT06B<J00lI3`0G8AP06B8O01TR8@0301PR8@0/01LS8@0L:2P062DU020^
;P0L:RX072XY01XX:00J:B`07Rdb02@c=P0V=SH08c<b01`/:@0R<S409CDe02Lg=`0U=3L09C@j02He
?00M;SD0:S]202Lh?`0T=SX09SPl024c=@0M;c409SPj024c<`0_@D4093Hf02Lf>@0Z>Ch08S4f028`
<`0U<cD08Bl_01hZ:00W=2h0:SD_02D`:00M:Ah07b/Q02<_9@0L91`201hU7@0701lV7P0Q:20092/S
02H]9@0S:R8092/S02P_9`0202/b:P0802Ha:00U<2P0:cH^02Td;00W<R`0;3La024/9P0U<2`202Lb
;P0_02Pc;`0Y=300;CHa02D^:@0T;RP0;CP`038o>00T<Rh0:3Pg02Ti>@0_@DH0>4UA0312CP0gBUH0
<DE@03I:E@0jCUT0BemX0;?5c`1NL7T0=4M>0393B`0[>d80:cY104EDF`14DUH0?DQ:02Xh>`0c@DD0
:SLo05QVK`18EV00<Cm:02dnAP0[?4@0:ca302dnA@0a@TH0;Ca102Xi?P0b@DD0;C`o03=1A00U<380
9S4c02Pd=00Y<c@00P0X<S<01`0]<SH07b@X02<X;00/<CD09BX^02H[;`0Q9RX00P0U:Rh02@0V:bl0
:c0d02T^<@0V:Rd092PY01hR8`0P92D092PY01`P8@0201hR8`0501/O800N8R<08RHW01/O800O8b80
0`0L81l201PL6`0[01HJ6@0N8R4051PG02<W9P0V:RT07B4P01/L7P0O82802@X<028S9@0H6A/06a`N
04m@DP0F5aT06Q/M01`M7`0C51H061TK01/L800M7R<06AXO01HF7P0L72D09RH`02XZ=00L72D05ADM
01HG700F5a/06Q/O01PI7P0H6Al06A`S028V;`0F6bD01PlH00TB6@0G7B<061dP00`@4P0Y:bX0B4Y9
01PG700401LF6`0U01HE6P0N7B807A`Q00d<4@0A41D061LL00l?4@0H61T02`/;018B4P0=3@d04a<C
018B4P0E5AD04A4A00d=3@0D51@03`l?018B4P0K6a/02PX:00H61P0A4A404@l@01XH6@0B414061@E
01<?400>2P/03PP:00`72@0D41404@d>00h:2`0A3@h03`/<01<?4005014=3P803`/<01l03PX;00d9
2P0A3@h03`/<00h:2`0?2``07a/L00/7200@30d03@T:00`7200B30h0Qh6303hh>P0F41802P@600h8
2P090`D03`T;014;3@0<1PP04`d?03H`<P0E3a403PP:00@0000:10H05Q0B02TS9@0M5aT03`T;0080
2P@600L03PP:01L=3P0:00406Q0A00L0000<0P<050X;00H040H700H04@L800l51P0<0P<02`4200d3
100@1PL600l51P0800`11@0A1PX05P/?01462P0?10P04PL;01462P0;00@200d21P0>00l4200J3a<0
OW=g01T@4P0D2@d04PL;01052@07000050T=00d21P0A1PX0200101D:3P0A1PXDooooo`006oooool3
00h>300500l?3@0A4@l04Q8@018B400@40h00P0>3P`07P0@40h04Q8@00/;2@0<30X02@T701<C4@0?
3`h030`:01dM6`0>3P`04A4?00l?3@0@40h02`/900h>300?3`d03@d;00`<2P0>3P`0410>018B400`
<2h03Ph<014A3`0C4a402`/900h@3@0=3``030h;00d?30<03Q0=01404A<@010B3`0>40d030h;00h>
300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0;2`/04aDD0412@@0>3`h03a<B00X=2`0300d?300300h@
3@0?4@h030h;008030h;00@02P`9018D4@0E5a@04Q@A0P0<3P/0600>40d02`d:00/=2P0=3``05ALD
01HH5@0;3@X03Q0=018D4@0=3``030h;00d?300>40d03a4>010B3`0?4@h020X801dO700@4Pl01@L5
01<E4P0=3P`03@d<00l?3P804Q8A00D03`l>00d=30092@P071`K01LG5P0200d=300K00l?4@0>3A80
3@d>00d=3@0=3@/03a0;00d>2@0@4@`04A4?00L72@0B4Q@03PhA00/;2`0>3P`02`/9010@3P0:2PP0
3Ph<00d=2`0A4@l03`l=00P81`0820H04A4?00l@2`0=3PT030d800803Pl:00l030d800l@2`092PD0
414<014B3@0@4@`02@X5010B3@0?4`h03A4;00D90`0=4@/01`/501HI5020Q7h00P0@50h02`1ZKVP0
418=010A2`092P@03@h800h?2@0:2`D04a@>00L80P0=3PP03a0:00803@h801803a0:00h=2@0M71L0
2`X501DD3`0=30T0CTe801`K5P0;2PP03@`700X91`0@3`X04Q4<01HE400@3`X030/6014@2`0;2PD2
010?2P0;00l>2@0D4`l03`h:00/:1@0B4@`030/6018A30061@0081lJ00`;1P0?3PT00`0<2`H04@0>
3@P04A0;018A300:2@@030/600d<1`0>3@P040l:014@2`0=30L03Pd8010?2P0?3PT03Pd800h=2@0=
30P03Pd9008040l;00D03`h:00d<200@3`/040l;00d<2002010?2`0300d<200>3@T03`h:00<040l;
01P03Pd900d<200C4Ph0:bXV051?B`0A40d04Q0=01<?3@0A40d03@`900X91P0;2`P03@d:01@E4@06
20@03@l;00`>2P0?4Ph02`/900d<2P0?3P`04Q4?01<B400E5183010?3@<03`h<0P0>3@/300l>300h
00h=2`0D4a401PD301HE4`040`4040l=010?3P0B4@l03Pd;00d<2P0@3`d04A0>00`;2@0D4a403Pd;
00/:200A40h02@P702<R800L7AP04A4>00X:200=3@l04a<F01@C600T8bP05A@H01<C4`0B4Q8030`9
010A300B4A804a4A014@4@0A4100410@00l@3`0B4a80414A010B4@0A4a803a4@00/=300>3@`03`h=
00l=3@0I5aL081lN00l>3@0>30`04a8A00X8200A40l07ahM00d<2`0>30d2014?400?010>3`0A3a00
4a4B00l=3P0;2@X03`d>010>3`0=2``03P`=00h>4@0B4AD030/?010?4`0C4aH03@`@00803`hB01<0
4A0D00h>4@0>3Q4051@F018A400=3@/030/900d=2`0B4Q0051DB00lA3P0F6QH08RHR01@I5@041`@0
4aPD01<C4`0B4Q<04A4B0080410A1P0A4A800`0A4Q404A<>010B3@04014C3P804aD@00/04A<>00lA
300A4`h04aDA01DG4`0F61@09RPT01XL600<3PX051HB01PJ5P0201HH500C00lA3@0=3`/05ATF010F
4`0D6QL04QPE01@J5`0H7Q/051XG014F4`0G7AX05Q`I01PN6`0@5A804ALD00lE4P0E6aP07B<P01TO
7003010F4`804QPE04/04aTF01@J5P0A6Q<03QP?014K4`0D7QD04A/B01<M5@0F81P0624K018K5`0>
5aH03aLH01TQ8`0D71d05b0P01<L700H8B00624O01TR7`0J8al05AhI01PQ6`0H8Q/04adE01dV800I
8al06R@R01XT8`0K9R@06bLV01`X9`0F8b<06BLW01/Y:@0Q<30062LW01`[;@0L:bh072`_020a<@0R
<c808C8`01`]:P0N;bh08S<b02<d=00R<cL08c<i02@e?00X>d409STn02Li?P0V>Cd093Hi02Li>`0X
>S/0:S/l02@e=@0^?ch0:SXj02hm?@0`?T00:3Df02Ld<`0Y=SD0:3<`02Da;00Q;BH08R`T020[8@0M
:1d07bXO028/8@0J91/00P0L9A`02`0L91`07bLO024Y8@0M9Qd08R/R02H_9P0X<2P092`T020Z8@0U
<BL08bhV0080:3<[00D092lY02D`:P0U<2X0:C@`02/f<P0202Xe<@0R02/f<P0T;BP09BlX02Pc:`0T
;bL0:3D]02Dc;@0W=c@0:CTi0352A`0a@TX0;Cm903M:E@0cAe80?51J03U=EP0V>D<0BEaT045CF`0h
BU80<D5902lnA@0^?D@0:3Lm02Tf>P15D5<0<Sm4034nA@0X=Cd0>TQA02`jA@0a?dX0;d180311B080
<49600T0;d1402ln@`0a@4D0<T550350@`0`?T40<3/m02`g>@0W<c<00P0Y<c@01P0Q:b`09b``01dR
9P0Z;c80<3Dg02<X:@<09R`[00T092X[02P]<00[<3@092T/02@X:`0U:BX08RHW020T9@0S9bP00`0N
8R<04@0L82407R8S028V9`0L824092PW020T8P0P9B8082@R01`P7P0L8Ah07R8P01PL6P0I7A/06QhL
03@h=P0M8B007QlQ00806Q/M02806AXL01XK7@0R8bD0HfAV02HW:@0E5QP05QLI01XK7@0F5aT05QLK
01/L8@0J6b005QLM01@D700F5Ql07AdV01LG7`0G61h05aPM01<D6@0C51P04a@I01`N900F6B004QHO
00lG800W<3T0:C8i01LO900H7B0041@F020R8@0G6AP04a8G0P0D4aP301DD6@03014@5@0I61d05QDJ
008051<H01h04Q8D018B4`0F5QH05aLG01@D500G5aL03Ph>01<C4`0B4Q803@d=010@400?3`l06ATI
014A4@092@T04a<C01@D500;2PX04Q0A010>3`0F4Q<04`l@018>3`0E3a405a8D02<O800M6AX0510A
014=3P0<20T600l;300@010<3@0A3@h04@d>018>3`0F4Q<04Ph?00h:2`0?2``02PH700l;300B3Pl0
3PX;00h92`0B3@l0BTA7028L7`804P`?00<04@/>00`62@0=1`X00`0@2Pd04P0B30l04P`>010:300@
2P`04@/=00l92`0A2`d03@L900h82P0A2`d03PP:00d72@0D2P/0200001071`10=SL03`L700l61PH0
40H700H03@<400h41@0A1`P04@L801061`0>10D600l51P0800X00`0?10P04`P<00l4200=0PH03`@8
01872`0>0`L200l4200>00h31`0C20`0I5UM01/@500?1PP02`8401@93@0?10P030<500l5200?10P0
40L901052@0<0PDDooooo`006oooool00`0B4Q004A4?00l?3@0300h>300B014A3`0@40h03`l=00l?
3@0@40h04A4?00X:200I6AL04A4?01`L6P0<30X02`/901LG5@0<30X04A4?00l?3@0D5180410>0`0>
3P`02@0=3@/03Ph<00l?3@0I6AL0Cdm=01HF500:2PP05ADC014A3`0600d?300F010B3`0B51404aDB
014C400>40d03Ph<014>3`0?3@h03P`=00l=3P0>3Ph03`l?010@40010`802P`;030b<@0<40l02@`:
00d?300?4@h0418?00lA3P803@l<00X03Q0=014C400D5Q<04Q@A00lA3P0D5Q<04A<@00`>2`0>40d0
3@l<0P0<3P/050051`@0418?01<E4P092`P030h;00X<2@0<3P/03Q0=010B3`0?4@h03Q0=00T;2008
2PL04Q@A00X<2@0C5A80<cDb00L81`0=3@d030`<0P0=3@d01`0>3Ph0;Rh^01@D50061PH02@T9010@
400B4Q800P0>3A804P0=3@h030`<00d=2`0>3`X0414<01@E400K6aT01`L900D51`0?3a8020P800X:
20092@L0410>00X:200?3`d020P600`<2P803@d;00<02`/900`<2P0=3PT01@0=3PT09`0@4@`03Pl:
014B3@061`803a0;018C3P0;30L06adH0084000:2`H04A8=014C3P0C50l0>S`g0001000];RT0=3D`
01@E400?40X02``600l@2P0@4@/03a0:01DF40092P@03Pl900d>200<3@L03@h800X;1@05100030/6
00<2000?3PT00P4002HU800@3`X03Pd801HE400200d<1`0E00`;1P0A40/020L2018A300g=S405aHA
01<B3@0920@05A@?03Lf<@0S8Qd01PD000/:1@0>3@P03`h900/:1@0:2@@04A0;00d<1`0@3`X03@`7
008030/600X03@`700h=200>3@P03@`700`;1P0=30L03`h9014@2`0;2PD03@`70`0@3`X01@0=30P0
30/700h=2@0>3@T03@`8008030/70P0@3`/0700=30P040l;010?2`0?3PX03Pd900`;1`0@3`/04Q4=
00l>2P0A40`03Pd900X91@0^;BT0IFAP01dL600?3@T04@d:010?2`0C4Ph040l;00l@2`0@4@`05aPC
018D3`0C5A001PP300hB300A4@l2014@3P8040l=00@04A0>018A3`0A40h040l=0P0>3@/00`0=30X0
3Pd;00h=2`02010?3@0;00l>300>3@/03Pd;00X91`0510<061LE01<B400>3@/040l=00h=2`0=30X0
0P0?3P`05@0>3@/040l=00h=2`0=30X040l=00H50`0D4a408B8M018C3`0;2`T0410B018B5@0<2a00
61LL00l?4P0@41004Q8B010A3@0D4`l04@d>018=3P02014=3P<03`d>01803Ph>00d?3P0>40l03Q0?
00h>3P0E51803`h<00d<2P0F5A<06APF00P71@0<2`T040l=00L6100>3@/06aXH00l>300>30d3010>
3`<04@l@00<040h?014?400B41400P0A3a009`0@41004Q8D00l?3`0B4Q<05ADG014A4@0?3a002@T;
01DE5@0D51D030`>018B4P0?3P`04a<A01HF500E5A<0418?00h@3@0=3``041DA014F4P083@T0;C8^
08N<R00O81d05ADE018B400B4Q40410@010@3`0B4Q004Q8B018B4@0B4Q004Q8B014B3P0?4@`0418=
014C3P02018D3`80418=0P0B50l2010B3@0H014C3`0C5A8061XG01`N6`0>40d02P`9010B3`0B5140
418?014C400@4Pl04Q@A01`Q7P0;4@l03aDC01LM6`0@5Q@04QPF010F500Q9bD06R0N010F500A5aD0
4aTG0P0E6aT0100?5A<041HD01PN700I7ad201<I5`8051XH04D05A/I01@L6@0C71T04AXG01@M6@0E
7aL041XA00lI400;5@`0218901TS700Q:RL0;SLf04]DD`0>5aH06B8O014J600E7Q/03aPE00dF4`0C
71T05AhK01lX900Q:RL06B8N01TR7`0G8Qh06B<Q01XT8`0K9bD07BTX01hZ:P0A7al07B//01XX:@0_
?cl093<e0391A00O<C<07S0`01lb<00R=C<08cHc024d<00N<Bl08SDd02@f>00T=SX09CHm02Dh?`0W
>T0093Pk02Pk?`0cATX0=dY<02`n@00W>CT0:CXj02<c<`0P<2l07bh^02Dc<`0^?CT0:3@`02Da;@0V
<b`09S4[02D`:00P:b<00P0L9Qd0100N:1d082PM01lW700K9A`301`V7@1001hX7`0P:R409BlV02@^
9@0S;B@092hU02Pb:@0Z=R`0:3@Z03M2>P0d?cL08bhV02D`:P0`>cD0:SD_02hi=@0_>SH0;STe02dh
=00^>CD0B55<02<]9@0[=Bd0;STa02Tf;@0P;RL093@a02Ti>00dATT0<45803Q:E01[OXP0AUYU03Q<
E@0hBeD0>4YD02e0A`0gBE00B5UQ055PI`0a@4L07B`c02He>P0c?d@0<Se102dj@01?G6<0<d1903A2
C@0e@dh0=49;0393BP0bA4T0<49402i0@P0Z>Sh0;ci30391AP0[>Sh0;Se002Xh>`0[=SP0:3<e02Da
<@80:38c01X09Bl`030e>00R9bX0:Bh`02dc<@0R:2@0:C0Z02H/:00W;BT09bdZ02H/;00V:bh08RLZ
020T9@0T:2T08RHW01dQ8P0O8b@07R8S01`P8@0M8B80720Q01hR8`0Q9BH07B4Q020T8`<07B8N0P0I
7QX06P0P9B405AXF01/P701CF5@0`/O302ld<00P8B<07QlQ03dn@00O82806Q/M01TJ700^;c408b@V
01PI6`0>3a406a`N01lP900F5a`071dR01dN8`0I6Ql051@K018B6P0G5al05ADL0P0I6Ql201@E6P0<
02//<@0Y;380724W01DL900@6240=3e608VBV@1jPXL09bla01DJ700N81l06Q`K0P0E51T04@0F5AX0
61LL01TH7@0I61d05aHK01<B5`0B4AH02`X?01@C600T92H06QXK00L71`0R8R806ATI00X:2P0G5aL0
3Ph>008061PH01D04a<C00`<300H61P092@T010@400820P03`l?01PF5`0?3@h03@/<01<?400A3@h0
510A01H@4P0A30d05a<D01<?400A3@h0510A018>3`0D41401@0A3@h2018>3`0N014=3P0D41406QHG
01@@4@0<20T06aLH00h:2`0D4140100100T51P0<1`T030H:00l93@0;1@T01`4501<=4@0@2Ph02@<7
014;3`0=1`/04@/?01`F6P0K5AP04`d?01D?4@0?2@/0100000h82P0B30h03PP:0P0=1`T0200:10H0
3@L90147200=0`@06a4B06=IFP0P5QL03`D61P0@1PL01P0<0P<03`D601<92P0D2P/04PP900h41@H0
3`D600T03P<701052@0C20`040D900l4200A1PX0304500/0100=0PH00P0?10P03@0>0`L01`0000l6
200I3Q802@0200/2100=0PH02`0400X10`0A1PX03P<700/1100;00@05?ooool001_ooooo00<04Q8@
014A3`0?3`d00`0>3P`200l?3@803Ph<0P0?3`d0300:2PP09BDS008200061P@051@B00L71@0=3@/0
3Ph<01TI5`0?3`d04A4?00l?3@<03Ph<00T03`l=00h>300=3@/03Ph<028R80010@005QHD01LG5@0<
30X01P0=3``07@0@4Pl04A<@014C400B51403a4>00h>300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0D
51@05aTH014C4P1IFeX051PG00`?3@0=3``0418?014C400?4@h03@l<00lA3P0=3``02P`900`>2`07
2@H02@/80080828O03<03a4>00D710051`@02P`9018D4@051`@00`D200h@3@0A4a004aDB00lA3P0;
3@X03@l<00h@3@0=3``030h;01@F4`0P8Ql0008001DG500@4Pl0@TA1018C4@0>3Ph03@d=00/;2`0<
30`03Ph>01HF5P0@41005ADE00P820061PH03Ph>010?500?3Q<03Ph?00h>3P0>3P`0414<00L80`0=
3PT03@d;00L72@0H61X04a8F014A4@0B4Q0030`:014A3`0>3P`00P0<30X01@0>3P`02`/900T91`0;
2`T0410>00H03@h901@020T4010A300=3PT02``701HG4P0@4@`05QLB034a;0051P4040l;00L71@0>
3`X02PT501@D4@0J6aH00@00014A3@0=3PT030d700X;1@8030d700h02``600d>200=3PP02P/500D6
000:2`D0414;00P90`0@3`X03`h901@C3P0@3`X04a8=00<200803Pd801402PT400/:1@0I61<04Q4<
01DD3`0<2`H04a8=038a;00?3PT02PT400`;1P081`807QdH018A300920<05aHA00l>2@02018A3004
00T8100C4Pd03@`700d<1`<03Pd800D02`X500X9100A40/02PT400/:1@02010?2P803@`700/030/6
00d<1`0?3PT04A0;01<B3P0H5a<06QTE010?2`0510001PD100/:1P0200l>2P0E00`;1`0?3PX03`h:
00l>2P0>3@T03@`8010?2`0B4@d03`h:00`;1`0D4`l04Q4=00/:1P0920@01PD100/81`0?2`P03@`8
01HE4@0D4`l03Pl:00804Q<>00L0004000lA300C5A003Q4<01<C4@0C4Q0040l=00<03@`:00<04Q4?
014@3P0@3`d00P0>3@/00`0=30X03Pd;00l>3003010?3@0;00l>300>3@/06APF01HE4`0M71X02`X8
00h=2`0@3`d03Pd;00`;2@0=30X00P0?3P`0500:2@L04a8@00d<2P0@3`d03Pd;00D40P0F5a804Q8?
00l?3@0@41803`lB00`;400:2@h03@`@014A4@0@41003a0<01DD400?2@/04@T<0P0@2P`0400?2``0
3@/<00h<3@0?3@h03Ph>00d=3@0>3Ph03`l?01<B400?3P`02@P600/:200>3@/02@P600d<2P0<2`T2
00l>3005010?3@0H5aD03@/<00d;300>30d0100?3@h00`0@3Pl03`d>00l=3P0200l=3P0T00`<2`0>
3Ph03@d;010@3`0B4Q80410>00X:2@0C4a<0:2PV02<S8P0;2`/020P600`<2P0D518061PF01HF500=
3``020X700dB3P062`L010T500D;1`0a=c<0RXn;01TJ5P0@40h03@h9010@3@0@40h0414=018C3P0B
4Q004Q<?018C3P0B4Q004A<>0P0@4Pd2018D3`0301<E400@4Pd0418=00804Q@?00X04A<>018D3`0B
51005ALD02LY9P0D5Q<02`d:01XL6@0A4a005QPE0P0B51409@0D5Q<071hK03]0?@0L9B80214>00hG
500330T031DB01HO700G81d07RLT051IEP0L9B805QlL014J5`0B6aP03AHC00`E4P0C71T05QlL00lH
5@0@6AH04AXG01<L6@0D7AX05AhK01HN800B71d04QdJ018M5`0>6A4041`B01HR5P0?6a4051lF00TD
3P084`l00P0F8Ad0;00B7AL05R4L00dH4P0A71H07bXV018M6@0D7a/06RDQ01/U900G8Al05b8N01<N
6P0D81d05B4O01HR800H9B@05bDU01TW:00J:B/03ahQ02Th>`0`?d<0CUeP01d_<@0L;Rh072l]01ha
;`0P<bl07c8^01lb<00S=C@093Hh02@f>P0T=C`09CPo028e>`0V>ch093Tl0396A`0jCDl07Bl_02<e
=@0Y>SX0:3Pg0P0O;Bd03P0U=340:CD`02@_9`0Q;2@082/S024[8`0P:R408bdT020W7`0N9Ad07bHN
01hU7@0M91`072LO0`0N:B40100Q;2@092lW02Pc:`0W<RX202D`:00702Xe;@0_>S80;3T_03M4>`0d
@CP0:CH]02Pe;P0202dj<`0a030l>00a?CT0;c/g02hj=P0_>SH0HVaU02dg;`0V<BP0;CT_030m=00Y
=c00<40m03=3@P0Y>ch08c@k045CG@2;WJL0BUaV03a>F00cADh0=DQ?02Xk@`0_@4L0>T]B03]:D@0]
>d40;3To02/h?P0Z=S/0;cXn03]8CP1NJg80=T=<02Tg@P0^?4H0<Cm80352B@0b@dT0<49402m1@`0/
?400<T5603=2A`0Z>Cd0;3/n02/i?00U<3809c8d02Lc<`0202@^;`0A02Tc=00_=3L09B/[02X`;`0e
>cL0=3/d03Y1>P0V;BH0:C0Y02Xa:`0T:RP08BLW02D[:`0M8B808BDV020T9@0K7b000P0M8B801`0J
7Ql07B4R01dQ8P0M8B808BDV01dQ8@0O8b800`0K81`201LL600G01/P700I7QX0724M05eRGP3Kh=`0
>Slk020Q8`0N7b40?Sm1020Q8`0J6ad061TK018C5@0?41805aPJ01dN800T9BL02@X>01PI7P0J6R80
6a/S01TJ7`0G61d00P0F5a`04@0D5AX05aPM01LG7`0E5Ad06ATQ00X=4P0K7R@06AhT00lF7P0O9bl0
JgEn0>Scn@3?e]T0<CTk01XP8@0?4a806Q`K00805QDJ02L05aHK01TH7@0J6Ah06QTN01HE6P0B4AH0
5A@I01<B5`0S8RL0>3Pj06YZJ`0;2`/02PX:00h>3P0@41006QXJ018B4P0G5aL051@D00`<30092@T0
6QXJ018B4P0D51@092@T01@D500>30d030X;018@4@0E4A804`l@01HB4`0G4A<040/=01LC500B3Pl0
3@T:00l;300<20T01`0A3@h0400B3Pl040`=018>3`0H51D04`l@00d92P0<20T00`00014=3P0C3a00
40`=00d82`0I51P04`hB01D@50060@D2010;3`0B00L21P0?2Ph03PX=018=4@0/9b/0RhF804U3A@0:
1@H05a4C00h82P0A2`d040X<00d72@0>20X03@L900T31@0:10H05@/<0P0;0@800`0S6AX040H70106
1`0601061`0300l51P0@1PL04@L800804@L800<040H700l51P0?1@H0100?1@H00`0?10P040D90146
2P0601052@804PL;00<03@8601hC5`0B1`/00P0<0@D0200C20`02P0300L0000K41@050T=00L0000B
1`/03`@85?ooool001_ooooo0`0>3P`0100?3`d04A4?018B400>3P`400l?3@0:00h>300C4a403`l=
03Xj>00[:bT02@T701DE4`0?3`d04A4?01/K6@803Ph<00h03@d;00l?3@0>3P`03`l=014A3`0?3`d0
3@d;00l?3@0G5aD020P600h>300;2`T04Q8@00d?30<03Q0=01T03@l<00`>2`0A4a003@l<00`>2`0?
4@h03Q0=00h>300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0>3Ph030h=00h@3`0@4Q403a<B00d?3@0?
4@h0418?014C400?4@h03@l<008030h;00@061XG02/]:P0I6aP03@l<0P0>40d01P0B51405aTF018D
4@0?4@h030h;01@F4`802`d:00@03a4>00L81P0>40d030h;0P0=3``02@0<3P/03@l<00/=2P0;3@X0
3a4>03do?0082PL04A<@00h?3@0200l?3`0700`<300;2`/03@d=01<C4`092@T02`/;00X:2P0200l?
3`8040lD00h03`l@00h>3P0?3`d0414<00`=2@0C50l02@T701@D5P0m?Cl08b8V00L71`0J6QP04A4?
00/;2@80410>01L02PX800l?3@0=3@/02`/900l?3@0L71X030d800d>2@0?40/030d800d>2@0?40/0
30d800d>2@041@4051D@00T:1@0H6A@061LC02TW8`081P80518>00l<2@0201@B3P0500`91`0=2`L0
518>00/91P0;2PH00P0?40X300h?2@0@00`=1`0?40X03Pl900X;1@0B4`d07AhH01<D3P0;2PD030/8
014@2`081`@04A0;00P7100=30P06aXE01lN6@8071/F00T03@`700`;1P0>3@P030/600l>2@0;2PH0
4a8=00d<1`0?3PT00P0>3@P0300@3`X04A0;00h=200B4@`04A0;00h=200A40/040l:00T80`0<2`H0
3@`700l>2@<03Pd800H02@P300/:1@0@3`X03`h900/:1@0?3PT200d<1`0700h=200@3`X040l;01@C
3`0H5a<04Q4=00h=2@0201LF4P803`h:00@030/700l>2P0?3PX03Pd90`0@3`/05`0?3PX03Pd900`;
1`0>3@T030/700/:1`0;2PH07QdI02<Q7@0@30P03Pd801<B3P0?3PX04Q<=03dn>@2:RhH0H69L01`N
600;3@L041<=014A3`0@3`d03`h<00803Pd;00@04A0>010?3@0@3`d040l=100?3P`00`0@3`d04A0>
014@3P02010?3@0500h=2`0H5aD0<S4_01<B400B4@l00P0?3P`0600>3@/03@`:00`;2@0>3@/04A0>
00d<2P0F5A<03@`:018A3`0F5A<03Pd;00h?2P0@40d04A4?010@4P0>3Q403PdB00T83@0?3Q80410@
00h>3P0<3@T03`h:01082`804PP<00/04`T<018:3@0A30d04`h@01<@4@0@3Pl03@/<00d<300?3`l0
3`h<00l>2`0200`;200H00l>2`0D4a0040l<00l>2`0E51404a8?00l>2`0I61H03P`=00`:2`0=2``0
40h?00l=3P0=2``04a4B01HD5@0B41404@l@01@B4`0B4140410=00l@300@40d03a0<0P0?3``01P0?
40`02`/800l?300@4@d03`l<014A3P803@d;01003Ph<00l@3P0A4a004Q@A00hC3`0:3`/03A8>00hD
40093`/061dI018D3`0A4Pd0414<01@E3`0G61<05aPB1P0C50l5018D3`804A<>0P0B50l0600C5A00
5QPC01<E4@0A4a00:2XW01@F4`0<3P/07AlL00lA3P0I6aP05ALD014C400@4Pl05aTF034f<`0C71T0
1Pl<014J5`0:4a003QLD01/T8@1NIf@0>44n03Ho?0804AXG00D02a@A00`E4P0D7AX0624N018K6003
00hG501E010I5P0A6QL04Q/H018K6@0D7R0041XM010J6`0B7AT04A`D01HQ600G8aL06BDH01HR5`0A
71@041/D01HQ700I91d06RDN01LR6`0B7AL072LQ03M2?P0G8Al05b8O01HP800C7Ad05R0P01TS8`0I
9B806RHS01/W900L:2H072TX01/Y:@0J:2T08S0b02Pg>P0^?d808S8f028b=@0P<S@07c8a024d<P0S
=S8093Lc028e<@0O<S008SDe02<e=`0Q<ST08C8j020c>P0U>Sh09C/m02<h>P0U>CX0:Shn02Tk>`0]
?cl09CHe02Ph=`0P;Rh0:3He02@a;P0U<RP09C4V028^8`0O:b007RPN01dW7@0R:R808RTQ01lV7P0N
91d07bDN020W800M:2407b/S020/9@0R;RL09c<[02Xf;P0V<RX0;3Pa02di<@0202Pd;@1?02/g;P0_
?380;3T`02dj<@0d@CP0;CXc028_:00`?CH0<clk03A0?00`?3P0;c/g02ll=@0X<R/0<cde03<n=@0e
@CL0=T<j02`j<`0X>3D08c<b02m1A00hBE00<DA;03iAFP0Z?4H0=4I@03E7D00eAdh0<T=;03A4C00_
?dH0<T5703M5B`0c@4H0:SLm02/g?00f@DH0>4E<034nA`0`?DH0;ce8034oB@0b@4T0<D990353A`0b
A4H0<TA40310@`0a@4D0<d9702ln@P0X=cX0:SPk02Pc=@0Z=CL0:CDe024[;00P:R/09S0a02@Z:P0Y
;bl0:S0]03<j<P1?ETd0K7AY03Dl<`0_=bd0:S8Y02D[9`0P9R@092XZ01hR8`0O8b@07B4R01`P8@0P
92D0720Q01TM7P0301dQ8P03020T9@0O8b<08BHR00<07B8M0P0I7QT03@0M8Qd082DP01/P6`0Q9R40
@DI101@I5@0L7Qd06Q/M01`M7`0K71h06Q/M020Q8`0O82800P0P8B<0100G61X07AhP01LH700G61d2
01LG7`0301PI7P0H6Ad05aPL00804a@I01405aPM01HF7P0G5al07alW04a?E00O8bT03A8H01@K8`0J
92`0@deF09RSZ@2;UIT04QXL01HK7@0?4a804ADD01<B5`0201@C60<05A@I00d04a8G01DD6@0G5Q/0
4a8G01@C600K6ad05aLH01HF5P0E5AD04A4A01<C4`092@T04Q8B00803Ph>01D04Q8B01lO7`0h>3P0
CDe=00410@0J6QX051@D00h<3@0A3a003P`=010<3@0>2P/04Ph?018<3P0=20T05Q8C01<?400?2``0
4Ph?010<3@0B3Pl01@0?2``0:P0@30d04`l@01<?400?2``04Ph?01<?400?2``05a<D04]7B00P71d0
3PX;00d92P0F4Q@030L<00d93@0@2a002PD:00h93P0A3A403PT>00T42@0P6b0061<H00`8300T7b80
2P@601@>40060@802`H7018<3P0;1@L03PP:01TC5@0K5AL04`d?00l92`0=0`@040H701<92P0;0P<0
4PP900l51PP040H700@03`D600h41@0?1@H040H71P0?1@H00`0>0`L03@8600d21P0300d21P0B0105
2@0?10P0304501052@0C20`02P4300h51`0A1`X03P<700d41P0<0`D040H901<8300B20/03P@700`2
1@0@1PT050T=5?ooool001_ooooo00<04a8@014A3`0?3`d00P0?3P`01P0>3P`040l=014@3P0A4@l0
4Q4?014@3P803`l=00T04A4?02HV900820H04A4?00`<2P0E5A<02`/9010@3P0=3@/00P0E5A<03P0?
3`d03@d;00l?3@0B4Q003`l=00/;2@0<30X03`l=00T91`0?3`d02PX800`<2P0<3P/03Q0=0P0?4@h0
3@0<3P/02`d:01@F4`0=3``030h;010B3`0A4a004A4?010>3`0?3@h03@d=00h=3P0>3Ph00P0?3`l0
1@0E5aH02`d<00H71P0D61L03a8@00<0418?02003a4>00h@3@0@4Pl01`T600P:1`0D5Q<01`T600H8
1@0C5A80418?00h@3@0<3P/02@/800lA3P0@4Pl04Q@A00@60`0D5Q<02`d:01PJ5`0j?3T03a4<00h@
3@0<3PX03@l:00h@3@0B5100004001PJ5`0;3@T05QPC00H81@803`l=01X04Q4A00h<3@0;2`T03Pd<
00T7200<30X05QDD00L51P061P@03`h?00h>400=31403@d?00`<300=3@d03Ph<01DE4`0820H04a<C
010@4P0820X04A0D01`L700n?S`0;Bd[00T91`8030`:00T020P6014A3`0C4a402PX800H6100@40h0
2``700d>2@0?40/00P0<3@P05@0?40/01@H100`=20092PD06Q/F01<D3`1lOGP071/G014>30030P00
30P5014>2`0510001`<001LD4@071P803`/8014?2`0>3@T02`X600d>200200`=1`0B00d>200;30H0
1PL100l@2P0;30H03@h801DF400:2`D04Q4<00`;1P0920<05QD@00d<1`0H5a803Pd800`;1P0F5A00
2`X50P081`800`0=30L03Pd8014@2`0200h=200F00L60@0@3`X07A`G00T80`0?3PT04a8=00H5000<
2`H03Pd800P70P0?3PT02`X5018A300?3PT030/600X9100;2PD030/600d<1`0;2PD03`h9010?2P80
3`h900/040l:00d<1`0?3PT040l:00l>2@0=30L03@`800l>2P0<2`L020L300X91@02014@30803Pd9
00T02`X600h=2@0>3@T030/7010?2`0C4Ph040l;00`;1`0=30P00P0>3@T01P0F5A403`h;01TH5001
00009B@P00h=20804Q4<01H03`h902<T7P20PG/0oooj0<G8`@0Z;BH05aXC00hA2P0E51804a8@010?
3@0>3@/03`h<018A3`0>3@/03`h<010>300A3@`04Pd:01<=3@0A3@`040l=0P0A40h2010?3@0600l>
300L6aT02`/900L610061P@04A4?0P0>3@/0600=30X02`X800d<2P0B4@l03@`:014@3P0C4Q006QTG
010?3@0D4a404a@?00l?300=3@/03Ph>00l?400>3Q00410B00d=3P0:2PX03Ph<014B3P0>3@T04`X=
01@:3@8050/>00<050d?01@>400?2@/00P0A3@h01P0>30d04A0@01HF5P0?3P`03Pd9014@30<04Q4=
00L03Pd901<B3P0>3@T04A0<01HE4@0:2@L040l=00803@/<02P04Q0A010>3`0>30d03`d>01<A4P0>
30d03@/<014?400?3P`03@h:00d=2`0?40/03`l<00h>300@4@`030`901@D4P0C50l051DA014A3`0:
2PP030`:00h>300B4Q005QPE01TK600J71T030l<01PJ5`0?51003A8>01HK5`0:3`T04A8=01<D3`0A
4P`03Pl9014B3@0D5@l04a@>0P0C50l00`0C50h04a@?01<E400201<E4P04018D4@0A4a004A<@014C
40<04Q@A020051HC01PJ5`0K7AX04A<>01@F4`0D5Q803a4<01LI5P0D5Q806Q`G01XL6@0H6QH04aD@
01PJ5`0V;2P06R0L01@J5P0<4Ph051XF01TO6`0=4`l0B4i:02L]:`0J81h06AlM01@J5`0C71L031D@
01DN6@0H8A`03AHC010I5P804a`K01`04a/L018J700A6A/04ATL01LN9P0B6b804a`P01@M700?6QH0
4A/E020Z8@0Y=BT06B@I01PR6@0H8a/06R@L00/G3@0/>2h05B0H024/9P0E81X06bHR01<M700K9B@0
92h_02<];`0K9BL04adN0P0H928201TU8`0b01PU9@0G9BD072X[01XX:@0U=3L08S4d02@c=P0S<SD0
7Bl_01h`;`0P<c408cHb028e<@0O<Rh08cHd02Hh=`0U=cT08cDi024b>P0P<cX09ca101he>@0/@D@0
9CPl02Xn@01UNGX0D69R02ho?`0/?3/0:CTh03E4@@0R;bP0:3@Y02Xf:P0Y=BT0930T020Z8@0O:B00
7B@L024X800N9Ad06b0J020U7`0T:b@06RHP01dZ8`0P;BH08c0Y02Tf;`0/>C8202dj<`0802Tf;`0V
<b`0;CXc03A1>P0[>2l0>TLn03E2>@0]>S4202hk=004034n=`0d@3`0=40l034m>@80;c/g05L0=D0i
03@m>00Z=Bd0?DQ004=@B@0_?CL0>TU603Q8A`0^?Sl0<3m403A5C00b@d/0@55I0311B`0a@TX0=DI>
02Pi@@0jBU40;ci502hmA00iB4l0=4=:030mA@0c@4P0:SLo0350A`0iAe00<3i702Le@00hAU00?4YC
03M8D00b@dT0;T1402do@@0Z>cl09CLk02dl@@0`?d@082lb028`<`0[=SP0:3@d02D`;`0S;B`09Bh]
02H_;P0W;Bd0>Clo03Hk>017CTH0TIV>0>[`iP17Cd80=Cdb02L^9@0X;RX092XX01hT900Q9BH07b<R
01/O7`0O8b@08bLV01`P800G6a`0720O01dQ8@0L82407b<R01lS8`0O9200724K01`Q700L8Ad061dG
01PM600C61@06QlJ02<X8P0Y;RX04aPC01XO6`0H6QT07b0R00`=3`0U9RP00P0H6A/0200Y:R`071dO
01lP8P0O82807QlQ00h?4`0H6Ah06AXO0P0K7240600H6Ah04a@H01<D600G61`07AhS01dM9@0L72@0
8b<[05QKH00H72803Q<I01dT:P0@62005QlV01XS:P0T;C407RHY010E5`0G6a`03a0B01<C5`0C4QP0
4a8G01<B60804Q4F0P0F5AX08P0C4QL051<H01@C600B4Q@05aLG0000000<30`05ADE01TI6@0A4A40
51@D010@400B4Q803Ph>00X:2P0M7Ad0410@00`<300H61P03Ph>01hL7@0@3Pl04Q0A01@@4@0C3a00
6ADF01PD5@0B3Pl06ADF01DA4P0@30d04@d>00l;300B3Pl6014=3P0M01DA4P0F4Q<03PX;00l;300D
41404@d>01HB4`1jMWL0;b//01TE5P0>2P/0<2`^01PC5`0@2`l03@P<01@?4`0<1`/01`8601XE6@0H
4aL0KVU]05mJGP0=20`04@/>00P2100I4aD09R0R00`6200>2@X00P0;1@L02P0?2@/03@L900P2100<
1PP03@<401H<3@0=0`@04PP900l51P0C2@X601061`803@<40P0?1@H00`0>10D03@<400l51P0500l5
1P0501462P0?10P03P<700l4200@1@T00P0?10P04@0A1PX040D901T>4P0T6Ad07Q<G00`11@0:0@<0
3@8601T>4P0A1PX040D901462P1lLGD05``@00L0000H3A403P<701Cooooo000Kooooo`0V010<2@0A
3P/040l;010<2@0@3@X040l;018>2`0=2PL040l;01DA3P0C4@d051<?010A300;30L03@h901DF4@0>
3`/0HV=N06Y[IP0C50l020T401<D3`031000;Rh/01lO7P071`L02PX:00h>3P0=3@d04A4A01@D500I
6AT0000001DE5@0D51@030`<00d=2`0C4a42018B400300h>30071`D03Ph<00L03Ph<04803@l<00h?
300=3``03@l<010B3`0=3``01@L401<E4P0A4a003a4?00d?3P0A4a804aDD00D71P0620L03a4@00T;
2P0:30/0418A00`>3@0=3`h03Q0<00T;1P0<3PT04Q@?01DG4P0L7Q/061XG01/M6P0=3`h06Q`K0001
000L7Qd05aPD00T:100>3`X02P/601DF400;30L030d701/L5P0R8ah04A8<00d>200C50l04A4=00d<
200<2PL03`/:00l>2P0A3P`04@d<00L60P0H5Q<040`;01lN6P0F4a803@d?00X93P0F5AX03Ph@00L7
2@0>3Q004Q8D01<C5@0:2P`2018A5P0T00d<400>3Ph0/k>a05QHEP0C4a405QHD00X:200A4@l0410>
00h>300=3@/03Ph<014A3`0=3PT03a0;00d>2@0<3@P04a@?018C3P0A4Pd03@h901HG4P0?40/03Pl:
01<D3`0D51803@d;00`<2P0>3@/03@d;010@3P0:2@L02`X800h>300B4@l04A0>0P0=30P02@0>3@T0
3`h:00l>2P0>3@T03@`8018A3@0>3@T03@`800h=2@02010?2`0600/:1@0?3PT03@`700h=200B4@`0
40l:0`0=30L01@0:2@@04Q4<01dL5`0B4@`030/600803@`700<03`h901@C3P0=30L00P0=30L01@0?
3PT040l:010?2P0?3PX03@`8008030/70P0=30P01`0@3`/03`h:00L60P0=30P040l;00d<200?3PT0
0P0@3`X02P0?3PT030/600/:1@0920<04Q4<01LF4@0>3@P02`X5010?2`0?3PX200`;1`0?00l>2P0>
3@T02`X600d<200@3`/03`h:00d<200>3@T03`h:010?2`0B4@d03`h:00`;1`0>3@T040l;00D03`h:
01d03Pd900l@2P0A4P`0414;01@E3`0N7aT0ADI00=KGd@27R8805aPB01@E3`0C50h040`;014=300B
3`h04a4B00D51@0:2PX06aXH014@3P0>2@H06@l>01/@3P0G2PX06A<C014=300C4Q00:2LU02TX9P02
010@3P0?00T91`0:2`P05aLE014C400<3P/0000001XJ600:2PP05ADC01lO7@0<30/04Q8@010@3P0>
3P`03`l=00804A4?00H051<?010?2`0>3@T03`h<010?3@0?3P`200h=2`0D00l>300>3@T03Pd900d<
200@30d030P901TE5P0<20T04@d>01/G600>2P/04Q0A010>3`0I5aP03P`=018@4@0F5A<051<A014@
3P0@3`d2014@3P1B00l>300;2PP020L501@C4@0@3`d03`h<00L6100;2PP040l=018A3`0?3P`03Pd;
018A3`0A40h040l=00l>300=30X030/9010@3P0;2`/030`:00l?3P0?3`l03@d;00`<2`0?3`l03Ph<
00d=300?3`l04A4?00l@300=3PT03a0;01TJ5@0H6A@0414<018C3P0D5A0030h901DG4P0K7AP051HA
00lA300B51403Q0;00h@300?4@h03a4=014C3P0A4a00418>00lA300B51404aDC01/O7P093@`03Q8A
00lC4P0D61L0310?010D4`0D61L03A4@00`@3`0@51<04QHC01<H4@0D6A<04QLA00lD3@0?50h041D?
00lD3@0A5Q004QL@00dB2`0@5@l04QL@014F3`0C61404AH?00lD3@804AH@01h05AXD01TN6P0L8Ad0
4QLC00lD3`0G7QH05QhC01@K4`0C6Q<04QPD01<I600?51L04aPL01@I800G6bH06alZ01LK9`0@5200
41LQ01DK900G72005alQ01`S8P1:D4`0_lW104A<A00P9al07bTP01XR6P0P:R4201/U700<01LQ6@0R
;2@04AXE01<L6@0B6aP07BHU01dU9`0H82806bDW01LS8`0J9RH06bLW0P0J9RH0100K9bL07b/[020/
;00P;Rh2028`<00P020^;P0S<c<08C4`028b<@0U=C808c@_01h_:@0S<c007bl^02@d=00U=3L08S4g
02Df?P0T>4<0:d5<02HmA@0W>d80Bf1V055TJ016FU/09CTg01T/:P0Z?CT093D_01LX800Y>2h09C8X
02Hc:@0R;bD082/S02D`:00i@c/201hU7P0;02L/9P0V:2<08RLQ02La;@2>VID0;3Lc02dh=00/=c<0
;cXf02/f<P0]>3@00P0Y=300100[=S80:CH_02/j<00Y>34202Lf;`1K02`k=P0`?cX0<D0k02hm>P0]
?3T0;Sdj02`k>00]>CL0=D4l03@o>`0b?cP0>4Dn03<o>`0Y=C80;3Pf02lm?@0c@D40<T11034o@P0_
?4<0;ca40390B@0c@TT0=4=:03E3C00hATl0=49;02Hg?`0hBE80=DI@0390B`0W>440;d9902Lh@00i
BU@0;Sm903E6D01WN880>daF03U7DP0b@4T0;C]403Y8D@0]?DD0;3m502/l@`0Y>Ch0:3Ll02hl?`0R
;Bl09c4b02/d<P0V;2X08RPV02@Y9`0R9RL0:2`]03Hj=`0]<R`0LWM`0:fcZ@0g?C<0;38X028Y8@0Q
9b<07bDS028X:00S9bH07R<O01`P7P0H71/08bPT01`Q7P0M8B007R<O01dR7`0E6AP03Q<?01/O7@0Q
8b807R0M01/M6`0K7A`06adJ01HH5P0K7A`071hL01`N6`0L7Qd071hL01dO7P0201`M7`<06a`N00P0
6Q/M01`M7`0H6A/07b0R01<D5P0A4Q@051DG01@C608061LL00/05aHK01TH7@0N7B806aXP01TH7`0H
5al06APP01LF7P0B4QX05APM01DJ7P02010E6@0N01HK8@0E6R0051LN01LJ7`0C5Q/03PlD010A5@0E
5Q/05QLL00X:4P0D5AX05QHM01<B600>3A<04A0E01@B5`0>31406aTL00h<3`0E4aH0518C00@20`0D
4Q<07Q`M04e;C01?CDh03`d>010>3`0A3a004Q0A0P0C4A801P0K6A`0BDM:00/9300<2Pd071XM00/9
30D040hA00@050lB01LC500G4a@04Ph?0`0A3@h2018>3`04010<3@0>2P/03@T:01@@4@803@T:00X0
4@d>00d92P0K5aP01P8301@@4@0C3a004Ph?00`82@0D41403PT;0P0?2@/01P0@2P`03`T;00l92`0?
2@/03PP:010:30806A<E03d040X<00d72@0@2P`03PP:010:300A2`d03PP:014;3@0:10H03PP:00@0
000K5AL030L800l4200C20`040D900d21P0B1`/04@H:00X00`0=0PH04@H:00X00`0G31003P<70105
2@0B1`/04`P<00l4200=0PH03P<700l4200<0@D040D904Hk?`1<@DD09Q/O01@8300900405@T=0145
2@0=0PD04PH:00h21P0@10P04@D901<72`0E2@d05PX>01X?4`0<0`D04`P<03<X;01EBTh030450146
2P0U6Qh06@hB00`11@0@1@T05@X>01Cooooo000Kooooo`0J00l<2@0B40`04a4=014?2`0@3PX04@l;
01LD4@0A3`/040h:00h<200=2PL040l;00P9100@4@`02@X501@E400<3@P08R<N01DF4@0B4`h03a0;
00/<1`0@4@`0=CHa01dM7@0<30`300h>3P0901@D500J6QX04a<C010@400G5aL0<c<c010@400=3@/0
2`/900803Ph<00<03@d;010@3P0>3P`01@0>3P`600d?301600/=2P082PL051HC01@E4`072@H061XH
00d?3P082PT04A<B00`>3@0:30/03@l>00X<2`0;3@`03a4@00/=300:30/03a4=00lB2`0?4@`0418=
00d?2P0@4Pl051HC00P:200U9bH0KFm^010B4@0<3Pd0418>00/<1P0E5Q003@h8014B300:2`H04a@>
01XK5P0J6aD03Pl:00l@2P0A4P`07AdI02HS8@0E4a003@/800l<2P0D4@l061DC00`91`0H5Q<03`d:
01LD4P0@3P`02PX<00l?4P0:2Pd0410C018A5@0J6Ad061PK00`;3`0B4QD03PhA00/:3P0B4QD09bLW
01`L6`0U9B<01`L6018B40L03`l=01002``700l@2`0@4@`03a0;018C3P0=3PT04a@?00T:1P082@@0
4Q<>00/<1`0C50l0410>00`<2P0?3`d0410>0`0=3@/01`0>3P`0410>018B400A4@l03@d;00/:1P0<
2`L00P0=30P05P0<2`L02`X6014@2`0>3@P030/600d<1`0>3@P030/700X9100>3@P030/600h=200D
4`h04A0;00l>2@0>3@P040l:00l>2@0F5A0081lJ018A300>3@P200l>2@0D010?2P0D4`h030/600l>
2@0A40/040l:00d<1`0<2`H03`h:014@300B4@d04A0<00h=2@0<2`L03`h:00d<2P0C4Ph030/800l>
2P0920@700h=208051<>01H0QhJ1030_:P0>3@P03`h:00d<200>3@T03`h:00h=2@0<2`L03Pd9010?
2`0?3PX03@`800h=2@0?3PX040l;014@300?3PX03Pd900l>2P0@3`/03`h:0`0>3@T0100?3PX03`l:
00l@2P0>3`T200d>200b014B300F5a40;RlY01dN600E5Q801@H101DE4@0D4@d04a0<00l=2P0D5A40
3Ph;018D400:2PL03`h:01<?2P0G3@T07A0<01hA3`0F3`d04Ph=014@3P0E518051<A00d=2`0:2PP0
4a<A00d?300:2`T0;Bl/03]0?00F5Q@02`/901TI5`0:2PP05ADC01HF500@40h04Q8@01HF500D5180
4Q8@014A3`0C4Ph040l;00h=2@0?3PX040l;00l>2P0>3@T200l>2P<040l;01<03`d>010>3`0=2``0
2`T:00d;300A3a003@/<01@B4`0_;Bh0clg>040n?`0@3Pl040l=018A3`0C4Q004Q4?00l>300<2`T0
3@`:00804a8@00L04A0>01@C4@0B4@l071/I014@3P0;2PP03`h<00804A0>00T03`h<00h=2`0>3@/0
3Pd;00d<2P0<2`T0410@00d=3@0>3Ph00P0@41003@0?3`l03@d=00l?3`0?3`l03Ph>00l?3`0A4@l0
4Q8?014B3@0B4`h04A8=00d>2@0<3@P00P0A4Pd02@0<3@P04Q<>01LH4`0@4@`04A<@018D4@0>40d0
3a4>01@F4`02018D4@0D01@F4`0C5A804Q@A01@F4`0D5aD05ATI01<G5`0G6a/05ATI00dA4@0A5AD0
4aLG01@H600?4a<04ADE01DI6@0A5Q8041D>01<H4P0D6A82018G4008014F3`0?50d04AH@01@I4P0?
50d041D>01<G3`0C5Pd201DH3`0]01@G3`0F6A805aTC01PJ5@0E5a806Q`I01<E4P0@50l051TA02Xb
9`1FGE@06B0I00lE4@0B61L04aPK01DJ7P0D624051PR01HJ9P0B5B804aLS01@H8P0E6B805AXP01LL
800L8R<0LgUi0;Fk^@17CDP07B@M01LO5@0M91d08R`S01<M500F81T04adF01TS700C71P07RLT020Y
9P0F7ah072@U01/S900N:2X06B@V00806RHX04006BDW01/X:@0N:b/07b`/01h[:`0M:RX07R/Z024^
;@0R<3008c<c02Ph>00_?ch0<40m02Ti=@0N;bT0830]020`;P0W=cH0:STl02/j?`0]?TH0AEUU0316
D`0S>D@08SHo0396C@0^@dH0<TE902Tm?00V>SH08SDa02Pl=00M<BP093@[02@a:@0X=Bd09c@/02Td
;@0/=c00;SPa02L]:00U;2H09BXU02HZ9@0Y;b/09S0]059MF@0X<bl0;3Lc02/f<P0c?SX0<C`h02lj
=P0]>3@0<C`h038m>@0]>S<0<d8i0350>@0_?SL0;C`e02hm>00a@3/0;Sdh0`0_?S/01`0X=SH093<`
02lk>00a?CT0=40l03M3?`0a?C/00P0[=cD0AP0Y=CD0;SXj030l?00/=cT0;STn03E0A`0e@TX0<d18
030mA@0^?4D0<3i702Tg@00lCEL0;d1;0311C00^?dX0:Sa80396D00[?DX0<dE@02doBP0^?dT0BU]U
02`mA`0`?TP0<T1:0350B00kB580;Si602Dh?`0U=ch0<T9802`k@00W=CL09S0a02Tc<P0Z<c409R`X
02DZ9P0Z;bX0;c4c02/];`0_<S0092TU02`a:P0m@cX0:2hT02@Z800a>340>3hl02T_;@0T:RX09RXY
01PM6@0Q9R808RLS020U8@0Q9R805a`H028W8`0O92007R<O02`a;@0h?CT07b4P01dO7P0L7Qd07AlN
01hP7`0K7A`201dO7P<071hM00@06adL01`M7`0K71h06a`N0P0J6ad02P0I6Q`07QlQ01`M7`0B4aD0
6Q/M01`M7`0J6ad06ATK01/K7@0J6Q`201PG700O01XI7P0M728071/Q01/J8@0M72@071/S01PH800E
61d05a/O01@I700G6Qh07b8V020R9P0I6Ah071`Q01TI7P0F51X061HL01/J800D5Qd05aLO01TI8@0?
3aH07ahT010?5@0G5Q/071XO018@5@0D4QD06A@H01LB5P0201PF5`0402PV9`0K6AX07adN014?4080
4Q0A0P0A3a02010>3`0601<A500h=ST0518E00`;3@0E4aH04a4D1@0A3a800`0@3@l040`=014=3P03
018>3`0<014=3P0@30d04Ph?01<?400B3Pl040`=00`82@0A3@h06ADF00d92P0D41402`L80P0>2P/0
1@0?30`04@d>02HS8`1VHV<04Pd=00803`T900X040X:00l92@0?2@T040X:014;2`0?2@T03@L700h8
200A2`/04P`=0P0>20X2010:300W00h82P0E3a401000010:300=1`T040X<00d72@0@1@T04PL;0146
2P0?10P04PL;01462P0F2`l02`0400l4200P5AT0<RL[01H;3`0A1PX04`P<01@93@0A1PX03`@80105
2@0C20`03`@801472P0F2`l07Q<G028H6`14>3`07Q<F00/20`0A1PT050P<00X00P0?0`L040@80080
4@D90P0C1`/0300:00<05@X>00`31@0800405@`>01872`0:00<04PL;00d31P0=0PH050T=01052ACo
oooo000Kooooo`0600T8100=30P03`h:00d<200<2`L02`X60P0>3@T02@0B4@d04A0<014@300G5Q80
3a0;01<D3`0720<04a@?01@E400200l@2`0G00X;1P0720<05QLB00X;1P061`802`/;00T92@0=3@d0
4A4A01TI6@0R8R80BDU900h>3P0820P02@T902DU9@010@403@d;00l?3@0M7A/05aLE00/;2@0@40h0
1P0>3P`600d?300:01HH5@0C5A805QPE00/=2P0Q8b00ADM502DW9P0B51<03@l>00h@3`803a4@01`0
3@l>00lA400A4a803a4@00d?3P0?4@d03A0900`>2@0>40/02`d800d?300@4Pl020X700T;2P0B51<0
2@/:01hP7`0=3Pd02``7018B400A4Ph06AXE00`<2P092PH02@X500X:20092PH03a0;0P0A4@l0200A
40h03Pd;00h=2`0>3@/03@`:00l>30030P003Pd;0P0<2`T03`0@3`d03Ph@014A4`092@/03@d?01<C
5@2XZ:X0DE5C01XJ700?3a4030`>00l?4@0A4A8092@T00l?3@0201<C4@0403Ph=P0>3P`03@d;00h>
3080410>00<03`l=00h>300<3@P00P0@4@`02`0>3`X0414<00/<1`0<3@P051D@010A30092PD06Q/H
09nPV`0J6QP03`l=00<02`/900T03`l=00d=2`0<30X03@d;00h>300<30X020T400d<1`0>3@P00P0?
3PT0100>3@P03@`7014@2`0>3@P300d<1`0<00/:1@0?3PT04Q4<00d<1`0<2`H03Pd800/:1@0@3`X0
3@`700`;1P071P801`H10P0=30L01P0:2@@02`X500/:1@0;2PD03`h900h=20803`h900d03Pd800/:
1@0:2@@03@`800h=2@0?3PX03Pd900/:1P0:2@D010<101DD40081`<030/800803`h:01003Pd800`;
1P0<2`H03Pd8010?2P0A40/02PT60040000_;RT0j>OR06]ZI@0D4`l03@`800h=2@0@3`/03`h:0P0=
30P300h=2@0400d<200>3@T03`h:00h=2@<03`h:0P0@3`/0200>3@T03@`800`;1`0=30P03Pd9010@
2`0@4@/03Pl90P0?40X05P0>3`T02P/500l@2P0E5Q002``60493?@1BDdd04Q8:01DE3@0>3`L04Q<;
010C2P0G6Q405aP@01@F2`0=2`<06a@<02PO600H3PP03PT6010<2`0@3`d200h=2`0M01<C4@0E5A<0
2PX800h@3@041P<06A/H02`a;@0I6AL0:RXX014A3`0G5aD05ADC014A3`0?3`d051@B01PH5P0B4Q00
3Ph<010@3P0B4@d03`h:00h=2@0?3PX040l;00d<200A40`040l;00h=2@0=30P00P0<2`L03P0=2``0
5aDF00h<3@0I5aP04Q0A00/92P0<2P/0518C01dK7011?d0071XK018@4@0?3P`04A0>0P0B4@l03P0?
3P`030/901HE4`0E51806APF00D40P0?3P`02@P6010?3@0=30X02`X800d<2P0<2`T02PT70`0@3`d3
014@3P04014A4@0?3`l03`l?010@40804A4A00`03Ph>010@400@41003Ph>00l?3`0@40h03`l<018C
3P0E5Q404A8=010A300C50l2010A300400`=200@4@`04Q<>00`=20804aDB00L03Q0=014C400H6QL0
51HC014C400D5Q<05ALD00804aDB03005QTF00lD400G6aX07R<P01PM6@062PT04QHD01@I5@0I7A`0
4QHD010E4@0C5aH04AHA010E3`0D6A<05AXD018G4@0A5Q0041D?00hC3@0@5@l05AXD014F400?50h0
4QH?01@G3P0E60l05QTA01LJ4`0H6a@061XD01HH4`0B50l071hK01LI5P0C5Q803a@=04eEBP22RH40
7RDN01/R6`0B61D04ALG01<H6`0B5a/04aPN01LL8P0D624201HK8@0H01HK7`0E6Qh061dP020U9`0<
4Q80:S0^01LM6P0L8Qh05A/G01TQ700F7aX07bPS020Y9@0>5a@06R<P01LP7@1NIf@0FV=P02D^;@0M
9RD06R<Q01hX9`0J9RH06BLX0P0H9RL00`0L:R/08S0`01d[:`0301h/;00N020^;P0R<3008S8b02Ti
>@0`@3l0<D4n02Ph=00O<2X07Rh[024a;`0V=SD0:CPk02Xi?P0Y>T80JGf803Q>F@0S>T807c<l02Xo
A@0aATT0>Ti?02Xm?00mD4`0<4<o03Q<A00_@3P08c8[02Db:`0V<b`0934Z0P0S;RP04`0T;BP0:S0/
02X`;00X;BT0:Rl[02dc;`0Y<c008bhZ02/f<P0^>CD0<chj03@o>`0e@3`0;cXf02dh=00c?SX0<Sdi
02Xg<00/?3<00`0_?SL02P0a@3/0<T4l02`k=P0]?3T0;chk030o?00[>CT0:3Ld02Xf<`0`?3P203Q4
@00X034m>`0_>cT0;SXh02Pd=00Y=CD0<3`l03E0@P0b?D40<Se303A1B@0e@TX0<3e502`j@`0b@4T0
;Sa502m0BP17F680PY>M03e>F00]?d`0<dID03=5D`0bA580>4YF03I7D@0mCUP0=TM?03Q6C`0fAD`0
<T5603E2B00[>d408S<j02Df?@0gB4`0;Se002Xf>00X<S<0:38a02L`;@809B/W01D0;34]02HZ:`0Z
;Rl09b`Y02ld<00P9Al0:RlW02/a9`0S:240<3L`03@j>00U:bT0;38a02@X9`0J7a/07b@P01`Q7@0M
8Qh082DQ01XO6`0Q9R800P0H7AT00`0U:RH09R/W01hP7`0501hP7`0301lQ800N81l07AlN00806adL
00<06A/J01XK7@0J6ad00P0I6Q`201PI6`0:01dN800H6A/07AhP01LH6P0=3Q007QlQ01@D5P0F5QP0
61PJ01PG70806QTN02@05aHL01DD6P0D4aT05QDM01LF7P0E51X04Q<G01<G6P0?4aH041@G01LH700E
5QX051<H01LF6`0F5AX05A<H01LE6P0H5a`03a4G01XJ8P0G5al06a`Q00/:400T8bT06QTN018@5@0K
6Ah03P`?01hI7@0G4QH02`T:00h<3@0I5aP04@l@018@4@081PL2018@4@804@l@0P0@3Pl201<A5004
00D31P0A3a80518E00800`D04@lB00T04PlA00l;300?2``04`l@010<3@0?2``04@d>010<3@0>2P/0
0`0?2``03@0A3@h04Ph?01<?400?2``0:RHW00<0000S7b0030P900<0000B3`l07ATJ04Q4A@0<1`P0
0P0?2@T02P0@2PX03`T900l92@0C3@d05a4A01H@400A2`/02`D500T30`0;1@H200d72@0:00h82P0?
2@/03PP:014;3@0>20X04@/=00T31@0=1`T04P`>01462P804PL;00P04@H:01872`0B1`/03P<700d2
1P0E2Ph04`P<01`A5@804@H:00<04PL;01@93@0A1PX00P0@1@T0300?10P01`0001D:3P0E2Ph05``@
00P00@0:00802`0301/?4`0>0PH02`4301<72`H03`<700H04@H:00h51`0700007a@H01<8300=0PH2
00l4200400/0100>0`L04PL;00X00aCooooo000Kooooo`0400d<200A40`04Q4=010?2`803`h:0P0@
3`/01@0D4`l04Q4=00`;1`0=30P03Pl:00802P/600D04A8=00d>2@0C50l030d800h?2P0201<D3`03
00l@2`0H6A@03`l?00803Ph>00l03@d=010@400E5AD06ATI01<C4`0A4A402PX:00d=3@0B4Q804A4?
018B400O7ad05QHD00X:200?3`d01P0>3P`600d?300:00/=2P031@8010H300/=2P072@H07b4O02<U
900F61L03a4@00h@3`80418A00<03@l>00h@3`0?4A000P0?4A006`0>40`02`h700/=200@4Pd03Q0;
00h@3@0:30T05aTF00P:2@0G6AP02P`;0001000>3`l051@B02XZ:P0F5QD030`:00h>3P0F5QD03`l=
018B4P0?3`h03Ph<00h>3P0;2PP02PT700l>300201@C4@0K00l>300C4Q0030/900h=2`0920H01`H4
00`;2@0D51H05ADG00/;3@092@/020P:09FEU`1?Ce4061PJ00d=3`0;2`d03@d?00l?40030`<04Q8@
00l?3@0b<S00K6aZ018B400<30X03@d;00803`l=00L03Ph<00d=2`0>3`X0414<00d>2@0;30L03a0;
00803@h900L01@H300/<1`0S91l020T601@E400F5Q@03`l=0080410>00X03Ph<010@3P0>3P`03@d;
00`<2P0=3@/02`/900P9100=30L03Ph60P0?3`L05`0>3PH03@d5014A2@0?3`L03Ph6010@200?3`L0
30`400l>2@0B4@`03@`700`;1P0>3@P02PT400d<1`0<2`H03`h900h=200?3PT051<>00d<1`0920<0
30/600802`X500<03Pd8010?2P0=30L00P0;2PD0100<2`H03@`700l>2P0=30P400`;1`0700`;200[
:RH05QDA03/j=P0H5a<00@0000h=200200`;1P0>00h=200@3`X04A0;014@2`0O7QT01`H203Lf<@0C
4Pd02@P400d<200?3PX040l;00h=2@0=30P200l>2P803@`81@0>3@T02P0?3PX040l;010?2`0@3`/0
3`h:00d<200<2`L03@`800l>2P0?3`X200d>200J010A2`0B4`d04A8<014B300?40X0414;00/<1P0H
6A<05AHA00/<100N81D02`d600T;000L7a@02`l50085000@4PD06Q/A01XG3P0J5Pd04P/400l:1`0?
2`X040l=014@3P0B4@l2018B400B00X:200E5a@061XG01dO700Q9R804a<A024Q7`0D51806ATG00L7
1@0K6aT0410>01<C4@0D51803@d;00X:200?3`d04A0<0P0?3PX00`0@3`/03`h:00`;1`02010?2`80
3`h:00L04A0<018A3@0=2``04a4B00X82@0E4a@040h?00803`d>00L02@L801@B4`0100006ALH00P6
1`0B4@l04A0>00@040l=00T05A@B00/:200D4a402`X8038a;`0G5Q@03@`:010?3@0?3P`00P0=30X0
100>3@/03@`:00d<2P0=30X300h=2`0E014A4@0@4100410@00l?3`0@41004A4A00l?3`0A4A40410@
00h>3P0?3`l0410>014A3P0B4`h0414<00h?2P0:2`H020T4018C3P0A4Pd03a0;00804A8=00P03@h9
01<E4P0D5Q<03a4>014C400H6QL04aDB010B3`804aDB0P0A4a004@0C5Q<051TC00hC3`093PT051TC
00hC3`0D6A@08RLQ02X_:`0K81/03A8<00hC3`0@5@l04aPB01DJ500D6A<04AH@008041D?01d03A8<
00lD3P0F6aD04QLA00lD3P0C5a0051L>01DH4@0G6Q<061/D01PJ5@0F61<05ALB01@F4`0P8Ql071hK
01DI5P0M8Q`04QTA02H]9P0L8a`05ahG01`R7`0B61H04aTI014G5`0A5QT05AXM018G6P0301@L7P03
01DM7`0I8R408BXY00808b`[01806b@R01dV8`0E7Q/06R<P01PQ7P0S;RX0:S@b01/U900F8Ad06B@P
04aGD`1;EU807RTU01`W8`0L9b808B`X01/W9`0J:2P201TW9`0601h/;00S<C406bTY024_;`0T<S80
8c4a0P0R<3008@0L;2`0830`02@d<`0S<c00830/01d^:00Y>CH0;3`j02hn?@0_?T40;ci302Xk@`0j
C5H093Q302/oB00X?4D0:Si402i1A@2>XZ<0>De;03Y=B@0mD4`0=dU301DV800Y=c00:cPa02Xg<00X
=Bh09C0Z028]9`0R:bH09RlZ02Pa;00202dc;`0?02Xc;P0^>CD09S8^034m>@0b?SX0>DE1038n>P0l
B4@0=D4m034m>@0f@Sh0<clk02/h<@0^?SD0<D0i0080<T4j00@0=4<n03I5@00c@Sd0<3ll0P0_?S/0
B@0/>SX0:STf02<_;00Z=S80<Shj034m>@0/>3H0:SHd02Pd<P0U<C409S8b03A0@016DE<0@4]?038m
@`0gA4X0>DI=034nAP0[>T407bde01h/=@0]?TH0;d1905IWL@0R<cd0;3e;0395E00gB5P0<dEC03e?
F`0nCeT0<45:02hoA`0^?D@0;Se20350@`0d@TD0:cTm020_=00S<SL0;ce202Dc=P0[=SP0:38c02H`
;`0T;BX08bTU02D[9`0[<2`08RHW038f=`0U:RL09R/W01/P6P0T:B80:c0Y020U7P0U:R@09BTX01XN
7@0W:b/09BTX02<X900L8Ad041DA01`Q7@0J7a/07b@P01`Q7@0H7AT06QlK01PM6@0E6QH00`0P8R40
1P0N81l07AlN01dO7P0O8B007R0O01dO7P806adL00<06A/J01XK7@0J6ad00P0I6Q`201PI6`0D01HG
6@0E5QP0824S01<D5P0T9BL05aPJ018B4P0D51D05QHH01PH6P0I61`061LL01XI7P0G5Q`05QDK01PG
7@0I61l06APN01@E6@0G61X201<D5P0501PH6P0F5QP04a4D01DC5P0F51L00P0G4QH04`0F51T09BL]
00d>4`0@4AH051DJ00P7300E51T092<X010>4@0U8bH040hA01LC500B3Pl06ALH01@B4`0F51D04Q0A
01HD5@0C4A800P0@3Pl02P0A3a004Q0A018@4@0B4140518E01dK7P0=2`h03P`?02<Q900F51L500d;
3P0400l<3P0:1PL02@D6014=3P8040`=01<05a<D01DA4P0?2``03@T:00l;300@30d03`/<00/7200A
3@h02PH7020L7@0N6Q/0MW9c00X61`0C3a006aLH00<0000G4a@04@`<00803`T900X040X:00l92@0?
2@T08Q`L02XT900I4a<030H600/51@0<1PH03@L8100>20X02`0?2@/0100001D?4@0:10H01P0200d7
2@0>20X03P<700d21P0?10P040D900803P<701<03@8600h31`0E2Ph02@0200h31`0?10P040D90146
2P0C20`04@H:00l4200A1PX0714E00P00@0?10P03P<701D:3P0>0`L06PlC008040D900<01`0000h4
1`0B1`/00`0>0`L300d21P0<00l4200B1`/0304501hC5`0800403`@801052@0B1`/03`@800d21P0>
0`L030455?ooool001_ooooo01403Ph900l?2P0>3PT030`800d=2@0@40`04A4=00/;1P0?3`/04a<>
010@300>3PT03a0;00/<1`0H6A@04a@?00X;1P02010A300700/<200A4Pd03a0;00`=200A4Pd03`l=
00l?3P0200h>3@0900d=300>3Pd03Ph=00/;2P0:2PT05QHE00H61@0C4a8051@B00803Ph<00<030`:
00/;2@0@40h01P0>3P`600d?300900h@3P0B51402P`900h@3@0<3P/02`d;00`>300?4@l0418@00<0
3a4?00<04Q@B010B400<3P`00P0>40h05@0?4@d03A0900`>2@0A4`h03Q0;00d?300>40d020X7014C
4P092`X030h=01LI600>3`l030`=01LH6@0>3Pl0410A00X;300A4Q<03@h?00h>3`0200h?400S00l@
4@0B4Q404A0?00l?3P0@3`h03`l>00`<2`0:2@P04A0?00d=300<30/04Q8A01hM7@0;2`/04Q8C00h>
3`0C4a@04A4B01@D5@0E5AH02@T:00l?400;2``01`L800h>3`0A4@l03Ph<01@D4P0;2`X0:2PV018B
400>3P`03@d;00h>300=3@/00P0>3P`05@0<3@P03a0;00`=200:2`H0414<00l@2`061`<05QLB00D6
0`082@@03a0;010A3P0:2PP02`/901DE4`0G5aD0410>00`<2P0@40h03Ph<00d=2`0200h>300300`=
200;2`@030`300803@d400D030`300/;0P0>3PD03@d400l?1P02014A200300h>1P0:2@@03Pd80080
30/601H04A0;00h=200B4@`03`h9014@2`0>3@P02PT400`;1P0?3PT03@`7010?2P0?3PT03@`7014@
2`0>3@P02`X500X9100;2PD03@`700l>2@0A40`040l;100?3PX01P0>3@T0>3Lc01`K5`0G5Q805QDA
01LF4PH03Pd80P0=30L03@0E50l03`h:018A300;2PD03Pd900l>2P0>3@T03@`800l>2P0B4@d040l;
00`;1`0=30P00`0>3@T200d<200;010?2`0B4@d04A0<018A3@0A40`03`h:00d<200?3PX04A0<00l?
2P0<3@L00`0=3PP2010A2`0C01@E3`0B4`d030d701<D3P0A4P`04Q@<00/>1P0@4PX03Q4700D8001@
ETT0=cX^028U6`0>40L04A8;01<A2`0@3@P04@d;018>3@02010?3@0E00l>300=3@/03Ph<01hN700D
5Q<06A/H01DG500;40`0410>01@D4P0B4Q005aLE04I6A015AD<03Ph<010@3P0?3`d03@d;00`<2P0>
3P`040l;00803`h:00<040l;00l>2P0;2PH00P0@3`/0400A40`04a8>01PG4`0K6QH03`h<00`:2P0C
4A404A0?00X9200B41004a8A00h=300=30/071XJ00d;2`0A3`l2014@3P<040l=00h04A0>00d<2P0G
5Q@01PD303Th=P3<blT0>3Le01<B400?3P`03@`:014@3P0@3`d03Pd;018A3`<04A0>0P0@3`d2010@
3`0300l?3P0>3Pd03`l>00804A4@00X04Q8A014A400?3`h03`l>010@3P0@4@`04A8=00/<1`0Q8Qd0
9BHQ0P0A4Pd0300@4@`04Q<>01<D3`0A4Pd03a0;01@F4`0F61D04A<@018D4@0F61D04aDB014C4080
4Q@A00L04A<@018D4@0D61<0314;01lT7@29SXP0<cPa00803Q<<00`05Q/D01hS700G71D04AH@01<H
4P0D6A<051TD01DJ5@0C61<04AHA018G4P0C61<200hC3P0E01@I500B5a804AHA01@I4P0E6A404aL@
01DI4P0G6a@05ATC01<F4P0F6AD05QTF01hQ7`0H6aT05aXI01@J5@0H7QT04aTD018H4`0D6QD05A/F
00807bHP00H06R0L01LM6@0I81/05A`G01@M6@0E7QX201HO7@0E01PQ7`0N9bH06B8R01DN7P0K92@0
8b/^020X:P0J8RD06R@U01HP8@0O:BX08R`/028/:`0J92<072LS020[9`0J9B008B`V01hY8P0O;2D0
6bXW00807B`Z00T072/Z01h];00Q<2l072/Z02@c<`0Y>3P09SDe02<b<P0U=3@00P0Q<C40KP0P<2l0
830]02@e<00Z>cD09cLd02hn?00]?C`0;Se002hm@P0V=cl0<dI>02TmA@0^@TT0:Ce402e1AP0^@T<0
;3lo02Pk>@0iBTT0;d4m02Hg<P0Y>S@08c0Z02Te<00X=2l0:3D_02Ha;00P:bH09S0/02La;00V<2/0
;CLc038i=P0/=S80<3`i03Q4@@0c?c`0=D4n03U5@P0d@3d0=d=003A0?@0`?3T0<Cdj030l>@0/>3@0
<40g030o>00^?CH0;C`e030o>P0b@C`0>dY503I5@P0c@Sl0<D0m02/i>@0X=c@0:CDb02/g<`0b?SX0
;c/g02lk>@0d@3h0<clm02`h>00T<300:SHf03U4AP0oBTd0>TE:03]8CP0iATd0<Sm602dl@`0`?dH0
<Cm7049CF`0]?TH0:S]402m0B@0dAE<0;d9C03]<GP0eAUH0?e5O04QHI@0`@DX0=4E<030oA00Z>S`0
;Cdm02`j>`0/>S`0;3Xn02/i?@0X=SP0:3Df02`g>00Z<c80:34`02@]:P0T:RL09R`Y02T^:P0T:BL0
:c0^01hS800S:2@082HP0P0W;2H01@0T:B<09BXV02DY9@0Q928082<Q00807R<O00@0724M01lT800e
>SH0;c@`0P0M8Qh02P0N8al082DQ01dR7P0M8Qh07R0O01lQ800P8R407AlN01/M700N81l201dO7P<0
71hM00@06adL01`M7`0K71h06a`N0P0J6ad05@0I6Q`06a`N020Q8`0P8B<07QlQ04i?D@0H6A/061PH
01LG600H61T06QXL01PH6`0C4aH06aXO01LF6`0E51T05QDK01LF7@0G5Q`04a@G01LG600201DE5P0H
01TH6P0F5AH05Q@F01PE5`0I5QP06QHH01TC5P0G4aL0:R`a01dN8`0K72405QLL01DD6@0A41D04a8F
01PF6@0I5aX04Q0B01DA4P0F4Q<04Q0A01<A4P0B41404a4B0P0A3a000`0@3Pl04@l@014?4003018@
4@06018@4`091`X03`d@01DC5P0Y9bX05Q@G1@0B41<02`0M6Q`06aLH01<?400E4A803`/<00d92P0H
51D06ADF018>3`0A3@h04`l@00804Ph?00`02`L8014=3P0E4A804@d>00/7200T8B40510A01LC500@
3@d0510A00T51P0@2`/200l92@0:010:2P0?2@T03`T9014;2`0?2PX03@L7014;2`0E3`l04P`<010:
2`804P`>00d03`T;00d72@0?2@/02PD601D?4@0@2P`0DD]=01/E5`0=1`T050T=01462P0E2Ph05``@
00804`P<01P05@X>00`11@0A1PX040D901P=4@0A1PX03@8600l4200A1PX040D900l4200@1@T03PD7
01052@0E2Ph040D900h31`0C20`04@P:00h51`0A1PX02`8400h41`0;0P@300h31`<03`@800T04@H:
00h51`0800406@hB00h41`0D2@d03@8601052@0?10P00P0=0PH00`0?10Soooooooooo`0Booooo`00
6oooool0400B4`h04A8=00h?2P0<3@P0414<01DF4@0W:2<051D@00h?2P0B4`h0414<00`=200C50l0
3@h900h?2P082@@2010A300300d>2@0F5a805AHA00804a@?01<020T4010@3P0@40h03`l=014A3`0>
3P`02PX800l?3@0A4@l03Ph<00`<2P0>3P`04A4?00d=2`0@40h03@d;00h>300=3@/02@T700H03Ph<
1`0=3``020072@H020X701DG500;3@X0418?018D4@0>40d02`d:0P0=3``02`0C5A807AlL01PJ5`0>
40d0418?014C400=3`X02@`500P:1@0?4@`0418=00803Q0=02H04A<@018D4`0>40l0418A00P:2@0C
5AD030d?01HG6@0<3@l03a0B00/<3P0P8B<07AhP00l@4P0>3a403a0B00`=3`0;2``03@d=014A4@0D
51@04Q8B00`<30061PH05aLG00`<30092@T05ADE020P800A4A402`/;01<C4`092@T01@D5014A4@0B
4Q804a<C00X:2P804Q8B00l03@d=00T91`0?3`d02`/901/K6@0?3`d03@d;00l?3@0>3P`030`:00/;
2@0<30X03`l=00L80`0;30L00P0>3`X02P0A4Pd030d800h?2P092PD06AXE00l@2`082@@05QLB01LG
5@0=3@/200X:200:00P81P0;2`T03@d;00X:20092@L02`/900`<2P0;30L03@d500h>10803`l500D0
3Ph400d=0`0:2P002PX100d=0`02010@1P0F00d=1@0<2`H03`h900`;1P0;2PD03Pd800/:1@0>3@P0
3@`7014@2`0B4@`03Pd800l>2@0=30L02`X500h=200=30L02`X500l>2@0:2@@02`X500`;1P<03@`7
00d030/700l>2P0@3`/03`h:00/:1P0920@03Pd90040000H5a<02`X701dL600;2PH03`h9008040l:
00H03`h900`;1P0;2PD03Pd8010?2P0<2`H200l>2@0300l>2P0>3@T03`h:008030/700H03`h:01@C
3`0@3`/02`X600`;1`0?3PX200h=2@0400`;1`0;2PH03`h:01<B3P804Q4=02004a8>010?2`0>3@T0
40l;01<B3P0B4Pd04Q<=01<D3P0<3@L020T300`=1`0C50h01PL1014B300G61803Pl900l@2P0;3@P0
51HA01<E3`0F6A804aH=01PK4`0K7QD03A0900d@2P0C5A8020X700d=3@0=30X04Ph=018A3`803Pd;
02d05QHD01PH5P0K6aT02`d;01/M6P010`0041DA00h>300I6AL0410>01PH5P0000007AdK00/;2@0<
30X03`l=018B400A4@l030`:00l>2P0>3@T03`h:010?2`0>3@T02PT501@C3`0A40`03Pd900d<200?
3PX04A0<00`;2@0C4Q00>STg02XY9`0?3P`02PT7010?3@0=30X04Q4?00L6100B4@l040l=00/:200>
3@/00P0A40h06@0>3@/02`X801/J600?3Pd0;2/Y01DD4P19B4H05QDC014@3P0=30X06QTG02XY9`0L
6aT030/9018A3`0@3`d03`h<00h=2`0=30X030/900h>300@40h03Ph<00`<2P0>3P`00P0A4@l02`0B
4Q004A4?00l?3@0?3`d0410>01@E400A4Pd01`P302`]:00a<Rd03@h900803Pl:00H04A8=01<D3`0@
4@`03a0;01<E4P0F61D2018D4@0401@F4`0C5A804aDB01<E4P804Q@A01H051HC018F400H7AH02a09
075fK`0Z;bP07b@M010E3P0H7AH051TB010E3P0D6A804QL@014F400C61@04QLC014F4P0B5a<05AXF
01LL600?5100314=0P0B5a<07`0A5Q805AXE01@I4P0B5a004aPB01@I4`0B5a404QLB01TN6P0D6AD0
51PG00hB4@0D61L051XH01HL600M8al03aDA00X@300E71D061lH01TP6@0D6a<04QTA01HM5@0D6a<0
51hF01HO6P0G81/051dJ01<L6@0E7Qd00P0K8bD04`0I8B@07RHY028Z;@0H82D06R<X02L`=@0I8bD0
628T05QRH`0[=CD05R0O01@O6`0L9b8072LQ01hY8@0V<b`072/V01h^:`0O;b`00P0M;B`201h^;@1?
02@d=00U=CD08S8b02<c<`0X>3P07Rh^01l_;`0N;Rd07Rh[02@e<00]?SP06b/X02De<`0W=cH0:CPk
02hm@P0V=ch093Ln02Pl@`0dBDh0=4M=0396B00P=3D08C<c03A5A@0P<2l07Rh[02Hg<P0Y>3<09C4]
02`h=00Z=S80:cLc02Lb;P0P:bL0:C@`02/f<P0V<Bd0:SDa038m>@0`?3P0;CTg03]7A@0_>cT0=40n
030l>P0iAD<0<Shl03E1?`0`?3X0<Cdk03<o?@0b?SX0<40g030o>00_?SL0<D0i03M6@@0kBTD0<T4l
03=2?`0fAD80=DA102lm?@0[>SL0;3Pe02Xf<P0_>cL0;3Pd02lk>@0hA480=40n02`h>00W<c<0:cLg
034l?P0iA4L0?4M;03Q5B`0203A1A`80=TE<01X0=dI=02m0B00dADd0:S]303I7C`0iBeT0:Sa@03]<
GP0jBe`0AeUW05UYMP0fAdl0=dU=0391A00[>c/0;3`i02He<P0/>cX0=49302hi>`0U<380;SXj02@^
;`0]=SD0:c@c02L`;@809bd[00<09bdY05mUH@12B4@00P0T:RH05`0O9B409b`V024V800R9b40724M
01dO700R924071hK02@Y9@0G71P0724M02DZ9P0Z;b/07B8N01DJ5P0R9b<06QlK018G4`0L8Ad06b0L
01TK6P0K7A`07R0O008071hM00<0828Q01/M700L7Qd00`0L7Qd00`0M7ah071dO01`M7`0301/L7P07
01XK7@0M7R006AXL01lP8P0E5QP06a`N01XK7@0201LG5`0N01/K6`0O7b407QhP01TI6`0L6b005aHK
01<B5`0D4aT05A@J01DD6@0K6ad07QhN01PH600F5QH05aHF018@4@0F51D05a@E01TE5P0J5QL05a4C
01@?4`0D5Q/030dB010A5P2@TID081lT01<B5`0K6ad0@d540P0C4A802P0B3Pl04`l@014?400C4A80
40h?01<A4P0?3@h04@l@01<A4P0B4142014?40803`d>00H030X=00T72P0P7R402@P:01<A500F51L5
00h<3`0301LD5P0?2``01`<400803PX;01@040`=01HB4`0@30d03PX;018>3`0C3a003`/<00`82@0@
30d06ADF014=3P0;1`P07ATJ00`82@0E4A801`<4014=3P0=2@X0510A00h92@803`T900X040X:00l9
2@0?2@T04@/;01<=3@0A2`/03@L700`61P0@2PX050h?0P0E3a406P0?2@/030H800h82P0G4A<01000
01H@4P2ZY:H081XL00P2100@1@T03@8601462P0D2@d03P<700l4200=0PH02P0301D:3P0=0PH03`@8
00`31@0;00@03@8600l4200>0`L03@860P0?10P00`0D2@d01`0001462P0201052@0600/010070000
3`@801052@0D2@d01`000P0>0`L200l4208040D900L01`0001872`0@1@T050T=00X00`0900805@X>
00<04@H:00<03`@800d21_ooool04oooool001_ooooo01T03a0;010A300>3`X061TD014B3@0T9B00
DeA?00d>2P0:2`P04A8=02`]:00A4Pd04a@?010A300=3PT02``702//9`0D5A0030d8010A300D5A00
2``701HG4P0<3@P03@d;00803Ph<0`0?3`d301DE4`0900`<2P0A4@l03@d;018B40071`D0<C4_018B
400?3`d03@d;00H03Ph<00`03a4>01TK600=3``0418?014C400:30T030h;010B3`0>40d04Q@A014C
400;3@X200lA3P0;00`>2`0?4@h03a4>00/=2P0@4Pl04A<@00h@3@0B51404A<@00h@2`0>4@X00P0<
3PT01P0=3`X03Q0=00h@3@0?4@h03a4@00d?3P803Q0?01<04A<C00`=3`0J6ad03a0B014B500;30h0
GUmQ02X[;@0E5QP04A8D00d>400I6Q`09BHW01HF5P0:2PX010@4014A4@0@41003`l?008030`<0180
3Ph>00d=3@0>3Ph030`<018B4P0@410030`<00l?3`0>3Ph020P801TI6@0B4Q80BDU903lo?`0@4100
2PX800/;2@0@40h201@D4P803`l=00D02`/900`<2P0;2`T03@d;01<C4@0200d>2@803Pl:00@03@h9
00`=200?40/03Pl:0P0:2`H200h?2P08014A400B4Q0030`;00l?3@0:2PT04A4?010@3P0>3P`200`<
2P0F00h>300?40/03Pd801LG400B4PX05AD>00`<1P0D50`02`X5014A2P0820004a<<00l?200F5Pl0
5aHA00l>2@0:2@H05A@?00`;1P0C4Pd040l:00l>2@803Pd81@0=30L05`0?3PT040l:014@2`0>3@P0
4a8=038a;00C4Pd02@P300h=200>3@T03`h:00`;1`0>3@T04A0<00d<200?3PX03Pd900d<200C4Ph0
3Pd901@C3`0A40/03Pd800803@`700@03Pd800l>2@0=30L03Pd80P0=30L01@0A40/03Pd900`;1`0?
3PX040l;00<03Pd900`02`X600`;1`0A40`03@`800`;1`0=30P04Q4=014@300;2PH03Pd900`;1`0>
3@T200d<200N014@300:2@D02`X6010@2`0?40X02``8010A2`0720@0:2TS01@E3`0>3`T020T301DF
4@0=3PP04Q<>00d?300>40d06A/G00H70`0I6Q<061TB01HF4@0A4Pd04Q<A01<F600>4QH03a0E018@
4@0M6AP071/I0P0G5Q@2014A3`0600h>300C5A802P`9014C400>4`l05QHD0P0?3`d02`0>3P`03@d;
00d=2`0>3P`030`:010@3P0?3`d02PX800l?3@0@3`/03`h:00803@`800P03Pd9010?2`0:2@D03Pd9
00T8100G5Q804A0<01hM6@804A0>100@3`d0200<2`T03`h<01DD4P0D4a405A@B00h=2`0C4Q003`h<
0P0@3`d05P0=30X04A0>00d<2P0S8R00?Sdk010?3@0A40h030/900d<2P0>3@/04A0>01<B400A40h0
3Pd;00l>300A40h03@`:00l>300A40h03@`:00h>300?3`d2014A3`803`l=00L04A4@00h>300=3@/0
7AdK00H6100@40h03a0;0080414<0`0A4Pd0300C50l05AHA018C3P0B4`h04a@?014B3@0B51405ALD
01<E4P0A4a005ALD01<E4P804A<@01404Q@A01<E4P0C5A804aLB014F3`0=4P/05a`E018G400;40T0
4QL@00`A2P0G71D04aPA010E3P0=4P/05AXE014F4P03010E4@05014F4P0C61@051TE01@I5@0C61@0
0P0B5a<00`0A5a8041L@010G4002014H4@1K018H500A5a<05A/G018H5P0M8b<04aTI01HL6`0A5aD0
51XH01LM6`0E6aL051XF01DL5P0F7AH05A`E01TP600M91`06R8G01<K4P0C7AD072LO020[8`0G8Q`0
62<M01TT8@0Y<c@0NXB5024[;@0H8BH05AhS01dV;00L9R/07bX^01`W:P0H8bD072PY01`X9`0M:BL0
72PU01`X900L:2<07R/S01h/9@0M;BL07BhX01h_:@0N;R/0830^020`;`0U=CD09SHf01d];@0S<SD0
8C0c02Lf>@0M;Bd0>DU804IFE@0_?c`09CHa02@e;`0U=C80:CTg02`l>`0/>ch0;Se202dnA@0]?dH0
;3m402e0A00^@DD0;T5302`n?`0^?Sh0;clo02dm?00T<c009cHb020_:P0S;RX0:C@`02/f<P0W<bl0
9C4]02@`;00U<Bd0<clk03A0?00b?SX0<Cdi02ll>0020350?@0<02dl>@0`?c`0<D0m02`k>00c@Sl0
9SDb03Q7A00_?S/0?Da9030o>P0kBT80=D@m0P0c@S/20391?00702dl=`0a@3d0<d8o03E4@@0b@400
<D0m02lk>002030l>01202lk=`0_>cT0;c/i03I2@00iADD0;CTi02Te=@0[=SP0:SDh03Y5B@0d@TD0
>4I903i<C`0`?d@0<d9803Y9D00iBU40;Sm70393B`0cA4`0;d5>03I9F`0jBed0>daL03a>F`0jBeH0
<D9:0312A@0]?3l09CDd02hn>`0a@3d0:SHe02Pc<P0Z=3D0:cDe02D_;P0W<2l0;cPg02Tb<@0S;2T0
8BLU02P^;00R:BH0;3H_02Tc:`0T;BP0:2hZ02X`;00X;RX08RHT028W8`0R92407AdK01`M6@0O8A`0
7B0M024V8P0S:2@07b@P01PM6@10AD4082DQ01hS7`0L8Ad06b0L0P0L8Ad401lQ800501hP7`0M7ah0
7AlN01XL6`0K7A`00P0N81l0200K7A`07QlQ01lP8P0L7Al06Q/M01TJ700J6ad05aPJ0P0K71h201XK
7@0S01XL700F5QH05aLE01XJ600b<S809RHW01HF600G5aT04a<F01@C600G5Q/06QTN01PG700H6A/0
6A/M02<T9P0Q8B<07AdO01TI6`0D4aH05Q@G01/I700^:bh03`X>01PF6@0E5a/04a@H01LH700N7b<0
61PJ010@4P0C4a@07A/L01PF5`0A40l00P0B3Pd04@0D4Q<04Q0A014?400C4A805A<D01HD5@0I5aP0
4Q0A010>3`0B41406ALH01`J6`0C4A@05A<F018@4`0A3a80518E008040hA00l03P`?014?4P0>30l0
4Q0C00d:300A3@h04Ph?014=3P0?2``040`=014=3P0>2P/05a<D00h:2`0D41400P0=2@X01P0C3a00
3@T:00d92P0E4A8030P900d92P8040`=0`0?2``00`0?2P/03`T900l92@0200h8200=00l92@0@2PX0
40X:014;2`0B30`040X:00h8200=1`P03PP:018<3P0G4A<05Q0B014;3@0300h82P804@/=00<03`T;
01052@0@1@T00P0A1PX201872`0301H;3`0D2@d040D900803P<700<04@H:01052@0@1@T0100@1@T0
300?10P040D901052@0@1@T03`@800h31`0@1`X04PT<00d51`0B2@`030<600l72@803PD800@05`hA
00X3100N5QP03PL81P0?10P01P0A1PX03`@800h31`0A1PX08QLK01<931Cooooo000Kooooo`0J01HH
4`0<3PT05QPC00h@2`0f>3<02`d800d?2P0B50l01@L204M9A03=clX0;2hY01HG4P051P805aPC01HG
4P0;30L00040014B3@0<3@P03Pl:00d>2@0<3@P051D@010A300?40/200h?2P8030d800`0414<00h?
2P0>3`X020T400l@2`0:2`H03`l=010@3P2XZ:H0BDU70000000B4Q0600h>300<00T;2@0T9R<09bTV
00<50`082PL04Q@A00d?300@4Pl03@l<00h@3@0@4Pl03Q0<0P0?4@`01`0;3@P03a4<00lA300>40/0
418=00lA300;3@P00P0<3PT00`0<3`T03Q4:00d?2P0200d?2P0P00h@3@0;3@X010H300@61@0@4Q40
5ALF00d?3P072PT000@300L;2P0;3`h04aLF00T=300830/061`K0045100^<S406alN01<G5P0V:BT0
414C01<D5P0?41804A8D00@41P0A4Q@03@h@018C5@0E5QP0414C00`>3P0<30`200`<2P0C014A3`0E
5A<03`l=01HF500A4@l010@201hN700S8b404A4?00/;2@0=3@/04a<A01LG5@0D518030`:00d=2`0C
4a406ATG00T91`0200h>300800`=200>3`X04a@?01DF4@0B4`h03a0;00T:1@0<3@P300h?2P0500l@
2`020P003@d;00l?3@0@40h00P0<30X300d=2`0F00`<2P0;2`T02@T7010?2`0?3PX02PT40081000C
4Ph03`h900T8100:2@D03@`7014@30071P4061LB00P70P0:2@@06aXE00P70P0<2`H01@@000d<1`<0
3Pd80P0?3PT06@0>3@P03@`700l>2@0F5A0081lJ02@S7P0E50l05aHA02<R7@0?3PT02PT400T80`0?
3PX0:bXV0040000A40`03Pd90040000@3`/03@`800T8100=30P02@P400l>2P0=30L00`0>3@P200l>
2@0700h=200?3PT03`h9014@2`0D4`h04A0;00d<2002010?2`0<00`;1`0;2PH03`h:00h=2@0;2PH0
3Pd900d<200;2PH03`h:00d<200?3PX040l;0P0C4Ph0900920@04Q4=01@C3`0?3PX05QDA01PG4`0B
4Pd030d701<D3P0?40X0<34[0:^/YP0l?CL01`P202<T7P1<CDL051D?01<D3P0A4Pd030d801LH4@0N
7Q@051@:01LF2P0F4`X04a<;014C3`0D61T06A`Q018F6`0N71d06QHE01DD4P0C4Q003Pd;00/;2@80
5QHD01@030h;01DG500I6aP061dI014A3`0F5Q@04Q8@01hN700D5180410>00d=2`0<30X03Ph<00d=
2`0:2PP03@d;014@300@3`/03Pd900d<20803Pd900H07QdI014@300L6aL03Pd900l>2P0<2`L2014@
300<010?2`0>3@T030/700X91@0=30P030/7018A3@0F5A402@P4014@300D4a4040l=0P0A40h05P0?
3P`04Q4?01HE4`061@<02@P600P71@0B4@l020L501<B400B4@l04A0>018A3`0@3`d03`h<010?3@0A
40h03Pd;010?3@0A40h03Pd;00d>2@0>3`X400l@2`0601dN6@092PD0824L05EFD@0W:2<020T40P0=
3PT200h?2P803a0;01<04Q<>01XK5P0E5Q40414<01@E400F5a803a4>02`^:`0I6aP05QPE00X<2@0@
4Pl04Q@A01@F4`0E5a@04aDB014C400<3`/04QLA00803a@>00l051TC00lD3P0F6aD03A8<00lD3P0K
81X0314;01PM5`0C61<04QHE01@H5`0E6AP04QHE00lC4P0@51<00`0B5QD2014E5004018H4P0B6A80
4QTB01<J508051XF01D06R0M00lE4`0B61P05Q`L01@J6P0@5QH03aDC01`R800X;R`06b4O018H500D
6QH0318>02L]:@0h?ST06b8K00lF3P0J8Q/04Q`D01XU7@0P:bD00P0K9R802P0L9RD05AlP03I0@@0Q
:bd0:S@f02H`<P0I8RL07RT]020[;@0M:2X201XU9`0D01HR8P0N:RX07BTW01/W9@0L:2H082`X024`
:`0S=2h07C4Y01T/9P0J;BT083<`02Dh=P0A8b<09SPi02<e=`0S=CT062X^018T9P0Z>SX202Lg=P0B
01h^:`0]?CT0>4U302Ph=@0Z>SP0;Cdl02ln@@0`?d@0;Sm60394B00`@dD0<D=503=5A`0cA4@0<D51
02Ti>@0`?ch0=4920P0[>SL0200Q<2d0:38a02`f=@0]=cH0:cLe02`h=P0^>SP0:3Ld0P0c@Sl04`0a
@Ch0<D0m02hn>`0^?Sd0<T910351@00`@3l0:c/j02Hf=@0`@3l0=dM602Hf=@0`@3l09SHe03=3@00_
?cH0;3/d02dl=@0a@3T00P0c@Sd0200^?CP0;Sdj0350?@0hAd@0>4I603E4@@0^>SL0;CTe0P0a?CT0
1P0^>SP0;CTg038n?00a?Cd0;3Ph02Te=@809S4c03D0>4=502Le=P0Y=cT0>DM:02ln@@0c@TH0>TU>
03i?EP0a@TT0;Ci50311B00`@Td0=TUH03U:FP0cAE80<TA>03=4CP0a@TX0;Cm102Xi?00W=cL0:3Pg
02Tg=`0/=cH0:c@a02Xc<P0/=C809Rl/028[:00T;BX09Bh[02@]:P0S;2T0;CHc02df<P0]=bl0:SH/
028]9P0K91l072DR02L]:`0T:2T08BDT01dO7@0M7A/07QlJ020P700L7Q/061dI02@Y9@0S:2@0BDi:
0;Bi]@0201lT800401hS7`0L8Ad07B8N01hS7`<0828Q00@07R0O01dO7P0K7A`071hM0P0J71/201/M
700401TK6P0O82806AXL01LH6P806a`N02`05QLI01XK7@0H6A/06AXL01/L7P0J6ad05ALF014A4@0H
61H0410>01<C4@0B4Q40820P01DE5`0D51H05QHH01TH7@0K6Ql06AXN01`P8`0J7b803Q8E00lC5P0=
3Q804Q<G01<D600J6Ah04a8G01lN8`0?3A8051<H01LI7@0C51P04Q<G018C5@0A4A<03`lA014A4@0D
4Q<04A0>01<B400F4Q404`l>018@4@804a4B0P0D4Q<0=00C4A804Q0A010>3`0?3@h04Q0A01HD5@0H
5QL04Q0C01PF6@0<2Pd04@lB028P8`0=2`h05aDH01DC5P0F51L04Q0C01HD5`0@3@l04Ph?01<?400B
3Pl040`=014=3P0B3Pl06ADF00P41@0F4Q<00`0003hj>`0G4a@0510A00@00@0c<300:bLX00H20`0<
20T07a/L03di>P0f<S<04Ph?00H20`070P803PP8018<300>20P02P@4018<300D3Ph03PP800l92@0@
2PX200l92@0<00l92P0?2@/040X<01<=3`0D3Q004P`>00h82P0=1`T03PP:010:300A2`d03`T;0P0@
1@T301462P0701872`0F2`l05P/?01@93@0A1PX040D900l4200601462P@040D900h03`@800h31`0:
0@@01P0000l62@0H3a8030@601<:3@0>1@P03@@701H=400A20/0:1lR020G6PH03P<700H02`0400l4
200A1PX0304501H;3`0<0@DDooooo`006oooool060000@004Q@?0001000C5A00WZ2K010B3@031@00
4Q@?0002000N81/0MgUd018D3`0@4@`03a0;01DF4@0=3PT030d801`M600;30L0414<00d>2@0@4@`0
2P/601@E40803a0;0P0>3`X300d>2@0;00T:1@0A4Pd061TD01HG4P0720<05ADC0000000];B/01`L5
00d=2`0D51801P0?3`d07@0H6QL01PP501TK600D5Q<04aDB0002000<3P/03@l<00lA3P0B51404aDB
010B3P0B50l04A<>00d?2P0A4`h04Q@?010B3@0?4@`03@l:00/=200<3PT03@l:00d@2P0>4@X03a4<
00h@2`0=3`X03Q0=00805aTF02803a4@00`>3@0;3@`030h=01@G5P0?5100310?00`A3P0B5a<03A4@
00P<2P0@5A407R8Q034e<`0:3`/01`/:00h@4@0?4180414C01DF600L7Al05aPJ014B500=3Q0051DG
01`M7`0G61X04Q@D00h>3P0>3P`03`l=014A3`0B4Q003@d;0P0B4Q00100A4@l00@400000000<30X2
00d=2`0=010@3P0B4Q00410>00X:200C4a40410>01TI5`030`401PH400l?3@0:2`H030d800l@2`02
014B3@04010A300F5a803Pl:00d>2@803Pl:01l03a0;00l?3@0N7Q`01PH400/;2@0A4@l05QHD00P8
1P0;2`T03Ph<00l?3@0>3P`030`:00T81P0?3P/061LC00`;2@0E51401PD1010?3@0:2@H03@`801@C
4@0>3@X02PT501DD3`0=30T0QHAo06=RG@0>3@P04a8=00803@`700D03Pd800l>2@0?3PT040l:00l>
2@0200d<1`0G014@2`0G5Q406QTD01DD3`0=30L01`H100D40P0B4@`05A@?01DD4@1bLFd0:BPT00P7
1@0<2`L08B0L014@300>3@T02PT500d<20061@402`X600`;1P0=30L0100?3PT2010?2P0;00h=200=
30L040l:00l>2@0<2`L03Pd900`;1`0;2PH030/701LF4P0E51000P0;2PH0=`0>3@T040l;010?2`0:
2@D04a8>018A3@0?3PX051<?00`;1`0?3PX04Q4=00/:1P020@000`8000l?2P041@004a@>00`=2000
0@00?d0j00d>200<3@L0;c0Z05UJE00@4@/061TC01LH400@40H06aX?03@b9@0O70d08Ql>01XG200L
6Pd05aL?01DG500H71d04aLJ02d[;00R7Qd06aXH01`K6@0F5A<05ADC00T91`0C4a4061XG01/M6P09
2`P08RLS00D50`0m?C/09bLU00/;2@0@40h00`0?3`d01`0@40h03`l=00h>300@40h04A0<010?2`0?
3PX00P0>3@T0200=30P01PD100T8100;2PH020L3010?2`0920@030/7100>3@T02@0<2`L03`h:00h=
2@0<2`L05QDA00T810071P8051<A010?3@02018A3`0=010?3@0C4Q002@P600l>300A40h051<A014@
3P0B4@l04a8@010?3@0?3P`04Q4?014@3P03010?3@0400l>300@3`d040l=00l>30804Q<>0P0A4Pd0
200@4@`03a0;00T:1@0<3@P04Q<>01lP6`0=3PT02``70P0?40/2010A30804A8=00@04a@?01PI500D
5A004a@?0P0F5a80100I6aP0@dE202h`;@0`<Rl401@F4`0B01DG500B51404A<@014E4@0U:R@092TU
01@I500D6A<04aPD014F4@0B5a4020d900lD3`0>4`d061dI00dB3`0A5A@04QHE0P0E6AP00`0D61L0
4aLF01<G5P0401<G5P0401<H5@0B6A804aXC01<J508051XF02@061hK010F500I7al04aTI01/Q8@0B
61P04QPF01hT8P0Y;bd07R@R01@J600F71T06b4O01LM6@0J81d0728N01XP700T:bL05R4K01PS7@0E
81X03aXF018M6@0K9B@07BLX01<M7P0E7b4072HX020Z;00I8bD06bHX01`X:00M:2X06bHX01TT9P0F
8R8201/W9`0Y01/W9P0K9bL07BTY01/Z9`0Q<R`07C4Y01`_:@0O<Rh09cXg02`o?@0U=cL08S@e01DW
:@0U=c/0;d5502do@`0Y>3/0830_02Xj>@0Z>SL0:CTe01d^:00[>cP0;3`j02hn?@0a@4<0<d970350
A@0^@480;D1102do@@0_@D40;d1002`l?00U=C@0:cXi030n?P0X=c@0:cXg02Da;`0[=C@00P0^>3L0
1@0_>cT0<Shl03A0?P0]?3T0=4=000<0<T8o00h0<40m0310?`0dA4<0<d=20310?`0[>cX0:3Pg0392
@@0iBDP09CDd0392@@14E5<0<D4n03=2>P80;chg03@0<D0i030o>P0_?ST0<D0k02dl>@0_?S/0=DA1
03A2@P0a@3d0;SXg02Te<@0^>SH0=40l034m>`0/>3H0:3@b02@`<00U<C40:CDe02Pc=@0U<38082/]
01PV9`0^?3h0<d5402He>00Y>3`0<d9703E6C@0^?dH0;Ci50352B@0cATh0>TiI03e?F`0eAe80<dI=
03M8D00fAdd0;3i202Xi?00/?3`09cLf02Le=P0_>SP0;SLd02`e<P0^=c@0:34^02</:@0Q:RL0:C8_
0P0Q:RL0500g@3d09c0/028]9@0T<2H09c8Z02Pa;P0W<2d0:2h^02L[;00Q9BH07AlM01lO7@0Q8Qd0
8R8L024S7P0/<Bd061dI01lT800A5Q80A4U50P0L8Ad0100M8Qh06b0L01XO6`0L8Ad2024S8P05020R
8@0N81l071hM01XL6`0K7A`0100J71/0<`0I6aX07QlQ01XK7@0I6Q`06Q/M01/L7P0H6A/05aPJ01PI
6`0G61X05AHH01LH6P0Q8b8071`J01PH5P0G5aD07AdK01/K6P0E5AD04Q8D01<C5@0E5AL05aHK01TH
7@0H6Ad061dP02D/;`0J7b807b@X01hR9P0M8B@04aHK01PI7P0:2`l051@I018A5`0F5a/05ATL01DF
6P0C51P04a@F01PH6P0K6ad051@D01<B400A40h061LE01dI600H51<04@l@01<A4P0201DC500401<A
4P0B41404Q0A010>3`803`d>0P0>30d04P0>30l061HI01HD5`0@3Q4071XM00L5200D4QD04@lB018@
4`0>30l04Q0C00h;3@0B3Pl0510A018>3`0A3@h04Ph?00l;308040`=01T0;RX[02TU9P1iMGH0:bLX
01XF5`0M6AX0HUiO05IBD`0?2``03@T:018>3`0D41401`<400P41@0U8B80:B@U00d71`0;1@D040X:
014;2`0@2PX03`T900`61P0=1`L03PP800803`T900@03`T:00h82P0=1`T03`T;0P0A2`d01P0>20X0
3@L900h82P0@2P`04@/=00h82PH04@H:00<040D901462P0C20`00P0C20`00`0B1`/04@H:01462P04
01462P8040D901004@H:01052@0@1@T03`@800/21@0700403PH800l62@0=1@L01`0100l62@0=10L0
40L:00/21@0H3a8040L:1P0=0PH01P0;00@0:AhR02hS9`0B1`/02@0200X00aCooooo000Kooooo`0<
01<E400A4`l0=CLb00lA300N81/02`d:01@F4@0?4@d02`d8010B3@0C5A004Q@?0P0?40/02P0>3`X0
4A8=00`=2@0L7AT03a0;00d>2@0<3@P04A8=01<D3`0A4Pd200d>2@0500h?2P0?40/0414<010A300=
3PT00P0F5a802@0:2`H04Q<>018C3P0=3@`051@B00h>300C4a403Ph<00`<2P0600l?3@0B00d?300C
5A801PP500/=2P0F61D03@l<00h@3@0:30T03a4>018D4@0=3``03@l;018D3`0@4Pd02`d8010B3@0B
50l03a4<0P0<3PT0700>40/03@l:00lA300?4P`03a8;014C3P0@4Pd030h900h@3@0@4Pl02`d:00h@
3`0D5QD03Q0?00/=300:3PX0314;00P=200;40/02@h800hC3P0@5@l00`P200X>2P0>4Pd05Q/E00/@
2`0=40h200h?4@0G014B500C51H061TK01PI6`0<3@l03@h@01@E5`0=3Q002``=00`<2`0>3P`04Q8@
010@3P0=3@/04Q8@01DE4`0:2PP030`:00/;2@0A4@l0410>01<C4@0A4@l00P0>3P`200l?3@08014A
3`020P406ATG01HF500H61H03Ph<00h?2P0=3PT200`=2006010A300C50l0:R/V018C3P0;30L03a0;
0P0=3PT0200=3@/0410?020P7P0;2`T03Ph<00/;2@0<30X03Ph<0P0A4@l05@0>3P`030`:00l=3@08
1PH04a4A01lM7P091`P03Pd<01<A4P0A3a0040l>00/92P0@3Ph02`X800/:1P0:2@D0:RTT010?2P0?
3PT02PT400d<1`0200h=20803`h900<040l:00d<1`0=30L0100=30L0500@3`X051<>00/:1@0B4@`0
40l:00l>2@0<2`P09RDQ00D40P0C4Ph02PT5010?3@0=30P03Pd900d<200B4@d02`X600l>2P0=30L0
3Pd8100?3PT400`;1P0;00l>2@0A40/03`h:00h=2@0<2`L03Pd901<B3P0G5Q804A0<00h=2@0A40`0
0P0>3@T00`0@3`/04A0<00l>2P0200l>2P0c01HE4@0d<bl08B0L00X91P0E51003`h:00/:200A4@d0
2@X601<D3P0<3@T04a@>00X;200?40X05aPB014B300D5@l03Pl901<D300F5PD04a<001hL1@0l>B00
?cXP040k7`0Z9@/09b@;01hN2P0E60/04QL<01@J4`0S8Ql071PG01HE4`0G5Q@04a8@01@D4P0C4a40
4A4?01<E4P0A4a00418?07IkM`0[:bT0GEeK03dm>`0C4a405QHD00l?3@0>3P`03`l=00803Ph<00<0
410>00h>300@3`/0100@3`/01`0?3PX05aHB030_:`0;2PH06APD01DD400<2`L00P0>3@T400d<2008
00/:1P0B4@d04A0<00/:1P0B4@d05aHB01<B400@3`d2018A3`05010?3@0D4a403Pd;01<B400:2@L0
0P0=30X01P0I61H03Pd;00d<2P0=30X04A0>018A3`804A0>00D040l=018A3`0A40h040l=018A3`02
00l@2`03010A300A4Pd04a@?00804a@?00@03@h:00`=200B4`h0414<0`0?40/01`0@4@`04A8=014B
3@0A4Pd051D@014B3@0@4@`00P0H6A@02@0A4Pd04A<@02<U8P0E5a@0828O00d?300C5A805ALD01@F
4`02018D4@0:01<E4P0G6QL0<3Db030d<`0G6aX04QLD01DI600H71X04AHC018F5@8051PF00L04ADD
01TM700D61L04aLF018F5@0C5aH051PG00H05QXI010051XG010I500@6A@04AXE018K5P0B6aP051dJ
010I5P0D7A`03aLI01DM7`0I8R805Q`K01LM6`0H7Q`05adM0P0F71`01`0P9RH05Q`K01TN7`0I7al0
7B8S05MNG@0O:BL00P0L:2@0;P0H92805R8P01/W9@0O:bT05b<Q03E1@@0Q;Bd072PX01l[:P0E8b40
52<P01PV9@0K:BT06RPX01/Y:@0I9bP06bTZ020^;`0S<C808c4c024`<00M;RP07C4W020d:`0R=Bl0
8cHa02<f<`0N<300:S`m02m1@`0bA4P09SLm02Pj?P0[>Sd093@d02Xj>@0S<c009cLc02ho>@0Y>CH0
:3Pf02/k>P0_?T40<D1502dl@@0[?Cl202Tk>`0B02Xl?00Y>SX09cLf02Pf=P0Z>3P0:cTi02Pd<P0c
?cd0<Cdk02/e=00]=cH0;SPg02hj>00b?S`0=44o0391?P0dA440<d=00P0bAD40900_@Sh0<D5003=3
@P0c@d80;Cdl02Xj>@0]?C`0<40o02lo?P0`@3l0=dM607V9R00eAD80<T8i02ln=`0^?CH0;chg02dl
=`0[>SD0<T4l0391?P0d@d00=dI303I4A00eA440;c/h02Te<@0]>CD0=D4m03M3@@0iAD<0<3`j02Da
<@0T<3009S8b02@_<@809S4c0180BUQI06AbL`0c@D80:CPk02ln@P0_?T<0;3i202Xl@@0]?TD0;d17
0313BP0hCE@0>diF03A7C`0eB4h0>DYB03M8CP0_@DD202ln@@0802/k?00Y=cX0;3He02db;P0]<bl0
;S@`02H/:00U:bT202@Z:00E02lh=@0Y<Rl08R/X030j=`0T<2H082hR024/900Y<Rl0:c@a02H/;00V
:BX092DW024Q800S8R0092<O02DS7P0H6QD082DQ01lT800Q9R8082DQ00806b0L00D07B8N020U8@0M
8Qh0724M01lT8002024S8P05020R8@0N81l07AlN01/M700I6aX00P0K7A`01P0J71/06adL01`N7@0M
7R00824S01dN80806AXL0P0M7R003@0D5AL07b0R02X[;@0T9BL071hM01`L6P0F5a8061TD01@D4P0F
5QD0410@01<C4`0G5aP00`0I6A/03`0I6Qh061hS028Z;`0>5QX0620V03Y0AP0I7b@05Q/R01TL8`0E
61h05aTP01DF7`0C5Q`04ADG018C5@02010A4`0:01HF5P0J6QX05ADE018A3`0A40h061LC01dI5P0I
5A<04@l@01@B4`805Q@E00<04a4B018@4@0B41400`0B4140;00A3a0040h?014?4P0A3a805aDH00d;
3P0@3Q404Q0C01<A500B41<05A<F01HD5`0O7B005Q<E018>3`0D41404Ph?014=3P0B3Pl0510A00P5
1@0H51D040`=00/8200Y9BH0510A00P41@0C3a004Ph?00d92P0F4Q<02PH700l;300@30d03`/<00h:
2`0?2``03`X;00d71`0?2@T04P`<00d71`0A2`/05@l?0`0>20P200l92@0400l92P0<1PP02`D700`6
20803PP:00<03@L900`6200=1`T00P0@2P`00`0>20X04PL;01872`0401462P0500l4200@1@T04PL;
01872`0A1PX01`0?10P201462P0;01872`0A1PX040D900l4200>1@P02`D700l:2`0:10H091hP00d7
2@0:10H0100;1@L00`080P<03P<700h31`0400h31`0600T00P0J41<08AHJ01062@0>0`L04@H:5?oo
ool001_ooooo00H05Q/E00X?2@0A5Q0041D?00P=1`0L8A/200lD3P0401<H4P0=4P`010T400h@2`80
3@h900X07AhI00T:1@0A4Pl0/;6/059CCP0=3PT04Q<>00h?2P0D5A00414<1P0>3`T0300D5@l0<S<]
03<d;P0F5a404a@>01@E400<30X071`J00/;2@0C4a4061PF00@40PH03Ph<0180418?07=eLP0`<Rl0
4Q@A014C400K7AX03a4>00d?300?4@h030h;00lA3P0C5A403a8;00d@2@082`@03A0900lB2`0>4@X2
00X=1P0a00lB2`0;3PL02`h700d@2@0?4P/04aD@010B3@0<3PT03Q0=03`n>`0g>CH02@/:00H81`0C
5A@03@l>020S7`0h?cL072<K00`C2`022@404AP@00@9100N9Ad061lG01LN5P00100000<0018G500D
61/020`?01LK7P16BTd0[k>f02X^<@0F6Qd02`lB00lC5P093A003Q4C018B400>3`X03a0;010A300=
3PT04a@?00X;1P0A4Pd05aPC014B3@0200/<1`0401<C4@0A4@l03Ph<00l?3@804A4?00<02@T701hN
7015AD<00P0A4@l00`0=3@/0414<00l@2`0200d>2@0?00l@2`0A4Pd03@h900L80`0?40/04Q<>00d>
2@0C50l0@40n05]KF@00000010@200h>300G5aD03Ph<00803`l=01403Ph<00`<2P0:2PP02@L801@B
5@1@CU40Shf@01dK7P0:20/0;bd`00/9300I5aX0518E00`:3@0<2P/030/701XI50020040000301/J
5@0=30L03`h900<03Pd80`0=30L200`;1P0<00h=200@3`X04A0;018A300>3@P00@0000d<1`0920<0
4A0;010?2`0510000@000P0:2@D02@081`<04a8>00h=2@0920@030/700P70`0>3@T040l:00h=2002
00d<1`0300h=200?3PT04A0;00804Q4<00D051<>01LF4@0C4Pd030/700d<200200`;1`0`00h=2@0=
30P02`X600l>2P0A40`030/700h=2@0B4@d05QDA00D4000T8al0<c8^01HE4@0S8Qh02`X60040000:
2@H04Q4=01<B3P0?3`X02P/501PI4`0E5Q0061TC00d>200>3`T0414;014B300R8ad010D001TJ4@0G
5`007Qd002l/2P17@ah0OWUC07iiD@1=B280=c<>02LW2@0V:180724;01`R4P0K6QD081`K01`K6@0F
5A<05aHD0P0E5A<03@0;2`T05ALD01TK600B51402Pl;014A3`0D51804Q8@014A3`0?3`d02`/900d=
2`0>3P`00P0<30X02`0A4@l030`:00d<200?3PX04A0<018A3@0A40`040l;00d<200G5Q801`H20080
40l;00<04A0<010?2P0>3@P00P0;2PD02P0>3@P040l:03ln>@0@3`X081lJ00l>2@0@3`X02`X6014@
3P0=30X2010?3@0800l>300C4Q003Pd;00h=2`0A40h051<A014@3P081`D200h=2`0A010?3@0C4Q00
4A0>00l>300A40h03`h<01<B400A40h03`h<01<B400A4P`03a0:00h?2@0?40X04A8<018C3@0<3@L0
0P0H6A<0100=3PP04a@>01DF400?40/2010A30<04A8=00<04Q<>010A300?40/00P0F5a80100A4Pd0
61XG014C400A4a0201@F4`0301LI5P0D5Q<04aDB008051HC01405ALD00hA3`0B5QL041@E00`@4@0D
61T05a/L01TM7P0A5AH0A4Q900dA4P0F6Q/0310A00lC4`0D61L04aLF018F5@02014E500401<G5P0E
6AP05ATH01HJ6@805a/J00@05A/H018K5P0B6aH04a`H0P0C71T03@0E7Q`01Pl>018K6P0a>C/03QHH
01DM7P0L8R806AlM01DK6@0F71`061hN01XO8P0E6Qd00P0H7B005`0>4aL04AHJ02Xa=00J92<062@R
01dY9`0N:RP062@R01TU8`0jAT@0:3@b01l[:@0B7Q`07b/Y01TU8`0P;b`072/V01d/9`0N;BX06RTV
01`Z:P0O;Bh07R`]00807R`_020082dc020_<P0O<2X07c<Y024e;00Q=2h083<^01ha;@0W>CT093Hg
02Dg>`0U=Sd0<45806anPP1MK6l0;Shn024a<00Q<Bh0:SXf02`m=`0/?3T0:CTg02`l>`0a@4<0<d97
02hm@P0Z?3`0:C`j02Pk>@0[>cX0:CTh02De=080:cTi01d0;C/k02/g=@0jAT@0?4Q6038l?@0e?d00
=T1103I2@P0fA4@0>4I603E4@`0dA4<0;d900395@`0aAD<0;d9003A4A00iBDT0?De=03E5A@0a@D40
=TI603];B`0dA4@0=TI60392@P13De<0;3`k0350>00202ln=`0@030o>00^?CP0;3/f0391?00iB4D0
>TU603I5@P0fA4@0>4M4030l>@0`?3P0<clk03A0?00e@Cl0>dM503E1?`80;3Ph00X09c<c02<^<00Z
=CL0:SDg03A2@`0/>S/03adN02<b=@0d@dH0<3m20P0bA4P0<P0^@4@0;Sm60313B@0cB4/0=4M=0313
B00bADT0<TA802i0A00a@dL0<T5602`k@00_?T<0;3To02D];@0W;2H0;34]02/`;00R9b<09bdY02H/
:P0P9R@0:c@a02H_;00Y<Rl0FfER02Te:`0R<2<06RLN01/V8P0N9b@08RPY01lP900Q8R@08b<R024P
7P0P7aX08R0K028T7`0G71P08BHR01DJ5P0I7QX08BHR01XO6`0N8al08RLS01lT800M8Qh08BHR100O
8B00;@0N81l071hM01LI600K7A`071hM01/M700M7ah0828Q020Q8`0O828071dO01TJ700G61X061TK
01lP8P0D5AL08b@V02d^<00R8bD061XI01/K6@0H6A@071dH00/;2@0D51805ADC01DE5@0J6QX071`L
01XJ700H61X061TM00dD6P0?6R406B@Z04eGH033c=@0PhbC02he?`0D6b@03A4J00T=5`0C5b806AhT
01@H6P0201@E5`0=01@F5@0D51@04a<C01<C4@0C4Q0040l=01<B3P0G4a004`l<014?400C4A80518C
01DC500201<A4P803P`=100?3@h0200<2Pd040hA00H41`0O7B0030X=01LE600>30l030X=0P0>30l0
1P0G5AP04@h@014=3P0B3Pl04@d>00l;308040`=01/03@T:018>3`0<20T03PX;018>3`0?2``05Q8C
00D10P0=2@X05Q8C00/7200C3a004Ph?00h:2`0;1`P02@D600H20`0;1PL03PP800d71`090`<02P@4
028L700X8R804@/;00l92@0>20P00P0?2@T01P0@2P/03@L900d72@0>20X03`T;00d72@<030H80P0?
2@/01@0=1`T04PL;01872`0B1`/04@H:008040D90`0B1`/00`0A1PX040D900l4200601052@804@H:
00X04PL;01462P0A1PX03`D9018930070@<03PT:00@0000E3a4010000P0<1PP0100:10H040X<00h8
2P0@2P`600h31`0601P=4@0<0@D03P<700/0100A1PX030455?ooool001_ooooo01X000@0010E3`00
1@005Q/E00T>200:3`T010T300T>200E6Q@01``6010E3`0K7AP030d801<D3`092PD0414<014B3@10
@C`0R8V401@E400J6aH030d8010A300?40/0414;00l@2P803Pl90P0<3@L0300@4@/04a@>01@E3`0:
2`D03Pl900X;1P0D518010@201TI5`061P@04Q8@01<C4@H03@d;00L03Q0=05IHE@010`004Q@A00lA
3P072@H03Q0=00804A<@04X030h;01XL6@0N81/04A@=00h@2`0930H03Q4:014C3P0?4@/02Pd600X<
1`0?4P`020/400H80`0:3@L03a4<01<E400A4`h030h900h@3@0C5A802`d:00X<2`0F61L04Q@C00lA
400?4Ph04QTB00870@083PP01Pd601@I4`0<4P/08bXS00@90`0M8ad00`X301XO6@062`P051PI00`@
4@0J7Ql0E5QI0=kRh`0^<S<05a/L00T=3P0?4a@02`l@01DH6@0L71X04Q<>00d=2P0@40h03@h900h?
2`092@L03a0;00/;200=3@/02``700l?3@0>3P`03@d;00h>300?3`d0410>00d=2`092@L092@R03lo
?@061P@06QXH00d=2`D03@h9010030d800h?2P0D5A008B8M01/L5`0:2`H03a0;0082000R8R004a<A
00d=2`0@40h02`/900T91`0;2`T030`:0`0=3@/0500G5AH00P41030^;`2:R8T04a4B01PF5`2;RHX0
6APH00d;300?3@h02`T:01@C4@0C4Ph02PT700T80`0M71L020L401DD3`0@3`X03`h90P0>3@P0200=
30L030/6010?2P0<2`H02`X500d<1`0B4@`051<>0P0>3@P04P030P004Q4<00L60@0@3`X030d800X;
1P0@4@`03a0;01<D3`0;30L09RLR01XI5@0?3PX03Pd900T8100@3`/04A0;00h=208030/600T03Pd8
00l>2@0A40/04A0;00l>2@0>3@P040l:014@2`0@3`/00P0C4Ph00`0?3PX03Pd900l>2P0200h=2@1n
00/:1P0920@051<?01HE4@0D4`l00`8003dl>01@Cd/04a8>00X91@0@3`/05A@@018A3@0920@03Pd9
01PH4`051P002``6010A2`000@006Q/F01DF4@0@4@`010D000h?2@0E5Q005QL=01@C000V8`00A3lI
06MP=P31^8d0b/:D08MnD`1PFc<0@T0O03Xm8P0V:A@06Qh>018A300N6QT06QTG010?3@0B4@l03Ph<
00P81P0>3P`05aPF00<30@0?4@h051HC00d=3@0>3P`06Q/G01PG4P0I6A406APC018>2`0B4@d03`h<
00h>3P0D51@03`l>00X:200=3PT0414<014B3@0B4Pd04A0<01/J5P0;2PH05A@@00/:1P0=30P040l;
00l;200<2PH02@P300d91P0C40`05aHA09nKV00F51004Q4<00/7100E4`l03`h:010?2`0<2`P03`h:
010?3@0?3P/04a8>00h=2`0<2`P03Pd900L6100=30T03Pd;010?3@0A40h04a8@01@C4@0@3`d03@`:
014@3P0?3P`04a8@014@3P0?3P`04a8@01/K5@0F5A004Q<=00l?2P0>3@P03@h800d=200<2`L0414<
014A300C4Ph020T4018C3P0C4a404a@?0`0D5A003P0?40/04a@?010A2`0B4`h05AH@01<D3P0B50l0
3@l:01PJ5@0?4@`03Q0;018D3`0@5@l051HA0P0D6A<00`0C61805QXH01PN7P0200hD500;01@J6P0@
5QH061hN05EKF`2na<@0728R00dC4`0K8B403a@C00lC4P0B5QD00P0D61L201<G5P8051PG00L05ATH
01HJ6@0F6QT05Q/H01<L5`0D7AP051dI00805AhK02h06B8O00H?300S;2/0GFIU01XS8P0D7A`061hL
01LM6`0D6QP04ALG018H600F6ah051TL01/P8`0E6al061dQ02@[<@0H7b@072PX01HR800G8b<062@T
01HR8P0M:BT072PX02Hb<P0W<c<06BDU02@`<00P;2`062LT01@S7P0J:BH08S4^02<a<@0[>CX0;3Xk
02Pf>@0P;C806RL]01/X<00M;340830_020c;@0R=Bl08cH`0P0U>3@0<P0[?S`09CLh03E7B`0eATd0
7Rlf03]<D`0]?4<09SDi0392@P0X>3P093@b02Xj=`0X>3D09CDc02Ph=`0]?Cd0;ci202Xi?00[>cX0
:CXg02Ti=P0Z>SL0:3Pe02@d<@0Y=cL0:SPh02hl?00/>3H0>dM503a8AP0`?3`0=41003E1@@0c@D40
=49203A4A00eADD0<TA402i0@00a@d<0<DE402i2@@0^@400=dU903e?C`0eADD0;Shn03=3@`11DE40
?dm?0P0lC4`00`0L;2`0>d]:03I5?`0203=2>`0I03=2?@0_?ST0;C`g03=2?@0lBdP0>dY70391?P0_
?Cd0<T4n030m=`0g@S`0>4@n03A0?00b?CT0<chk02/g=@0Y<c80<3/k02di>@0Z=3D0:38c02Da<@0Y
=CD0:SPi02Le=P0202Dd=`0<02ln@`0hBTh0>daC03A3BP0e@d`0=TQ=03A7B`0cATX0<4960394B00_
@DD0:cXo0P0c@TL0:@0[>C`0<T1302hl?`0R:b/09R`X02hc;`0/<Bd08BLS02/a;@0N9280:c4_02L`
;@0M9R<0:c@a02@]:P0R;BD08BhU01l/900K9R8072DT024X:00H71l07QlQ028S8P0O7ad071dH01lO
6@0P8Ql07R8Q01/O7P0_<c800`P401/O7@0G71P0724M024V8P0M8Qh06b0L01lT800N81d07R0O0080
7b4P00h07R0O01dO7P0F61L06adL01dO7P0L7Qd07R0O028T8`0T9BL07AhP01TJ700J6ad061TK018C
5@806Q/M02T0824S01PI6`0C51H09RPW01/K6@0C4a407AdK01<C4@0H61L02@T901<C4`0I6AT06a/K
01PH6P0E5AL05AHJ01TP9P0E82H0;3Lm075jP@3eoOl0Y:^e038i@`0I82T07R8[018F7`0@51d04aHM
010C5@0A4Q@04a@F01DG5P0C4a<0410@01@D4P0F5A<04Q4?018A3P0C4Q0040l=018@4@0201<A4P80
518C00D04a4B01HD5@0D4Q<04a4B014?400200l=3P0M00`:3@0O7B002`T<03/i?00F51L061HI01/I
700E4aH0518E00l=400D4QD03``>010<3@0A3@h040`=00h:2`0@30d03`/<01/G600<20T040`=00h:
2`0B3Pl03`/<00@00@0H51D05a<D00P41@0D41400P0;1`P300h:2`0:014=3P0D3`l030H600d71`0D
3Ph02P@400T30`0A2`/04P`<010:2P<03`T900<040X;00l92`0?2@/00P0A2`d0100>20X030H800/5
1`0<1PP200l92`0500d72@0B1`/04PL;01872`0A1PX0100@1@T0100A1PX04PL;01<8300D2@d70146
2P<04PL;00h04@H:01052@0600005a4C00/51P0[8RD0VI:D01hH6P0D2`h03`L:00H00P0>1@P02P@5
01072PH03`@800H0304500/2100A1PX02@0200`21@0<0@DDooooo`006oooool01@0=3`X0418=00d?
2P0=3`X03a4<008030h900L02`d800h@2`0A4`h04A<>00d?2P0@4@`03a0;00803@h900X03a0;010A
300K71L051D@014B3@0>3`X05QLB00l@2`0<3@T0414<0P0B4`h0200M7QT0>CXe00l@2`0E5Q404Q<>
00`=200=3PT03a0;0P0?3`d2010@3P03014A3`0@40h03Ph<00<0410>00T03Ph<00d=2`0>3`X04A8=
00l@2`0>3`X03a4<010B3@0=3`X00P0>4`d01`093PP03Q@>00`?2P0=3PX03Ph<00h?300?3``00P0?
3`d01P0>3`/03Ph<00h?300>3`/03Ph<00h?30<03`l=00<03Ph<00d=2`0=3@/00P0@40h09`0>3P`0
4A4?018B400@4@l0310=00L91`0>4@l0310=00/=2`0<3`d01@P600lA3`082`T02Pd;01<E4`082PP0
4aDC010B400L7Q`03@l=04=5@`0I6aT0418@00lA3`0>40h02`d;01XL6P0W9bL05QHE00/;2`0>3Ph0
3@d<01HF5@0C4a<04A4@00l?3`0A4A404A4@010@4005010@3P0E014A3`0>3P`03`l=00l?3@0<30X0
2`/9010@3P0B4Q004a<A034a;`010@003`l=00h>300=3@/06QXH00P81P0G5aD02PX800h>300>3`X0
3@h900@02``70P0<3@P200d>2@803Pl:01004A8>01<C400>3P/03@h:010@3@0=3@X051@A010@3@0>
3`/0414=00l@300<3@P03a0:00l@200=3PH030d50P0=3PH00`0?40P03@h600`=1@0300d>1P0501@E
3`0?40X03Pl900l@2P0>3`T00`0=3PP0;@0>3`T030d700/<1P0=3`P04aPA02D[900D6Q805ATB00P<
1`0>4P/03Q4:00d?2@0;3@H0414;00X;1@0?40X03@h900X;200A4Pd04A8>00T:1`0H6A@02P/600l@
2`0>3`X02P/600d>2@0@4@`030d801HG4P0?40/04Q<>00P9100;30L051D@00T:1@0B4`h01PL301<D
3`0<3@P061TD018C3P0@4@`051D@00/<200200d>2@0N00l@2`0=3PT02P/600/<1`0@4@X030h401TJ
500<3@P03@d;02/[:`0G5aP04A4A00d=2`0C50h05aPA01lP4`0a;0h0<2X606=J<02`XWL0m^o10?ok
c@3gkL80_[::05iF=`0_;AP0;2dN01dP5P0H6A@05aHB0`0E5100>@0C4Ph04A0<018A3@0B4Ph040l;
00l?2P0A4@h07AdN05]KFP1WIUh0UYB303Te8P0T7@`06a8801`C3P0E3`l04PhB01LE600D5AD03Q4>
010E4@0;3`/030h;014B3`0=3@/03Ph<00d<2P0>3@/04`l>014=300>2@P050h>01<=300E40l03`T9
01@?3P0?2PP05@l?01@?3P0B3@`04P`<014;2P0?2`T03@`800l@2P0G6180414<014B300?40`02P/5
00h?2P0?40X051D?00`=200A4Pd04A4?00T92@0200d=3@0R00h>3P0B4Q804Q8B00l?3`0;2`/0@d=3
04e=C@0>3@/04a4;01LD3`0;2@@04a0;01@@3@0A3`/0514?018>3P0@3@d04PhA01HA5P0E4aD04A8A
014C4P0<3P`04Q@A00`>2@0C5A004QD>01DH400E60l04QD<01PK4@0@4`T04QD=01@G3`805AP@00D0
4AH>00lE300A60l04AL>010H3P02014I4007018L5@0?6AH07BLS00hH500D7Q/05R0M07J0O00203Do
>`0601@N6`0A6aP041XG01LN6`0F6aL04aPD0`0B5a<02P0D6AD06AhJ01dR7P0I7QX04aPD01DJ5P0I
7QX05A/G018H500C6AD201DK5`8051XF09D06R0M01lU8P0M8b005Q`I01PN700F71X05adK01TO7@0K
8Al0624P01`U900F7ah05QlP01TR8`0G8B<06RDW02Da<`0=6a/06BLX01PV:00E8bD07B/]02Ha=P0_
>Sl0?4M<03Y3B`0[=3`09Ble024_<00K:RP08Bl_02Dc<`0N;2d0938d01h/<00T<CL072Ta020]=@0T
<CX0938j02@d>P0O<C@08cHf02Dg=P0T=c@0:Sdi02Lj=P0V>3P0:C/n02m0AP0X>D00:3U402De@`0W
>4D0:ca502Dg?@0Q=3D0;D0m02`o>`0T=c<09cXg02/n?00[?Sd0;Cln03E6@00b@S/0=4<m0350>P0Y
>3<0:3Lb02/j=P0]?3T0;3/h02hm>P0a@3d0:CPf02/m>`0/?S`0<dA303A5A@0b@d@0=TQ:0353AP0c
ADX0=DM<03I7CP0cA4`0<DA902a1?`0cAdD0<TI403=7A@0dAdD0<DA20395@`0b@T40=TI503A4@`0g
ADD0=D=303M7@`0b@ch0=dQ303I6@`0b@Sl0=DE203I6@`12DTl0@E5>03I6@`0a@Ch0=4<n038m=@0d
?SH0BeE>041;A00^=c80;cTd02H`;00X<Bh0;SPe02/d<P0Z<c40;3Dc02@]:`0W<2l0<Cdm02Pf=`0U
=3L0:c`o03]=D@16E5`0>4E?03e9E015Ced0>dQA03];D00`@DD0;Ce202hm@P0[>C`0=D95041<D00f
@TD0=3m002/f=`0R;Bh0;cPh02@]:`0202Ta;`03028[:00U;R/092dX00809c0[01T09BhX02L`:P0T
;BP07RPV02D`;P0Y<c409Bh]01/T8`0O9bD0728Q01hS8@0Q928082<P01lS7P0R9B40EEUK01dP900M
8B<07B4R028V9P0O8b<0:2`Z02<X900L8Ad0724K00807R<M00<07b4N020R7`0O8Ah00P0M7a`201XL
6@807AlL00L06adJ01TK600H6QL08B<R01hP7`0J71/061XI00805aTH03407R0O02@V9@0O8B008bDT
01HH5`0I6aX071`M01DE5P0G5aP061PI01@D5P0B4Q@0410B01XJ700@418061PJ018B500M7R0051/L
01@N7`0H8B<09bhc07j5R`1>DU/07B4Z018F7@0C5Q`051PL014E5`0C5AP04A4B010@400E5AD04A4A
01XJ6P0C4a<04Q8B01<C4`0K6a/0=CDd01LG5`0D4a@04Q0A01<A4P0D4Q<06ALH020N7`0C4A804@l@
00803`d>00h040h?00l=3P0=2``04@lB01TG6P0M6ah04a4D01/I700_;C00>SPk00X82`0L6Qd02`T<
01LE60803P`?00D0518E00d;3P0E4aH01`D800l=400200h<3`<03`d@00L04PlA00X61`0B3Pl071PI
014=3P0>2P/03@T:00@03PX;00D03@T:00d82@0>20X03PP:00l92`02010:300300l92`0>20X03PP:
00<03PP:00<03`T;010:300?2@/00P0=1`T01`0?2@/03PP:00h82P0>20X03@L900h82P0B30h00P0C
20`08P0?10P04PL;01462P0B1`/03`@801T>4P0K41@050T=00`21@0B1`/0304501@93@0>10L04@H:
028G6`0J3a<040H900l4200>0`L03@8600`31@0?1@P03@@600/3100>1@P07Q<G05Q>DP0?1`P03PD7
00d31P0?1@P040L900d31P0?1PP200h31`<03@8600<0304500l4200?10P0100?10PDooooo`006ooo
ool02P0<3PT03a4<00d?2P0=3`X0418=00d?2P0>40/04A<>01<E400B50l2010B3@0O00d>2@0>3`X0
3a0;00l@2`0>3`X03@h904e>B@0K71L03@h9018C3P0A4Pd01`P3018C3P0=3PT02P/600L80`0<3@P0
8R<N010A300=3PT02``700d>2@051P4030d800h>300=3@/030`:00d=2`0?3`d0410>014A3`03018B
400?014A3`0@40h03a0;00X;1P0;30L03Pl:00d?2P0<3PT04Q@?00dB300:3`T082DO01XQ6P072@L0
3`l=00<03Ph<00<03@d;00h>300>3P`01@0>3P`300l?3@0300h>300=3@/03@d;00804A4?01T03Ph<
010@3P0@40h03@h<00D71P0:30/02@/:01<E50010`80418A01`N7@0>40l071hM01DG5P000@006A/I
01<E4P051`@061XG01@F4`0@4Pl03a4>00`>2`0A4a00418?00801PP500H04A4A00d=3@0@41003`l?
00X:2P0B4Q83010@4003014A4@0D51@071`L00H03Ph<00@03@d;00`<2P0;2`T03@d;0P0?3`d200X:
200?01HF500820H0410>00X:200B4Q006a/I00`<2P0F5Q@02`/900`<2P0A4Pd03@h900`=200>3`X0
3a0;00<030d80P0=3PT200h?2P06018C3P0C50l03@h900/<1`0>3`X02P/60P0<3@P01P0>3`X0414<
00l@2`0<3@L03@h800d>1P8030d50P0>3`L02P0;30@03@h600h?1`0>3`L030d500/<100P8A/05AH@
010A2`0=3PP200`=1`1@00d>200>3`T020T300`=1`0>3`T01PT200T?200[<RX0SiJ>06icK00C6140
0@H0018E3P0?40X02P/500h?2@092P@03a0:018C3P0D5A000040020Q700U9R40:b`W010A300?40/0
3Pl:00`=200;30L03@h902<T7`0f=c8051D@014B3@0<3@P03@h901@E400B4`h04A8=00<4000?40/0
51D@04a=B00k?3L0:BXU02`]:00@4@`05AHA00d>2@0<3@P03a0;01<D3`0D5A005AH?00X<0@0?40X0
4A4=02@T8P2b/[80A4A4010@400?3`d05AHA01TJ4P0R8aL0;RX=03Tc3`1hKdP0a[V?0?ojc`3oom@0
imVb08IlF011>Qd05aH405mQE00>4`/051D@01@C3`0C4Ph201DD400401<B3P0B4@d04Q4=018A3@80
40l;01d051<?04=4?`2VYil0EeM40;JeV@2IUGP0Ad4W02HO3@0V7Q<07ALB01<?3P0B4@l04Q@?00hC
3`0@5A403A8>00h@3@0A4Pl03`l=01PH5P0E51803Pd;00l;2P0D40l06QHE010<2`0A3@`05a<B00h:
2@02018>3@0>00l;2P0A3@`04`l>018>3@0?2`X02`L600h=2@0;30L03a0;01@E400A4Pd00P<000T:
1@0<3@P200H70P0401<D3`0Q8Qd0IFES01/K6`80410@00`01PH601<C4`0=3@d00`<3018B4P0n?Sh0
@41001PH5P0B4@d040l:01HE400=30P2014@300B01@C4@0B41404Q0A01<A500E4aH05Q@G055BD@0L
7Qd04Q@C01TK600=3`X05QPC00P:1P0B5@`061/B00/>1@0J7A803A050`0B5@`08@0D5`h04aT?01HM
4`0=5@X06B4F01PQ5P0C7A806bDJ018M5@0540`051lK01PS7`0951005R4M08RCS`0`>cL031LC00/F
4P0G8Qh03QTE01@L600C61@041DA01<H500I7QX06QlK01TN6P0G71P05AXF01<H500B5a<04aPD01<I
5@02018H500401HL600H7QX05Q`H01DK5`805adI00H051XF01<I5@0E6aL06R0N01TO7@0G7A/201TO
7@0;01DN7@0E7ah05b4P01/U9P0G8b<062@T02Xe=`1HIVL0<Cm001/Y:P0M:bh00P0O;C00:`0d?dD0
@diD07Z5R`1UKgP0ADmH02`f?P0Z>3T09CDd02Ti>@0Z>SX08C4a01h]<00T<cP0<D1502@c>P0O;SD0
9C<k01XX<@0T=Cd08S<j02Dg>`0V>3P09STg02Xm>`0N<Bl0:chm028d=P0gBDd0=TM>02Lh@P0Z>TT0
9CE502Hg@@0W>4009SPk02Tl>P0aA4009STe02Pk=`0^@Cl0;T5002/n?00cA3h00P0_@3X02`0/?CL0
9SLb02Lg=00Y>CH0<D500392@@0a@D00<40o02Xj>@0`@d40;T100080<D=301L0<D=503A6B00`@TH0
<dA;03E6C@0fAdh0=TM?03A7C@0dBDL0;T9002a0?P0cAdD0=TU70354@P0bAD<0=4A303e=C00c@d80
<Clo030n?P0b@Sl0<d=003I6@`0203E5@P0703Y:A`0hB4D0Be]H04MGE00a@Ch0;Cdj03I5@00202Xd
;00T04I@B00oBD40:34/02L`:`0_>3<0;CHc028[:00]=S<0<3Tf03Dl>`0[=3<07bPW02Lc<P0[>CT0
9cHi02Hg>P0W>Cd0@U1I03e:E00c?d/0@D]G03=0B@0jBDh0<d9702Xi?@0T<cH09C<f02hj?@0mB4X0
9c8d02Pb=00a>c`0HVa]08bEU@0c?3/0:34`0P0W<2l05P0R:bP09Bh[02Tb;`0X<B`09S0X02Pb:P0U
;bP092h]028/;@0kAD@0;SLf024Z:@0U;R/07B<Q01hT8P0O9200724M01/P700N8ah092PY01/O8P0U
:B`2028V9`05028V9@0N8R40720O01/P700L8A/00P0M8Q`01P0M7a`07b4N024S800L7Q/06Q`I01hP
7@807AlL00L06Q`I01PJ5`0J71T07R0M01dO7P0K7A`05aTH00805ALF00P05QPG00T;2P1lOWd05QPG
01XL6`18BTT06adL01lO8@<061PJ02L05ADG01HF60071`T04Q8D014A4`0N7R006QXL00d>400L8R00
5A/L01`Q900=4QH04ADJ020S:P0F6B004aDK01DF6`0C51P0414C01<C4`0H61P03Ph>01<C4`0A4A40
20P8014A4@0D51@0410@00h>3P0O7al09bLW024Q8@0A3a00518C01DC500A3a005A<D00/92P0B4140
0P0@3Pl05@0B414040h?00l=3P0E4aH06QPK01hL7`0C4A@03P`?01HD5`040PD05Q@G01LE600:20/0
518E00l=400@3Q403P`?018@4`0?3A006aTL010>4@0200/9300600`:3@0@3Q404a4D02<P8P0G4a@0
30P90`0@30d0100<20T03PX;00h:2`0=2@X200`82@0300d82P0>20X03`T;00803`T;00<040X<00l9
2`0>20X01@0>20X01P0=1`T03`T;00l92`0?2@/03PP:00l92`802P@600D050h@01PB500C3@l05``@
01<8300201052@0P01462P0=0PH03@8601<8300F2`l04`P<00h31`0F2`l03@8601052@0?10P03@86
00l4200=0PH0;24U01T>4P0E2Ph05``@00/0100?1@P06@hB00P00@0C20`050T=00P00@0?10P05``@
01462P0N4aL01`0001<8300D2@d300h31`803@8600<0304500l4200?10P0100?10PDooooo`006ooo
ool03P0>40/04A<>00h@2`0>40/04Q@?00lA300=3`X04aD@01@F4@0A4`h03a4<014C3P0<3@P03Pl:
0P0@4@`06P0>3`X030d8024R7@0<3@P04Q<>00X;1P0=3PT04a@?018C3P041@0030d801XK5P031000
004001/L5`0:2`H02@X501PI500@4@`04A8=00l?3@0=3@/030`:00d=2`0@40h04Q8@1P0A4@l200l@
2`0:014B3@0<3@P01@L200D70P0B50l03A8<018G4@0k@3X0>T4j014D40803`l=00@03Ph<00d=2`0=
3@/03@d;1P0>3P`300l?3@0K00h>300=3@/03Ph<018B400A4@l03Ph<010@3P0?3`d03Pl>00lA400I
6aX03@h=024S8P000@005QPG00<510000@004Q@C01/M700F61L03Q0>00/=2P0@4Pl07R0M018D4@0<
3P/04A<@00<030h;00/02@/800h@3@0A4A403`l?018B4P0@41002@T900X:2P0=3@d03`l?010@4002
00d=3@0301@D500>3P`03Ph<00<03@d;00L030`:00l?3@0<30X030`:014A3`0C4a404A4?008030`:
00P03`l=018B400@40h01@D300P81P0A4@l020P6010@3P803@d;00H04A8=00`=200;30L03Pl:00l@
2`0;30L200`=20803@h90P0>3`X0200;30L03Pl:00X;1P0:2`H03a0;00`=200;30L03@h90P0@4@`0
0`0>3`X02``700`=1`0200`=1@0<00d>1P0?40P03a0800d>1P092P802P/300d>1P0:2`<01PL001@E
3`0>3`T030d70`0=3PP06@0B4`d061TC00`=1`0<3@L0414;00L:0`093`P04AP@07Z1N@1JGeP03A8;
00X?200J7AH051D?00h?2@0@4@/02``6014B300;30T02@X502h_:P0J6aH0`<6l01lP6`0?40/00`0<
3@P0<P0;30L01`P300l@2`0Q8Qd02P/600T:1@061`803Pl:010A300E5Q403a0;00P9100@4@`01PL3
020Q700G61<0414<01@E40010P003@h900l@2`0<3@P03a0;01DF4@0F5a805AH?00h?1`0?40X030d7
0000001FEUH04a<C010@3P0C4a407b0K01lP6P0H6@d0:bX>03Lb4P1CC2T0N6m80;JZPP3`h[/0_;2:
061H=010?B<0<S0Q071bI`0P9Ah04A8=0P0@3`/0100B4@d04a8>014@300?3PX2010?2`0P00h=2@0?
3PX051<>00H8001@DT@0QhU`0?kng03ooml0WIUj02lY4`0Z91@07AXA01HC3P0D4`h04Q@>00lA300>
4`l03A8>00lA3P0?40h03Ph<00T91`061P@01@@2010<2`0a;B`0CTY901/G5P0D40l05a<B010<2`0A
3@`2010<2`804@d<01l040`;00l;2P0;2PP030/7010A300:2`H030d801@E400S91l05aPC01HG4P0?
40/020T401@E400L7AP0GEeM00l?3`092@T05QHF00/;2`0?3`l04Q8B01PH600:2PX02`/;00`<300=
3@/03Pd900`;1P0N7AP03`h:00804A0<02004a8@014?400A3a004Q0C01<A500B4Q80;Rl^018D4`06
20L01`T600<5000?4@`05QTB01<F3@0G6Q402@`302<V6`082`005AP?018E300A50/04QD<018H3P0?
5P`03aL<018J3`0H8AH04adB00`F2`0?6A802QDA018M6@8041/G00P00Pd901`W8`0?6QH07BPT00PC
3`0G8Qh051lK014H5@8051TE00X06QlK01`Q7@0G71P051TE01<H500A5Q804QLC01<H500@5A404ALC
0P0C6AD01P0E6aL05adI01HL600D6QH05Q`H01LM6@804QPD00@05adI01TO7@0H7Q`05adK0P0I7ad0
7`0F7ah041XI01@N7@0H8R<04alO01DQ8@0S;S00;S`m020^;`0M:b`07R`_01l]<00`?T40>DA:05=N
I02jaL/0[kW208>=UP18E5/0?De=03=3@P0X>3P08c<c01h^;P0R<C@0<T56041?E00Z>D007Rdd02He
?@0G9Bh00P0R<c/08`0S=3/093Hh02Dg=`0W>SP08cHd02Tk>P0J;2`0;d5302i0A00]?TH0;Ce:02Xj
B00Y>T@0:CY202Xl?`0]?cl0<TE302Dh=00X>cL0;d9002m1@00[?S`0<40m02dm>@0^?cT0;Shk02`l
>@0`@3l0:SXi03A4A00c@d<0;clo02lo@00]?Cd0<TA30080<49200@0<TA403A6B00gBD/0=DM;0`0f
Adh0400cA4`0<TE;03]@CP0fBTP0<4A20396A00cAT@0;T4o03E8AP0a@D00=DE403A4@`0`?Sh0=492
0310?@0b@Sl203=3@00m03A4@@0gAd@0>DU603=3@00b@Sl0=4A103=3@00c@Sd0;SP`02`f;P0`>S80
92hV020Y900Z<bh0;SLb02lh=@0S;2T09c0]02`e<P0l@d80=3dl024Z:@0R;Rd0:cTj02dl?`0]?D40
8S@h03Q7CP1ULW`0AU9N03<mB@0gA4d0=TE:0350A@0_?T80;C`o02Tg>P0b?T40@Te?03U4AP0^>3X0
7RPY045;C01[M7@0;3Dd028[:P0T;B`09Rl^02@]:P0W<2d0:S<`02Tb;@0V<2P0:38Z02D_:00M9bH0
;SPi0:bf]@2IXZ40>T=2024Z9`0201hT8P0:01hS7`0J7a/06QlK01dR7@0A5AH0GV9U028V:@0A5AH0
4QHG01`P7`807R8Q00/07R<O01lT7P0O91h07R<M01`N6`0K7AX07b4N024S800O8Ah0828O01PJ5`02
01TK600601PJ5`0L7Q/0828O01`N7@0J71/05aTH0P0F61L07P0G6AP06A/J02LY:00^<2l07AlN00d?
3P0Q8b807alQ01PH6P0G5aT05QHH01@D5P0H61X09RHX01`L7P0?3a406ATK01hN800>3a403a<B014G
5P0=4QD04aPL01TL8P0J7B@04aHM01LG7P0G61d05ADH01@D50805ADE0180410@00T92@0I6AT05aLG
01hN7P0;2`/051@D00l?3`0>3Ph0820P01LG5`0>30d0518C01LE5P0A3a005aDF014?400D4Q<2014?
400801<A4P0A3a0040h?00h<3`0B41<06ALJ01HD5`0A3a8201DC5P0H01<A50091`X03`d@018@4`0@
3Q402`T<01<A500H5QT0NWQk0:2NX@0B41<03P`?00d;3P0>30l04Q0C01DC5P0U8R@06aLH00l;300@
30d04`l@01DA4P0>2P/03@T:0`0>2P/00`0@30d04@`=00l92`0400l92`0300h82P0=1`T03@L900D0
3@L900L03PP:010:300@2P`03PP:010:300=1`T050h@008091hP00<04P`>00l4200:00<00P0?10P0
2P0C20`0304500d21P0>0`L04@L:01872`0<0@D050T=00/0100<0@D201462P0A00d21P0@1@T07Q<G
01462P0<0PD040D900X00`0800404@H:00h31`0;0P@05``@01@93@0A1PX05@X>00L0000d:Bd00P07
00000`0@1@T03`@800l4200200h31`803@861P0?10PDooooo`006oooool03P0:30L03Q0;00`>2@0<
3PT0418=00d?2P0<3PT04A<>018D3`0?4@`03Q0;00lA300=3PT03a0;0P0@4@`06`0?40/03@h901@E
400@4@`06a`G00X;1`0<3@P04a@?00`=200?40/03@h900h?2P0=3PT06Q/F00`=200N7aX06a`G018C
3P0@4@`020T4014A3`0?3`d03Ph<00l?3@0B4Q004a<A010@3P0300h>300>00l?3@0@40h03@h9010A
300A4Pd02``701DG4P0U9b804A<>00L<1P0O91h051TC01XQ6P0=4@`200l?3@803Ph<00<03@d;00h>
300>3P`01@0>3P`300l?3@0600h>300=3@/03Ph<018B400A4@l03Ph<0P0@40h05@0<3@`020X900P:
2@0A4a80Bde<01PJ6@0;3@`02@X902<U900c=C@071hM01TK6P0=3`d03@l<00h@3@0=3``061TG06AV
H`0?4@h030h;00/=2P0200d?300500h@3@0=3@d02PX:00/;2`0@41000P0B4Q80100820P02`/;010@
400>3Ph200`<30803`l=00D03Ph<00d=2`0<30X030`:00d=2`0200`<2P804A4?00<03`l=018B400?
3`d00P0<30X03P0>3P`04Q8@00X:200?3`d03Ph<010@3P0B4Q003`l=00h?2P0<3@P02``700d>2@0>
3`X03@h90P0<3@P200d>2@<03Pl:00/04A8=00d>2@0<3@P0414<00h?2P0?40/04A8=018C3P0@4@`0
30d800/<1`0200d>200700`=1`0=3PP03a0:00l@2P0>3`T02P/500d>200201<D3P0>010A2`092P@0
2@X400`=1`0?40X03@h800/<1P0G6180824K01<D3P0;30H03a0:00`?200>4P/200X?200Z00lD3@0?
4P/03A0900lB2`0<3@L020T300h?2@0<2`H04a8=00l@30092PD020T600h?2P0D5A003@h900`=2009
2PD02``700d>2@0>3`X05aPC00`=200?40/0414<00l@2`061`804A8=00d>2@0R8ah03a0<00/<200B
4`h04a@?00<40@0720<0414<00d>2@0@4@`02P/700d>2@0:2`H02``70P0>3`X06`0A4P/03a0800T:
100?40X04A8=010@3`0H61H051@B014B3P0O81/09BHP01`M4`0T8Pd0;BX@03Db5011?1`0FE8`075Y
A`1SFc/0>cDH034_6@0M7Q404QH>018H4P0B4`h04Q4=014@300201<B3P03018A3@0@3`/04A0<0080
4a8>010051<?01PG4@0W:QT0=CTQ08B7IP3gn=<0ko3807UhD`0`;1<09B4>01PE2P0G5@`05aL=01HH
3P0=3`X030l<0P0?4@h02`0<3@X030`:00l?3@0B4Q004a8@014@3P0B40h05a<B01dI600?2`X05A4@
00804@d<00<040`;01PD4`0E4A000P0A3@`0500D40l05A@B01DE4@0=3PT030d801PI500:2`L061TD
01hO6P0:2`L0414<00/<1`0F5a805QHC01TI600?3`l04A4A00h>3P0;2`/030`<0P0>3Ph02`0M7Ad0
51@D01TI6@1;BdT06APD00T8100C4Ph04A0<00`;2@0F5A<051<A00@04a4B01X04Q8A01@F500`<Rl0
7R0M01<E4P0?4@`051HA03e0>@0I71D00`H001TL4`0@4`X04A@;01PK500D5a004A@=010C300@5@h0
3Q@=020W7`0B6A40O8Al09fWWP0h@ST05R0I014J5`8041TF00@0624N014J5`0E7Q/04a`I0P0@6AH0
1P0B6aP03AHC01<K5`0C61@04QLC01<H50@05a`H00P061dI01hS7`0N8al061dI01LM6@0H7QX051XF
01<I5@805A/G00<051XF01DK5`0I7a/00P0H7QX01`0I7a/05adK01HL6P0F71X05b0M01TR7`0H8R40
0P0I8b801@0G8b<06BDU01`X:00G8R@072X[00807bd^02X09C<f02Le>00oCE00Gfab09RUZ`3^nO`0
joSl0>;^lP28UY`0A5=F03U9B@0Y>CT08S4d020_<P0Q<3<07bhc02dl@@0P;c@08C0g03A3BP0`@4P0
8c@n02Hg@P0V=d009SLo02Pj?P0V>3T0:S`m02Dh=`0Z?C`0;T1002Dg>00^?dD0:CY302loB`0/?DH0
:3U102/m@00^@400;d5002Dh=P0X>cT202i0@00C02do?`0a@D00;Cdl02lo?@0_?ch0;3`k02lo@00_
?T00<d=502hm@@0]?400<T5503=2AP0bA4D0<dE50394A00fB4X0>Ta>03U;C@0203E7B`0E03I8C00g
B4l0=dQ?03I9C@0iCT`0?U9@03Y>C00eBDL0=DQ603A7A@0gBTP0=dM603U9B019FEP0<T1003E3@`0d
A440=DE203A4@@0fAT<0=dM40080=DE20P0a@Ch00`0dA440;cll02dl=`0202`f;P0R034k<`0W<BT0
7bPS02D^:@0Y<Rd0;CHc02L`;@0J8b006b@Q02H^;00S;2/082PZ02D`<@0/>S/0;Se003A4B00Z?400
?4]B04mMI@0gA4d0=Cm;03=0B00Z>Ch09SDh04]JG@1NKG00?de>02hj?00Z=CL0<clo02/f=P0S;Bh0
<cdn030j>`808R`]02X09Bl_02<];00T;Rd09S4]02Td<00X<bd09C0Z02Lb;00S;RT0:S@c03Q2@`2S
[:`0S9FD02lh=`0T;BX07bDS01hT8P0M8Qh06QlK01/P700O91l0:2`]05QLGP0a=CH08BDV01dQ8P0Q
9B@07R8Q01lS8P0P9B407R<O01`Q7@0K81/092HS01dO700O8Ah09BLT020R7`0N81d06A/H01`N6`0K
7AX301TK600=01dO7P0L7Qd06A/J01TK6P0J71/071hM01DG5P0I6aX092HU01TK6P0O8B0051HE01XJ
700201LG6@0301HF600D51H06QXL00805QHH02<07AdO01HF600E5AL04a@F018E500C5aL03a8D01XL
8@0J6R405aLO01<C6`0G5A`05Q@J01LE600G5AH05Q@E034a<@0V9RH03`l?01LG5`0H61P051@D02`/
;00G5aL03`l?010@400I6AT03`l?014?400B41405Q@E00l=3P0C4A8040h?01@B4`02018@4@0>01<A
4P0B414040h?014?4P0?3A004@lB018@4`0?3A0040hA018@4`0:20/030X=01DC5P0:20/2010>4@0A
014?4P0H5QT0BTQ;069PH`0D4QD03`d@00h<3`0=2`h03P`?00l=400C418030P900h:2`0?2``03@T:
018>3`0=2@X00P0?2``01@0<20T02PH700`82@0@2`d040X<00@03`T;00<03PP:00d72@0=1`T00`0=
1`T0<@0?2@/03PP:00d72@0?2@/040X<00d72@0C3@l03`T;014;3@0L5QP06aDG00`6200=10H02`84
01P=4@0@1@T05``@01062@0D2@d040D901462P0F2`l03@8601462P0;0@@0304501872`0@1@T03045
01052@0;0@@04PL;01052@0B1`/07A8F01@:3@09008060dA01D:3P0;0@@03`@801<8300?1PP04@L:
040e>@0J41<04`T<00d41P0@1@T00P0?10P300h31`H03`@85?ooool001_ooooo00h02@/600d?2P0;
3@P030h9010B3@0=3`X030h900d?2P0?4@`04A<>010B3@0=3`X03a0;00h?2P803@h900T03Pl:00l@
2`0;30L00`@000T:1@0=3PT05AHA00l@2`0>3`X00P0@4@`02P0G61<03a0;014B3@0O81/0XJ:M092A
S00O81/05aPC01<D3`0>3P`200l?3@<0410>01<03`l=00d=2`0<30X03@d;00h>300?3`d03Pl:00/<
1`0=3PT02``701LI500[;BP04A<>00/@2P0D6A<0<CH`071gL00H6aL03@d;00<03Ph<0P0?3`d600h>
30<03`l=00<03Ph<00d=2`0=3@/00P0@40h04P0>3P`04A4?014A3`0Q8R00;Bl^01XL6`051PD02`d<
00P:2@072@P06A/J00P:2@0=3`h04A<B0001000B518030h;01<E4P801`T600@0=SPe00`>2`0<3P/0
3@l<0P0@4Pl01P092`P03`l?014A4@0@41002`/;00X:2P<02`/;00@03Ph>014A4@0A4A403Ph>0P0@
40h0200?3`d03@d;00`<2P0<30X02PX800`<2P0?3`d03Ph<0P0=3@/200/;2@0501lO7@092@L020P6
018B400>3P`00P0?3`d02@0:2PP03Ph<00L71@0;30L03a0;00h?2P0;30L03@h9018C3P0200`=2080
3@h90P0>3`X02@0@4@`04Q<>00`=200<3@P03a0;00`=200=3PT0414<00l@2`0200`=200300d>2@0>
3`T03Pl9008030d70P0=3PP09P0:2`D06AXD01TJ500@4@/03a0:01@E3`0>3`T030d700d>200?40X0
30d700X;1@061`402@X400X;1@0<3@L0414;010C300:3PL03A8;00/@2@0>4@X01@P101<F3`0<3@L0
30/600/:1@0B4@`03Pd801@C3P0;30L06Q/F00D60@0A4Pd00040014B3@0?40/04A8=0P0@4@`0100E
5Q4071dH00h?2P0@4@`200`=200>00<4000>3`X07AhI04Y;AP0D5A00004000T:1@0J6aH03Pl:00l@
2`0C50l04A8=01<D3`0<3@P3010A300M00h?2P0?40/030d700/<1P0H6A@05aPC024R7@0:2`H061TD
014B3@0=3PT04A8=01DF400I6Q804A8201DG0P0J6@D0;R`C03`h6`13?R40@ShS03@b6`0D50L04aH;
010E3P0A5a<04Q<>014@300@3`/00P0A40`0100>3@T040l;01<B3P0H5a<201TH500?01/J500M7P`0
:B/C034e501PHS/0Q8IN03Xk6@0S8@X071X;01@B200;2`<020P001@D2`0>40/030d;00804Q8@0100
2`/900d=2`0J6QP04Q8@00T91`071`D02@T700X91`0@3`d04A0>020O7@0E51803@`:010?3@0?3P`0
3@`:0P0:2@L06`0=30X040l=00X:200G5aD03Ph<0082000J6QT0YZJT08N7Q@0_;bd061PF00T91`0>
3P`04Q8@01LG5@092@L010@200`<2P0B4Q004A4?01LG5@0410804Q8@01PH5P030`4061PF01DF4@02
00T:1@05028R800410804Q8@018B400C4a400P0B4Q02010@3P0;01HH500:30L00@<001XL5`0H6QD0
418=01@F4@0A50d041<<00/>1`0N8AX00P0D5a008@0B5@h04A@=01<F3`0B5a003A<<01hU7@0I81P0
TYZB0:jh[`0kAC`04Q`E00`E400?61<0624L00XC3P0<5A00214<01XS7P0?61<03QLB01XS7P0E7QT0
5QdI01XP700M8al06b4M01LM6@0J81`05Q`H010F4P0C6AD061hJ01TO6`0201HL600301LM6@0D6QH0
5A/G00@05Q`H01h05adI01XP700J81`061hJ01HO700D7AX05AhK01LP7@0H8Ah05R0O01/U900J9R@0
5b<S01PV9P0N;2`05bDV01<Q8P0K:BX0528S02@b=@0`?T40D5iQ07Z9SP2Z^Kh0jOOi0>kmo`3?g^D0
Lh>90394AP0]?d4202@f>00:02Dg>@0P<S@07S0d02Li?@0P<SH09CLk02i0A00^?dH093A102PjAP80
9SQ203T0:Se302@g>`0Z?Sl08SHe03A8A`0Z?S`0=4Q602Xn?@0X>D00;Sm702dnAP0/?D@0;T1302Tk
?@0Z?3h0:3Xj02`n?P0]?cl0;d5103E7A`0_@D40;Clo0312@P0_@D<0:C/m02Tk?`0_@DD0<D=702ho
AP0`@DP0=TM>03=4B`0dATP0=dU;03E7B@0hBT`0>Ta>03I8BP0dATX0=DM;03I8C00hBTh0>D]?03U=
CP0cB4H0>De;03M;B@0hC4X0>Da:03E8AP0fBDL0=TI503Y:B@1=GE`0<Clo03U7A`0b@Sl00P0_?c`2
03Y:A`1D0392?`0dA440?Ti;03];B00]?CX09cLd02Xi=015CdL0<S`d02/e;@0X<RX08b`W02D^:@0W
<2/09Rl/02L`;@0]=S<09c0]02L^;@0Y<C<08RX]01lZ;00W=CH0;C`o02lo@`0[?D40>TU@02`j@P0_
?4@0@D]E030mA00a@4<0:cXm02dl?P0`@400;S`m02ll?@0T<300:CDe02Xe=@0^>3L0<C/j02La<@0Q
:b`09Bl`02Tc=00T;Rl092h]02H`;`0X<bl09c8^02<^:00U<2X08B`W00hH5`0J92D0=d5003M0?`0S
;2/082TV01lU8`0N92807B8N01/P700L8Ad08RLR04E9B00T:2T07B4Q01/O7P0M8B008bLV01`P7`0N
8R407b<R01`P7`0K81`07R<O01hP7@0I6aP071hK01dO700L7Q/0<38_0P0N81d01P0K7AX06A/H01/M
6P0N81d07AlN01`N7@806Q`K01T071hM01hP7`0J71/061XI01`N7@0N81l061XI01HH5`0E5AL05QHH
01XJ700H61X05aLI01dM7`22PX@0;Bd_01<C5@0B4Q@071`N01hN800B51<051DF01TI6`0D4aP040lD
00805a@K01H05a<J01<>500J5AT07ATJ01DD4P0D51@00P8201`L700?3`l03@d=028R8P0W9bL06QXJ
01/K6`0H61P04Q8B020P800B41403@/<01<A4P0B41405Q@E0P0C4A82014?400=018@4@0A3a003`d>
00/9300=2`h03`d@018@4`0C4A@04Q0C01PF6@0A3a8030X=00X82`02014?4P0701LE600:20/02`X<
02LU:00@3Q402`T<00d;3P0200`:3@802`T<00d030T;00X61`0@30d03`/<00h:2`0C3a003@T:00h:
2`0?2``030P900/7200@30d04`h?008040X<00<03`T;00h82P0>20X01P0?2@/02@0C3@l04@/=00/5
1`0=1`T03`T;00`6200?2@/03PP:00`6200300X41P0;01X?4`0D2@d08AHJ00T00P0C20`05@`>0187
2`0;00@03P@701P=4@0=0PH00P0>0`L04@0A1PX03`@800`11@0=0PH03P<700L0000<0@D0308500`1
1@0B1`/03`@800h31`0700003`H800l4200C20`0200100804`P<00@02`0400L0000C20`04`P<0P0@
1@T200l420803P<71P0?10PDooooo`006oooool02@0<3PT0418=00h@2`0?4@`051HA014C3P0=3`X0
2`d800h@2`0201<E400300h@2`0@4@`03Pl:008030d800<03Pl:010A300B4`h00P0B4`h04@0=3PT0
4Q<>00P9100F5a8051D@00`=200?40/03Pl:01LH4`0[;2L0kNkY0=;CcP0N7aX03@h900l@2`0=3@/0
3Ph<00803`l=0P0>3P`0100?3`d03@d;00`<2P0=3@/200l?3@0<00l@2`0<3@P04Q<>00X;1P0620<0
3a4<010B3@083@L041D?00lC3`1CFU<03A4<0P0=3@/0100>3P`03`l=00l?3@0?3`d600h>30<03`l=
03403Ph<00d=2`0<30X03`l=010@3P0>3P`04A4?018B400D5A@03a4@00<5100D5QD0418A01DG5P0B
51<02`d<00lA400;3@`0418A01LI600A4a403@l<014C40092`P03a4>01<E4P0?4@h03Q0=00/=2P0>
40d04Q@A010B3`0820P03`l?018B4P092@T01PH600/;2`0A4A403Ph>00`<300?3`l0410@00d=3@0A
4@l0410>00l?3@0>3P`03@d;008030`:00T03`l=01<C4@0?3`d03@d;00h>300<30X05ADC03lo?@0M
7A/00P0=3@/01`0?3`d0410>018B400;2`T04Q8@00X:200:2`H00P0A4Pd00`0<3@P03@h901HG4P02
00`=20803@h90P0>3`X030082@@02``700P910092PD03Pl:00`=200:2`H03@h900`=200:2`H02``7
010A30803a0:00/03@h800`=1`0<3@L030d7018C3@0];RP0:R/U014B300=3PP05QLA00l@2P0200/<
1P803@h802P030d701<D3P0:2`D03Pl9014B300:2`D02@X400T=1P0@5@h000D000hA300B5@h030l8
00h?2@0=30L02`X500l>2@071P4030/601HG4P000@007b0K00L81@0H6A@02@X500`=200?40/02``7
00T:1@0?40/04Q<>00l@2`0J6aH030d8018C3P0=3PT051D@00X;1P0[;2L03Pl:0P0?40/01P061`80
5AHA010A300=3PT05AHA00d>2@8030d803403a0;00h?2P0;30L03@h901<D3P0E5Q00824L00@50007
20<051D@014B3@0E5Q405aPC01HG4P0>3`X04a@=018D1`0L7`h06QX801/J1@0L6P<0:RPA02TW4P0f
=B405QL900@7000G71H0318>01PH5P0G5Q805A@@01HE4@0E51004Q4=00d<200A40`061LC01XI5@0I
61@06ATC01<D100a<ad06A`602//2P0T9@<08R@8018A000C4@D05a<>008040l;00H0:bXU010A300>
3P`051@B01<C4@0<30X200h>30802@T700T03@d;010@3P0?3P`03`h<01/J600^;B/06aXH00/:200A
40h01@0>3@/07`0?3P`071`J00D50`092@L06ATG00/;2@1EEE<0H61N00`<2P0A4@l03Ph<018B400A
4@l0410>01lO7@0Y:BL04Q8@00T91`0A4@l02@T701XJ600=3@/04a<A0041000A4@l03a0;01DF4@0G
61<0?Shl00`<2P0D51800`0@40h0100?3`d03@d;00d>2@0:30L201HH4`0Z01DG4P0:30L04Q@?00d?
2P0I71D04A@=01`O600=40T0:bhW010C300A50d04QD>01@G400D6A805A/C01hU7@0;4PX0;CD]03Do
=P0D7QD08b`V01PQ700=5Q403aPC018K5P0K91l03aPC01dV8@0>5a807RLR01PQ700>5a8051/G01XP
700V;2P092XV01HL600?5A403A<?00lE4@0A5a<051XF0`0F71P201@J5P0_01LM6@0I7a/05adI01PN
6P0G7AT05A/G01PN6P0I7a/05Q`H01PQ7P0F7a`05AhK01LP7@0F8Ad051hM01@P7P0E8Al04AdM014O
7`0I9bL062HW01<Q8P0V=3D082h_024_<P0U<cH0BUUL05ASJ01YN7d0a]GJ0>[io`2GZ:l0AEIM02i0
A00X>S`07S0b020b=00V>3X09cTk01`^<P0R=3P07c4e02@f>P0S=CT08C8i020b?P0W>DH00P0T=T80
400X>T<08SDk02i1A@0O<c@0:cln020d<P13Ee@0;D4o02do@`0_@4P0;Sm603=5B@0dATT09SPj02Tk
?@0Z?3h202i0@0040312@P0iBd/0;T1002i0@@80<dE700/0;T1302i0A00_@DD0<4970352B@0eATd0
>DYB0393BP0fB4/0>Ta>03M9B`0203U;C@0303=5A`0iBdl0=dU=0080=TQ<06L0=dU=03I:B`0gC4X0
=4Q60396A00gBdT0=dY80313@@0hBdT0;cln0351@010D4l0<3hn041>CP0fAT<0<D4n0392?`11DDh0
@e=@03Q8A@0gAd@0=DE20392?`0/?3T0:CTf02Xi=00a>c<0<cde02Pb:P0L9Qh07RLR02H_:P0W<2/0
8b`Y02H_;014CDX0?DI3024X:@0M9BL082P[02Td=P0a?d00;3/n02Ph?00^@4@0;ci503Q6CP0b?dL0
9Bli02Tf?@0^?D00:3Lj02hm?`0c@d<0;S`m030m?@0d@400;CTi02/f=@0T;Rd07BLV02Tc<`0O:BX0
8B//02Pb<`0V<34092h]02D_;P0X<S409S4]028]:@0T;bT082/V01dW9P0R;2d07bTX028[:P0J8b80
7RLT01lU8`0N92807B8N01/P700M8Qh092TT01XN7@0Q9B@06alN02``;`0Y;B`05QXI01dQ800O8b80
8BDT01hR8@0O8b8092PV02@V8`0P8Ql07R0M01@F4`0A4a00<C<`008071hK00/06A/H01XL6@0Q8b00
:B/X01`N7@0K7A`06A/J01XL6`0L7Qd07R0O01/M700201TK6P0^010B4@0H6QT03Q0?01@D5P0G5aT0
71`N01/K7@0I6A/07alQ055AD`0I6A/09BDW024Q8`0F5QP04A4A01PJ6@0M7Qd05aLI018A5P0N7280
3``C01/H7`0I5A/050lE01hI700Q7A`061LE01@C500I6AT05QHF01DE5@0X:2P04Q8B01PH600F5QH0
4Q8B01@D500m?Cd0OGem028P8@0D4Q<05aDF014?400@3Pl02`T:01<A4P8040h?01404Q0A010>3`0?
3@h03`d@01<A500B41<040hA00d;3P0:20/03P`?014?4P0?3A00518E01PF6@0@3Q400@0201<A5002
010>4@0?00H41`0B41<03@/>00d;3P0>30l03@/>00`:3@0?30h030P900h:2`0<20T03@T:018>3`0:
1PL030P9008040`=00<04`l@01XF5`0I51D00P0@2P`0100?2@/03PP:00h82P0@2P`5014;3@0T01D?
4@0B30h02P@600/51`0>20X030H800T31@0>20X04`d?010:300<1PP02`D700X00`0700006@hB00L0
000I3Q80:QlS01H;3`0>0`L04`P<01lD600D2@d04`P<00l4200C20`03`@800`11@0C20`04PL;01<8
300@1@T04@H:00h31`0;00@03`@80P0<0@D02P0C20`03@8601`B5@08004040D900/1100@1@T060dA
00/1100B1`/201052@803`@80P0>0`L600l421Cooooo000Kooooo`0<010B3@0C5A004aD@04U;AP1Y
JfH05ALB01@F4@0?4@`04A<>010B3@0<3PT0418=0P0C50l0@00B4`h04A8=00h?2P0<3@P03@h901@E
40092PD04Q<>01LH4`0=3PT06Q/F00l@2`0>3`X04Q<>014B3@0=3PT03Pl:038c;P0j>cH030d801TJ
5@0720D03Ph<00P81P0H61H04A4?00/;2@0<30X06ATG01PH5P0820H04Q8@00@40P0>3P`0414<00d>
2@0<3@P03@h900lA300@4Pd02`d800lD3P0;40X02Pl900XA2P0:3@T03`l=00/;2@0I6AL04a<A00L7
1@0B4Q003`l=00h>300@40h04Q8@014A3`0<30X04A4?00T91`0@40h02`/901HF500;2`T200`<2P05
00l?3@0<30X030`:00l@3P0?4A000P0A4a80300>40l03@l>00`>3@0C5A@02@/:014C4P0=3`h0418A
00d?3@041@<0418?00P:1`803@l<00d03a4>00/=2P0?4@h03Q0=00T;200I6aP0=cLg00T92@0>3Ph0
2@T9010@400=3@d02`/;00803@d=0P0<30`04`0?3`l03`l=00h>300>3P`03@d;00h>300?3`d02`/9
00h>300@40h03Ph<00d=2`0A4@l0410>00/;2@0J6QP051@B00l?3@0=3@/00P0>3P`03@0G5aD0EEEC
01XJ600?3`d03a0;018C3P0720@00`@100d>2P0B4`h0414<00h?2P0=3PT00P0>3`X200/<1`0800`=
200=3PT03Pl:00h?2P0=3PT02``700h?2P0?40/200h?2P0900l@2`0<3@T05AHA00d>2@0<3@P04Q<>
00D60`0=3PT03Pl:00@03a0;00<02``600`=1`0=3PP00P0>3`T02@0=3PP03Pl900/<1P0>3`T03a0:
00`=1`0@4@/08bHO00lB2`0200/>1`0;00/<1P0=3PP030/6018A300=30L03P/6014>2@0=30L03a0<
00`=200A4Pd00P0=3PT200l@2`0;00h?2P0=3PT03@h900`=200:2`H0DU=>04M8@`0?40`03Pl:01DF
4@0@4@`01P0=3PT200h?2P0401<D3`0N7aX061TD00l@2`804A8=01h03a0;00d>2@0?40/04Q<>00l@
2`0>3`X04A8=014B300D5@l05QLA01<D3P0@4@`03a0;00h?2P0@4@`04QD=018E2P0D5PT05aP801XJ
200N7P`07Qh=01/L3@0F60/04A@=00lD3P0?51005aLD00d<200C4Ph6018A3@0f01<B3P0D4`l051<?
01PH400F5`X06Q/801`O1`0I70@06Qd;00h>1@0>3@X04Q0C014?4`0A3a407ahL010?3@0;2`T04Q8@
01HF500?3`d030`:010@3P0;2`T03Ph=01<C4@0=3P`02P/900l?3@0A40h0>STg00h=2`0?3P`04A0>
00d<2P0>3@/02`X8010?3@0>3@/04a8@00d=2`0?3`d03Ph<00T91`0<30/030`:024Q7`0A4@l07QhL
020P7P0A4@l05ADC00h>300N7Q`07alM0P0=3@/01@0E5A<04a<A014A3`0@40h03`l=0080410>00d0
51@B010@3P0F5Q@06QXH01<C4@0@40h05ADC01hN700E5A<04A8=01@E400D5@l04A<=00804QD>00<0
4A@=00lA300>40/00P0B50l04@0@4Pd03a4<01<E400G6A@051HA01LI500D5Q406adH018G4@0C6A80
4QTB010G400C71@051hF014K4`0A6A<04QPD00804ALC018051XF01HL600F71P05A/G01LM6@0E6aL0
4QPD01<I5@0C6QH03QLB01/T7`0]=S404a`G00/D3`0F7aX04a`G01@M600G81/201@M600401@L5`0D
6QH05adI01PN6P<05Q`H00P05adI01TO6`0I7a/061hJ01HL600D7AX05AhK01DP70805R4M01T05R4O
01<O7@0D81h05R@T01PV9P0I9bL072X[024/;P0N:B/092la020^<@0Z>3/0:3Lj03=4B00hBTh0G6mc
06AfO01DIfd0>4]A02Hi?@0Q<cL07c4e028d>00Q<cL08S@h00807Bla0P0T=SP08P0Q<cD0:ce202@f
@@0W>DH09cU502HhA00V>480:3]102Lj@@0Y?4009c/k02Di>00V>cP0:Shl02Xl?P0Y>d00;T1402m1
A@0/?T80;d550353A`0a@dH0=DM903=5AP0`@T80=dU903mAD`1:G5h0<D=503A6BP0bA4P0;3i202ho
AP0Z>d<303Q9D@0L05=TJ`22U9T0=DM;03=5B@0eAd/0?U1D03U;C`0eAdT0>4Y<03U;C@0hBT`0=DM9
03=7A`0dBDL0<dM503U=B`0fBTP0@eID03=6A00gBTP0@U9A04ADD`0jBTT0>dU903E3@`0gAd@0=DE2
03I6@`80>DU604D0>4Q503];B00iBDH0>d]803=3@00[>cP0;chi02hi<00/=Rh09BlW024[8`0T;BP0
9RlZ02Xc;P0]=S<08b`Y02Tb;`0N9b@0;C@e02<[;P0K8RP09c8f02lm@00]?3l0=DI902/m@@0`?d@0
;3Y002dj@00/=Sl0;S]002dm?@0a@D40;clo02`l?00fA4@0:cPh02@`;`0W<c40:SDc02Pb<@0Z=C40
92l^024/;P0X<cD0Ef=T02/g=`0T<3009C4_020/:P0R;R`08bl[024]:@0K9b<08B/[028/;@0U;bh0
7bPW01dV9@0`>CH0:c4_01hT8P0L8Ad06AhJ01dR7P0P9Al07R<O020T8P0R9RD00P0P92<02`0R9RD0
CU9A04U=C00S9bH07b<R01dQ800R9RH08R@R024S800M7a`06Q`I00@06A/H01007AlL01/M6P0K7AX0
9bTV01/M700H6QT05aTH01TK6P0K7A`061XI01HH5`0H6QT06A/J01PJ6@0F61L051HE0P0C4aD01P0E
5AL06QXL020P8P0H61X06ATK01PH6P805aLI028061PJ01TI6@0E5aD061XH01XJ6`0I61`05A@J018?
5P0D4AP061@J01D@5@0F4Q<061@C01@C4@0C4Q<0410@014A4@0F5QH05ADE01<C4`0E5AD05QHF010@
400C4a<09BDU08R8R00P7Ql020H700h<3@0B41403`d>01@B4`0A3a004Q0A100A3a00100A3a8040hA
010>4@0@3Q4200l=400300d;3P0A3a804@lB00803`d@01003@/>018@4`0@3Q4040hA014?4P0<2Pd0
3`d@010>4@0>30l02PP;00h<3`0?3A0030T;00l;300>2P/02`L80P0A3@h05@0>2P/04@d>010<3@0=
2@X03PX;00l;300?2P/03`T;014;3@0F418040X<00`6200A2`d05@lA01@>400@2P`03@L9010:300A
2`d03`T;00h82P0200d72@0700h82P0?2@/03PP:00h82P0=1`T03PP:00l92`0201052@0:01H;3`0>
1@L04@H:01462P0G3Q00=b``01062@0E2Ph0304501462PH040D91P0?10P01P0A1PX03`@800l4200A
1PX04`P<01462PH03P<700<03`@801462P0A1PX00P0?10P01`0A1PX02@0201`A5@0C20`02P0300l4
200;0@@05?ooool001_ooooo00P010H1014C3P0:30L05ALB02HX8`0620<04A<>00h@2`803a4<00D0
3@l:010B3@0D5A004a@?014B3@0200l@2`0700h?2P0E5Q403@h900`=200=3PT0414<00l@2`0300h?
2P<03a0;02P04Q<>00d>2@0A4Pd04A8=01TJ5@0?40/03@d;00`<2P092@L01`L6028R80092@L04a<A
014A3`061P@04a<A00T91`0=3@/02P/600/<1`0=3PT0414<014C3P0B50l02`d800P=1`0730H02a0:
00`C300>4@d05ADC00d=2`0_;bd0<c<a00h>300=3@/0410>00h>300@40h04A4?0P0@40h03P0G5aD0
5ADC00/;2@0<30X02@T701hN700>3P`02`/9010@3P0?3`d03@d;00h?3@0>40l03@l>0`0<3Pd01006
20L02@/:018D4`0<3Pd200L9200@03m1?`0K7AX03@l<01LI5P0E5a@04A<@00d?30092`P03a4>01<E
4P0=3``0418?01HF5P071`L04Q8B00T92@803Ph>00<030`<00d=3@0>3Ph00P0<30`07P0?3`l03`l=
00h>300>3P`03@d;00h>300?3`d02PX800/;2@0<30X03@d;014A3`0J6QP0410>00H6100;2`T02PX8
00h>300;2`T061PF00L71@030`40;bl]01LG5@0:2PP02``702l`:`0N7aX02``7010A30803a0;00H0
3@h900`=200=3PT03@h900/<1`0<3@P2010A300A00d>2@0<3@P03Pl:00/<1`0A4Pd051D@018C3P0<
3@P020T400@40P0Z:RP02`/901<C4@0=3@/06a/I00X:200;2`T00`0<30X05@0;30L02``600X;1@0:
2`D02``600`=1`0=3PP030d700H70@0Q8Q`01`P300P90`0?40X04aH?00T:100;30H03a0:01@C3P0G
5Q403Pd8018?2P0200h;1P09014>2@0>3@P020P500`=20020`003a0;018C3P0A4Pd030d800<03@h9
00P03Pl:010A300H6A@03a0;01HG4P0:2`H030d800X;1PD03@h90P0C50l0100?40/030d800P9100;
30L2010A30804A8=02803a0;014B3@0B4Pl0410>014B3@0B4`d02P/500T:100;30@03Pl7014B300C
50l04Q<>00l@300=3`X03A09010A2P0C5@X05AL:01PJ3@0E5`T061X=01PJ3P0C50h03a4<010B3`0F
5a8040l;01HE4@0@3`/03@`8010?2`0B4@d04A0<0P0@3`/08P0A40`04a8>01hJ6@0I5A805AD;018D
1P0@4P@04aD:01<E4P0B4aL040lF010=500B41D03`/;01LC4P0A40h0;bh/03<b<00H61H05ADC01PH
5P0K71T03Q0=024S800?4@h02@/800/;2@0D51800000014A3`0?3`d05ADC00d=2`0?3`d200h>300B
00d=2`0<30X02`/;00X:2P0D51@08b<S018B4P0F5QH0410@00l?3`0G5aL06QXJ01<C4`0<30X04A4?
00P910061`804Q<>0P0H6A@05@0@4@`03a0;00l@2`0@4@`04A8=018B400J71X08B<R01<E500=3`h0
4A<@00`>2`0C5A805aTD00/=200<3PT04aH?00lB2`0@4`/04A@;018E300301<F3`03018D3`0@4Pl0
418?00<04aDB00H06Q`I01PJ5`0:30T02@/802/`;00@5Q8201<I5@0:00lF4P0=5Q404AXE018J500A
5Q004QLA01@I4`0F6aD061dG01HK5@804aPB00@05AXD01PM5`0G71H05QhH0P0;50l01`0I8Qd07RLR
02lh<`0/=C003QLB010I500E7QT00P0C71L0100F7QT061hJ01TO6`0H7QX201HL60805adI020061hJ
01LM6@0F71P05A/G01TR7`0G8Qh05R4M01DQ7@0F8Qh06BDS01PW900D8b004R0P01DU900G9bH05bHV
01hY:`0^>C/08Rd_01DS9P0U<cH08C0c02@f>P0V>3`0>4]?03U<DP0dBDh07S<h020c>@0L;cD07C0f
024d>0807S4e0P0S=cP0A00V>S/093Pg02@h=`0]@4@08C@k02Di@`0V>TD09CU402@h@`0U>D80:Ce6
02Hj@00T>C`09S`j02Y0?@0/@3h0:C/k02Li>`0]?d40<TA802m0AP0/?D@0<T=:0353A`0cADL0<D=5
02i0@@0bA4@0Jgn007fATP0]@D80C61Q02i1A00/?d<0<4=702m2A`0_@TP0;T5703M:D@1:GF@0E6E/
02Pi@00cA4/0?4iB0394B00T=SX0>4Y<03U;C@0jC4h0>4Y:03E7A`0cAdH0=DY7049FE00W>cT0>4a:
02m2@00bAD<0=TU704]KFP1>GUd0>d]:03M5A@0b@400>4Q503I6@`0gAd@0>TY70`0kBdP0=00fAT<0
=DE20351?P0]?CX0<3lj02Td:`0S;BD07RPP024[8`0X<B`0<S/f02/d;`0/=C809Rl/02Pa;P0h@Ch0
E5]L024X;P0O9R`0<Ca002Le>00^?D00<T=603E7B`1IJ6d0;3Y003=0AP0d?dD09S@h02hn?P0c@d<0
;Cdl02@d<`0H9RH0934`02@`;P0Q;B/072PT02lj=P0d?c/07bXZ02`g>`0b?Cl0>4=502Pc=@0[=cL0
8bl_02Te=@0P;2X0:SHd024]:`0K9b<202D_<00<02<];00L9B@06R<R02Xc<00U:bT07B<Q024V8P0P
9B4092TU01lT7P0I7QP0724K0P0Q9R80100P9B408RHU02X^;@0[;bh301/O800501lS9@0Q8b80828O
01dO700J71T00P0I6aP01P0J71T06adJ01dO700I6aP05QPE01`N6`8061XI00D06Q`K01`N7@0J71/0
5ALF01PJ6@0301TK6P0:01PJ6@0F61L04A4C02PX:P0P82801`L904M7B@0b<S@04a<E01HF608061PJ
01X05QHH01<C4`0D5Q<04QLB01<E500B4aD04A8E014@5@0F5AX061HK018@4`0B4A004a8@010?3@0B
4Q80410@014A4@0D51@04a<C018B4P0>3Ph02`/;00`<300F5QH071`L000000804Q0A00<040h?00h<
3@0A3a000P0D4Q<00`0C4A804Q0A010>3`0200h<3@0401@B5@0C4A@04Q0C014?4P803`d@00X040hA
00l=400?3A0040hA00h<3`0A3a804Q0C00X82`0=2`h04a4D0P0Q7b8200d;3P0400L5200=2`h03`d@
00`92`803`/<01<03PX;010<3@0@30d040`=00/7200:1PL040`=00/7200:1PL03PT:01<=3`0L5QP0
7ALI014;3@0@2P`0618D01XD5P0H4Q@04P`>00<03PP:00D03@L900h82P0?2@/04@/=01@>4002010:
300@00l92`0>20X03`T;010:300E2Ph03`@800X10`090080200101462P0V6al0?C8f01<8300@1@T0
3@8601<830H040D91P0?10P01P0<0@D02`0400d21P0@1@T03`@800`11@H03P<700<03@8600l4200?
10P00P0=0PH01`0?10P04PL;00l4200<0@D03@8600l4200@1@T05?ooool001_ooooo00L02P`701<E
400<3PT01`T4018D3`082PD03a4<00<03Q0;00l03a4<010B3@0E5Q404Q<>00l@2`0>3`X03a0;010A
300F5a802P/700l@2`0;30L02P/600d>2@0;30L00P0@4@`200h?2P0G010A300>3`X04A8=010A300?
40/03Pl:01@E400<30X0410>018B400=3@/0;Rh/00l?3@0@40h030`:00H6100C4a4030`:00d=2`09
2PD030d800l@2`0A4Pd00P0@4Pd02`0?4@`02Pl900/@2P0@5@l03QD>00P<1`030`406a/I01XJ6007
1`D04Q8@0080410>02P03Ph<010@3P0@40h03`l=00`<2P0410803`l=014A3`0=3@/08R8P05IFE00J
6QP03@d;00/;2@0=3@/03`l=018C4@0?4A0030h=00/=300=3`h03Q0?01@F5@082PT05aTH00X<2`0Q
8b801PP704Q:B00N81d010H300h@3@0A4a002P`9014C400<3P/03a4>01DG500A4a003Q0=0P0<30`0
1`0B4Q8030`<014A4@0@410030`<00d=3@0>3Ph00P0;2`/01`0>3Ph03`l=00h>300>3P`03@d;00h>
300?3`d0100=3@/05@0?3`d051@B00h>30061P@03Ph<018B400C4a4020P6010@3P0A4@l030`:00L7
1@0820L02@T700T:1@0O81/04Q<>00@5000<3@P04Q<>00l@2`0200d>2@0400h?2P0?40/030d800d>
2@804a@?00<03Pl:00`=200A4Pd00P0B4`h02P0>3`X02``700/<1`0>3`X03@d;01TI5`0C4a403@d;
00L71@0J6QP200/;2@8030`:01P02`/900/<1`0>3`T02``600X;1@0;30H03@h800h?2@092P@03Pl9
03`m=`0A4P`020T300X;1@062@802``601<D3P0B4`d020L200D4000?3PT040d800h;1P0?30L2014>
2@0604I6@@0_<2/0004000h?2P0D5A00414<0P0<3@P02P0=3PT03Pl:00h?2P0<3@P01PL200P9100@
4@`051D@0493?P0a<Rd500h?2P0801XK5P0C50l01`P3014B3@0B4`h03Pl:00l@2`0@4@`2018C3P05
014B3@0B4`h0410=00P81P092@L00P0C50h05P0@4@T03Pl700h?1`0A4P`04a@?018C3P0?3`d030h;
00d?2P0@4@/04Q<;01@F2`0F60`0418501HH2`0I6a004a@<00l@2P0A4Pd05aHB00l>2P0B4@d200P7
0`804Q4=01d04A0<00l>2P0>3@T03`h:018A3P0I5AH05A4@018A2`0@4PL030l400dA2P0B51<04Q<G
00/;4`0>2a805Q@G01LC4@0C3`h02`T701TH5P0M71X03`h<00h>30061P@00`@200X<2@0?4@h02`h;
00D:1P0200X:200L00h>300M7A/02@T7010@3P0:2PP030`:00h>300;2`T03`l=00T91`0G5aL030`<
00d=3@0A4A403@d=00T92@0C4a<03@d=00@410071`L04Q8B01@D4P0:2PP04A8=01<D3`0@4@`04a@?
01PI50803Pl:00h03a0;014B3@0B4`h04a<A014C4P0M7ah05ALF00d?3P0>40d03@l<01/M6P0B50l0
3a4<018D3`803a8;0P0B5@`05`0C5Pd051L@01@G400D5a005ALB014C400C5A8061XG01LI5P0D5Q<0
4A<@01HH5@0@4Pl0;Bl/08F:QP0l@Cd04QPD01<I5@0A6A@04AXE01@M600F7AL05AXD00805Q/E0180
5AXD01@I4`0E6Q@04aPB014F400E6Q@06AhH01LL5P0G7aT04AXE00lH4`0D7AP04AXE01XS7P0M9R40
3QLB010I500D7AP2014J5@0401HM6@0H7QX06AlK01LM6@<05A/G02<051XF01HL600G7AT061hJ01PP
6`0L9B806B@P01HQ7@0C7a/0520L01LS8@0L:bP05RDR018P800F9RD06RXY01PW:00J9BL08Rd_01HQ
8`0K:B`0:CLj01LV:@0S=CT08cHj02a0@`0X?D80;DE902Q0A00N<cP06bhd01lb>00S=SX083<g01ha
=@0202Di>P0802@h>@0R=SD093Pg02/o@00O=3T093Po02LkA00V>T<202DiA00;02TmAP0U>D409S]0
02]0@@0^A480:d4n02i0@00Y>c/0<D=503M9C@0dAD/00P0_@4L03P0`@DP0<TA80394AP0cADH0=4I6
049FE@0fBT/0;41102Xn?`0[?d40<4=702Xm@@0dAd`0<dI<0`0_@TP01P0eATd0@E9I04mPI`15Ee/0
>deA03i@E0<0>Ta>01@0>4Y:03E7A`0cAdH0=DY7041DDP0Z?S`0=4Q604MJF00eB4H0<4=103Y:B@0l
C4/0<T9103U7A`0fA4@0>4Q503I6@`0gAd@0>d]803a<B@80>d]800T0=TI303E5@P0a@Ch0:c/h02Xi
=00U;bL082XR01hX800S;BD00P0Y<Rd0>P0J8ah0:34^03@m>P0c?3T0:C8_03U0@@0V;C<0;3<i02dh
?00a?d80>dY=03=4A`0cADT0<T5602hl@P0L:Bl092le02<a<`0Z>SX0;Cdm02Lg=`0V=SD0C5YJ02dj
>@0P;2X08RhZ02<_:`0/=c<0<C`h02D_<00R;C405b8T01`W:@0_>S`0;c/k01`X:019EED0=40n028^
;00S;bd082`Y01dW:00Q:b`092h]01hW9P0I8R406R<P020V900V;2X0;c@`01/P700I7QX08RLQ01/P
6P0N8ad082DQ01lT800L8Ad201`P7`0C01hR8@0L8240720Q01`P8@0N8R@0828Q01lQ7P0M7a`06adJ
01XL6@0I6aP05ALD01TK600K7AX06A/H01PJ5`0J71T06Q`K01/M700201`N7@0401XL6`0H6QT061XI
01PJ6@805aTH0P0F61L0200;2`d0410B018B500E5AL09BDW00h>400C4aD05ADG0P0F5QP03`0E5AL0
4Q@C01DJ5P0D6A@04QLC014E5P0D5AP05AHJ01HG6`0H61/04a<C01@C4P0E51004Q4=018B4P02014A
4@<04Q8B00T071`L01DE5@0820P05ADE03Hf=P0F5QH06ALH01hL7@0F51D00P0A3a000`0=2``04a4B
018@4@02014?40803`d>00@0518E018@4`0A3a8040hA0P0>30l02@0A3a803P`?00l=400A3a803P`?
00/9300>30l03`d@01@B5@0200H41`0701@B5@091`X02PP;01@B5@0@3Q402PP;00/82P0200l;300=
00`82@0=2@X03`/<00l;30091@H04@d>01dI6P0<20T01`<400d82P0@2P`05@lA01LA4`0200h82P80
4P`>00<04@/=00l92`0>20X00P0?2@/01`0>20X040X<014;3@0C3@l05Q0B010:300?2@/00`0>20X0
3@0@2P`040D900l4200A1PX0714E00l4200=0PH02@0201lD600<0`D040D901<8300A1PX0300@1@T2
00d21P0401052@0C20`04PL;00d21PH03`@800<03@8601052@0?10P00P0>0`L01`0?10P08aPL0105
2@0>0`L04PL;00h31`0?10P05?ooool001_ooooo00P02P`700X<200>40/03Q0;01XL5`0F61<03Q0;
00lA308030h900@03a4<00h@2`0B4`h04A8=0P0>3`X200l@2`0P00X;1P0=3PT0414<00l@2`0>3`X0
414<00h?2P0C50l04Q<>00d>2@0<3@P03Pl:01HG4P0C50l03@h9010A300;30L04a@?010@3P0B4Q00
8R8P018B400O7ad030`:00h>300<30X02`/9014A3`0@40h03@d;00d>2@0?40/2010A300900`>2@0;
3@P03a4<00X?2@0>4`d041D?00`C300B5A404A4?00802`/900D03@d;00h>300@40h0410>00h>3002
00l?3@0:00h>300?3`d04A4?01HF500@40h020P600`<2`0c<c4051@B00`<2P<03Ph<00@04a@B014C
4P0<3Pd03@l>0P0@4Q403`092`X04aDD00P:2@0=3`h051HE00H81`0B518020X701@F4`0:30T0418?
018D4@0C5A803Q0=00/=2P0200h@3@0800`>2`0?3`l05aLG00X:2P0@41003`l?00h>3P0=3@d200h>
3P802`/;00L03Ph>00l?3@0>3P`03Ph<00d=2`0>3P`03`l=008030`:00T03@d;00l?3@0?3`d03@d;
00h>30071`D03Ph<00d=2`0?3`d00P0;2`T0400@40h00P8101HF500=3@/05ADC01<D3`092PD03Pl:
018C3P0=3PT0414<00`=200;30L02P/600`=200=3PT200/<1`804A8=010030d800/<1`0?40/03Pl:
00l@2`0>3`X03@h900h?2P0A4Pd051@B00X:200@40h010@201@D4P092@L03@d;0`0>3P`01@0=3@/0
30d8010A300>3`T03@h800803Pl900T03a0:00`=1`0@4@/0=cPb01@E3`0;30H03@h8018C3@0<3@L0
0P0=3PP02`0?3PT051<>014>2@0?30L04@h901<>2P0A30P04@h903@d;`0W:2<01PL200803a0;0P0<
3@P200d>2@803Pl:00L04Q<>00D60`0?40/0;2dX00/<1`0E5Q40414<00D03a0;00D04A8=00`=200:
2`H04Q<>014B3@03010A300?018C3P0C50l04A8=014B3@0[;2T0;Bd/01HF500?40X03a0900`=1@0>
40D04Q<:014B300?40/03`l=0080410@01404A4@01<C400D5@l051D>01@E300>40D04aD:01TI3`0D
50`04A0:01<A300?3PX030/701LF4P0C4Ph040l;018A3@02014@300R010?2`0?3PX040l;010?300A
31003`X=014A3@0B50X0314500XA200A5QD041DG014B5P0A41404A0;014>1@0F4Ph05Q8A00l;2P0?
3P`051<A00X:200=3@/04a@A01@F4`0730P0@4E103Pm>@0B4a4030`:01TI5`092@L04Q8@00l?3@80
4Q8@014051@B00T91`0C4a401PH4018B4P0=3@d05ADE014A4@0b<S804a<C00`<300@41003Ph>00l?
3`0B4Q803@d;00h>2`02010A30803Pl:01D03a0;00h?2P0>3`X03a0;014B3@0C50l051@B00h@4009
2P`03a0B010B4@0G6AH08bDR03<e<00>40/04A<>010C300:3@H05QTA01HI3P0D5`h00P0C5Pd2018E
3P0301<E400A4a004aDB00805aTH01805QPG01LI5P0M7a`04A<@010B3`0g?3P04AHB010F4P0A5a<0
4a/F01<L5`0@6A@041LA01@I4`0F6aD061dG01HK5@0E6Q@201HK5@0501<H4P0D6A<05Q/E01HK5@0C
6aD00P0?6Q@0100B7AL041/E014L5P0F8A/201DP6P0401PS7@0C7QP04A`F01DM6@805adI00<05A/G
01<I5@0D6QH00P0F71P0D`0I7a/06R0L01XP700H7a/05R0L01@O6`0C7a/05B4M01PT800J:BH07bh[
01/Z9`0H:2L07Bd/020`;`0P;bl072LY01XT9P0K9RP06BLZ01l]<00Q<C<07C0d01P[;`0P=SP08SPm
02@l@00T?D4083@k01ha>00S=S`0:3]102@g?@0R=CT08SHg02<g>00Q=C@083@c02Hj>00V>cT08SLi
02Dj?P0W?4809SY202PlAP0Y?DP09c]602PlAP0/@4P0<4A:0315B00/@D40;d=102/m>`0`@T<0=DM:
0394BP0`@DT0:S]302/l@`0Y>cl0:C/n02/m?P0W>CT0:3`j02e1@00fBTT08cLf03E9B@0aADH0:Sho
03E8B`0gBTh0=TU=03Q;C`0dAd`0>4UA0393BP0cA4/0>T]B03Q:CP0oDED0>Ta>0080>D];05/0>4Y:
03I9A`0eBDL0=DY803M;B@0oDe40>Ti<07f@SP1;GU`0=DQ603E5A00hB4L0=dM603e;B`0fA4@0=dM4
03A4@@0eAD80>4Q503U9AP0hB4D0>DU603Q8A@0fAT<0<T8o02Lg=00O;RT082/R020Z8P0T;RH0:38Z
02Tb;@0[=2l08R/V02hg=00/=C80<CXg02Pa;P0Y<38082L_02Xa>@0_>T00;ca20391AP0`@4@0;T12
03Y9C00[>Sd0JgUl02hi?@0/>S/0:SXi02hn?@0`@3l0A5AC0:Vh]@16E5407b/Y02di=@0jAD409c8^
02Td;P0]>CP082ha02<a=00/>S`0;S`m028`<@0X=SH0?de=02`j>P0T<c0082l/01/Y9P0N:2T08B//
028/:`0Q:RT08R/Z028[:00Q9bD092XX02L/:00H7AT0724M028W8@0M8Q`07b@N024V800P9B407b@P
00808BDT00H0720O024U9P0O8bH082@W01dQ8`0N81l201hP7@0501`N6`0K7AX06Q`I01HH5@0I6aP0
0P0G6AH0200H6QL05aTF01lQ800O8B006adL01XL6`0K7A`07R0O0P0F61L401@F5@0801TI6`0F5QP0
51@F01HF600K6ad05aLI01HF600D51H2018B500A01@D5P0E5aH051XF018I4`0@5Q8041HE018G6@0D
61/041@G01<E600@4Q404Q<A01<E400A4Pd04a<C01@D500C4a<00P0B4Q802P0C4a<0:2PX020P800?
3`l0410@00d=3@0>3Ph04Q0A01DC500@3Pl201@B4`0400/92P0A3a004@l@014?40<04Q0A00@04@lB
010>4@0@3Q403`d@0P0>30l0100@3Q403`d@00l=400A3a8300h<3`0;00T72P0=2`h04@lB01hL7`0l
>Sd071XM00D31P0?3A002@L:00`:3@0E4Q@00P0?2``0300=2@X02PH700h:2`0A3@h040`=01LC500K
5aP02PH700`82@0E41403@L900/51`<03PP:00L040X<00h82P0=1`T03`T;010:300?2@/03PP:00<0
3@L901@03PP:00l92`0>20X03PP:00d72@0<1PP03@L900h82P0I3Q8040D900/2100P5AT03@8601@9
3@0<0`D05P/?00l5200=0`H05``@00h31``040D90P0>0`L0100@1@T04`P<01872`0>0`L700l42080
4@H:00T03`@801052@0A1PX08aPL01052@0>0`L04PL;00h31`0@1@T05?ooool001_ooooo00d02P`7
00lA300@4Pd03@l:014C3P0:30L03Q0;014C3P0;3@P02P`700h@2`0:30L03@h900803Pl:0P0=3PT0
2`0;30L02@X501hO6`092PD030d800h?2P0;30L03Pl:010A300?40/03Pl:00803@h900@04A8=00X;
1P082@@02``70P0=3PT0300B4Q0030`:01PH5P0?3`d03@d;00P81P0?3`d0410>018B400<30X0410>
00h>30<03a0;00D03Pl:00`>2@0;3@P03@l:00P=1`0200/@2P0900lF3`0A510020P601XJ600<30X0
0P8001HF500D5180410>00<03Ph<01X030`:00H61@0:2PP01PH400d=2`0D51805QHD00T91`0:2PP0
2`/9014A3`0=3@/030`:014B400?4A002`d<00d?3P0@4Q403a4@01/M70031@@02@/:01XL6`1lOWd0
6A/J01<E4`801@L400<00P@1018D4@0:30T00P0@4Pl200h@3@0;00lA3P0>40d07alO02TY:@0@4100
61PH00P8200:2PX03Ph>00l?3`0>3Ph00P0;2`/0200=3@d03`l=00h>300>3P`03@d;00h>300?3`d0
3@d;0P0;2`T05P0>3P`0410>00h>300=3@/02PX801HF500;2`T02PX8010@3P0C4a4030`;02PX9P08
20H0410>00H6100?40/02P/600l@2`0C50l03@h900H70P0<3@P200/<1`0500d>2@0>3`X030d800l@
2`0A4Pd00P0B4`h2014B3@0=00l@2`0@4@`03Pl:00/<1`0<3@P03Pl:00D50`0@40h08B4O04a<BP0;
2`T04a<A00h>300200l?3@0400h>300<30X030d800l@2`<03a0:00D03@h800`=1`0;30H01@H000d>
200200P90`0A00d>200?40X0414;018C3@0>3@P01`H100P70P0@3@P03P/601@A300F4@d03`X600h;
1P0=3@/03@h9018C3P0?40/00P0:2`H0300>3`X03@h900d>2@0=3PT030d800L8100E5Q405QLB00/<
1`092PD061TD00X;1PD03a0;00P030d8014B3@0G61<051D@018C3P0E5Q404Q<>00l@2`804Q<>00h0
3a0;00h?2P0G5aH04Q8B00H610092PD04Q<;01PI4@0G6@h0418700l@2P0?40`0410>018B4`80518C
02D05A@B01<D3`0A4P`03a0800lA1P0@4PL051@:01HC2P0E4PT0510;01@C3`0=30P06QTE01TH500E
51004A0<010?2`0A40`04a8>018A3@0A40`03Pd:014=3P0?2``03`l9010C200;4@D031@8038h=00J
81h02`h<00l@200<300061H7010;1`0?2PX03@T800803Pd;02D010@201<C4@092`P05QPE01XO6`08
3@T02@h:00T;20092@L00P8001PH5P0?3`d02PX8014A3`0?3`d04a<A00@40P0H61H02@T700D51@0E
5AD06a/K0000000F5QH04A4A01@D500>3Ph02@T900L71`092@T04A4?01LH4`0>3`T030d701<D3P0D
5@l04Q<=00<03a0:01<04A8<018C3@0B4`h05aXL00lC500<41402Ph=010E4@0G71P06QlI00hC300;
40T03Q<<01@J400M8aT051L<018E300A50/04QD<00804aH?01@04A<>014C400@4Pl04A<B01HH5`0I
6aX04Q@A014C400;3@X051HC01lT800D6QH04ALC01<I5@0C6QH04Q/F01<L5`0D6aD051TB01DJ4`<0
5a`E00d05Q/D01DJ4`0D6A804aPA01@I4P0G71D0620J01PS7@0I91h05R4K018M5`0<5a403APB0080
4A`F00@051lI00lJ500>6A<04a/F0P0F71P0FP0E6aL051XF01LM6@0G7AT061hJ01hT800O9B40728N
01LN6P0C7QX04alK01DQ7@0I9B406bLS01/Z9`0G9R<05RDR01DU900C9R@052LU01@U9@0G8R@051hP
02@_<@0C8B@0938e01d^<01fRHd0AEQL01/b=00F;S806c@h02Q1A@0N<ST06blf01hb>@0S>3d08CHk
020e>00O=3D08cPi028h=P0S>CH0:T0m02Hl>@0V?3X09Cdn02@l@00T>d40:3m802e3D00Y?d`0:d5<
02]2BP0Z@DL0;DE90397B00]@Cl0:Sdj02/m?@0/?T00:Sa202hoA`0_@4X0;d1702Tk?`0Z?400;Cm0
02Dg=`0M<Bl0=4]602Y0?@0^A440=de;03Q>C00gCD/0=4Y903=8B@0aATL0<4E703A7B`0iBU80>daD
0352BP0b@dX0;T1403a>DP0gBD/0=dU903I8B080=TU700H0=TY803I;B@0eBDL0;D4o0355@`1:GE/2
03E8AP0603Q8A`0kBdX0=DE403E3@`0]>c/0=4A10P0a@Ch0;P0c@d00<T8o0351?P0eAD80=4A10351
?P0b@Sl0:CTf01l^:@0S;RD092hV02Tc:`0[=Bd0:S<^02Tb;@0D7AP0:c@a03a5@P0i@Sl09c0]02<Z
;@0a>480<SU1030k@@0^>d409cHk02Lh>`0oDE<0EfIY03E3AP0oCE0082/]030n?P0/?3/0=dM603A4
@`0fATD0@E1=02@b;P0L:2@09c<_034m>00S;RP09S4[02Lb<@0M:bh202hl?`0302Hd=`0Y=cP08c4a
00805R@T00<08c8_01h]:P0K:RL00P0W<C804@0O:BP06b@S01hW9P0L9B808RPV020V900P9B406AhJ
02@Y9@0P9Al06QlH01/P6@0K81X06QlK01/P700Q9B<0<cLf00808RHW01T0720S01lS9P0G6al07AlN
01dO700N81d07AlL01/M6P0J71T05QPE01TK600D5Q<05ALD01/M6P0H6QL071hM01hP7`0L7Qd06A/J
01PJ6@0K7A`05aTH01HH5`0D5QD04aDD00805ALF00H0410B01XJ700K6ad0LW9d04Q8BP0<30h201@D
5P804a<E014051@F01<E500@5Q803AL@00dF4@0=5Q<03aHG010E600B5aX051TK00lC4P0@5A4041D?
00lA300E5AD05aLG01HF5P0201<C4`0>01DE5@0=3@d02`/;00X:2P0B4Q8051@D01`L700H5QL05A<D
018@4@0A3a003`d>00`:2`0B4143014?408040h?0P0?3A03010>4@04014?4P0>30l040hA010>4@80
3`d@02403@/>014?4P0?3A003`d@00h<3`0;2@`06ALJ018@4`0:20/03P`?00X82`071@P02`P:00l;
300E4A805a<D00d92P0<20T03`/<00d92P0;1`P02@D600P41@0;1`P03`X<00d72@0<1PP03PP:00`6
200>20X04`d?010:300?2@/00P0@2P`00`0=1`T03PP:00l92`0300h82P803`T;01403PP:00d72@0=
1`T03@L900l92`0700003P<702<H701CB4`09a`P00h41`0B1`/03`@800h41`0900807A8F01@93@06
01052@H03`@800H03@8600`11@0<0@D03P<700l4200=0PH700h31`0701462P0@1@T03P<700l4200@
1@T03`@800h31`0300d21P0301052Ooooooooooo01;ooooo000Kooooo`0K0001000?4@`04A<>00/=
200?4@`02`d800h@2`0A4`h02P`700T;1P0=3`X02@/600/<1`0=3PT03Pl:00d>2@0<3@P02@X501`M
600e=S403Pl:010A300B4`h030d800d>2@0<3@P03@h900<03Pl:01402P/601LH4`0I6QD03@h901@E
400E5Q40410>00T91`0;2`T03Ph<010@3P0>3P`0410>01<C4@0E5A<02`/900l?3@0300h?2P0A00h?
2@0>3`X03@l:00d@2@0?4@/020d700X?200;40X05QdF04U=B0061P@02PX800/;2@0c<c40JFUW01TI
5`0@40h00`0>3P`02@0<30X03`l=01DE4`071`D0410>00H6100M7A/04Q8@00h>300200d=2`0W00X:
200<30X04Q<B00d?3P092`X030h=010B4@0=3`h01@L601XL6`0<3Pd02`d<03Hh=`0F61L0418@00D7
100F61D030h;00h@3@072@H020X700X<2@0;3@X02P`900/=2P092`P03@d=01/K6`092@T06QXJ00P8
200B4Q803Ph>00l?3`0>3Ph02`/;00X:2P0=3@d03`l=00803Ph<00L03@d;00h>300?3`d051@B010@
3P0;2`T030`:00803`l=01<02`/900h>300U9B<061PF00d=2`0A4@l02PX800D50`0=3@/051@B00P8
1P0>3P`030`:01<D400;30L02@T7010A300<3@P0414<00803a0;00H04A8=01<D3`0A4Pd03@h900`=
200>3`X2010A300=00h?2P0A4Pd03Pl:00`=200@4@`07b0K02h_:P0I6AL061PF069RH03Rh^009bLU
00P81P0400h>300300`<2P0;30L03Pl900803a0:01403Pl900/<1P0:2`D03a0:00/<1P0720804A8<
00h?2@0A4P`03@h800`=1`0>3`T03Pd8010?2P0E50l03@`700h;1P0201HC3P0D00h;1P0=2PD04A4=
00P70`0;30L020P500d<200@4@`03`l;00l>2P0>3PT030d800d<200A4Pd030d80042000E5Q4020T4
014B3@0B4`h500l@2`0I010A300B4`h03a0;00l@2`0J6aH05AHA00/<1`0?40/04Q<>014B3@0>3`X0
30d800X:2@0820P030`:018C3`0=3PP02``400`=1@0=3PH03Pl9014A3P0B4Q004a<C01@B4`0201DD
4P0A018C3P0@4@`03@h7014B2P0@4@T04A4901@D300F4``0514;01lN6P0A40`04Q4=010?2`0A40`0
4Q4=00l>2P0A40`00P0D4`l0=@0B4@d03Pd:01HB4`0B3Pd03`l:00d@1`0:40@03A<902H[9@0<4@d0
2Pd901`M5@0C4`L04@l201HC3P0;1`H03`h<018A3`0=30X03`l=00h>300K7AX0004002@V8`0F6aL0
3a@@00h@3@0=3@/05ADC05QHEP0A4Pd05QLB010A300?3``05aLE00T91`0T92@05aLG01<C4`0<30`0
3`l?00H61P0C4a<05QHF01DE5@0B4Q005ADC018B400;2`T03Ph<00d>2@0B4Ph04a@?00803a0;01@0
4A8=010A300?40/03a0;010A300A4Pd04A<@00L:2P0D61T03Q8A00lC4P0D6AD03a@@00T>200K81X0
4QL@00lD3@0@5@h02a47018E308041<:00T04QD>01@G400E61404aD@01<E4P0B51404A<@01PJ6@0M
7a`00P0F6aD03`0D6A<07b@N018I4P0C6AD03aPC01HL600C71L05AhI01hW8P0O9b4061dF01LL5P0F
6a@05AXC01@I4`0201<H4@0>01@I4`0C614051TB01TN600E7AL03aXD018K5P0B7AL05b8L01HQ6`0B
7AL04A`F018M5`0F8A/2018M5`0301@N6@0E7QT05AhI008051dH00T05b0K01@M600C71L072DP020Y
9P0N9b@06R<P01PT800I9B400P0J9R804@0I9B405bHS01HU8P0H9b@062PW01@T8`0@8b404R8R028]
;`10BT`0HVe_01d[;00R<3<08S8e07^=T@0oDUH06Bha00807cLk00`06C8f02Di@00Q=C`093Po02Tm
A00W?4409ca0020e>00U>S/09C/j02Lm>`0]@d4202Pn?00]02Ln?P0T?4009SY102XoB@0_AE80;d9@
02i3CP0Y@4P0:3a302e4B00gC4d0;T<n02Xn>@0Z?S`0:C/k02Lj?@0^@DL0:ca302`nA@0W>Sh0:cdo
0313@`0W>cT0<DM402Dl=`0bB4D0:Cll02a2?`0bB4D0=D]90398AP0iCdd0>4i<0397A`0fBdh0>DaB
03M:D00`@dT0>deB0353A`0iBdd0=TQ903E7A`0eB4H0=TU70080=dY804P0>De:03iBD00R=c80?4m<
02Tl>00hBdL0=TU503U9AP0hB4D0;cll03M6@`0d@d00=DA00310?@0_@3X0<D4m0310?@0^?cT0=4A0
0351?P0]?SP0<d8n02hm>P0V<Rh09S8Y02@`9P0Y<bX0;3H]02Xd:`1BG5@0=Clg020Y900/=c<0=d50
038l>`0b>d80EEeZ04eGH@0`?TH0@e9I03U8C`0_@DD0Sj6S06YiO00gATT07B/^04IDE`0Q<340<d=2
03A4A00/?3/0>d]:00`J6P0/>cT07RdZ02Da;`0X=340:CDa02hj=P0V<c80:CPk03M6B@0R<C@0<T54
02Dc=@0]>c`0;3Xj02Xg=`0M:BT082`Z01dY9`0K9B@2020Z:@0902</:`0W<2l082TV020V900X;R`0
;34]01PM6@0M8Qh08BHQ00808RLQ00H07b@O01/P700L8Ad08BHS02da<00I7Ah201`P8@0?02DY;00P
92H071hK01dO6P0N81d07AlL01`N6`0J71T04Q@A01DG500A4a005ALD020R7`0O8Ah05aTH00807AlN
01406A/J01HH5`0F61L06A/J01LI600E5a@05ADE01LG5@0H61P05aLG01<C5@0N7R006QXL01HF600H
61X04Q8D01@D5P0201HF600K01@D5P0A4a8041HB00lG4@0@5Q8041HD014F5@0A5AH06QhQ01/O800D
61L051LE01DG500A4a005QHF01PH600G5aL04a<C01@D500F5QH04a<C01hN7P0L71`02`/;00l?3`08
20P04Q4?008040h?00d03@/<00l=400C4A@0518E01<A4P0B414040h?00l>300>30d03`d@010>4@0A
3a804Q0C00804a4D00<030X>014?500A3a@00P0?3A801@0@3Q405Q@G010>4@0;2@`03@/>008020H9
00/030X=00h<3`0:20/04Q0C01@B5@0=2P`03`/<01XF5`0O6a`040`=00/7200200l;300600d92P0>
2P/0510A00l;30080`@030H80P0@2P`020090`D030H8018<3P0=1`T030H800l92`0@2P`03@L9100:
10H00`0;1@L03@L9010:300200l92`0?00h82P0?2@/040X<01072P0900<0200202lT:00>1@P04PP<
01D:3P0?1PT05@/?00h31`0P5aX040H900803`H901003`H:00l62`0@1@T040D:00h32@0>0`L03P<8
00h32@0>0`L03P<800l4200=0PH0304500h31`0@1@T03`@81`0=0PH200l4200900d21P0>0`L03`@8
00X00`0A1PX03`@800/0100=0PH03`@801Cooooo000Kooooo`803a4<0P0M7aX200lA300500X<1`0>
40/02`d800`>2@0@4Pd00P0=3`X0100@4Pd03a4<00d?2P0>40/2010B3@803@l:00@0418=00d?2P0:
30L03Pl:0P0;30L0100A4Pd03@h901HG4P0>3`X200l@2`0300d>2@0>3`X03a0;008030d800X03@h9
00h?2P0>3`X03Pl:010A300B4`h03a0;018C3P0P8A`0:R/U0P0=3PL05`0>3`L03a0800hA2@0>4@P0
4A@;00dB2P0<4PP0318900dD2`0@50d051HC00/=2P0<3P/0<S@a07]mNP0D5Q<03@l<00X<2@0=3``0
418?00d?300?4@h01PP500803@l<00D07b4N01XL6@0D5Q<0418?00h@3@0200lA3P0500h@3@0=3``0
3Q0=00h@3@0?4@h00P0>40d200lA3P<03@l<01003a4>010B3`0?4@h03a4>00H81@0E5a@02`d:018D
4@0f>3D0418?01`N6`0;3@X0418?00T;2P0=3`h0418A0P0?4A00>`0>40l01PP701@F5@0;30/03Q0?
00lA400=3`h04Q8@00h>300C4a401`L501DE4`0I6AL03@d;010@3P0?3`d03@d;010@3P0?3`d030`:
018B400H61H04A4?00`<2P0?3`d03@d;00`<2P0>3P`03`l=00h>300;2`T03@d<010@3`0<30/02`/;
00h>3@0;2`T0410>00h?2`0@4@`04Q<>00l@2`0:2`D03Pl;00d=2`0>3P`0410>00h>30092@L03`l=
00`<2P0:2PP03Ph<01/K6@0U9B<03a0;010A300=3PX0<c@_00<03@h900<0414<01DF4@0C50l00P0=
3PT01P0>3`X02@X501DF4@0<3@T02P/600h?2P803a0;00/02``700d>2@0>3`X030d800h?2@0?40X0
414;00d>200C50h030d900d>2002018B300B00h>2@0=3@P03`l9010>2P0?2`P03``9014>2`0B3P/0
4@l;010=2P0E4@h03``8010>2P0D40d03`l;00`>2@0;3@P030h90P0?4@`07`0@4Pd04A<>00lA300>
40/051HA01<E400C50l04Q<>014B3@0?40/0:2TT02`]:00A4Pd0414<00l@2`0<3@P03a0;00h?2P0=
3@X01PH501<C4@0>3P`03Pl;00/<200A4@h04Q<?00l@300>3P`04A4?00l?3@0A4Ph00`0@4@`02P0A
4Pd04a@?01HG4@0=3PT04A8=014B300C4`h03`l;01DF4@0@4@`200h?2P1300l@2`0E5Q403a0;024R
7@0D5A003a0;01<D3`0@4@`0410=010@2`0?40/03Pl:00h@2P0?4@/03a4<018D3`0A4Pd03a0:014B
3@0A4@/07QhK01<C4@0=3@/03`l=010@3P0<30X04A4?010@3P0>3P`04A4?00l@3P0@4@l04A4A010@
3`0A4Ph03a0;014B300P8AX05QL@010A300J6QP0;bl`03`l@00@3a@0510F018?4`0?3A003P`=00l>
3P0?3`d04A8>00d>2@0;3PP03Q4;010C300>4@/03@`:01<?3`0B3`l03`h=018@400E4a<04A4@010@
3`0=3@`04Q@B00`>300200lA3`0900h@3P0C5A803Q0=018D4@0?4@h051HC00d?300C5A404aDB0080
4A<?00L04QL@00/@2@0D6A8041D?01XO6@0_=2h051TC00<04aPB02004aPC018H4@0@6Pl041/?00hI
300D7a@05R4G00lJ4@0>6A4031H@014L5`0E81`0DUeI0458A00?5A005A/G01@J5P0N9Al03A<?01@K
5P0C6A@04QPD01HL5`0J81/06AlK01XP700D71L05adI01<L5`0D7AP06B8M01@N608062<M00H04AdF
01/X8@085@h06BHN01HR6@0E8A/201@P6@805b<O00H05B4M01PS800I92<06RDS01TT8`0F924201HU
8P03010O700?7Q/04b8O00@062LT04P05bLT01PW9@0G8b<072PX01l[:`0J:2P06RPY01TX:@0N;C00
830c01//;P0J;3008S@h02@f>`0Z?D@062`e02a0B@1?Hf`0;d=;02TnA00Q=S/08CHj028g>`0T>C`0
9S/m02Pm?P0W?3/0:3`n02Xn@`0Y?4<0:ci803U<E`0iBeL0:ci802`oAP0aA4X0;45202Tn?00X?SP0
9chf02Hm=P0W?CT0:3hk02To?@0W?3X0:Sln02a1@@0]@T00:T0n02Lm>`0Z@3d0;D@o0358@P0cBTD0
<TU402m6@00eBdP0@5IB03mFD@0gCDX0=Ta803Q>B`0cBTX0>4e?03]@D@0hCD`0=d];03=7AP0eBDP0
>Te:03Y=B@0fBDD203=6@P0703U;AP12E4l0<dDo03U:A@0`@CX0>T]403E6?`0203=4>`120393>P0b
@cP0<d<j03E2>`0[>S@0:c`d03M:@P0eBD40:She02m2>P0]?CH0<3hg02Xe;`0Y<2d082PS02Hd;00T
<BP0?4Tm02Xf:00^>B/0930R01l[7`0Z=Rl0:cXg03M7B015EeX0>TaI05IVO00kC5l0>4YI0354D00]
?dX0>4UA0393B@0]?d<0<45502ln@`0_?T@0;ci205ATI@0b@D@0;Sdo01h^;`0]?Ch0:cXl02Ti>P0/
>S`0:cXl02Pg>@0W=SP09cTk02Hj?@0X?3l0:Se102@f>@0W=ST0:3Dh02Td=`0X<cD09Bh`02@];P0T
;2`08R/Z020[9`0Q;2P0;CHc0P0N9b@02`0N92808bTW02<W9P0M8B007R8Q01lS8@0L8Ah07B4O01dR
800M8B007b<R008092PW0P0S9bH0100R9RD082@T01dQ800N7aX201lP6P0f01dN6@0L7AP06a`G02@T
8P0R8R005aLE01DE5@0I6AT061XI01dO7P0F6AP06adL01`N7@0H6AL06QXH01/K6@0J6QL05aLC01LF
4`0F5A405A@@01DE500G5aL05QHF00`<300H61P04Q8B01PH600B4Q805ADE01PH600E5AD04a<B01HG
500E5Q8051DC01DF4`0E5QD04a@C01HF5`0B4aD04A4C01@D5P0C4aH04Q8D01HF5`0>3Ph07alO010@
400j>SX07QhN014A4@0C4a<04Q8B0P0?3`l05@0A4@l0414<014A3`0A4A003`lA00X93P0@3aD040lD
00l?4@0?3`l03Ph=00h?2P0>3P/03@/=01HD5`091`X04a4F00L52P0B41D030X@01@A6@02010=5@03
018@5`0@3Q803`d>00@03`d>01004@l@00D4100=2``030X;00D3100B4140514C00T4200o>Sh0If9V
01D@500;1PX06QDI014<400@2`l03`X>0P0>2@d03@0?2Ph03PT=00l;3P0<20/03`X>01D@501JEET0
5a<F00H21@0B3A4030P;01<>4P0=20`00`0;1@T0700<1PX03@L;00d72`0E3a<030L:014;3`0F41@0
3@P;00`62P0@2Ph030H:00P21@0@2Ph03@L;00`42@0;1@T03@H;00h72`0=1`/03PL;00X52@0?2Pl0
71HL00/42`0=1@/05P`C00h4300>1@/200l4300300l42`0?10`03`@:00D03`@:00D02`460146300?
10X03P<901052`0700h32@030146300@1@/03P<900803P<900<03`@:ooooooooool04_ooool001_o
oooo00@03@l:00h@2`0J71L06adH0P0@4Pd0400=3`X0418=00`>2@0<3PT03Q0;00/=200<3PT03a4<
010B3@0>40/03@l:00h@2`0620<03Q0;018D3`0?4@`200h@2`0301DF4@0B4`h020T40080414<00@0
4A8=00l@2`0?40/03Pl:0P0;30L00`0<3@P03a0;00l@2`03010A300;014B3@0@4@`03a0;00h?2P0<
3@P02``700/<1P0=3PL03@h600h?1`0?40P00P0>4@P0600@4`X03Q@:00hD2P0=4`T02Q8700dB2`0E
5a@03Q0=01<E4P000@003a4>018D4@0<3P/02@/800h@3@0A4a003Q0=00T;200?4@h05QPE01PJ5`2D
UY<0Ce5>00T;20803Q0=00<04A<@010B3`0>40d00P0<3P/300d?300500`>2`0=3``03@l<00d?300<
3P/00P0=3``04@0<3P/02`d:00T;200>40d020X7014C400@4Pl0:bdZ00d?300D5Q<01PP500P:1`0<
3Pd020X900h@3`0@4Q402`d<0080418A018071hM018D4`0;3@`01`T800/=300B4Q001@D301LG5@08
20H05ADC00`<2P0:2PP03`l=010@3P0=3@/03`l=00d=2`0<30X200T91`803`l=00T02PX800h>300=
3@/03Ph<00l?3@0>3P`02`/900d=3@0@41000P0<30`02`0>3Pd02`/900h>300=3PX03a0;014B3@0C
50h04A8<00h>300=3@/03Ph<0080410>01@03@d;00T91`0=3@/0410>00l?3@0:2PP01@D300/<1`0<
3@T03a0;00d>2@0A4Pd04a@?00d>2@0>3`X04a@?014B3@0<3@P03Pl:01@E40802``700<03Pl:0001
000C50l00P0>3`X0100;30L03@h9010A300=3PT200`=1`04014B300?40X03Pl900@500803a0:00D0
3@h800`=1`0?40X04A8<00l>2P0200h=2@0B00l>2P0@3`/04A0<00X91@0<2`L03@`8018A3@0A40`0
3@d800d?2P0?4@`04aD@014C3P0<3PT02P`7018D3`0E5a804Q@?0P0@4Pd01@0<3PT04a@?014B3@0?
40/04A8=00803@h900<0414<014B3@0>3`X00P0>3`X00`0?3``030`:01LG5@0201<C4@0800L71@0;
2`T03`l=010@3P0A4@l020P600h>300A4Pd3010A300;014B3@0C50l030d800l@2`0D5A002P/6010A
300B4`h051D@00l@2`0B4`h00P0A4Pd0200b<bh071dH01@E400A4Pd030d8010A300D5A003a0;0P0>
3`X0100=3PT03Pl:00l@2`0;30L300h?2P10018C3P0A4Pd03@d;00d=2`0<30X03@d;010@3P0A4@l0
6QXH00l?3@0l?3X0;2`Z00/;2@0>3P`03`l?010@3`0C50l04A8=01<D3@0L7AD06AXD00d>200@40h0
DU9D04m>DP0I61h06A@J01HC5P0C4A@04Q0A014@3`0@40h03Pl:010A300D5Q405QTB014E3P0=3`X0
40l=01<?400A3@h04@l@01HF5P0J6QX02`/;00D71P0@4Q407b4P018D4`0E5aH04aDB018D4@0F61D0
3@l<00lA3P0<3P/04aDB00D7100E5a@04Q@A00lA3P0K7AX03a@>00hC3@803a@>00@05a`F020U7`0D
6A<051TC0P0C61806@0B5a404AP@018L400A6a003QP=010J3`0@6Q403QP@01/U7@0@6A@0624L01DN
6@0@6AH04ATE00P>2P0A5a<0>T0l01@J5P0B61@05Q`H01LM6@0H7QX04aTE018H500H7QX00P0J81`0
4P0V;2P07RDQ00lH4`0D7AP04A/E01`W8@0F8A/05b<M01<P6@0F8a`04b0H01@Q600D8AX04b0I018O
600E8Ad05b<O01DQ7@80520N00D05B4O01HR8P0E92405RDR01@S8002018Q7P0301HU8P0I:2D06BPU
00@06BPU00d07RXZ01DQ8@0L:2P09C<c01l];@0R<3405bHY028a=00O<C<0:Sa003i@E00]@4D0:Se4
0080<4A=00<0V:be020d?@0[?dH00P0T>Ch02@0U>Sl09CXm02Hk?P0V>c`0:3`m02Hi>`0Z?D40;3m6
02TkA00202TkA@0=02i1B@0cAT`0;T5702Xn?`0`A480:T4k02U0>P0X?cT09chh02Po>P0X?S/0:Cll
02Y0?P0202]1?`0H02a1@@0/@T00;D=102a2@00_AD80<dU70357A@0[@Ch0=de;05Q^J`0lDTl0;dE3
02i4@@0hCT`0=dm?03M<C@1@IFH0<TQ604IJF@0eBDP0=TY803Y=B@0iC4P0=TU50P0dAd<0C`0lCDL0
AUMA03A5?`0_@3X0:3Ta03U:@P0_@3P0;3dc02/l<P0^?cD0<dDi03I6>`0_?3D0:cXc02ho=`0iC4<0
=T]202i3>P0[?cH0<3lh02`i<P0W<B/092XV020Y900nBdT0<clk03E1>@0^>S00@4Y102La:@0b?CL0
;CTi02hl@@0kC5H0=dUG03M9G014EVh0=dUO03mAI017FVP0AUQT065dN`1ZOH<0@eEI02/l@P0]?TD0
=TE<03e<D@1WMWT0@U5D02@c=P0W=ST0<d9502Pg>P0^?D00;ci102dl?`0[>Sd0;3/n02/n@@0U>Sd0
9CPl02Xl?`0W>C/0:3Lj02/f>00X<cD09Bla02H^<00U;Bl082LX020Y:00D7a/07BPT02Pa;P0I8Ql0
7bPU01`R800N92800P0M8B000`0P92<07B4P01lS8P0201hR8@0601lS8P0P92<082@S024U900M8B00
8RHU0P0_<c80E@0O8b407AhI01dN600M7QP06a`G01TJ5@0G61<04Q8@01PH5`0H61P06ATI01dM7@0I
6aX071hM01LJ6@0J71/071hM01TJ600H61H05aLE01LG500G5Q805QDA01LE400E51006QTG01DE5@0A
4A405QHF010@400E5AD04a<C01DE5@0H61P05QHF01<C4`0G5aD051@B014A3P0D51806QXH01/K6P0F
5QH04a<C01DE5P0E5AL04a<E018A5P0B4Q@061PI00`<300J6QX07AdM055AD@15ADD04Q8B01<C4`0B
4Q804A4A010@400B4Q004a@?00h>300F5Q@04a<E014@5@0B4AH040lD01<C5@0D51@04a<B00l@2`0=
3@/0518D01PF6@0<2Pd0518G00T7300A3a@05Q<J01dJ8@0;20l061DN01@A6P0:20d01@0?3@h0400B
41402PP901XH6@10?Sl05A<D0040000>2`d02PD900D0100<1`/03PT=014<400E41@04@`@010;3`0?
2Ph2010;3`0300l:3P0L5a/020<700805A0D00X00`0203Lb=P0<1`/00`0200P31`0<1`/05A0D00l9
3@0@2Ph04`dA0P0D3Q803P0C3A405Q0D00@00P0=20/040X>00H0100>20`02P@8010:3P0I4aL07ALK
01LA5@0B310030H:0`0=1`/200`62P0300/6300@2a406aHL00802@8900@03`P?00h4300>10`03P@<
0`0?10`700l42P0401D:400A1P`03`@:01052`L03P<900@04@H<01052`0>0`T03P<90P0?10XDoooo
o`006oooool0500C5A002P`700X<1`0:30L03@l:01LI500?4@`04A<>00d?2P0<3PT03Q0;00X<1`0>
40/03a4<00h@2`0<3PT03@l:010B3@0<3PT03a4<0P0A4`h200lA3005028S7P0M7QT02P/600l@2`0>
3`X00P0;30L200d>2@0300`=200>3`X0414<00H0414<00X03a0;00d>2@0>3`X0414<00h?2P0;30L0
3@h700d>1P0>3`L03a080P0>4@P0300?4PT03Q@:00hD2P0=4`T02A4600`A2P0@4Pl03a4>010B3`0D
5Q<02`d:010B3`803a4>00h03Q0=00`>2`0;3@X03@l<00lA3P0<3P/02`d;020R7`0a<c001PP500/=
2P0<3P/03a4>00h@3@802`d:00D03Q0=00lA3P0?4@h03a4>00h@3@0600lA3P0S00h@3@0A4a003@l<
018D4@0?4@h02`d:00840@0E5a@01PP5014C400;3@X04A<@01DG5P0=3`h0418A018D4`082PT03a4@
0001000L7Qd030h=00430P0;3@`05aTH04I6A01?Cdd06ATG00l?3@0D51803`l=00d=2`0?3`d0410>
01@D4P0G5aD00P0@40h01P0<30X02@T700d=2`0=3@/02@T700l?3@803@d;0P0?3`d00`0<30X03@d=
010@400200`<300500l?3P0;2`T03`l=00h>2`0<3@P00P0=3PT01P0=3PP03Ph<00d=2`0>3P`04A4?
018B40803`l=1@0@40h00`0?40/0414<00l@2`0200h?2P0<00D60@0:2`H02P/600h?2P0<3@P02@X5
00/<1`0I6QD020T400l@2`0@4@`020T40P0=3PT02`0>3`X02``700h?2P0A4Pd03a0;00h?2@0;30H0
5QLA00T:100>3`T06Q/E00@03Pl900@03a0:010A2`0?3PX03`h:0P0>3@T0300@3`/04Q4=01<B3P0?
3PX02`X600`;1`0?3PX03a0;00d?2P0?4@`04Q@?010B3@8030h900d04A<>010B3@0=3`X05ALB01/M
600E5Q406AXE01DF4@0I6QD04Q<>00P9100B4`h04A8=00804Q<>00l05QLB018C3P0=3PX03`l=014A
3`04108051@B014A3`0H61H04A4?00`<2P0:2PP04A4?00`<2P0A4Pd00`0@4@`0500A4Pd04a@?00h?
2P0A4Pd04a@?00T:1@0C50l05AHA014B3@0:2`H03Pl:00/<1`061`808b@O02HW8P0>3`X0414<00X;
1P0=3PT051D@0P0>3`X300d>2@0800h?2P0=3PT0414<00l@2`0>3`X04Q<>014B3@0<30X2010@3P0e
00`<2P0;2`T03@d;010@3P0D5180SHf;07IfM00A4@l010@2010@400B4Q004Q<>00l@2P0>3`P04A8:
00T:100D51401PH4014A4`0D4aL04a8G01TD600G4aL0518E01<A4P0A4100410>00d>2@0@4Pd051HA
01DH4@0A5@h03Q0;010?3@0B3Pl04@d>014?400C4a<05ADE01LG5`0>40l03a4@00T;2P0620L071hM
01<E4P0@4Pl04Q@A00`>2`0C5A8051HC010B3`092`P00P0E5a@01P0@4Pl051HC01<H4P0C61803Q<=
00/@2P803Q<=00L05AXD01@I4`0C61804aPB014F400A5Pl04A/>00803aT>01004Q`A018L4`0?6A00
5AlG00hG4P084@`051dH01XS800C6QL03A<?02`b;P1iOg/08RPT018H500E6aL051XF0P0I7a/201@J
5P0I01DK5`0I7a/09bdY01lV8P0@6A@051dH01@N600K9R0072LQ02@`:P0>6a@08BhW014N5P0D8AP0
524J01<P6@0B7aP05B4M01PT800G8al05R8P01DQ7`0G8b406BDU01LV8`0201PW900301HU8P0E9240
5B@Q00H062LT00<05b<S01HR8P0J9RH00P0L:RX03@0P;Rl06bX]024`<`0P<S@0:Sa003I8C00V>3d0
93Po02e1BP0V>T<0?51I02LkA00T>3l00`0V>d0202Hk?P0?02Dj?@0W>c`09CPk02Pk?`0Y?480:C]4
02m1B`0Z?4H0<4=:02/nA00Q=3P093Lj03=7AP0Y?c`0:3li00809Sdg01P09S`h02Hl>@0/@Sl0:d4o
02Y0?P0[@Cl0;T=302m4A@0^A480;D=10357A@0gCD/0>4i<0398AP0cBDL0>e5?02Lm>`0jD4h0:d4o
04EKF@0fCTh0DfQY0;gBd`1EJfT203M;BP0403I:B00iC4P0>Da803I9A@80=DQ400L0;3dg02/l=P0S
=2h0<T<m02Tj<P0b@c/0;Chf0080:c`b02h0;Chd0312=P0a@cL0;S`e02dl=@0a@3T0=DLo02i2>@0V
>c80;d8i02/j<`0^>c@0:C<^02<Y9@0X<Bh0@Di>03Y6AP0hA440>dI205AMF00Y<c40?DQ:02lj@00/
>TH0BeY]03Y;G`0Z?5<0AeUa03a>I00lCV40>4]I0312CP17FV40CF1V03a>DP0hBDl0=TM>0350A`0a
@4D0DF1S03M6B@0P;c80:cXm03I5B00Y>3/0:STl0P0/>ch0500]?3l0<3m203=6B@0/@D@09CPl02Dh
>`0T=SP0:3Hi02Pc=@0S;S008R`^02L_<@0X<3808bX[02</:`0K9R808bhZ02D^:`0T;BX08b`Y0P0K
8Al01@0J7Qd07B4P024U900M8B008BDT008082@S0P0R9RD0200O8b808BDT01dQ800N8R40:2`[02T]
;00M8Al07b0K0P0O81X04@0L7AP06Q/F01PI500C4a406ATH01XJ6P0K6a/07AdM01PJ6@0J71/061/J
01XL6`0K7A`06AXI01LG5@0E5A<05QDB00805QDA00<05aD@01DD400J6AL00P0C4a<0100Q8B403`l?
01PH600J6QX201HF5P0E01DE5@0C4a<05aLE01XJ600B4Pl04Q8@01XJ600N7Qd061PH014A4@0E5AH0
51@F018B500D4aP061PJ01<C500<30`05QHF018B4P0[:b/07alO00<04a<C00L04Q8B014A4@0B4Q00
3`l<00L71@0@40h02PX<00803PdB01804Q4F01@D5P0E5AD051@C010A300?3`d04a4C01@B5@0<2Pd0
4a4F00d;400A3a@02PL>010=500?31<0QX><01TF7`0=2Pl500h<3@0:00`:2`0=2``04a4B02l];P0O
7Ah02`T:010<3`0C3Q805A0D00d830803PT=01@03@P<00h93@0=20`03@P<00h93@0?2Ph04PdA00L2
1P0;1PX02PH900l:3P0:1@T0100300H11@0F4AD040/?00<00P0<1`/02`H:00`62P803`T=00d03@L;
00X4200C3A405@lC010:3P0B31001P04010:3P0C3A402P@8034[;`17@DD06Q@H00@03PP<00T03@L;
00`62P0;1@T020<900<010080`T030D<01@=500<1@`00`0?1@d301053@H03`@:00H04PL=01P=4`0D
2@l04@H<01873@0?10X600h32@8040D;0P0>0`T00`0?10X040D;ooooo`0Cooooo`006oooool0700<
3PT03a4<01HH4`0F61<04A<>00d?2P0@4Pd04Q@?00h@2`0=3`X03a4<00/=200A4`h03a4<00/=2009
2`H03@l:01<E400I6aH0418=00d?2P0C5A004Q@?00lA300J6aH05aPC00T:1@0B4`h201<D3`0300h?
2P0?40/03Pl:00803@h90`0?40/300h?2P0400d>2@0@4@`02``700`=20804Q<>00D0414<00d>200=
3PP03Pl900l@2P0300hA2P<03A8;00H02Q49014F40041P<03a4>00d?300@4Pl200h@3@0<01LI5P0I
6aP04A<@00P:1`0;3@X03Q0=00d?300A4a00=SPe04A6A00B51403@l<0P0<3P/0100?4@h0418?00d?
300<3P/200d?300400h@3@0=3``03@l<00d?30803Q0=00l03a4>00h@3@0>40d0418?01DG500=3``0
10H401`N6`0<3P/03@l<018D4@0>40d03a4>00d?300>40d00P0:30/0900J71/07R0O010B4@0;3@`0
6adL065SHP0?40l03a4@01PJ6@0O8B00b/[80>WYi`0b<S005QHD00X:200C4a404Q8@00h>300=3@/0
6QXH028R800E5A<030`:00l?3@0@40h03@d;00l?3@0D51804A4?00h>300=3@/03`l=010@3P0>3P`0
3Ph>014A4@803@d=00T0410?00`<2P0<30X03Ph;00h?2P0=3PT03Pl:010A2`0@40h00P0>3P`06`0?
3`d04A4?010@3P0:2PP030`:00h>300?3`d0410>00l?3@082@@04A8=00T:1`0?40/03Pl;01HG4P0A
4Pd03Pl:014B3@0@4@`03a0;018C3P0<3@P03@h901`M600;30P04Q<>00X;1P0200l@2`0L00`=200>
3`X04A8=00l@2`0A4P`03a0:00/<1P0L7AL09BHP00/<1P0<3@L03Pl9010A2`0B4`d03Pl900`=1`0>
3@T04A0<010?2`0=30P040l;01<B3P0>3@T03`h:010?2`0>3@T04A0<014B3@8030h902804A<>01LI
500I6aH05ALB010B3@0>40/04Q@?01dO6P0L7QT04Q<>010A300<3@P05QLB01@E40092PD0414<00l@
2`0<3@P04A8=01TJ5@0C50l03Ph;00d=2`0B4Q00410>00`<2P0W9bD0ATI400d=2`0J6QP03@d;01LG
5@0@40h04A8=0`0@4@`00`0A4Pd04a@?01@E400200h?2P0@00X;1P0B4`h04a@?01DF4@0A4Pd05AHA
01@E400>3`X04a@?02HW8P0@4@`03a0;00d>2@0<3@P04A8=010A30803a0;00X03Pl:00l@2`0@4@`0
4A8=01@E400B4`h03a0;014B3@0@4@`03Ph<0P0B4Q005`0>3P`030`:00l?3@0@40h03@d;024Q7`0@
40h04a<A00d=2`0?3`d04Q8@010A300@4@/04Q<=014B300@4@`0410=01XJ6@071`P05ADH00L62P0F
4A@05A8C00804a4B02H04A0@00l?3@0>3P`0414=010B3@0?4@`03a8<014C3P0@40h04a4B01DC500D
4a<03`l?00d=3@0E5aH05QPG018D4`0>4Q40:Bd/05=GEP0?4@h05aTF01dO700A4a00418?00`>2`0S
9B806A/H00h@3@0A4a005aTF00h@3@0@5@l04aPB014F400D6A<05Q/E01<H4P8051TC0`0C61804P0C
61405ahE01<I4P0D6a<05A`D01<I4P0B61806B0I03Dj=P0I7a/04ALC01`Q800>5140<SPd02hd<00H
7QX03Q@@01TO6`<051XF01/05A/G01HL600F71P05adI01@J5P0K8Ad0620K01@M600I8Qd05R0K01dX
8P1LIf40Oh^501PU7P0G91d04QlG01@Q600F8a`05B8K01@Q6P0F8Qh05b<O01HR7P0E8Al05R8P01LS
8@0J9RH00P0D8b00100F9B805bHS01PW900F9B8601TX9@0W020^;P0`?Sh0:CLg01HT900N;2`0830`
028a=00L;Bl0838d02@f>P0N<3@08C@i01lc>P0N<S/0:3a501P/=@0Y?DH09c]202Hk@00W?440:3e2
02Pm@00V>ch093Tl024e=P0[?d40=4M;02i1A`0W>T00;D160354B`0Z?D@0:3]102m2AP0cATT0:Shm
02]1?P0Z@C/0:3li00<0:3hk0P0^A4805`0/@T00;D930356A`0cB4T0<DI70397B00dBDX0=da=03Q=
CP0fBd`0=DY;03iCE00kD540<dQ903]@D@0aATL0>51@04AIFP24VIX0@5ID03]?CP0cAdH0=d]90080
>Da80P0gBTH0=@0hBdL0=TM10352?00gB480DV=M03A5?@0/?CD0;Chf02m0=P0`@CL0;Sle02Xl<00X
>Rh0;Sdf0350>@0fACh0<dDm02/o=P0Z?SD0<44i02hm=P0]>S<0:SD_024Z9@0^>CD0<3do02dh?00^
>3X0<3Xl03m9BP0/=CT0?4I?03i9E`1IIWd0EVF203a;J`19FWL0NhnW04iSN@17Ffd0@5=Q02@h@`0j
CED0=DQ>03=4B`0dAD`0<D990393B`0c@dP0<d=302/k>`0V=SH093@d0080:c/k01h0:3Ph02Xj>P0Y
>CT0:3Ph02Xj>P0/?T00:Ca002/m?`0a@T@0;3/n02Hd=@0/=cT0:3<e02H`<@0Z<S@0:c<e02H];P0N
:2H082/W024/:00G81d0<3Tf01/T8@0L8R007B<Q01`P7`0N8R408RHU020T8`0O8b82020T8`0:01lS
8P0N8R407b<R020T8`0N8R406QhM01TM700M8B0092TV01`N6P807AhI00h071dH01XK5P0I6AL05QHD
01TI600G5aL061PH01hN7`0K71h05aXI01TL6`0J71/06adL01/L6`805ADC00h05aLD01PG4`0H5a<0
5aD@01@C3`0I61H05QHF01lO7`0Z:RX061PH01lO7`0Z:RX06a/K01DE5@8061PH01@061PF02/[:@0L
71T04a<A01@D4P0F5QD04Q8B014A4@0C4a@04Q8D01<C5@0I61d07AdO014A4P0?3`l05ADE018B4P0?
3`l02PX:01@D50<04Q8B01804A4A010@3`0C51003`l=014A400L71d06QTN01<B5`0D4aL04Q8D014A
4@0A4A004Q8?018B400D4Q<03P`?00`:3@0A3a82018@5@06010>4`0I5Qd0;b`c08N4R`0@3QH040dB
1@0>30d0500?3@h0>SPi044o@00C4A801PD500`:2`0A3Q0030L;00l:3P0>2@d03`X>01HA5@0A3100
40/?00l:3P0>2@d03`X>010;3`0B3A403PX=0P0@2`l02`070`H05Q4E00l:3P0<1`/02PH900/72P0B
3A404@`@00`72`0?2@d04`dA00805Q0D00H05@lC00d72`0e;c<04@/?018<400;1PT200d72`0500T3
1`0L5QX0:28V018<400=1`/00P0>20`02P0?2@d03PP<00h8300=1`/03PT?00P32@0?2Q002`H<010;
4@0;10/200h73P<040H>00<04@H>00l42P0?10X01@0?10X01@0D2@l04@H<00h32@0?10X03@8800H0
3P<900H040D;00l42P0>0`T03P<901052`0A1P`Dooooo`006oooool03`0B50l03a4<00X<1`092`H0
3@l:00h@2`0?4@`04Q@?00h@2`0=3`X03a4<00`>2@0=3`X03a4<00h@2`0200d?2P04010B3@0D5Q40
3a4<00d?2P80418=00d03a4<00d>2@0<3@P02P/601<D3`0B4`h06AXE014B3@0B4`h04A8=00h?2P0=
3PT03a0;00<03Pl:00@03@h900`=200<3@P0414<0P0=3PT00`0>3`X03@h900`=200200d>200500h?
2@0?40X03Q4:00hA2P0<3`P00P0:3`P0300<4@X031<;00hC3@041P<00@<0010B3`072@H030h;010B
3`0?4@h0418?00d?30802@/800L04A<@000100031@80@dE204i@C@000@005QPE00803Q0=00@0418?
018D4@0A4a003@l<0P0;3@X0C@0<3P/02`d:00/=2P0;3@X030h;00d?300>40d03@l<00`>2`0:30T0
2@/801/M6P0:30T0828O01XL6@0@4Pl02P`9018D4@0?4@h04A<@010B3`0?4@h03Q0=00X<2@072@H0
2@/8014C400?4@h03@l<01DG500620D0418?01<E4P19BDL0I6AR01LG5@0A4@l05ADC018B400?3`d0
3Ph<00`<2P0B4Q0061PF018B40092@L03@d;010@3P0=3@/03Ph<01<C4@0A4@l03Ph<00d=2`0>3P`0
410>00l?3@0>3Ph04A4A00h>3P0=3@d0410?00`<2P092@L03Pl;010A300>3`X03Pl900l@2P0A4@l0
3@d;00`<2P0=3@/03Ph<00d=2`0<30X03`l=00804Q8@00d03`l=00/;2@0F5a800`@001XK5P0H6A@0
7b0K00@5000A4Pd03@h900l@2`0>3`X03a0;00804a@?00D02``700`=200Y:RD02@X500l@2`02010A
300R00d>2@0>3`X0414<00h?2P0>3`T03@h800/<1P0Y:R@0<S<]00d>200<3@L02``600h?2@0B4`d0
414;00d>200=3PT0414<00l@2`0;30L03a0;01<D3`0L7AP02P/600d>2@0>3`X02``700h?2P0>40/0
30h900lA300E5a8061XE018D3`<03Q0;01/04A<>00d?2P0<3@P030d800h?2P0@4@`051D@01DF4@0<
3@P03a0;00h?2P0=3PT04Q<>014B3@0:2`L0418?00lA3P082PL03a4>00P:1`10@Sl02P`9018D4@0=
3``0418?00d?300A4Pd00`0@4@`0300A4Pd04a@?01<D3`0:2`H05QLB01@E400=3PT0414<00/<1`0?
40/03Pl:00/<1`803Pl:00H05QLB01DF4@0>3`X04a@?018C3P0@4@`2014B3@<0414<04d04A8=00l@
2`0B4`h04A8=00l@2`0B4`h0414<00h>300@40h03`l=00h>300?3`d0410>00d=2`071`D03`l=00h>
30092@L03`l=00d>2@0A4Pd03@h900l@2`0F5a804a@?01<C4@0A4A003Ph>00820P0=3@h03`lA018>
3`0C40l04a8@01@C4@0B4Q004A4?00d=2`0@4@h03a4>00d?2P0=4@/04A<>00h>300>30d03`d>010@
400<30`020X901PJ6@0;3`h03A4@01XN7@062PT000<2014C400M7a`09BLT01LI5P0B51403Q0=02@V
8`0F61D03Q0=00lA3P0C5A803Q0=01LL5P0E6Q@05a`F01HK5@0B5a404aPB014F400B5a404aPB01@I
4`0201DJ500B01LL5P0D5Q405Q/E01DI4`0C5A005QXE01<H500[;BX04QDB018G4`0D5Q<06R0L02<Y
9@0U:bL04ALC00lE4@0>51006b4M0P0G7AT03@0D6QH05A/G01XP700L8Qh04aTE01PN6P0E7AP051dH
01XS7P0E7aX072LQ03E0>P0Q;BH00P0K:2401P0C81P05R<J01LT7@0G91d05R<L01LS7`806BDQ00X0
6BDS01LS8@0F8R005B4Q02Dc<`0O;Bd05R@T01DS8`0I9bL07B/[1P0K:BT01P0N;2`0:SPh028`<00A
8B005bLV01`/;0807Bla01d07c8c01ha=@0M<3@09STn0396C@0gBe@093Q10396C`0E:C80;D5802<h
?@0T>Ch09ca102Pm@00V>ch093Tl02Di>P0[?d40<TE902i1A@0X>cl0;3m302m2B011E5P0?4mC0313
A`0^@T@0<dM602Lm>P0302Hl>@0W02Lm>`0X?S`0;TA202i4@`0_A4D0<DI703=8BP0dBD`0<dQ;03Q=
D00iCU40=DY=03I;CP0jCe80@eQK06AiO00Y?T40<dQ;02i3AP0lDE@0=dm?03eBD`0fBd`0=de;03iB
D@0Y?C`0=d]903U<B00hBdL0=dY603Q;A`0jCDT0=DI003a=A`0b@cd0<44k02dn=P17F500<44i0080
<D8h04P0;Sle02/m<@0Y>bl0;3de0311>@0fAcl0<d@l02m0>00b@c/09cH_055NE`0S<2T08bhX024/
9P0V<Rh0;chn02@b<`0^>c/0<3`l03M1@`0_>Cl09Bli03i:FP1DHGT0@e9c04QHO00nD6h0@EE^02e1
F@13F6`0?eES03A7E@0fBU80<TI=03Y=D`10DeT0=dYA0393B`0gAd`0<T1103E3A00[>CX07bd^02Dc
=00]>c`0;3Xk02dk?00/>S/0:3Hg02Le=P0U=CH0:3Lj0350@`0hAdT0;cdn02Td=P0U<C40930`02<]
;P0R:bX08BXY020Y:00T;b/07bXV02Td<00U;R/0BU=@02/d<@0M8b408BLU028V9@0O8b82028V9@1>
024U900U:BP09b/Z020T8`0O8b809b/Z01`P7`0M8B00720O01PL6`0J7Qd08RHT01dO700N81/07b4L
01lQ7P0N81d07AlL01PJ6@0M7Ql06a`N01dN800S92H08R<U01@H5`0J7A`06A/J01/M700L7A/04a<A
01LG5@0I6AH06QTE01TH500G5A004a8>01@C4@0A4A406a/K01HF5P0D51@05QHF01dM7@0D51@04Q8B
01<C4`0B4Q804a<A01PH5P0C51004A4?01@D4P0H61L06ATI018B4P0C4a@05ADG01PH6P0F5AX051@F
01<C500B4Q805ADE01`L700C4a<06QXJ018B4P0?3`l0410@018B4P0@41003Ph>00P81P092@T020P8
03Ti>@0S8bD020P:0P0@4180400@41003`l>00h>300>3P`09B<T01LE5P0D4Q<040hA014?4P0;2@`0
5aDJ01HD6@12@4D0Q86800P5300>310500d;300900P61`0J61T0:2HW00<10P0100003`d>00d9300:
1@T03`X>00805Q4E00D05A0D018=4@0B3A404@`@010;3`0200l:3P0<00/62P0O6Qh01@0400h93@0F
4AD04@`@00`72`0F4AD061<G01@?4`0:1@T010030P0;1@T04P0=1`/03PP<00l93@0@2Ph04`dA00/5
2@0=20/04P`@00P21P0J51P02`D901<=4@0:10P0100201<=4@0B310030H:00d72`<03`T=00L03PP<
00H11`050`P04@lD00T42P0=20h040/A00<03PL>0`0@1Ph600l42P0600h32@0D2@l04PL=01052`0B
1`d040D;1P0>0`T01P0?10X03P<900h32@0>0`T040D;014631Cooooo000Kooooo`0I010B3@0A4`h0
3Q0;00`>2@0=3`X02P`700h@2`0A4`h03Q0;00d?2P0@4Pd03@l:00X<1`0?4@`04Q@?010B3@0=3`X0
30h900X<1`0>40/03a4<00h@2`0?4@`04A<>01@E400200l@2`09014B3@0:2`H04a@?00h?2P0@4@`0
4A8=010A300B4`h04a@?00803a0;0P0>3`X0200=3PT030d800h?2P0@4@`04A8=00l@2`0=3PT030d8
0P0=3PP01@0>3`T03a0:00hA2P0>4@X030l800802@h700P02a0900dD300A5A0071hK0043000B5140
61XG010B3`803Q0=00X030h;00lA3P0B5140418?00`>2`0J71T04aDB00X<2@082PL05QPE0P0=3``0
1@0;3@X03@l<010B3`0@4Pl03Q0=00803@l<03403Q0=00d?300=3``03@l<00h@3@0@4Pl04A<@010B
3`0>40d0418?014C400f>3D06Q`I01HH5@0<3P/04A<@00L91P0B514030h;00lA3P0<3P/04A<@01HH
5@0D5Q<03Q0=010B3`0?4@h05QPE00840@0:30T04Q@A00X<2@0?4@h05ADC018B400E5A<01PH401HF
500<30X02`/900l?3@0=3@/02PX800d=2`0>3P`030`:00h>300?3`d030`:00802PX801X04Q8@00h>
300=3@/03Ph<010@3P0?3`d03`l?014A4@0>3Ph03@d=010@3`0<30X04a<A01TI5P0I6QD05AHA014B
300@4@/04A4?00h>300;2`T030`:00d=2`0<30X0410>00h>308030`:00X03Ph<010@3P0?40/04A8=
0083000D5A00TY>>02LX8`0C50l03a0;0P0@4@`0200A4Pd05AHA00`=200<3@P071dH07IgLP0D5A00
3a0;0P0A4Pd06`0=3PT03Pl:010A300=3PT04a@>00X;1@0C50h03@h8010A2`0D5@l03Pl900X;1@0;
30H0414;014B300@4@/03@h9014B3@0?40/02``700h?2P0C50l0@d@o01HG4P0?40/04Q<>010A3002
014C3P0C00h@2`0=3`X03@l:00/=200?4@`05ALB01<E400<3PT03a4<01<E400C50l02``7018C3P0<
3@P0414<01TJ5@0:2`H04Q<>01DF4@0200h?2P0>018C3P0E5a<03@l<00`>2`0E5a@01`T6010B3`1l
OW/061XG00H81@0?4@h06A/H014C400A4Pd3010A300D014B3@0C50l04Q<>00`=200R8ah071dH00`=
200A4Pd03Pl:01LH4`0B4`h020T4014B3@0F5a802``701LH4`0=3PT05aPC01DF4@0A4Pd2018C3P06
014B3@0@4@`04A8=018C3P0<3@P03a0;0P0>3`X0100B4`h04A8=018B400@40h300d=2`0e00`<2P0=
3@/03`l=00l?3@0F5Q@03Ph<00l?3@0?40/0414<00X;1P0;30L04Q<>00h?2P0:2PP05QHE00h>3P0G
5aL03@d>010@400A3@`04a0?01@C4@0E518051@B018B400<30X0414?014C400?4@`03Q4<014C400B
4Q8040h?00l?3`0C4a<04Q@C010B4@0I6aX06QhM00hB4@0<40l03A4@01HJ6@0<3P/04A<@01DG500<
3P/04aDB01DG500A4a0030h;01DG500C5A800P0;3@X02P0B5a403a@>01DJ500E6Q@04AH@01DJ500@
5@l04AH@018G4@0E6Q@201HK5@0U01@F4@0@4Pl05QPC01LI500E5a806adI01@F4`0M7a`05QPE02<U
8P0B514061dI00P>2P0K8Ad05adI01TO6`0;4@d05A/G01HL600O9B40728N01HL600J81`0728N01DK
5`0K8Ad05ahJ018K5P0I8Qd04adH01hY8`0mB48082`V01<P6@064``06BHN01HS6P0201PU7P0>01LT
7@0G8al072PT01l[9`0N:RP06bLU01LS8@0C7al0>DM702lm?@0L:RX05R@T01XX:00O;Bd601d[:`80
82h^01h07bd]01d];00O;bh0:3Ti01X/;P0Q<cD07S8c01`_<`0T=c/093Ll014U;00gBe@08SHo02Xn
A`0R=Sl09CU0024f>`0S>3d09S]002Pm@00V>ch093Tl02i2@`0U>3/08cHj02Hi?@0]@4@0>4]?02/n
@P0_@TH202Pk?`030395B00cAdP0:T0n0080:T0m0100:d4n02e3@00^A480;TA202m4A00aATL0<TM8
03A9B`0eBTd0<DI903Y?DP0lDE@0>DiA03]@D`14FE`0?55D0P10EEP0D`0hCE00>e1C03U>D@0lE5@0
>4e>03iCE00aAdD0:Cdl03U=C00gBdT0>Da803Q;A`0gBTH0>4]703Y=B@0gB480;Chh02`m=`0jBdD0
93D]02Xk<`0b@c/0<44g02m0=P0^?cD0;T0d02do<`0[?3@0;Slg03=4?00^?cL0:c`d0350>@0eA3d0
Ohb5034n=`0d?cT0=T4k03A0?00a@3h08S4^03=0?P0lB4H0A4i?045<C`0iATh0Df1`03M5G00lBfX0
Ff^=04iQO`1:GWL0@5A/03]@I00P=T@0<dID03eAF`0kCeH0=dYA03A7CP0_@TT0<45903Q7C00c@D80
>TQ902Pf=`0Q;c00:CLh02hl?@0[>CX0;S`m02lm?P0/>S/0:cTj02dk?@0^?D00<T130390@P0Y=cP0
;3Li024];@0R;Rh092h_00808b`[01<09Bh]02Td<00H8al08RdY01hW900j@d005AhK01hT8P0S:BL0
9BTX01lS8P0Q9B@08bLV01hR8@0S9bH09BTX01`P7`0K7ah09b/Z00807B4P00L07R8Q01/O7P0H71/0
5a/J01PJ5`0I6aH06adH00806adJ01P06Q`I01HH5`0K7Ad06Q/M01/L7P0N7b406a`N01@H5`0K7Qd0
6A/J01/M700L7A/04Q8@01PH5P0J6QL06aXF01XI5@0G5A004Q4=01TH5P0C4a<06QXJ00`<300E5AD2
01@D500701DE5@0H61P05QHF01<C4`0G5aD04Q8@01<C400201<C4@0/01<C4P0B4Q804a<C01@D5@0I
6A/06a/M01<B5`0<30h04A4B018B4P0D51@06QXJ00P8200@41004Q8B00h>3P0?3`l04Q8B00l?3`0=
3@d04Q8B01HF5P0E5AD0G5aL03Ti>@0B4Q803@d>010@400A4A403`l?00`<300:2PX05aDF00/92P0=
2``03P`?01DC5P0?3A00518G00D3200D4QL07AXQ00/83`0@3Q8500d;300@010>3`0200402`T:018@
4@0A3a00518C00L41P0J5AT071LK010<3`0910P030L;01<>4P0@2`l03`X>00h93@8030L;00X03`X>
018=4@0L5a/0@ci200L21P0:1@T04@`@010;3`0:1@T03@P<0P0;1PX04P0F41@04`dA014;3`0>20`0
3@L;00`62P0:10P04P`@01D?4`090`L0?SPl03li?@0>20`040X>01@>4P0@2Ph04`dA00X4208030H:
00X03PP<00l93@0?2@d03`T=01@B5`0;2@h03`dB010;4@0F4AL030L=0`0>1`h301063PH03`@:00H0
2P0501052`0>0`T0304700l42P0=0PP:00h32@0301052`0A1Pcooooo01?ooooo000Kooooo`07018D
3`0@4Pd03@l:00/=200=3`X04A<>010B3@03014C3P0900lA300=3`X03a4<018D3`0A4`h03Q0;00lA
300D5Q4030h900803@l:00D030h900h@2`0@4Pd04A8=010A300200l@2`803Pl:100@4@`01P0>3`X0
3@h901DF4@0K71L051D@00l@2`804A8=00h08b@O038c;P0I6QD030d8010A300720<0414<00`=200C
50l03a0;00d?2P0>40/02`d8010E3`803A8<01d02@h900dA300>40d03@l<010B3`0B51404A<@00`>
2`0?4@h05aTF01HH5@0?4@h030h;00lA3P0=3``03a4>01DG500@4Pl03a4>01lQ7P0F61D07AlL010B
3`0B51401`T6010B3`0>40d03@l<010B3`0200d?300T010B3`0=3``030h;010B3`0H6QL010H4018D
4@0620D0418?01<E4P0A4a0030h;00h@3@0D5Q<05ALD00lA3P0:30T03@l<00/=2P0=3``03a4>00d?
300<3P/03@l<00D7100F61D030d;00T;200?4@h03@l<00d=2`0>3P`03`l=00d=2`0;2`T03`l=0P0A
4@l0100?3`d03@d;010@3P0A4@l300l?3@0500h>300=3@/03@d;00`<2P0>3P`00`0?3`d03P0>3P`0
2`/;01`L700G5aL03@d=00/;2P0=3@/04A4?01lO701hNG@04Q<>010A2`0>3`T03Ph<0P0=3@/02@0<
30X03Ph<010@3P0=3@/03`l=00X:200;2`T0410>00h>300200`=200401@E400720<0824L014B3@80
3@h901@03Pl:00l@2`0?40/0414<00h?2P0<3@P03a0;01<D3`0>3`X02@X500h?2P0=3PT030d800h?
2P0A4Pd04Q<>00`=1`0=3PP03Pl9010A2`804A8<00h04Q<=014B300?40X030d700d>200?40X04A8=
00/<1`0D5A003@h900T:1@0=3PT03a0;010A30<04A8=00H04Q<>018D3`0B50l04A<>010B3@0?4@`2
00`>2@0300h@2`0@4Pd03a4<0080418=0P0>3`X01P0A4Pd04a@?018C3P0B4`h04A8=010A30<03Pl:
01l03a4=01/M6P092`P030h;01<E4P072@H05aTF01@F4`0<3P/04A<@00lA3P0T9R<04a@?014B3@0?
40/03@h900h?2P0@4@`04A8=01PI500];RT0414<00l@2`0D5A005QLB00d>2@0?40/04a@?00h?2P0B
4`h030d800804A8=00l0414<018C3P0>3`X03Pl:014B3@0@4@`03a0;018C3P0A4Pd0414<01@E400C
50l03@h9010A300B4`h00P0>3P`200l?3@80410>00`04A4?00X:200>3P`04Q8@010@3P0=3@X03@h9
018C3@0>3`T03@h9010@3@0=3@/2010@40804A4A0280410@00h>3@0G4a404@l;018A3@0G5Q@05QDC
00h>300C4a405aPE0001000K7AX03A4=01DI5@0>3Ph051@D00l?3`0C51<05QPG010B4@0<40l05ATH
00lC4P0A5aD02a4?00dB400@4a003a4>018D4@0A4a004Q@A01LI5P0E5a@03Q0=0P0D5Q<01@0J71T0
4aDB014F400J7aT06AhH00804aPB01<05Q/E01<H4P0F6aD04AH@018G4@0H7AL061dH01PK6@0@4Q40
61/I01@G500T9R<061XG01dP7@0K7AX061/G01PL600H6QL051TE00805adI03/05A/G01dS7`0S:BD0
8BLS010F4P0O9B406AlK01dS7`0G7AT06AlK01PN6P0I7a/0620K01HO6P0D7AP04adH01/V800E81X0
5b<M01<P6@0B7aP08BhV01XW7P0G91d062DN01XW800H92005b<O01HR7P0I9B<0CUYH020/:P0K9bL0
9S@e01`Z:`0F92D06RPY01TW:00H9RL06BLX01PV9`0G9BH06BLX01`Z:`0P;Rl06BTX01h^;@0M;B`0
7Rh]02<d<`0O<C408C@e02@h>@0N<S<07c@g01/`<`0N<cL09c]2028f?`0202@h@@0>01da>P0W>d80
734f02@i?P0X?D80:d1302Hk?P0S>3/09cXn02Pl?P0Y?Ch0:cm002i2@`0Z?Sh302Tm?P0602m3A00d
B4X0;D5202Y0?P0X?S/0;48o0P0aAdD0=00Z@3h0;45203I;C@0iCU40=T]>03Q=D00kD5<0=T]>03U>
D@0mDUD0=DY=03]@D`1KL7<0DVMZ03Y?DP0hCE00?E9E03U>D@0lDE@0>U9B03Y?D010EEH0=de;0355
A00fBTT0>4a:03a?B`10Ddl0=dY603Q;A`0aA400=TM103Q9@`0dACl0;Chh02m0>00b@c/0=4Dm03E6
?00fAcd0=dPn03M9?@0fB3`0;d<j02dn=P0cA3`0<D0i02Pf;`0X=Bh0<3df02/h<@0/>C8202/h<@0N
02dl=@0_@SX0<D8i03U8?`0hACd0=d@m03Y7A00c@D<0>4I?03m?H@1AHWX0GW2<05Q/R01<HG/0@eUa
03mDJ00kDEl0=TaI03M<EP0lD5P0?51G03E9D00cATd0=DMA03U8C@0kAdL0=T9202`h>00Z=SH0:cLg
0P0/>3P01P0]>CT0;c/k02hj>P0[=cL0:cHg02Xf>080;3Li00/092la028^;P0T;Rl09Bl_02<];00P
:BP08BXY02Tb;`0U<2`092l[01lZ9P0201XS800301dV8`0U:bT08BLU00<07b<R00@0:Bd/02@X9`0P
92<07R8Q0P0T:2L03P0N8R406QhM01`P7`0L81l06QhM01TM700L81l07b4N01hP7@0I6aP0828O01HH
5@0J71/07b0R0P0P8B<0400O82@07QlS01hO8@0J7Qh061/J01LI600H6QT06AXI01TI5`0H61H05aLD
02PW8`0N7AT05A<?01@C3`0H5aD201HF5P<05ADE00h092@T02TY:@0E5AD05QHF01DE5@0@40h04a<A
01HG4`0F5Q@051@B018B4@0D51@04a<C01<C50804Q8D00D04A0E014A4`0C4a@05QHF01DE5@02018B
4P0301<C4`0H61P020P800804Q8B00X061PH01DE5@0C4a@03`l@00`<300E5AD06ATH00`<2P0A4A00
410@0P0?3`l200h>3`0700l=3@0?3P`040l=010>3`0?3A003P`?00l=400400l=4P0300l=400>30d0
3P`=00<03P`=00L03`d>00d;300>30d03P`=00T7200<2P/04@h@008040/?00@03`X>00h93@0>2@d0
3`X>0P0A3105010;3`0501PC5`0Q72004@`@00X52@0?2Ph01@0>2@d0300<1`/03`T=01@>4P0?2@d0
30H:00l93@0A2`l01`85018<400C3A40618F01/F6@803PP<0P0=1`/03P0@2Ph04@/?00/62@0;1@T0
5Q4D04m9C@0?2Pd03PT=01HD6@0920d061HK030^<`0X9R/050lE0P0?2Q002`0?20l03@H=00d63@0>
1Ph03P<901873@0?10X04PL=00d4200M4QP040D;00803P<900<040D;0146300?10X01P0?10X01P0F
2a403P@900d4200D2@l02P0500h52ACooooo000Kooooo`0800d?2P0>40/03Q0;00`>2@0>40/04A<>
00`>2@0>40/2014C3P03010B3@0>40/02@/600804aD@00X03@l:010B3@0J71L030h900h@2`0=3`X0
30h900h@2`0@4Pd03Pl:0`0?40/2010A300@014B3@0;30L03@h901<D3`0?40/02@X5018C3P0I6QD0
4a@?00`=200>3`X04A8=00d>2@0F5a803a0;00h?2P8051D@01804A4?00T91`0@40h03`l=00T;200A
4a00418?00lD400320@02a0<00L=2@0B5Q<03Q0=00X<2@0<3P/04A<@00lA3P0>40d201<E4P0700lA
3P0;3@X030h;010B3`0>40d03a4>01<E4P02010B3`0b01/M6P0A4a005aTF01PJ5`0C5A802P`9014C
400=3``03Q0=014C400<3P/02P`900d?30051`@02@/801TK600U9b@03a4>01HH5@0H6QL05QPE034c
<00H6QL0418?01LI5P041P<01`T600T;200A4a002`d:00/=200=3`X03a4<00d?2P0<3PT03@l:00X<
1`0D5Q404Q@?00d?2P092`H02`d8014A3`0=3@/02`/9010@3P0C4a40410>00h>300?3`d2014A3`03
010@3P0?3`d03`l=00803`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0B00h>300@4100410@
00T92@0:2PX061PG024Q7`0A4@l02@T602d^:@061`803Pl900X;1@0A4@l02PX800T91`0>3P`04A4?
0P0=3@/04P0>3P`0410>00h>300=3@/051@B01DF4@0=3PT0:2TT01LH4`0;30L02P/600l@2`0=3PT0
30d800h?2P0?40/0414<00X;1P803a0;00L030d800/<1`0<3@P03a0;00h?2P0=3PT03Pl:00803a0;
00L030d700X;1@0:2`D03Pl901@E3`0F5a403@h80080414;00T03Pl900d>200=3PP04aD@010B3@0:
30L0418=00lA300:30L00P0@4Pd4014C3P0900lA300>40/03Q0;010B3@0A4`h0418=00lA300A4`h0
418=00803Q0;00H03a0;00`=200=3PT05AHA01TJ5@0D5A0200l@2`0:00h?2P0=3PT03Pl:00l@2`0D
5A4051TE00T>2P0?51004aPD00X?2`803A8>00@020d900`?300@5A405aXG0`0A4Pd3010A300N018C
3P0A4Pd051D@00@5000C50l04A8=01@E400=3PT051D@018C3P0H6A@06Q/F01LH4`0@4@`03@h9014B
3@0@4@`03Pl:00d>2@0A4Pd0414<014B3@0E5Q4051D@00d>2@0J6aH07b0K00l@2`0;30L04A8=0`0@
40h01@0A4@l04Q8@018B400W9bD05aLE00803Ph<02L03`l=01@E400>3`T05QL@00l@2P092PD03Ph=
01@D500;2`d04A4B014A4@0?3`l03`l>014A3`0A3@X040h:010?2`0B4@d051<@01@D4P0@40h0414?
01<E500?4A005QTH00/?3P0C4a<03a0@01<E500>40l041@C01/O7P0@51<04aTG00P>300220H0;cPe
02P^;00J7AX00P0E5a@04@0B51404A<@01DG500O8Ah03Q0=01LI5P0H6QL04A<@00h@3@0D6A<04AH@
01<H4P0H7AL051TC00lD3P0E6Q@061dG00805AXD00h05a`F01HK5`0<4A000PH700hD500O92<06QhM
018H5@0L8Qh01@X601XO6P0C6Q<05Q/E01<J508061hJ00<051XF01TO6`0N92000P0E6aL05P083PX0
:Bl[00dC3`0K8Ad07R@P01`R7P0H7QX061lK01XS7P0I8Qd05R0J01dX8P0I91h05R8K01HS700?71D0
5B8J01HS6P0F8a`062DN01LT7@0F8Qh201DQ7@0[05=OG@3@g=X0DEeK01DQ8@0T<S<07R`]01`Z:`0K
:BX062HW01/Y:P0X=SL08Bl`01PV9`0I9bP07B//028`<@0N;Rd06b/Z01d`;P0R=C<083<a01ha<@0I
;Bh06bl`01`a<P0W?3l083Dh02Ll@00cAdh07c<l01hb>`0aADh0:cm802Pl@`0dBDh0:Sm402Dj?`0g
C4l0;dA702Ll?`0Z?D40:3`n02Tm?P0202a0?`0I02/o?@0U>CP0:3`k02Xn?@0_@d@0<dI902/o@00[
@Cl0:Clm02e3@@0aAdD0<DM602a1@P0T>C`0<4E803eBE@0nDeP0=T]@0315B00jCe80=DY;03Y?D00h
CDh0<4E603E:B`0203I;C00;03eBD`0lDE80=T]<03eBD`0iDE40>e1A045FE`15FeT0CV9Q0396A@0/
@3h00P0cAT801@0Y?3P0=dY603]>BP0fAd40<T<m0080;d0j00h0<D8j03=4?00fAcl0<d@j0352>00b
@cT0=4Hj03E7>`0jCTD0?U9903m@B00`?cP09c@]02Xe;`80<3/e02<0<C`f02dj<`0]?3D0<d8k02`o
=00a@SP0>DXo03I6>`0e@SP0<T0i02Le=@0/>ch0?e5L05Y]OP1QMXT0DFIo05E]Q`1GKHD0@EM]03I=
G@0hCU`0>E1I03aCF`11EEh0@5AM03]?F00jCUL0Df=W04EAC`0[=cD0=40n02Da;`0O:bT0;c/i038n
?003030l>P0:02hj>00`>c`0;SPj02/e=`0Y<c@08bd^02D_<00Z=3<0:38a02D_;@<09C0/0P0T;b/0
2P0S;RX07bPU01hW900P:BH07bDS01hT8P0S9bH08RHU01hR8@0Q9B@4028V9@0C024U900P92<07R8Q
01hR8@0L81l05a/J01PL6`0O8b806b0L028W8`0H71/04QHE01/O7P0H71d08RHW01dQ8`0K7b807B4T
01lS9P0201`P8@0=01PK6P0E5aH05QPG01XK6@0K6aT061PF010?300I61@04A0<01<A300G5Q8051<A
01@D500201DE5@805aLG01<04a<C01dM7@0C4a<06QXJ01`L700K6aT04a<A01HG4`0F5Q@051@B01<C
4P0D51@04a<C01<C500C4aD04Q8D018A5P0B4Q@04Q8C0080410@01L04Q8B01<C4`0B4Q8051@D00h>
3P0E5AD0410@018B4P00000020P:01XJ700B4Q8030`;00`<2P0B4`h03Pl:00l?3@0?3`l03`l@010?
500@41803`d=00l>3002010?3@0300l=3P0>30d03`d@00803`d@0P0?3A800`0?3A003P`=00h<3@03
00h<3@<04@l@00D05A<D010>3`0<2P/03P/=010;3`0300l:3P0>00h93@0A31003@P<00X52@0?2Ph0
3@P<00/62P0?2Ph08ahR01D@50060PD04PdA00h93@0=20`500`72`0[00`62P0?2@d04P`@00l93@0=
1`/03`T=01H@500@2Ph02PD800T31`0;1@T040X>00d72`0?2@d04@/?00d72`0;1@T03`T=010:3P09
0`L0100200d72`0A2`l0510C01`J7`0000@0<S4f0<[9cP3Lfn00BTQ=018=4`0=20h02@@:00h73P0@
2A003@H=01052`0>0`T04@H<01X?5@0F2a40=BX`0146300200l42P8040D;00<03P<900l42P0?10X0
100?10X01P15>T0060lC00`11`0E2Q005``B01<83QCooooo000Kooooo`08010B3@0A4`h0418=00d?
2P0<3PT03Q0;00lA300>40/200`>2@803@l:00`02@/600lA300?4@`030h900h@2`0D5Q403@l:00lA
300>40/030h900h@2`0@4Pd200h?2P0>00l@2`0@4@`0414<014B3@0@4@`030d800h?2P0C50l03a0;
00/<1`0A4Pd04Q<>010A300>3`X200d>2@0L00h?2P0=3PT03Pl:00h?2P0A4Pd05AHA00`<2P0D5180
3`l=00`<2P072@H04A<@010B3`083@T02a0<014F4P0@5Q8041@@018D4@0<3P/03Q0=018D4@0@4Pl0
3Q0=014C400@4Pl03@l<00/=2P803@l<0P0:30T03`0<3P/02`d:00/=2P0>40d020X7000100041P@0
3a4>00`>2`0@4Pl02`d:00d?300A4a002`d:00P:1`0200`>2`0F01DG500?4@h0418?00D7100>40d0
3@l<00/=2P0L7Q/03a4>00d?302Z[:T0BTa900lA3P041P<01`T6010B3`0;3@P03@l:00lA300=3`X0
30h900d?2P<03Q0;00/03@l:00P:1@0;3@P03Ph<00d=2`0<30X04A4?01LG5@0E5A<04A4?00h>3002
00d=2`0300`<2P0@40h03`l=00803`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0300h>3008
20P030`<00803`l?00T02`/:00<30@0B4Q002@X600h?2P0;30L04A8<00d>200=3@/00P0<30X01@0=
3@/030`:00T91`0?3`d02`/90080410>00l03@d;018B400F5a8051D@02//9`0L7AP02P/600`=200@
4@`03@h900`=200=3PT03a0;010A300?40/00P0B4`h0100@4@`03a0;010A300@4@`200l@2`<03Pl:
00L03@h800/<1P0;30H03Pl9018C3@0D5@l030d700803a0:0P0>3`T00`0@4@/04A<>01`N6@0200X<
1`05014C3P0>40/051HA018D3`0A4`h00`0@4Pd0100>40/030h900/=200<3PT300lA300C014C3P0@
4Pd03Q0;00lA300A4`h03Pl:00/<1`0D5A006Q/F01DF4@0@4@`03Pl:00d>2@0<3@P03Pl:010A300E
5a<04aPD00lD400200hC3`0700dB3P0B5a<0KW=_01HK5`0I7QX04QLC00D91P02014B3@804Q<>0P0A
4Pd04@0;30L04A8=01<D3`0:2`H06AXE00`=2P0@4@`05QLB00/<1`0=3PT00@8000P9100>3`X03a0;
01HG4P0A4Pd02@X500803Pl:0P0A4Pd02P0?40/04a@?018C3P092PD05AHA01XK5P0<3@P02P/6014B
3@0?3`d2010@3P804A4?02@04Q8@03Hf=00S8b4051@B010@3P0?3`d051D@00`=1`0B4``03a0:00`<
2P0A4A004a<C00l?4@0E5AL051@D00h>3P0<30X0414<010=200B40/040l;00h=2@0A40d05QHD010@
3P0@4@l05ALF00L9200A51<00@D400d?3P0A4Q805QPG01@F5@0>4Q42010D4`0601TO7@0?5A<07B<Q
09ZSX02[/Jl0720L0P0F61D0400D5Q<04Q@A01DG500V:2D07b4N03i0?@0g>CH04aDB01@F4`0D6A<0
41D?018G4@0G71H04aPB00lD3P0D6A<401HK5@0V01DJ5P0H7Qd08RPX01`R8P0@5QH0318@01<I5`0R
:2@01P`801TO6P0H7aP072<L01@J5@0M8al06b4M018H500A5a<04QPD01<I5@0M8al05A/G01/Q7@0@
5Q809R`X01LM6@0I7a/05A/G01LO6P0L9B006b@O01HP6P0J9Al062<M01<O6@0I9Ql05B8K01DR6P0G
91/201@Q6P1801DR6`0G8al07b/W01dY9@0D81h0BeME018N700G8b<06bTZ01XX:@0L:R/06bTZ01TW
:00Q;c00;C/l02Hd=@0J:2T062HW01XX:@0I9bP07bl^01PX9`0L;bd08cHd01d`;P0L<2l062`]024e
=P0N<c@09CXm02Pm@00]@TH0SZ:Y03A8D@0[?dP07c<l028f?`0V>T40:Ci3014V:`0U>Sl08cPk07>8
R`16Feh0;T5502Xm@00[?d00;D5002a0?P0]@Cl09CTg02Xn?@0[?ch0;T9302m3A@0W>Sh0;45202]1
?`0^A480<DM50397A`0_A4D0Bf1S03U>D@0aATT0=DY?03I;D00eBTd0>Di?03I;C00lDE80?E9C0P0f
Bd`0BP0jCe00?55B049GF00mDU<0=DY;03U>C`0iDE40<dQ903Y?D024VYP0X[Je04YNG@0jCT`0;T4m
03I9A@0aA400<4<o02m2?P0gB480<44k02ho>@0`@C/0<d@l03A5?@0gB400=4Dk03=4>P0b@cT0<T@h
0355>@0fBd80C61G04AHC`0Z>C80:C@^03@o>@0^>C<0;3La030k=@0_?3D0;Sdf0352>P0Y?C@0;Chf
03A5>P0b@SL0<Sle0392>P0U=C809cTk03]=EP17FVT0Aea]04ELM01AJH<0Bf1k03iDJP17GVh0A5YX
03Y@G00kDUX0?U9K03mCG00iCEH0=d]D04aLH00mBDL0:CDc03A0?P0V<S008bl]038n?00c?cd0;c/i
0`0]>CL02@0_>ST0:C<e02@^<00S;Bl08R`]02H`<@0f@3l0;cTh02Ha;@0202D`;00<024/:00T;b/0
9C0/02@_:`0P:BH07RLT01lX9@0S:BL08BLU02DY:00S9bH07B4P0P0N8R401P0Q9B@092PW024U900P
92<08RHU01/O7P806AdL00`07b<R02<W9P0U:BP082DQ028W8`0E6AP04aLF01XN7@0P92D0:Bd^01lS
9@0I7B0201`P8`0301HJ7@0Q9BH07B0O00806Q`K00X06AXH01LG5@0I6AL04A0=01LF4P0A40`05aD@
01XI5@0D4a404a<C0P0D51@201DE5@0300h>3P0G5aL0410@00805aLG0P0E5A<0100F5Q<05QHD01DE
4`0D51<201<C4`0O01<C500C4aD04a<E01<B5`0B4Q@04Q8C010@400C4a<061PH01DE5@0B4Q8051@D
00h>3P0@41004A4A020P800F5QH071/P00/;3@030`<051@C00d>2@0;30L03Pl:00h>300?3`d0410B
010?500A4A<03`d=00l>3002010?3@0300l=3P0>30d03`d@00803`d@0P0?3A800`0?3@l03P`=00h<
3@0300h<3@<04@l@00@06ALH01@B4`0>30d03@X<1@0?2Ph200h93@0;00`72`0?2Ph06QDI01PC5`0=
20`07aXN01<>4P0810L05A0D00X52@0;1PX01P0<1`/02P0?2@d04@/?00l93@0>20`03`T=00`62P0A
2`l030H:01<=4@0A2`l200l93@0300d72`0>20`03PP<00802`D900T0618F00/52@0K5AT04`dA014;
3`0b;C40;R`a01PG701XIf`00P3oo_l0401LFUl04`hD010;4@0:1@/02P<:00`5300=1Pd06A0E0146
300>0`T04@H<00/21P0`9B/04`P>01052`0?10X201052`0300d2200?10X03`@:00@03`@:00<03@88
01052`0C20h00P0700800`0<0@Ooooooooooo`0Booooo`006oooool06@0;3@P03@l:00`>2@0;3@P0
30h900lA300I6aH051HA00`>2@0;3@P03@l:010B3@0C5A003Q0;00d?2P0?4@`0418=00d?2P0?4@`0
418=00lA300=3`X03Q0;010B3@0>3`X00P0?40/2010A300T014B3@0>3`X04A8=014B3@0@4@`03a0;
010A300B4`h02P/600d>2@0B4`h03@h900X;1P0>3`X02@X500h?2P0=3PT02``7010A300C4a40410>
00`<2P0?3`d04A<@00/=2P0=3``02@d:04A9A@0`=3404QPD00lC3`0B51403Q0=00d?300?4@h03Q0=
0P0<3P/01@0=3``03Q0=00h@3@0?4@h03Q0=00803@l<02T030h;00h@3@0?4@h03a4>00L91P0R9240
?T0m00`>2`0=3``03a4>00d?300?4@h04aDB00lA3P0<3P/07AlL018D4@0@4Pl02P`901@F4`0=3``0
4Q@A00/=2P0A4a001@L401DG500N81d08R@Q00D7100?4@h02P`900P:1`0A4a002`d800d?2P0?4@`0
3@l:00`>2@0=3`X0418=00T;1P0200/=200600`>2@0>40/030`:014A3`0>3P`02`/90P0A4@l01P0>
3P`03@d;01HF500J6QP04Q8@00h>30<03`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0D00h>
300>3Ph04a<C00d=3@051@D06QXI03lo?@0>3P`04Q8?00X;1P0D5A00414<00l@2P0;2`T05QHD01PH
5P0@40h02PX800/;2@0A4@l200h>300;010@3P0?3`d02PX800P9100B4`h051D@00l@2`0>3`X030d8
010A300?40/0100>3`X01P0?40/030d800d>2@0@4@`03Pl:00`=20<04A8=00/0414<00h?2P0=3PT0
3Pl900l@2P0@4@/03a0:00h?2@0=3PP03a0:00h?2@0200`=1`0;014B300D5@l04aD@02<U800B50l0
4A<?01LI500F61<061XE01@F4@0@4Pd00P0=3`X01P0A4`h04aD@014C3P0>40/03@l:00h@2`803@l:
00T03a4<010B3@0?4@`0418=01PI500G61<03a0;010A300B4`h00P0?40/04P0@4@`03Pl:00d>2@0@
4@`04a@?010C3P0@5A403a@@010E4@0?5100314=01DJ5P19CTX0724M01<G500?51004QLC010A3080
4A8=0P0B4`h03`0A4Pd061TD01PI500>3`X071dH02l`:`0H6A@05AHC051AC00I6QH05QLB018C3P0@
4@d03Pl:00d>2@0200`=200?00l@2`0C50l04A8=01@E400A4Pd03@h900h?2P0<3@P061TD01XK5P0F
5a80414<01<D3`0D5A003Ph<00803`l=0P0@40h0>00A4@l06ATG014A3`0?3`d03Ph<00d=2`0B4`h0
3Pl7014B2P0C50h061TE01/K6`0@41803`hC01DE5`0E5AD04A4A00l@3@0C50l04a0;01DC3P0B4@`0
3Pd900l?2`0C50l03Ph<014B400?4A006a`N03m2@`17Bd`03Q0?01<E500=3`h06QhM01lS8P0A5A@0
2Q0>01DK6@0>518041TF05eVH`1LHV004aLC00d?300A4a004aDB018D4@0C5A804Q@A01DG500L7Q/0
9RPU020R7`0B51404QLA0P0E6Q@2018G4@0801DJ500C61804QLA01DJ500G71H05AXD01HK5`0?5aL2
018J701P01DN7P0C71/05AhL01HO700=5Q40628K018L500K9Ad072@N01HL600H7QX05A/G01LM6@0H
7QX06AlK00lE4@0J81`05Q`H01LM6@0Q9b<05Q`H01PN6P0G7AT061lK01LP6`0E7QT05AlJ01LR700K
9R0062@N01h[900R;bP062DM01DR6@0J9b008BhW01TV7`0F8Qh05b<O01`X900G8b404AdK01dY9`0M
:BT06BLY01TW:P0K:B`06BLZ01HT9`0M:bh06BLZ01PV:@0I9bX072X]01d[;P0L:bd08c<b01/^;00N
<Bl08cHd01lb<00O<c809CXk03E:B`0W?3d07cLi02U1@`0W?d80@EEL051TK@0_@d`08cM00355CP0Z
?TD0:d1502Ll@@0Y?T<0;T=606MlO`13F5/0<dI<02/n@@0]@D40;T9102Xn?00^@ch0:Chi02i3?`0]
@Cl0;D5202a0@`0U>3`0;T=402i4@P0`AT@0<DI70P0cB4T02@11EUT0?U=G04=HG@10EEX0=daA03Q=
D00dBDT0=Ta:03Q>B`0203I<BP0503Y@C@0gCD/0=4Y703I<B@0iCdd00P0jD4h04@0kDe<0=DY;03M<
C@1JL6h0Jgmn0355A00fBTP0?e9>03M:AP0bAD40?E1<03E8A00jBdD0=4Do0352?00b@cd0=4Dm0080
=TLo0P0gB3h09`0eAS`0<D<g02i2=P0]@ST0=TY103A7?P0^?CH0;CPb02`g<@0[=2l09c8/02dh<P0b
?cP0<40h0312?00^@T00;3hl0392?P0c@Sd0=D@n03I5@00a@D40<495041CG01/PHl0JGnA04YQN@1=
IGl0AUih03aDJ@16GFd0Aei/049II00mDeh0>U5I03aBFP0fBU<0<dMB03M6B`0203I0?`0703<m?00[
=C@0;SPg03@n?@0_>CP0:cDd02Tc<P0202Xd<`0802/d=@0U;Bl082PZ02@/;P0X<380;CHe03Q1@00`
>CP202<^:P0:02D`;00R;BL08bhZ02@_:`0R;BT07RLT01`U8P0M9R<08bTW020V90808RHU00<082@S
02L[:P0S9bH00P0V:RT05`0O8b806alN01`P7`0L81l05a/J01XN7@0Y;B`0;C4`02@X9`0K7ah05a/J
01TM700/<2l07R8Q024U9P0V:Rd07b<V01/O8P0M82D07R4V01XN8@0H71d06ahM00807R0O00X06AXI
018B400G5aD04a8?01XI5@0F5A406QPD01HE4@0J6AL06ATI0P0H61P03@0G5aL05QHF01@D500J6QX0
5ADE01/K6`0H61P06ATG01LG5@0F5a<05QHD01LG5@0F5QD00P0C4a<0600C4a@04a<E01@D5P0D4aP0
51@F01@D5@0G5aL06QXJ01dM7@0G5aL04a<C00d=3@0I6AT061PH010@40092@T06ATJ018A5P0?3a40
5QHF00h>3@0>3`X05aPC00h?2P803`l=00X0410B010?500A4A<03`h;00l>2P0@3`/040l=00l=3P0>
30d03`d>100?3A000`0?3@l03P`=00h<3@0400h<3@0600X82@0<2P/04a4B010>3`0<2P/03@X<100?
2Ph03P0@2`l03`X>01TD600H4aL03`X>02@O8`0R7B403`X>010;3`0>2@d04`hB00l:3P0;1PX03`X>
1@0>2@d200l93@0[010:3P0?2@d03`T=00l93@0;1PT03PP<00l93@0>20`03@L;00h8300B31002P@8
00/52@0A2`l03PP<00l93@0=1`/04P`@02DO8`0910L020<604E0A00W9R/03PlC02`[<02:RHh0V9NL
02TW;0081P/04@lD01dH7P0E41H03@P>00X42P0=10T04@H<01@93`0A1``09a`R07EZL00C20h04@H<
01052`020146300300h32@0?10X03`@:00@03`@:00H040H;01D:400=10P040H;01D:400;0PHDoooo
o`006oooool200lA30803Q0;00D04Q@?01LI500F61<04aD@00lA300200h@2`0>00lA300A4`h03Q0;
00h@2`0?4@`04A<>00lA300@4Pd04A<>00lA300=3`X03Q0;010B3@0@4@`300l@2`@03Pl:01@03a0;
014B3@0@4@`03a0;010A300=3PT04A8=00l@2`0<3@P0414<01@E400B4`h051D@014B3@0=3PT03Pl:
014A3`0F5Q@0?clm00h>30802`d:00l04aDB01LL600P9B405AXF00@:1P0>4Ph0418?014C400>40d0
2`d:00`>2`0=3``02`d:00X<2@0<3P/00P0>40d03@0<3P/03@l<00`>2`082PL03@l<00lA3P0H6QL0
0`D20001000X:RL04A<@01LI5P0:30T00P092`P08`0>40d030h;00`>2`12A4409bTV00d?300B5140
1@L40001000<3P/02P`900/=2P072@H03@l<018D4@0;3@X03a4>01<E4P0B514051HC00H71@0;3@P0
3A0900lB2`0=40T030l800d@2@0;3PL03a8;01XM5P0<3`P03a8;014C3@0=3@/04A4?008030`:00P0
5ADC010@3P0>3P`030`:01PH5P0M7A/04Q8@00d=2`<03`l=00D03Ph<00d=2`0=3@/030`:00h>3003
00l?3@0M00h>300B4Q801`L700`<300C4a<03`l>00T91`0;2`T03a0<014B3@0>3`X030d8010A2`0=
3@/051@B01DE4`0?3`d03@d;010@3P0<30X06a/I014A3`0;2`T04A4?00X:200:2`H0414<00P9100<
3@P00P0@4@`01P0>3`X0414<010A300?40/030d800/<1`80414<00D03a0;00h?2P0?40/04A8=010A
3003014B3@0300l@2`0>3`X03Pl900<03Pl90P0?40X2014B300A010A2`0?40X04A8<01<D3P0>4@`0
00<000X?2@0W;2H08BHP00/@2P0C61803a@>00`A2`0:3`T02a0:00hB300A4`h00P0@4Pd0100?4@`0
3Q0;00`>2@0<3PT200h@2`8030h900<04a@?01DF4@0A4Pd00P0?40/200h?2P0C00l@2`0>3`X04Q<>
01XK5P0P8A`051PC010F4P073@T0:Bl[03Hl>00@5Q801`d900lE4@032@D04QPD020V8P093@X03a4<
00l@2`0200h?2P05010A300B4`h05QLB02PY900K71L00P0=3PT02`0F5a80004002`]:00>3`/02``7
01@E400E5Q404A8=024R7@0M7QT02@X5008030d800`05QLB01PI500E5Q404A8=01<D3`0@4@`04a@?
01@E400@4@`03Pl:014B3@0=3PT3010@3P0A014A3`0B4Q004Q8@01DE4`0C4a405ADC01<C4@0<30X0
3@h9010B1`0B50X04a@>01LH4`0H61T03`hC00h=4P0@3a<00P0A4A40@@0@4@d0414;018?2P0D4P`0
51<>01<B3@0B4Pd04Q<>00`<2P0B4a4030h=010A4`0H6ad00`L8014C4P0>40l02P`;01@H5`0J7Qd0
51PG01@J600Y<Rl09Bh[01LP7@0?61D02a4?014E4@0>40d05ALD01TK600F61D05ALD01dO700K7AX0
3@l<010B3`0Q8b004Q@A018G4@0E6Q@04aPB010E3`0B5a405AXD01XO6@0C61805AXD01HK5@0C6180
51XF01XS9@1aNgd0IW1a00hH6@094a805R4N010K5`0b?CL051lH01`W7`0F8AT04a/E01HL600H7QX0
51XF00804aTE01X03Q@@03@j=P0<4Ph05adI01PN6P0F71P0728N01TO6`0K8Ad05ahJ01DN6@0I8Qd0
6R@O00hI4`0J9Al06bLQ01<P6@0I9Ql05R<K01PU700P;BH0:SL`01dZ8`0I9B407BTU02@`;0806RHT
02/072PV01/W9`0L:Rd06BLZ01XX:`0I9bX05B<V01LU:00M:bh08S0c02Dc=P0P;S4072X]01d/;@0P
<3007c8`01/^;00J;R`07c<a01lc<P0Q=SL0:3dn02Ll?@0[@dD0:D5302]3AP2;WjH0i_[o05IZL`0R
=Sl07S8k028f?@0[@4D0<dQ=02Ll@@0gC4l09CXm02i3AP0bAD/09STm02Tm?00Z?Sd093Te0080:Slh
00L0;d=002a0?P0/@440;T5502Xm@@0_A4D0<4E50080<DI702L0=4U;03I;CP2hcM00HgQl02]0A@0]
@TL0>DiC045FF@0fC4X0=Te803A;A@0bB4D0=4Y603A;A@0nE540>U1<03E<AP0fC4T0=di903I<B@0c
BdX0>Di?04=HF@0eBdT0>De<04IJF@1cQhD083<_03A7@`17FUH0=dY602i1?@0lCDL0>da603Q9@`0c
A3h0=4Dm03M8@00eASh00`0dAC/09P0bA3P0;d<g0398?P0^@ST0;Slg03I4?@0d?cT0:S<^02/b;P0`
>cD0=D0j0390>@0dACd0>Te90354B@0`@TH0=TI903I6AP0iAdL0>dY:02`k?P0gB4l0AeYV03eBH`1;
HGH0DFR104YRO01>IX00A5eb03]EIP10EfL0AEeX03aDGP0kDUX0@UQQ03U=F00dB5<0=TE:0P0e?ch0
1@0_>CP0:38a02Xd<`0_>CP0;3He0080:C<b0P0Z=3<02@0Y<S<092T/024V:@0Z;c80;C8e02`e=00[
=340:34^02<^:P0202@_:@0=024/9P0P:bL082/W01hY9@0L9B807BHS024Z9`0Y;bd09B/Y02DY:00P
92<0720O01lS8P0202DY:00702<W9P0M8B006QhM01LK6P0I7A`05a/J01TM700201hR8@0701TM700I
7ad05Q`J01LM6`0]<c<09R`/01LM7@0301HK7P0801HK7`0G72005a`O01HJ6`0I71/07R0O020R8@0M
7Q`201LG5@0601@D4@0K6QH05aHB01`J5@0A40`05QDC100E5AD09P0D51@06a/K01/K6`0C4a<05aLG
010@400D518061PF01HF4`0F5Q@061PF01LG5P0B4Q804a<C01<C500D51H05ADG01DD6@0E5AL05ADF
01LG5`0F5QH05ADE01@D500E5AD061PH00l?3`0000003`l?02h^;P25QHL0MGAi00D51`0@41005ADD
01TJ5@072080414<0P0?3`d02@0?3a403PdB00h=4P0?3P/03`h:010?2`0@3`d03`h<00h=2`0300l=
3P803`d@00<03`d?00h<3@0>30d00`0>30d01`0?3@h030X;00d;300>30d02PP900/92P0?2`h00P0>
2@d0400?2Ph040/?010;3`0@2`l04@`@010;3`0=20`03`X>00h93@0@2`l01P45014<400?2Ph01P45
01<>4P0?2Ph500d830803`T=00`03PP<00l93@0?2@d03`T=00P21P0:10P0:bDY01lI7@0H4QH02@<7
00l93@0;1@T2010:3P0K00`62P0K5AT03PP<00h8300910L03@L;01LA5@0D3Q8051<H00P93@010PH0
3`hC01LF6`0920d01@<800d;400I51X05A0F00h93`0;1@/05PdB01873@0<0PL05P/A00X11@0=0PP0
4@H<008040D;00<04PL=01<83P0@1@/01P0?10X01P070080EDY@02dR:00E2Q00200301H;4ACooooo
000Kooooo`0J014C3P0?4@`030h900X<1`0=3`X04Q@?00d?2P0>40/03a4<00h@2`0<3PP02P`700T;
1P0<3PT03@l:00/=200>40/04Q@?010B3@0A4`h03a4<00d?2P0>40/0418=014B3@0@4@`200l@2`0;
00h?2P0=3PT03a0;00X;1P0=3PT051D@014B3@0<3@P03Pl:018C3P0D5@l00P0;30L01@0E5Q002@X4
00d>2@0?40X04Q<=00804Q<>01<03Ph;03@d<P1lO7X04Q8@00L91P0J71T0;S0]09^PW01DFED06QlK
00<8100>4@h04A<@01DG500A4a0030h;00h@3@0A4a003@l<00802P`903h030h;00d?300=3``0418?
00lA3P0;3@X0418?018D4@0:30T08R@Q010B3`0>40h01`T601<E4P0>40d02`d:00`>2`0@4Pl03a4>
014C400B51402@/801DG50072@H0;S0]02T[:00620D04A<@00/=2P0J71T02`d:00T;2@0@4Pl030h;
00P:1`0?4@h01`T600h@300;3@P03A0900lB2`0=40T030l800d@2@072P<05QTB02LZ8`0?4P/041<<
018D3P0>3P`03`l=00X:200C4a408B4O01PH5P0E5A<030`:00h>300A4@l02PX8014A3`<03`l=00D0
3Ph<00d=2`0=3@/030`:00h>300300l?3@0300h>300A4A403@d=00804A4A02P03@d<018B400=3@/0
2``801<D3`092PD030d801<D3`0=3PT03@d;00`<2P0;2`T03@d;010@3P0820H092@R01@D4P071`D0
4A4?00d=2`0>3`X03@h900H70P0>3`X02P/600l@2`0=3PT0414<018C3P0@4@`02``700T:1@0<3@P0
4Q<>00l@2`082@@030d8018C3P0?40/04A8=0P0B4`h200l@2`0700h?2@0;30H02``600d>200A4P`0
4a@>010A2`0201<D3P0;014B300@4@/041<<00hA300A5Q005a`F018G4@0?50h0314;010E3`0=4P`0
0P0;40X0100=4P`0310:00/=200<3PT200d?2P8030h900<03Q0;00lA300=3`X00P092`H0100;30L0
30d800h?2P0@4@`201<D3`0f01DF4@0C50l0414<00`=200=3PT0414<00dA300D6AD01P/703m4@01E
FUH061dI00X?2`0B5a<03Q<?00`A3@042@D04QLC00lA3P0?40/03@d:00d=2`0?40/04Q<>00d>2@0J
6aH03@h:00l@2`0>3`X03@h901<D3`0:2`H04A4>010A30041@00414<01DF4@10@C`0BDY401DF4@08
2@<030d700h?2P0A4Pd03a0;00`=200>3`X030d800X;1P0?40/04Q<>010A300B4`h0414<0P0A4@l2
018B40804a<A054051@B01DE4`0I6AL061PF01<C4@0D5A003Pl901<D3@0?40/03Ph<010@4@0>3Q00
4A4C00l?400>3Ph03`l=00d>20092P@03`h9014@300C50l05QDA01DF4@0C50l0410>010A3P0?4@h0
4Q@C02X];00H71/03@l>00X<2`0B51<03A4@00H:2@0830/041HD02dc<@0K924020l=00@:200N9280
3Q4>00`>2`0C5A8061XG018D4@0@4Pl03@l<00h@3@0M7a`03Q0=00lA3P0D5Q<04QLA01<H4P0B5a40
4AH@018G4@0D6A<082DO01DJ500G71H05AXD014F400C6AD04ATJ059JG01>EUP03aPG01HO7P0?6QH0
AU5=09ZUW`0R;BH051lG018M5@0=5@l05adI01/Q7@0I7a/00P0K8Ad05`0N9200Q8f8024W8`0D7AP0
5QlJ014J5@0E71P05adI01XP700F7aX0624L02</9`0S;RP04A`F020[9@0R;bP041dF01DR6`0E8QX0
524H01HS700K:2404QlH00805B4M02/0:3@`01DQ7`0M:BL04AdK020/:`0L9bT05bDV01TW:00K:BX0
62HW01XX:P0G9BP07B/^024_<P0J:2/05R@W01`Z;@0S=CD09STg01la<@0L<2l09CTh02@h>00V>c`0
8CHi02U0@P0dC4h08CTk02@l@011EU/0RinV03Q<D`0Z?TD08cLn02a0A`0Z?d@083Dj02Tn@`0N<cP0
8cPm02Tn@`0`@dL08cLi00809c/j00@08CHb02Pm>00X?CP0;D<o0P0[@Cl00`0_A4H0;T=602m4A`03
0356B@0k03A9C00gC4l0H7Ej04=HG@0lDEH0?U=H0397C00]@TD0>U1>03Q?BP0gCTP0>Dm<03YAC00e
C4H0=4Y703M>B@0dBdD0<dU603M=B@0iCd`0@5UG03E:B`0gC4d0>4i<0355A00bATD0@5AB03Q<BP0j
CdX0<4A003E8AP0hBdL0>Te803e@BP0iC4H0<d@n03A5?`0hBD40=DHn0393>`0`@CL0<D8h0393>@0c
A3X0<4Dl03Q<@`0a@SX0:SP`02hi<`0_>S80:S@_03U4?P0kB440<3li03M8@P15EE@0;d560311B00h
Ad/00P0fATH0:P0gB4T0=4M;03U=EP0oEF@0DVQm05eeS@1>IX80AEak04MON`1;Hg`0@U]_045HJ012
FFD0>E9I03YAF@16Ff<0?51I03E9DP0kBTh0<Cdk02Tc<P0Z=C<08bl]02D_;P0/=cH0:cLe02Xd<`0[
=S@0;3Pf02`f=@0Y<S<082PZ01hV:00W;c40:C4c02H_;P0W<2l09c0]02Ha;P0U<2`08RdY01/V8P80
7RTU00l07BPT01`U8P0O:2D09Rl/01lU8`0N92808BLU028V9@0N92808RLU020T8`0N92807b<R01hR
8@0M8B000P0K7ah0C`0M8B007b<R01dQ800M8B008BDT02<W9P0M8b4041DD01hR8@0Y;bd05a`L01TM
7P0K82406R0P01PL7`0F6Qd05a/L01DI6P0F6AP05aTH01PJ6@0E5QD04A4?01XJ600G5aD06a`G01PG
5@0M71P04a8>01HG4P0G5aD061PF01TI6@0J6QX06QXL01PH6P0G5aT04a<C01TI6@0E5AD071`J01PH
5P0F5Q<05QHD01PH5P0G5aH04Q8B01<C4`0C4a@051@F01DE5`0E51T05ADG01DE5P0D51@04A4A00d=
3@0A4A405QHF00h>3P0J6QX03`l?010@40092@T0IfMW03`l?P0820X0:BTY00l?3@0D5A002``7014B
3@0@40h03`l?00l?4@0>3A803@`A00l=300?3P`00P0@3`d00`0?3P`03Pd;00l=3P0200l=3P803`d@
00<03`d?00h<3@0>30d00`0>30d01`0B4140518C01<A4P0@3Pl02PP900h<3@0B3Q400P0>2@d01`0?
2Ph040/?010;3`0C3Q8030L;00d8300F4AD00P080`L01`0C3Q80100301LB5P0=20`01@0401HA5@0:
1@T01@0<1`/200l93@0^00h8300?2@d040X>010:3P0B3100100201/E6@0400802P@8010:3P0=1`/0
3PP<01H@500?2@d02P@802<M8@0>20`04@/?00`62P0=1`/02@<700d72`040PD01`L900l?4P0A3a@0
40hA014?4`0;2@h02`H:00P320060@L02@@8010:3`0<0`P040L<00h42P0E2Q003P@901893P0A1P`0
3`D:00l62`0B1`d04`T>014630L03`@:00D0@cPn00L00P0?10X05@X@01052`0Dooooo`006oooool0
1P0C5A803a4>00h@3@0A4a004Q@@010B3@<03A0900D03Q4900lB2P0@4`/03A0900hA2P02010C3005
00hA2P0=40T030l800d@2@0>4@X00`0?4P/0300?4@`02`d800`>2@0?4@`02`d801DG4P0@4Pd02P`8
010B3@0?4@`030h900h@2P803a8:01`03a8900lB2P0>4@T03A0700d@200A50`03a8900hA2@0A50`0
4QD=010B3@0B50l04A<>00lA300@4Pd04Q@?04a>B@3=c/X0K6iY01<E400A4`h0418=014C3P072@@0
51HA00l@3@0E5a8030h:0P0=3`X0100?4@`0418=00d?2P0<3PX500d?300500lA3P0@4Pl03a4>00lA
3P0>40d00P0?4@h00`0>40d03@l<00d?300200`>2`0<00h@3@0:30T02P`901<E4P0B51403@l<00X<
20082PD0418=00d?2P0;3@P03Q0;0P0@4Pd02`0?4@`03Q0;00lA300@4Pd03@h901DF4@0?40/02@X5
02<T7`0C50l03Pl:00<03a0;00h03Pl:00d>2@0;2`T03`l=00`<2P0:2PP03`l=00h>300;2`T051@B
010@3P0D51803Ph<00d=2`H03@l<02P0418?00d?300;3@X02`d:00d?300@4Pl03`l=00d=2`0>3P`0
410>00l?3@0<30X03Ph<00`<2`0A4@l02@T7014A3`0F5a<06A/F010B3@0:30L03Pl:010A300=3PT0
3`h:010?2`0G5Q801`@1034^:`0C4Ph03Ph900l@2`0=3PT02``700`=200@4@`04A8=010A300?40/0
3Pl:0P0<3@P02@0J71L03a4<014C3P0<3PT03Q0;00/=200>40/0418=00lA300200/=200300d?2P0>
40/03a4<00803a4<01403Q0;00d?2P0<3PT03Q0;00lA300A4`h04Q@?01<E400D5Q404Q@?010B3@0>
40/030h900/=200>40/03@l:00`>2@0200d?2P0600lA3@0;3@X051HC00`>300<3P/03Q0=0P0<3P/0
400?4@h0418?00d?300<3P/02`d:01DG500A4a003Q0=00`>2`0:30T03Q0=014C400C5A803@l<00h@
3@0?4@h200h?300@00l@3@0?40h0414>010A3P0@4@l03a0>010A3P0A4Q00414?018C400D5Q@0418@
00h@3`0E5aH06A/I01LI5P803a4>00D03a4<00`>2P0A4`h03Q4;00`>2`02010B400;00lA3P0A4a00
2`d8018E3P0G6Q<04aH=00X=1@0=40L03Q4800lB2`0>40/00P0=3`X02`0>40/0418=00T;1P0I6aH0
3@l:00P:1@0Q8ah0<cD`01@F4`0B5140418?00@03a4>00P03@l<01<E4P0;3@X030h;014C4@0@4Q80
418C010B4P80418A02H0418@00lA3@0=40/03A0:010B300A50d0418<00h?3@0D51D051HF018C4P0@
4Q004A<@00/=200>4@/051H@00lA2`0Q8ad03Q4;01<H500R9RD05ATH00`@3`0C5aH051PG010D4`0J
7Qd05a`J00hC4P0E6AP03Q8A018G4`0?51003Q<?01@I5@0>4`l04AHB01<H50803A8>00P05a`H01DJ
5P0=4Ph051TE018G4`0A5Q804aPD01DJ5P805Q/G03/05AXF01@I5@0D6AD05Q/G01PM6@0D6AH061hK
01TN6`0H7AX051XG01LO6P0Q:RD0JG9]028[9P0D7aT0<chh010I500I7a/05A/G018J5@0@6A@05AhI
024Z9@0W<R`0628M01DQ6P0?6aD082`V01HQ6`0C71L05AhI01LP6`0A71H07bXT02Xe;`0H9Ah072XS
01PW800=71D062LP01PV7@0F8QP06RDM01PS6`0I91`07RTS01/V800I91h06RDQ01TT800J9B407BPU
01dY9`0J9RD07b/Z01XV9@0S;bh07BTY01lZ;002020[;@8082/_01X07b`_01d_<@0I;Bd09SXk03]>
D@0Z?T0083Dh02Y0A010F5`09ci302M0A00Z@dP093e102<h>P0V?3/0;45302]0A00Y?T80:Sm402a0
A`0Z?TD0:3a402Lk@`0Y?DH0;41702@g>`80:3`k02@0:Cdl02Ll>P0^A4808cXg02]3@00`BDH0;dU6
02i7A@0]ATL0<dY@03A:E00dBe@0=TeD03YAE`0lE5T0>e9H03M>D`0eCE40>51D03YBEP0iDE<0?EED
03M@C@0dCDX0=e1=03YCD00iDTl0=Tm<03UBC`0fCd`0=e1=03eFD`0lEE80?UAB03]AC`0jD4h303U?
C@1305M]J`0hCT`0;48o03Y@CP0_A4<0=4U703Q=BP0dBD@0=T]603=7@P0`@cd0=4M103A7@00dACd0
<D8j02`m=00`@3H0<d@j03i@B014ED/0<D8h02/l<@0a@SL0:c`a03M8?@0hB440<T8j03I6@P0b@T00
;Shm02lk?P0c@D80=4=20354@@0dB4@0=di;03YBEP0lEUl0@5a]04AQNP1:IX<0EW2D06N0Y`1BJY00
DV^:04=KL`0nE6T0Aei[04iUK00nDeP0A5QL03Y=D00_@d@0=4E302`k=P0^?3L0;C/f02He<00^>cT0
=D=002dl>@0/>CT0:cPh02Tg=`0d@D40=D9202Hc<`0202@a<@0<02Ld=00W<S<0:38c02li>@0V<300
92d]02H^;`0S;2`08BXW01hW8P0L9B007BHQ0P0N9b802@0/=C007bPS01`U800P9b<07RLR01lX8`0S
:RP07RLT028Z9`02024W9@0G01TO7@0G6aX07B4P024S8P0O8B00828Q01lQ800L7Q/06QhJ01dP7@0I
6aP06A`I01lR800M7ad071lM01hQ7`0M7ad061/I01dO7@0M7ah071hM01PJ6@0C5A@00P0E5aH0>00H
6QT06adL01DG5@0E5QD06AXI01DG4`0G6Q4061/B01@F400D5Q<05aTJ018C5`0L7B805aPL01@E600G
61X071hN01dO700P8Ad07AdJ00h>300E5A<05ADD030`<00N7Qh06ATJ01HF600G5aT05A@I01<C5@0B
4Q<04A4A01<C4`0E5AD04a<C010@400A4A40410@01<C4`0E5AD04a<C01<C4P0F5A804Q4?014@3P0B
4@l04@l?010>3P0O7Qh03@/=01HD5`0=2`h030X?018@500A41004@l@0P0@3Pl200l=3P03014?400?
3@h03P`=00803@/<00T030X<01@B5@0<2Pd04a4D00l=400;2@`0JVQ[06=QI00K6A`00P0;2@`0600:
20/03P/>014<400@2`l05Q4E00/62P0910P05a8F00d8300;1PX03`X>00d8300?2Ph04PdA00d8300<
1`/03@P<00h93@0=20`030L;00d8300?2Ph04@`@00l:3PL03@P<1P0<1`/02@0@2P`03PP:00d72@0?
2@/040X<00l92`0>20X030H800d72@0200l92`0900`6200?2P`01`<300d72@0@2Pd03`X<00l:2`0;
1PT030H8008030H900D030H800`62@0=1`/03@L;00d62P0200`52@0>00X4200?1``02`@8014;3`0G
41@02`D801XC5`0D2@d040L901052@0=0`H05P/?00`31@0@1@T400l4200301052Ooooooooooo01;o
oooo000Kooooo`0700lA3P0@4Pl03a4>00d?300>40`04A<>00d@2@0200hA2P0500hA200?4PT03a89
00d@2@0>4@X00P0?4P/00`0>4@X03A09010C3002010C30<04A@=00d03a4<00H80`072@@03a4<00T;
1P0@4Pd051HA02DW8P0=3`X030h9018D3`0;3PL03Q4900803a8900X03Q4800/>1@0:3@@051L>00`?
1P0@4`X020/300X=100G6Q403Q0;0P0?4@`05@0=3`X03Q0;00lA300@4Pd0=3Ha01PJ5@0D5Q40418=
00h@2`0H6QD05ALB00L9100:30L020X501`N6@0@4Pd030h9010B3@0D5Q40418=00`>2P0500d?30@0
3Q0=0P0=3``05@0;3@X03a4>01<E4P0>40d020X700/=2P0>40d02P`900`>2`0A4a003Q0=00d?300@
4Ph051HA00lA30072@@03@l:01@F4@0<3PT03@l:00lA3003010B3@0700l@2`0;30L06Q/F01hO6P0P
8A`0>CXe00h?2P0300l@2`0>00h?2P0=3PT04Q8@018B400<30X02@T700h>300A4@l0=SHd04U9A`0D
51802`/90000000G5aD<00d?300800`<2P0?3`d03`l=00h>300=3@/03Ph<018B400J6QP200d=2`0D
010@3`0A4@l05QPC010B3@0>40/0418=010A300<3@P03@h900l?2P0B4@d03PX701LC40071P8040l;
00d>2@0<3@P03@h900h?2P0=3PT600h?2P0501lQ700<3PT03Q0;014C3P0D5Q400P0<3PT01@0?4@`0
3Q0;00`>2@0;3@P030h900<03@l:01803a4<010B3@0A4`h03@l:00h@2`0?4@`04A<>018D3`0C5A00
418=00d?2P0;3@P02P`700/=200<3PT03Q0;00d?2P0<3PT200d?2P0I00T;1`0210403Q0=01`N6`08
2PL00`D200`>2`0L7Q/01`T600P91`0<3P/01@L401<E4P0B51404A<@01@F4`0C5A803@l<010B3`0B
51404aDB00h@3@0?4@h0418?00d>300200`<2P803@d;00X03Ph<014A3`0B4Q003`l=010@3P0A4@l0
3@d;014C4P092`X0418A0P0F61L05P0k?CX03Q0=01<E4P082PD02@/600`>2@0@4`d02P`900`>3@08
2PT020X700`>2`0Q8ah02Pd600hA2P0>4@P030l6010C2P0B5@/04A@=014C3P0?4@`300d?2P0300/=
200@4Pd0418=00802@/600H06Q`G014C400A4a004A<@010B3`0?4@h200d?300500D710092`P03@l<
00`>2`0<3Pd00`0A4Q@01P0A4a804A<A014C400C5A004A<>010B3@804A@=02H03Q0;018D4`0D5AL0
4a@F014C4P0@4Q004A<@014C3P0>40/04aD@00`?200@4``02`d800hC3`0F6QT03Q8A00`@3`0B5QD0
41@C00lC4P0F6QT051PG00dA400C5aH03A4@01<H500>4`l0314=01<H500>4`l04aPD014F4P0E6QH0
5Q/G01XO6`0H7AT04QLC01<H50804QLC00@04aPD01@I5@0E6QH06AhJ0P0F6aL301PM6@8051TE0P0E
6QH02`0B61@02Q8=010I500K91l06B<M018M5`023@L0620K01TO6`0G7AT0620K008051dH02@05R0K
01<N600?6Q@0520I00TF3`0D8AX06B@N01LP6`0H8A`06R@O01DP6P0L9b40?DU3014N5`0O;RL03ahG
01/Z8`0]?3D09cD/01hZ800N:B406RDM02@_9`0S;RP062<M01`W8@0L9b<06B@P01PS7`0K9R806RHT
01LV8`0N;BX06BPU024`;@0J:2P2028`<@0D024_<00P;S407bd`01h/;`0Q<cD06Bd^01/_<00/?d<0
83<g01ld=`0Q>Cd03RHZ02Y1A`0V?d@093e202a5BP0W?3l0:Cho02a1@P0[@4<202Xo@P809ca100D0
:3a302a0B@0aADh0=DU@03A7B`0202<g>00:02@h>@0S>3T07c@e03UAD@0cBd/0:D5102Do?P0^B4L0
>eEF03=:D0<0=DaD01D0=DaC03A;D@0gCU@0=TiC03Q@E00kDeL0?5AG03YBE00kDe<0=Di;039;B00d
CDX0>U=@03aEDP0fCd`0>eAA03UBC`0jDe00?EIC03UBC`0jD4h00P0kDDl0100lDU00>e5?03Y@CP0g
CD/203E;B@0e03eCD@0eBdT0>Dm=03Q>B`0fBdH0=da70397@P0^@C/0;d8l03U<AP0eASh0;Slg02/l
=00dA3X0>d]103e>AP0oD4H0;d0f02Pj;P0/?S80:3X^03Q:?P0lCDD0<D8j03Q8A@0dA4<0:CTh030k
?@0b@400<d900354@00cB4<0=4a903QAE@0mF640AF5b04YVOP1;JHD0GWVM05efWP1FKY@0AEam03]C
J`10EV/0B5i[03Q?E@0W?440?eAF04iRH`0`@T80;3dk02Th<`0X=c800P0[>SD0:00^?CX0;chk02ln
>`0^?3`0:CLg02Pf=P0W=CH082h^01l^:`0T<c009cHc02He<P0W<c409c4`01XT8`0T;Rd08b`[05iW
IP0[=3<07bPU01dV8@0L9B007BHQ01lX8`0N9b80624L02H_:P0N9b809BhY02</9`0O:2<06R<P02H_
;00K92405adK014G5@0K8Al05a/J01dQ800O8B0201/M700E01TK6P0F61D08B<P01TK600U9b@08bDR
01DG500:30T06Q`I01@F4`0U9b@04aDB020R7`0J71/0:bd/01@F5@0G6AP061XI01hP7`0E5aH061XI
00805QPG01<061XI01<E4P0H6a@05aXC01HH4`0J71/071dP018C600F5a`061TM01LH700G61X06A/J
01`N6`0<3@P051DA01DE4`0J6QP04Q8A00806a/K01805ADF014A4`0>3Q002`X?00T92`0A4A804Q8B
014A4@0?3`l04A4A018B4P0C4a<030`<00l?3`0I6AT051@D00d=2`0C4Pl2010?3@0:018A3`0B4140
4@l@01DC50050`H04Q0C01HD5`0D4QL05Q@G014?4@8040h?0`0?3@h500h<3@0C00l=3`0B41<081hQ
038`<`0O7B002PP;01HD5`0D4QD01085010>4@0H5QT04a4D01@@500I51P05A0D00H21@0F4AD07QTM
010;3`0200X52@803@P<00L03`X>014<400=20`030L;00d8300>2@d03@P<008030L;00D03@P<00h9
3@0=20`030L;00d8300500h93@H030L;00<03PP:00d72@0>20X00P0@2P`01@0=1`T03PP:00`6200:
10H030H800803@L900H040X<01D?4@0F4180100001TC5@0:1@H600d72@<03@L;0`0<1PX03P0;1@T0
1P04014;3`0B31005Q0D05UCE`1ZGf<050/=01hC5`0>0`L030<501L<400>0`L040D90P0A1PX00`0@
1@T03P<7ooooo`0Cooooo`006oooool01`0@4Pl04aDB018D4@0?4@h0418>01@F4@0?4P/00P0@4``3
010C2PH03Q4:0P0=40T400hA2P0?010B3@082PD030h901@F4@0:30L03Q0;01DG4P0U9b803a4<00`>
2@0B50l02P`700d@200=40L03Q4800803a8900<041<:01@G3P0:3@@00`0930<00`0<3`P03@l:00h@
2`0400d?2P0B00/=2@0B50l03@l:014C3P0>40/02@/600<5000B50l03a4<014C3P0T9R40Ce5<01TK
5P0@4Pd030h900d?2P0>40/03Q0<1P0=3``300h@3@8030h;00X02P`900h@3@0C5A804A<@00d?300@
4Pl04A<@00/=2P0<3P/03Q0=0P082PL00`0620H02P`700d?2P0200X<1`0400<50@0:30L02`d800h@
2`<0418=00L02``700H70P0;30L01PL200P9100B4a003Pl:00<03a0;00h03Pl:00d>2@0B4Q004A4?
00d=2`0;2`T03@d;010@3P0N7Q`0;Bd[00P81P0@40h02`/900h>30H03@l<00L030h;00d?300>40d0
3Q0=00d?300<3P/02`/90080410>0P0=3@/0500?3`d00P8004e=B`0l?3X051@B00@40`0W9bD03Q0;
00`>2@0>40/04A<>018D3`0@4@`02``700l?2`0C4Ph06ADB014=2P0>3@T0414<0P0<3@P200l@2`04
00`=200=3PT03@h900h?2P<03a0;00/020X500h@2`0C5A003a4<01LI500E5a803a4<00d?2P0;3@P0
30h900lA3002014C3P0D00h@2`0=3`X030h900d?2P0>40/04Q@?014C3P0@4Pd03a4<00h@2`0=3`X0
3a4<00`>2@0:30L02`d800`>2@0=3`X03Q0;00d?2P0<3PT200d?2P0C010B3P0V:2D01PP500d>3008
2PL00040014C400M7a`07R0M01@F4`0E5a@02P`900T;200B51404A<@01LI5P0D5Q<03@l<014C4002
00lA3P0400h@3@0=3``03@l<00d>2`8030`:00H03@d;00h>300>3P`0410>01<C4@0B4Q0200l?3@0L
00d=2`0B51<03@l>00d?3P082PT02@/:02d_;0041P<05ALD01PJ5@0G6A@03a4<00lA2`0F61D04aDD
00T;2P0:30T05QPE04E7@P0@4``04A@=014D2`0?4PT041<:010C2@0@4``0418=00lA30<03Q0;00L0
4aD@00lA300=3`X04Q@?01DG4P0?4@`03a4>00<04A<@00T03Q0=00`>2`0>40d030h;00h@3@0F61D0
4A<@01<E4P0?4A000P0?4180100?4A003a4?00lA3P0A4`h2010B3@04018E3P0A50d03a4<00lA4080
3a0B01/03a4@014C4@0C5A805QPC014C3P0R91l02Pd600lB2`0D5Q403A8>00lC4P0:3Pd03Q8A018F
5@0?4a803A4@01/O7P0O8b805QXI01<G5P0:3Pd06AhJ01HK5`0C61@05a`H00dB3P0@5A400P0B5a<0
100>4`l04QLC01TN6P0I7QX3018G4`0501<H500D6AD051TE01HK5`0G71P00P0I7QX03P0C61@03Q<?
018G4`0F6aL0724M01/P700A5a<04aXF01<L5`0A6QD04Q`F01LR700D7aT05QhI0P0H7QX04P0L8al0
51dH00dF4@0E7aT04A`F00lJ500G8a`03AXC010M5P0J9Al06B8M01PQ700K9Al05b8L01TT7P0Q;BH0
6BHO01LV7`8052<L00<03A`E01LU700G8aT00P0B7AD01@0E81P06RDO01`W8@0L9b407BPT00806RDQ
00L072PT01XY9P0E92406bXW01d/:@0V=C806BLW00<08Bl`0`0P;S40<P0B92H08cLh01lc=00T=c/0
:ci201`a=00X@4@07CDi02PoA@0B:c007cPm03YCE`0Z?d80:d1102e2@`0/@D@0:d1302Xo@P0V>d00
9ca102Pl@`0[?dP0;d=<0355C00Y?400;T9302@h>@0iCDh0<dQ902Tn?`0O=cL09Cdm0318B00eCdh0
=U1?035;C00`Add0<dYB03I=E@0hCeL0>4mF03M>E00hCeD0>U9G03eEF@0nEUX0?EEH03YBDP0kDe<0
=Tm<0P0bBdP0200gD4d0>eAA03M@C@0lEE80>U=@03]DD@0mEU<0>55>0`0nE5800`0lDU00>4i<03M=
B`0203I<BP0<03Q>C00mDe40>4i<03Q>C00iCd`0>4e803I;AP0aAT40;D0j02`o>@0cAT00<T<k0P0]
?SH0?P0hB3h0?dm503]<A00lCD<0<D8h02Li;@0U=b/08C<W02m1=@0iBT80<44i03];B00fATD09SHe
02dh>@0/>SX0;Sdj02e0?00_@Sh0<4Q503E?D00lEeh0B6=c055]P`1HLi00HGfO04iXS@1BJXh0@eai
03UBJ00hCf40?UAQ04UPIP17G640=DY<03Y>C`0Y>c/0<D8o02dl=`0Z>C@0;C`g030o>P0`?c`0;C`i
02ln>`0^?3`09cDe02Xh>00U<c@072XZ028a;P0Y>3D0:cXg02Dd<@0U<Bl0=d5001HP7`0`>ST0KWMf
0:Zc/P0U;R`07RLT0P0L9B009P0M9R407RLR01hW8P0X<B`0>D8m01`U800Q:RD08b`W01lX8`0O:2D0
;cPe01@M6P0b>3H09bd[01LM6`0J7Qd07b<R024S8P0M7ah07R0O01dO7P0H6QL08B<P01LI5P0];b`0
8B<P01lQ7P0Q8b006adJ01TK600Q8b0071hK01hP7@0J71/0;S0_00d?3P0H6QT06A/J0`0J71/04P0G
6AP05QPG01HH5`0E5a@05QPE01HH500H6QT08B8T02DV:P0I6Ql05AHK01XK7`0J6ad05QLI01DG5@0H
6QL03a0;01DF4P805QHD00@04A4@018B4P0E5AD04a<D0P0A4A<04`0A41D0410B018B4`0D51@04A4A
00h>3P0A4A405ADE014A4@0G5aL04a<C00h>3P0@41004A4?018A3P0?3P`040l=018A3`0B41400P0A
3a001`01008030X=014?4P0;2@h01`D8010>400@3Pl00P0?3@h200h<3@0I00d;300>30d03P`=00l=
3P0>30d030X<03<a=01QGf80BDM:00X82`0>30l06QPK014?4P0@3Q403P`?00`:3@0610L01`@700H1
1@0C3Q8040/?00@00`0A31003`X>00/62P0200X52@0700T4200:1@T03@P<00d8300<1`/03@P<00h9
3@0200d8300400h93@0?2Ph03`X>00l:3PD03PT=0P0=20`600`72`803`T;01004@/=01@>400C3@l0
3`T;00h82P0<1PP02P@600/51`0=1`T030H800T31@0B30h03@L900@000090`D02@@51P0>20X600d7
2`0900T31`0<1PX04P`@00l93@0<1`X0>38f02TN8P0<0`D01`00008040D900<03`@801052@0B1`/0
0P0E2Ph00`0B1`/040D9ooooo`0Cooooo`006oooool03@0@4Pl04Q@A014C400>40d03a4=01<E400=
40T03Q4:00lB2`0?4PT03A0700/>1@0?4P/0100>4@X00`0?4P/03Q4:00hA2P0400d@2@09018D3`0?
4@`051HA01XL5`0<3PT03Q0;01<E400@4Pd04Q@?00803Q0;00h02`d800lB2`0=40T03A09014D3@0F
6A8061/D010C300?4P/020/401/N5`0O8Q/030l800h@2`8030h900T03Q0;00d?2P0<3PT04A<>00lA
300D5Q40418=00h@2`0=3`X00P0<3PT01`0@4Ph04A<>00<40@0J71L051HA01PJ5@0C5A000P0<3PT0
0`0>40`03@l<00d?300400d?300600h@3@0?4@h03a4>00h@3@0<3P/03@l<0P0?4@h0100>40d030h;
00d?300>40d200/=2P0F00h@3@0=3``03a4>014C3`0B50l02P`801LI500=3`X0418=00X<1`0<3PT0
3Q0;00lA300@4Pd03a4<00d>2@0A4Pd03Pl:00T:1@0N7aX03Pl;00h?2P<03a0;00X03Pl:00d>2@0>
3P`030`:00h>300?3`d03@d;00h>300?3`d04a<A0P0?3`d00`0B4Q002`/900d?300500d?300E00/=
2P0=3``03a4>00lA3P0=3``02`d:00`<2P0?3`d0410>00h>300=3@/03`l=00h>300D51801PH500h>
300A4@l02``;00`>2@0:3`T02a0:00803Q0;00P030h900l@2`0A4@`04a8>01PG4`0<2`L051<?010A
30803Pl:0P0@4@`300d>2@0500h?2P0?40/0414<010A300D5Q400P0@4Pd0400?4@`05ALB00/=200<
3PT04A<>01HH4`0G6A@04A<>00d?2P0@4Pd03Q0;00d?2P0>40/03a4<010B3@0?4@`500h@2`0300lA
300>40/03Q0;00803Q0;00@03a4<00h@2`0=3`X030h90P0=3`X04`0O8Ad0<38_00/=2P0I6aT0418?
01DG500l?S/07b4N00X<2@0<3P/020X701PJ5`0<3P/03a4>00d?300A4a0030h;00T;200D5Q<00P0?
4@h0100A4a003a4>00h@3@0?40h200l?3@80410>01004A4?00d=2`0@40h04Q8@00`<2P0>3P`03`l=
00H81`0?4A004Q@C00h@3`0A4a80418?01LI5P0@4Pl03a4<0P0=3`X0400@4``02`d900lA3P0@4Pl0
3@l<00T;200J71P04A@=00hA2P0?4P/041<:00lB2@0=40P03Q0:00h@2`0@4Pd3014C3P07010B3@0L
7QT05aTD00d?2P0B50l02P`700h@3@03010B3`0800lA3P0=3``030h;00h@3@0A4a008bDR01DG500A
4a04010B4@09010B400@4Pl03@l<00d?2`0@4Pd04aD@01<E3`0@4Pd04Q@A00804A<B00h04Q@C018D
4P0A4a003@l<01@F4P0m?cX051HA01LJ500C5A004AHB00hB4@0;3`h04ADD01<G5P804ADD00D05a/J
01dQ800E6AP051PG00hB4@0301DJ5P0;01XO6`0>4`l03a@@00lD400C61@041DA018G4`0F6aL05AXF
018G4`0C61@0100D6AD07P0C61@04AHB014F4P0C61@061dI01XO6`0H7AT04QLC01HK5`0G71P04QPD
01DM600A6QD07bPS03Q2?@0E81X041/E01@L5`0H7QX04QPD01PO6`0I8Qd05AhI01hX8P0A71H04ahH
01HR700J9b004b0I01XU7`806B8M02h06R@N01LR700G8Q`05B4J020]9P0B8AX062LP03E4?@23TX/0
BEM>01XW7@0I9Qd0;c`c01LT6`0A7QL07BXS01XW800L:2@06bLS01`X900P;2P093<`01TX9@0L:bP0
9C@a0350?@0N;2`07B//01h/;@0O;Bh08Blb028`<`0S<C@07Bla02Di>P0Q=CH09STm02Pk?`0S>3/0
7cLk02a4B00R>Cl0:dA905M`M@1[Q8T0:3e00P0W?3d202Pm@00802Ll?`0Y?T<0:Ci302Pm@P0V>d40
9SY002Dj@00Y?44202e0A00<05]^LP12EUT0;T=6059ZK00mEEL0;TI8035;C00dCTl0;TM;0358CP0c
BU80=DaD0P0fCE<03`0eC580=dmC03YBEP0kDeL0>U9D03I>D00cBd/0>E9@03M@C@0cC4T0<T]803E>
B`0hDDh0=Tm<03]DD@0203UBC`0N03aEDP0hDDh0?E=A03iDDP0oEE<0?UAB03aBD00kDDl0?eEC03M=
B`0iCdd0?59@049HEP0lDU00>U1=03Q=B00dBD@0<4E002i1>`0[?SP0;d8l0393>`0`@CT0;Slg0392
>00gAcd0>T]303Y;@@0gB3h0<48f0P0[?C407`0]?c<0=TLo03E6?P12DTl0?4a;02lo?P0^>cX0:cTh
02dm>@0^@C/0;d8n03A:A`0kE5H0?eUP04QRL01BKH40FWF>05igUP1@JHX0@U]k045JM00nF6X0@EQW
03mGH00_ATX0=TY=02i1@P0mCe40;d5103E5@`0`?cX00P0^?CP01@0c@Sd0<D0m030o?00d@d00;cdm
00809C<c00L08c4b01d/:`0S<Rl0:STf02hm>P0Z>CH0:cLe00809c4`00L08B/Z01/T8`0]=SD07bPV
020Y9@0O:2<082TT00808b`W03l08R/V03<l=`0j@ch07BHQ02H_:P0W<2/07BHQ024Z9`0N9b@072DR
02/a;`0U:bT07B<Q01PL6`0M8B00828Q01dO7P0P8R408B<R01`N6`0Q8b007AlL01hP7@0?4@h0BD]8
06]]JP0N81d061XG018D4@0`<Rl04Q@A01@F5@0O8B0020X901XL6`0M7ah05aTH028T8`0L7Qd06A/J
01LI600E5aH061XI01<E5P0C51H04a@H01XK7`0M7R@04Q8I01TJ7`0K72006AXL01DG5`0B51804Q@A
01HG4P0D514051@B010@3P0G5aH05ADE018B4P0C4a@00P0B4Q@03`0D4aP05ADG01DE5P0E5AD051@D
014A4@0B4Q8051@D014A4@0D51@04A4A01PH600K6a/05ADC018A3P0200l>300:018A3`0B41404@l@
01lM7P0B41<05aDH01hL7`0E4aP03P`?010>40<03`d>0`0>30d02`0?3@h040h?010>3`0>30d04@lA
018@4`0=2`h03P`?00d;3P0;2@`03@/>00804Q0C00L02`T<00l=400B41<0AT=6034/<00:1PT04`hB
008030L;0`0@2`l02P0?2Ph04PdA018=4@0?2Ph03@P<00`72`0=20`03PT=00d8300<1`/800d83080
30L;00<02`H:00`72`0<1`/0100<1`/200h82P0500l92`0A2`d04@/=00d72@0>20X00P0<1PP200h8
2P8030H800D04P`>00`7200V828020<400l92`0600h82PH03@L;00h02086014;3`090`L03`T=00l:
3@0=1`/04`X<01P>4@0:0@<06A0B01D:3P0>1@L03`@801462P804`P<00<04@H:00l42?ooool04ooo
ool001_ooooo00h04A<@00h@3@0=3``03a4>010B3P0?4@`030l800hA2P0?4P/03a8900`?1P0930<0
3a8;00hA2P803A0900@03Q4:00lB2`0@4``041<<0P0?4P/200hA2P0@00d?2P0;3@P03@l:010B3@06
20<03@l:00lA300:30L02`d800`>2@0>40/0418=00hA2P0?4P/041<<014D3@804QD>00L03A09018E
3P0?4P/06ahG01lR6`0D5a003Q0;008030h901D0418=00h@2`0<3PT030h90084000C5A0030h900lA
300>40/08B<N01PJ5@0>40/020X5010B3@082PD02`d801<E400E5a803a4<00`>2@0<3PX01P0=3``0
5`0>40d0418?014C400?4@h03@l<00/=2P0>40d03a4>00/=2P092`P03a4>01DG500<3P/020X700`>
2`0=3``03Q0=00`>2P0A4`h0:R`W05YLE`0Z;2L03Q0;00D03@l:00P03Q0;01XK5P0D5A0051D@00/<
1`0=3PT02P/600h?2P<03a0;00`03Pl:00d>2@0>40d02P`900`>2`0?4@h03@l<018D4@0?4@h0418?
00`>2`0J71T800d?300900`>2`0=3``03Q0=00h@3@0=3``030h;00h>300=3@/03Ph<00803`l=0100
30`:00d=2`092@L03Ph<00l?3@0@40h010H300lA300=4P`0314;00X?2@0:3PP02`d8014C3P0?4@`0
3a0;0P0=30P01@0C4Ph03@h9010A300A4Pd0414<00L03Pl:01003a0;018D3`072@@01PP300lA300F
61<020X500d?2P0E5a8071hI01lQ700E5a803Q0;00`>2@0=3`X03Q0;0`0?4@`200X<1`0=00/=200=
3`X03Q0;00h@2`0?4@`0418=014C3P0@4Pd03@l:00/=200>40/03@l:00`>2@0200d?2P0I018D4007
2@H061XG07j0O@0];b`03a4>02LY9P051`@0004001<E4P0:30T04A<@00d?300A4a003a4>014C400;
3@X04Q@A01lQ7P0@4Pl03Q0=01<E4P0A4a003a4>010A3`02010@3P<04A4?02004a<A01LG5@0C4a40
3`l=01TI5`0@40h06Q`K018D4`072@P01@L600L9200=3``02P`9018D4@19BdH0:B/V01HH4`0D5a00
4Q@?01DG4P0A4`h03a4<018D3`0E5a803Q0;00T;1P0<3`P04QD>00hA2P0=40T03Q0;00lA30<04A<>
00T0418=014C3P0P8Qd07R0K00d?2P0:30L04A<>00lA3P0>40d00P0=3``200lA3P0600h@3@0:30T0
7AlL04a>B`0`<Rl02@/81P0A4a001`0>40d03a4>018D4@0D5Q404aD@00lA300A4a000P0?4@h0300A
4a003a4>00X<2@0B51403Q0=01HH5@072@@04A<>018D3`0D6AD03a<B00hB4@<04ADD00L04QHE00lC
4P0E6AP03a<B018F5@0@51<041DA00803A8>00@051TE00hC3`0B5a<03Q<?0P0C61@01`0E6QH04aPD
00hC3`0B5a<04aPD01@I5@0E6QH00P0C61@01`0H7AT06QlK01PM6@0F6aL07b@P02L/:00/<Bd00P0F
6aL0<P0C61@03aDA01DL600F7aX05AhI03Y4?P0E81X03QTC010H4`0D6QH05Q`H02D]:00Q:RD04Q/F
01@N6@0D7aT08RdW01HR6`0M:R<04QlH01PS7@0J8ah06b@O01TS7@0H8ad06RDO01LS7@0=6Q<052<L
01h]9P1@GeP0_Lc506akL@0U<RP09S<Z05MTF`12CdH082dV01PU7P0L:B807BTU01/W8`0L:2@07b/W
020_;00H:2D072`Y01l_;00[>cP0830_0P0N;Rh04@0P<3008C0c028a=00S<SD05RPZ01X^;`0/@440
?4mC02Pk?`0O=3L08SXn01P`=00Y@4H07cPm01Tb=`0Z@dP0:3e000809S/l00<0:Ci102]0@`0Y?T40
0`0Y?T402P0X?D009ca002Dj?`0Y?480:Se302e0AP1OLWP0YKVo03Q=DP0dC5020359C@0303=<D00a
BTh0:dA800<0=DaB01D0=TeC03Q?E00iDED0=4a@03Q@D`0hD580=De?03=;C00dC4`0<4U603A=BP0e
CT/0<da903E>B`0iDTl0=4e:03M@C@0eCT/0=Tm<03]DD@0jDe000P0lDU006@0mDe40?UAB041FE011
EeD0>e5?03aBD00nE580=de;04AJF00nE580>U1=03M<A`0_A3l0;T<n0313?@0]@3X0;d8l03=4?00a
@SX0;3de02hn=00a@CL0@55903M8?P0fAcd00P0`@SH07`0gBCd0B5Y>03e>AP0kC4@0?dm<03E5A00c
@d80<T4n02dl>@0`@3X0<TDo03=6@P0gC4X0?EEG041IGP12GFP0Af5b04]TN01LMXl0PI^f04aTOP14
Fg40>4mO04UOK00cBDl0Fg1c09nc]012EED0=DM703a<C00]?C/00P0`?cX05@0_?ST0=TE003I5@P0c
@Sl0<D0m02hl?00W=CD07R`/020^;`0T<c408c8]02Dd;`0[>SD0;C`g02`h=00U<2`0:SDa020[9`0C
71T07bPU02</:@0201`U800701hW8P0Q:RD08R/V01lX8`0G81/051dH01PQ700202@]:00N024Z9@0I
8Ql0:C8_024Z9`2AUiD0NX1n01TO7@0I7A`07B4P01hP7`0J71/07AlN01lQ800R924061XG01/M6P0U
9b@07AlL01lQ7P0Q8b004Q@A024S800=3``061XG018D4@0E5aH05aTH01HH5`0L7Qd0828Q0P0K7A`0
7P0I6aX07AlN01`N7@0F61L061TK01TJ7`0I6B405ADM01HF7P0H6Al04Q<H01XK800G61`05AHH01DG
5P0D5Q@04A<@01hO6P0F5a<05ADC00d=2`0P81l071`L01LG5`0I6AX05aLI01DE5`0F5AX061PJ01DE
5P<04a<C00T0410@00h>3P0B4Q80410@00h>3P0M7Ad07QhN014A3`0C4Pl00P0?3P`02`0@3`d03`d>
00h<3@0E4a@03@/>00l=400G5AP04Q0E00h<3`0?3@l03`d>00803P`=0P0=2``01P0?3@h040h?014?
400?3@h030X;00h<3P802PP;01<03`d@014?4P0=2`h02@L:00h<3`091`X020H9018@4`0F51L04@hA
01hI7@0F4AD0100301D@500D3a<020<700`72`0>2@d030L;00804@`@00L03PT=00d8300<1`/03@P<
00h93@0=20`030L;00802`H:00L02PD900/62P0;1PX03PT=00l:3P0>2@d030L;00802`H:1P0<1`/0
1P0=1`T02`D700/51`0<1PP03@L900/51`803@L900@03`T;018<3P0A2`d030H80P090`D0100<1`P0
6A<E02/U9`0;1PL600d72@0400X4200;1@T02`D900`62P803@L;00@02`D900l93@0400802@<70P0:
10P01P0800403`@8024F6P0=0PH0MV]_04@i?@803P<70P0?10P200h31aCooooo000Kooooo`0>01@F
4`0@4Pl03a4>018D4@0C5A40418=00lB2`0A50d04aH?018E300?4PT030l6010C300>4@X200`?2004
00hA2P0@4``03a8;00lB2`803Q4:01D03A0900`?200C5A00418=00h@2`0@4Pd02P`701DG4P0>40/0
418=00D70P092`L0418=01<E400=40T04A@=01<F3`0B5@h03A0900X=1P0<3`P00P0?4P/03@0=40T0
3Q4:010C300?4@`030h900d?2P0@4Pd03a4<00`>2@0=3`X010H101TK5P051`<00P0=3`X01`082PD0
0`D001LI500210005QPC010B3@0>40/00`0<3PT00`0=3`X03@l;00d?300400d?300U00h@3@0?4@h0
4A<@018D4@0@4Pl03@l<00T;200=3``04Q@A00d?300<3P/06A/H02@V8`0G6AH03a4>014C400@4Pl0
3@l<00lA3@082PD02P/803Pj=@0>40/04A<>00lA300>40/030h900/=200<3PT03Q0;014B3@010P00
3a0;00/<1`000@005AHA00h?2P0300l@2`0300h?2P0=3PT04A<@00802`d:0P0>40d01`0F61D0OGml
05iPG@0?4@h061XG00840@0>40d0300=3``00`0?3`d03@d;00d=2`02010@3P0900/;2@0?3`d03Ph<
01@D4P030`402PX801HH5@0;40X0314;00802a0:00<03A4;014C3P0@4Pd00P0>3`X02@081`<04Q4=
01LF4P0;30L04A8=018C3P0?40/03Pl:010A300600h?2P0500`>2@0E5a804aD@00h@2`0D5Q400P0;
3@P010092`H030h9018D3`0A4`h200lA3080418=00@03a4<00`>2@0:30L030h90`0;3@P200X<1`09
00h@2`0A4`h04Q@?010B3@0;3@P02@/600h@2`0=3`X030h900803@l:00`02P`8018D4@031@80;2h[
00d?300E5a@03Q0=010B3`0C5A80418?00lA3P0B514200d?300<00`>2`0>40d020X701<E4P0R9240
3@l<00/=2P0A4a003Q0=00`>2`0?40d03`l=0P0@40h3014A3`0[010@3P0<30X05QHD02l_;@0S8b40
61XI00/=300?4A005ALF00`>3@0B51408bDR00P:1`0S9B000P@000@60@0E614020X500d?2P0?4@`0
4A<>01DG4P0<3PT04aD@00d?2P0?4P/051L@00lB2`0<3`P0418=014C3P0B50l04A<>010B3@0>40/0
4aD@014C3P0>40/0418=00/=200?4@`03a4>00h@3@0200`>2`0800h@3@0@4Pl02@/801<E4P092`P0
6Q`I00T;200F61D600lA3P804Q@A00@051HC01DG4P0C5A003Q0;0P0A4a00300D5Q<05aTF01HH5@0A
4a003a4>014C400>40d05aTD018D3`072@H05ATH010D4`<03a<B00`04ADD00hB4@0A5A@06QhM01<G
5P0@51<02`l>01@I5@0=4Ph02@h:010E4@0=4Ph2018G4`0m00hC3`0:3`/03a@@01<H500@5A404AHB
01<H500D6AD05AXF01<H500B5a<04aPD020U8@0O92005AXF01<H500G71P06QlK00dB3P0D6AD05Q/G
01<I5@0B6QD0624L018K5P0F81/02QD?01`W8@0D7AP06b4M01<I5@0J8Qd06B8M00lH4`0D7QP072LQ
034l=P0I9Ah06bPQ00hK500F8A/06b@O01dV8@0I8ah062<M01`W8@0L:28072TR01d/9@0@7aP07RdV
041?B00W=R`05b@J01dZ8@0V<bX03a`C018O600S<2T07R/T01hZ9P0201/W8`0801`Z9@0G9b@05BDR
01XZ9`0F9R<08C4^01d];00Q<C42028b<P808S4d00L08S<e024c=@0X?3d083@e02<f>P0X>cl0;D95
008083Pl00X09ci4018[<00iDUL073Di02@i?00Q=SL083Df02Dj?@0W?3l09S/n0P0X?D00400Z?d80
:d1302]0@`0[@4<0;d9802Pk@@10DeT0<TE;082DVP0]@TL0:d=702i6BP0_Ad/0;TM;039;C`0hDED2
03M>E00<03Q?E@0kDUP0@EQM04ALH00eCE40>E5C03YBE00gCe40=dm@03YBDP0[A440<DY70P0eCT/0
1P0gD4d0>eAA03=<B@0fCd`0<da903A=BP80>eAA00@0@EME03iDDP0mDe40?E=A0P0nE580200gCD/0
@EME04AJF00cBDL0?eEC03U?C@0jD4d0=T]60P0]@Sd0@`0bACl0;d8l02i1>`0a@SX0;d0h02dn=P0b
@SP0=THl04MHD00eAS`0<44g02Tk;`0Z?300=4Hj041BAP0]?SH0;Slg03I6@`0b@T40>4Q70391?P0]
?3L0<40j03A5?`0cAT80=DU703]@D`0nEE/0@UYU045KJP15G6h0B65g07bF[@10F700@5QZ03E=F@1A
J700?59G03A9BP1/P840<DA403E7A`0oCdl0;C`j0350>`0c@Sd0<T4l03Y9A00lBdP0<d8o02Th=@0Z
>3P0:CLg01h/;00R<340;3Xi02He<00U=2l0:3Lb02Xi=00X=300;CPd02Pc;`0P:bL07RLT03Q1?P0N
9b@00P0O:2<02`0R:bH09BhY02H_:P0S;2L09BhY01XS7P0Q:RD07bPS01XS7P0O:2<06B8O00807RLT
0140=C/i02P^;00Q9bD0720O020T8`0P8R406adL01dO7P0N81l07AlL01/M6P0N81d061XG01dO700K
7AX05aTF01@F4`0201LI5P0@01@F4`0H6QL051HE01<E500I6aX04aDD01DG5P0B51<051HE01DG5P0O
8B00828Q01LI600F5aT05QHN01TI8`8051@L02L06AXO01HG6`0I6Qh051DG01<E500E5aH05QPF01<E
4P0E5Q404Q<?01LG5@0<30X061PG00T92@0@410051@E01<C5@0@41804a8G01HF600C4a@0410@018B
4P0D51@03`l?00X:2P0A4A406QXJ014A4@0@410051@D010@3P0D4a0040l=00l>300@3`d03P`=00d;
300C4A800P0=2`h01@0E4aH040hC00l=400?3@l03`d>00803P`=0P0=2``0200?3@h040h?014?400?
3@h02`T:00d;3@071@P03`d@0P0;2@`03P0G5AP03P`?00`:3@0;2@`04@lB010>4@071@P02PL:01<>
4P0;1PX05A0D00h93@0300803`X>0P0@2`l0200<1`/03`X>00h93@0<1`/03@P<00`72`0=20`03PT=
100=20`00`0<1`/03@P<00d83002010;3`0300l:3P0>2@d03@P<00L030L;00@03`T;00d72@0;1@L0
3@L90P0>20X0300<1PP03@L9018<3P0D3Q004P`>00`6200@2P`0100001D?4@1FD580Y9jP01/E5`H0
3@L900@02@<700X4200;1@T02`D90P0<1PX03P0:10P040X>00l93@0@2Ph02@<701XD600?10P04`X<
00L0000O51P0:R4S020E6@0A1PX040D90P0?10P00`0@1@T04@H:ooooo`0Cooooo`006oooool01P0A
4a003a4>00X<2@0<3P`04A<?00h@2`803a8;01403Q4:00d@1`0<3`H02`h500T<1@0@4``03A0900/>
1`0=40T030l8010C300:3@H041<<018E3P0<3`P03A0900h@2`02014C3P0700lA300>40/03a4<014C
3P0@4Pd03a4<010B3@02014C3P0D00/=200=3`X04Q@?00lA300;3@P0418=014C3P0:30L04Q@?018D
400E5a803@l:01<E400K7AP051HA00h@2`0?4@`03Q0;00d?2P0;3@P200lA3008010B3@0G6A@03Q0;
00T:1`0=3`X03Q0;00`>2@0>40/2014C3P0A00`>2@0>40/02P`700lA3P0C5A8030h;00lA3P0:30T0
3a4>010B3`0/;R/0?T0m014B400E5a@0418?00`>2`0A4a000P0<3P/01@0H6QL03@l<024S800I6aP0
4Q@A008030h;00l03@l<014C3`092`H0418=00d?2P0A4`h03@l:00lA300@4Pd05ALB01@F4@0>40/0
30h9010A300>3`X00P0@4@`0100;30L03@h900`=200<3@P200d>2@803Pl:00/02P`901HH5@092`P0
5ALD00@61012A440h^CQ055CD00?4@h01`P601DG500200lA3P0;00/=2P0>40d03a4>00lA3P0=3``0
3a4>00X<2@0?4@h02`d:00lA3P092`P00P0@40h200l?3@80410>018030`:00l?3@0>3P`03@d;00h>
300A4a003A8<06M^I`0F7AH02Pl901@I500=4P`0418=00lA300>40/03a0;00h?2P0=3PT2014B3@05
010A300?40/03Pl:00`=200=3PT00P0:2`H00`0=3PT03a0;014B3@0200d?2P0600h@2`0?4@`0418=
010B3@0>40/03a4<100@4Pd200`>2@0<014C3P0@4Pd06A/F02X/9`0A4`h030h9014C3P0?4@`05ALB
00X<1`0@4Pd03a4<100=3`X00`0C5A005ALB00h@2`0200lA300<00/=2@0<3P/03Q0=014C400?4@h0
3Q0=00d?300A4a00;c4^014C400@4Pl03Q0=0`0?4@h0100:30T020X700h@3@0A4a0500h@3@0700h?
300>3P`0410>014A3`0@40h03Ph<00l?3@02010@3P03014A3`0B4Q004Q8@0080418A01T03Q0?018D
4`0O8B00418@01@F4`0=3``03Q0;01XL5`0I6aH041<<00hA2P0=40T04QD>01<F3`0B5@h04A<>01HH
4`0C5A004A<>00X<1`0I6aH0:bdX010B3@0B50l04A<>00803@l:00T0418=014C3P0:30L04A<>01@F
4@0F61<03Q0;00`>2`0>40d0100?4@h4010B3`0300h@3@0=3``03a4<00804aD@0P0A4a00400C5A80
3a4>01@F4`0E5a@04aDB010B3`0?4@h05ALB010B3@0E5a804Q@A01<E4P0;3@X04aDB01@F4`0C5A82
01@F4`09014C400@51<04aLF00hB4@0@51<04aLF010D4`0A5A@0310?00804ADD00D030l>014E500B
5a<03A8>00`A3@02018G4`0<01`Q7@0=4Ph05Q/G01@I5@0F6aL03a@@02H[9`0F6aL051TE00dB3P0J
7a/01``80P0G71P201DJ5P0901PM6@0E6QH04AHB01<H500D6AD061dI01LL600D6QH05AdH00804Q/F
00L04Q`F018M5`0C7QP0624L01`R7P0K8Ad06B0L00805QlJ00L0628L02lj=00nBD<0:CD^01<P6@0G
91d07RTS00809BhY01405b4L01XU7`0U<2X08RhW01XW800K:R<06BPQ01LV7`0M;2D08C4W01XZ7`0H
:1h072`R01/[8@0I:2406bXS01d/9@0201d/9`8072/V01H05bLT024a;P0J:RL07BdZ01h^:`0U=C@0
72`/02<c<`0M;Bd09C@g02Th>`0R<cD093Li01X^;`0Y?Ch083<g04MJGP10EEP09Si203E=D@0dBe40
9Ci30P0[A4T01`0V>cl09CXm02Hk?P0X?Ch09c`m02Dj>`0Z?d000P0W?3d202Xo@00702Ll?P0[?T<0
;T5702/nA00^@DL0<dM<02]0A@020318C00A0359C@0aBTh0=4eA03I?D`0bBDl0>U5G02m6C00oEe/0
=dmC03aDE`0gCe40>E5B03UAD@0hD500=dm?03E=C@0dCDX00P0_B4D01@0eCT/0>U=@03QACP0lEE80
>E9?0080=e1=04`0?5EB03mHE@0mDe40?UAB03mED`10EU@0@EME04=IE`0kDDl0?59@03Q>C00oEE<0
@5ID03M=B`0iCd`0=4U40356@@0`AD00=4M103I9@`0/?cT09cP`02Xk<`0/?CD0;Shd0351=`0fAcl0
=DHl03=4>P0`@SH0;d4e0312=P0bA3P0<T<k02dn=P0hB4D0=dM60351?`0nCDT0>da603A5?`0^?cT0
9STe03iAD01;H680=DY?049GH012FF@0@UQU04]RL`11FVd0@U]]04IOK013G6@0>e9G0397BP0hC4d0
;Cm00352@P1?Gel0>4M:0391@00d@ch0<d8m03E4?`0fAD00=4=00350?@0[>SL09cDe02Tg=`0P;Rh0
=TA502Hd<`0a@3/0:3Lb0P0V=C00100Z=S809S4]02@_:`0P:bL201`U8P0401lX9@0J8ah072DP020Y
90808R/V00L08BXU01dV8@0O:2<08BXU01dV8@0K91l07RLR00<07BHS0P0O9B<03@0P9R@06QhM01/O
7P0N81l071hM01XL6`0L7Qd08bDR01XL6@0T9R<07AlL01LI5P0M7a`00P0L7Q/02@0I6aP07R0M028T
8@0G6AH05ALF01XL6`0D5QD04aDD01PJ6@0201LI600F01PJ6@0I6aX05QPG01<E500H6A/0KVie05=C
G00D51/09BH/01PI7@0K71l05aTI01HH5`0D5QD05ALE01@F4`0A4a004A8=01@E4@0E5A<051@B01<C
4P804a<C01805ADF01<C5@0E5AL05A@I010@4P0@41405aLG00d=3@0C4a<04A4A01HF5P0B4Q803Ph>
00l?3`0>3Ph03@d=00l?3@0?3P/300l>300A010>3`0?3@h04@l@014?4P0F51L0518E00l=4P0B41<0
40h@01<A4P0?3@h03P`=00l=3P0<2P/03P`=028P8@1HEUL00P0=2``01`0=2`d03P`?00l=400=2`h0
30X=00h<3`0?3A001@0=2`h01`0>2`h03PT=00d8300>2@d04@`@01@?4`0A31000P0@2`l03@0=20`0
3`X>01<>4P0<1`/040/?00d9300>2@d02PD900`72`0>2@d040/?01<>4P0@2`l0100=20`01`0A3100
50lC018=4@0<1`/03`X>00d8300<20/00P0>2@d00`0<20/03PP:00`6200200l92`0D018<3P11>cd0
40X<00L10`0A2`d07ALI01<=3`0=1`T030H800/61`0?2@/0?CLi05eGF@0C3@l0<B/]010:300=1`T0
3PP:00/51`0:1@H200l93@803PP<0P0=1`/0200<1PX04`dA00H1100?2Pd03PP<00T41`0@1@T03`@8
0P0>0`L0100?10P040D901052@0?10P200h31`0300l4200@1@Wooooo01?ooooo000Kooooo`0700lA
3P0B514020X701DG500@4Ph030h900`?200200d@2@0800hA200?4PT03a8900T<1@0@4``03a8;00hA
2P0B5@h3010C3005018E3P0?4P/041<<01HI4P0=3`X00P0@4Pd01P0>40/03@l:00h@2`0>40/03@l:
00`>2@803@l:00<03Q0;00/=2P0:30T00P0=3``02@0<3P/03Q0=018D4@072@H03a4>014C400B5140
1`T600lA300200/=200R014C3P0@4Pd02P`700h@2`0B50l04aD@00lA300E5a80>S`g02T[9P0;3@P0
4aD@00h@2`072@@03@l:018D3`092`H0418=00X<1`0T9R4030h:0001000>40d04A<@00P:1`0@4Pl0
3Q0=00840@0>40d0418?00/=2P041P<03Q0=01PJ5`8020X701001`T600T;200A4a00418?01HH5@0D
5Q<030h;00/=2P0;3@T05ALB00/=20092`H03Q0;00T;1P0>40/02`d80P0<3PT0100:30L0418=01HG
4P0B4`h2014B3@0400d>2@0>3`X030d800`=20<03@h900@03Pl:00L91P0A5Q802Pl;0P0;40`02`0G
71P05Q/G01DJ5P0?51003Q<?00H;1`0:3`/05aTF030b;`0D5Q<01PP500804aDB00H01`T600X<2@0?
4@h02`d:018D4@0:30T600`<2P0D00l?3@0=3@/03@d;00h>300@40h03Q0=01HM5P0nAcl02A0901HM
5P1LHU`0<SLa01LL5P0D5a803Q0;00`>2@0=3`X03a0;010A300?40/200d>2@0800l@2`0@4@`03a0;
00/<1`0<3@P0414<00l@2`0<3@P300d?2P<03Q0;0P0?4@`0600@4Pd03a4<00h@2`0=3`X02P`700P:
1@0:30L01`T4018D3`0R91l061XE00h@2`0:30L03a4<00P:1@0:30L030h9014C3P0<3PT03a4<00/=
200Q8ah03a4<014C3P803@l:00<03Q0;00lA3@0@4Pl00P0@4Pl200lA3P0=00h@3@051`@04Q@A00/=
2P0@4Pl03Q0=00lA3P0>40d0418?00lA3P0@4Pl05QPE01DG500500h@3@0600l@3P0A4@l04Q8@01<C
4@0B4Q004A4?100@40h200l?3@<030h=00l071hM01PJ6@0@4Pl04A<@00/=2P0@4Pd07AlJ01`N6@0C
5Pl071lF00d@1`0B5@`01`X300lB2`0B5@h00P0E5a801`092`P00P@101<E4P0E5a@04A<>010B3@0>
40/00`0?4@`01P0B50l03a4<00h@2`0@4Pd04A<>00h@2`803@l<0P0>40d200lA3P1;010B3`0?4@h0
3@l<00h@3@0@4Pl04A<@00h@2`0A4`d0418=00lA300?4@d0418?00h@3@0@4Q004A<B00lA400@4Q40
4A<@018D3`0?4@/03Q0;00lA300A4`l0418?01HH5@0Q8b403Q0?00P:2@0F61L04Q@C00hB4@0B5QD0
3a<B010D4`0A5A@03A4@01hR8@0l@3l0004001`P7`0;3`h03a<B01PM6@0@5A405Q/G00lD40062`L0
6b0L01@I5@0H7AT03Q<?00`A3@19CTX0e]_G024V8P0D6AD07b@P018G4`0E6QH06QlK01@I5@0A5Q80
5Q/G01`Q7@0I7QX05AXF018G4`0P9B40:BhZ024V8P0E6aL05QhI01PQ700F7aX051hI00804QdG01/0
72@O024W8`0K8Ad051`G01<L5`0E7QT09c4/02Pc;@0F8A/04alH01l/9@0M:R<05b8L024Z9@0S;2L0
6bDO01HQ6`0H8ad06RHO01`Y8P0L:b@06BPQ01HU7P0I:2407BdS01LY7@0E9Q`00P0K;280400L;BD0
834Y020a:@0O<2X07BhX01`]9`0K;2H08c<`014T800P<bl0H7=_02<f<P0U>3H05RPX028d=00P<S82
028d=P0@024c=@0S=cP093Pi02Xn?`0U>3`0;d9602@i?00T?400:d=702U0AP0/ADX0>55F039;C`0U
>Sl09S/n02Dj?@808SLh010093Tj02]1?`0Z@3h0:Clm02Y0?P0[@Ch0:3hl02Xm@@0/?d<09cXn02Dh
?00X?3l09c`o02]3A@0_AdT0<TY<0P0bC4d05`0`BT/0>U9F0359C@0U?D40<4Q<0359C00eCDl0=Ti@
03M?C`0hD500=e1=03I?C00eCT/0?5EB03M@C@0eCT/0>55>03YCD00hDDh0=Di;03M@C@0hDDh0>E9?
0080>U=@01<0>U1>03]AC`0nE580@5ID03eCD@0jD4h0AE]I03Y@CP0mDe40@EME03aBD00iCdd0>e5>
03=8@`0aAT40<dQ303=6@00aA3h0=4M10080=DHn00L0<D8j03=3>@0jBT00<44i02ho=@0]?S@0;Clc
0080;T0d01h0=DLk0311>@0eASh0A5AA03Y:B@0/?3T0=4Dm0352>P0cA3d0>DY403E8A00kCTd0;D52
03mBEP0jCeD0Cf=/05=WL012FFD0A5]Y04INJP15GFH0?eMK03Y?DP0nDU<0>4a;03=5A@0iBTX0=4A4
03=1A00/>ST20391?00@03A3?P0c@Sd0;chk02`k>00T<c00<3hn02Pf=P0O;Bd08Bl`02Tg=@0[>S<0
8S4Z02Lf;`0P;bP09S</02@_:@8082/U00D09c0[02Pa;00O:2<07RLR01lX8`02024Z9@0X020Y900N
9b8082TT024Z9@0P:B@072DP01XS7P0L9B006B8O01XS800M9R<082HT01lU8`0N92806alN01`P7`0N
81l06adL01XL6`0M7ah04Q@A01`N6`0C5A804Q@A030b;`0K7AX07AlL01TK600C5A805QPE01/M6P0G
6AH05ALF01PJ6@0C5A@04Q@C01PJ6@0K7A`06Q`K01HH5`804Q@C010061XI028S9@0C51T04a@I01TJ
7P0C51H0;Bl^03<e<P0K7AX05aTF01DG500E5aH05QPG01DG500F5a804a@@0P0A4@l08P0C4a805ADE
014A4@0E5AH04a<E01@D5P0E51T04A4C010@4@0D51@030`<01<C4`0?3`l0410@02h^;P0D51@04A4A
01HF5P0E5AD051@B018A3P0A40h040l=00l>300>30d03@/<00l=3P0@3Q404a4D018@4`0>314040hA
010>400A3a0200l=3P08010>3`0<2P/040h?0040000<2P/04@l@00<10P0?3@l200d;3P0300/9300:
20/030X=00H03P`?00<040d@014<400?2Ph00P0=20`04@0>2@d030L;00P31`0C3Q803@P<01<>4P03
00805A0D00<00P0G4QH02`H:018=4@0:1@T03PT=00l:3P0>2@d03@P<00802`H:0P0<1`/00`0>2@d0
40/?010;3`0200`72`803PT=01`02PD900d8300J5AT0?SPj00/51`0>2@X04`d?00D00@0E3a404@/=
00d72@090`D02`D700d72@0;1@L030H8018<3P0?2@/01P0200X41P0:1@H03@L901hH6P0;1PL03@L9
00h82P0D3Q003@L;0`0<1PX400/52@06010:3P0A2`l02086014;3`0@1@T03`@80P0>0`L0100?10P0
40D901052@0?10P200h31`0300l4200@1@Wooooo01?ooooo000Kooooo`06018D4@0;3@X04A<@00lA
3P0M7a/04A<>0`0>4@X300hA200800`?200?4P/030l800`?200>4@X02Pd600T<1@0>4@X2014D3@03
00lB2`0>4@X03@l:0080418=00@03Q0;00d?2P0>40/03Q0;0`0=3`X200h@2`0800h@3@0<3P/030h;
00lA3P0@4Pl03a4>010B3`092`P2010B3`0301DG500=3``03Q0;008030h900/03Q0;00d?2P0;3@P0
30h900d?2P0A4`h03a4<00h@2`0A4`l02`d800X<1`0200d?2P0:00lA300A4`h04Q@?00H80`0E5a80
3Q0;03Pj=@0N81`0ADM400/=2P803Q0=00l04A<@00h@3@0=3``04aDB00T;200J71T04A<@00h@3@0N
81d02P`9014C400D5Q<02`d:00`>2`0>40d00P0=3``0500>40d03a4>00h@300D5Q403Q0;01PJ5@0>
40/03@l:00lA300=3`X03Q0;00`>2@0:30L03a4<00d>2@0:2`H03@h9018C3P0@4@`03a0;1P0=3PT0
6P0?4@h02@h:00hC3`093PX02a0<00`A3@0@5A400@D1010E4@0:3P/03Q4>069WH`0I6aP08B<P00lA
3P0A4a006adJ06U[J00_<Bh03@l<018D4@0@4Pl02`d:00h@3@0<30X03@d;0P0>3P`00`0=3@/030`:
01<C4@0200l?3@0A018B400D5180418?02H]9P0B71@04AXB02/b:`3Af=40AD]4018G4@0A5@l03Q8<
00h@2`0=3`X03@h9018C3P0@4@`00P0>3`X0300B4`h051D@00h?2P0;30L03@h9014B3@0?40/030d8
00d?2P0>40/0418=018D3`8051HA100?4@`0700=3`X030h900`>2@0?4@`05QPC01DG4P0=3`X02`d8
01dO6P0C5A002P`7018D3`051`<03Q0;04I8@`0j?3L05QPC018C3`0b=2l02P`700`>2@0>40/03@l:
00`>2@0=3`X04A<?014C400>40d200d?300800h@3@0@4Pl03@l<00d?300@4Pl030h;00/=2P0?4@h2
010B3`0400d?300<3P/03Q0=00lA3PD03Q0=00<0414>014A3`0B4Q000P0B4Q02014A3`03010@3P0?
3`d03`l=00803`l=01l04A<B01@F5@0:30/03a4@010B4@0Q8b0051HC00lA3P0>40/0418=00d?2P0=
40T0:2/R0495>`0M81L06A`D00d@200A50d02`d:03<e<00/;R/03@l=02HX9P0A4a404aD@010B3@0>
40/04A<>01<E400@4Pd02`d800804aD@00<06Q`G01DG4P0A4`h00P0>40d08`0=3``03Q0=00lA3P0@
4Pl03a4>00h@3@0<3P/03@l<018D4@0D5Q404A<>014D3@0?4P`0418=014C3P0A4`l0418?014C4@0@
4Q403a0A018C500F61H03@l:01@G400;3PP0418=01<E4@0J71P04A<@00lA3`0@4Q404Q@D01<E5@0B
4a@02`l>008041@C0P0C5aH0600?4a804QHE010D4`0=4A003a<B01TM700E6AP04QLC014F4P0>4`l0
5AXF010E4@0B5a<051TE018G4`0C61@06AhJ01PM6@0X;BT061dI01@I5@0A5Q805Q/G01LL60804aPD
00<03a@@01DJ5P0H7AT00`0D6AD01@0L8Ad08BHR01XO6`0C6AD05QdI00805AhI01T051hI01@O6@0E
81X0620K01TO6`0G7AT05QdI01LP6`0J8ah07BLQ01`W8@0I91h05b<M01PU7P0I9Ql05b8L01LP6`0K
91l07BLR01lZ900Q;2H08BdW024^9`0N;BH072/T008062LP00d06b/Q01LY7@0F9ad06BXP01LX7P0I
:R807RlW01d^9P0M;RP07RlY01d^:00N;bT07C0/00807c8^00X0DfIR02@g<`0J;B/07c4a02Hh>00M
;bl08S@f02Dg>@0R=3H08CDf0P0X?3d05P0/?d<09cXn02Dj?@0W?d<0:T9602LnA00V?d@0;DI;02Ho
@`0Y?T<0;45402Tn@@0T>CX09c`m02Tn?`0T>SP09C/i02Lm>P0X?S/0:T0l02Y0?@0V>S/202Tm?`0?
02Pk?P0]@D<0=4U;03A<C@0cBd`0<TY;031:BP0_BDT0;TQ903I>DP0aBDd0>E5E03A<C`0hD5<0>E5C
0080>E5A00`0>55?03UBC`0iDTl0>55>03aEDP0hDDh0=Di;03I?C00eCT/0<da903E>B`0hDDh203YC
D00:03M@C@0dCDX0>U1>03mED`0nE580>Dm=03eCD@12F5H0C69P03I<BP80?59@00X0<DM503=9A`0f
C4T0=T]603Q=B00kD4/0=TU30354?P0bACl0;Chf0P0`@CT202`l<P040393>`0`@CL0<D8h03E7>`80
=TPl0280=DLk02Xk<`0]?SH0<40m02dm?00dA440;Chd02`m=00a@S/0=4Do02e0?00hBdX0>di>045D
EP0lCe<0AeYQ049EG015Ff<0B61Y04URJ@15GV80?EEF03]AD00hCD`0;40n04=DE01XN7L0QIBD03e;
CP0c@T40;C`g02hm>00a@3/0<T4l0P0^?CX04@0Y>3D09cDe02Hd=00/>SX07R`]02dl>@0^?CH08c8[
02Xi<P0M;2D09C8[020[9@0K9R007BPR02`e<00_>3<08BXU00807bPS100Q:RD00`0N9b807BHQ01hW
8P0301dV8@0J01/T8@0M9R<082TV02<Y9`0R:2H082HT01`P7`0M8B007b4P01`N7@0K7A`07AlN01lQ
7P0H6QL07R0M01dO700P8Ql07R0M01/M6P0G6AH04Q@A010B3`0C5A805QPE018D4`0F61L201PJ6@0L
01TK6P0J71/08R@S01LI600Q8b808R@S01PJ6@0S9B@07QlQ01XK700Q8b00@dE20;>e/014ASl07AlH
01PJ500D5Q<05ALF01PJ6@0H6QX05QHD01<D400B4Q004a<A01@D4`0B4Q803`l?01DE5P804a<E00l0
5A@I01<C5@0A4A804Q8B014A4@0S8b<05QHF00`<300G5aL02PX:00/;2`0?3`l03Ph>00l?3@0@3``0
0P0@3`d01@0A40h04@l@014?400@3Pl040hA00804@lB00D040hC010>4@0=2`d03P`=00/92P0200l=
3P0=00T7200A3a005A<D00/92P0>30d030X;00d;3@0=2`h03`d@010>4@0A3a805A<F018@4`0500d;
3P0300l<3`0@2`l03`X>00<03@P<01D03PT=00@00`0C3Q803`X>00d8300N6Ad0NGAh00h:3@0;1PX0
2PD901LB5P080`L040/?00/62P0=20`04PdA00h93@0<1`/03PT=00d8300<1`/00P0>2@d0100=20`0
20@700l:3P0E41@200X52@0I01hI7@1YHfD09R0R00h92P0<1PP03PP:018<3P0>20X04P`>00/51`09
0`D04`d?014;3@0B30h030H800h82P0A2`d03@P9010:300=1`T01000018=3P1SGEl07ALI00d72@08
00d72`0600l93@0@2Ph0DTe@02XU:00@1@T03`@80P0>0`L0100?10P040D901052@0?10P200h31`03
00l4200@1@Wooooo01?ooooo000Kooooo`0601LI5P0D5Q<04A<@02X/:@0M7a/00P@00P0@4``02`0?
4P/03Q4800hA200=40L02Pd600hA2P0=40T041<<01DH4@0@4``030l80080:B`U00@04QD>01<F3`0L
7aP03Q0;0P0A4`h400lA300800h@2`0=3`X03Q0;00h@2`0?4@`0418?00h@3@0=3``2018D4@0800d?
300D5Q<02@/800X<2@0=3``0;S0]03Tk>00?4@`201@F4@0I00/=20082PD03@l:00h@2`0;3@P0418=
014C3P0;3@P03a4<01TK5P0E5a8030h901<E400@4Pd02`d801@F4@092`H030h900@60@0K7AP06A/G
06IXI@0;3@X020X700`>2`0200d?300700P:1`0?4@h030h;01<E4P0:30T03a4>010B3`0200/=2P03
02HX9@0@4Pl04aDB00802`d:01804A<@01<E4P0>40d02`d900/=200<3PT04aD@00X<1`092`H03a4<
00h@2`0A4`h0418=00/=200=3`X0:R/V01hO6P0?40/200`=2003014B3@0>3`X03Pl:00<03@h901/0
30d8018G4`062`L03A8>00/@30083@T04aPD00870`0a=S802Pd:00dB3P0F6aL0>d0l00T;200;3@X0
4aDB00L91P0];b`0fM_H04A6@`0=3``04aDB018D4@0620D03a4>00d=2`0?3`d00P0@40h00`0?3`d0
3@d;00l?3@0200d=2`0A00h>300@40h03Q0=01DL5@0H8QX04A/C00P?200V;BH061lH00T>200;40X0
314;00h@2`0=3`X02`d8014B3@0@4@`00P0?40/01P0B4`h051D@018C3P0A4Pd0414<00h?2P803@h9
00H03Q0;00lA300A4`h051HA01HH4`0G6A@400h@2`0D00d?2P0<3PT020X500D70P0:30L04Q@?00h@
2`0:30L03Q0;00`>2@0;3@P0418=00`>2@0A4`h04A8?01lQ70000@003Pl<02<U800U9b8200d?2P0>
00lA300;3@P030h9010B3P0>40d030h;00/=2P0<3P/03@l<00/=2P0E5a@02`d:010B3`0:30T200lA
3P@03Q0=0P0?4@h500h@3@0300l@3@0?3`d03`l=00H03`l=0P0@40h02@0A4@l02@/:01@F5@0?4A00
4Q@C02`^;@1<CT/04A<@00lA3P02010B3@0B014C3P0Q91`0Z:^R0?KikP1JGE@07B0G01HI400=40T0
8B<N01@F4@0M7a`09BLV014C4P0<3P`04A<@010B3@0>40/0418=0P0A4`h0200F61<08B<N014C3P0G
6A@05ALB01hP6`0?4@h03Q0=0P0<3P/00`0?4@h04A<@00h@3@0200d?301100h@3@0A4a004aD@01<F
3`0@4``03Q4:010B3@0B50l04A<>018D4@0C5A<04A<B010A4`0B4aD05QPG01<E400<3`P04aH?018D
3`0C5A40MWQc02d_;00A4a404Q@C01LH6P0?41805AHH00X>3@0?4a80310?00hB4@0?4a80310?01DI
600J7Qd04ADD020T8`1YKF`03A4@01DJ5P0F6aL0724M00`A3@0H7AT0AT]701dR7P0N8al08bPT00D:
1P0>4`l01``8010E4@0J7a/0:BhZ01DJ5P0B5a<04aPD01HK5`0D6AD061dI01DJ5P0F6aL07b@P01PM
6@0B5a<00P0C61@01@0C6AD061lK01LP6`0F7aX051hI00804QdG01D051`G01LM6@0I7a/06R4M01TR
7@0H8A`06B<M01HQ6`0E81X06RHP01/X8@0L:B808bhX020Y900M9R407bTS01hY8`0O:R@07BTR01TV
7`0H9b000`0K:R<01@0J:b4062XN01X[8@0O<2H07BhT00807c0X02/06BXR01//9P0L;BL07BhX01l`
:P0J;BT0:chj014T800H:bL07C0/028e<`0W>CT0:3Xj01/];@0S=CL0:3Xl028d=P0R=SL09c/l02@h
>@0V>Cd08SDi02Hk?P0Y@DD0;TI:02e4BP0X@DH0:T=802U2A`0W?440:Sm202Hk?P0U>S/0;45202Pm
?@0R>3H093Xg02Lm>P0W?SP0:D0j02a3?@0Y?C`0:3`m0080:cm00100;4520397B00cBd/0<DU902m7
A`0^B4L0<Ta;03E?CP0kDeD0=4a@04ALH00Y@D<0<TY<03UAD`0dC4`0=4a;0P0cC4T0200eCT/0=Tm<
03YCD00iDTl0>55>03I?C00eCT/0=4e:0`0hDDh02`0gD4d0=Tm<03E>B`0nE580@UQF03mED`0jD4h0
@eUG04eSH@15FeT0=4Y80080>U1>00`0<TQ603I<BP0`AT<0=T]603U>B@0jCdX0=dY403I9@`1LKfT0
?Tm703M8@00jBd<203Y:@00503=4?00_@3H0<T<i03Q:?P0iBcl00P0gBCd0A00fAcl0?Tm703Q8A@25
UI@0<d=002Li;P0]?S@0=TLo03]<AP0iC4X0<D=203]=C@0_@D<0AUQK04=FFP14Ee/0BEmS04MPI@16
Gf<0@eaM03iGE00mDe00?E1>02@g=@18F5L0AEAD06IdM@0_?D00=4=203Q7@P0fAD00=4<n0350>`0]
?3T09SDb02hm>P0[>CT0;C/k03m=C@0G9BH08S0^02/j<`0Q<2T09SD^01h]9P0U<R/07bXT01XU7`0I
91h08BXU02</9`0M9R407RLR01lX8`0P:B@08BXU028[9P0S;2L08R/V020Y900N9b8072DP01/T7`0H
8A`0624N01XS800N9b@092XX0P0U:bT03`0J7Qd0720O020R8@0N81l071hM01dO7P0P8Ql0;Bl/018D
4@0e=c@0Q8J304E7A00B51404aDB01HH5@0201@F4`0901/M6P0H6QT06Q`K020R8@0O8B006adL01dO
7P0H6QT06Q`K00804A<B02X05aTH00lA400K7AX0:2XU020S7017BT40cM3504I9?P0H6a005AP@01<E
400E5a@05QPI01DF600F5Q@04a@@01<C4@0E5A<051@C00h>3P0H61P07alP01TI6`0D51H04a8G014A
4`0A4A804Q8B01<C4`0X:2P061PH00`<300A4A405ADE01PH600B4Q803`l?01<C4@0D4a004a8@014@
3P0?3P`200d;3009010>3`0A3a803P`?010>4@0A3a@03`d@010>400?3@h03P`=00804a4B00<030X;
010>3`0;2@X00P0<2P/01P0I5aP02`T;00l=400@3Q403P`?00d;3P803P`?1@0<2Pd00`0=2Pd03PT=
00h93@0300l:3P0;01LB5P0I51P07QTM00P31`070PH020<703Td>00C3Q8061<G00X52@0J5AT00P0>
2@d01P0?2Ph03@P<00h93@0910P04@`@01HA5@803@P<01003PT=00l:3P0=20`04`hB00`72`080`L0
3`X>010;3`080`L02@<500D00@0?2@/0100000L10`0<1PP01P020P0=1`T0100<1PP04P`>010:300A
2`d200d72@0:00X41P0600803PP:00d72@0;1@L0100001lI6`0E3a402`D700d72`<03PP<0P0?2@d0
200C3A404@/?00H010040080G5IJ01XD600@1@T03`@80P0>0`L0100?10P040D901052@0?10P200h3
1`0300l4200@1@Wooooo01?ooooo000Kooooo`0600T;200K7AX05ALD01/M6P0?4@d03Q0;0P0>4@X0
4@0?4P/03a89010C2P0@4`X03A09010C300?4P/04aH?01PK500B5@h00@@001PK500F6A801PT200P;
100=40T03a4<00804Q@?0P0@4Pd0100A4`h03a4<00h@2`0=3`X200h@2`0F00lA300?4@h03Q0=00d?
300D5Q<04Q@A00X<2@0<3P/03a4>010B3`0H6QL0DeEB071bK`0A4`h05QPC01TK5P0@4Pd02`d800lA
300@4Pd03Q0;010B3@803a4<018030h900H80`051`801PP300lA300A4`h03Q0;010B3@0>40/03@l:
00h@2`0B50l02P`801TK600D5Q<03a4>00/=2P0?4@h200h@3@0H01/M6P0A4a0020X700@60`0H6QL0
008000/=2P0h>SL0MgUf01hP7@0620H03@l<010B3`0C5A804A<@00`>2`0=3`/04A<>00h@2`092`H0
51HA010B3@0>40/030h90P0?4@`01P0;3@P03a4<034b;@0T9B0051D@00l@2`803@h90`0>3`X0100=
3PT030d800`=200;40`200L=2@0A00T?2`083PX03Q@@00lE4@2CVID07R@P00H<200D6QH041HB018D
4@0?4@h030h;01<E4P0H6QL05aTF02@V8`092`P00`0?4@h00`0A4a003@d;00l?3@02014A3`0?00l?
3@0=3@/030`:00h>300=3@/030`:00h>300?4@h0<CPa030j<P074@T031H>00dF3P0?5Pl02a0:0080
2Pl900<030h900d?2P0=3`X00P0>3`X400l@2`07010A300C50l04Q<>00l@2`0D5A0061TD00`>2@02
00d?2P<03a4<00@030h900d?2P0>40/03Q0;0P0=3`X0100D5Q40418=00h@2`0?4@`2014C3P0B00h@
2`0@4Pd04A<>00/=200<3PT020X500X<200A4`h04Q@?010B3@0;3@P0;BlZ00h@2`0=3`X0418=00X<
1`0;3@P03a4=0`0=3``02@0>40d03a4>00`>2`0L7Q/02@/800d?300?4@h05QPE00lA3P0200`>2`04
00h@3@0@4Pl04A<@010B3`D03Q0=00<03a0>010@3P0?3`d00P0?3`d08P0@40h03`l=00h>300?3`d0
4A4?018B400C4a404Q@C01/M700=3`h00040014C4P0F61D02@/8010B3`0G6A@03@l:00`>2@0W:R80
/;>Z0??fj`1DEdh04aH=00lB2@0@4``03a4<00D70P092`P061XI014C4P0>40h03@l<00d?2P0>40/2
00d?2P09010B3@0J71L09bTT00lA300C5A00418=01`N6@0?4@h03Q0=008030h;00@03a4>014C400>
40d03Q0=0P0?4@h07@0@4Pl04A<>01<F3`0>4@T030l800hA2P0A4`d0418=014C400C5A<04Q@C010A
4`0@4A@04Q@C00h@2`0;3PH04QD>01/N5`0G6Q@0JF]V02PZ9`0E5aD04Q@C01@E5`0@4A@04a@F01<G
5P0D61L03Q8A00803A4@03l02Ph=00hB4@093@`06AdL020T8`0m@D0051PG00D:1P0:3`/06AhJ01HK
5`0Y;RX0FUmK02T^:P0>4`l04QLC01@I5@0H7AT04aPD018G4`0b=c<0PhR401hS7`0B5a<05AXF014F
4P0D6AD06QlK01PM6@0Q9R80<SLc01hS7`0E6QH061dI01/P700H7QX06R4M01PQ700G81/05AlJ01@O
6@0E81X05alJ01XP700K8Ad072@O01XS7P0I8Qd072HP01TT7P0H8ad07BTS01dZ8`0N:b@09S4[024Z
9@0L9B007RPR01/V800J9Al072PQ01`Y8P0K:R<00P0N;BH02P0M;2D06b/Q01T[7`0N;bD08S<Y01h_
9@0O<2P07RlW01PY8@0I:R@201X[9@0/01//9P0O<Rh06bhZ01d`;00U>3@05bXV028e<`0R=3@0:3Xj
020b<P0U=cT09SPj020b=00T>3T09SXk02Lk?00T=c/09CPl02Ll?`0U?D40:41402PoA@0V?d@0:456
02M0A@0S>3d09S]0028g>P0V>c`0;dA502Dk>@0S>CL09S`i02Ln>@0U?3H09C`e02Po>@0/@3l0:3`k
02e1@00_@d80;D9002m5@`0^Ad@202m8A@0C02m9AP0aBdP0<Ta;02m7B@1=IFP0O9BF04aTIP0hD540
;DE503=;B`0bBTT0<DY7039;B00dCDX0=Di;03M@C@0iDTl0>55>03M@C@0203I?C00603UBC`0gD4d0
=Di;03I?C00iDTl0>eAA0`0kDDl0100mDe40@eUG04ILFP13FEL203I<BP0g03=9A`0/@T00;D=102m5
@P0dBD@0<dQ30356@@0dAd40>4]505=VH00gB400;d0h0311>@0c@cT0=THl0352>P0]?S@0<44g03M9
?@0hBSh0=DLk0394>00Z>c<0=TLo0351?P1]OG`09CDb0311=P0b@cT0<T<k0393?@0eAD@0<D9104AF
EP0fB4X0CEmQ045CE@1LKW00@EIJ04AMH@11FEd0@UQJ045GE@0nDU00@EEA03E8A01<G5/0>DQ802Le
=P10CU40BUQG03m>B@0jBD@0=D@o0391?00202ln>`0A01<R7`0N;2`0>dU909j/[00`?Sl09S@a0392
>00W=bd093@Z01l_9@0Q;RD07RTQ01`W7`0I91`072HN024[8`0W<BT00`0Q:RD02@0P:B@08BXU028[
9P0S;2L082TT01dV8@0L9B006b@O01LP6`0201PQ7P0;01XS800M8b407R@R01lU8`0I7A`0720O028T
8`0P8R407AlN01`N7@0K7AX00P0H6QL0<P0E5a@07b4N01HH5@0A4a005QPE01`N6`0H6QL04A<@01PJ
5`0L7Qd06Q`K01dO7P0K7A`06A/J020R8@0R92<05ALF01/M700L7Qd04Q@C01PJ5`0>40/082<J01dP
5@0C5P/0CU9401XN400D60X04aH=018D3`0D5Q<05AHH018C5@0J6QP04a<@010@3P0C4a404a<B010@
400F5QH07AdN01PH6P0C4aD04a8G018B500?3a004Q8B00d=3@0I6AT0410@0P0=3@d02@0?3`l0410@
00X:2P0820P03@d;01DD4@0C4Q004Q4?010?3@0200d;300700h<3@0?3A002`T<00d;3P0?3A8030X=
014?4@0200l=3P0501DC500D4Q<03@/<00h<3@091`P00P0F51D01`0@3Pl02`T;00l=400?3A0030X=
00X82`0;2@`01P0=2`h00`0>2`h03`X>010;3`02010;3`0D00l:3P0;1PX00`0200<00P0>2@d071LK
00h93@0300801`86018=4@0C3Q805Q4E00l:3P0<1`/03`X>018=4@0A3100100300X52@0D3a<200h9
3@8040/?01403@P<00T4200=20`03`X>00/62P0:1@T040/?01H@4P0=1`T01`4301<=3`0L5QP03PP:
00T31@0<1PP03PP:00d72@0200h82P803@L900X04`d?01PB500K5AL03@L900`6200C3@l040X<00@0
000A2`d020<40P0<1PX200d72`803PP<00P02`D900d82`0?2@d07ALK01H@500>20`040D900l42080
3P<700@03`@801052@0@1@T03`@80P0>0`L00`0?10P040D9ooooo`0Cooooo`006oooool04@0=3`/0
3Q0<00h@30072@D0418=01<E400;3PP03@l900hA2`0@4P`041<<010B300=3`T03Q4;00/>200>4@/0
4QD?00802`d700D03Q4;00lA2`0@4`d051H@014D3P03010B3@<03a4<01003@l:00lA300A4`h02`d8
00T;1P0A4`h02`d9018D400<3PX04A<?00d?2`0?4@d04A<?00`>2P0=3`/02`d90P0@4Ph200h@2`0X
014C3P0?4@`02P`700/=200>40/04A<>010B3@0<3PT04aD@01PJ5@0D5Q404aD@010B3P092`H030h9
010B3@0>40/0418=00h@2`0B50l030h9014C3`0B4a00O7ij024S7`0620@05ALC014C3`0?4@d0418>
014C3`0O8Ad05QPD00lA3@082PH051HB00`>2P0S9B401`T500lA3@D03Q0<01H02P`8020R7@0A4`h0
30h902X/9`19BdH071hI014C3P0<3PT03Q0;00`>2@0?4@`03@h900T;1P0;3@P0418=00h?2P0?40/0
3Pl:00h@2`0?4@`03@h90P0<3@P01P0>4Pd02Pd9018F4@0N8Qd03a8>00hA3@803Q8=01<041@?00X>
2@0A51002Ph900l@3P0=3P`0414>00P91`0;30X03Pl=014B3`0<3@/051DB00P91P0@4@h030d;00d>
2P0>3`/03`l<0080410=01003Ph<014A3`0@40l03Ph=00L71P0C4a805AHC00H8100>40`04AHA00/?
3@0>4a403A8A00`B400<4@l03A4?0P0=3`/04`0@4@`03Pl;00`>2P0<3PX03a0<010B3P0@4@d03Pl;
018C3`0C51003a4=01<D400I6aL03a4<014C3P0<3PT05aTD00`>2@0@4Pd00P0;3@P0700=3`X03a4<
00/=200>40/02@/700h@300<3PX02`d9010B3P0A4`l03Q0<010B3P0C5A403Q0<010B3P0:30P03@h;
00h?2`0?40`02P/8018C400:2`P03a0<014B3`0B4`l03@h:00`=2P0>40`200d?300A00lA3P0A4a00
418?014C400K7AX02P`900d?300D5Q<05aTF00h@3@0=3``02`d:018D4@0A4a004Q@A00`>2`0=3``0
0`0>40d05P0A4a004A8B00d=3P0>3@l0518A01<@3`0A3P`040l<00`<2@0@51002@l;00hI5`0F8Ql0
314?01HH5P0@4Q002@/901@F500>40d04Q@A00lA3P0?4@d2018D400J01@F4@0R91d0?T0h01TK500A
4`d02P`600`>200F5a80>S`g034c;`0:2`L04A8>014B3`0<3PT03@l:00h@300@4Ph02@/9010B400>
40h05QPD00`?2@0?4PX02Pd400/>1@0A4`d300h@300300lA3@0A4`l03Q0<00@03a4=01D03a4<010C
3@0=40X03@l900lB300@4`d03Q0;014C3`0B51004Q@B010B400?4A003a4?00d?2P0D5Q003a4;01PJ
5P0?4@d051HB014C400B51400P0B51805P0C51D051DE01lR7`0L7a/04aHB014D400B5A404AD@010D
3`0B5Q404A@@01TL600D5a<03Q4=01DJ5P0B5a<041DA014F4P0@5A405AXF01<H500I7QX201@I5@07
014F4P0F6aL05QTF03@h=01nPGh09BPU01@H500201<F4`0T01@H500H6aP04QHB01PK600S:2@06QlJ
01<I500H7QP082LQ01@L5P0H8Q/05R0J01PR700G8Q/04AdF01LS700K9Ah06R@M01dU7`0K9Ah07BLQ
01hX8@0K9b007B/S024]9P0M;2<05bLO01/Z8@0R<2L082`T01dY8P0O:b<07B`S020/900S<RT093<Z
0P0R<RT0100P;bL072`S01`/900M;bL201d_:00;01X/9@0L;RL0838/01T[9P0O<B`07BlZ01T[9P0M
<2/07S4^01``;@0M<2d00P0O<Rl01@0T=cD07c8a02Lj>@0V>CP093Lf00808SDd04808cLg01hc<`0W
?3d0:Ce002<g?00W?4809ce302PmA00X?T@0:T1402U2A00X?T00:3`m02a0@@0U>CX0<DA503U>C00Z
?S`093Pe02Lm=`0X?CH0730Z02@j<@0W?CL0:d9102Y2@`0[@d@0<4I802e3A@0`B4L0<4Q902m8AP0a
BDP0<da:0359B00^A4D0>U5C02e4A`11F5X0=Ta?03M=D00dBT`0=Te>03U?D@0dBdX0;DA504=JFP0k
De@0=Ti?03I?C`0jDe40>55>03UBCP0fCdX0>e=>03A<B00bBDL0>Tm>03iCE@14FET0=de:03=8AP0g
C4P0?55=03Y@C00iCd/203I;AP0A03E:A@0bAd40;T@n02i3?P0cAd80<TI002m3?@0]@C`0<dI003Q;
A@0^@C/0<48k02i0>@0dASl0>de603Q:@`0iBd@00P0dASl0A`0iBd<0>DY103i?AP0kC4<0;clh03A4
?@0b@S`0;clj02hn>00_?cD0;clf04=CC00c@ch0?Ti=03]<B`12De@0>D]>045CEP18FUl0LhB:059U
J`16G640@UIL03eBE010De40>dm;03M;AP1FJF@0?e1<03]<B`0lCTd0>dY<03Q7AP0jBD@0<3lj0391
?00Y>3<0<D0l02Dd<00b@Cd0:3Lc024`;@0iB4H09S@c02Db;@0c?cP0;SXc02<_:00Q;BH08bhW020Z
8`0O:B<07RPR01hX8@0R;2D0:cD^028/9`0S;bX082/V024[9P0R;2P07RPS01dW8P0H8Qd07RLS01XS
7`0L9B407BDQ01PQ7P0P:BH07RLT00807R@R0280728P01TM700K7ah08B<R020R8@0N81l06adK01TJ
5P0K71L07b4M01HH500E5a<06AXH01PI600`<C00@dA501/L7@0B4a@071dM01PJ6@0G6AP071hM01DG
5P0G6AP06adL01lQ800G6AP0@49103m1@00E5aH07R0N01`M6P0D5Pl07R0I0P0E5`l0:00K7AD051H>
01<E3P0B4a004a@A01@E500C51<06ATF01DF4P0B4Pl04A8>01<C4@0C4a804A4@01DE5@0C4a@04Q8C
01@D5@0E5AH0410@01XJ6P0@41003`l?00/;2`0B4Q805ADE010@400B4Q803`l?018B4P0A4A404Q0@
00l>3@0@3Ph04Q4@014?400?3@h04Q0A00l=3`0>30h2010>400C00l=400>31004@lC014?4@0?3A00
4@lA00`:300B418030X;014?400>30d02`T:00l=3P0>30h03@/=00h<3P0?3@l04@lA01<A4`0200`:
300T00l=3`0=2`d030X<00d;3@0A4180510C00d:3@0920X040d?03Xg>P0c<S@030P;00h<3P0;2P/0
3PX=01<@4`0@3A0020D800d8300910P03@P<014<400@2`l05Q0D01PB5P0<1`/030H:00d9300:2@X0
40h@038^<@0]:B/040`>00l:3@0B2Ph04@T=0P0=10P01P0?1PX030D700l92`0>20X02`D700T41@<0
3PP:0P0?2@/04P0=1`T03PP:00X41`0=2P`04`hB00L21`0@3@l0@Si201LB5`0;2@X0<bhb00l93P05
0`@050hC00/52@0;1@P03`T<010:3@<030H900D03@L:01LA500;1@P02`D800h82`0201052@0:00l4
200>0`L040D901<8300?10P040D900l4200>0`L03`@801462QCooooo000Kooooo`8030h90P0=3`X0
100<3PT02`d800`>2@0=3`X300h@2`0>00d?2P0>40/03a4<00`>2@0>40/04aD@00d?2P0G6A@01`T4
00d?2P0E5a80418=0043000?4@`200h@2`803@l:0P0<3PT03`0;3@P00040018D3`0K7AP0004000h@
2`0I6aH04A<>018D3`0620<03@l:010B3@0?4@`03@l:00`>2@0200/=200600h@2`0<3PT03@l:010B
3@0A4`h0418=0P0>40/01P0=3`X02`d800h@2`0;3@P00P@000L9108071hI00<03a4<00X<1`0<3PT0
0`0=3`X03`0>40/03@l:0084001@DTd061XE0002000A4`h03Q0;00d?2P0;3@P03@l:01DG4P0A4`h0
30h900h@2`0400lA300B00h@2`0;3@P02P`700h@2`0A4`h0418=018D3`0620<03@l:01<E40000P00
<cD`028T7`0C5A002`d800lA300:30L02`d80P0=3`X00`0<3PT02`d800/=200200X<1`0<00`>2@0?
4@`03Q0;00d?2P0?4@`02P/600L80`0B4`h05QLB00D60@0?40/030d80P0?40/0AP0>3`X04A8=014B
3@0>3P`01`L503@d<P12@T003`l=00h>300820H04A4?00h>300<30X051@B00L80`0<3@P03a0;014B
3@0B4`h0410=00/;2@061P@06QXI01dM7@0G5aL010@400@30@0<20L05a<A01`L6P0E5AL020X=00T=
400=4QD0310B01@H5`0@4Q40418>00X;1P0I6aP04aDB00lA3P0@4Pl04A<@00lA3P0@4Pl03Q0=018D
4@0A4a002`d:00`>2`0@4Pd04A<>00P:1@0C5A000`D000L9100<3PT02`d800d?2P0>40/02P`7010B
3@0<3P/03@l<00/=2P0?4@h04aDB014C400?4@h200d?300300h@3@0=3``02`d:00803Ph<0P0A4@l0
2@0@40h04A4?010@3P0B4Q00410>00h>300?3`d04A8@010B3`0200h@3@<0418?00@03a4>00d?300>
40d03a4>0P0@4Pl060082PL04A<@00L81P041P<051HC014C400=3``03a4>010B3`0C5A8061XG02LY
:@0P7b@03P`?00T41P0>1@H04`/902<O7011@Sd041HB00`I5@0kDT`0WkJb02@]:P804A<@00`03@l<
00L91P0>40d03@l<00lA3P0@4Pl03a4>00h@3@0?4@h04a@?018C3P0A4Pd3010A300D00X;1P0I6QD0
61TD00d>2@0F5a8061TD01@G400I6aH01PP500L9200<3Pd03PlA010B4@0?4@h03a4:010C200@50H0
3A4300hA2P0<3PT2010B3@0400h@2`0A4`h030h900d?2P803Q0;0P0@4Pd00`0?4@`03Q0;00lA3002
014C3P0300lA300@4Pd04A<>00804A<>00/0418=00lA300:30T05aTF02LY9P0U9b@05ALD00d?300@
4Pl03Q0=01<E4P0201@F4`0=01dO700D5Q404aH?018E3P0C5Pl05APA01HI4P0C5Pl04A@=01<F3`0A
50d03a8;018D3`06014F4P804QLC02P04aPD01@I5@0D6AD051TE01HH5@0I6aP06adJ01TK600E5a@0
4aDB01@F4`0F61D06Q`I01TK600J71T07B8N01LM5`0B6A809bhW02hh<00F81P04Q`D00lJ4P0J9Ad0
5B4I010M500D8AP04alF01XU7@0K9Qh06RDM01hY8@0L:B006BPN01TY7`0N;R@093D[01d^900J:b40
72`R0P0M;B<201/[8@0301d]8`0Q<BL08C4W0080830V05X07RhT01/[8@0K;BH072l[01X]:@0H:bL0
6RdY01`_:`0G:RH07C0/01LZ9P0P<bl0:chj01ha;@0K;bd07S8`02Lk>@0U>CL0730^01T]:`0P=380
7C4_01/_;@0Q=C<09SXh02@h=P0S>CH08SPe02Dj>`0V>d00;T=80314C00Y?DH0:Si502]0A00[@4<0
:d4o02Y0?P0Y?3X0:3/i02Hi=`0^@Cl09cXh02`o>`0U>3807c8/02Pk=@0X?3<0:clf02@i=00Y@D40
:DA602U3A00cC500;dU:02i8B@0bBT`0<DU:03=;B`0eCDd0=Da<03=8B@0bAdX0=DY=0397BP0`ADP0
<TM:03U>D@0cB4/083Dh049GFP0lDE@0BUmR02Lo@@0nEUX0=e5C03==C00Z@d00>55<04=ME010Edl0
>Di:03I:B@0oDe@0?4mD03]>DP0gBdP0>Di903eBC@0hCDH20356?`0403=8?`0gC4<0=da30398?080
<4Hj03@0<dI003I9@`0eB480<D@n0395?`0dAd40=DQ203a?B@0^@C/0;3li03M:A00mD4X0=4M303=6
@P0Y?3P0>Te803U:A00eASh0=4Dm03=2>`0c@cT0=DDk03A1>00a?SD0;c`c03a;A02a`;X0?Da7024a
<00nCTh0?Te@041BEP15EU`0BEYQ04YKH`19FV<0A5EM03i?EP0iBdh0>Da:03=6@P0dB400@UI=049E
C`0lCd/0?4m=03e?C`0iBTL09cHa02/j=@0b@C`0<3lj0P0X=c802`0]?3L0:cXe02/j=@0]?3L09cHa
02Pc;P0V;bX0:34/02D^:@0O:2<06b@O00808R/V0P0Q:RD0;00R:bH08R`W01lZ9P0Q;BT08bl[01hZ
9P0Q;BT072LS02D`;00G8Qh07BHS01HO700J8b005Q`J01PQ7P0S;2T06b@Q01`R800M8b406R0N020T
8`0O8b807b4P01`N7@0J71/061XH01HG4P0L7AL06a`F01LH4`0L7AP071`J02PX:00H61T0:2PZ018A
5P0K6Ql04A4C01XK7@0Q8b807b4P01HH5`0K7A`06Q`K0P0E5aH0300N81l071hM018D4`0E5aH05ADC
018B400G5aD06ATG01`L6P0U9B<05ADC01<C4@804A4?00<04a<A01DF4@0A4Pd00P0D5A001P0B4`h0
4a<@01HF500B4Q004A4@010@40804A4A01d04Q8B01PH600<30`02@T901HF5P0B4Q80410@014A4@0>
3Ph05ADE018B4P0I6AT04a<C010>3`0>30d03`d>014?400@3Pl03`d>00d;300F51D06QPI01<A4P0<
2P/03P`?01TG7@0<2Pl03@/@00X83@0201DC5P0J00T72P0610D02`T:00h<3@0J61T040h?01lM7P0^
;2d040h?0040000>30d0518C00/92P091`P040h?00l=3P0>30d0BdY;0410@00:2PX04Q8B014A4@0C
4a<0N7Qh07AdM00Q8B4200H61P0;00P8200=30d030X=00`:3@0<20`030L;00d8300>2@d03@P<00h8
300?2@d00P0@2Ph02@0B41802`d<020P803oo_l0bLO801hH6P0B2@`04@P;01<72`0201<42@0901<3
200A20/03PP:00h82P0=1`T03PP:00l92`0<1PP03@L900803PP:0P0=1`T07`0>2@d05Q@I01dI7`0?
2Q005A<H04A0AP0:1@/00@0403Hc>00300@00@0400T52@0<1PP0208400P3100;1@L03PP:01@>400J
51H03PP:00X41P0;1@L03@L9018<3P0>0`L040D900l4200=0PH03`@801@93@0>0`L00P0@1@T00`0>
0`L03`@801052@0Dooooo`006oooool0200;3@P03Q0;010B3@0A4`h03a4<00d?2P0?4@`03Q0;100=
3`X03@0>40/03a4<00d?2P0?4@`04Q@?00d?2P0:30L05QPC00<5000;3@P0008001lQ700@4Pd00P0?
4@`200h@2`0=00d?2P0C5A000P@001PJ5@0B50l03@l:018D3`0<3PT04Q@?00h@2`0B50l02P`700d?
2P0400h@2`0600d?2P0<3PT03Q0;00`>2@0>40/051HA0P0E5a803@0@4Pd02`d800/=200>40/030h9
00d?2P0?4@`061XE01`N6@0;3@P03a4<01DG4P0>40/00`0=3`X0500<3PT051HA00h@2`051`8051HA
00X<1`0H6QD04Q@?010B3@0?4@`03Q0;010B3@0=3`X020X500X<1`0=3`X0418=00lA300>40/03@l:
0P0<3PT0=@0>40/04A<>010B3@0C5A00004000h@2`072@@01@L200`>2@0G6A@03Q0;00/=200=3`X0
2@/600`>2@0=3`X0418=00`>2@0=3`X051HA00h@2`0=3`X03Q0;010B3@0>40/03@l:010B3@082@@0
51D@01DF4@0=3PT020T4014B3@0=3PT0414<00l@2`0=3PT0414<00l@2`0E5A<01PH4030`;P10@3h0
30`:01@D4P0=3@/03Ph<0000000D5180410>010A300;30L03@h800803a0;02@03Pl;00h>300>3P`0
20P70000000N7Qh08B4Q00/:200B3Pd02`L600/;2@0D51H030hA01@I700>4aH02@l@01PL6`0D5QD0
7R0L018D3`0?4@h030h;00/=2P0>40d04A<@010B3`0>40d02`d:018D4@0E5a@03@l<00X<2@0=3`X0
418=00`>2@0@4Pd300d?2P0<00`>2@0>40/030h900d?2P0A4`h03Q0=00lA3P0<3P/0418?01<E4P0A
4a003Q0=0P0<3P/02@0>40d03@l<00/=2P0;2`T020P600d=2`0:2PP010@200H61002010@3P0800l?
3@0>3P`04A4?01DF4`0D5Q<04A<@00d?300<3P/2010B3`0[00lA3P0@4Pl03@l<00/=2P0>40d0418?
01TK600B51404A<@024S80000@003a4>00`>2`0=3``03Q0=010B3`0D5Q<04a@E00X;3`0<30h061DF
01`F5P0G4Pl04`l<02`]:00320@04AhJ04UNF@2ldLd02a@A00@60`0E5a@01@L400/=2P0C5A803a4>
00h@3@0<3P/03Q0=00lA3P0>40d04A8=010A300200h?2P0N014B3@0D5A003a0;01@E400C50l03a0;
014B3@0B4`h0004000L9100?4@h061XI010B4@0K71h04Q@C010B3`0?4P`04A@;018F200B5PL02`h7
00/=200A4`h04Q@?00lA300A4`h02`d800d?2P0>40/03a4<0P0A4`h00`0@4Pd03a4<010B3@02018D
3`03010B3@0?4@`0418=00<04A<>00L0418=018D4@0D5Q<06A/H01PJ5`0B514051HC00803a4>0P0C
5A801P0D5Q<06adJ010B3@0D5Q405aTD01TK5P805aTD0P0D5Q40100A4`h04Q@?018D3`0?4@`601@I
5@804QLC00D04aPD01@I5@0D6AD051TE01HH5@0201DG500H01HH5@0G6AH05aTF01DG500F61D06Q`I
01TK600J71T07B8N03Xo>`0B61@07bDQ01TR7@0@6A@051hH01HQ6`0L9b404QhG01/X8@0S<2T05b<L
01XU7`0K9R006RHP0P0M:R<0200M:b@062LP01HU7P0O;bL06b`T01`]9@0O<2P06b`T0P0M;RH01@0L
;BD07BhV01l`:00M;RH072dU00807BhV00<06R/S01X/9@0K;RX00`0J;BT01`0K;RX09CPd010S7`0R
=C405BPT01ha;@0L;b/00P0Q=C<01`0T>3H083@b01hb<00/@3h09SXh02<g=@0P=3800P0S=cD01`0Q
=C<07S@a02]1?P0R=cP05R/`03=8C@0I;C@00P0Z?TD0>@0Y?T80:Ci102To?@0Z@3d093Le020c<@0X
>cT0;d90024d<P10Ddl0J7]g04MJEP0hBdD0=4M102Pk=00R=c0093dj02Q1@P0W?cl0;dM902e5A`0a
BD/0<4Q:03=<C@0cCDh0<Ta=03=<C@0dC4h0=4U<03aAE00hCE00<DI903Y?DP0lDE@0;dA705aaM00K
<3<0;T=6041EF00mEEL0=DeA03YCEP15Geh0?eQE03mHD`0hDD/0:D0j03aAC@0jCTd0=TY;0395BP0n
DED0=d]803Y?BP0mDTd0=DY502m4?@0203=8@@0Q03E:@@0dBD00<DLk02m5>@0`ASX0<TDo03Y=A`0i
C4H0<D@n0313?@0dAd407S4[02Pk=@0[?SP0>Te703A7@@0fBD<0=4M103M:A00W>S@0A5M@04EFCP0_
@3P0<D8i0351=`0b@SP0=4@i03=0=P0b?cH0=D8j03Q7@01FIEl0>DQ30080>4Q701P0>dY=03]=D@17
FEh0CUmV04UJH@15EUd0?TmG03U:D@0jC4l0=DQ602i1?@0cASl0?e=:041CC@0jCDT0>Da:03U;B`11
DU00<d8m045@B`0jBD@0>dY501/Z9@0S<Rd202dl=`0902hm>00H9b803ahI02hi=00S;2L082TT02D^
:@0O:2<072DP00<082TT02l08BXU028[9P0S;BP0:3<_01l[9`0Q;BT03a/G01PT800R;BT05b0M02`e
<P17D4d08bTW018H5P0T:RP05QlL01`U8P0F7a`07R@R020V900N928082@S01lS8P0N81l06Q`K01TK
6P0H6QP051D@01XK5P0G61<05ADC01`L6P0G5aD071`L014A4P0K6ad05aHK01XI7P0C4aD06AXL01TK
6P0;3@`05aTH020R8@0B51<08B<R01/M700201DG5P0:01LI600I6aX061PF01@D4P0F5Q@061PF01LG
5@0I6AL04a<A018B4080410>00@04Q8@01<D3`0?40/04Q<=0P0B4`h0100C51005ADC010@3P0A4A02
018B4P804A4A00d03`l?010@400C4a<03Ph>00`<300@41003Ph>00P8200>3Ph02`/;00l?3`092@T0
3`d>008040h?01d03P`=00l=3P0@3Pl03`d>01`J6`0O7Ah04@l@00h<3@0F51L04Q0F00P62`0E4aP0
4Q0E00h<3`0:20/040hA00/92P0=2``02@L800d;30071@H0>3Hg051>C`0?3@h03P`=028P8@0=2``0
2PP900P61`0200`:2`0>00d;3013@T80<30`00410@0>3Ph00@410000000P820030`<010@400[:b/0
7alO018B4P081`P200l:3P0500h93@0<1`/03PT=00l:3P0=20`00`0?2@d01`0@2Ph02PL900d=3@0N
7Qh0f=KG08:0P@0E3a400P0?1PT01@0A1@T04`@901<42@0B1@T04@P;00803PP:00D03@L900h82P0?
2@/030H800d72@0200h82P803@L901h030H:01/F6P0L5a/040X>01HA5@0B3A0071HJ00X52@0e;c<0
50hB01D@500E3a<081XL00@0001@BT`0H5YL014;3@25Oh408Q`N00l92`090`D030H800l92`0@2P`0
3@8600l4200>0`L03@8600l4200B1`/200h31`0401052@0A1PX040D900d21QCooooo000Kooooo`04
00d?2P0>40/03Q0;00h@2`803a4<00@04Q@?00lA300=3`X030h90P0>40/600lA300601`N6@0=3`/0
3a4<010B3@0?4@`02`d80P0@4Pd200lA30803Q0;00T06A/F05YLE`0C5A007AlJ01DG4P0;3@P03a4<
014C3P0@4Pd00P0>40/0100?4@`030h900h@2`0?4@`2010B3@0500lA300>40/030h900h@2`0C5A00
0P0D5Q4200h@2`0:00lA300@4Pd0418=014C3P0=3`X05aTD024S7P0>40/02P`7010B3@803Q0;00d0
3@l:00`>2@0<3PT020X601HH4`0<3PX02`d800h@2`0@4Pd030h9014C3P0B50l0418=00803@l:0P0?
4@`01@0>40/03a4<00lA300>40/03@l:008030h900/03@l:00h@2`0>40/030h9014C3P0?4@`02P`7
01TK5P0:30L030h900/=200200h@2`0K00/=200?4@`020X500lA300<3PT04Q@?024S7P0J71L04Q@?
01<E400A4`h03@l:00/=200>40/03Pl:01HG4P0I6QD05QLB00d>2@0>3`X03a0;014B3@0?40/030d8
00l@2`0=3PT03Ph<00803`l=02<02PX800`<2P0:2PP04A4?00d=2`0H61H0?Cdk00d=2`0F5a803a0;
00d>2@0@4@`03a0;00l?300E5A<04Q8@018B4@0h>3P05QHF00h>3P0H5aD040`<01dK600L71X071`N
00hB500?51L04aTL00X@4@0A5aD03Q8A024S7`0F61<03a4>00h@3@0200d?300K00h@3@0?4@h0418?
01@F4`0H6QL04aDB00`>2`0>40d03Q0;00d?2P0?4@`02`d8010B3@0<3PT03@l:00/=200A4`h03@l:
01<E400>40/03Q0=00lA3P0<3P/03Q0=014C400?4@h03Q0=008030h;01D03a4>00h@3@0<3P/02`/9
00d=2`0C4a404Q8@010@3P0C4a403Ph<014A3`0B4Q00410>014A3`0@4@l0418?018D4@0?4@h030h;
00lA3P0A4a001@0?4@h02P0B51401`T7014C400c=C80GEmL01@F4`0?4@h04A<@010B3`0?4@h200h@
3@0H00`@400>4aH04aHG01@D4`0?30/03`/801<A3@092PD05QTF00dF4`0@7a`0830]014G5@0B5140
3Q0=01HH5@1WJFH0Gf5N01<E4P0?4@h030h;00lA3P0A4a00418?0P0?40/2010A3003014B3@0B4`h0
5AHA0080414<01D04a@?010A300@4@`05QPC00H8100Z;2T0=SPf00P91`0l?Cd04Q@C010B3`0>40X0
41<:018E2P0C5P/03Q4:00h@2`0D5Q405ALB010B3@0A4`h01P0?4@`2010B3@03014C3P0C5A004aD@
0080418=00L04Q@?01<E400D5Q4051HA01<E400E5a@04A<@00804Q@A00<04A<@01DG500A4a000P0C
5A82018D4@0=01@F4`0D5Q405QPC01HH4`0E5a804Q@?010B3@0C5A005aTD018D3`0G6A@06adH01DG
4P06014F4P804QLC00@04aPD01@I5@0D6AD051TE0P0F61D08@0G6AH061XG01TK600I6aP05aTF01HH
5@0H6QL05ALD01@F4`0F6aL0<3Hb018H500D6QH03aPC01hW8P0G8A/03APB01/V800U<BX07BXS01XW
800D81X06B@N01XV800M:B807BXS01d[900K:B806bXS01`/900L;2D08c@/024d:`0201`]9@0<01l`
:00P<BT07c0X020a:@0Q<RX07RlW01d^9P0N;bL07c0X01h_9`0L;RP07C0/0`0N<Bd0G`0M<2`0;d8n
07^>RP0`@cl07C0/020c;`0O<Rh083@b01hb<00P=3808cLf02Di=`0_@d408CDc028f=@0V>ST08SHd
01``;`0Q=C<09C/i02To?@0P=CH0AU]N08BIW@0bAT`0:Si402Tn@`0W?4009CXk02Hk?00W?C/0:3Xi
02@g=P0S=SD0;3lm02Hi=`0gBTL0@UEA02Xm>@0X>cD0:Sdg02`o>00bAT00:3di02a2?`0/@d80=Te<
039:BP0aBDX0;DI803==C`0cCU00;dY<031<C`0gDU@0=Ti@03=8BP0mDU@0=4U;03E:C00cB4X0DfQZ
06UnP00_A4H0;D9403]@DP0eCDh0>U9E03]EE@0oFEP0=Tm<03YCC`0kE4l0?5=>03iCD@0cAdH0?U9C
03e@D`0_@dD0=d]903U>BP0jCT/0<TM203=8@P0jCdT0<TM00356?@0`AC`0<4Dk02m4>P0^@cX0<4<m
0354?P0bACl0<dI00080<TDo00@0LHAn0313?@0W>S@0?E1:0P0hBdD01@0dB3l0=TU202Xn=00mDDL0
?4e40080<T<h02@0;cle0392=P0a@CD0;S``02ll<@0_?3@0;3/d03e<AP0b@C`0<D4n03E5A@0gAdL0
=TQ:03i@E014EE/0@UAI049CF@0oD5H0?e5E03i@D@0_@T00;d8n03M:A00kCdL0?U5;03U<A`0fBDH0
=4I502`m>P0hAd80=dI102ln>@0gAT40<3lj02@c;P0^?CP202dl=`08028a;00oCTT0JWIa02lh<`0P
:B@08b`W01dV8@0O:2<201dV8@0F01lX8`0P:B@08R/V02@^:@0X<bl07BTU03Q4@00O:RH09C4]01dX
900P:BH072DR01hV8`0O9B<06b4O01`R800G81d06B8O01XS800X;R`08RPV01XP7P806AdL0P0M7ah0
6P0K7A`06A/J01hN700G61@07alL02HV900M7A/05aLF01TI6P0O7b006a/M01/J7`0E51T092@V01HG
6@0c=C@06Q`K01DG5P0F61L06A/J02@V9@0P8R405aTH01TK6P0M7ah05aTH0P0I6AL0100F5Q@04a<A
01@D4P0G5aD201@D4P804Q8@00<051@B01@E400A4Pd00`0A4Pd0100A4Ph04A4?014A3`0D51<201HF
5P0A01DE5@0D51@06QXJ00h>3P0J6QX03@d=00l?3`0B4Q80410@00T92@0A4A404a<C01XJ6P0D51@0
40h?01<A4P0A3a000P0=2``06P0@3Pl05aDF01@B4`0B414030X;01<A4P0M6ah0K6Y`014?500:20d0
4Q0E01@B5@0=2`h040hA00X82@0=2``030X;01<A4P0>30d03@/<01/I6P0c<C805A<D00T8200>30d0
3@/<0`0?3@h03P0>30d040l?018B4P0?3`l03@d=00l?3`0=3@d02`/;00T92@0=3@d04a<C00P8200@
41005aDG0P0>2@d01@0=20`030L;00d8300?2Ph03PT=00@03`T=00H03`/>00<30`0;2PX071TJ01PD
5@0A2`d200l62@0501462P0D1P/050L;01@8300A20/00P0>20X01@0=1`T03PP:00l92`0<1PP03@L9
00803PP:0P0=1`T0500=1@X040P=00h72`0>1P/05@dB00d62P0;0`P02`@801L?500A2Ph02`D801PA
5@080P@03`X;02PR900Z92H040X<01HA4P0B30h03`T;0P0C3@l00`0=1`T02`D700d21P0300h31`<0
3`@800D03@8601052@0C20`04@H:00X00`0Dooooo`006oooool0200K7AP05aTD014C3P0>40/03@l:
00h@2`0@4Pd03a4<0`0>40/01`0?4@`0418=010B3@0A4`h03a4<00d?2P0A4`h00P0B50l01@0J71L0
LgE`01XL5`0J71L0418=00803a4<0P0>40/01`0=3`X0<C<^0;Rj]@0U9b802@/600L9100>40/00P08
2PD0200@4Pd03@l:010B3@0:30L04aD@010B3@0>40/03@l:0P0<3PT00`0?4@`030h900d?2P0200lA
30803Q0;00T04A<>010B3@0<3PT030h900T;1P031@0020X501DG4P0A4`h00P0:30L0200>40/03@l:
00d?2P0=3`X030h900lA300:30L07R0K0P0B50l01`092`H0418=00/=200=3`X0418=00/=200<3PT0
0P0A4`h0100>40/030h900`>2@0=3`X200`>2@0<00d?2P0<3PT02`d800`>2@0=3`X05aTD00/=2P0?
4@`02@/600X<1`0;3@P030h90P0?4@`0100>40/0418=00lA300B50l200d?2P0301<E400=3`X03@l:
00803Q0;00/030h900h@2`0B50l04A8=00H70P082@@04A8=00L80`0B4`h030d8010A3002014B3@80
5QLB02/0410>00h>300@40h0410>00d=2`0:2PP01`L5018B400<30X08B4O01<C4@0:2`H04Q<=01LH
4`0R8ah07AhI00d>2P0=3@/03`l=01TI600h>3P03@d=01PH60020P00;b/Z00/91P0:2PP05aPJ02DY
:`0=4QD0:S8d02<Z:`0=4a40310?00dA300620<03a4>014C400@4Pl03Q0=00d?300>40d05ALD0080
7R0M00l04A<@00d?300E5a@03Q0;00T;1P0?4@`04Q@?00h@2`0<3PT061XE00X<1`0A4`h03Q0;01PJ
5@092`H00P0>40d06@0;3@X030h;00h@3@0;3@X03Q0=00`>2`0=3``0418?00lA3P0>40d03`l=01HF
500=3@/020P600`<2P0;2`T03@d;018B400D5180410>00l?3@0<3@/02`d:00h@3@0@4Pl00P0?4@h0
3@0@4Pl03a4>00h@3@0A4a004aDB010B3`0G6AH00`D2010B3`0L7Q/0=cTf01lQ7P0@4Pl00P0=3``0
4@0?4@h04A<@010B3`0730/03ADG01dS8`0M81l05aLE01DD400>3@T05aPC00`>2`0;4@l01a4@010L
6`0;3`h02@/8008020X700H0=cTf038d<@0B5140418?00lA3P0@4Pl2014C400500h?2P0?40/04Q<>
018C3P0@4@`00P0=3PT01@0:2`H030d8010A300@4@`04A8=00802`d801T0=3Ha04U;B00E5a@02P`9
00lA3P0>40d03@l:00hA2P0@4`X03a89018E3P0@4Pd051HA01<E400?4@`0418=01<E400B50l0418=
00lA300>40/03@l:010B3@0?4@`0418=00804Q@?00D0418=014C3P0C5A004aD@01@F4@0201<E4008
010B3`0B51406adJ01dO700D5Q<03Q0=00/=2P0B5142014C408051HC00`04aD@018D3`0A4`h04Q@?
01<E400D5Q404aD@01HH4`0E5a806A/F01`N6@0J71L601<H50804QLC00H04aPD01@I5@0D6AD051TE
01<E4P0E5a@201LI5P0501@F4`0C5A805QPE01LI5P0J71T00P0H6QL06P0K81`03Q@@01PN6P0G7AT0
5b0K020Y900J91l04ahH02Ha:`0kAd0082dV01PU7P0I9Al062<M01TV7`0O;2D07BXS01`[900N;BH0
8C0Y01l`:00F9al07RlW020d:`0N<2P07c0X0P0P<BT02P0O<2P08C8Z02@e;@0R<b/07c0X020a:@0R
<b/08C8Z020b;@0O<Rh3020c;`0L01lb;P0S=S80Sj:N024d<00S=S806bhZ02<f<P0U>CP083@c028f
=@0W>cX09CTh02<g=P0eBDP09SXi020d<`0X?3/09CTh024e=00T>SP0;D=102Hk?00U>Sd0A5UL024f
>@0Y?T<0:Ci102Pm?`809S/l04T09S`j02Xn?@0_@D408C<c02Xm>`0`@d409CPf03=6@P0^@Cd0<TE0
02Hi<`0^@C/0<dI003mBC00gC4L0B5aJ06UmN`1JL6h0<TY:031:B`0eD580<e5C031=D@0bCe<0>UII
04=KG@12EeP0AU]L02]0@@0eBT/0AEYK0:g2``1:Gf00@EIG03I;C00eBT/0?5AD02U1@`1LMWH0MHn>
05A]JP0iDTh0=e1<02]1?P0oE580<DE403Q<C@12EEP0@5AE03=7AP0kCdd0@5AB03U>B@0bAd80<dQ3
0315?P0^@c`0;d@k0315?00/@CP0:Slf02m2?00X>cD0:Sdg03=6@00bACl0;T4k03E8@P0/?cT0@EA>
03Q;A@0fBD<0=d]20080<DDj0140;d<h02i2=`0W>Bd0<T@h03A6>@0_?c80<d<f02m0<@0Y=bP0;3X]
03I3>`0fACh0<d8l03Q7@P0`@3d0<D4o03Q8B00203M9B`0303U;C`0oDED0@UAH0080@59D0140>4Y9
02e0?P0bAD40>Da703a?B@0oDT`0>di903M:AP0cAT@0<d@o06AcKP17EU40<T4l02Lf<@0`?cX09SD`
02dl=`0202Dd;`0801h]:00S<Rd0?DU402H_:P0R:bH09c0[028[9P0O:2<2024Z9@0D028[9P0T;BP0
9RlZ02Pa;00Y=3007BTU03<o>`0R;BT09S4]01`W8`0@6AH05AhK01TO7@0N92804aTG01HL6P0G81d0
5QlL01`U8P0]<c4202<Y9`806alN01H07R0O01/M700H6QT051HE01/K6@0B4Q007alM02TY9`0L71`0
6a/K01LG6@0I6A/06QXL020O900H5a`07AdO01HH5`0Y:bX07AlN01XL6`0H6QT04A<B0P0F61L02P0H
6QT06A/J01DG5P0A4a8051@B01HF500B4Q004A4?01@D4P0B4Q0501@D4P8051D@00P04Q<>014B3@0A
4Pd0414=00h>300@40h04Q8A01<C4`<051@D0P0C4a<01P0a<C404A4A00T92@051@D05aLG00/;2`80
410@01l05ADE00`<300B41404Q0A014?400?3@h03P`=00l=3P0B41403@/<010>3`0B41403P`=00l=
400;20h06QPM01lM8P071@X05aDH02`Z;@18ATT0:bTZ01`J6`0=2``05Q@E00h<3@0200400@0001hL
7@040P<00@0000802`T:00d03P`=00d;300?3@h040h?00h=3@0:2PX020P800T92@0:2PX020P800h>
3P0C4a<00`<3008020P800L0000000/82P0<1`/03@P<00/62P0:1@T030L;00803`X>0`0>2@d01`0=
20`040h@00T92@0B41401`<4018>3`0=1`T00P0@1`X01@0B1`/050P<01@8300D2@d04@P;00803PP:
00D03@L900h82P0?2@/030H800d72@0200h82P803@L901804PT>00X11P0?1P/04@P=00`3200A20d0
3`H;00d42@0?1P/030<800/21`0F3A802@<500@0000=1`T04@/=00`7200S7Al200`6200700l92`0=
1`T02`D7018<3P0>0`L03@8600h31`0201052@<03P<700@040D901462P0@1@T03@865?ooool001_o
oooo00L06adH01PJ5@0E5a804aD@010B3@0?4@`03Q0;00803a4<0P0@4Pd03P0?4@`0418=010B3@0B
50l0418=00/=200A4`h03@l:01/M600f>3<0gn7L01`N6@0620<03a4<0P0>40/200d?2P0D00`>2@0:
30L08B<N00/=200H6QD01PP3010B3@0U9b8020X500X<1`0;3@P051HA00T;1P0B50l03Q0;00`>2@0=
3`X03a4<014C3P0>40/200`>2@0300lA300@4Pd03a4<00803a4<00/0418=014C3P0?4@`03Q0;01HH
4`0D5Q400`D10084000>40/04Q@?00`>2@0300d?2P0700h@2`0B50l01PP300lA300<3PT01PP300<5
000300d?2P05018D3`0>40/03@l:00d?2P0;3@P0100:30L03@0;3@P03@l:00lA300=3`X02`d800`>
2@0=3`X06Q`G00d?2P072@@051HA00`>2@0=3`X00`0>40/02@0?4@`03Q0;010B3@0?4@`03@l:00/=
20092`H020X500/=200200`>2@0;00/=200=3`X04aD@00h?2P0;30L03@h9010A300720<051D@00d>
2@0A4Pd00P0@4@`201@E400l01HG4P0=3PT03@h900h?2P0;30L03a0;00d>2@0>3`X00@800001000@
4@`03@h9014B300E5Q00824L01/L5`0<30T0410>01@D4P13@d804a<C00@4100D51@07AdK09VEU00O
71X03Ph<01PI6`0V:R`00`/=020X:P0W<3002a4?01@H5`0;40/02Pl900P:1`0=3``03Q0=00d?300>
40d04Q@A014C400F61D061XG00lA3P0<3P/04Q@A00d?2P0620<0418=020R7@0B50l05ALB02T[9P0<
3PT0418=00`>2@0L7QT020X50P0@4Pl01`0<3P/03@l<00h@3@0<3P/03a4>00d?300>40d00P0A4a00
2P0?4@h0:2PV034a;`0J6QP03@d;01<C4@0=3@/03`l=018B400A4@l200l?3@08010A3P0>40d03@l<
00lA3P0@4Pl03a4>00h@3@0?4@h2014C400400lA3P0>40d04aDB01XL6@803@l<00d04Q@A00<50P0<
3P/02P`900T;200=3``0418?00h@3@0H7ah08R`]01LP7`062`X02@/80080414<01407AhI00lA3P0<
4Q0000D400T@40072`X03a4>01hP7@0=3``020X700/=2P0>40d03a4>014C400?4@h03Q0=010B3`02
00l@2`80414<0P0?40/00`0B4`h051D@014B3@0200d>2@0800/<1`0E5a804Q@?00d?2P0F61<03@l:
00h@2`0?4@`200h@2`8041<<00T03A09010B3@0=3`X0418=014C3P0>40/04A<>018D3`0A4`h00P0@
4Pd01@0?4@`03Q0;00lA300>40/03a4<00804A<>00@03a4<014C3P0A4`h04Q@?0P0A4`h0300?4@`0
61XG00lA3P0>40d0418?014C400E5a@02P`9018D4@0A4a00418?01DG50804Q@A00<04aDB01@F4`0F
61D00P0G6AH00`0D5Q<04aDB01HH5@0201HH5@0301TK600E6QH05AXF00@05AXF0P0B5a<01P0C61@0
51TE01@I5@0D6AD04aPD01@I5@805AXF00D04QLC014F4P0D6AD05AXF01PM6@0201HK5`0@01/P700L
8R0061hL018H5P0@6AH03aPE01LQ7@0>6AD05R4M01/V8P0<61@04QhJ01XV8P0G8al06BDQ01l/:080
72/V00L08c<]024b;00S=2h08cD_01HY8`0J;BL093La00807c8/0P0M<2X0100O<R`08cH`024d;P0N
<B/301lb;00301lb;@0O<Rh07c8^00<07c8^00T09STe0313?`0P<bl08cHb00hQ7@0R=C40:3`k02@h
=`0S=cH00P0T>3L00`0/@3l0?U9A02m3@P0302Di>00803=7AP0J<2h09C/i02a2@00O=3D08cPi03I;
C00[@4<202]0@@0802Xo@00Y?cd0:3hl02Hj>@0^@T409CTh02a0?`0aAD@202/o?@8093Td01h07c@_
0315?`0hBdD0:chh02Tl=P0bAd80BUmJ03eCD00Q>CT0<4Y;039=C`0`CU00;da@035@E@0gE5P0<TY<
03U>C`0hCDh09S/l049GF00eBT/0>e1A03=8B@0]@T<0@UMH03Y?D00kDe<0=4a<04EOGP18HV420319
AP0b03iGE01<HV00=4U702/o?P1PM7D0LXJ703eADP0kCdh0>dm=03eAC`0hC4X0<TM203=8@`0_A3h0
;D8k02m4?@0`AC`0:d0g02Ll<`0_@S`0;D0j02m2?00bACl0;d8l02/n>00aA3h0?4m905=VH00W>S@0
=dY403mCBP0eBCd0=d/o03I:?P0cAc/09cT]0312=00cACH0;Sl_03A5=@0`@C00:SPW02hl;@0f@c/0
=4<n049AC00fAD009SHc03A4@P0gAdH203I8B00M03U;C@0nD580@UAF045CD`0mCdl0<TE303=6@P0g
BTH0=DQ403U<B00lCd/0>4]703A7@`0_@Sh09SLc03e<A`0a@3/0:3Lb02He<00R<B`0:3Lb02Lf<@0Z
>C@0<3lj03=2?@0/>cH0930[01dV8@0S;2L00P0U;RT07@0V;bX092dX02</9`0T;BP09BhY02L`:`0Y
<Rd0:SD_020[9@0M:28062<M01XU7`0Q:RD09B/W01lU8@0P9R80AT]703a1?@0K8Ad08BXW01XS800I
8Ql09bd[024W9@0`=S@07R8Q01`P7`0J71/05aTH00805QPG00@05aTH01XL6`0K7A`061XI0P0H6A/0
3P0;30h06a`N02X[;@0S92H05aPJ01PI6`0E5aH03@l>018D4`0K7A`07b4P00P:2@0F61L04aDD0P0J
71/00`0E5aH06adL01HF500201DE4`0301XJ600I6AL020P600804a<A0P0D51800`0C4a404a@?01@E
4002014B3@0B01<D3`0C4a003`l=014A3`0A4A004Q8B01@D500E5AD05QHF01<C4`0];Bd0DU9B01`L
700B4Q805ADE02/[:`0J6QX07AdM0P0I6AT01P0?3`l0518C014?400A3a004Q0A010>3`<03P`=0P0D
4Q<03P0;2@X020H9018?5@0100@02`T>01LE6P0L6Qd04a4D01/I700;2@X01`D600@20`0B41402PP9
0P0H5QL06`02004040h?01@B4`0;2@X04Q0A014?40091`P02PP900d;300<2P/03P`=01DC500F51D0
2@L800X82@0?3@h02`T:00T7200B41404a4B00`:2`0;20X03PP<00l93@0=1`/030H:00d8300300l:
3P0900d:3@0;2@`02`T<02<Q8`0C4A8020@501@@4@0H51D02@<5008040L:0P0A1PX201872`080148
2`0>20X03PP:00d72@0>20X03`T;00`6200=1`T200h82P803@L901D040L:00`11@0@1@T03P<700T0
0P0=0PH05``@00h31`0@1@T02`0400l4200;0`D06A<E00d72@06008050h@010:300400003`T;00X4
1P0;1@L00P0<1PP0100A2`d03`@800h31`0?10P201872`0700d21P0>0`L040D901052@0>0`L03`@8
01052@0Dooooo`006oooool500lA300300h@2`0B50l03@l:008051HA00<03Q0;01<E400@4Pd00P0?
4@`200h@2`09010B3@0A4`h04A<?01<E400k?CP04aD@018D3`0?4@`04Q@?00802`d800l0418=00T;
1P0A4`h0418=00h@30092`L05QPC01<E400j?3L061XE00h@2`0;3@P04Q@?00/=200>40/00P0<3PT0
100?4@`04Q@?01@F4@0=3`X400h@2`0C00lA300>40/04A<>00d?2P0o@C`051HA00/=200>40/03@l:
00d>2P0A4`h03Q0;00/=200@4Pd04A<>010B3@0B50l04aD@00h@2`02010B3@0400h@2`0?4@`051HA
00lA308030h900T04A<>00h@2`0<3PT03Q0;010B3@092`H03@l:00T;1P0B50l00`0=3`X200`>2@07
01<E400=3`X04A<>00T;1`0<3PT05QPC010B3@0200lA300=00d?2P0D5Q406Q`G010B3@0>40/030h9
014C3P0B50l03@l:00h@2`0;3@P03@l:00h@2`0200/=200=00lA300720<05AHA03Df<@0C50l030d8
00d>2@0@4@`02P/8014B3@0<3@P03Pl:00d>2@0200l@2P0400h?2P0=3PP0414<00l@2P803Pl:0280
5QLA00d>200@4@/03@h9014B300=3PT0414<00d>2@0:2`L05QHD010@3P0L71/05ADE04=3@`0[:b/0
=SHd04]:B00@40d051HC00h?4@0C6AX02a<E00TB500F7al01Pl<01<I5`0<4@`051TC01@F4`0];b`0
51HC01DG500?4@h051HC0P0;3@X300h@3@08010B3`0@4Pd02@/600d?2P0H6QD030h900lA300Q8ah2
00lA300600`>2@0E5a802P`700h@3@0@4Pl03a4>0P0>40d0400=3``0418?00lA3P0?4@h03Q0=010B
3`0B51405aLE01`L6P0G5aD020P701TI5`0>3P`0410>014A3`0@40h200h>300D018C4@0B51403Q0=
00d?300A4a00418?00h@3@0@4Pl04Q@A00h@3@0;3@X03@l<00h@3@0<3P/03@l<00lA3P0;3@X04aDB
00h@3@0?4@h4010B3`0>00`C4P0:5QH02a@C00XB3`0?5100418=00lA300=3PT03@l<01TK6P083@h0
5a`M01<F5@0A4a0300h@3@08018D4@0:30T04aDB018D4@0<3P/0418?00lA3P0>3`X200`=200O00h?
2P0@4@`04a@?018C3P0D5A004A8=00h?2P0@4@`04A8=010B3@0C5A004A<>018E3`0>40X041<=014C
3@0@4P`03a4<00lA2`0>4@/03@l:00h@2`0=3`X03Q0;00lA300>40/0418=014C3P0@4Pd03a4<00h@
2`0200d?2P08010B3@0?4@`0418=018D3`0A4`h030h900lA300A4`h200h@2`0?014C3P0?4@`04aDB
014C400C5A805ALD01<E4P0B51402`d:01TK600;3@X04aDB01@F4`0E5a@04aDB00804Q@A00<051HC
018D4@0?4@h00P0D5Q<0100F61D04Q@A018D4@0H6QL6018G4`08014F4P0B5a<051TE01@I5@0C61@0
4QLC01HK5`0D6AD201DK5`1B01@I5@0F6aL051XF01XP700C61@04QPD00hD400@5A405adK01DK6@0H
7Q`06b@Q01DN6`0H8Qh05b8N01`W8`0J9R805R8N01TU8@0K:2@07R/W01TW8P0P;RX072/V02@d;P0P
<2/07c0Z03=5?`1=H5X093Pa01@X8P0P=2h08C@^02<f<00Q=2h072lY01ha:`0P<bd08SD_01lb;00N
<B/09CPb01d`:P0R=C008SDa01lb;P0M<2`0:chj04=FDP0S=S8062/W02Dh=00[?SX07S4]02@g=00T
>3L09SXj02/o?`0X?3`08cLg028f=P0/@4009SXj02Pl?00O<c<07C4a03eAD@0hCDd08SLg028h=P0^
A4<0:T0o02]1?`0_AD@0;49102a1@@0aAdD0IWaj02i3@`0V>SX0:Shn02Lk>`809c/j02`0:Shm0396
A00Y?C/0=4Q503Y?BP0aAT40;D8k03I7?`0fB400<4<m02m4?`0]@Sh0<da902e5A@0`C4h0;Ta>02Y9
C00ZBTh0<E1C039:B`0jCdl0>Di>03mDE01HKFd0<dU803U?CP0hCTd0>4e=0397A`0iCdh0=4a;03aD
D`0iDe40=e5?03Q@C`0oEeH0>51?03M=C00kD500<DE503mCD`19GEd0>Ti=041DD`80=d]90380=DU7
03M;B00lDDd0<4E002m4?P0^@c`0;T<k02m4?00`ACd0<4<m03=6@00dAd40<D@n02e0>P0Z?CL0<dI0
04QKE@1FJF<0=4M103E8@P0_@cX0<dLl041DB00jCT80=DTm02Xl;P0^@380=4Hf02`m;@0b@c<0<44_
02dk:P0b@340=D8k03I5@00hAd80>DQ302hn>`0a@Cl0=DE30395@P0fB4L0?4i=03e@C`0oDDl0>di;
03I9AP0gBTH0>Te903U<B080>4]700d0>Da803Q;A`0eB4@0?4m;03M8A00X=c80;3/f02/j=@0W=S40
7bhY04YIE01;FUD0>TU400809C@_00H0:cXe02Pc;P0T;BP09RlZ020Y900O:2<402D^:@8092dX03L0
9RlZ01dX8P0P:bD08B/U02H`:`0P:RD072<O01dS7`0Q9b<07b@P02<X900O9200:2hZ03a2@00Z<c00
6b@Q01lU8`0K8Al08bTW01`P7`0I7A`06A/J01LI600F61L071hM020Q8P0V9bP07AhQ01<D5`0I6Qd0
6Q/N01lP8P0J6ad07AhP01PI6`0J6ad061TK01PJ6@0L7Qd0828Q01HH5`0G6AP061XI01HH5`0D5QD0
6Q`K01TK6P0F61L07b4P01PH5P0D51806a/I02/[:@0];B/04Q8@00804a<A00h04Q8@014A3`0B4Q00
4Q<>01@E400C50h04Q<>01<D3`0C4a00410>01<C4@0C4a804Q8B01@D50805ADE00l03`l?00`<300N
7Qh030`<00h>3P0?3`l07AdM018B4P0>3Ph04a<C018B4P0=3@d04Q0A01<A4P0G5AH00P0@3Pl02@0<
2P/040h?01<A4P0B41404@l@00d;300:20/040hD01<A5P0200h<4@0G01<A500A3a80518E01hL7@0G
5AH03P`=018@4@0>30d01P@500l=3P0A3a002PP901PF5`0I5aP0NGMh02<Q8P0=2``05A<D00T7200@
3Pl03`d>00`:2`0:20T00`0<2P/01P0>30d02`X:00d;300:2@T020H7014<3`804@X>014040T>00l9
3@0?2Ph04@`@01<>4P091@T03@/>00P72P0@3a403@/=00P51P0D41402PD700T51P0@2P`04@P;00l6
2@0300h4200500h41`0>20X03PP:00h82P0=1`T00P0>20X0600?2@/03PP:00`6200@2P`03`T;00`6
200A1PX04PL;01462P0@1@T03P<701472P0>0`L03@@601062@0@1@T050T=00l52@0=10L040X<014;
3@0;1@L03PP:018<3P803@L900L03`T;010:300;1PL02`D701052@0?10P040D900804@H:00L03`@8
01052@0A1PX040D900h31`0?10P04PL;01Cooooo000Kooooo`08010B3@0>40/030h900`>2@0>40/0
418=00/=200A4`h2010B3@0L014C3P0;3@P01PP300h@2`0B50l04aD@00h@2`051`8010H101@F4@0A
4`h0418=00`>2@0>40/06Q`G010B3@0>40/05ALB0043000S9B003Q0;01hP6`1OHE`0<cD`00X<1`0;
3@P030h900h@2`802P`700D03Q0;00d?2P0=3`X03@l:00h@2`0400lA3005018D3`0A4`h03a4<00lA
300A4`h00P0?4@`040010`008B<N00`>2@0A4`h030h900/=200<3PT03Q0;00`>2@0;3@P0418=014C
3P0;3@P03@l:00h@2`0;3@P200d?2P0700/=200>40/03Q0;00d?2P0;3@P030h9014C3P0200h@2`0G
00X<1`0?4@`03@l:01LI500?4@`06Q`G00D70`0G6A@061XE00H810082PD03@l:00D70P0E5a8061XE
010B3@000@002P`700`>2@0@4Pd030h900lA300G6A@00P0?4@`01@0=3`X04Q@?01@F4@0>40/030h9
00804aD@00H04Q@?00d?2P0:30L02P`701/L5`051P4201TJ5@08018C3P0:2`H04A8=0042000720@0
414<034b;@0=3PT300l@2P0500`=1`0=3PP0414;010A2`0>3`T00P0<3@L02`0>3`T0414;00T:100>
3`X04a@?018C3P0@4@d051@B00l?3@0@40l03`l?00805aLG01<05aLE00l>300?3``04A<@00lC500H
7b005QhP00hH6@0C7Ad02a@A01@J600D6A@041D?00T;200M7a`02@/800h@3@0@4Pl09RPU00803@l<
00@03Q0=00lA3P0?4@h03a4>0`0=3`X00`0>40/03a4<00lA300200d?2P0500`>2@0=3`X0418=018D
3`0C5A800P0=3``03`0?4@h03Q0=00`>2`0@4Pl03Q0=018D4@0A4a003Q0=00lA3P092@L05QHD02h^
;00C4a406QXH00X:200200h>300700l?3@0>3P`03Ph<00l@3@0A4a003Q0=00`>2`02010B3`0400lA
3P0@4Pl03a4>00h@3@<030h;01P03@l<00lA3P0@4Pl0418?00lA3P0=3``03Q0=010B3`0?4@h03@l<
00lA3P0?5A@031HG00`E500:4Pl02Q0<00hC3@0A4`h03a4<00@60`0@4A404Q<E02/_<@0?4A02018D
4@0>00d?300<3P/04A<@01@F4`0E5a@02`d:00`>2`031@804A<@01HG4P0D5A00414<00l@2`0@4@`2
014B3@0A010A300>3`X03@h900h?2P0A4Pd0418=00lA300>40X03A0900hA2P0?4P/03Q4:00lB2`0@
4Pd03a4<00lA3P0>40d00P0A4`h2010B3@<03a4<0P0@4Pd2014C3P09018D3`0G6A@02P`7010B3@0B
50l03Q0;01TK5P0A4`h051HA0080418=00D05aTD01@F4@0@4Pl04Q@A01<E4P0201@F4`0:01<E4P0K
7AX0:2XW00h@3@0H6QL04A<@01@F4`0C5A804Q@A014C40<0418?00H05QPE01PJ5`0F61D04Q@A01DG
500J71T601<H500@01@I5@0G71P06AhJ01TN6P0F6aL05AXF01HL600D6QH02Q0<01DK5`0?5A406b4M
01hT80001@408BLS01PN6P807B<O00H05Q`J014G5@0D6QP0624N01LP7@0E7a/201DP700601HR7P0H
92006RHR01/Y900Q<2/06BPS0P0M;2L04@0dACl0:CXd01`_:@0Q=2h0;D4k01/`:@0L<BX0>De60354
?P0N<B/08C@^02Hi<`0N<B/06RdW01`_:@0S=S009STc00809CPb00T06bhY02<f<P0H:bL07C0/028e
<@16FED083<_02@g<`0J;BT00P0R=C40100aA440:Cdl02Tm?P0X?3d302Hj>`0F018V9`0T>3T0;d=4
02Hj>`0X?3d0>4a=05AYJP0fBd`0:d4o02Lm>`0S>CH0:T0m02a2?`0V?3T0:3hl02a2@01cRHL0;D93
0355AP0_@d@0;41102Xn?@80:Cdl01T0:Shl02Tm>`0W>cT0<dQ303U>B@0W?3L0=4M10396?@0dBD80
<dQ302i4@00]AT80<D]8035<C00^C4h0;D]=02a;CP0]Bdd0=Ti>03A:B00^A480=de;03iDDP0/@T00
=Ta:0080>4i<00@0=de;03Q>C00hDDh0>U=@0P0iDe004`0oEeL0@5QH03A<C00fBd`0=DU:02m3A00c
AdH0?51?03Q<B`0dB4L0<dM603Q<B`0fBTP0<TI403I:B00`AD00;D8m02a1?00]@S/00P0^@c`0:`19
G5H0FVeW04=FD00]@3X0;T4k02/n>00fBD<0=DQ20395?`0eB480>4]503I:@@0]@CH0>Ti20355>@0`
A3P0<48f03M9>`0iBc`0=TLg02m0<00/?B`0;cd/02lm<00c@3X0<d8m03I5@00^?CP0:c/h0392?`0c
@d00<4<o03Q;A`0nDDd0?4m=03E8@`0/@3L0;D4h03U<AP0gBTH0=TU503e@C00gBTH00P0eB4@0700b
AD40?E1<03m@C00Z>C@093<^020_:P0L:bH0:3Lb03A3?P0T<bh07B`W02<b;@0X=c80:STd02Pc;P0Q
:RD08R/V01lX8`0N9b808b`W02lh<`0/=C00:C8]02Xc;P0/=C00;SLb01lZ900Q;2H2020Y900@02</
9`0O9B4082HR020V8P0O92007B8N01hS7`0S:2@09bd[01`U8P0G81d06b4O01PN700G7A/04aLF018F
5@805QPG00/05ALF01hO800Q8RH071dQ01PI7@0J6al071dQ01XK7`0I6Q`0824S01HG6@0201/L7P04
02//;P0F61L061XI01LI60805ALF00P05QPG01LI600H6QT05aTH01DG5P0F61L06A/J01PH5P805QHD
00D07AdK01`L6P0:2PP05QHD01@D4P02018B400:01<C4@0C50l03@h900h?2P0A4Pd051D@01LG500H
61H04A4?014A40@04A4A1P0?3`l05`2GUiL0?3`l01`L700820P04a<C00T92@0K6AX0F5IG04a:B`0>
30d03`d>01HD5@0B4140518C00h<3@0;2@X03@/<00d;3P050PP03`dB01HD6@0=2a002PP;008040hA
00<07A/L018@4@0=2``00P0@3Pl0200C4A801`D600d;300H5QL020H700/92P12@4402`T:0P0=2``0
1@0:20T03@/<00d;300>30d040h?00802PP900L02`T:014?400?3@h02@L8018@4@0>30d030H900<0
4PT>0P0@2Ph01`0:1@P04PdA00X82`0:2@`00`<500410`091`P00P0>2P/300l92`0601072P0A20/0
40L:00h5200A20/06A0C1P0=1`T03@080P@09R0R01/E5`0F41801@0101<>3`0E30l05``@01@93@0A
1PX03`@801D:3P0;00@00P0@1@T00`0<0@D03P<700`21@0600h82P06010:3005004050h@00@0000H
4Q@02@<51P0?10P201052@803`@80P0@1@TDooooo`006oooool0200>40/03@l:00/=200;3@P03@l:
00h@2`0=3`X06A/F0P1ADdh0100I6aH03@l:01<E400?4@`200d?2P0300lA300C5A0020X500805ALB
0P0B50l04`0C5A00EEMB07MiM00=3`X05ALB00h@2`0:30L03Q0;01TK5P1IFeH0;BlZ00<5000<3PT0
2`d800h@2`0;3@P030h9014C3P0@4Pd00P0=3`X01`0>40/03a4<00lA300?4@`0418=018D3`0A4`h0
0P0@4Pd03@0A4`h03@l:010B3@0D5Q40008000`>2@0>40/030h900/=200=3`X03Q0;00d?2P0>40/0
0P0B50l02P0<3PT02`d800/=200=3`X04Q@?014C3P0>40/04A<>010B3@0=3`X200/=200I010B3@0<
3PT030h900h@2`0F61<03@l:00P:1@0210002`d800X<200>40/00@<001DG4P0?4@`03@l:02@V8@0>
40/02`d800h@2`0<3PT05aTD00/=200B50l03Q0;00L9100200`>2@0400h@2`0<3PT03Q0;00lA3080
2`d801H07AlJ01/M600F61<04aD@014C3P0>40/05AHA00X;1P082@H04a@?00L80`0C50l061TD010A
300>3`X06Q/F04Y;AP0D5A003@h800l@2P0@4@/03@h80P0;30H0800@4@/03@h801DF400E5Q003@h8
010A2`0;30H04A8=010A300>3`X03`l<00d=2`0?3`d03Ph=010@40092@T03Ph>018B400>3P`04A8>
01DG500D61T06b8S02D_<00O:BX09c4a00hI5@094Pl01`l900X?2@0D5Q<03@l<0P0B5140100=3``0
7b4N010B3`0?4@h200h@3@8030h;01l02`d800d?2P0?4@`03a4<00d?2P0;3@P03Q0;00/=200:30L0
30h901@F4@0I6aH071hK00d?300:30T03a4>00h@3@0;3@X0418?00h@3@0E5a@05aTF00lA3P0<3P/0
4A4?02DU8`0l?3X0820N024Q7`0C4a403`l=00<03Ph<00D03`l=00l@3@0?4@h03Q0=00`>2`02014C
400900h@3@0?4@h03a4>00lA3P0=3``030h;00d?300?4@h0418?00804Q@A00`04A<@00lA3P0=3``0
3a4>00h@3@0=3``03Q0=00hD4`0=5AL031DD00/A3`0:40`200hC3@0600`>2@0I6aP09BLV03Hg>@15
ATT03Q0?100=3``08@0?4@h04A<@01<E4P0O8Ah0<C<`00P:1`0=3``0414<014B3@0@4@`03Pl:00l@
2`0D5A004A8=010A300>3`X03@h900h?2P0A4Pd04A<>00lA300=40T02`h700`?1P0>4@P030l600hA
2P0A4`h04Q@A014C4P0?4A00418?010B3@0300lA30803Q0;00L0418=01<E400D5Q4051HA01<E400A
4`h03Q0;00809BLR00@03a4<01LI500C5A005ALB0P0B50l06P0F61<051HA01<E4P0A4a00418?014C
400E5a@061XG01@F4`0P8Ql030h;01DG500@4Pl04aDB01<E500E5aH051HE014C4P0C5A@05ALF01LI
600H6QT05QPG01<E500F61L06Q`K1P0C61@09P0D6AD05AXF01LL600G71P05AXF01@I5@0J81`05adI
00D;1`0E6aL03Q@@01`R7P0C6AD03aDA01HL600>51004QPD01LM6@0F71/041HF01PN7P0I8R404a`K
01DN7@0E7ah05R0O01PS8P0K9bD07BTW020]:`0L:bP04R4N01`/:@0W=c@0=4A102Hg=00P<bl07C0/
0P0M<Rd06`0Y?ST0>e1;02m4?`0Q=S407c@_024f<@0S>3<0:3dh01ld;`0F:bH0;T<n018W8P0U>SD0
8cLb02<f<P0D9b<08C@`01<V8P0Y?3P06bhZ01ha;@0hBdL0:3/g02Dh=00D9b@09SXi02Lk?00202Pl
?@0D02Lk?00V>S/0<4A502a0@@0L<340:cm002Pl?@0/@440>e1A01hc=00W?C/0=D]802a2?`0U?3L0
:D0j02Hm=`0Y?c`09C/i03eCD@0W?3d202e2A@0b02a1@P0[@440;45202e3@@0kDDl0>Dm=02Y0?@0V
?3T0<DM402i3?P0dBD80<TM003E:@`0dBD@0;D@o02a5@@0hDTl0;dY902Y8B00_CDd0<DmA02a8B@0e
CDd0<4I402i4@P0kDDl0AE]I03E;B@0jD4h0=de;03Q>C00kDDl0?59@03I?C00kE500=4m;03iHE@17
Gel0@5QI03A<CP0gC4l0<dQ:0314A@0fBTT0?E5@03Q<B`0aADD0=4Q703U=C00fBTT20314@P0f0355
@`0/@C`0;D8m0315@00Z?cP09CXc04IID`1NLF/0@EA>02i1>`0eB480;d8l03Q;A@0/?cT0;d8l03I9
@`0gBT@0=d]203Q<@@0gBd00:Shc02m3>00fB3`0>D/o03U;?P0nCT40;clb02`m;P0d@S<0;cd`03A1
>`0fAD00>4M20391?00b@cd0=4Do0311>`0_@S`0?4m904=FD00mD4`0<4@k02Lk<00/@3D0>De503Q;
A`0iC4P0?e9@03]>C00gBTP0=4M403=6@P0bACl0;3dg0P0V=C005@0U=2l09cHa02`k=P0`?cX0:STd
02Pg<P0/>cH0:STd02Lf<@0T;bX08R/V024Z9@0O:2<07RLR028[9P0a>SD0;3D`02L`:`0X<B`0:S<^
02/d;`0202<]9@0d020Z8P0R:B809RdV02D/9@0R9b4082DO01hS7@0Q8ah08R@O024T800J81h0624N
01/T8@0L8R005adK01TO7@0L81l06AdL01XL6`0H6QT05QPG01hO800P8bP06QdR01HI7P0K7R<07R4V
01XN8@0F6Qd09BT[01PL7@0O8b@07B4Q03Hj>@0G6AP061XI01DG5P0C5A@051HE01PJ6@0L7Qd06Q`K
01@F5@0B51<05ALF01XL6`0?3`d04a<A018B400D51805aLE018B40@05ADC00@051@B01<D3`0D5A00
51D?0P0C50l0100C51004Q8@014A3`0A4A04014A4@80410@100?3`l02`1`L70061PH01lO7`0<30`0
5QHF01@D500B4140D4i?04A2@`0F51D04@l@00803P`=00h03`d>010>3`0@3Pl06ALH02@R9@0[:Bl0
108701@B5`0@3Q<04@lB01<A500;2@`03@/<00`:2`803`d>01403P`=00`:2`0P7Ql03@/<00l=3P07
1@H04Q0A0040000<2P/04@l@00X82@0<2P/03P/<00h:2`0B3Pl05Q8C00h:2`0200`82@0602/W:018
A4D05A4B00@00@0I5AH03`P;0P0C20h201893P08010:3P0E3a<04PdA00@21@0<2`h092@V010A4`0?
3@l500l92`0600d72@0@2P`04@/=00`6200?2@/07QPJ1P0=1`T04P0F4180SHN904<m?`040000:28T
00d82@0@1`P04`X;01D<3@0=10D030<40107200:0@8040L801482@0=10D03PD600`310H03PP:00H0
50h@00P2100E3a40100000/51`05004800l420803P<70P0?10PDooooo`006oooool200lA30803@l:
0`0?4@`02P0P8Qd0aLO20<G7`P0P8Qd03a4<00h@2`0<3PT051HA018D3`0;3@P2010B3@0G00`>2@0@
4Pd03@l:01<E400=3`X092HQ03<e<00>40/04Q@?00P:1@0E5a804A<>00X<1`0C5A002@/700h@2`0A
4`h03Q0;014C3P0>40/03@l:00lA300>40/00P0=3`X0200>40/03a4<00lA300?4@`03Q0;00d?2P0<
3PT03@l:0`0>40/02`0=3`X03a4<010B3@0B50l02P`700d?2P0<3PT03@l:00lA300=3`X03Q0;0080
4A<>00@03@l:00/=200<3PT03a4<0P0B50l0300>40/0418=00lA300=3`X02P`700/=200>40/02`d8
00X<1`0<3PT04A<>00d?2P803Q0;00h02P`800d?2P0D5Q404A<>00`>2P0;3@X05QPC03Tk=P0F61<0
2P`7024S7`1EEe803@l:00`>2@804A<>00H03@l:00h@2`0=3`X03a4<00h@2`0=3`X200`>2@0:00d?
2P0D5Q40418=00h@2`0A4`h04aD@010B3@0720@05aPC01@E40803@h900<051D@00`=20082@@00P0>
3`X0100G61<02``700d>200>3`P200l@2@0401<D3@0G6140414:00l@2@808B8K02403a09010A2P0D
5@l03a0;00T:1@0>3`X05ADB00h>300@40h03`l>01PH60092@T03Ph>01<C4@0B4Q004aDA018G4`0E
6AX06b@T04MADP1ZMGH0@de=02<^:P0X<Bh06R8L01<J4`0H6QL051HC01PJ5`0S9B803Q0=00/=2P0@
4Pl00P0?4@h00`0>40d03@l<00`>2`0200d?2P803Q0;00<03@l:00`>2@0=3`X00P0<3PT01P0>40/0
5ALB01TK5P0G6AH03a4>00`>2`803@l<01<030h;00lA3P0@4Pl051HC018D4@0>40d0418?00h>300=
3@/061PF00d=2`0D518030`:014A3`0?3`d03Ph<00l?3@0@40h0414?0080418?00X03a4>01@F4`0D
5Q<03a4>00h@3@0?4@h0418?00h@3@0=3``03Q0=0`0@4Pl3014C40D03a4>01`03A4A00dB5@0=4Q<0
2a0>00T?2`0;4@X03aD>00P>1`0=4`l061/J014D5@0;3@l04A<B00lA3P0>40d04Q@A01@F4`0A4a00
51HC01TK600X:RL0>C/h01LI5P0D5Q<03a0;018C3P0E5Q404a@?0P0B4`h00`0@4@`03a0;00l@2`02
00l@2`0>010A300?4@`0418=014D3@0A50/03a8800d@1P0@4`X03a8900lA3@0@4Q404A8C01<D5P0?
4@h500lA300:00d?2P0@4Pd04Q@?018D3`0?4@`03@l:00h@2`0E5a807AlJ01TK5P803a4<0P0A4`h4
010B3@803a4>00L0418?014C400C5A805ALD00d?300F61D03@l<00804Q@A00L05ALD01DG5P0A4a80
4A<B01HH5`0D5QD04Q@C00805QPG00@051HE01<E500F61L061XI1P0C61@601DJ5P0<01HM6@0@5a<0
4QXE018J5@0J8Qd04a/F01XQ7@1UK6P04a/F01/R7P0?5Q80620K0P0D6QX0100N92@05b0O01HO7P0O
:2L201XT8`0o01/V9@0M:BL07RXX01h/:@0N;BX09cHc02@d<@0S<c009SLd01la;@0T=c<09CXe020f
<00S>C<09S`g02Hk=P0O=2l07S<^028g<P0Q=S4083D`01db;@0Z?cX0:Chi06YoNP0W?3L07c@_02<g
<P0W>SH07C0/02Lj=P0M<2`093Lc02Dh=00V>CD0PiJB02@g<`0P<bl09cXg028f=P0U>3/0:Cdo02/n
@@0Z?D009SXl02<g>@0Z?T00:Se002e1@`0I;Bl0H7=f06b1P`0mDU<09S`j02Hl>@0Q>380:3li02Hm
=P0]A3d0:T0l02a2@00X?S`0:Sm10080:Ci103P0:Sm102]0@@0[@440:d5002i4@P0Z@3h0<4I402a2
?`0eBdP0HWQe03Y@C00bBD<0;dM202i6@@0]AD40<T]703UBC`0bC4P0;DU6031<B@0bCT/0<Da:03A=
BP0eBdP0<TQ503I<B@0kDDl0=D]903M=B`0hCT/0>4i<03U?C00iCdd0>55=03aED@0fDD`0?eUF049J
FP0hD540>E5D03iCE`0hC4h0=d]<03eAD00oDe40>dm=03M;B`0iCDd0>dm?03]?CP0jCT`0>De<03=7
A@0bAT<0<DE20315@080;T<m00X0=DQ203I9@`0aA3h0=TU303M:A00^@C/0BUeG03=6@00hBdD0?U5;
0P0hBdD0201<H5L0?4m802Xn=00bAS`0>T]203Q9?P0fAc`0=4@j0P0b@SH0:`0d@CH0=D8h03<o>`0`
?cX0=4<n03Q7@P0gB480=TM103=4?P0dAd00@UE>04MKD`0oDd/0;D4f02Hk;@0aACT0@5A:03]>B00j
CD/0?e9@03a>C@0hBdT0<dI30395@@0Z?CL08C8/02Th<`0/>cH0:CPc02ln>@0d@ch0;chi02He<00T
<bh09SD`02Th<`0[>SD0:3<^028[9P0Q:RD07bPS020Y900R:bH00`0X<B`0300S;2L08BXU028[9P0T
;RH08bdU02@/9@0S:R<08RTR028X8P0R9b4082DO020S7P808bDP01l07R4L01dS8@0K924072DR01hT
8P0M8b40728P01`P7`0H71/071hM01dO7P0K7A`07QlP024T:P0O8RT07B0W01/N900J7B806QhR01<G
6P0L82809BTZ00lC500C5aL05a/J01/M700J71/05aTH01DG5P0G6AP06adL008061XI00`05aTH01DG
5P0G6AP06Q`K01`L6P0G5aD04a<A01@D4P0F5Q@05ADC018B400D518201HF500:01<C4@0?40/061TD
01LH4P0D5A004a@?010A3@0?3`d04Q8@018B4@804A4A0P0@4100100B4Q804A4A010@400@410200l?
3`1201<C4`0F5QH030`<014A4@092@T03`l?010>3`0F51D04a4B00h<3@0A3a006ALH00l=3P0>30d0
4a4B00h<3@0B414081hQ02d[<@0;2@h05A<H00T7300H5QT04a4D010>4@0=2``03`d>00d;300<2P/0
4Q0A00l=3P1[JFX0?3Xk00l=3P0A3a003@`<01DC500>30d02PP9018@4@01000040d>00h:2`0A3@h0
5A4B00l;300>2P/040`=02<O800e<C805A4B00/7200G4a@040P<01<73@0B1`d04PP=01483@0?2@d0
3@L;01LE601gMGP0JVY/01PI6`051PP03P`=1@0?20X01P0>20X03`T;00h82P0<1PP03@L9014;3@H0
3@L9018030L801<=3`0?2@/040X<00d72@0?2P/0204101082@0L51D04PX;00l7200;10D04@T:01@<
3@0A2PX030D500l8200B2P/600d72@0600/51`0C3@l02@@500l92`0J5AH03`T;1`0?10P01@0>0`L0
3@8600d21P0>0`L03`@801Cooooo000Kooooo`H03a4<02404A<>00`>2@0[;BP0:bdX00`>2@0A4`h0
5aTD00h@2`0G6A@051HA00/=200L7QT02@/601@F4@0T9R401`T400h@2`0=3`X05QPC018D3`0A4`h0
4Q@?01@F4@000@0030h900d?2P0I6aH0418=00/=200B50l0418=01<E400?4@`00P0>40/0100;3@P0
3@l:00d?2P0>40/300lA300E010B3@0<3PT02`d800h@2`0?4@`03Q0;00lA300C5A000080014C3P08
2PD03Q0;00d?2P0<3PT03Q0;00lA300>40/030h900/=200=3`X03a4<00802`d800L03Q0;010B3@0?
4@`030h900lA300>40/030h900802`d800D03Q0;00X<1`092`H03Q0;00d?2P0200`>2@0>00T;1P03
1@009RPS00H80`0>40/04aD@01@F4@000@00418=00X<1`092PL0F5YE0;2b[@0N81/200X<1`0;00d?
2P0B50l04A<>00X<1`0?4@`04A<>00h@2`0<3PT03a4<00h@2`0?4@`00P0>40/200lA300>00`>2@0H
6A@010D000h?2P0A4Pd03@h9018C3P0J6aH02P/6014B3@0N7aX02P/601PI500=3PP200d>1P0500l@
200G61007b0H01DF3P0=3PH00P0@4@T02`0=3PH05AH>01<D3P0=3PT0414<01<D3`0?40`030`:01<C
4@0:2PT04A4A00803Ph>01@051@B01XJ600I6QH05a`H024W9`0g@D40SiVJ0>kjnP39e=<0R9>?05aU
HP0O9b405QdF00h@3@0B51401@L401PJ5`0C5A803a4>00d?30<03Q0=0P0?4@h0100@4Pd03Q0;00h@
2`0=3`X200h@2`0<00`>2@0>40/03a4<00lA300@4Pd04Q@?00`>2`0?4@h03Q0=00/=2P0<3P/03Q0=
0P0?4@h02`0>40d02@/800d?300E5a@05aLE00/;2@0B4Q0051@B01LG5@0>3P`0410>00<03`l=00L0
410>010A3P0A4a004A<@010B3`0D5Q<04aDB00<03Q0=00<03a4>00h@3@0>40d00P0>40d0100=3``0
3Q0=00h@3@0@4Pl2014C400A00lA3P0A4a004A<@010B3`0?4A404A8F018C5@0>4Q40314=00`C300@
5a003aH?00dC3`0Z;bd07B4R01XN800?4A000P0=3``2014C400700h@3@0B51405ALD00`>2`0@4Pl0
3a4>01<E4P0200d>2@0400l@2`0C50l051D@018C3PH03a0;00h02P`700`>2@0@4`/04A@;00lB1`0;
3P<04aH=014D2`0<3`X02`d<00h?4@0C51L04Q@A018D3`804aD@0P0D5Q400`0<3PT03a4<018D3`02
01<E400?018D3`092`H051HA00/=200:30L05ALB00lA300@4Pd03a4<018D3`0C5A00418=014C3P0=
3``0418?00804aDB01@04A<@00lA3P0C5A805ALD01HH5@0C5A8051HC01DG500H6QT04A<B01DG5P0Q
8b806Q`K010B4@0E5aH04aDD018D4`0C5A@051HE01DG5PH04aPD00l05a`H01DJ5P0C61@051TE01DJ
5P0E6aL05QhI00hG4P0F7aX03aPC024Z9@0?61<0624L01@M600K91l00P0@6A@01`0C71T061hN01DK
6`0F71`05AhM02Xc<P0]=cH00P0J92<05@0I92<06RHT01/W9@0L:bP04b<P01h^:`0K:bP0:SXg02Hi
=@0R=C40:3/g02Tn>@0P=S007cH`020g<@0R>3808SLb020e<00O=2l07C8]028g<P0202Dj=@0I01`a
;00R=c806c0[0315@00J;RT09CPd02<f<P0P<bl093Lc024d<00[?SX072l[01ha;@0Z?CT0>Da801ha
;P0R=SL093Lk02Tl@00[?T80:Ca002Hi?@0`@dL0>TeA02Tl@0020313A`0A024d>00X?D005R//028h
=`0^A440:D0j02Dl=00P=bl0:d8j02Po>@0cBDL0>e5?03A9C00Y?T40:Sm202a1A00]@T<00P0^@d@0
200`AT@0=de;03A:B00_AD80;TA1028k=`0Z@cl0:T@o0P0`BDD202U2?P0?03=<B00dCTX0<Te802i9
A00`BTH0=Di:03=9AP0iCd`0>4i;03=9AP0aAd@0=4Y703=9AP0fC4T0=de:0080=D]808h0=e1<03QA
B`0hDdd0>59?03A<C00aBD`0>E5E0356B`0_@dL0=4Q903Q<B`0jCd/0?E5?03]?C`0jCTl0=TY;03Y>
C@0oDe80?U9A0314@P0bAT@0;T9002]0>`0aAT40=da703=6@00bACl0=dY40395?`0`@cd0=dY403mB
C00cAT00=DQ203U<AP0dAd40<TDo03Y=A`0cAT009cXd0395?P0jBd<0>da403U:@@0^?S@0=THl03A4
>@0]>S00<Slf02hj=`0[>SD0;Sdh03M6@@0hBD<0>da603i?B@0kCdH0?E5803]?AP0eBD00:clb02Xo
;P0fBc`0@5A903A7@@0dAd<0>de<03E7A`0aA480;3ll02Lj=P0S=S00834/02@c;P0[>SD0<D0k02hm
>00[>SD0:STd030o>P0a@3/0;C`g02Xi=00V=C008bhY028[9P0P:B@08BXU02@]:00U;RT08BXU02@]
:00X<B`09RlZ02@]:00V;bX08R`T024[8`0U;2D08bXS01dT7@0N8ad07b@N01hS7@0Q8ah08R@O024S
7P0N8Q`08BLS01`U8P0G81d082HT02L]:`0S:BL092PW01lS8P0O8B007R0O01XL6`0H6AX07R4X02<V
;`0S9Rd06A`S01@G7P0I72408bLZ028V:00g>c`06AdN024U9@0D61L05aTH01PJ6@0E5aH04aDD01@F
5@0H6QT04A<B01HH5`0J71/06A/J0P0H6QT0200W9bD05aLE018B400F5Q@05ADC018B400@40h04a<A
0P0D5180100A4@l03Pl:014B3@0A4Pd2018C3P0401<C400C4a404a<A01<C4P804A4A0P0?3`l2018B
4P0@014A4@0@41003`l?00l?3`0C4a<02@T900`<300D51@0410@05iNGP0R82404a4B01@B4`0A3a00
3@/<02TW:08040h?00/04@l@00d;300:20T03P`?00T73@0A3a@05Q@I00/93P0C4A@02PP;00`:3@02
00l=3P0L00X82@0<2P/03P`=00H41@0O7Ah05aDF01DC500100001`H600l=3P0100004@l@00L51P0=
2``03@X;00d92P0>2P/040`=00`82@0>2P/04@d>00`82@0400403PX;014=3P091@H040L;01853080
4@H<00T040L<00h8300>2@d05Q@G08B4QP1nOX001PL900<720091`T01@0?1PT00`0<1PP02`D700`6
2002010:300300`6200=1`T03@L900@03@L9018040X<00@0000A2`d0100000/51`0B30h03PP8010<
2`0B3@d02P@400T5100=20L03PP8010<2`0<1`H01`4100X61@0?2@T600`6200600P2100:10H02@<5
01hH6P2HTY@0D4Y<200?10P200h31`803`@85?ooool001_ooooo0P0>40/200lA30803Q0;014010H1
01HH4`0B50l04Q@?01HH4`041P400P@0018D3`0g>C@0=3Ha00h@2`082PD06adH01LI500U9b802P`7
01@F4@0200`>2@0A00h@2`0I6aH020X500h@2`0K7AP02`d900/=200H6QD03a4<00@60@0B50l0418=
01@F4@0A4`h0418=014C3P0>40/00P0=3`X01@0>40/03a4<00lA300?4@`04A<>008030h900D03a4<
010B3@0?4@`02P`701HH4`02010B3@0600P:1@0=3`X03Q0;00`>2@0>40/03a4<0`0>40/01@0B50l0
5QPC00lA300>40/03a4<0080418=00@03@l:014C3P0A4`h03Q0;0P0<3PT03`0?4@`02`d800X<1`0>
40/020X500/=200@4Pd06A/F02`^:@2WZJ@0?3hi00T;1P0=3`X03Q0;0043000200d?2P0Z01PJ5@0A
4`h0:R`W00`>2@0;3@P02P`700d?2P0?4@`03@l:00X<1`0=3`X04A<>00h@2`0<3PT03a4<00d?2P0>
40/04A<>01@F4@0B50l03a4<00d?2P0D5A0020T4018C3P0@4@`01PL201LH4`0>3`X02@X500P9100@
4@`030d8014B300<3@L03@h600h?1`0=3PH04A8:01HG3`0A4PX03Pl70P0;30@03@0>3`L04A8:01DF
400>3`X051D@00l@2`0=3@X08b<Q020P7P0<30/02PX:01HF5P0C4a<00P0J6QP03`0J6aL07B8N038h
>01JI6@0cmWJ0?;noP3`n_T0WZVU05=LF@0S:bD0<CPa01PJ5`0D5Q<03@l<00lA3P02014C40H03Q0=
00d0418=014C3P0A4`h0418=00h@2`0<3PT03Q0;00lA300>40/030h900d?2P0?4@`03@l<00802`d:
0`0=3``02@0?4@h030h;00d?300;3@X03@l<018D4@0?3`d01`L500/;2@0200d=2`0400P81P0@40h0
410>014A3`80410>00L03a0=010B3`0@4Pl03a4>018D4@0?4@h03@l<00803Q0=00D03@l<00h@3@0>
40d03a4>00h@3@0200d?300X00h@3@0@4Pl04Q@A010B3`0>40d03a4>014C400?4@h03Pl@018A5P0C
4aD041<B00`A3@0<4``02Q<;00PB2P043@P05AdJ00<92@072P`030h=00`>2`0=3``03Q0=00d?300:
30T02`d:00lA3P0<3P/04aDB00h@3@0=3``061TD014B3@0;30L0414<01DF4@0D5A003Pl:00l@2`80
414<0P0?40/200d?2P0;00hA2@0?4PT03a87010D1P0B5@X041<:00d@2`0<3Pd03@h@010A5@0A4a00
0`0B50l201<E4004010B3@0A4`h04Q@?018D3`804aD@00h02`d801<E400F61<061XE01LI500=3`X0
418=00h@2`0D5Q405ALB014C3P0C5A004A<@01<E4P8051HC00l04Q@A00lA3P0>40d03a4>01HH5@0B
51405QPE01LI5P0E5aH051HE01XL6`0S9B@06adL01<E500F61L00P0C5A@00`0D5QD05QPG01HH5`06
01<H500H01LL600C61@04AHB018G4`0D6AD051XF034i=00W<2/031D@018K5P0H8A`04Q/F01PQ7000
1P4082TT01HO6P0G81/05QlL01PM7`0E6Qd051TL01PP8P0W;c409Bh_0P0J92D02P0K9RL072PX01hZ
:P0R<3006RXY02Ti>00R<c80<DA202Xm>`0X>cT202Xn?00M02<h=P0S>CH0:3hk02Dk>00T>SL0:3hk
028h=@0L<Rl0:T0m0316@`0V?3T0:T0m02Lm>P0Z@3d0;48o01ha;P0O<Rh08SDa020c;`0R=C407c8^
01ha;@0W>SH0:Sdi02Hi=@0J;BT09CPe02@h>@0V>Cd00P0Y?4008P0X>cl09STm01lb=P12EET0@eIJ
02Tl@00_@TH0:Se103E:C@0W?3d09CXi024g=00V?CL0<DPo02Hm<`0Z@CT0:T4k02]1?`0iCdd0;T=6
02Dm?`0V?T00:d=502i6B00`B4X0<4Q802Hn?P0[@d<0;DI3039;A`0dCDT09Slk02Q2?`0X@d02031:
A`0?02Y4@00YA3l0<DY603A=B00cC4H0<4U30359@`0dBdD0;dE203E;B00jD4d0>Dm<03M=BP0iCd`0
=D]80080=4Y701`0=Ta903M=BP0cC4P0<DY403A?B@0`BTL0<4Q803=;CP0cBdl0;D9702i2A`0fBT/0
=d]:03M<B010EE00?51@03]?D00eBDX0=d]<03]?CP0hC4/0<dM50355@`0_@d40;d@o0397@P0eBTD0
<D@n0P0eB480;@0cAT00=dY403Y=A`0cAT00=4M10354?P0bACl0<D@n02`o>@0`@cl0=TU502e0?00d
Ad80=TM103Y;@`0iBT80=TDn03I6?00c@cT0<Slf038o>00b?S/0=TE00391?00gAT40?Di8041ABP0n
CdL0>4a303=7?P0_@cX0;T8g0314=P0cB3L0>Tm003a@A@0^@C/0<TE103e?CP0dATH0<4=102Tl>@0N
<Bd08SD_02m1>P0202Lf<@0N03M6@@0eA3l0:STd01l^:@0P;bX09C@_02He<00Y>3<09cHa02@`:`0R
:bH082TT02</9`0W<2/0:34/02/d;`0V;bX08BXU02D^:@0X<B`09BhY02D/9@0R:B408bXR024X800L
8a/08BHO01dR6`0N8a`08B@M0P0P8A/03P0R91h07bDQ01`U8P0H8Ah07bDS02H/:P0P9R@0<3@c02L[
:P0P8R407AlN01XL6`0J6a`07R4X0P0P92d0300I7R@05Q/Q01LL800K82<06R0Q01LM7@0F71X04aTG
018F5@0F61L061XI01LI60805ALF00h05QPG01<E500H6QT06Q`K01TK6P0G6AP05QPG028R800D5180
4a<A01HF500E5A<05QHD018B40<051@B00X04Q8@010A300C50l04a@>014B3@0@4@`03`l<00h>300C
4a404a<B0P0A4A4200l?3`0401<C4`0B4Q804A4A010@40<03`l?03D00@4101<C4`0<30`000000451
@@0G5AH02`T:00d;300G5AH02PP901TG600?3@h03P`=00d;300C4A805A<D014?4P0F4aT02PP=00`:
3`0A3a@04@lB00d;3P0<2Pd04@l@00h<3@0<2P/03P`=014?400@3Pl00P0100P61`0E4a@04@l@01TG
600:20T02`T:01HD5@081PL04a4B00X7200=1`T03PP:010:300<1PP03PP:014;3@0G4A<05Q0B01<=
3`0;1@L02P@601D;3`020185300:0146300@1``03PP<01@?4`0200<03@d?024R90041@L03a<D00/8
2PD03`H900<030H800d72@0>20X00P0<20T00`0=2@X03@L900d72@0400d72@0B018<3P0;1@L050h@
00/51`0:10H040X<00`81`0;2PH02@H400L300030P002PP400T50P0<2`L030X600T50P0920@02`L5
1P0<1PP01P0J51H03PP:00H00P070@<0E4i@01LA4`H03`@80P0@1@T200l4208040D95?ooool001_o
oooo02H020`700/>2P0>4@d03a8>00dA300;3PX03Q8=00lC3P0@50l04A@@00lB3P0<40/05QPD00d?
2`0E5a<04Q@@00lA3@0E5a<092HR00h@300B510030h:01<E4@0620<02`l800d@2P0=4@T03Q4;018E
3`0K7QP03Q8<014D3`0D5a803Q8=00/?2P0:3PT03@l;00lA3@<03@l;00@030h:00/=2@0=3`/03a4=
0P0@4Ph03@0@4Pd04A@>00`?2@0<3PP03a4;010B300?4P`030h800T<1P0>4@/02`d7010C3@0?4@`0
0`0?4@d00`0=3`/030h:00/=2@0201<E4@04018D400C5A403Q0<00`>2@<02`d800<03Q0;00d?2P0=
3`X00`0=3`X0600;3@P02P`700/>2@0W:bH041<A00`?30072`L04aDA05YLF00J71P01`T4010A3@0=
3`X0414<018D3P061`@03@l:00`>2@051`@03a4<00h@2`0=3`X03Q0;00d?2P8030h900P03@l:010B
3@0=3`X030h9010B3@0<3PT02`d800`>2@803Q0;07H03@l:00X<1`0>3`X0414<00h?2P0?40/0414<
00l@2`0;30L04a@?00l@2`0:2`H04A8=010A300;3@L03a4:014C300<3PP030h700d?1`082@@0418;
00d?1`0B4`h03Pl900`=1`0F5Q403@d900l@2`0A4Pd08R<O09nSWP1OH5`051DA00/<200E5A@03Ph<
018A3P0I6aH03Q<=01/Q700b>cL0HVaX0<?=bP3SkNX0f>?N05aXH`0/>34051lG01<K500D5Q803a0<
01DF4P0?40`04A8>014C3`0?4@d04A<?00lA3@0>3`/03a0<00h?2`0?4@`030h900d?2P0B50l02`d8
00lA300F61<03@l:00X<1`0;3@P030h900d?2P0?4@`030h:00P:100@4Pd0418>00hA2`0@4`h03a4=
010B300?4@`03Q0<010B3P0A4Q002``900`=2P0B4a404A8@018C4@0>3``03a0>014B400A4Pl03a0>
00lA3`0;3@/04aDC00T;2@0I6aT030h<00d?3@0?4@l03@l=00`>300F61H0:B/Y01<E4`0B51805ALE
01<E4`082@L05QPF010B400?4@l03@l=0P0?4@l01`0>40h03Q0@010A4@0@4A803a4>00d@3@0=40`0
0P0>50l05P0:40`03a@A018G5`0R9BD0418@014C400C5A804Q@A014C400?4@h04A<@010B3`0>40d0
51HC00h@3@0A4a008B<O01`M6@0D5Q804A8>00l@300>3`/200/<2004010A3@0D5Q803@l;018C3`80
3a4=00`03a4<00h@2@0?4P/04aH>014D3@0?4P`03Q0=00lA3`0?4A403Pl@00h@2`0@4P`3014C3@0L
00lA300E5a<04aDA010B400>40h04A8A014C4@0C5A404Q@@014C3`0B51003Q0<01LI5@0C5A40418>
04Y<B00L7QX04aDA01PK5`0I7Q/05Q`I00lD4@0=4Pl05QXH010C4@0E61H04Q@B01HH5P804aDC00H0
51HD00`?3`0A51@04aHF014D500G6QX301@G5`0701PK6`0@4a<06ahN018E500C5aD05AXG01DI5`02
01@H5P0<01DJ5`0H71X05a`I01DJ5`0L81h05Q/H01DI5`0e>c/09B`/01<J6P0B6AT041LG0P0C6QX0
O00J8B4051/K01XQ8@0F7Ad04Q/J01HO7P0?5QL0624Q01LQ8P0L9BL06B<U01`Y:`0Q;S008Bda01l^
<@0V<SL07Rh_02i2?P16FUL0;40m02@i=@0[?c/0;48n020f<P0W?CT0:3hi02Ln>@0^AD00?5=>02]0
?00S>3@0:Clk02a2?P0Y?SX0:Clk028h=00M<bl093Te01ld<00I;RX0:Chh024g;P0V>S<093Ta02Hl
=@0V>SD09CXf01hc<@0Z?S`08cLf01da<@0W>c`09SXl02Tm@@0_@dL0;41302Tm@00W>cl0:3a002Hj
?P0[?d807C4e02e1A00T>3`0:Cln02Hl>00Y?c/09Sdg028i<`0V?CH0;48m02Y0>`0]@d409C/j02Tn
@00Y?T40:d5302e4@`0`AdL0;TE60317AP0X?ch0=Te<02i5A00_Ad@0;DE202Hm>P0aBDD0<D]602a6
@P0]Ad80;dU5035:AP0cBdL0=4]802m7A00bBDH0=4Y803=9AP0dBTH0<4Q2039:A00cC4@0=4Y60399
@`0bBD80?55=03E;A@0bB440>e1<03E:AP0mDT/0<DLl0399?@0^A3`0<DE103I;BP0cAdP0<dM90354
A`0iCDh0=TY903A9AP16FeL203]@CP1P03mDE00kCe00=d]=03Y@DP0jCe40:D1003I=C@0lDe40=De:
03=;B00bAT@0>Ti;03I9A`1:GE/0=d]803Y>B`0gBTH0>4]803M;A@0bAT40=4Q302i2?00fBT80?558
03U>A@0fBT<0<DDm03E9@00gBD40>D]303A7?P0eAch0=TM00393?@0a@T80>T];03=4@P0hBDL0?U1=
049DCP0jC4D0<TDl02Xm<`0/?S@0<dHk03]?@`0lD4H0>dm603E8@@0bA3h0>DY704ADD@0nCDX0=T@o
02Le;`0P;RL0:CL_049BBP0iBD<09SHa02Xi<`0^?3H0;c/f030k=P0_>c<0;STd02/g;`0Y=bl09S@/
02@^:00Q:B@082HR02<Z9P0Y<B`0:34/034k=@0[=Bl082/U02@`:P0Z=S0082/U02<[9@0R:B808RPR
01lV800N9Ah09B/U01XP6`0L8Q/07b<N01lR7P0N8Q`082@O01`Q7`0K8b006b0O0P0J7ad09`0F6aT0
7b<R01/O7P0D5aH06QdL01hQ800O8b<07b@X01/R9P0I7bD07B@X01XP9@0S:Bd0;C<f01dS9P094140
72<T01DL7@0H7Qd061XH01XK600J71P061TG01HF500H61D061PG01/J600K6QL06aTH01XH5P0H61H0
<c8`01PH5`0D51<06QXI00l?3P0B4Q005ADC01HF500201DF4P0>01@E4@0C50l030`901@D4P0A4A00
3`l>018B4@0?3`h04Q8C01@D5@0F5QL03Ph?014A4P0B4Q<2018B4P0O01<C4`0A4A403Ph>00d=3@0A
4A407QhN00D51@0D51@03`l?00P8200@3a404a8D00h=3`0?3Pl02@P:010?4@0@3a003Pd?00/:2`0>
3@l03`h?00T82`0=31003`hA010?4P0<2`l02PT<01@C5@0B4A@051<D00/:2`0200h=3P0I00`;300;
2@X040h?00h<3@081PL0518C00d;300>30d04a4B00`:2`0?3@h030X;00/92P0;20T03@P:00l;300<
2@X03PT;00l;30091PL03PT:00l;300?30d030L800l92`020148300<0108300?20/03PT;00/72@0F
4aD030T;014@4@061@H061LI01LC500@20X040T:0P0>1PP02@0@2@X03`T:010:2`0?2@X02`H600X5
1@0?2PX030H700d7200300h82@0O00d7200;1@H05@l@00P3100;1PL040X;00`61`0:1@@02`T600/7
1`0C3Ph02`P600/8200;1PL02PL500h:2@0<1`L03@X800`71`0?20X03PH900h5200?1@T03PD900/4
1P0>10L040T:0149300C2@d03@@701D;3`0600l4200601872`0n<cL04`P<00h31`0C20`091TM5?oo
ool001_ooooo00@051TE00hC3`093PX02Pl;0P0=4Ph00`0>4`l03A8>00`A3@0200`A3@0800/@300:
30T02`d:0043000J71T04Q<A01HH5@0D5Q<200h@3@0B00lA3P0S9B809bTT00dC2P0>50X02a4700X@
1P0?50d04aPA018G4@062`D0<cPb00D:1P0730P04QLC00lA3P0>40d03@l<0P0>40d00`0?4@h030h;
00lA3P02014C4080418?00L03Q0:00`?200=40T03a8;00hA2P0<3`P03A09008030l800@03A0900hA
2P0<3PX030h;0P0?4@h200d?300800h@3@0@4Pl051HC00lA3P041P<01`T600h@300>40/400d?2P03
00h@2`0=3`X030h900<030h901006QlK05AJF00Q9B@05ATH00L;2P082PL02P`9014C400>3`X020T4
01TJ5@0?40X020X400`>2@0>40/03@l:0P0<3PT04P0A4`h03@l:00T;1P0<3PT03@l:00T;1P0B50l0
4aD@00h@2`0<3PT03a4<00`>2@092`H02P`700h@2`0A4`h0418=00d?2PH03@h91P0>3`X09@0B50l0
20X500<50@0:30L030h900lA300=3`X02`d8010B3@0;3@P05ALB00P9100D4`l04@h;00/<1`0B4`h0
5QXD08V>R01OI5h04QD@01@F4@040`004@h;01dL6015BT@08RTR01DL5@0G7QL07RPP03Do=`1KIEd0
KGQ`02<`9`0I9Qd03a`C014K4`0@4Pd00P0G61<04P0B4`h051D@01`M600>3`X04a@?00l@2`0>3`X0
414<00h?2P0a<bh0@48m00`>2@0=3`X05QPC00H80`0K7AP03Q0;00`>2@80418=01<03a4<00X=1P0;
3PL02`h7010C300;3PL030l800lB2`0C5Pl04A@=00`?200>4@X04A<>01@F4`031@807R0M06a^J`0E
5a@0004000803@l<01403a4>010B3`0?4@h051HD00840`0A4a809bTX05=EE00P8R402P`;010B4@0>
40l02`d<014C4P0];bh0418A00lA400200/=300301LI6016B4L0:2XY00D03Q0?00@03a4?00lA3P0?
4@h03Q0=0P0?4@h2010B3`@03a4>0P0A4a00100@4Pl03a4>00lA3P0?4@h200d?30803Q0=0P0?4@h0
100620D03@l<010B3`0@4Pl201@F4`0901HH5@0B514051HC01DG50072@H02@/800`>2`0>40d03a4>
00803@l<00@03a4>018D4@0?4@h03Q0=0P0@4Pl00`0>40`03a8;010C2`02014D3@0A010C3@0?4@`0
30h;00lA3`0A4a804A8D00l@4`0;30h092HU00L91P0A4a00?Cll03@f<`031@805ALD00`>2`16B4D0
0P0C5A806P0E6QH06R0N00D;200E7Q/06b4O00dC4@0>51803Q8A00lB4@0C5A@051HE01`N7@0/;Rd0
2@d>01<G600E6AX08RHW00`@4@0C5aP06QhO00`@4@0>4Q<05QXK010D5@0F6Q/04QHE100D61L0400E
6AP04aLF01<G5P0B5QD082@S01LK6P0E6AX041DI01dR9P0J7b<07B8V01LL800B5a/05a`P01DJ7P0G
720201/P900N01LO8@0H8B8041XI01HP8@0J9RH04ahP01XV:@0J:2/08c8g01h]<`0H9bh082lf01P[
;00S>S@09C`f01dd;P0R>C<09chh02U0>P0R>C<0:d8l02Ln>00U?3H093/e03A:A@0X?CP08cPc02]0
>`0/@C`0:3dh0P0S>3<03@0V>cH09c`g02a1?00]@Sd09S`c02Q0<`0Z@SD08SX^02Ln=P0X?cT093/g
02Dk>@0U>S/00P0U>Sd09P0S>3d07c@g02i3AP0nDeH0=4U<02Hk?P0O=3L0:3e002]0@`0`ADP0<DI9
06AiO00]@T@0;4<m02]2>P0Y@3P07cH`01`c;@0R>3D0:3hl02Hl>P0[@440<dQ903eBD`1FJfd0<4I4
02Pn?00P=S@08CLe02e3@@0eBdT0<dU702m5@`0`AT@0<DM502i4@P0bB4D0<DM40P0_AT002P0aB480
<TU40398A@0cBDL0;TA20398AP0dBDX0<TM803I<BP0_B482031:@@1/0399@@0cBT80=Te503I;A010
EDh0<DHo0354?P0iC4H0:Shc03I6>@0gB3P0=dTm03Q9?`0hBTD0=dY803E7A`0cATH0>De>03M;BP0h
CD`0BV1M03Q?B@0iCd`0AE]H045FE`10EEP0BV9V04UPI@0[@dL0=U1A03E?C`0`BTT0;TQ703Y?D00/
@440<4A50396A`1KKfh0;T910396A00fBTP0<DE303=8@`0fBdH0=4U203A:?@0fC3l0>Dm203I<@00e
Bcl0>4i203U>A@0gC4<0>4e403U>A`0eBT<0<TM2049GF@16FEd0?51A041DD`10De40@5=?03Y=A`0c
A3`0:S/b03E6?00oCd@0?dm903a?C@0hBdT0<dE203Y:A`0oCTT0?D]503M4?@0/=bl08R`T02Xd:`0^
>2l0;3Xb02Pk=@0[?3H0<T4k02dj<`0Y<Rd0:C4[02/b:`0/=Rh0:C@[02@`9P0Q;R@0:34Z02T^:P0T
:BD09BXV02P^:P0T;BP08RdW02D`:P0Q;RL093</02dl=@0U<b`09RlZ02L]:@0R:2@06R0L0P0G7AT0
;`0L8Qh07B<O01dS7`0M8al06b4M01TO6`0N8al06QlK01TM700L81l06alN01HJ6@0D61L061`K014E
500L81l08RHU01hS8P0]<SD09blb01XR9@0@61/00`/>01XR9@0>5QT07RHY02@/;`0G7b803ADH01XO
8P0H6QL05QLB01PI500H5a<051<?01HE4@0I5A806QHC01/G500L5a@06aHC01XF5@0E4a@05ADE028R
8P0V9RH05aLF00805ADC00<05ADB01@E400C50l00P0C50l0200E5AD03@d?01LG6@0O7b405ADG01LG
6@0?3a402PX<0P0B4Q@01P0C4aD02@T;01<C4`0A4A40410@00l?3`803Ph>00L03@d=00X:2P0G5aL0
10@400l?3`0;2`/03Ph@00<03`lA0P0=3@l01P0>3Q003`lA010@4P0?3a403@d?00`<3PH03`lA00<0
6ATK01PH6P0:2P`00P0<30h01@0>3@l03@/<00d;300<2P/03@/<00803`d>0`0>30d00`0=2``030X;
00`:2`0200/92P0:00`:2`0=2``03@/<00`:2`0@3Pl01P@500X82@0<2P/0518C00h;30803`/<00X0
3PX;00d92P0=2@X02`L8018>3`0;1`P03PX;00<0000<20T02`H60P0=1`L0100:10@02`D500h8200?
2@T200h820803@L700@03PP800X4100;1@D03@L70P0?2@T05P0@2PX0<B/[03H`<00I4a<02@<3014;
2`0C3@d071HH00X41P0?2P/03`T;00@0000=20T03PP:00`6200C3@l030H800h82P0@2P`050T=0146
2P0@1@T201872`0700l4200;00@03P@700X00`0>0`L04@H:00L0000600l4200600h31`0T6Ad02001
01052@0C20`0;R<W5?ooool001_ooooo01<04QLC00/@30093PX0314=00dB3P0730P041DA00`A3@0B
5a<04AHB00P=2@0;40`04aDB01PJ5`000@0051HC04i@C@0E5a@04Q@A00<03a4>00h0:B/X034c;P0?
50`03A<900H<0P0>4``06AhG01PM5P0=4P`05a`F069WH@0J7a/02a0<00`A3@8030h;00D03@l<00lA
3P0A4a004Q@A00h@3@0300lA3P803@l<00P02`d800`>2@0?4@`0418=00`>2@0:30L03Q0;00d?2P80
30h900<03@l:00`>2P0<3P/00P0?4@h03`0=3``03Q0=010B3`092`P03a4>00/=2P0>40d05aTF00d?
2`0?4@`03Q0;00`>2@0:30L030h900h@2`0300d?2P0N00h@2`0?4@`0310=024W9@0420L02`l>00H:
2@0A4a0071hK01LI5P0F5a803@h901hO6P0720803a4;00h@2`0?4@`03Q0;00d?2P0>40/05QPC010B
3@0:30L030h900d?2P092`H04aD@01HH4`0B50l03@l:0P0>40/01P0;3@P03@l:00h@2`0;3@P02@/6
00P:1@H03a0;1P0>3`X0;00F61<03@l:014C3P0H6QD03Q0;00`>2@0=3`X020X501XL5`0<3PT0:R`W
014B3@0?3PX04a0=00`=200A4Pd03Q4<02DZ900I7QP02`d900d?2P0?3PX04a0=00`;1`0];bX04aPB
00`A2`0E6Q@07RDN01lY8@0P:R80=T0h01`W7`0D7aL02aH>00D?1`0:30L02``700T:1@0:2`H03Pl:
010A300>3`X04Q<>0P0?40/02`0@4@`03Pl:02X/9`0a<bh04Q@?00H80`0=3`X0418=018D3`0;3@P0
2P`700803Q0;0P0<3PT04`082PD030h900d?2P0:30L03Q0;00lA300A4`h0418=00`>2@0=3`X03a4<
00lA3P0A4a0051HC020R7`0B51404aDB00d?300>40d00P0?4@h0500>40d020X800T;2P0W:BP05ALF
01/M700<3Pd051HE00d?3P0>40l03@l>00P:2@0H6QT01@L600T;2P0?4A002`d<00lA400X:RT04A<B
1@0>40l0100?4@l03a4>00lA3P0>40d200lA3P80418?00X03a4>00h@3@0=3``030h;018D4@0@4Pl0
3@l<00`>2`0=3``0418?0P0=3``300h@3@0F00lA3P0:30T0418?00d?300<3P/051HC00lA3P0B5140
3Q0=00lA3P0D5Q<03@l<00lA3P0>40d03a4>010B3`0>40d03@l<00lA3P0A4a00418?00h@3@80418?
01803Q0<014D3@0@4``03a8;00lA300@4Pd04A<>00d?300?4@l04Q@C018C5@0@4A<03PlA00lA400B
51403a4>01LI5P0C5A8201DG500P00h@3@0E5a@0418?01DG500A5Q8000H402hg=00C71T03A<A014G
5@0>51804aLF01<F5@0C5A@0418A01PJ6@0Z;2/07B4R01DI6P0T:2T041@E00dA4P0G6a`0ATY;03Lk
?0052@X08RHW00dA4P0420T04QHE014E500B5QD201@H5`0@01<G5P0B5QD06alN010D4`0=4A002Ph=
01LK700C61/0DeQK02@Y;00K82<04QLJ01XO8P0F6ah05AXM01HK7P806AhQ01T05QhP01XS9@0`>S/0
7BLY01LR90084aD08c0b01XX:`0S<SD082lc01/Z;`0Q<3D07S4a01lf<00N=Bl083La028i<`0T>cD0
9chh02<j=00]A3h09chh02e4?P0T>cD0:d4l0080:3dh00@0;T<n02a1?00Z?cX0:Chi0P0bAd8202Dj
=@0M024f<@0L<RT09clb02U0=P0S>S409Sde02Hm=`0V?CT09S`j02@i>P0X?D00:Ci102@i?P0W?3l0
<DI903M<C`0W?3l07S<f02@i?00W?3l0:d1302m4A`0bAdX0J7f002m4AP0W?CX0:d8l02Po>@0P=S<0
0P0]@d00600eBdP0;dE202Hl>P0R>3H093Xh03I<B`0^A480;49003Q>C00/@T008CLe02Pn?00]@d40
:d4o02i4@P0bB4H0<DM50398A@0_AD80<4M102m6@00^ACl0<4I20398A@80<4I403L0=4Y803A9BP0b
AdP0=Ta:02m8@P0_BD00<D]203E<A00fCDD0=4]303M<A@0_@cd0=TU302e0>P0aA3h09CT^03=3=P0e
AcL0>4Xn03U:@00gBD@0=4M502do?`0cATH0=4Q70396A@0gC4X0@5IC02i3?P0_@d40<dM503A8B@0h
CE00?U=F049IG@0bBTh0=Ti@0359BP0_AdL0:dA10355AP0_@d@0>De>04MKFP2calH0KH6003U=B`14
F5H0=TY803aAC00cB4<0<dQ10398>`0dBSd0>4i10080=de102`0>e5503E:@@0eBT<0=T]403M<A@0c
B440<4E0049GF@16FU/0?e=D049FE@0nDDl0?4m;03iAB`0kC4@0;d0g03]<@P12DTL0>da503Y=B`0l
C4/0>DU703a<B@0mC4L0=T@n02`i<P0U<2X09C0X02hi<@0^>300:SP`02Tl=P0_@3X0=T@o02hj=P0Z
<bh0:30Z02dd;@0_>C40:cH]02@`9P0S<2H0:S</02X_:`809B/W00h09bdY028[9P0T;bT09S4[024^
9`0V<b`0<3df02Tg<00O:2<08BLS01lU8@0J81`06AlK01/Q7@<0728N02406b4M01XP700I7a/07B8N
01XO6@0H7AT07B8N01hS7`0H7AT04QLC01TN6P0E6AP08BDT02L[:P0S:2P05AXM01HN800D71h04QXL
00lG6@0e?Cl0GfMY03@l?P0D71h04QXL01DM7`0H7Qh05QPG01@D4P0I6AL06a/I01TI5`0K6QP00`0H
51<201TC4`0K01PD4`0<2P/05ADE01TI6@0L71`051@C01LG5@0C4a404a@@01<D3`0B4`h04Q<=014B
3@0H61H04A4A00h>3P0@410020P801TI6@0N7Qh04Q8B010@400A4A405aLG00d=3@0D51@0410@0080
3Ph>00P03`l?014A4@0>3Ph03Ph>01`L700I6AT04A4A00/;2`803Ph@0`0?3a4200h>400300l?4@0@
4180410B00803`lA1P0=3@l00`0M7Al071`N00h>400200`<3P0300l>400=2``03@/<00<030X;0P0>
30d00`0=2``030X;00`:2`0200`:2`0<00/92P0<2P/030X;00`:2`0=2``02`T:014?40040P<03`d>
00T7200E4a@030T:0P0?2``03`0>2P/03@T:00d92P0A3@h05a<D00X61`0<20T020@501DA4P0A30`0
30H600X4100<1PH03@L700`61P0200d71`8030H600<03@L700h8200>20P00`0>20P04@0?2@T040X:
01dG5`0U7al03PP800@0000600002`D500@000080P@040/<00T31@0R71h050h@00P210070@<040X<
0080208400d03PP:01462P0@1@T040D901872`0C20`04@H:01<8300D2@d03@8601/@500/8BD05P/?
00H03`@800H04`P<00P00@0=0PH04`P<01052@0F2`lDooooo`006oooool090093PX04AHB02<X900[
<2`082DQ00X?2`0=4Ph03Q<?01lT800N8al0314=00lD400;3@X02P`9024S80092`P05QPE00X<2@0@
4Pl03a4>01@F4`0>40d051HC014C3P0=4`X03aD<00L=100D6A807b@N01LL5P0>4`d03A8=01@H500;
3``04QHD00dB3`<03@l<00@03a4>010B3`0A4a003a4>0P0<3P/200lA3P0300h@3@0A4`h03Q0;0080
3Q0;00D03@l:00/=200?4@`03Q0;00d?2P0200`>2@0400h@300@4Pl04A<@00h@3@8030h;00L0418?
00`>2`0?4@h02`d:03/m>P13AD80418>00803a4<00@03@l:00/=200;3@P03@l:0P0<3PT04P0=3`X0
3Q0;00lA300?51002Q0>00@81`0?4a801`/:01HH5@0?4@h06Q/I04]<A`0E5Q403a0;00`=1`0G61<0
3Q0;00lA308030h901<03Q0;00lA300@4Pd04A<>00h@2`0<3PT03@l:00h@2`0C5A004Q@?00/=200=
3`X0418=00lA300=3`X030h900d?2P0>40/03@l:00H04A8=1P0>3`X0;@072@@03Q0;00lA30082PD0
3@l:00lA30051`804Q@?01<E400@4Pd07AlJ00l@2`0>3@T03``900h?2P0<3@P041@>00870P093PP0
@D@o02T[9P0l>cT08AlK01lN6P0@4Pd03a8<00hB300G6A@07b8M01HL5P0V;2D08BLQ01dU7P0?6100
3AH?00dD3@0];bX06Q/F00`=200?40/0414<00/<1`0?40/04A8=00l@2`02010A300F00d>2@0<3PT0
0P@100T;1P0>40`03Q0;010B3@0;3@P03@l:00X<1`0<3PT03Q0;00/=200<3PT03a4<00`>2@0:30L0
5aTD014C3P0>40/03a4<00h@2`8030h901P03@l:01@F4`0<3P/020X7010B3`0:30T03Q0=00d?300@
4Pl03a4>00d?300>40d04Q@B00lA400D5QD02P`;01DG5P0=3`h04A<B00X<2`0>40l04A<B00d?3P0A
4a8200`>3@0501XL6`0:30/0418A02DW9P0D5QD01@0>40l0100?4@l03a4>00lA3P0>40d200lA3P03
010B3`0?4@h03a4>00<03a4>300>40d03`0?4@h03@l<00lA3P0?4@h03@l<018D4@0C5A804A<@010B
3`0C5A8051HC01DG500>40d0418?014C400200h@3@@0418?0P0?4@h0=00>40`04Q@?010C3@0>4@/0
3Q0;010B3P0B51004aDB00d?3@0=3`h03Pl@00l@4@0E5aH03a4>01DG500B51405aTF01<E4P0G6AH0
3a4>01<E4P0?4@h061XG018D4@0>4`l06AlM04I?C00G81d03Q8@01TN700;4@l04QHE014D4`0F61L0
5ALF018D4`0C5A@051HG03Pl?@2=TI8051PI01dQ8P0=4A80<3@e0414A@0F6Q/04aLH010D5@0F6Q/0
4aLF00hB4@0@51<201@H5`0>018F5@0C5aH07B4P00hB4@0G6aX04QHE01<G5P0F6ah0>Sm201hS9P0F
6ah06QlR018G6P0E6Qd201HK7P805a`O01`05AdO01lW:`0V;c<06bDX02lj?@0G8R@072PZ01PV:00M
;2h07Rh_01d];P0R<S<09SXh01he;`0O=S00;4<m02U0>P0W?SP0:d8l0317@@0jDD/0:T4k0399@`0Z
@C/0;dE003=8@`0bAd80;d@o0P0Z?cX09P0cB4<0;T<n02@i=00W?3L0:Chi02Pm>00U>c<09clc02U0
=`0T>c<09C`e02Dl=`0U>cT09S`j02Hk?00U>Sd09S/n02Ll@@0S>3/09c`o02Xo@P0W?3l09CXm02Pm
@00^@dH08SLj02Tn@@0W?3l0:Ci102]0@P0U>cT0>Dm;0398AP0S>CH0;D=102Hl>@0Z@3d0:3hk0P0[
@Cl03@0Y?c/0;490055WI@0]@d40:d4o02e3@@0/@T00<4I402]1?`0/@T00;dE30316A00_AD<00P0^
A440200aB480<4M102e4?P0^A400<TQ502a2@00cBDL0=D]90P0cB4T0100eBdT0<DU30318@00cC4<2
03Q?A`0c03=9@P0gC4D0A5QA02Xm=`0_@S`0C5iH03I7?`0[>bh0;3h_02do<`0^?cD0;T0j02`o>`0Y
?3X0=TY80355@`0]@D00=DY703I;AP0hBdD0>T]803E8AP0gBDX0>4Y>03=7B`0V>Sl0=TY>03iDE`0j
D500>E1>0357A@0iCDh0@eMG0355A@0jCTd0B5aK03]?CP1<H5h0?U=?03Q<B@0nDdh0;D8l03M<A@0e
Bch0=D/o03Q>@P0fC400=T]103Y@A@0dBD00=DY30080=T]40240=T]503I:A`0hCDh0?E5B04EIF@1?
Hf80@eID03]>B`14Ee40A5E=03Q9@010DDL0@E5703I6@00iC4X0?dm>03m?C@0nCT/0>DQ402lm>00/
>S@0;SXd02lk=@0^>S<0;SPa03I4?P0eB4<0;d0j0390>`0`?3P0;SLb02dd;`0[<B`00P0Y<b/03`0U
<2L07b`S020Y8`0R:2@08BLS02@[9`0W;bX09c0[02Xe;`0X<bd08RhW024^9`0U<R/08BhW01dV8@02
01lU8@80728N00<082HR01XP700J81`00P0K8Ad07P0L8Qh072<N01`Q6P0O91`07B8L01XO6@0K81/0
61dH014F4P0I7QX051PG01XN7P0M8B4061`M01HK7P0G7R0051/M01DL7P0C6A`0:c8d0<;9b`1MI6H0
5A/N01LM800J8B<0318B01`N7@0G5aD061PF01LG5@804a8@00/06ALE01TF500G4a8061<B01PC4`0H
51<04Q0A014A4@0?3`l0820P00d=300201DE4`0A01@E4@0D5A004a@?01<D3`0B4`d03@h:01HF500:
2PL05aLF01HF500L71T07QhM014A3`0C4a003`l=01@D4`0@40l00`0A4A402`0@41003`l?00l?3`0>
3Ph05QHF00X:2P17AdL03@d=00`<300>3Q003`lA00@0410B0P0=3@l0100>3Q003`lA010@4P0@4186
00h>400601DE5`0I6A/0410B00d=3`0820X03Pd?0P0=2``00`0<2P/02`T:00/92P0200d;300500`:
2`0:20T02`T:00`:2`0=2``01@0<2P/01`0>30d02`T:01<A4P0>30d03`d>00H41@0=2P/00P0?2``0
3P0>2P/03@T:00d92P0G4a@081`M014=3P0B3Pl02`L801@@4@0?2P/03PP800d71`0@2PX04@/;1P0>
20P0200@2PX05Q0@01@>3P0@2PX03@L700`61P0=1`L01`820P0H4Q803`0B30`04@/;00l92@0;1PL0
5A0A018<3P090`D0G5IH014<3@0G4A<02`D700d72@090`D02P@600h82P0200d21P0300l4200@1@T0
4@H:00804PL;00D0308501`A5@0>0`L07A8F01<8300600l4200600X10`0G31004`P<00l4200C20`0
2@025?ooool001_ooooo00D02Pl;010E4@0L8Ad08RLS01XO6`0200/@300=00X?2`0A5Q804AHB014F
4P0O920061XG02/]:P082PL03Q0=0494@@0H6QL0418?00X<2@0200h@3@0@01<E4P0;3@P03149010E
3P0:3`P03A8;00hC3@083@L03a@>01DJ5P093PX07b@P00D9200830/0418?00lA3P@03@l<00h051HC
00h@3@0>40d04aDB01@F4`0C5A80418=00/=200:30L030h900h@2`0=3`X03Q0;00d?2P8030h900<0
3@l:00d?2`0=3``00`0>40d02P0A4a004aDB00P:1`0=3``03a4>01XL6@0T9R<051HB010B3@0A4`h2
01@F4@03014C3P0>40/030h900<030h900h03@l:00X?2`000P001PX900T=30072`X051HC00L91`04
1P<0<C8]00`=200;30L03a0:00h@2P803@l:0P0;3@P0200=3`X01`T400/=200?4@`02`d800T;1P0<
3PT02@/60P0=3`X02@0:30L03Q0;010B3@0;3@P030h900lA300>40/02`d800@60P0600d>2@H03Pl:
01X03a4<01<E400@4Pd03a4<01<E40082PD01PP3018D3`0620<04A<>00`>2@0A4Pd03@`8010>2P0G
61<03Pl:00X=20083@L03A8<02X^:00G6A@05QDA01hK600F4Pl01PD100l?2`80414<00h04a@?01@F
4@0F61<030h9018G4@0?50h041H?014F400A4`h06AXE014B3@0720<04Q<>02//9`803a0;00H03Pl:
014B3@0@4@`030d800d?2P0B50l200d?2P0>01LI50041P4030h901<E400=3`X030h900lA300<3PT0
2`d800h@2`0B50l03a4<01`N6@0:30L200h@2`803@l:0P0<3PT07P0>40d03@l<00L91P0620D030h;
01LI5P0>40d04Q@A00lA3P0;3@X030h;00P91`092`X05ALF00`>3@031@@02@/:01<E500:30/0418A
00d?3P0A4a802`d<01DG5P0F61L0=3He01hP7`0?4A00418A00d?3PD03Q0?00@03a4?00lA3P0?4@h0
3Q0=0P0?4@h0300>40d02`d:00`>2`0=3``03Q0=00lA3P0;3@X03@l<010B3`0A4a00418?00h@3@80
3a4>0`0>40d0400=3``04Q@A00`>2`0?4@h0418?00T;200<3P/0828O02<U8P0N81d04A<@01<E4P0>
40d03@l<00lA3P0@4Pl200lA3P09014C400?4@h0418?014C400>40d03@l<00lA3P0A4`h041<=0080
3a4<00H0418>014C400?4@h0418@01`N7@0M7ah2018D4`060043000D5Q<04Q@A00lA3P082PL051HC
0P0B51407@0I6aP0418?00d?300D6AD04aTG014J5`0M9R<06b4O00lE4`0G7A/04QHE010C4P0L7Qd0
8bDT01/M700@4Q402`l@01<G600X;2d0310A00/?400J7Ql02Ph?01DI6P0H71d0310A01DI6P0C5aP0
4aLF008041@C00L04aLF01@H5`0D61L051PG03/o?P0F6QT041@C00804QHE00L04aTJ00D:3@0E6Qd0
4aPK020U:00C61/05Q/N00805a`O01d05AXM01HK7P0E7Al07BD[01lX;@0_>3d0D5]O03Q3A@0O:bd0
8c4a01d];00L;2/07Rh[01`/:`0S=c<07SD_020g<@0]A3h0:d8l02Po>@0^ACl0=Da603mFD00[@S`0
;dI002U0>P0aAd40=4U403=8@`0202e2?@0<02i3?P17G5L0@5E@02Tn>@0^@ch08CHa01`a;00U>cD0
:3lg02Y1>@0W?SL09C`f0P0U>cP01P0W?C/09c`m028g>P0R=cX0:Sm402Ll?`808cPk00@0:3e002Xo
@P0V>ch0;D950P0W?3l05P0bAdX09CXm02]0@`0aATL0Fg5_05Y_K`0]@d409C/i0357A00[@Ch09cdj
02Hm>00V?CL09C`f02Po>@0bB4D0738`03E;B@0W?C/0:d4o0357A@0`AT@203M=B`80;D=104@0;dE2
0316@`0aB480<4M102i5?`0_AD40<4I302e3@@0cBDL0<TQ60356A`0eBT/0<dU703=:A00bBD40<dY2
03E<A00eBd@0=4U20315?P1@I5d09CPb02i1>`0nD4X09CH^02Ti;00Y>R/0:3X^02Tj<00Z?3H0:Sdi
02e0?P0iC4X0<dM50314@P0fC4L0>4e60394?00dACl0=4A103M7A`0fADP0<49603M9C@0lCe<0@5AE
03Q=C00iCdd0<dU703mCD`0[?ch0>De<03eAD00R=S@0=d]909jb/01NLfh0D6EP03eBC@0]@S/0=da3
03U>A00gCD40>4i203=9?@0cB3l0=da303=8?`<0=4U202h0>Di903a@CP1<HF40CF5R04mSHP1CIfH0
@eID03I9AP0iC4P0?Di803Y;@`0lCDD0>d]103E5@00iC4X0@51?03i>C00jBTL0=4=002Lf<P0X=c80
<Cdi03=0>@0^>c@0<Slh03a:A`0cAT80<44k03=2?@0_>cL0:34^02T`;00W;BT08B/S02D`:00W<RX0
7BXQ01`V800U:bL09R`X02L^:P0X<B`0:C8]02Pc;@0W<R`092lY0P0R;bP06@0Q;BH07RLR020V8P0N
92006AlK01LM6@0J81`08RPT024W8`0N92006R0L01TO6`0H7aT05a`E01dS6@0K8AL05Q/D01XO600F
6aD05Q/G01hS7`0F6QT061`M01LK700D61T00P0C61/0300>4aH061dP01HK7P0J7b805Q/N01LL7`0E
6Qd041DH014F6@0N92@05ALF01@E4`8061PF00X071/I02HU8`0K6QP06QLF01PD4`0G4a8061@C01LF
500V92D05QHF0P0>3Ph01@0>3Pd061PF01DE4`0E5A8051D@00804a@?00X04a@>01/L5`0C50l03Pl:
010A300?40/0Ngag0;>d[`13A3l04A8=0P0B4`h03P0>3`X03`l>014A4@0C4a<04Q8B00l?3`0=3@d0
410@00h>3P0H61P04a<C014A4@0B4Q803`lA0P0@4180100A4A<0410B00l?4@0=3@l200`<3P0300d=
3`0>3Q003Ph@00H03`lA00H02`/=00l?4@0=3@l03`lA00H6200;2P`200d;300600h<3@0=2``030X;
00d;300>30d03@/<0`0<2P/200d;30<030X;00P02`T:00`:2`0:20T05Q@E00l=3P0C4A802PP900l<
3@803`/<00l03PX;00d92P0=2@X071PI020L7@0300001P8301hJ6`19ADH0=2l_00`61P0=1`L03`T9
00h8200<1PH00`0>20P0100?2@T040X:018<300@2PX200l92@803PP801D03`T900/51@0E3`l040X:
00/51@090`<01`4102@N800500403@L901<=3`0I4aD030L802hX:P0G4A<040X<00l92`0>20X030H8
00d21P0?10P00P0A1PX0200B1`/05@X>00l4200D2@d0?S<g01hC5`0C20`04@H:1P0?10P01P0B1`/0
3`H800L0000A1PX03P<701D:3QCooooo000Kooooo`8020d901T02Pl;00`A3@0;40`020d900hC3`0?
51002Pl;00P=2@0?51006QlK00/=2P0G6AH02P`901DG500<3P`06Q`I00h@3@0=3``04aDB00lA3P0E
5a@04A<>00/@2@0?50d03A8;00802@h800T02Pl9010E4@042@D000@000P<2`0420L04ADD010B3`0>
40d00`0=3``03P0>40d05aTF00h@3@0<3P/04A<@018D4@0@4Pl03Q0=00`>2`0>40d04aDB01DG500D
5Q<03@l<0P0<3P/0100=3``03Q0=00d?300=3``200h@3@0300lA3P0B51404Q@A00802`d:00`030h;
00X<2@0>40d0418>00d?2P0>40/05QPC01TK5P0B50l03@l:00lA300>40/300d?2P0=010E4@0>5180
61`K00`@3`0:3Pd04A<@01TK600<3P/00@8000h?2P0@4@`02@X400lA2`0200h@2`8030h900D03a4<
018D3`0?4@`02P`700/=200300`>2@0600h@2`0;3@P02`d800lA300=3`X030h90P0?4@`00`082PD0
2`d801/M600600l@2`H03Pl:00<01`T400H80`0>40/00P0;3@P09@0R91l07R0K00/=20092`H03@l:
01<E400F5a8030/7014>2`0A4Pd03a0;00/>2@0<4@/03a@>00P<1P0;3@P04a8>02XX900@30T061@A
01LE4@0D4`l040l;00d<200A4Pd06a`G01@E400D5Q405QPC00hA30092`H01`P301HG4P0H6A@04a@?
01lP6`0f=c800P0?40/0200=3PT04A8=014B3@0;30L02`d800L9100F61<020X60P0=3`X0800@4Pd0
61XE00lA300;3@P0418=00`>2@0W:BH01`T601@F4`0>40d05ALD00X<2@0?4@h03Q0=00d?300>40d0
3@l<00`>2`0<3P`0418?01lQ7P0?4@h06A/H0001000=3``04Q@A00lA3P0:30T030h;01DG5@0E5aH0
30h=0P0@4Q402P0C5A@03a4@00/=300D5QD02P`;01DG5P072@P051HE00430P0G6AP200@61@03010B
4@0E5aH03Q0?00@03Q0?00@03a4?00lA3P0?4@h03Q0=0`0?4@h200d?30D03Q0=100@4Pl300lA3P0:
00h@3@0=3``03@l<010B3`0B51403@l<014C400J71T03@l<01@F4`807AlL00D03Q0=01@F4`0A4a00
30h;00h@3@03010B3`0i01<E4P0>40d0418?014C400>40d030h;00lA3P0?4@`0418=014C3P0A4a00
418?00lA3P0@4Pl04Q@A028T8@0S9B805ALD01@F4`0P8Ql05ALD00X<2@0E5a@04Q@A00h@3@0D5Q<0
4aDB01HH5@0?4@h05ALD014F4P000P004a`I00lH5@0D6QP03aDC01TO7@0G6aX051LF01TK6P0L7Qd0
5aTH01@F5@0;3a00310A00X>3`0N8R<02`l@014E5P0L82406alP00hB4`0D61T05QXK00861`0D61L0
4aLF00804QHE02005ATH01PL6`0T:2L0GV9Q02HZ:@0C5aH07B4P01lS8P0G7Ad06R0P01lU9@0=4a<0
4ALG01hT900F71`06AlO01PN7P0E6a/05Q`L01HN80073aH07BH]01lX;`0S;S807BPZ028^;`0^?3`0
830_01l_;00S=2h07BdZ02@h=0808SPe00X0:3hk02Y0?@0[@Ch0;D=002]1?P0gCDX0<4I303Q>B`0a
Ad@0=D]80P0fC4T03`0bB4D0=D]803=9AP0fC4T0;D=002<i=P0[@Ch0:Cll02Y0?@0]A3h0:T4k02]2
?00Z@3`09S`i02Dk>@0202Pn?00S02Ll?@0U>Sd09c`o02]0@`0`ADP0:Sm2024f>@0R=cX0:3e002i3
AP0/@D@0:3e002Hk?P0cB4/0:Sm202e2A@0P=CP0?E9C03aAD`0M<S<083Hd02To?@0X?S/093Xg02Ln
>00_AT00<TU103YAB@0W?CX0<TQ60767Q@15FeT0>e5?03=9A`0_AD<00P0iCdd0@00X?S`0:Clm0316
@`0cBDH0<DQ202m6@00`Ad40<DM302m5@P0`AT@0<TQ602i4@P0`ADH0=T]<0398AP0cBT80=4]103=:
@00bAch0<dPo03A9@00dB3l0<TDl02`m=@0Y>S807BhV02Lh;P0W=bX0:CX[02/m<@0/?C<0:cdg02Pk
=`0Z?C/0<DE20397@P0`AD00=Ta403iCBP0hB400=D@o03U8A@0mC4`0?De=03i=D010D5<0=dU;03a>
CP0gBTT0>Ti<03Q<BP0kCdh0;d=203iBD@0oDe40>De;049FE01QMW40?E9=03aAC00fBd@0?U=<045F
C@0iCT@203M=@@80<dPo02d0>4e40356?`0aAT40;d@o0315@00hCDP0?U9@051VI01BIVD0AUYI049F
E00jCD/0>4]803I9A@0jBdD0?Tm803Q9@@0fACh0=dM203a<B@0oCd`0?4a903M7A00_?c`0:3Pe02Pg
=00/>cP0<T4l0350>`0gAT40>dY60354@00dA440=D=102/g<`0X<Bh0:C4]02H/:00R:bH09c4Z02Pc
:`0Q;RD082XS02@]:00V;bX00P0W<2/00`0X<B`09S4[02@_:@0202D`:P0302<^:00Q;2H06B8M0080
728N01`06R0L01/Q7@0P9R809R`X02@Z9P0O9B406b4M01TO6`0H7aT06R0F01`R5P0G7A<0724J02DZ
8`0J7aT06QlK028W8`0J7Qd0720Q01dQ8P0M8B@082HV01lU9@0E6a/061hN01<I6@0@5QH07R@T0P0J
82001@0H7Qh04aTI01@J6P0B51<051HE00806A/J01@08b@S03De=@0K6AX06ALH01DC500F4Q<061@E
01LE5P19AdP06QXJ010@40030`<0?Cdl024Q7`0C4a404a@@01<D3`0B4`h04Q<=014B30804Q<=00/0
5aPB01TJ500];RP0e=G?0?oonP1NGeT0414;014B300C50h05QLB010@3`02010@400:014A4@0@4100
410@014A4@0B4Q807AdM00<30`0C4a<051@D010@4P<04A4C00@03`lA00h>400@41803Ph@0P0=3@l2
00h>40H03@d?00/03Ph@00X:30092@/0410B00P82P0<2``030X;00h<3@0?3@h03P`=00d;300400h<
3@0300d;300<2P/03@/<00803@/<00X030X;00/92P0;2@X030X;00T7200E4a@0IVAU014?40081PL0
3``=0P0?2``03@0>2P/03@T:00d92P0<20T0510A00l;300C3a002@D6014=3P0=20P03PP8010:2P0?
2@T00P0>20P300d71`0300h8200?2@T04@/;00803@L7100>20P07P0?2@T050h>00d8200=1`L03PP8
010:2P0>20X0100000h92P0A2`d0100001<=3`0R71h03PP:00l92`0>20X02P@600/51`0>0`L040D9
01872`0@1@T04@H:01@93@070000304502<H700M4QH040D900d21PH03`@800H06PlC00`21@090080
50T=00d21P0@1@TDooooo`006oooool0100=4Ph041DA00`A3@0>4`l200lD400@00hC3`0B5a<03a@@
00`A3@0=4Ph03Q<?010B3`0>40d03a4>00d?300@4Pl03a4>00L91P0U9b@0@48o018D4@803Q0=0100
314;00lD3@0?50h02a0:00dB3@0C61<02Pl;00X>300E6AL03a<C014E5@0I7A`04A<@00h@3@0=3``0
3Q0=0P0?4@h04`0D5Q<03@l<00`>2`0=3``030h;00/=2P0=3``04Q@A01<E4P0E5a@09RPU00lA3P0C
5A801PP601DG500;3@X05QPE00lA3P0G6AH00P0?4@h04@0:30T061XG04=5@P0U9b@04aDB00`>2`0U
9b@0GV1M01LI5@0?4@`02@/601lQ700R91l030h9018D3`0A4`h0418=00<03Q0;01H0314=00@:200=
4A002Pd<00X>3@0I6aP02`d:01DG500;30L03Pl;01<D3`0?40X03Q0:00`>2@0C5A003@l:00`>2@0>
40/061XE01@F4@0<3PT03Q0;0P0C5A0200lA300G00d?2P0>40/0418=00lA300:30L0418=00h@2`0<
3PT04Q@?030b;@0A4Pd05AHA01<D3`0H6A@04Q<>00l@2`0=3PT02``700d>2@0?40/03Pl:00l@2`0>
40/00P0?4@`06`0:30L06A/F04e?BP0Y:bH02`d900h@2`0:30T02`d800T:1@0>3@T04@h;00/<1`0@
4@`041@>010E3`0:3`T03A4;00`>2@0D4`l06aTE01LC400A3@X05Q4>01DA3P0@3PX04@l<01LF4P02
018B3P04018C3P0F61<04Q@?00l@2`803@h900<03Pl:010A300@4@`00P0>3`X04`0@4@`04A8=03@e
<00A4Pd0414<014C3P0:30L04A<>00d?2P0A4`h03Q0;01dO6P1TIV405aTD00h@2`0E5a803a4<02la
;P072@H00P0<3P/200d?300O010B3`0G6AH02P`900d?300<3P/03Q0=00lA3P0=3``02`d:00d?300>
40d05QPE00h@3@0@4Pl03Q0=00d?300>40d03Q0>00lA400<3Pd04A<B018D4`0A4a802P`;00lA400E
5aH03Q0?01HH5`092`X0418A00L81`0201@F5@0A01<E500<3Pd03@l>00lA400>40l03@l>00h@3`0?
4A003a4?010B3`0=3``04Q@A014C400?4@h05QPE00d?300A4a000P0>40d01`0@4Pl04aDB00/=2P0F
61D0828O01DG500B51400P0@4Pl07@0A4a00418?00h@3@0=3``02`d:014C400>40d0:R`Y08^=RP0i
>cP03@l<018D4@0D5Q<02P`901<E4P0?4@h03@l<01XL6@0L7Q/0418?01<E4P0B51404A<@010B3`0?
4@h0418?018D4@0C5A80418>00804Q@@00L04Q@A014C400?4@h04Q@A00lA3P0E5a@05QPD00804A<?
02002`d:010B3`0C5A805QPE018D4@0?4@h0418?01<E4P0B514051HC01PJ5`0<4@d06b4O00hG500;
51405adK00lE4`0<4Q004aLF010C4P0B51<051HE01LI600J71/04ADF01LK700A5AH03a<D01dQ8P0B
5QL051PI014E5P804aLH03L03a<D01XN7`0@51<04QHE01@H5`0B5QD08RHU01XN7@0B5QD092PW00`@
3`0G6aX06AdL00`@3`0F71`06AlO01<I6@0D6QX041HF01XP800F71`06AlO01PN7P0F71`06AlO01/S
9@0I8BP082T`01HO9@0I92P06B@V01hZ:`0O;R/05RHS01`]9`0S=2d0834Z02<g<`0W?C/0:3hk02Dk
>@0[@Cl0;dE30357A@0`AT@0=Ta903M=B`0mDe40>4i;03U?C00kDTl0?5=@03UACP0hCd`0=Da900<0
<DQ502d0;DE202Y1?P0Y@3d0:T4n02a2?P0_AD80<4I302]1?`0Y?cd0:Cln02e3@P0W?3d0:Sm2049G
FP17G5l0:Sm202a1A00Z?d80:d1302Xo@P0bAdX0<dQ;02Pm@00]@TD0:d13028g>P0`ADP0;45402i3
AP0V>ch083Df0315AP0V?3X0:Cll02Dk>00Y@3X0;TDm02]2>P0Z@CP0;dE202m5@`0nE580;TA203Q>
C00`AT@00P0_AD<01@0aAdD093Xh02Pn?00_AD80<dU60080=di800X0=4]50357@`0`AT<0=de;03A:
B00^A480;dA503E:B`0eBdT0<TQ00P0bB3h07`0bAch0<dLn03=7?P0dASh0<dDm02Hg;`0Q<BT09cL`
02hn=00T=2P09CHZ02/m<@0b@c/0:cdf02Pk=P0/?c`0;40k0397@00dBD80>4i4045GB`0b@cT0:3P_
02dl=P0^?CX0;cln03M7AP0eADH0<49203Q;B@0kCT/00P0nDdh03@13EeD0@UIE03]?C@0lD4h0>Di:
03U=BP0lDD`0>4e703U>A`0hCDH0@EI>03Y?AP0hCT@00P0iCd@0>`0eBT40=DY203Q=A@0eBT@0=DY5
0356@@0iCTX0@UIC03mCD@17GEX0C61N03a@CP0hC4X0>Te:03iACP0lCd/0?Ti:03i?B@0iBT<0=dI0
03Y:AP0jBTL0?Ti;03U9AP0_?c`0;Shk02hm>`0[>SP0;chl0392@00iBdH0>TU703U;B@0eB4D0AUID
03a:B00Y=C<0;3Dc02L_;00O9B807bPS024[9@0O:R<07b`T028^9`0N:28082XT02La;00Q:bD09S0Z
02La:`0Q:bH09c4/05QRG00g@C`08BXU024W8`0P9R807B<O00806b4M00@07bDQ02<Y9@0Q9b<07B<O
0P0N92002P0K8Q`07R<K01`Q6@0F71@0724K02<X8@0I7QT04QLD01LL6@0G6a/201TM7`0401hR9@0F
6a`05a`L01@I6@806AhN02806QlO01hS8`0D6AT05a`M01TN7P0F6a/06AdN01XN7@0H6aX04A@C01<E
500C51@08b@T01PG600F5AD0518C01DB4`0F4a@0518C030`<00I6AT06QXJ020P801XJ6L06a/I018B
400A4Ph0414<014B3@0A4P`03a0:010A2`0E5Q004a@>0P0H6A<0101<CDL0OWmi02`]9`0@4@/2014B
300301LH4`0B4Q403`l?00804A4A00D0410@018B4P0C4a<04Q8B00h>3P02018B4P0300X:2P0@4180
410B0080410B0P0?3a40100@41804Q8D018B500@418200h>400F00d=3`0>3Q003`lA00h>400<30h0
2`/=03Hf>00<30h020P:010@4P0?3a403`h@00d;30091`P04Q0A00T7200B414030X;00h<3@0?3@h0
40h?00h<3@<03@/<01`030X;00/92P0<2P/030X;00d;300A3a005Q@E085oP00B414040h?00l<3@0?
2``03PX;00d92P0<20T03@T:00X61`0C3a002PH700d92P0<20T04`l@00l:2`0?2@T04P`<014;2`0>
20P040X:0P0;1@D00`0=1`L03`T900l92@0200h8200700l92@0>20P03@L700`61P0;1@D03`T9010:
2P0200d71`0400h8200=1`L040X<00`720803`T;00@06Q@F00/61`0@2P`02PD60P0=1`T04@0>20X0
40X<00l4200?10P04PL;00/2100B1`/050T=00l4200A1PX03@@601072@0B1`/03@8601052@0E2Ph0
4PL;00803`@800<03P<700X10`0?10P00P0A1PX00`0B1`/030<5ooooo`0Cooooo`006oooool0200B
5a<03A8>00P=2@0010003Q<?010E4@0;40`03A8>0`0>4`l00`0<4@d0418?00lA3P0300d?300G00h@
3@0C5A805QPE02HX9@0;3@X04aDB00`>2`0=4P`03Q<=00dB300:3`T0314=00lD400@5A403Q8A00H:
2@0@51D09RX[05mSHP0A4a4030h;00/=2P0=3``00P0>40d09P0@4Pl03a4>00h@3@0>40d03@l<00`>
2`0@4Pl00`D201/M6P0A4a000`D202@V8`0`<Rl02P`90002000C5A80FeeJ03Xl>@0@4Pl00@<0010B
3`082PL02@/8038d<@0@4Pl0004001HH5P031@80=cTf01HH500A4`h010H104mAC01SIF007AlJ00P:
1`0?4@`03Q0;0`0=3`X01P0;40`02a4?01<G5P072`X03A4@01@F4`8030h;01003@h900h?2P0?40/0
3a0:014B3@0=3`X05aTD014C3P0@4Pd03Q0;00`>2@0>40/03@l:00`>2@0@4Pd04A<>0`0;3@P300`>
2@0;00lA300F61<0418=01DG4P0G6A@030h;00/<1`0@4@`030d800l@2`0>3`X00P0=3PT300h?2P80
3a0;00h020X5010B3@092`H03Q0;00lA300>40/020X5014C3P0I6aH01`T4024S7P1=CTT03`h:014>
2`803a0;01003A0;00/@2P0=4P`041<>00`>2@0>3@T03``900P40@0E40d07APE01HB3`0@30T04Q0<
01@C3`0=30P05ADA0P0L7AP0100E5Q4030d800d>2@0>3`X300l@2`0:00h?2P0H6A@01`P301/L5`2;
S8L03a0;0042000A4`h03a4<018D3`803Q0;01l051HA01<E400];bX00040018D3`0<3PT051HA00T;
200:30T03Q0=018D4@092`P04A<@00X<2@0@4Pl00@<001/M6P0A4a002@/800P:1`0?4@h06Q`I01/M
6P0;3@X00`D200d?300>40d03a4>00d?300:30T02P`:00804A<B00/03Q0?018D4`0C5A@03Q0?01LI
600C5A@01`T800lA400@4Q403a4@00`>3@0200X<2`0?010B4@0>40l030h=00lA400=3`h030h=00d?
3P0?4A0051HD01LI5P0B51403a4>00T;20082PL061XG00803@l<00T03Q0=01PJ5`092`P05ALD00T;
200I6aP09bTV01DG500<3P/00P0@4Pl06`0A4a00418?00h@3@0<3P/04aDB00h@3@0A4a0010H304M9
AP0I6aP030h;00/=2P0@4Pl04aDB024S800N81d06Q`I02HX9@0L7Q/01`T600`>2`0@4Pl0?T0m02h`
;@0@4Pl01@L400T;2002018D4@0601@F4`0F61D05ALD018D4@0?4@h04aDB0P0A4a002@0C5A004Q@?
00d?2P0B5140418?014C400C5A8051HC01<E4P0201@F4`0>01<E4P0D5Q<05ALD01@I5@000P007BHS
00TB3`001@<05A/I018H5P0B5QD04A@C014C4P0C5A@201@F5@0301<G600@51D03A4B00806alP00@0
6QhO018F5`0B5QL04QHG0`0A5AH03P0G6aX05QXI01TM700B5QD0720O00hB4@0H71/051PG01<G5P0E
6AP05QXI01DI600D6QX06AlO0P0L8R80100G7Ad05A/K01@J6P0F71`201DK6`0;01TO7`0J8R@05AdS
01LP9@0E7b405R4T01PS9@0M:RT07RdZ020a:`0V=c400P0Y>S803@0S=S809cdk02To?@0X?S`0;dE3
03=9A`0eBdT0?59@03iDDP0oEE<0AE]I04ILFP14FeT00P13G5T01011FUL0?5EB03]DD@0fCd`2035:
A`050319AP0]AT<0;DI302e5@P0^A4800P0_AD<0700^A480;49002Pn?@0Z?d009S/l02Hk?P0dBD`0
@eQK04IKGP10EEP0;T=602Pm@00U>Sd0<TM:02<h>`0[@4<0;D9502Tn@@0aATT0:d1302e2A@0_A4D0
:Sm102Dj>`0`AT@0:Clm02Y0?@0W?CX202Po>@0902Hm=@0]A3`0<4I302a2@00_AD<0;TA202m5@`0b
B4H0>U1>0080<DM501P09cdk02e3@@0]@d00;48o03E<AP0fCDL0<4M102a3?P0`AT<0=4Y803]AC`0l
DU00>Tm@03A9BP0/@T00<4Dn0397?P0aASd0;d@k02a1>00[?cH0:CXb02dn=P0P<BT2028a:P0K02Xj
<00W=b`08c@X024c9`0[?3@0:C/d03A7@@0fBDD0>De703M<@`0_A3/0=D`o051VF@0iBSl0;Shd0310
=P0/?3H0:c/h03A4@`0gBDP0>4]903U<B00kCdX0?55:03eBB`0kCd`0>4a:0080?E5?00h0=T]603A9
A00lDD/0=T]40356?`0eBT40>Di503M<@`0hCD@0>e1703Y?AP0gC4<0=da503Q=AP80?E9=01X0>Tm:
04AHEP16FUP0?E5?03aBC`10E580>4a:03E9A`0dAd<0=DQ403a?B`0oCd`0?4e803i?B@0mC4L0>TY6
03E5@P0hB4D0<T8o02`l>@0^?S/0:c/i02Ph=`0a@D00;T4o03U<BP80;d9000`08cHd0351@00[>CL0
8Bd[02Tb<@0X;bh092XX028[:00R;2H072LQ01`Y8P0P;2D201dX8P0N02D`:P0^>C<0:C@^02`e<00R
:bH07bPS05aUH00b>cH082TT024W8`0O9B40728N01XP700L8Qh07bDQ020V8P0L8Qh06AlK01`R7P0M
8al06AlK01PM5`0G71H05a`H01TN6P0K81`05QXI00hB4@0=4A804QHG0P0F6Qd05P0M8B@09RX[028V
9`0J7Ql05QXK01@H6@0@51D0Ngn002da<P0830d061`M01@H6@0Q9BH03Q8A00lC4P0@51<04Q@C01dO
7P0?4A005ADE01@C4`0D4Q<201DC5006018@4@0G5aL04A4A010@400A4A4071`K0P0G5aD07@0D5140
4A8=014B3@0A4P`03Pl901DF400P8A/06Q/E018C3@0@4@/03a0:024R700D5@l03Pl9014B300H6A<0
4Q<>01@D4`0?3`l04a<C018B4P0>3Ph0410@00T92@030`<02`/;01@D500A4A404a<C00L03`lA00<0
4a<E01@D5P0A4A<00`0=3@l03P0?3a40410B00l?4@0<30h02`/=05eMG`0d=3H04Q8D00d=3`0A4A<0
0`8300l=3P0U8b@0<2h_0P0N71d0100<2P/03@/<00h<3@0>30d200`:2`802`T:0P0=2``0800<2P/0
2`T:00P61`0?3@h00@0001`J6`091`P07A/L014>3`0:1PL02`L801<?400F4Q<040`=00/7200A3@h0
2PH7014=3P0810D0=C4b010;300=1`L03`T9010:2P0=1`L03`T900/51@0:10@02`D500d71`0?2@T0
3PP80`0=1`L500`61P<02`D501P030H605==C`0W8B<03`T;00L10`0:10H04P`>00/51`0?2@/03PP:
00`6200>20X03@L901052@0800404@H:020E6@0Y7R804PL;00h31`0E2Ph02`0401H;3`0>0`L200l4
200601<8300?10P03`@801<8300?10P03P<70`0?10P201052ACooooo000Kooooo`0800T>2P0:3`/0
5a`H00L<200F6aL0314=00/@300=4Ph300hC3`0300dB3P0@4Pl03a4>00<03@l<01H03Q0=01XL6@04
1P@00`D201<E4P0a<c009bTV00`A2`0=4P`02a0:00X?2`0<4@d03A8>00X>3@0F6Q/020`=014E5P05
2@X0720O00lA3`0;3@X02P`90P0=3``00`0<3P/03Q0=00h@3@0400h@3@0700lA400@4Q400040010B
4@0[;B`0004000T:2@0201<E500G010B4@0E5aH0418@00d?300620D04aDB00`>2`010`004aDB01LI
5P0D5Q<0=CLd00lA3P0<3P/0418>00`>2@092`H061XE01TK5P0B50l05QPC00lA300>40/00`0=3`X0
3`0A5Q800@L500`@3`0B5QD04ADD0001000@4Pl030h;00d>2@0>3`X03a0;00l@2P0@4P`02`d8014C
3P0200lA300300/=200:30L03@l:008030h900<0418=00lA300;3@P00`0;3@P200X<1`0600<5000@
4Pd020X50001000G6A@04Q@?0P0?40/0600=3PT01`P301<D3`0I6QD03Pl:01@E400A4Pd03@h9018C
3P0?40/02@/600h@2`082PD04A<>00h@2`0620<02P`700/=200=3`X0004003Tk=P1fMg803Pd900l=
2@803@h901H02`l900X?2@0:3`T04A@?00h@2`0>3@T04@h;00l;200F4Pl05a<@010<2@0:2@D03Pd9
00l>2P0=3PT04a@?01TJ5@0H6QD04Q@?00`>2@0@4@`03a0;100>3`X2018C3P0700h?2P0S91l02``7
01HG4P0@4Pd03a4<014C3P0200h@2`0=01<E400g>C@0004000/=200I6aH00@<0010B3@0<3P`03@l>
018D4`0?4A001@L601<E5002018D4`0;00X<2`0>40l00P@301`N7@0G6AH030h;010B3`0D5Q<03Q0=
00/=2P0=3``00P0>40d00`0<3P/02`d:00`>3002010B4@0:00h@3`0A4a804Q@C014C4P0210<00081
01XL6`0C5A@01@L600P:2@803Q0?00@02`d<00h@3`0>40l03@l>1@0>40l00`0;3@/030h;01DG5002
01LI5P0=01TK600@4Pl03a4>01/M6P0?4@h04Q@A010B3`0A4a0030h;01<E4P0J71T04Q@A00/=2P03
00lA3P0M00h@3@0=3``030h;01`N6`0=3``05ALD00H81@082PL04Q@A00lA3P0=3``0418?00lA3P0J
71T05aTF01<E4P0F61D0418?00T;200>40d05aTF01hP7@0G6AH03Q0=00lA3P0E5a@06A/H00lA400D
5QD00P0G6AP02@0B51803Q0=018D4@0A4`l04A<>018D3`0A50h03Q0;01<E4P02018D4@0L01<E4P0D
5Q<04Q@A01@F4`0C5A804A<@018D4@0D5Q<051TE01`R8014CDX07BHS00@:200C6AL02Q0>018F5@0D
5aH05ALF01@F5@0E5aH061XI00`@4@0R9RL01`/<01@H6@093@h05ATJ01@H6@804aLH00H04QHG014E
5P0A5AH04ADD00/?3P0D61L201HJ6@0401PL6`0F6QT05a/J01LK6P805ATH00P05QXI01PN700@5Q@0
5Q`J01PN700F71X06R0N01DK6@805adK02805Q`J01LM6`0G81l051dP01<M7`0E7b005B0Q01`X:00O
;B/072/X020`;@0Q<R`08S<]02<d;P0P<c009S`j02To?@0[@Cl0<TQ603I<BP0hCT`0?E=A045GE@14
FUP0Bf5O04eSH@1:HUl0BV=P04URG`16Ge`0@U]H03mHE@0iDTl0=4e:0P0cC4T01`0aBTL0<4U60317
AP0_A4D0;45202Xo@00[@4400P0/@D80G@0Z?d00:Cho02a1@P0L<C80;T=403aAE00dBD`0:Sm202Tn
@@0X?D00;T=602]0@`0_A4L0:Ci102i3AP0U>Sd0:3e002Pm?P0/@T00:T0o02@j>00Z@3h0:3hl02To
?00X?S/0:d4m02U0>P0V?CL0;D@n03mEDP0[@Cl0>U1>02i4@P0`AT@0>U1>0316A00]@d40;TA202Lm
>`0cBDL0=D]80316@`0bBD<0<4M102m6@00`Ad80=4Y703I<BP0iCdd0<TQ60356A`0eBT/0<4I402i3
?00dBCh0<dLl02e1=P0Z?C80;Chd02<d:P0W=bd08C4W028b:00N;R@0;3`b02Lg;00Y>Rd09CL[02Xk
<`0Z?3D0=dY403E8@P0]@CX0:3dd02Dk;`0W?S40<DPh0396=`0[?C40;Chd02Tj<`0X>3D0;D0l03]>
C00jCT`0>e1;03]AB`0kDTX0?5=;03M<B00kCdd0@5AB03]@B`0203A9A00703aABP0fBd@0<4Dl03=8
?`0eBT40<TLn03Q=A00203]@B@0=03Q=AP0hCDP0>Di903aAC00iCD/0>dm=03mCD@0lD4h0>4a:03U@
BP0mDTd0=da703A9A00203=6@P0n03Y=B@0oCd`0?dm<045ACP10Cd`0?4]703Q7@P0hAd@0<d=003U9
AP0jBTT0;d0o02Xm>`0cADD0=DU803iBD@0aAD@0?U9@03U<BP0dA4<0;C/k02Te=@0c?3/0<3Lg02L]
:`0R:bP092hZ024/:00P;BH07R/T03A1>P0mBT<08BdV01lZ900Q;2H0:C8]02D^:@0O:2<0<3Hb01lU
8@0Q9b<08RPT020V8P0M8al06b4M01`R7P0O9B408BLS01dS7`0J81`0728N01dS7`0I7a/07B4P01XN
7`0I7Ah06QhO01LK700@51D04ADF00dA500@51L201HJ7@0401XN8@0U9RP08B<R01XL6`<05aTH01X0
D59A02T[:P0H6QT0:2XY01PJ6@0F61L08BDV01DI6P0I7Ah041@E01lQ8`0<3@l05AHH01<D5P0C4aD0
51@F01@C5P0B41<071`L010@400A4A40410@00H61@0K6aT071`J01LH50804Q<>00D04A8<00l@2P0?
40/05AHA01<D3`02010A300C00d>2@0C50l04A8=00d>2@0A4Pd07AhI018C3P0H61L04A4A018B4P0A
4A403Ph>00l?3`0H61P04a<C01@D500K6a/00`<3010@400700l?4@804A4C00D03`lA00h>400?3a40
30`>00h>400200l?4@803@d?00h05aLI00000P010@<03`lA00/;3@0G5QL020H700d;300A3a005aDF
00`:2`081PL03@/<00`:2`<02`T:02H02@L800`:2`0B41404a4B00d;300;2@X030X;014?40010000
3`d>0040000C4A803``=00`82@0>2P/07a/L02DQ8P0H51D04@d>00/7200300004Ph?020L7@27Ph@0
>C@d00d71`0?2@T040X:00d71`0?2@T040X:00d71`0;1@D030H600h8200@2PX02P@400/51@803PP8
00@03@L700`61P0<1PH030H60`0=1`L07`0<1PH04`d?00D00@0<1PP03`T;010:30090`D02P@600l9
2`0A2`d040X<014;3@0=1`T02P0300d21P0I3Q8060dA01X?4`0>0`L02@0201<830070000714E00P0
0@0@1@T04@H:00d21P0:00<03`@801D:3P0>0`L00P0@1@T300l4200300h31ooooooooooo01;ooooo
000Kooooo`07014F4P0<4@d02a0<01HK5`0U:RH08RLS00`A3@0200dB3P<03Q<?00<0418?00lA3P0=
3``00P0=3``05P0>40d02`d:010B3`0F61D051HC02DW900Y:bP0314<00/@2`0:3`X02a0<00/@3@0<
40h0310?00X>3`0;3a002@d?014E5`0:3Pl03a4?00d?300<3P/200lA3PH03Q0=01h03a4>01<E5006
20L06adL00lA400@4Q404aDD00/=300=3`h04aDD00h@3`0=3`h0418@00h@3@0C5A803a4>00/=2P0A
4a003Q0=00X<2@0B51403@l<01<E4P0<3P/03a4=00X<1`0>40/0418=00/=2@0?4@`200h@2`0D00d?
2P0<3PT03@l:00d?2P0>4Pl0BDm=08F9R00H71/03A4@00/=2P0?4@h030h;00d>2@0>3`X03a0;00l@
2P0<3@P02`d800lA300>40/200d?2P0600/=200>40/03Q0;00h@2`0A4`h03a4<0P0@4Pd0900?4@`0
3Q0;00h@2`0=3`X08B<N06QZI@0D5Q802`d:00`>2@0@4Pd04A8=00l@2`0B4`h01@H101HG4P0K71L0
3@h901HG4P0B4`h03@h901LH4`0B4`h02`d8018D3`0=3`X03a4<00X<1`0?4@`03Q0;010B3@0620@0
418=00/<200J6aH040l;014>2`803@h901003A0;00`A2`083@L041@>00d?2P0<2`L040d:018>2`0D
4@h04a0=014@300B4@d04A4=00d>2@0B4`h03a0;0P0:3PP01P0=4@/04A<>01<D3`0@4@`03Pl:00d>
2@803a0;00@04A8=00h?2P0?40/0414>0P0=3PT200h@2`0I00d?2P0<3PT03@l:00lA300D5Q802P`7
00lA30092`H0418=014C3P0@4Q403Q0?00L9200?4A003Q0?014C4P0B51<01`T8014C4P0@4Q402`d<
03m1@00O8Ah02P`900P:1`0200d?300300h@3@0?4@h03Q0=008030h;00<0418?014C4@0?4A00100?
4A002@0B51<051HE01LI600;3@`02@/:01<E500@4A004aDD01DG5P0200lA400I014C4P0?4A003@l>
00lA400@4Q403a4@00d?3P0?4@l02`d:00lA3P0:2`T071hK038d<@0N81d04Q@A01dO700?4@h04Q@A
00h@3@0=3``03a4>00d?300>40d04aDB014C4003010B3`803a4>02003Q0=00`>2`0?4@h09RPU00lA
3P0H6QL04aDB00lA3P0;3@X03a4>00X<2@0@4Pl03Q0=00lA3P0<3P/04A<@01HH5@0A4a003a4>01<E
4P0B51404A<@018D4@0@4Pl030h;00lA400@4Q804A<C014C4P0@4Q003a4>010B3P804Q@?00@04QD?
018D3P0@4``05ALD0P0C5A8201@F4`03014C400C5A804Q@A0080418?00H04aDB01<H500F71X041LD
010I5P0D6QP201<I5`0800lC4P0D5aH05ALF018D4`0D5QD061XI01HJ6`1IGEh201LK700300`@4@0J
7Ql05a/L00805QXK01405ATJ01@H6@0D61T06AdL00dA400O8b809b/Z018F5@0G6aX05ATH01`P7`0M
8B0061`K01@H5`0E6AP05Q`J01<I5`02028X9P1901@J600F71X061hL01TO7@0J81h06b4O01TO7@0G
81h06B8R01TS8`0O:BL06RHU020/:`0X=S@082l/020`;P0S<c40:3Td02/k>@0W>SP0:3dm02]0@00^
A4<0<TQ703M=C00lDE40A5UI04]PH01CJ6P0G79a05idL`1KLg40F75_05E^K01@JVP0BfAR04IPGP10
FUP0>UAB03M@CP0dCT`0<Ta:031:B00_ATH0;dA602e2A00[@480:Sm102]0@P0]@T@0<DI802]0@@0a
ATL08CHg02Xo@00X?D008SLj02a1A00_A4L0<DI902Pm@00]@TD0=4U<055VJ@0eBTd0D6EX0397B@0V
?3T0:Clk02]1?P0W?CX09C/i02To?00202Lm>P0N02]1?`0`AT<0<DQ302m5@P0aAdD0:Clm04YPGP0d
BTP0>e5?0398AP0_AD<0<dU70357A@0_AD<0>U1>03Y@C@0gCDX0<DQ202]2?00]A3h0<TQ403E;B00e
BdT0>4i<03A:B00eBT/0>4e>0398A@0]@S/0;d@i0P0aACX0=00a@cT0<44g02Lh;P0V=R`093@Z02/i
<00U<bX0;C`a02Hf:`0_@3<0<T@h03a=A@0bA3d0;D0j0396?P11ETd0@UQ<03E;?P0Y@C40;4<b02Pl
;00Y?Bl0:d0c02a0=P0_@cd0=4Y403U?BP0jD4X0>E5903YCB@0kE4T0?5=904UNFP0nDTl0?55=03U>
B@0fBdD0>Di803]@B@0hCD@0=4U003Q=@`0jD4D0=da303eBBP0mDT/0?55:03Y?B00gC4L0=T]603M<
B00dB4H203U=B`0d03E9A`0fBTP0=Te703A9A00bAd80<4E00395@@0fBDD0?E1<03m?C@0mCD/0?dm=
03m>C00kBTH0=dI103A3@00`@3d0@U9?049DDP0`@d40:3/j0355A@0hC4`0@5AD03=7B@0fBDX0=DM6
02Ti>@0Z>3P07BTY02Pa<@0X;bl08RPX01dV8`0S;BX09S4]02Lc;P0Z=c40?de604EBB`0Y=Bl08blY
024/9P0O:2<092dX02`d;`0P9R8092XV02H/:00Q9b<082HR01dS7`806b4M00@07B<O02<Y9@0P9R80
7B<O0P0L8Qh03P0L8Ql061`R01TK900J7BH05APP018E700K7R@061/Q01@G6`0H6al07R8U01XN8@0D
61X06Q`K0P0H6QT0400J71/06adL01XL6`0H6QT051HE02<U900A4a806Q`K01dO7P0Q9BH0;34a00lD
5@0K7b004aHG01TK7@0E5QP201@D5P0M01DE5`0E51L04a8D010@400F5QH02PX:01`L700K6aX02`/9
01TI5`0E5A804A8=018C3P0C50h04A8=010A3@0@40h04A4>01<C4P0C4a40410=00l?3P0D5180410=
00/;2@0C4a807AdL01XJ6P0D51@00P0@410200h>3P0601<C4`0<30`030`<010@400A4A403Ph>200?
3a40200>3Q003@d?00h>400@41802`/=00d=3`0>3Q003`lA0P0>3Q003P0D51H0;Bd_01HF600>3Q00
2PX<01dL7@081`L03P`=00X82@0>30d01@@4018@4@0?3@h03@/<0P0<2P/01@0=2``030X;00l=3P0E
4a@04a4B00803@/<00L03P`=00l=3P081PL04a4B00P61`0>30d03P/<00803@T:01405a<D01/G600D
414030P9010<3@0<20T03PX;010<3@0L61T04@`<00d71`0?2@T040X:00d71`0?2@T04`d=014;2`02
00l92@0:010:2P0?2@T02@<300/51@0>20P040X:00l92@0=1`L03PP800l92@804@/;00<040X:00l9
2@0<1PP00P0@2P`0100;1@L030L800X51P0>20X200d72@03018<3P0F41803`T;00804`P<00L03PD7
00/2100@1@T0304501462P0B1`/0;24U00804@H:00T03`@801872`0?10P03`@801052@0?10P03045
01462P0@1@T00P0?10P00`0>0`L03@86ooooo`0Cooooo`006oooool02@093PX03A8>00P=2@0b=c<0
ADY605=HE00B5a<041DA00dB3P0200/@300300X?2`0@4Pl03a4>00<03@l<00P03Q0=00P:1`0?4@h0
5ALD00/=2P072@H02`d:00dB3P802Pl;00l0314=00`@3`0;3`h03Q8A00451P0D61T02`lB00`@4`02
1PL03a4?00d?300>40d04A<@010B3`0?4@h01P0>40d07P0?4A004Q@C01TK6P1mOgh0004000lA400=
3`h030h=00@61@092`X03a4@00X<2P082PL02P`900d?300C5A804Q@A00T;200?4@h03Q0=00`>2`0>
40d00P@1010B3P0<3PT03a4<00D7100210004A<>018D3`<030h90P0=3`X03`0I7AX0PhV70<G9b00R
9RD01PX901/M6P072@H030h;00d>2@0>3`X03a0;00l@2P0C50l06A/F00h@2`0200`>2@0500lA300:
30L03@l:00`>2@0:30L00P0=3`X200h@2`@03@l:02000P@001lQ70051`<06Q`G01DG4P0A4a003@h9
00h?2P0@4@`02@X5014B3@0?40/030d8018C3P0@4@`03@h901@E400A4Pd03@l:01@F4@0@4Pd03@l:
00/=200N81/00@<000/=20000P004A<>01@F4@1KG5L04A0<014>2`803@h901003A0;00dB300730H0
3A0;00/=200=30P04a4=01@@3@0>3@T03`h:01HG4P0H6A@04Q<>00h@2`0=3`X03a8=0P0@5@l0100>
4`d02a0:010B3@0@4@`300l@2`09010A300B4`h03@h900T:1@0720<04A8=01@E400?4@`04A<>0080
3@l:01d0418=00lA300D5Q405QPC00/=200A4`h05ALB00P:1@0>40l04A<B00T;2P0>40l02@/:00P:
2@0<3Pd05QPG014C4P0@4Q4020X900D71P0<3P/02P`9010B3`0B514030h;00/=2P0<3P/04Q@A014C
400200/=2P0?00lA3`0>40l03Q0?010B4@0=3`h030h=02LY:00E5aH0418A01/M700<3Pd0418A00`>
3@0@4Q404Q@C00803@l>01T03a4@00h@3`0=3`h03a4@010B4@0?4A003@l>018D4P0B51404A<@00X<
2@0@4Pl071hK01PJ5`0;3@X04Q@A00h@3@0C5A8051HC018D4@0E5a@0418?00/=2P0@4Pl03Q0=0080
4A<@01D0418?00lA3P0@4Pl04A<@01@F4`0A4a00;Bl/00h@3@0L7Q/03a4>00h@3@092`P0418?00d?
300A4a004aDB01HH5@0@4Pl03a4>018D4@0A4a000P0?4@h03P0=3``02`d:00h@3@0B51406Q`J01<D
5P0A4Q@03a0B00lA400B51805ALD00h@2`0A4`h04Q@?0P0A50d01`0B5@h051HA01<E4P0C5A8051HC
01DG500C5A800P0A4a02018D4@0C01<E4P0A5Q805Q`J01@M6P0?61D041HD01<I5`0>518041@C018E
500C5A@04Q@C01<E500F61L0310A024U9P062P/04QHG00H:2`06018F5`0F01<G600;3`h04ADD02da
<00a=C@06alN01@H5`0R9RD06alN01DI600A5A@051PG01LK6P0C6AL061hL02@Z:00S:BL051XH018H
5P0G7A/05A/I01HL6P806AlM02005QlL01HP6`0G8Qh06RDQ01LS7`0J9R@07bdZ01DT8@0L;2/0:SXi
02<c<P0V=SD0:Sdm02Xo@00]@T<0<dQ903A9BP0iCTl0@UMH04mTI@1IKVl0IW]l07:7R01dRHX0LHV9
06^5Q01UOgh0GWQg05I`K`1?JFP0AEmN03aFE@<0=U1?02X0=4i=0318B@0_A4L0;dA702i3AP0[@4<0
:Sm202]0@`0cB4/09c`m02Dj>`0[@44093Tj02m4A`0S>3/0;D9502Pm@00`ADP0;45402<h>`0B9bX0
?E9E02Pm@00_A4L0:3do02To?00V?CL09chh02Y0?@0T>SL0;48o02Y0?@0Y?c`093Xh02Lm>`0`AT@0
=4U902Lm>`0/@T00?E=A02Y0?P0gCD/202]1?`0Z02m5@`0/@T00=4Y803A:B00aAd@0>Dm<03=:A00]
A3h0;TDo03=9A@0fC4T0>U1>03E;B@0nE580@5EF03=8B@0]@d00<4@k02a0=@0[?c@0;T8g02`n=00U
=R`08c<Y02Ti;`0S<bT0;CXa02`i<00/>Bl0;Cd`02m0=00[?C40>4U103A6?`0[?SP08CD/0397?@0a
AcX09S`_02Dm;00/AC80:T4_0P0]A3@02`0]A3L0<TU103M>AP0fCTP0=Dm603I@A`0hDTL0>E=603UC
B00oEDh0=T]60080>4e801H0<TM00315?P0fBd@0=DY103=8?`0iCd<0?UA803]AA@10EDh0?E9;03aA
BP0kD4T0=da703A9A00iCD/0>4a:03M;B@0iCD`0>Ti=03]?C@0dBd@0;T<n0P0`AD00:`0cAT80>Te9
041CC`0oCdh0>DU803Y:B@0kBDT0>TU603A3?P0a@3d0:cXg03A4@@0gBTP0<4A202Tm?00aADH0<DI7
03=8B@0Z?d80=T]<03e?C`0L;2`08c4a01DQ8@0T;2h09B`]028X:00M9R<082XV020[9`0Q;BT082hX
01`[900N:b@07b`U02@a:P0R;BL08b`W028[9P0W;BT07R@P028X900S:2@00P0O9B401`0M8al06R0L
01XP700J81`082HR01hT800I7a/00P0F71P08P0H7Q`06Q`Y01/L;P0P8C806A/Z01<E8P0T9c405APQ
01@G7P0M82D08bLZ01hR9@0I7Ah05QPG01LI600J71/071hM01/M700F61L061XI01`N7@1dMWD0>cdl
01XL6`0R9RD0WJ6R0;:h^00D6QX06AdN018F5`0E6AX05QLI01@E5`0D51H201DE5`0>018B500D51@0
5QHF00l?3`0B4Q80410?018B400@40h03a0<010A300C50l051D?018C3P0H61H301<C4`803`l?00T0
30`<00h>3P0<30`071`L00410@0I6AT05aLG01<C4`0>3Ph00P0?3`l01`0<30`0>CTi02LW9`0L71`0
30`<01`L700410@01P0?3a4300d=3`0300`<3P0>3Q00410B00<030`>0`0=3@l0300410H0<S8d014A
4`061PP03Ph@00d<3@0;2@X061HG00`:2`0D4Q<05A<D018@4@803`d>00<03P`=00d;300>30d00P0<
2P/01P0>30d02`T:00T7200;2@X03P`=00d;30<02`T:01/030X;00h;300?2``03@T:00X61`091@H0
30P9010<3@0H51D02`L800<0000F4Q<00`0001HA4P0=1`L03`T9010:2P0=1`L03`T900/51@0:10@0
2`D500h8200?2@T03@L700/51@0<1PH00`0?2@T00`0>20P030H600`61P0300d71`0500`61P080P@0
1@0102PR900m=cT00P0E3a402@0;1@L03@L900/51`0<1PP040X<00d72@0=0PH04@H:00d31P020187
2`0=00d21P0@1@T04@H:04]0A00:00<04@L:00T00P0C20`04@H:01872`0A1PX03P<701462P020105
2@<03`@800<03P<7ooooooooool04_ooool001_ooooo00P02Pl;01DJ5P0;40`06AhJ010C400:3`/0
3a@@00hC3`80314=00@03A8>00hC3`0@4Pl03a4>0`0=3``0200>40d030h;00lA3P0:30T04Q@A014C
400B51403Q<?0P0:3`/04@0>4Q403A4@00`@3`093@h0<SHg00020`062Pd05QXM01@H6@0>40h030h;
00h@3@0A4a003a4>00h@3@0@4Pl03a4>00803Q0=02003@l<00`>2`0>40l020X900T;2P0Q8b803@l>
01DG5P0>40l03a4@03Pj>@0a<c808R@S01<E4`0<3P/02@/8010B3`0C5A803@l<00X<2@0F61D04A<@
01LI5P0<3P/02@/8018D400=3`X02@/6010B3@0F61<03Q0;00T;1P802`d80P0<3PT04@0=3`X01PX7
01<I5`0^<S4041@C00P<2`0G6AH03Q0=00`>2`0=3PT03Pl:00l@2`0?40X08R@N02d_:P0<3PT02@/6
008030h900@03@l:00lA300;3@P02@/60P0=3`X00`0;3@P030h900`>2@0200`>2@0=00d?2P0D5Q40
10H101HH4`0;3@P04aD@00X<1`0=3PT04a@?00l@2`0C50l0414<00h?2P0300l@2`<03Pl:00h030h9
014C3P0>40/0418=00h@2`0Q8ah092HQ00X<1`0E5a80418=00<50P0N7aX04A0<00l=2@802``700X0
2`l900dB30083@L02`l900`>2@0B4@d06aTE01/G500=30P030d80P0B4`h02@0;3@P03@l:00d?2P0>
4`d04AH@010G400=50d02a0:00h@2`02010A30804A8=01@0414<01<D400@4@`06AXE00h?2P0J6aH0
004000lA300A4`h030h900d?2P0@4Pd03Q0;00/=20082PD01PP301<E400A4`h0418=01<E50804Q@C
0P0:30/03`0Q8b803a0?010B4@0>40l030h=01TK6P0C5A@03@l<00/=2P0>40d03@l<00h@3@0B5140
3@l<014C4002010B3`0D01DG500F61H03@l>00d?3P0@4Q4030h=00/=300:30/01`T804i@C`1_LG00
30h=0001000>40l03a4@010B4@0<3Pd03Q0?00lA400=3`h200h@3`0C00lA400>40l03Q0?00T;2@0=
3``04aDB01`N6`0E5a@03@l<018D4@092`P051HC00lA3P0;3@X07R0M018D4@0D5Q<04A<@00d?3002
00h@3@80418?00d03a4>00h@3@0?4@h04A<@00/=2P010`003@l<00lA3P0J71T030h;01<E4P0=3``0
4Q@A00802`d:03L03@l<00lA3P0?4@h030h;00lA3P0D5Q<05QPE010B3`0B514051HC018D4@0>40d0
2P`:014B500A4QD0414C010B4@0C5A<04aDB00d?2P0B50h04aH?014D3@0A50`04aH?01<E400B5140
4aDB01DG500F61D051HC010B3`0B514051HC01DG500D5Q<041DA00@:200A6QL02A8?00P>300C6AL0
4QPF01@H5`0C5QD051HE01DG5P0G6AP05QPG01@H6@0?4a@0310A01PL7@0G6a`05QXK008041@E00L0
4ADF018F5`0C5aP04aLH01/O7P0N8R40:Rh]00805a/J00<041@C01lS8P0I7A`00P0F6QT201LK6P05
01DK6@0B61H04QPF01@J600F71X00P0G7A/09@0D6QP05A/I01XP7P0K8Al0624N01LQ6P0G8Q`051lI
01PU7P0L:2@082dZ01h]:P0eAD@0Be]J02dm?@0[>c/0<4=502]0@@0_A4D0>4e>03U>C`0nDe@0BUmP
05M/K@1SN7T0LXN8082EUP22UiP0P9RH07ZDT`1bS8/0JXB3061jN@1FL6l0BfET041JF@0jE5<00P0h
DU40:@0eCdh0<TU:0315BP0_A4T0;T=802a1AP0[@4<0;4540315B00^@d@08CHg02i3A00U>S/0:3e0
01`a=00[@4<08SLj02m4A`0^@dH0?E9E02Pm@00^@dH0=T]>01X_<P0bAdT0;D@n02Dl=00T>c<0:d8l
02<j=00]@d009S`j02i4@P0`ADH0:Sm002e2@`0cB4X0=4Y803=9A`0bB4H0;TA20080<dU700P0=de;
03Q>C00hCT`0C69P04=IE`10EU<0=D]803A;A@80<TU302H0=Te803Y@C@0oEE<0<TQ604AJF018GEh0
=T]<03Q>B`0aAC`0<4@h02e1=@0]?c<09cT]028d:00Z>Rl0?Ti302hn<`0^>c40;c`b02hk<@0^?S40
<T<g02Xl<00cA3`0<dDm02m3>P0cAch0:Chd02Dk;P0_ACP0=Ddk02Ho:P0[A300;THf02a4=00Z@SD0
<DQ003A>A@80=e5800X0=U5803IBAP0fDT@0=U9603I<AP0fBdH0>Di903E:@`0`ACh0<DHo0P0eBT40
2P0cB3l0>U1403iDB00kDDD0?U=<03]@B@0lDDX0?E9=03Y?BP0gC4L203]?C@0<03A8AP0gBdX0?E5@
03U=B`0cBT<0<4Dn03I;A@0dBD@0=4M303Q;A`0nDDd0?dm>0P0jBTT09@0iAdL0>4M403=2?@0c@Sd0
;chj0310?@0hBdT0>Ti<0355A00fBd`0<dQ:0318BP0]ADL0KX>408FGU`0fATH0;3Xj02Da<@0b>S`0
:C0a02@Z:P0O:2L07RPV01/V8P0N:RH0938/02hm=P0a@3T09cD^02Tf;`0a?3H092dX024Z9@0S:BD0
9R/W01lT800Q9R800P0P9R801`0N9200728N01/Q7@0J81`07R@P01dS7`0H7QX00P0C6AD07@0F71/0
8bDd01lP=@0R8cL07Qla01@F9@0I6bL051LP01@G7P0K7R<07R8U01XN7`0K7b005ALF01HH5`0I6aX0
7R0O01lQ800L7Qd061XI01HH5`1IFeX092HU01dO7P0f>ST0]KVj0;Zo`P0K82<05QXM00804aLJ00<0
5QLK01@E6@0C51P00P0E51T03`0C4aD05QHF01@D500E5AD03Ph>014A400I6AL03Ph<00l?300B4`h0
5AHA01@E400A4Pd0410@00`<3P02010@4P0300h>400C4aD03Ph@00803Ph@00H0ATI800L72@0C4aD0
4Q8B014A4@0=3@d2010@400300/;2`0I6AT04a<C00803@d=00<05aLG00l?3`0?3a401@0?3a401`0;
2`d03@d?00d=3`0<30h03@d?00h>400=3@l01@0<30h0300=3@l02PX<00h>400?3a4010@600l>4008
1PL00P0101LE5P0=2``03P`=00/92P<03P`=00@03@/<00`:2`0;2@X02`T:0P0<2P/200/92P<03`d>
00@020H700T7200610D030T:0P0A3@h01P0?2``03@T:00h:2`0:1PL030P901<?40805A4B00T00`00
00l:2P0=1`L03`T9010:2P0=1`L03`T9018<300?2@T00P0<1PH200d71`D03PP800<03@L700`61P0<
1PH00`0;1@D0800<1PH04P`>00d72@0B30h06Q@F00@000090`D02P@601D?4@0I4aD030H800T31@0<
1PP01`0001H;3`0E2Ph03@8600/2100=0PH02`0400h41`0/8BD0304500d41P0W72008AHJ01<8300@
1@T04@H:00l4200B1`/03P<70`0?10P201052ACooooo000Kooooo`0;00P>2`0[<Rl06AhK00H<2@0;
4@h03A8?00X?300;3`d03A0>00hB3`0A5A800P0C5Q@01`0930X06QdK00L81P0=40h04A@B00hA3`0F
6AL00P0>4@l0400?4Q002Pd;00hA3`0>4Pl03A0>010C4P0F6AP03a8A01`O7`2;SXh0=CPh014D500?
4Q@04aHG00d?3`0?414200d>3`0800lA4@0<3Ph071hN00lA4@0A4Q<03@l?00d>3`0;3@d200d?3P0;
014C4P0;3@`05ALF00H71P0D5QD02P`;03/m?00X:RT02P`;00d?3@0?4@h00P0=3``04@0<3P/02`d:
00h@3@0;3@X04aDB00/=2P0?4@h051HC00lA3@0E5a804Q@?00`>2@0:30L02``700h?2P0<3PT03@l:
00<03Pl:01D04A@?00lC3P0930X03a4>00/<200>40`03a4=00h?2`0?40/05AHA01LH4`0B4`d0824L
02T[9`0>40`02`d900h@300?4@d0418>01dO6`0Q8al00P0>40`09`0?4@d03Pl:00h?2P0=3PT030h9
00d>2@0>40/01`P501PI500;30P030h900P91P0B50l03a0;014B3@0;30L04A8=00h?2P0A4Pd04a@?
010A300?40/03Pl:00/<1`0<3@T0:R/Y01HG5@0<3@/051DD00d>2`0N7a`0KFi[01DF4P0<3@P020T5
010A300?40/03`l:00l?2@0200`=200d00`?2@0<40T02Ph800hB3@062@D04Q@@00d?2`0?4Ph02Pd9
00/?2P0C5a804A@@00X=200?4@`03A4;00hB300<40T02@d7014E3P0830L03Q0;010C3`16BTD0ATM3
00lB3@0B5A40?3lk014C3`052@@02`h900P:1P0F61@03Pl:00l@2`0<3PT02P/6010A300=3PT04A8=
01@F4@0?40/03Q0;00P9100@4Pd03a4?00`>300B518030h<01/M6`0o@Cl0@49000X<2P80418@00h0
61XH05mQG`0B5Q<0:Rd[05ILF@0B5Q<020/900P>2`0?4a403A0>00/?3@0@5A806ahL01XM6`803a4?
01P0418@00h@3P0>40h0418@00d?3@0E5aD04A<A01<E4`0G6AL03Q0?014B4@0>3`l03a0?010A4@0A
4Q804Q<C00`=3@0A4Q40414A014B4@0;30`03a0?018C4P0A4Q02018C4P0:00h?3P0H6AP04Q<B00l@
3`0?40h03@h=01<D4P0=3`l03Pl@010B4@804A<A01/04A<@014C3`0@4Ph03Q0;00d?2`0>4@/0418<
00lA3P0C5A<04Q@B01<E4`0A4a403@l=018D4P0>40h04A<A00lA3`0@4Q004aDC01DG5`0<3Ph04A<@
01<E4P0@4Ph04A<=00lB300@4`d00P0B51401P0C5A<04aDE00d>3P0@4Q004Q@B014C4@804A<@00H0
4aDA018D400@4Ph03a4=014C3`0C5A42018D4P0_01<E4P0D5Q<05ALC01<F400D5Q805ALD01@F500C
5AD04aDF00lB500@5A@041HD014F5@0@5A@04QLF01TN700@51<04A@C01DH5`0=40l05APG014D4`0?
4a<05a/K014E5@0D61P04aLG014E5@0@51@05ATI01LK6`0B5QH051PH01PL700G6aX07B4P01lS8P0F
6QT0<cLf03e1@00E6AP05a/J014E500Q9B@051PG01XN7@0A5aD00P0H7Q`04P0G7A/05Q`K01@J6@0H
7Qd051XI01HL6`0L8R<07R<U01`R8@0K9Ah06bDM01PS6`0M:28082dW01d[9P0N;BT0<D4m03i?C@80
9SLf01h0;T9102]2@@0^AD@0>Dm?03eCE013FUX0E6U[06UmO`1iS8l0S9bP09bZ[P2P[[@0XJbd09fW
/02CWjH0QY>J07R9SP1ZOh<0FW9c04YTI010G5X0>eQF03IDD@0aCd/0<D];0398BP0_ADT0;D=602]2
@`0[@D<202]2@`0802m6AP0S>SX0:D1002To@00[@D@08SXm02e4A`0S>C`202]2A01?02a1@`0fBdd0
:d1202m4AP0cAdL09cdm03I<B00V?SP0:40k02e5@00V?CX0<4M402@l>@0iDDh0E6]Z02m6A@0]A4<0
<4I702m5@`0`AD@0<dQ603M<BP0`AD<0<DI303=8AP0`AD40;D8n03Y?B`0cBDD0<DM30399@P0`B480
;dM202m7A00dBdX0>E1@03M>D00hCU40EF]/06^1PP0oEU@0>4i90398?00dB3`0<DDl02i0>`0Z>cT0
:CXj03A5AP1QLG00AUEA03I6?P0a@CH0:c`_02dm<00gASX0<d@h03=4>@0b@cX0<dHl0396?@1>HeX0
:d0g0316?00dBSl0<4Ll03A:@P0eBd40<dTn0399?@0gCD<0>55803U@C00jDDh0>E1>03Q@B00fD4@0
=e1503Y?B00203U>B080>4e602P0>e1903E:@P0fBd<0=da403aAB00oE4`0?E9:03eBB`0lDD/0?U==
03iCCP0kD4/0?55<041DD@0mDDh0=da803]?C015FEP0?U=?02i2>@0W>c40=DQ103E7@00bA3d0=dU3
03Y<A`0kC4L0?4e903I6@P0c@T00<D0k02hl=00a?cT0;chh02lo>`0hBD@0>Te:03A9A@0iCD`0=D]9
0P0aB4L03@1aQ8<0TZ6Q02ln?P0Q;B`09S0^02Pc<00Z<c009RdZ024Z9@0S;2H08RdV02D`:00Y=Bd0
0P0U<BT08P0P;2D0:38[02Pb;@0R:bH07bPS024X9@0]=34082PT02@Z9`0Q9b<082HQ01hS7P0O9B00
7R<N02L]:00P9R406b4L01PN6@0J7aX06R0K01`Q7@0M82L061/T01/N9`0M82P05APO01@G7P0E61d0
4QDH01DI6@0L8Al07B8N01dQ7@0I7A/201XM700>01TL6`0L7ah08bDS01PJ600A4a407b4M01<D4`0P
8Qh03@h;02LZ:@0e>3P05APH01LJ6P0D5AH201DF5`0601TI6P0C51D04Q8C01XJ6`0>3Pl0410?0P0A
4A00:00@3`h06aXI01<C4@0E5180410=01@D4@0E5A805aLC00l?300C4Q804A0B014@4@0E51D051<D
018A4`0D4a@04A0B01XI6`1<Bdd040l@01<B4P0@40l05QHE00X:2@0A4A003Ph>00l?3`0A4A404A4B
00T92P0>3Pl04A4B00d=3`0@3a403Pd?01<B4`0?3Q002`X;018A4`0<2`d200h=3P803@`>01403Pd?
00h=3P0;2P`03@`=010?4@0?3Pl030/<00h=3`0L6a`03@`=00`;3@0?3Pl02`X;00T82@0P7b00W9^K
01hM7P0200l>3P0600`;300=30`03@`<00/:2`0:2@X030X;100>2``03`0=2P/030T:00/82@0?30d0
3P/<00l<3@0<2@X03@X:00l;2@0?2`/040`<00l;2`0=2@T03`/;00`82@0200l;300@00T61P0E4A80
3PX:010;2`0?2PT03@P800/61@0>2@P06QDE01HA4@0>2@T02`H600`71P0>2@T03PP800l92@803PP8
02<030H600l92@0>20P03`T900d71`0<1PH03PP800l92@080P<04P`=00d7200;1@H02P@500h82@0<
1PL0618C01/E5P0B30d02PD500d7200A1PX04`P<00h41`0B1`/04@H:00l4200>0`L04`T<00`21@0F
2`l050T=030V:00P5QH04`T900d30`02010620803@<700D03@D900/31`0>1P`04@T?00`42P0Doooo
o`006oooool0200010404a`I00/D4@093`d0728P01lU8`0<40l03A0?0P0?4A02010B4@0U00T=300F
6QT0D5AC02@X9`0G6aX010P70001001:CTd0Gf=R01@H5`052@P04QHE010B4@0B51<02`d<00P:2@0?
4A000`D4010B4@0I6aX02P`;014C4P0;3@`00`D4018C5P061`/051DI010A5@0=3Q804Q<G030a=@02
0`L01`P<01TJ7P0S92P071dO00h@3`0201@F5@804A<B0P0B51<04P0<3Pd0418A01HH5`082PT0418@
014C400:30T01`T600d?300@4Pl04A<@00L91P0E5a@04A<@01TK600>40d04Q<?00h?2P80414<00@0
3Pl:00l@2`0?40/03Pl:0`0?40/0200>3`X03@h900d>2@0@4@`04Q<>00d>2@0<3@P03a0;0P0<3@P0
3`0D5A005aPC010A300=3PX03a4>00h@3@0;3@X02P`900h@3@0=3``07R0M01XL6@0;3@X030h;014C
400200l@2`0500h?2P0=3PT03Pl:010A300B4`h00P0?40/0100L7AP04A8=014B3@0;30L200l@2`06
00L80`092PD061TD01<D3`0B4`h0414<0P0>3`X0300>3`/0:b/[01LG6@0;2`d0410@00l?3`0E5AD0
8B4O00X:1`0>3`X03@h9010A30803a0:02l03a0800h?1`0>3`T03@l900`?200H6QD03A4<01DJ5P0V
:bL01P`801<I5@0H7QX051TE00D:1P042@D03a8>00lA300C5Pl02P`6014B30082@402P/401/L5P0A
4`h03a@@055FDP1?E5004aPD020U8@1JGe/05a`H00@91@062`L0314=01@F4`0>3`X03@h900h?2P0=
3PT04A8=00d>2@0O81/06Q/F01@E400B4`h020T400`=200200/=2P0A010B3`0<3P/02`d:01@F4`0?
4@h0418?0043000C5A807b4N06MYIP0B5A@02@l=03e3@@062PP04QPF00X@3P0<4Q000P0;4@l00`0<
4Q003A<A010C4@02010B3`0F00lA3P0@4Pl0418?01DG500J71T05aTF014C400B51404A<@01HG5@0F
5QH04A4A010@400<30`02`/;00X:2P0B4Q805QHF00d=3@0P8200410@01DE5@803`l?00`02`/;01<C
4`0L71`04Q8B014A4@0C4a<03`l?00`<300B4Q803@h@00d>4P0>3a42014C4P0<010B3`0B50l04A<>
00lB2`0=40T03Q4:00lB2P0D5Q<04A<B01<E500E5aH0418A0P0A4a803P0@4Q403a4@010B4@0A4a80
4aDD00/<3P0E5QP051HD00<50P0?4P/02Pd800lB2@0@4`X04Q@?0P0B51<03`0A4Q@0418=014D3P0@
4Pd03a4<014C3`0E5a@0418?00h@3P0>40l04A<B01@F5@0C5A@04A8D018D500201<E4P0P018E3`0A
50d04aH?01DG4`0@4A<03a0D018C6@0?3aL041@E00lC4P0C5aH04QHE01<G5P0K7ah05QXI01<G5P0A
5A@05ATH014E500=4A007R8Q00lC4P062PT041@C00030P0J7Qd061`K018F5@0F6QT07B4P04Y>C@0@
51<201XN7@1E01PL6`0G6aX07R8Q02<W9P0F6QT07B4P01LK6P0L81l06QhM01PL6`0C6AL05adK01PN
700G7A/05adM01PN7P0I7al061dP01TN8@0L8B@0724U01/P8`0I8Q`06R@L01`V7P0M:2807BXS01l]
9`0O<2X08C8/02@g<P0Y?3P0:Chi02]1?@0Z@d00;4E203M@CP10F5P0BV9R05eaM01hRXh0SibR0:Ra
^@2m`L`0aLOC0<_6eP37`=80^[K50:>T/@2=UJ00O8VA06^0Q01ILg@0AV=Q03aJE`0fEU40=EE@03IC
D00cBd/0<DU90318B00_AdL0;DE502a4A00^ATH0;dM702]3@`0Y@D40:d=301lh?00H<CD0;DI:03E=
C`0/A4H0;TI803A9BP0]@T<0:Cdn02/o?P0]@D00=TY90357A@0W@3d0;DI302U2?`0202Y3@00903E>
B`0]AT<0?5EB01lh=@0cC4T0<4Q502m3@P0aAD@0<dM50080<4A20440<dQ303A9A00bAd80<DHo03A9
@P0fBd@0=DY303E<A00cC4L0<T]803=;B`0eCE00=dmC049JGP0fCU40;DE5051YIP0bBdH0>4m503=9
?00cAcX0<DA00353A@0^?dP0;3a903E5DP1TMGd0BeeO03Y=B@0`A3L0;3h^02dm<00e@cL0=DDj0351
=P0a@CL0=4Dk04YNE@23Uhl0>4e603I=A`13FUD09cdk03U=CP0hC4X0=da503Q>@@0nDdX0@UM@04YN
GP0fBDd0>Da@03M;B00fBd80?eE903aABP0hCDH0=da503Y?B00iCTL0=da503=8@@0fBd@0>4e603]@
B@0203eBB`0303eBC@0lDD`0?U=>0080>Tm:03<0?eA?03]@B`0bAd80>4e803iCCP12Ee80=4U203]=
@P0oD4H0@eA:03A5>`0b@c/0>da403M8@00hBD<0?Di802m0>P0Y>S@0:CLa02Tf;@0[>2l0:SPa0391
>P0gB480<T@n02i1>`0aA400;T<n02Pn>`0Y?C/0:SXi06A`L019EE<08Rh[02Xe<@0N:B<082XS020Z
8P0N:1l09blW02Xa:@0Z<RL0:C8X02H`9`0`>S80<C/c02<]9@0Q:RD05b0K024Z9@0U;R/00P0N9b@0
6`0H8Ah0724M020U7`0L8A/08BHP028W8@0b=c40724K01PM5`0I7QP0724K01/P6P0M8Q`061dG01@I
5@0G6aT06QhM01PL7@0K7b008bLX01`P7`0G6aT0724K01dR6`0D6A4061hJ01TO7@0201/O7P0;01hR
8@0V:2D05aTF00h@300B4`h04a@?014B300I6Q@04Q8@01HF500H61H00P0G5aD02@0J6QP092@R018B
400?3`d0410>01/K6@0B4Q005A@B01@C4@0201<B400V01@C4@0E51806QTG00l>300;2PP00`8000l>
300E51803`d>01XH6@0c<C806QPI014?400@3Pl0518C01/I6P010000GUaM04=1@P0;2PP02``803Ph
=P0o?cd05aLE010@400;2`/02PX:01@D5P0=3@l04A4C00/:3`061PP0518D00L51P0F51D05aDF00P6
1`0D4Q<600h<3@0400l=3P0=2``03@/<00l=3P8040h?00d04@l@02d[;00J61T04Q0A010>3`0:2@T0
20P800H61P18B4P02@T900`<300>3Ph030`<00@02`/;00<03P`<00l;300=2@X00P0<20T01@0=2@X0
3PX;00l;300?2``03PX;00803@T:00@03`/:00l;200>2PL03@T70P0=2@P00`0=2@T03@T:00h:2`03
00l;300C00`8200I5A@04@d<00d9200>2PT04Ph=010<2`0?2`X02`L600T5100:1PD03@T801D?3`04
00003`T901dG5`070@405@l?00`61P0400/51@0=00`61P0=1`L03PP800/51@090`<03@L700h8200?
2@T03PP800D000070@401P00010:2P0601052@0600d21P0>0`L050T=01H;3`0@1@T03P@50P0=0`80
2P0;0@0030@200l71P0@1`X05Q0B00X52P0E41H03PT?00X62`0910XDooooo`006oooool00`0B6aP0
214>00PA3P0200`B400300hD4P0<40l03Q4@00803a4@0P0@4Q402@0B5QD02Ph=02<W9P000P4020`;
014E500I7A`07R8Q01/O7P0200X>3@0900T=300?4A004aDD010B4@0?4A006A/J00h@3`0620L061XI
0080418A01`04Q@C01dO7P0?4180414C018C5@0:2`d02@X<00/<3P14ADL04A8D00d>400A4Q@04a@F
00T:300H6QT08R@S01DG5P072@P01PP700D71P0C5A@03a4@01HH5`0O8B0030h=00h@3P0@4Pl03Q0=
0P0@4Pl02@0>40d0418?00d?300A4a004Q@A014C40041P<03a4=00h?2P02014B3@<03a0;00@03Pl:
00l@2`0?40/03a0;0P0>3`X02@0@4@`04A8=014B3@0B4`h03Pl:00`=200=3PT02``700d>2@0200l@
2`0300d?2`0>40d03a4>008030h;00L03@l<00`>2`0:30T03a4>028T8@051`@02`d:00<03Pl:0180
3a0;010A300C50l0414<00/<1`0H6A@07AhI018C3P0>3`X02P/600d>2@0>3`X02@X500X;1P0D5A00
4a@?018C3P0A4Pd200l@2`0>00l@300?3`l04Q8D00/;2`0<30`051@C00X:200820H02@X6018C3P0?
40/05QLB01DF400?40X200l@200T00h?2@0>40T030l800D70P0F6QD020d90;Fj]P0M8al08BLS05UO
F`0T:BD03A8>01@I5@0A51001`T401HI4P0:30H04Q<=01HG3`0=3PH04Q<=00X<1`0=3``08B<P020R
7`0C5A8071hK010B3`0?4@h030h;018D4@0?4@h010H300h?2P0=3PT03Pl:0P0@4@`06P0=3PT05AHA
018C3P0>3`X04Q<>00/<1`0@4@`03@l<00/=2P0A4a003Q0=00L91P0;3@X03a4>01dO700<3P/071hK
00d?300;3@X03A4@01XN7@0T:2L00`D4014E500>4Q403A4@0P0<40l0100=4A003Q8A010C4@0@4Pl3
00lA3P0<010B3`0A4a003a4>00d?300:30T01@L400X<2@0D5A<0410@00h>3P0B4Q80410@0P0?3`l0
1`0I6AT02PX:00l?3`16ATH08R8R01<C4`0;2`/00P0=3@d04@0<30`05QHF01<C4`0@41004a<C014A
4@0>3Ph0410@00l@4P0>3a4030d?00h@3`0?4A003Q0=014C3P0@4Pd03a4<00803Q4:00P03a8<01<E
4P0A4a8051HE01DG5P0B51<04aDD014C4P<0418A00/04A<B01<E500;30h01@H8028T8P0O8Ah030l8
01LJ4P0C5Pd04QD<014C3P02010B4@0?014C4`0B50l04Q@>00h@2`0=3`X04A<?01HH5@0>40d03Q0>
010B4@0C5A@05ALF018D4`0A4Q@04Q@D00804aDB00X04QD?014D3@0?4@`04aDA010A4`0@4AD04a@J
00l@5@0C5aP04QHE0P0E6AP08@0C5aH061`K010D4`0A5A@05a/J02L[:P0G6aX0:bl^010D4`0B5QD0
4aLF01XN7@0Z;Rd0IVYY01<G5P072`X06alN02T];01iOG`09RXY01LK6P0B5QD04aLF01LK6P0E6AP0
4ADD018F5@0H71/06alN014E500N8R4041@C01DK6@0201PN700^01LM6`0I7al06b4Q01LM7@0H7B00
5a`O01HK7P0F6al061dP01PR6`0J91`072HN01dX8P0N:RH08BlZ020a:`0Q<Bh0:3/g02i1?@0[@3/0
:T0l02Y3@00^Ad@0>U=A04EMG@1CJ6T0IgYm08>BU`2NZJl0_<;;0=OGh`3Qgn`0i]o`0>;Ik03DcMd0
]kO509^S[P26Ti/0MHR=06=kO@1<JFL0?eeK03QFE00gEU40>5=A03A<C0<0<TY:00@0<4Q802]3@`0X
@400;4A40P0[@d<03P0]ADD0?EIJ02]4B00S?4009cm102<k?@0[@dD0@eQI03]@D@0`A4D093Pg01lc
<P0X?3/0;dE20P0^A440300V?3T0;dE202e3@00eBdP093Xg02i4@@0Z@3d0@5IC02]1?P0cAdH0=4Q7
03=7A@80<4A203`0<dQ30397@P0aAT40<TM003A9@P0cB440;d@m0399@`0eC4L0>Dm=03U>C`0iCU00
=da?03]@D`0kD540<TQ6051WH@0hCdL0<TTo02m5>00`A3X0<4<o0312A00`@DX0<41=03U9EP1GJ700
BE]M03e@C00bAS/0<D<e02/k<00c@cP0=THk03A4>P0b@cT0=4Dk02i2>@12Edl0<dQ103U@BP0lDdd0
<dU603Y>C`0kD4/0>4e403M=@010ED`0B5eF055UI@0`@dL0>4a=03U=BP0dBD00?eE903eBB`0jCdP0
>Di703Y?B00iCTL203M<A@0303U>A`0jCdP0?55:0080?55:00T0?E9=03Y?BP0kD4/0>Di903aAC012
Ee80>e1;03=8@`0lDD`00P14FE@04`0bAd00=DHk03m@AP15ET`0>4To03A5?@0gB400<T<k03M8@P0n
CdT0<D8l02Tj=00Z>S<0:cXc02Th<@0W=S40;chi0311>`0^?cT00P0/?cT0100Z?CL09c`g02Tl>00a
@Sl206ijN00;02hi=P0b?CT08bhX020Z8`0N:2008B/S02Pa:@0W;RH09RdU02<[8`0U;bH00P0W<BT0
1P0M9al07RLR02/d;`0L9B008R/X01hW90809Bh[00H07b@P02L/:00M8Qh06QlK01/P700Q9R8201PM
6@0C01`Q7@0J7a/05Q/G01XO6`0K81`05a/J01LK6`0M8B807B4T01`P8`0R9RT07B4R01PM6P0I7QP0
6QlH01LL5@0I7a/061hL01TM700201/O7P0:01dO700P8Ql06AXF00T:1@0M7QT05AH@02//9P0P81h0
51@B01DE4`805aLE00T08R8P04=3@@0G5aD05ADC01HF500D51805ADC01<B400D4a400P0E51809P0D
4a404a8@00l>300D4a4081lM01/J600G5Q@02`X801XH6@0Q7b00BDM801lM7P0D4Q<05Q@E010>3`0?
3@h07A/L01XH6@0=2``04a8@01TI5P1`L6h0LW9`00/;2@0O7al06QXJ01PH600B4Q@02@T;00l?4@05
10T04a<E014?4@0G5AH02PP900d;300:20T01P@51P0>30d200l=3P0700d;300;2@X03`d>01<A4P08
1PL07Q`M01@B4`0201DC5007010?400?3`l04a<C00L71`0E5AD04Q8B014A4@0300/;2`8030`<00P0
3P`<00l;300>2P/03@T:00`82@0=2@X03PX;00l;30<03PX;00L03@T:00l;2P0?2`P03PX700d91`0=
2@P03PX900803@T800d03PX900l;2`0?2``03PX;00`8200E4A004`l>00`81`0>2PT03`/:00d9200<
20L02`L600802PH501T02`L600/51@0>20P0618B00D0000400002`D500l92@090`<02`D500d71`08
0P8030H600h8200?2@T02P@400`61P0C3@d040X:00P20P0@2PX05Q0@01dG5`0B30`030H600H040D9
00H050T=00X10`0E2Ph040D900h31`0C20`200l51P0:00d3100;0P<03PD70189300600803`X=00D0
10030080:RDY018=4ACooooo000Kooooo`0800D>2`094Pl041TF00lE4`0;4@l04QPF00dA400>4A04
00lA400900dA40072`X06alN00/?3P0>4Q403a<B00X>3@0=40l04ADD00803Q8A01l041@C014C4P0D
5QD05ALF01@F5@0N81l05aTH01<E500?4A003@l>00lA40082PT05ALF010A4`0:2`d05QLI01LH6P0>
3a404Q<E014B500D5AL05aPJ00/<3P0A4Q@04a@F01dO7P0T9RD051HE00lA400F61L04aDD00803Q0?
01<04Q@C01LI600:30/04A<A00d?300;3@X030h;00X<2@0;3@X03a4>00h@3@0;3@X051HC00d?3009
2`P04A<?014B3@0D5A004Q<>00803Pl:1P0?40/01`0>3`X04Q<>018C3P0=3PT03a0;014B3@0?40/0
0P0@4@`03@0?40/03@h900l@2`0?40`03Q0=010B3`0>40d03@l<00lA3P082PL06Q`I01/M6P0b=340
0P0>40d600l@2`08014B3@0B4`h09bPS01HG4P0720<04A8=00l@2`0A4Pd201@E4003014B3@0;30L0
4A8=00804A8=0P0@4@`03@0?40`030`<014A4P0@41003Ph>00l?3P092@L0414=014B3P0<3@P020T3
01LH4P0@4@/00P0@4@T05`0?40P03a0:00h@2P0=40T02`d:00T<200H7AT06b0L01DK5`1OIF40gN?O
04M=B@0=4Ph05AXF00`?2`0Q8ah01`X301PJ50092P@051D=00d>1`0@4@/02P`700803a4>00H03Q0=
00d?300<3P/04aDB00h@3@0;3@X200d?300=00`>2`0A4Pd0414<00`=200?40/02``7018C3P0=3PT0
30d800X;1P0A4Pd030d801<D3`0200d?300B014C400;3@X03@l<01HH5@0c=C<0418?014C400>3`d0
2`d:00h@3@0?4a80:Bd/02DY:00@51<02Ph=00hB4@0<40l03A4@0`0>4Q407P0?4Q00418?00lA3P0>
40d03a4>010B3`0A4a003@l<00lA3P0A4a0030h;01LI5P0N7ah0410@00l?3`0D51@04A4A00l?3`0@
41004A4A00h>3P0@4100<c<c01`L700B4Q802`/;01HF5P0N7Qh030`<00h>3P<04A4A00T03`l?00h>
3P0B4Q8051DF014C4`0>41003Q0?00lA400?4@h00P0?4@d01P0?4@`03a8<00lB300?4P`03@l<00h@
3`80418A00<04A<B010B4@0>40l00P0@4Q4200h@3`0:010B4@0C51H01`P:02/]:`0a<c005aTD01lR
6`0F6A4051L@014C3P803a4@00X0418B014C3P0B5@l04A<>010B3@0A4`l04aDB01/M6P0F61H04Q@C
0P0C5A@0<P0A4a804A<C018D4`0C5A804aD@018E3`0A50h04A<?01HH5P0D5QD04a@H01@E6P0?41D0
4QHG010D4`0E6AP05QXI01<G5P0F6QT05ATH01<G5P0G6aX08BDT04=7AP0O8b8051PG01DI600C5aH0
3Q8A01PL6`0f>ST051PG00lC4P0J7Qd0310?01hR8@0B5QD05QXI01@H5`0G6aX06QhM01DI600A5A@0
61`K01DI600A5A@07b<R01HJ6@0I7A`05Q`J0`0G7A/00`0I7al0728R01LM7@0201/P8`0Y01PM800K
82@07R<V01TR7@0I8a`06bDN01hY8`0Q;BT08BhZ020a;00T=340:3/h02/n>`0Y?SX0:d8o02e6@`0a
BTL0?5AC04MOG`1HKFh0LH:5096MX`2^][h0dmCO0>o[n@3jloh0oOCo0?_`o`3]iOH0d<kL0;2e`@2G
XJX0Nh^B06AiO01BJf`0AV5Q03YHEP0fDU00=Dm>03A<C@0cBd`00P0dC4d05P0bBT/0;TI702]3A00/
A4D0;dM8039:B`0fCU00=DiB03=<D00/ADT0;dM902U1@`0iDE<0=da=0315AP0]@D80;D5002/o?P0/
@3l0<TQ502To?00^A44202Pn>`0=0316@`0bB4D0:d4n03E;B00X?S/0<TQ50316@`0hC4/0=TY90396
A00aAD<0<TI403A9A00202i3?P@0;T<l03@0<dY403E<A`0hCT/0>Dm<03Q>C@0gC4/0=4Y903U?B`0_
ASh0A5]A03Q?@`0/A3L0;40d02a0=P0[?SX0;3i00393B`0iBUD0>daG04IGG`1;GEl0@eIB03I:?`0a
ASP0;3hb03=4>@0hB3h0=dPn03E7?@0dB3h0=d]202e2>P0fBd@0>4m803aCC00aAd<0>4a<03aAC00i
CTD0=4Xm03Q=A00oE4d0?51?03=6BP0hC4d0?51=03U?A00hCT80>e1803Y?B00kD4T0?55:0P0mDT/4
03aABP0O03]@B@0jCdP0>e1;03eBC@10EE00?U=>03eBC@11EU40>Di903M<A`0nDdh0@EIA04MLE`0k
D4T0=4Dj02m0=P0kC480?Tm503Y;@`0dACd0;d0h03=4?P0hBD<0<D8l02`m=`0Z>cD0:S`g02`k=`0_
?c/0=TI203A5?`020351>`0H02`l=P0W>3409SH_02Lg<@0X=c<08Rh[03<o?00^>SH0<C`h01XU7`0U
;bT08b`V02D_9`0Y<BX09B`U02H]9@0/=2`0=3he02Pb:P0Q:b<08R`T03Dn>@1lQH00=Chi0P0Q:RL0
1`0K924072DR01hS7`0Z;b/07b@P01`Q7@0O92000P0M8Qh03`0I7QX06b0L01hS7`0J7a/05a`I01PL
700G6ad06alR02@X;00V:Bd07b8W01`O9@0K7b<0720Q01`P7P0201/P6`0C028X9@0L8R005QXI01PL
6`0J7Qd061XG01DG500G61@07QlJ01DF4@0D5A007AhH03/k>@0M7A/05QHD01LG5@0E5A<08R8P034a
;`0201HF500501@D4P0E5A<051@B018A3`0D4a400P0F5A<05@0D4a404Q4?01LF500?3P`04a8@018A
3`0G5Q@03Pd;01HD5@0G5AH05A<D018@4@0A3a0040h?00h<3@0@3Pl061HG018@4@0?3@h03`h<00d=
2P0201<C4@0>02d]:`1=CDd04a<C04U9B@0@41804A4C00h>400=31403Ph@014?4@0?3@h03P`=01LE
5P0;2@X900h<3@0@010>3`0C4A804Q0A014?400@3Pl03@/<00T7200>30d04@l@00`;30051@D03@d=
00l?3`0>3Ph01PH600d=3@D030`<00H03P`=00l;300?2``03`/<00h:2`0=2@X600h:2`0600l;2`0?
2`T03PX800d9200>2PT03`/:0P0>2PT0300?2`X03`/;00l;2`0>2PX040`<00@1000B3Pd02`L600l;
2P0=2@P02`L600`81`803@T801X030P700/71P0A2`/01`8200`61P090`<05Q0@00d8200B30`02P@4
01<=3@0I4a<03@L700h8200<1PH03@L700h8200C3@d0618B00l92@0D3Ph03`T900H10@0B30`040X:
00/51@H040D901805``@00l5200?10P02`0401872`0>10L04PL;01462P0C20/040L;00d41`0A20/0
3PP:00T51P0<20T0920R03Hb<`0K5aLDooooo`006oooool0200C71T03QLD00@=2P093`d03Q@B00H<
2P0>4Q403a8A0`0?4A000`0>40l04aLF00P<2`0200H:2@0800P<2`0>4Q406alN00P<2`0420L0310?
00hB4@0C5aH200h@3`0@00lA400:30/03a4@00T;2P0620L07R0O01LI600<3Pd0;2h]05eOGP0H6A/0
=CHh014B500720X04Q<E00D620804Q<E00/051DG00/<3P0<3@l01@L6014C4P0C5A@03Q0?01TK6P0W
:BP09RPW00lA4002010B4@0A00lA400:30/04Q@B00lA3P0H6QL08B<P01@F4`0<3P/03a4>00`>2`0:
30T03Q0=00L91P0D5Q<02P`800h?2P0?40/00P0@4@`2018C3P0;010A300?40/03a0;00l@2`0@4@`0
30d800P9100;30L04A8=00d>2@0<3@P00P0>3`X01`0?40/03Pl:00`=200<3@P03@l;00h@3@0?4@h0
0P0>40d2010B3`0500L91P0j?3T0LgEb01<E4P0<3P/00`0@4@`04@0?40/03Pl:00`=200D5A002``7
014B3@0D5A0030d8010A30092PD06a`G02TZ9@0D5A001`P3010A300>3`X03a0;0080414<00l03a0;
00h?2P0D51@030`<00l?3`0B4Q803@d;01@D4P0A4Pd03Pl:00d>2@0;30H04a@>0083000A4PX00P0@
4@T05`0?40X03a4:00hA2P0A4`h04QDA0002000]<Rh03Q@@01LM6@0Q9b<03A<?00dB3P0B5a<03Q8=
00d?2P0A50d02`d601LH4P15ASh06AXB010A2`0@4Pd03@l<00803a4>00d03Q0=018D4@0<3P/010H3
01HH5@0G6AH02@/800d?300B4`h03Pl:00`=200J6aH02``700804a@?01T04A8=00h?2P0B4`h030d8
014B3@0<3P/05aTF01dO700?4@h02@/8018D4@0O8Ah01@L400d?30072@H05QPE01TK600A5A@00@D4
00T=300?4a801PX900/?3P0<40l03A4@00<03Q8A00<03Q4?00lA3P0>40d00P0>40d08P0?4@h0418?
010B3`0@4Pl02P`900<50P092`P051DD010@400?3`l051@D014A4@0?3`l04A4A00T92@0E5AD04A4A
010@40092@T04Q8B00P8200?3`l05aLG00`<300@410051@D018B4P0>3Ph030`<00h>3P0C4a<051HE
014C4P0?4A02010B4@0300lA3P0=3``03Q0=00<0418=01L03a8<00d?300@4Q40418A00lA400A4a80
418A00`>3@0?4A004Q@C00h@3`0;3@`03Q0?010B4@0H6QT04Q@B00@60`0F61<04aH@01@G400C5Pl0
4Q@@010B3`0200lA400c00lA300C5@l051HA018D3`0@4Ph0418?01`N6`0F61H04A<B018D4`0F61L0
61XI014C4P0B51804aDB01<E400B50l04A<>01DG500H6QP051DG01@E6@0E5QX0414E01<G600>4Q40
4QHE01DI600D61L05ATH01LK6P0@51<03Q8A04E9B03=dM00>Cdl01@H5`0M8B00?T9101`P7`0N8R40
4ADD00hB4@0H71/03a<B02@X9`0C5aH08RHU01<G5P0G6aX061`K00<05a/J00L061`K01`P7`0G6aX0
=CTh00`@3`0L81l051XH00805adK02005Q`J01PN7P0J82005adM01XO8P0K82<0724T01lT:00P9BP0
6R<O01XS7P0K91l07RTS020/:00N;2P07bl/02De<P0U>3D093Le02Lk>@0]AD80;dU6039<B@0kE580
B5eN05Y^K`1iR8`0WjR_0;g1bP3Sgn/0o_?o0?oio`80ooSo00/0ooCo0>KRl@36b=D0ZK2j08NFWP1[
OX@0EV]^04MOH@0oFEX0?UQI03eFE`0203Q@DP0503UAD`0hD580=4a>03=;C@0aBD/00P0]ADL0G00^
ATP0;dM902i7B`0X@DD0;DI:03YBE00dC4h0X[Zl04mTI@10EEH0;d=402/o?P0Y?C`09c/j02e3@00Y
?c`0A5YG03eCD00Y?c`0;D=003=9AP0[@Ch0<4I302i4@@0cBDH0<TQ503I:B@0cAdH0<DE30396A00c
AdD0<dQ302m4?`0`AD00<4Dn02e2>`0_A3d0<dQ10399@`0bBD@0<TQ503=9AP0eBdP0=Te703U@BP0`
Ach07CDX02Hn<00U?Bd09C`/02Hl;`0[?cD0;D0l02do@@0fAdd0?e1J03e>F00oD5P0BUaN045DD00j
CT@0<THj0394>00fAc`0>DY003Y;@@0hC480=TY102Xo=P0X?CD0;D8k02e4?00jDDT0=Te703=7AP0k
D4/0>e1703M=@@0iCd<0?55:03M;B@0lD540<TI703E:A`0nE4P0>Dm303U>AP0iCTL0>4e603I;A00g
C4D0>Di70`0hCDH02P0gC4D0=4U203A9@P0jCdX0?U=>04=HD`0oE4l0>Tm:03aAC011EU4203mDC`0H
03M<A`0oE4l0>Tm80393>00iBT00=dPn03U:@014EDd0@5590311>@0_@3X0;3dg02Pi<`0U=S009SPc
02`o>`0_@Sh0=4E203Q8A@0eAT00<T8l02ln>@0X=c00938[0P0T<BX0<P0W<bh0:SHb03M3?`0g@cl0
;cXf01dX8P0R;2H08R/V020Z8P0U;BH09RdV02T`:00Z<RX0<3Xa03@n=P0^>30072HN01`U800X<B`0
6B8M020Y9P0L9B808b`Y028[:00J7a/08BHR01XO6`0M8Qh07R<O01`Q7@0Q9R806AhJ01PM6@0O9200
7R<O01PL6P0L82<07R4V01lR:00R9B`092L^01dP:00P8b`07b8Y01hQ9@0K7b006QhM01TM6`0V;2X0
7R@R0P0E6AP0300H71/061XG00`>2`0I6QH0Si2;03<d;`0H6A@01PL101lO7@0C4a405aLE01/K6@80
5QHD00P03@d;01HF500G5aD03`l=01PH5P0@40h04a8@01@C4@805A@B02H051<A01<B40081`D0;B`Z
04E4@P0_;R`06APF00d<2P0?3@h0;2X[00T7200L6Q/0518C01/I6P0D4Q<03`d>01TG600:20T01@<4
01@C4@0@4@`04Q8@00/;2@0=3@/03@d=00X:2P0d=3@01PH801@D5P0@41805aHK00<31@0F51H0=S@e
00l=3P071@H02`T:00P61`H03P`=01<03@/<00`:2`0A3a006ALH01<A4P0;2@X03`d>00H41@0?3@h0
40h?00X82@0<2`/05ADE00L71`0@41001`L701HF5P0?3`l03Ph>00803@d=0P0<30`01@0>2``03`/<
010<3@0@30d03PX;00<03@T:0`0>2P/00`0?2``03`/;00h:2@0200d9200>00h:2@0?2`X03`/:00h:
2@0?2`X03`/900h:1`0=2@P02@D401PD4`0?2`X02@D400/71P0?2`X200d920@03`/:01P0208200T3
0`0F4100100001hH600>20P030H600X4100D3Ph0618B00l92@0;1@D04@/;00T30`0:10@040X:00d7
1`0>20P01P0000d71`0O6AT0>cDe02lY:@0>20P601052@0B00`11@0F2`l03@8601462P0?1PP05``@
01052`0900@040D;01893P0=10T040L:00h82P0?2PT05Q8A020L6`091@D03@T65?ooool001_ooooo
00P02Q<@00D>2`053P/03Q@B018H5P0@5Q@03Q8A00lB4@803a4@0P0>40l0:`0;40`04AHB018G4`0C
61@02a0<014F4P011P803Q<?01LL600<4@d041DA02H[9`0<3P/03@l<010B3`0<3P/04Q@A00lA3P0G
6AH02P`900P:1`0B5140418?01XL6@0Y:bX0FUaK01/M700:30/08R@S00d?3P0@4Q402`d<00h@3`0?
4A005QPG00h@3`0>40h03Q0=00d?300?4@h04aDB01DG500C5A800P0A4a003`0B514030h;00lA3P0>
40d07b4N02h`;@0I6aP02`d:00h@3@0=3``03Q0=00`>2`082PL08bDR00P91@0300d>2@0400h?2P0B
4`h04a@?010A30<03a0;00X0414<01`M600B4`h020T4014B3@0=3PT02``7010A300>3`X03@h90`0<
3@P01P0=3`/03a4>00lA3P0=3``03Q0=018D4@805ALD00@03@l<038d<@0G6AH03a4>0P0?40/2014B
3@0@010A300?40/03a0;00X;1P061`804Q<>00T:1@0=3PT02@X501LH4`0P8A`03a0;00H70P0?40/0
30d800d>2@803a0;00h03Pl:00d>2@0C4a<03@d=00`<2P0@40h03`l=018C3P0A4Pd03@h9018C3@0?
40X04a@>00P90`804A8:01d04149010A2`0?4@X03Q4:00<5000930T092TU0002000=4`l00PP400hD
400F6aL0314=00@91@0:3PT03@l:01LJ4`082P<05QLA05IGC`0M7QH010D000l@2`0<3@P02@X500/<
1`0@4@`04Q<>034b;@02010A300900l@2`0>3`X061TD010A30082@@03a0;02d^:@0A4Pd03a0;0080
30d801D02``7018C3P0>3`X051D@00lA3P0F61D07AlL018D4@0:30T04A<@00lA3P0@4Pl05ALD018D
4@0@4Pl00@<001<E4P0@4Pl05QPE010B3`072@H00P0>40d00`0?4@h04A<@010B3`0200lA3P803Q0=
00X03@l<00h@3@0>40d04Q@A01XL6@0K7AX04A<@00h@3@0@4Pl0414?0P0;2`T201<C4@0=01@D4P0I
6AL03`l=00d=2`0D51807alM00X:200@40h01`L500X:200>3P`030`:010@3P02014A3`803Ph<00<0
410>018B400@4Pl00P0?4@h2014C400I00h@3@0<3P/03@l<010B3`0A4`h0418=00lA300>40d04Q@A
014C400?4@h04Q@A00lA3P0=3``04A<@01DG500?4@h03@l<010B3`0A4a0020X700d?30092`P02`d8
01@F4@02018D3`0B018D4@0A4a00418?00lA3P0A4`h04aD?018D3`0@4Pd0418>014C400F61D04Q@B
014C4P0D5QD05aTH01PJ6@0A4a004Q@A0P0C5A806P0B51404A<@01@F5@0F5aP04Q<E018C5`0F5a/0
4a@H01PL7@0A5A@04QHE01DI600D61L05ATH01TM700A5A@02@d<02/_;P22QXD05a/J014E500Z;Rd0
K71_00lC4P0D61L03A4@0P0D61L01@0=4A004ADD01HJ6@0;3`h05QXI00805ATH00d05QXI01LK6P0H
71/04aLF01PL6`0I7A`08RHU00lC4P0I7A`05A/I01PN700J81h06AlM00806AlO00L05Q`L01DJ7@0G
71l06QlR01XO8`0J7b807BHR00806b@O01D07BPT020/:P0P;R/07bl/028b<@0S=S@09cXh02Pl>P0]
AD80;T]703A>B`0kE5<0BUmP05ibL`1oS900XjZb0<;5cP3Wh^l0ooCo0?oho`3omol00P3on?l02P3`
j_T0c]3M0;2f`P2>Vj<0L8>905aaMP1=IFT0A5aP049JGP0nEUP303UAD`0M03M?D@0cBdd0<4Q:02m7
B@0^ATP0<4Q:02m7B@0Z@T@0;4E903=<D00bBdl0=4a>01/c=@17Gf40=T]<02i3A00Z?Sl0;T910355
A00iCD`0;d=103I;AP1?I5l0?55<02]0>`0^@ch0<TM202]0>`0bAd800P0jCdX0@`0`A440<dM60355
A00`A480<dM503A8AP0bAd80;d@o0397@P0cB440;d@m02e2>`0_A3d0;d@o0315@00aAT40<TM203=8
@`0cB440=4U002i4>00Y?c80;D@d02Dl:P0Q>2H08SP[02e3>00dBD@0=DU803Q;D@0nDEP0@5=J03mB
E`14F5L0>Di903aAA`0dBSh0=TXo03M;@00hC440>De403U>A@0gC4<0>e1703M<@`0lDDP0=T]202a1
>00jCdP0=TY903U>A`0hCT80=de003Q>@P0jCdH0>4a;03Y>C`0eBDP0<dQ303Q>@P0iCd<0>4e503Y?
B00iCTL0=da503U>A`0lDDX00P0hCDH0700gC4D0=T]403A9@P0cB440>Di903aAC010EE00?55<03M<
A`0jCdX0AU]F041ED00oE4l0=da703aAC00cB4409SP]03E6?00hBCl0?4e304MHD010DDT0;d0h02m0
>P0/?CL0:S/e02Pi<`0/?ST203=7A@0702i1?P0/?c/0;Chh02hn>00_>cL0:CH_02Lc:`0202Td;00E
02@`:00]>S<09C8[02Te;P0Y=2h0<chh03@n>00X<B`08b`W02L_:@0W;RL09RdV02Xb:P0a>c80@4Y2
03]5?@0S;BD08R/V01<L5`0M9R408R/X00806R<P00P051dJ01lS8P0P92<061`K01`P7`0G6aX05QXI
01hR8@8061`K01h06alN01TM700I7Ad07b@X024V;00M8RP06QhW01lS;00P92h09RXe020T;@0I7R<0
61dP01XP800K8Al082HT01/Q7`0F6QT05ATH01HJ6@0G6AH092HS018C3`15AT400P<0014B300O81X0
4Q8@014A3`0E5A<201TI5`0901DE4`0F5Q@07AdK01`L6P0A4@l05QHD010@3P0E518051<A00804a8@
00D051<A01DD4P0B4@l07ahL028Q7`0200h=2`0O01LF50061@<06QTG00X91`0B4@l02`X8010?3@09
20H03Pd<00`;2@0H5aD0:2LU00L6100F5A4040l=01TH5P0H5aD0518C010>3`0C4A803P`?00T72P0?
3A005aDJ010>4@0T8R@0GE]L01TG600;2@X07Q`M00l=3P0800h<3@0@010>3`0C4A803P`=00X82@0A
3a001083014?400?3@h02`T:00X82@0@3Pl02PP900/92P0:20T040h?00/92P8040h?00D03P`=00`:
2`0;2@X03@X;00l;3002010<3@0300l;300=2@X03@T:00803@T:00@03PX;00l;300?2``03`/;0`0=
2@P00`0>2PT03`/800l;200200l;200900l<200>2`H03@T600/71@1bKVd08alN00d920060P4030P7
00<03PX90P0?2`X02@0@30/04P`<00/51@080`<07aTI07I`L00/9RH02`D500`61P02010:2P0>00l9
2@0<1PH04P`<00L10@0D3Ph07ALG00`61P0=1`L03PP800`61P090`<05a4A01D?3`0A2`/601052@0B
00d21P0C20`02@0201@93@0?10P0DTM=01dB6P0<0PT03`@<0188400>1@X04@P;00@0000D3`l02@D2
00<000091@<03@X55?ooool001_ooooo0P0<5A801P0B6aP04QPF00X@3P093`d03a<B010C4P80418A
0P0?4A00200>4`l08RLS00X?2`0:3`/03a@@01PM6@0:3`/02a0<0P0=4Ph0100C61@082DQ01@F4`0>
40d200lA3P0<014C400@4Pl02`d:010B3`0?4@h04Q@A00/=2P0<3P/04A<B018D4`0?4A00418A0P0=
3`h01`0@4Q404Q@C014C4P0;3@`03@l>00X<2`0?4@h00P0@4Pl00`0?4@h030h;018D4@0200d?3003
00h@3@0@4Pl02P`900803a4>00d04A<@01@F4`0=3``030h;010B3`0<3P/0418?018D4@0H6QL0;2h[
01<D400?40/03@h900<03Pl:00X03a0;010A300?40/03a0;010A300A4Pd07b0K01TJ5@0=3PT03a0;
0P0<3@P08`0B4`h03Pl:00l@2`0E5Q404A8=00`=200@4@d04A<@00lA3P0D5Q<0:R`Y01<E4P0X:RL0
2`d:01PJ5`0m?c`05QPE00lA3P0@4@`03Pl:00l@2`0B4`h04A8=010A300A4Pd05AHA00h?2P0C50l0
3@h900l@300>3`X03@h900l@2`0>3`X03a0;008030d800<03@h900h?2P0>3`X00P0>3`X01`11@Cl0
9BDT00X:200?40`03a0;00d>2@0?40/00P0>3`T0700:2`@0414:014B2`0@4@T03a08010A2@0A4P`0
418<00hA2P0<3PT04QHA00@81@0?51002a0<00dC3`0B61@03Q@@01@I5@0?51002`l:00lA300=40T0
5QPA00X;1`0I6Q8030d501<D300@4@/200l@2P80414<01D03@h9018C3P0=3PP03a0;010A300=3PT0
3Pl:00d>2@0:2`H03a0;02LX8`0D5A002``700l@2`0A4Pd0414<018C3P0=3PT0414<00h@3@092`P0
0P0@4Pl200h@3@09010B3`0>40d03Q0=00`>2`0A4a00418?014C400@4Pl03Q0=00804aDB00@03a4>
00h@3@0?4@h0418?0P0?4@h400h@3@803a4>00L03@l<00`>2`0@4Pl03Q0=010B3`092`P04a@A0080
4A4?00@04a<A014A3`0?3`d03Ph<0P0D51801@0A4@l051@B00X:200D5180410>00804Q8@00H04a<A
018B400?3`d04Q8@01<C4@0B4Q0200l?3@0>00d?2`0>40`0418>014C400@4Pl03@l<01@F4`092`P0
4Q@A00lA3@0B51003a4=014C400B5142014C400801<E4P0<3P/03a4>018D4@0E5a@04Q@A010B3`0C
5A8200lA3@0401DG500>40d02P`900lA3@80418>01@04A<@018D4@0A4a00418=01<F3`0@4`d03@l:
01PJ5@0Q8al04aDB01`N6`0E5aD05ALF00h@3`0D5QD04Q@C018D4@0B51005QPD014C40804A<A01L0
30h>01<E5P0>3a404a@G01LH6`0E5QP05a/J01DI600A5A@04QHE01DI600C5aH041@C018F5@0F6QT0
4ADD01HJ6@0C5aH04ADD024U901RIVD061`K01TM700201<G5P0N01LK6P0T:2L041@C02HZ:@0O8b80
6QhM01LK6P0C5aH05QXI01LK6P0J7Qd05QXI01DI600G6aX04ADD01TM700J7Qd05A/I01dS8@0L8R00
;C<a01TO7`0N92@061hN01PM800K82<07R<V01<H700N8bH072DR0P0M9R80:@0N:BH07b/Y020];00N
;R`08C4`024c<P0[?C`09c/j02i6@`0]BTH0<D]803eFE@1@IFH0H7Ae07n<T02PYjl0`L7;0>SQkP3o
lol0ooSo0?ofo`3omol0ooSo0?C]n`3Ee>80/kW508fJX`1^PHP0H7=j05EZL015GF80?UEL03UAE@0h
D5<0>E5D03I>D@0eCE00<d]>039:C@0aBD`0=4a?0080>U9E00/0<DU<02i7B`0fCe<0:4550318BP0c
Bdd0;TI802]0@@0/@D80<DE60355A00202i2@@0903E9A`0gC4L0>e1;02m4?`0]@Sd0<DI103I;AP0a
AT40;T<n0080;D8m00H0<4E002m3@P0/@3l0=4Q60355@`0cAdD203E:A@0h0315@00`ACh0;d@m02Tn
=`0/@CX0:d0k03eBC00hCDL0<TM103A9@@0]@SP0=Ta002Y0<`0X?bl0:T4a02i5=00bBCP0:3hb02m4
?00lDDd0?51?03iAEP10DeT0A5MM041CF011EE@0>De:03U>AP0gCD80=4Xo03I;@@0gCT<0>4i503Y@
A`0lDTP0<dPo07^@Q`19GUD0<4Hk03Y@A@0hCDD0>De<03Q=AP0fC400=4/l03A:?@0eBT00=4Q603M;
C00lD4l0=TY60357>P0fC400=DY203U>A`0kD4T303aABP0?03M<A@0iCTL0>e1903Y?B00gC4D0=DY3
03U>B@0hCDP0>Di903Y?BP0mDTd0?eA?041ED00gC4L0>Tm:0080>4e800X0=DY30352=`0hBCl0?4e3
04aMD`1=GUH0<T<k02dn=P0W>380<44k0P0dACl08P0^@3/0<TE20314@@0Y>cL093Ha02Xj=@0_?3P0
:3@`02D`:`0X<bd0:C</02Ta:`0X<b`0:cP`01dZ8P0T<2T072LQ02<^:00[=C00;3D`02Xc;P0[<Rd0
:S0[02D[9P0S:b<08B/R02Pb:P0T;RH07BLO02@]:00Q:RD07RLR01PQ7P0V;b`201`U8P1302<W9P0N
8R407B4P02@X9`0N8R40720O018F5@0U:BP051PG020T8`0D61L07b<S01PM8@0H7R@05Q`T01/P:`0W
;CL0=S]602hd?P0U:c<06AhU01LM8@0H7R4051`J02<Y9`1;DDl092PW01LK6P0F6QT06A/H01DG500H
6QH04Q<>014B3@0F5a804Q<=01XJ600F5Q@051@B01LG5@0H61H05aLE01HF500D51805ADC018B400F
5Q@061PF01<B400F5A<04a8@014@3P0D4a405QDC01<B400B4@l06APF01HE4`0C4Q0040l=01/J600@
3`d06QTG02@S8@0O7Q`04A0>01TH5P0301<B400:00X9200F5A<05QDA01dL6P0F5A<030/901LE5P0<
2P/03@/<01hL7`803`d@00P03P`A018@4`0;2@/05A<D00d;300D4Q<040h?00`:2`804@l@01P03P`=
00l=3P0@3Pl03@/<018@4@0?3@h03@/<00/92P081PL040h?01`J6`0?3@h04@l@00d;300:20T03P`=
00`:2`0>30d03@/<00h<3@0;2@X03P`=010>3`0A3a0300d;300700d:2`0>2P/04Ph?014=3P0>2P/0
2@D600l;300200d92P<040`=00D03`/;00h:2P0>2PT03@T800l;2P02018>2`0Y00T6100B3`X04Pl9
010=1`0C40X04Pl<07YfM@0[9bH0510?00`81`0=2@P0510?00d9200<2@P030P7014=300=2@P030H6
00T30`0=20P040X:038/;00@2PX02P@400d71`0?2@T03PP8014;2`0D3Ph04P`<00`61P0I4a<071HF
01<=3@0;1@D03`T900h8200<1PH05@l?00`61P0;1@D01P0@1@T04P0B1`/03P<700X10`0@1@T050T=
05=8CP0P5Ad04PL@00l4300@1Ph03`H<0189300G4A<02`H5010<2@0=2@H02`L400`91ACooooo000K
ooooo`03010I5P0=5Q<02a@A00<0318@00@03a<B010C4P0@4Q40418A0P0?4A00400:3`/05Q/G00P=
2@083@T0314=00/@300A5Q803Q<?00dB3P0?51003Q<?00dB3P0O8Ah04Q@A014C400?4@h200X<2@06
018D4@0C5A804A<@01<E4P0E5a@04Q@A0P0?4A0200h@3`803@l>00d030h=00lA400?4A003a4@01<E
500G6AH04A<@00h@3@0;3@X0418?00T;200>40d0418?00804aDB00P0418?00h@3@0>40d03a4>010B
3`0A4a00418?00lA3P804A<@0`0@4Pl02@0?4@h03Q0<014B3@0C50l05aPC01DF4@0A4Pd03Pl:00l@
2`0200h?2P0D00l@2`0@4@`0414<014B3@0B4`h03a0;00`=200>3`X0:R/V018C3P041@00?3dh034b
;@0C50l030d900h@3@0@4Pl01PP502@V8`0>40d300lA3P803Q0=00D03@l<010A300<3@P03@h9010A
300200d>2@0<00T:1@0:2`H04a@?00d>2@0?40/02@X601<D3`0?40/01@H201hO6P0;30L04Q<>0P0?
40/2010A30804A8=00X0BDU702PX9P0=3@/04Q<>00h?2P0?40/02``600l@2P0;30H02P/30`0>3`L2
00d>1P0M00h?2@0<3PL020/4018D3`0;3PX0008000dB3P0A5Q809B/W00lE4@0<4Ph08bPT01/P700=
4@`03Q0;00`?200?4@X03a0:00h?1`0?40P04149018C3@0>3`T04A8<018C3@0>3`T0414;01<D3P0A
4P`0100@4@/02P0B4`h04a@?00h?2P0>3`X03@h900P9100D5A003@h900X;1P0;30L200d>2@803Q0=
00H03a4>00`>2`0<3P/04Q@A014C400@4Pl200lA3P803Q0=00<04A<@00lA3P0C5A800P0=3``00`0F
61D03Q0=00h@3@0600h@3@803a4>0P0@4Pl01P0A4a004Q@A01DG500Y:bP04Q@A010A3`804Q8@00X0
4a<A014A3`0?3`d03Ph<010@3P0B4Q00410>00`<2P0=3@/0410>0P0C4a40900?3`d0410>00l?3@0>
3P`04A4?01<C4@0D51804a<A01DE4P0C5A004A<>00`>2@0;3@X03@l<018D4@072@H04A<@024S8009
2`P02P`901TK600=3``02`d:00d?300D5Q<05QPE014C400@4Pl04A<@018D4@0A4a00418?01<E4@0@
4Pd04A<>014C4080418?00D04A<@010B4@0?4@h0418?014C4002018D3`0J00/>1`0H6aD04Q@?00h@
2`0D5Q80418?01LI5P0?40h03a4@02T[:P0f>3L0418?01`N6@0B50l01`T400T;200N81h06adL020Q
8`0H6A/04a@F00l@4P0;30h09RLY00lC4P0D61L2014E500301<G5P0>4Q405QXI00805a/J01H05QXI
01<G5P0A5A@03a<B01<G5P0W:bX04ADD01dQ800H71/05a/J020T8`0U:BP05a/J01PL6`0I7A`0:Bd/
02@X9`0H71/05a/J014E500D61L061`K0`0F6QT201LK6P0S00dC4@0B61H0728P059HEP0P9RH051XJ
01lU9@1/LG@09BX]01LL7`0J7b<07R<V01PQ7`0K92407BHS01dW9P0L:2H08c0_02@d<`0/?3/0;3hm
03E7A`0mDE00Df]X02]8A00nF5D0GgQf065fM`1VNW/0MX>709^RZP2h^l@0h=_X0?[]oP3omOl00P3o
n?l05P3onOl0lnck0=?EhP2c^LD0S9RR06n2R@1PM7/0DVU`04MNIP13FV80?eIM03]CE`0lE5P0?EEI
045IG@10F5`0>U9F0318C00]ADT0<DU=039:CP0^ATX202i7B`0402m8C00^ATP0;4A602U1@`80:Sm0
01P0;D520355A00bATD0<TI403E:A@0bAd80;T<n02a1?00^@ch0<4E00397@P0aAT40;T<n02]0>`0Z
?cX0:d0k02e1?`0]@D00=TY80355@`0cAdD0>Tm:045FD@0dBD@202m4?@0L02Tn=`0^@c`0:d0k03mD
C@0lDDP0<DHm02i4>00/@SH0<DLj0398>`0eBch0=4Xm03iDA`0bB3`0<4Dl0315?`0oDe40?U9A045E
E`10DeL0>TeC03]?D@0nDU40>De;03M<AP11F4h0?eI<03aCB@80>4m501h0?EA:049IC`0iCTD0K85h
03iCBP0bB3`0>4i202e2>@0fBTP0>Di703Q>@P0gCSl0>e5403iDB00hCDT0>4a;03U=C00cAd<0<4Hi
03A:?@0gC4@0>Di703]@B@0jCdP0=T]403=8@@0gC4D0>4e603U>A`0jCdP203U>A`0403]@B`0eBTD0
<dQ303Y?BP80?U=>01/0>e1;03U>B@0mDTd0?55<03I;AP0eBT<0>de2041AA`0iBT00@eA:04MHD00X
>C408S<[02`m=`0`@C/072dW03U:A00nCdT0=DQ203E6@00_@3X08c@^02@c;P0X=S408bl[02D`;00Y
<c000P0W<2d0>00X<R`09C8Y02@a:00P;2D07bXT024/9P0S;BL09c0[02Tb;@0X;b/0:Bl[02L]:@0S
:bD08bdT02@^9P0U;bL08bdU020Y900L9B0041TD02H_;00K92404a`I020Y9P0F6QT05a/J01XN7@0L
81l07B4P01`P7`0M8B007b<R01`P7`0S9bH0720O01TN7P0O92P072<Y01XQ:@0K8R`082La02L]>@0Q
:3807RD]01TQ9P0H82<0620R01LP7`0>5180>3hl014E500I7A`020`;01/M6P0P8Ql061XF0P0G61<0
3P0F5a4061TC01DE4`0?3`d04A4?01<C4@0G5aD08R8P01DE4`0D51804Q8@01<C4@0E5A<05QHD0P0G
5Q@04`0E51804Q4?014@3P0D4a4040l=01@C4@0K6QP05aHD00l>300C4Q005aHD00h=2`0E51807QdK
01LF500;2PP04a8@018A3`0A40h00P0B4@l0200C4Q006APD024P7P0L6aT05A@B018@4@0@3Pl04a4B
0P0F51L04@0D4QD04Q0E01<A500S8B<04@l@00l=3P0=2``02`T:010>3`0A3a0040h?00/92P0=2``0
40h?00d;300;2@X02PP9008040h?00@03`d>00H41@0>30d03P`=0P0=2``00`0<2P/03@/<00d;3004
00d;300=00/92P0?3@h04@l@00`:2`0=2``03P`=00X7200B3Pl030P900L4100?2``040`=00/72002
00d92P0500h:2`0?2``040`=010<3@0?2``00P0@30/02@0>2PT02`L400h;1P0/:B804a0900T60@0@
3@@01040010=2@0200l;2P0Q014=300?2`X02PH5085mO01NFUT06ADD00<0000D40l03@T800d71`0>
20P05@l?00T30`0400005Q4A01LA4@0D3Ph03`T900h8200?2@T04@/;00`61P0D3Ph01`8200X4100B
30`03PP800X4100D3Ph01`4100@0000:10@040X:00L040D901403`@800d21P0>0`L040D90146300?
10`03P<;00d22P0=0`/03`H;01482`080P@02`H501<?300A3@X03@T601/H4`0Dooooo`006oooool0
2@043@X0214>00TB3`093`d02a4?00lE4`0?4a803a8A010B4@0300lA400900lD40062`D041D?00dB
300;40X03Q<=01HK5@0=4P`02@h800803A8<00D02Pl901HH4`0>40/0418=014C3P0200h@2`08010B
3@0A4`h03a4<014C3P0C5A00418=010B3`0>40d200d?300D00h@3@0?4@h04aDB018D4@0>40d01`T6
00H81@082PL04Q@@00lA300<3PT03a4<00P:1@0=3`X04A<>01@F4@0C5A003a4<00d?2P0>40`200lA
3P<0418?00<04A<@00lA3P0=3``00P0>40d01P0<3P/02``800l@2`0D5A005QLB018C3P803a0;01X0
414<00l@2`0>3`X03Pl:00l@2`0A4Pd04Q<>014B3@0>3`X03@h9010A300A4Pd04Q<>01hO6P0Q8Qd0
2P/600P9100C5A405ALD01<E4P010`003a4>00h@3@0@4Pl03a4>00h@3@803@l<00<03Q0=00d>2@0<
3@P00P0>3`X0200:2`H03@h9014B3@0=3PT04Q<>000100092PD03a0;0P0>3`X0100=3PT04A8=00`=
200A4Pd200l@2`80414<0P0A4Pd08P0L7AP051D@010A300A4Pd03Pl:00l@2P0<3@L0414:00`=1@0:
2`<03Pl600d?100@4@T03a08010A2@0A4P`0418<00d@2@0;3@P02`d900X?2`0J7a/00PH300D;1`04
2PH01@/707YoN`1cN7@02`h:00T;1P0=40T030h700/<1P0=3PH2010A2@0F01@C3P0B4@`04a8=014@
2`0>3@P04Q4<01LF4@0D4`h04a8=018A300A40/04Q4<00d>2@0?40/03@h9010A300D5A004Q<>01DF
4@0<3@P02P/600d>2@803Pl:00P03Q0=00lA3P0A4a0061XG00`>2`0C5A804Q@A010B3`@03a4>00H0
3@h901XK5P0`<B`071dH00H70P0E5Q4500l@2`0300lA3@0?4@h03a4>00<0418?00T04aDB018D4@09
2`P06Q`I055CD00[;BX030h:010A300A4Pd00P0B4`h0100A4Pd03a0;00d>2@0>3`X200l@2`0500h?
2P0?40/04Q<>01<D3`0B4`h00P0F5a80100A4Pd03@h900h?2P0B4`h201@E400?01<E400A50d030h9
00/=200=3`X04Q@A00/=2P0?4@h01`T8014C4P0I6aX03Q0>014C400?4@`03Q0;00804Q@?02/03@l:
010B3@0A4`h04Q@?010B3@0?4@`04A<>010B3@0?4P/0418>01@F4`0D5QD04A<B014B500A4a804Q@B
018D4@0C5A004aH@00lB2`0B50h04A<>010B3@0A4`l051HC01HH5@0C5A<05aTH01`N7@0S9B@0828O
018D3`0>40X06Q`G01DG50082@X04Q<E010A5@0;31005AHJ01TJ700A4Q<051HE00804QHE0P0G6aX0
0`0@51<03a<B01@H5`0201@H5`0n01<G5P0A5A@03a<B01`P7`0C5aH05ATH00lC4P0M8B004aLF01PL
6`0K7ah07b<R01DI600F6QT04aLF024U900K7ah04aLF01PL6`0C5aH051PG01/O7P0H71/05a/J01HJ
6@0G6aX061`K01dS8@0W;B/06b4O02D[:@0>51@0728R01dS8`1YKW406b0S01dR9@0U:Rh05Q/N01TR
800K92<07BHU01dW9P0L:2P06RLW01`/:`0Z>SX06bd]03E7A`23UiP0X;Nf03==BP0eCd`0EVm]05Q]
KP1QMGH0M8>709>LX`2]/KX0dloK0?3Um@3ml?l20?oio`0f0?ofo`3/j?H0cLoL0:jd`027UZ00LhF?
06AhP@1AJ740Bf=]04MOJ@0mEE/0?5=I041GG@0jDEL0;dI<03A;D@0iD5H0<dY@02m6C00^AD/0;dI<
0399C`0Z@dL0;TM;039;C`0_AdT0:d=502U1@`0aATL0;T=402e1@P0`A4<0<TI50314@`0_@Sh0>Da6
03I9@`0Z?CL0;D0j0313?@0bACl0<4<m02/n>00X>cD0:C`f02`o>P0fBTP0?51?03Q<BP0gBdT0=4Q6
03Q=B011EU40=da70P0bAd001`0/@CX0<DHo02m2?00eB480>dm603E9?P0/@3@00P0bASX04`0_@cL0
;D4f02e1=P0nDTP0=DY10356?`0bBD80@eUF041FE010EEH0?E9C03Y?DP0oE5D0?eEC03Y@C@0mE4d0
C6=K03E?AP0gDDP00P0jE4/0@@0gD4H0<dY003U@AP0hCd@0<4Hj03E;?`0gC400;40g03I:B00jCdH0
>4i103I=?@0kDD@0@EM;03]@B`0dB4L0=TY803E:@`0eBch0>4i103U>AP0jCdP0>e1903U>A`0fBd@0
=DY303aABP0jCdP0>Di703Y?B00mDT/0?U=<03mDC`0dBD@0<TM203M<A`0jCdX0>e1;03U>B@0kD4/0
>Tm:03]@B`0gC4L0<DHo03m@A@12DdT0>DY003A5>`0fAcl0<D8j02Lh<00`@C/0>T]504EFD02L[JL0
PY><03I7?`0fACh0=4<l02/j<`0Y=C40:3@`02Da;@0X<S40:S@c00809Bl^01`0:CD_02Tf;00W=2/0
8RhU01hY8@0O:R@08bdW02Tb;@0Y<Rl09bh/02P^;00V;2X08BTS02<]900U;bL09S0X028/900N9b80
82TT034j=@0B6aP092dZ02Tb;`0P:BH05a/L01hR8`0M8B805QXK0P0J7Ql02@0P92D02Ph?024U9P0P
92D0:bl`01lT9P0R9b/07bH/01hU;00301`S;@0H01/R;00L8b/06b8X01HN8@0E7Al06B8P00hD4P0G
7A/02`l>01hR8@093@`06Q`I020R7`0I6QH061TD01TJ5@0G61<06AXD01/K6@0F5Q@04Q8@014A3`0L
71X0;bl]0P0E5A<401@D4P0=01LF500>3@/04Q4?01@C4@0A40h061LE010?3@0E518061LE01@C4@0?
3P`05A@B01TH500301<B3P04010?2`0B4@d04Q4=018A3@804A0<0P0B4@d0200G4a007ATH01TE500D
40l04@d>00l;300D41404PdA0P0C3Q80200A31803`X>02@R900;2@X040h?00h<3@0=2``06ALH0P0>
30d02P0;2@X030X;010>3`0?3@h04@l@018@4@0L6Q/03`d>01`J6`0:20T200h<3@803@/<00<030X;
00h;300?2``0100?2``00`0>2P/040`=018>3`0200l;300:010<3@0?2``04@d>00<0000K5aP030P9
01DA4P0<20T03@T:00l;30803@T:01X040`=01<?400>2P/02`L600`81`0A3@`05A4>01@A300l>C80
8AhG01/H3`0R81@00`40010<1P0@30/04`l>01DA400<20L03PX902dY:00[9bH03@T800/71P0Q7A`0
1P8101XD50803@L701D0100000P20P1FD5008adM01XD500>20P030H600h8200=1`L0100001@>3P0E
3`l03`T900d71`0?2@T01000014;2`0G4A4050h>01TC4`0=1`L01P0@1@T201462P0501052@0?10P0
3`@800h31`0=0PP00P0>0`T02@0=10T03PD:00h5200G4A<03@P700H20@091@@02PH503Da;P0Doooo
o`006oooool0200@6AH02Q8?00L?300;4@l03A<A00`B400>4Q403a8A0`0?4A00200>40d04AHB00X?
2@0F6aD02@h800dB300;40X03A8<0P0@5@l0600>4`d03A8<00hC3@0<3PT02P`700h@2`0?4@`03@l:
00h@2`0?4@`0418=00d?2P0@4Pd04Q@?00lA300@4Pl03@l<00`>2`0=3``03a4>014C400I6aP03Q0=
00d?30804Q@A00P0418?010B3@0>40/030h9010B3@0:30L03a4<00d?2P80418=0P0>40/0100?4@d0
3a4>00lA3P0>40d200d?300@00`>2`0;3@X02`d:00d?300@4Pl03a4>00d?2`0@4@`04a@?014B3@0?
40/0414<018C3P0A4Pd0414<00l@2`803Pl:01P03a0;010A300@4@`0414<00l@2`0>3`X04A8=00X;
1P0:2`P05AHA018C3P0=3PT06AXF01PJ5`0>40d04A<@00lA3P0=3``0418?00lA3P0=3``030h;00d?
300@4Pl200`=200700l@2`0=3PT02@X500h?2P0:2`P061TD00h?2P02010A300700d>2@0>3`X03@h9
010A300A4Pl04Q<>010A300200d>2@<03Pl:03/03a0;00H70P0<3@P03a0;00h?2@0A4P`03Pl900d>
1`0B4`/03Pl700h?1P0B50X04Q@900`=1@0=3PH0414901<D3P0D5Q004QD>014C3P0B5A406AhJ00<8
100C61@041@A00X@300A5a<0J6eY065VHP0D61<03@l:01@G400>40T02``600h?1`0@4@T03Pl700h=
1`0@40T04A0:00l?200@3`T04Q4;01HE3`0C4``04Q8;014A2P0A40X04A0;018C3P0@4@`03a0;010A
300A4Pd04Q<>00`=200B4`h051D@018C3P02010A300700d?300:30T05QPE034c<00B514030h;00d?
300200`>2`0900h@3@0A4a004Q@A018C3P0H6A@09BHQ01/L5`0=3PT04a@?00D03a0;00<0414=010B
3`0@4Pl00`0@4Pl01`0>40d04A<@018D4@0A4a00;S0]01DG500<3PX00P0@4@`2018C3P0<01<D3`0A
4Pd03Pl:00h?2P0A4Pd04a@?014B3@0@4@`04Q<>014B3@0=3PT03a0;0P0@4@`05@0A4Pd0414<01@E
400E5Q404A8=00d@2@0>4@X04A@>014C3P0@4Pd03Q0<00d?300C5A804Q@C014C4`0<3@h05QLG01<E
4P0A4`h03a4<014C3P02018D3`0;010B3@0A4`h04Q@?00lA300>40/03a4<00hA2P0@4``04A<>010B
4@0A4a800P0E5QP03P0F5aT05QPF018D4@0@4Pd04QD=018E3P0>40X04aD@018D3`0@4Ph07AlL06U[
J00E5aD05aTH0P0B51<04`0C5A803Q4;01HH4P0<3PT04aDD01LH6@0E5QT05QLL01PI7@0D5AT03@h@
01TK6P0C5A<06alN01@H5`0J7Qd06AdL014E500F6QT00P0D61L02P0E6AP05QXI01LK6P0G6aX051PG
01LK6P0A5A@05ATH01`P7`0A5A@201DI600301TM700H71/07R8Q00805a/J00<04aLF00lC4P0K7ah0
0P0F6QT0>`0N8R406QhM01LK6P0G6aX061`K01TM700F71X06AlM01DK6@0M8b405adM01XP800K8B40
5a`O020U:00M8RD04aPL020U:00N9bD07RLV01lX9`0O:BT07b/[020];@0P<300:CTi02@f=P0]?d00
;D5203eDD`0gDDh0:48o03QAD017Gel0Bf1Q06inPP22SY@0UinV0;Vja@3Gdn00j^;a0?K[nP3gk?X0
l>Wg0=_HiP2l`Ld0XJZf086AV`1aQHl0HWV204aUK`18Hfd0A5iX03iFG`0kDUP0=TeC03YAE`0nEE/0
>U5G0080<dY@01H0=4]A02m6C00^AD/0<TU?02i7B`0bBdl0<da@02i6B00[@dD0<4Q:0315AP0^@d@0
;T9303=7AP0dB4L0<4A202/n>P0hBdD0=DQ202`o>@0cAT00<4<m0P0Z?CL01P0[?SP0;D0j02m2?00a
A3l0@eME04]OGP80>Ti<00@0=4Q603A9A00iCTT0=DY50P0cB4401`0bAd00=da50396?P0hC4<0=TXo
03A8?00fBch00P0dB3`0:P0^@SL0B5]D04QKEP0oDTl0>Di;03E:AP0fCDL0AeeJ04=IE`10EUD0>e1A
03iCE010EED0?eEC03aBC`0mE4h0?UQ@03mJDP0jETh0>5=;03YDB`0lET`0?EI;03I>@P0gCT80@UQ<
0398>`0cB3`0>De203Q=B@0jCdH0=T`o0399>00hCcl0?UA803]@BP0`A4<0=4Q603aABP0mE4D0?UE6
03E:@P80>Di700L0>4e603U>A`0jCdP0@5E>03iCC00mDT/0?U=<0080?eA=05/0>e1;03Q=B00gC4L0
=4U403eBC@19GUT0?eA?03aAC00cB4<0>4e803]@B`0dBD80>D]003Y;@@0oD4H0=TLm02ho=`0Z>c<0
9CH^02Tj=00hBD<0;Sli04UJE013DTT0<cld02ll<@0`?C<0<3`e02di<`0/=c<0:3@b02Td=00b?3h0
;cXm02Lb=@0W=2l0;3T_02Xg;P0T<2P07bXR01lZ8`0T;RP0:S<^02Tb;`0T;2X09B/Z02@Z:@0R:RD0
8bdT02<]9@0R;2@082XR01lX8`0M9R406b@O02D^:`2:Ti00DeaI01`U8P0K7b008bLX01dQ8P0J7Ql0
9BTZ01lS900N8R<0<cLh01dQ8P0O8b@09BTZ02<X:@0S:bd07bP/01/T:00J8RT07RH^02@/=@0N9Rh0
72@[01TQ9@0E7R0051hM01HO6`0D6QP06b4O01HJ6@0B5QD05a/J01/M6P0L7Q/05ALC00805QLB00P0
51D@01HG4@0L71X05aLE01<C4@0B4Q0061PF01`L6P@05QHD00/051@B01<C4@0Z:BL05A@B01PG5@0J
6AL04A0>01DD4P0F5A<04a8@014@3P0201<B4003018A3`0I61@04a8>00804Q4=00H04A0<01HE4@0B
4@d04Q4=010?2`0A40`2018A3@0D010<2@0E4A004`l>01<?3P0C3a004@d>01DA4P0@2`l04@`@01@?
4`0A31803PT=014?4@0=2``04Q0A01<A4P0=2``030X;00h<3@0?3@h2010>3`803`d>0P0=2``0100;
2@X04@l@00P61`0<2P/200h<3@803@/<00<030X;00h;300@30d0100@30d300l;3004010<3@0?2``0
3`/<00l;30804@d>00L0E51A01<?400B3`l030P9018>3`0F4Q<04`l@00803@T:00@03PX;00X61`0=
2@T04`l?0P0A3@X0:00H5@l0Cda5092=Q01eLfL0;R`O02DS5P0I5Q004Ph=00h:2@0B3Pd02`L601hJ
6@0@3@`04`l>00T61@0?2`X040`;00h:2@0@2PX01`8200h8200B30`02`D501TC4`0D3Ph04P`<00l9
2@0<1PH03@L700l92@0G4A403@L702hX:00:1@D04P`<00X4100E3`l01`4100d8200=1`L200`61PH0
40D900<03`@801462P0A1PX00P0A1PX200l4200;01052@0A1`T040L;01072P0>1@P01P42018=3`0@
3@d0BTI802`X:@1FDU805?ooool001_ooooo00T0IVm/03i7A00H8Ah04QPF00/A3`032@L03A4@00hA
400?4A000P0>40l0;00=3``01``6014F400>4`d01@X4010E3`0<4@/03A8<01TN600K81X03a@>00/@
2P0?50h04Q@?00lA300A4`h03Q0;00X<1`0<3PT03@l:00lA300<3PT03Q0;010B3@0=3`X03a4>00d?
300<3P/03Q0=00lA3P0@4Pl0@dE201dO700=3``02`d:00P:1`051`803Q0;00d?2P0;3@P0418=00/=
200A4`h03@l:0`0@4Pd02P0B50l04A<?00h@3@0?4@h0418?00d?300;3@X03@l<00lA3P0=3``200h@
3@0:00`>2`0=3`/03a0;00h?2P0<3@P03Pl:018C3P0C50l0414<00l@2`803Pl:01<03a0;00h?2P0=
3PT03Pl:014B3@0@4@`030d800X;1P0@4@`05QLB00h?2P010P002P/6014C3`0=3``030h;018D4@04
1P<04aDB00803Q0=0P0=3``0100>40d0418?00l@2`0=3PT200l@2`0900/<1`0?40/0004001/L5`0<
3@P07AhI00H70P0>3`X0414<00803Pl:00<0R8V402`]:00=3PT00P0?40/2010A30@04A8=00P03@h9
00d>200A4P`03Pl900/<100@4@T03@h600`>0`804A<80200414900l@200?40P04A8<010B2`0<3`P0
1@L205mSGP1dNGD02@h:00H<200?5A4051XF00hC3`083@T000D100d@300@4Pd05QTB018D3P0?40X0
3a0800h?1`0=3PH051@<018B2P0=3@D03`l701HF3P0D50`04A49010@20<03`l700X0410801<D3`0@
4@`04A8=00h?2P0<3@P03Pl:00l@2`0A4Pd03a0;0P0=3PT0200?40/03@l<00lA3P0?4@h04Q@A00T;
200C5A803a4>0P0=3``02@0A4a005QPE01PJ5`0A4Pd03Pl:00P9100?40/04a@?00d>2@0500l@2`04
010A3@0@4Pl0418?010B3`803a4>00X04A<@00d?300;3@X03a4>01dO70092`P04aDA01DF4@0C50l0
414<0P0>3`X0100?40/04A8=018C3P0C50l2018C3P07010A300?40/03a0;00h?2P0D5A005QLB01<D
3`0200l@2`0/014B3@0B4`h0414<01<F3`0A50d030l800/=200=3`X04Q@?01DG500:30T0:B/Z01@E
5`0F5aT03Q0@01HH5@0D5Q404A<>010B3@0B50l05ALB010B3@0A4`h04Q@?010B3@0?4@`04A<=00`?
1P0A50/04aD@010B4@0B51<07b0R01DF600H6A/05aTG014C400>4@X041<;01`O600A50h051HA01LI
500D5Q8201PJ5`0B01LI5`0>40l03@l>01`N7@0K7AX041<<01HI4@0J71L05aTF00d>4@1CE5P0GUmT
014B5P0J6ad071dO01@F500@4Pl05a/J0`0B5QD0700@51<051PG014E500A5A@04QHE01<G5P0F6QT0
61`K01DI600N8R404ADD01<G5P0J7Qd0720O01DI600G6aX061`K01LK6P0M8B0051PG01TM700G6aX0
4QHE01XN7@0E6AP05QXI01dQ800I7A`201HJ6@0:01TM700K7ah0728P0416A00oAD<06b4O01TO7`0L
8R807R@T01TN8@807b@W00<06QlS01PM800M9RH00P0L9B@0;00M9bP07BTY020];P0fATH0@U9B01d_
<00L;S0083@e02e2@P0[A440<4U603I?C@18H600CfAU05]^L@1bPHH0QI2F0:2V[`2k^lL0b/SE0=SB
h03Le><0em7O0<;2c`2W[kX0TYjZ07J9T`1TNXD0EG1i04ERJ`11GFP0?5QS03QBFP18GfD0Bf9X03Q?
E@0cBU00=DaB0317C@0bBDl0=DaB0399C`0_AT`0<4M=0P0cC500100aBTh0;4A602e5A`0dC4h20315
AP0F0314A@0^@T40;D5002/o?P0dAd<0=dY40354?P0^@C/0<TDo02Xm=`0U>3809cXd02e0>P0bACl0
=4M103E8@`0iCD/0>dm>03=7A@0dB4H0<dM503E:A@80>4e804P0=DY30356?`0aASl0=4U202e1>00i
CD80;d<g02a0=00fBSd0;T8f03I:?`0]@3T0DVEQ05=UI@0mCe80?4mC03Y@C@0hCdX0AE]H03mED`0n
E5<0>Tm@03]@D@0kD500>e5?03mEDP11F5<0=Tm903QCC00nFU<0@UeF03iID00eCdD0;dTn02U1=00b
BCd0?59602m5>00hCD40=d]003M<A`0gC4<0=de003U@?`0oETH0@UQ;03U>B00bATD0=TY803Y?B00f
CCd0=D`l0356?P0iCTL0>e1903Y?B00lDDX0?eA=03iCC010EDh0@EI?041ECP0mDT/0>e1903I;AP0i
CTT0>e1;03E:A@10EE00DFIQ03]@B`0nDdh203eBC@0S03I;AP0^@c`0=4Hk03A5>`0mCT@0=dPn02Lh
<00Y>S80<T<k02Hg<@0Z>cD09SLa03I7@@0kB3l0=3la02dh:P0W<BH0:3@Z02Lb:P0V<Bd09C4a02Xe
=`0lAd/0>DI<02dj@00S<Bh08c0V02Db:00U<BP092lW02Ha:@0W<B/0:34/02D^:`0P9bH00P0R:2P0
4@0R:RD08R`S01lY8@0M9al07RPP024Z9@0E7QT05QlJ02H_;01XLFh0=Sll01`U8P0M8B807R8S01TM
7P0M8B809BTZ0080720Q01d0EUYK01PL7@0N8R<05QXK01hS8`0N9RP06B<T018L7P0A6Ql05AhS01hW
;@0J8bP05b4S01<M7`0E7ah05b8N01HQ6`0B61H03A<A018F5@0=4A003a<B01TK600K7AX05ALC01LH
4`0H6A@05QLA01LH4P02018B4004014A3`0F5Q@05aLE00h>30<05QHD0`0E5A<0400T8b405A@B01HE
4`0H5aD04a8@01@C4@0H5aD05A@B010?3@0C4Q005aHD010?3@0B4@d030/7010?2`0C4Ph4014@3080
40l;0P0A40`01`0E4@h05Q8A01<?3P0D40l0510A010<3@0D41400P0A31005@0D3a<050lE01<>4P0A
3a40518C00d;300?3@h05A<D018@4@0F51D03@/<014?400E4a@040h?00d;300<2P/06ALH01<A4P1:
B4T02`T:018@4@0200h<3@803@/<00<030X;00h;300?2``0100?2``04P0@30d03@T:00d92P0A3@h0
3`/<00h:2`0;1`P06QHG01TE5P0]:BX04@d>01@@4@0;1`P04`l@01LC500E4A803PX;00/720804@d>
01X040`=010<300@30T07ATF04Y7@@2PWI@0oO__0?Cci`1THUD0928E014?1P0?2`X03PX901LC4P0?
2`X05Q8A00d9200300002PH501@@3`0=2@P030P7010:2P0B30`03PP800d71`805a4A01801`4100`6
1P0A2`/03@L700X4100<1PH0100001@>3P1jM7@07ALG00T30`0?2@T0100001D?3`0l=SH05@l?028L
700:1@D601052@0400l4200@1@T040D901462P804PL;0P0C2@X02P0B20T04@P901072@0@1`X02`D7
00P31@13?T80h]gQ07]fNP03008Dooooo`006oooool0100G81l031DD00D>300:4Q02010F500P00dA
400>4A003Q0?00h@3`0>3`l03@l=010D3P0@5@h01P/5010E3`0=4P/03a@>00X?2@0?50h041D>00`A
2P0:3`T0314:00lB300>40X0418<00d?2@0<3PP0418<00h@2P0?4P`030l900lA2`0A4`d03Q0:00d?
2P0>40/400lA300401DG4P0A4`h03a4<00h@2`803a4<01/04A<=00lA2`0<3`P0418<00T<1P0>4@X0
3a8;010B300?4P/03Q4:010B300=3`/030h:010B3`0E5a<051HB014C400?4@d030h:00`>2`0=3`/0
3Q0<00d?300?40`03a0;00`=200?40/00P0C50l06`0A4Pd03a0;00h?2P0?40/0414<014B3@0B4`h0
414<00h?2P0?40/04A8=010A300=3PT04A8=018C3P0@4@`05QLB01@E400=3`/051HC00h@3@0E5a@0
10H301<E4P0<3P/03@l<00lA3P02010B3`0500lA3P0C50l03Pl:00l@2`0B4`h00P0@4@`01P0C50l0
3Pl:0493?P0R8ah03Pl:00l@2`803@h900@04A8=0452?@0P8A`03a0;0P0>3`X200l@2`80414<02X0
4A8=00h?2P0@4@`04A8<00d>1`0?40P04A8:01DF3@0@4PL030h400lA1P0>3`H03a0800h?1`0?40P0
4A8<00lA2`0<3`P030h901<F4@0B5a803Q4>00lE400830L041DA00dA3@0>4`h01`/700d?2`0=3`X0
3A09014C3@0A4P`03Pl700d>1P0?40P0?clg02/Y8@0?3@H03P/401@B2P0=30@2014>2004010>200B
3`T04a0:018B2`8030d800<04A8=010A300=3PT00P0A4Pd04`0>3`X05AHA01dN6@0C50l02@X5018D
4@0A4a004Q@A00X<2@0>40d04aDB018D4@0?4@h03@l<00h@3@0B514051HB00h?2P0D5@l00P0@4@/0
2@0D5@l05AH@00l@2P0?40X03a0;00l@2P0?40/0414=010B3`0200lA3P@03Q0=00H03@l<010B3`0U
9b@0418?018C3`0A4P`2010A2`0:014B300C50h04A8<018C3@0E5Q004A8<00d>200?40X0414;014B
3080414;00H061TC01`M5`0I6Q@06AXD01XK5@0E5Q0200l@2P0:010C2`0@4`X03a8;00hA2P0?4@/0
418>00/=2P0f>3H0TiFD01<D5@805AHG00<06A/F01LJ4`0A50d00P0=40T0;@0A50d041<<014D3@0C
5Pl04QD>014D3@0D5a004A@<014E3@0A4`l04A<B010B4@0A4QD0414D01@E5`0F5aH04A8>00lA2`0D
5Ph06ahG010C3@0@4Pd06A/F01/M6@0B514030h;01@F500B51<051HE02/];00F61D061/C00hA2@0B
50l06A/H01LH6`1kO800OWn401TJ7P0G61X04Q@D01@F500L7Q/03Q8A01DI6002018F5@0401DI600>
4Q405QXI01@I60804QLE04l04aPG01@I600F6QT08BDT01HJ6@0E6AP04ADD01HJ6@0D61L06QhM01PL
6`0E6AP06alN018F5@0E6AP061`K018F5@0F6QT04QHE01HJ6@0K7ah05a/J01DI600F6QT06QhM01`Q
800H7Q`06R0N02H/:P0R:BL0;38b01XQ8@0I82004APJ01XQ8`0P9bT08bT/01/Q900P:2T07RLV01dV
9@0N:2T07RXZ020^;P0O;bl08S<d01h`<@0U=cP06Rh_02Xo?P0^Ad@09Cdj03M?C@11FET0?5AD05EY
K01SMGT0LX:708JAV@2FWJL0X:J`0:n__02g]L80/k>o0::W/`2>VJ<0OXbG06QlQP1CJgD0BFA^04ER
K00mFVD0>UMR03aGG`1HL7D0GWEk03eDFP0nEE/0?EAJ00<0<DQ>03P0;dI<02m7C00aB4d0<4U=02m8
B`0^AdX0;TI802m7B00_AdT0<4E60397B00cAdP0<4A303A8A`13EeH0<TI202m3?@0^@S`0;T4l02a0
>P0]@3X0:chi02Xn>00[?cT0;T4l0314?P0eB4@0=d]:02i2@@0dB4H0;d=103E9AP0iCTP0=DY403M<
AP0gC4D0<dQ103E:@`0hCDD0<4@j0355>P0dB3`0;T8f02Lk;P0^@SL0=d]102m2?00bAT@0<dE703i?
EP0jCE80@EMD03QAB`0nEe<0>55>03YCD080>eAA02@0?UMD03UBC`0hDDd0?eQC03eFD00jEDl0BFEO
051]I@1:IE`0?eU?03eFB`0fCT40<dXm03I<?`0dB3`0=DXm03I:?`0gC4L0=4U003M=@00mE480?EA4
03]AA00hCDL0>De<03mCD@0oE4`0>4i003M>@00eBT80?eA=045FC`0nDd`0?E9;041ECP0nDd`203mD
C@0C03iCC00lDDX0>e1903]@BP0dBD@0>Tm903Q=A`0iCTT0@eQB03]@B`0hCDP0?E9<03Y>B00aAD40
<dM003U:?`0lCD@0=dPo03A5?00202Xk=00N01//9@0Y>SD0B5UD02`m=`0fAd40<Shd03<k;00_=bT0
9BlR02H`9`0T;bL08RdY02Xf=@0f@d@0@4e@034oA@0U<cX08Rl]02<`9@0T<BL09C8X02@_9P0U<2P0
9BlY02D^:@0R:bP072@R020V9P0Q9bP07bLS0P0N:200<@0O:B4082TS024Z9@0M9R405alJ03@m>P0e
?S/08BXW01TR7`0M8R80724R01dR900M8B<06AdP01LK7P0L7R807B4T01XN8P0N8bH08BHY01lT9`0G
7b005b4Q01XT9P0K92T06R<X01LP900H8BD06b@V01TS900B6aT03aTE01@O600E6aP04QLE018F5@0E
6AP05a/J01<E4P0J71T05QLC01PI500J6aH05aPB01PI4`0C4a4061PF018B400A4@l00P0H61H01P0G
5aD05QHD01@D4P0D51805aLE01TI5`8051<A01h04Q4?01DD4P0H5aD05A@B018A3`0L6aT05QDC010?
3@0E51805aHD014@300?3PX04Q4<014@2`0?3PT04a8=014@300@3`/03`h9010?2P0@3`/04A0<018=
2`0D3Ph04@`;01D@400G4A<04`h?01<=3`0E3a<201<>4P0901L@5`0I51P04@lA010>3`0B41403P`=
01XH6@0/:R/08R0Q008020H700T04@l@010>3`0?3@h03@/<014?4@0<2P/09B<T00h<3P0;2@X00P0>
30h200d;300300`:300>2``040X<00@040X<00L04P`>00d72@0<1PP04`d?010:300>20X03PT;0080
3@T:00D040`=014=3P0;1`P040`=00h:2`0200d92P0400h:2`0?2``04@d=00l;2`8040`<02`04`l<
02`X9025PW`0YJ:I0=_HcP3Acl@0?S`_01hL3P0D40T05A4@010<2`0I5A@04`l>00`81`0A3@`03`/:
03Xf=@0:1PD03@T800l;2P0>20P03@L7010:2P0D3Ph05Q0@00T4100<1PH03@L700l92@0A2`/040X:
00`61P0C3@d02P@401@?3`0=1`L030H600d71`0@2PX02PD501TC4`070P8040X:00h820H040D90180
5@X>01<8300@1@T03`@801052@0A1`P050X901881`0?1@@03@D400l71`0@1`X040T;00d7300F4AH0
=2hd01hH7`0?2@lDooooo`006oooool020053QD02A<I00D?4@0<5QL041LF00hD400<4@d03a0=0P0@
4102018@4`0800lA400>40d03@l<00d?300>40d03a4>00d?300>40d200lA3P0?00h@3@0=3``04A<@
01@F4`0C5A803Q0=00/=2P0=3``03Q0=00@60`0>40d04aDB01@F4`0T9R<02`d:00803a4>00L03@l<
010B3`0C5A804aDB01HH5@0D5Q<02@/800804A<@01P03Q0<00X<2@0>40/030h:00/=2P0@4Pd04aDA
00lA3P092`H03a4=00L91P0C5A003a8;00h@2`0C5Q004A@=010B3@0@4P`03A0900d?2P0=40X03Q4:
010B3@0?4@`200h@2`0400d?2P0<3PT030h900d?2P803a4<00l0418=014C3P0B50l051HA01TJ5@0F
5a8030d800l@2`0C50l04A8=02//9`1<CDP05aPC0042000K71L00P0>3`X200l@2`803Pl:0P0A4Pd2
00l@2`09014B3@0E5Q409bTT01TK5P0<3PT03a4<010B3@0:30L0418=00<03a4<00<03Q0;00`=200@
3`X00P0@3`X00`0>3@P03@`700/:1P0300h?2P0c00h>300?3`d0418>010A300A4P`030d900`=1`0>
3`T01`P201@E3`092PD03@h600h?2@0R8al030d7018C3@0F5a403Pl900/<1P0@4@/03Pl900`=1`0:
2`D030l8018C3P0C5@l03a8;01@F4@0;3@L03Q4:00X;1P0<3@L01`P200/<1P0H6A<071dG018C3@0:
2`D05QLA018C2`0>3`L04149010?2P0>3PT04A8<00d=200F5A4051D@00L70`0A40`04A8=00803a0;
02404A8=018C3P0>3`X02``700X;1`0M7QT05AHA04M8@`082@@03@h9010A300:2`H0414<01DF4@0;
30L03Pl:00d>2@0F5a804A8=018C3P0?40/04a@?00h?200@4@T04A8:014B300>3`T03@h800h?2P0A
4Pd04A8>010A300@40h00`0A4Pd02@0B4`h04a@?01<D3`0A4Pd03a0;01DF4@0@4@`04a@?00/<1`02
01<D3`08018C3P0A4Pd0414<00l@2`0H6A@01@H100h?2P0G61<200h?2P0H01DF4@0A4Pd04Q<>00h?
2P0=3PT05AHA02<T7`0K71L03@h9010A300I6QD04Q<=00lB2@0<3`H03@l;020R7@0K7AX0418A00/=
300H6QT07b4O01<E400D5Q403Q4:1P0?4@`06P0C5A0020X500lA300D5Q4030h9014C3P0A5A@03A<A
00lC4P0830/03a<B01@F5@0=3@/03`l=01<C3P0D4`h04Q4<00h>1`0G61<0418?014C400m?c`04aDB
01TK600F61D051HC0`0C5A80800@4Pl06AhJ014F4P0?51003Q8A014E5@0N8R<04aLH01@H6@0D61L0
4aLF010D4`0=4A004aLF010D4`0E6AP041@C01@I600@5Q@04ALE00hF4`0D7AX082TV00`E4P0G81d0
3A<A01<I5`0=4a40<3Hd01<I5`0=4a4051XH0P0J81h00`0=4a406AlM01<I5`0201<I6@0701@J6P0F
71`05adM01PN7P0G7Ad04aTI01@J6P0201LM7@0601DK6`0E7A`031DD020Y:00@6QT06b@S0P0H8R40
8`0G8b405R8P01/W9@0D81h06BDU02@`<00W<c<09S8b01h[:`0O;Bd07Rh]01TY:00K;R`08C@c02@g
=@0/?Sh09SXi02Pn?00`A4<0=DY:03Q=CP0nDe@0BEiP05I[KP1PMGP0K86507J;T01oTYP0S9jU092Q
Z@2:WJ@0P9>J0724R`1VOH<0FW9g0080CFI]00T0C6M^03aGGP0gDUT0>eIM03QCFP0iDUL0=e1E03E>
D`0dCE400P0`B4`0GP0]@TH0>4eB0356B@0`ADT0?55B039:BP0`ADH0<DI702i4@P0bAdL0=D]90316
A00cBDL0=de;03E;B@0jD4h09C/h03=:A00aAT809c/i02i5?`0[@Cd0:3`j02]2?00bAd<0<TI402e4
?P0Y?C/0<TI70314A@0dB4H0=4U40356?`0fBd40<dTm0357>`0fC440>e1903Q=A`0hCD@0>4a00312
=00^@3@08CDY02Pl<P0cAch0=T]403M<AP0bBD<0<4E003E;A@0mE4`0?5I;03UCB@0fD4L0=Tm903UB
C`0lEE80?eQE041IEP1>If@0<T]704AMF00mEU00>E9<041JD@0nF4l0>eE<03eDB`0jCdH0<DHm03aA
A@0jCT<0>De203eAA@0jCT<0=da503M<@`0gCD40>4i103M=@00gCD40?59704EJD`0nDdh0?55<03]?
C@0dBD@0>Di703Q=AP13F540>e1904QMEP15FU<203aABP80>e1901X0>Tm803U>A`0hCdH0>e1903U>
A@0lDDT0@5==03eAB00oDT/0=dY403I:@@0iBT<0<T<m02dn=P0iBT<0<40m03=3@@0Y>CP0@51@06If
MP0B8R80<40o07R8Q`13De00;d0j03A1>P80<3Xa0440:cD/024[8`0S;2L08BXV03a7@`1dOWd0BUAD
02H`<@0O:BX08bhZ01`/8P0U=B/07RhU02Ld;@0X=Bh0:3@]02<^:00M:2807BLQ01PQ7P0J8b007BHR
01hW8P0R:bH092dY024Z9`0P:BH0624N024Z9`1SK6T0DU]H01`U8P0H8Ah051lI01LR700I8Ql061hL
01LK700M7R406aXO01HG700N8RP06b8Z020W;`0R:c809B`d018I8@0a>3h0EUeS024X;P0P9BT05Q/N
01@J6P0G71T05AXF014F400C618051TE01PJ5`0G6AH061XG01/M6P0D5Q<05aTF01HH5@0301@F4`03
01DG500A4@l051@B00<05aLE00@05ADC01PH5P0D51804a<A0P0D51800`0C4Q005a<B01LC4P0201LC
4P0501HD4P0E51802@P602h^;00J6QP00P0;2`T0600@40h040l=01<B3`0C4Ph04A0>010?300@3`/0
3`h<010?300@3`/040l<010?3@0A40h04@l@018>3`0?3@h04@dA018=4@0A3a804PlB020K7`1VI6L0
5A8E00l:3P804@lB01h020H9014?4P0A3a8030X=014?4P0?3A003P`?00`:3@0:20/03@/>00l=400=
3@l02PT>00d=3`0B4QD040lD00d=3`0?3Q802`X?01LG6@081`/02`X?00h;3@0>2P/040`=014=3P0@
30d03PX;00l;300E4A8200h:2`0?01LC50070`@0510A018>3`0>2P/04@d>00l;300;1`P04`l@010<
3@0B3Pl0510A00d92P0;1`P03PX800803PX701<04@d:01@A300D4@`061D@020M5P0j=c00De1902@Q
6P0>2`@040`800d71`0@2PX04@/;00l92@0<1PH0<2XZ01XD500;1@D04@/;00803PP801<04@/;00L1
0@060@402@<301<=3@0;1@D040X:01D?3`0?2@T04@/;00d71`090`<03PX9014=300B3Pd02PH500L3
0P0<1PH040L800803`H700<03PD600l61`0A1`P01P0@1@T01P0E2Ph050T=01<8300B1`/04@H:0105
2@804@L800X040H701052@0?10P03`@801462P0=10L02@0301483@0K4QL04PT>5?ooool001_ooooo
00h05AlY014K8`0?6Qh03QPJ00T@3`0=4`l04A<>014B3`0A4@l04@l@018>4`0@3Q404Q8D010B4@80
3a4@00<0418A014C4P0=3`h01@0=3`h03@0?4A004Q@C014C4P0=3`h030h=00d?3P0A4a8030h=00h@
3`092`X0=cTh01@F5@0<3P/00P0?4@h0100=3``03a4>014C400;3@X200D7100E01LI5P0R92403Q0=
00lA3P0<3P/03a4>00h@3@0=3``04A<@00`>2`0>40d02`d:014C400?4@h051HB00d@2@0@4``051L@
00d@2@0930D030l800<03A0900<03Q4:00lB2`0?4P`00P0>40/0100=3`X030h900`>2@0>40/300lA
30803Q0;00h0418=01HG4P0E5Q403Pl:010A300B4`h03Pl:01hO6P0c=2l04Q<>00H70P0E5Q402``7
00h?2P803a0;0P0>3`X0100D5A004Q<>010A300@4@`2014B3@0600T;1P0=3`X04Q@?00h@2`0<3PT0
418=0`0?4@`01@0@4Pd03a4<00h?2P0?3PT04@h900<03Pd800T03Pd900d>2@0=3PT03@h900d=2`0>
3P`03a4=00D6000;30H00P0?40X0300@4@/02``60001000E5Q003@h801dN601;C4H0:BXT00d>200A
4P`02P/500P90`8030d703L04A8<010A2`0A4P`051D?01DF400A4P`04a@>00`=1`0A4P`03@h801<D
3P0@4@/04a@>010A2`0A4P`03a0:00d>200C50h04Q<;00l@200B4`/04Q<=00l@2P0B4`d03a0;01`L
6P0N7Q`03`l=010@3P0=3@/03a0;00d>2@0<3@P03Pl:014B3@0B4`h02P/600h?2P051P409RLR00H7
0P0>3`X04Q<>030a;00E5Q4020T400X;1P0?40/051D@00l@2`0D5A005QLB00T:1@0>3`T03Pl80080
414900H0414;00h?2@0>3`T03Pl:010@3P0A4@l2010@3P03010@3@0@4@`0414<00804A8=00D04Q<>
010A300`<B`04a@?00l@2`0200d>2@03010A300A4Pd04A8=00<04A8=01l02``700h?2P0:2`H03a0;
018C3P0?40/0414<014B3@0@4@`03a0;00h?2P0?40/04a@?010A300;30L030d800l@2`0=3PP04aH=
01@G300<3`P02P`900d?300;3@d030d?01@F5@0F61@04A<>018E300<3`H04A@=00804A<>0`0@4Pd0
300E5a80418=010B3@0D5Q402`d801@G4`0A5AH020d@00`B4P0;3`h03a<B01<E4P804Q<>00/04a8=
01HC3P0F4`h0518<01<D3`0?4@h05ALD02HX9@0B51406A/H01@F4`02018D4@0901@F4`0E5a@04Q@A
01/O7P0D61L04aLF018F5@0D61L07b<R00<04aLF01<04QHE014E500?4a806AdL02da<00d>3L0720O
014F5@0C6AL03QLD01@M6P0?61D03QTE01LR7P0;5Q8051XH01hT8P0E6aT0;C<a00805Q`J00H051XH
01DK6@0I7ad08BLU01`R800@5Q@201DK6`1801HL700G7Ad061hN01PN7P0J82005adM01TO7`0O9BD0
8BLW020V9P0H8B005QlN01XS8P0G8B0092h]01<M700N:RP062LT01<R7`0F9B8041lL01HU8P0X=3@0
;3Xj02Hd=00L:RX07Rh]028b<@0Y>CP09CPf01P[:@0[?S`0;D0n020c<P0[?ch0<DE403=7A`0eBDX0
>Tm@049IFP1<I6H0EFe_05mgNP1VOh<0KHJ:07J?U01iTYL0N96F076:S`1WP8D0H7Un05UbM`1CK740
E6eb05=/L@18HFH0@U]P03aFG00hDeX0=e=G03IAE@0eCU<0=4eA0359C@0Y@DD0>4e@02Xo@P0/@D@0
=4U;03iDDP0eBdT0;TA20P0]@d403@0gCD/0=D]90316A00aAdD0<dU70316A00cBDL0<TQ502e3@00/
@Sl0=D]803Q>B`0[@Ch00P0_AD80B00^A440;48o02i4@@0dBTL0<dM80396A`0fBTT0=da703=8?`0f
C400>U1303=9?00eBcl0?55:03M<AP0aASd0<dDi02i0<@0Z?3007c<X02e1>@0gBT@0<DI103E;A00i
D4P0>e9803YAAP0eCD00>E=603QBAP0fD4D0=e1:03UBCP0lEE80AUmL049KF01<IF80=4e904=LE`0n
Ee40>E=:03I>AP0gCTH0=4]303Q>A@1=HUT0B5eD03Y?A@0hC440>De203E9?@0gBd00>Di603aAB00k
D4L0>4i203=9?@0bB3`0>Dm303iCC00dBD80=DU703iBD`0mDE00>e1:03M<A@0hCDH0>e1904=HD@0n
Dd`0?eA=03eBB`<0?55:02h0?E9;03Q?A@0lDDP0>Tm603eBB@0oDdX0?51703eAB00gB400=TLo03M8
@00b@CX0;Sdf02m0>P0lC4T0=DE403m?C`28UiX0_<[<03e=C@0L;2`0;cln02/k>00cA3h0>dQ1030j
<P0^>3009c4Y01hX800Q:RD0:S<_079kN03foo`0UYnM02D^;@0Z<c80:CDa02<b:`0X=c009cH_020_
:00Q;RL09S8/02<^:00Q;2H082XU0P0J8ah0:00P:BD08R/X02@]:P0R:bP07BHS01`U8P0H8Ah08BXW
01`U8P0O:2D05QlL01PR7@0F8A/05b@K01TS7P0H7Q`05a/J01`L7P0G5Q`07AhS03XmA@0l@dd0=Ci7
02<]=P0Z<C/082La02H]=@0k@4H07B8V02@Y;00N8R<06alN01dO7@0J71L05QPC01TL5@0;3@X04Q@A
01/M6P0G6AH201<E4P0301LI5P0F61D051HC008051HC00X05ALD01<C4@0D51805ADC01HF500E5A<0
51@B01HF500D51804a<A0P0E5A<00`0C4Q005A4@01HA400201DA400901@B400C4Q006QTG00l>300;
2`T05aLE01@D4P0K6aT040l=00804a8@00<04A0>010?3@0A40h00P0B4@l4014@3P03014?4P0@3Q40
3`d@008040hA00`04@lB018@4`1NG5l0THnB01TG6P081PT07Q`O00d;3P0;2@`0518E018@4`0:20/2
00h<3`06010>4@0?3A003@/>00`:3@0=2`h03@`A0P0>3A802@0=314030/@00`;400I61d0Lg9g00/:
3`0K6Ql03@`A00P61`0200l;300F010<3@0?2``03`/<00d92P0C3a003PX;00l;300@30d030P900T5
1P0>2P/02@D600h:2`0=2@X020@500h:2`091@H02`L8010<3@0>2P/03@T:014=2`804Pl:00/04a0;
01@A300D4@`05A8=014>2@0I5Q40:RLR010=20040@002`H500d71`02010:2P0B00l92@0=1`L08adM
01<=3@0<1PH04P`<00l92@0=1`L02`D5010:2P0^:2P050h>01<=3@0;1@D01P0000`61P080P803PP8
0P0=1`L01`0@30/04`l>01@@3`0=2@P02`L6010:2P0@1`P00P0?1PL00`0?1@H040H7014720060105
2@804`P<00@04PL;01462P0@1@T040D90P0A1PX201052@803`@800H04@H:01052@0>0`L04PL;01P=
4@0A1PXDooooo`006oooool03P0e?dP0U9jU00D;3`0E7B003QDD00P>2P0B5Q404a@A018B400B4140
4PhB010>4@0A4A803a4@0P0>40l02@0?4A00418A014C4P0?4A003@l>00h@3`0@4Q404A<B00d?3P05
00h@3`804A<B00D02`d<00lA401`LW40>3Xi00h@3@0200lA3P803Q0=0P0?4@h01`0A4a0030h;01XL
6@0X:RL04aDB010B3`0>40d00`0?4@h0200A4a00418?018D4@0B514030h;010B3`0?4@d03Q0;0P0=
3`X0100<3PT051HA01LI500>40/200d?2P0300h@2`0?4@`03a4<00803Q0;00@03@l:00`>2@0<3PT0
3Q0;0P0?4@`01P0>40/03@l:00d?2P0=3PT04A8=018C3P80414<00T04A8=00l@2`0A4Pd03Pl:010A
300B4`h03@h900`=200>3`X00P0@4@`0400?40/03Pl:01@E400A4Pd0414<018C3P0C50l03Pl:00h@
2`0@4Pd03a4<00d?2P0>40/03a4<00T;1P0:30L400d?2P06010@2P0?3PT03Pd800d<1`0>3@P0414<
0P0>3`X200d>2@0]00h?2P0>40/02@X401@E3`0O81X06AXD018C3@0C50h061TC01<D3`051P404a@>
014B3P0=3PP03Pl9014B300=3PP030d7010A2`0B4`d03a0:00h?2@0?40X0414;00l@2P0=3PP03a0:
00d>200@4@/02P/501<D3P0B4`d09RLQ014B300<3@L04A8<018C3@0?40X03Pl700d>1P0B4`/04a@>
00h?2@0?40X04a@?00806ATG00d03Ph<018B400?3`d04a@?014B3@0=3PT030d801HG4P0N7aX04Q<>
010A300=3PT0414<00804A8=00H05aPC03`m>00E5Q403Pl:018C3P0@4@`200`=200801@E400A4Pd0
20T401DF400?40T03a08010A2@0@4@/200l@2P0600h?2P0>3P`0410>010@3P0?3`d03a0<0P0?40/3
010A300:01DF4@18BD@061TD018C3P092PD03a0;00h?2P0?40/0414<014B3@804Q<>00L051D@04]<
A`0K71L03Pl:01LH4`0E5Q4030d800803Pl:00D0414<00l@2`0=3PT02``700l@2`02018C3P0?00l@
2`0A4P`05AP?00`?1@0A50d06A/G00D7100Q8b802`d<00X<2P0?4@h06A/E00lB2P0A50/04aH?0080
4Q@?00l04A<>010B3@0@4Pd03Q0;01@F4@0A4`h061XE00h@2`0B5A40?40o020V9P0C6AT0310?00T=
300A4a000`0A4Pd02P0B4@`051<>01HE400>3`/04Q@A01/M6P092`P04aDB01LI5P0C5A82018D4@06
01@F4`0F61D051HC018F5@0A5A@04QHE0P0A5A@00`0G6aX04aLF018F5@02014E500J01<G5P0D61L0
3a<B01/O7P0S9bH051PG014F5@0A5aD06B8O01<L6@0G81d04QdI00XE4@0E81`051XH01`R800A5aD0
6AlM00hD4P0F71X06R0N01LM6`0;4@l06AlM00dC4@0J81h601LM7@0a01TO7`0F71`05A/K01PN7P0K
8B40728R01TR8@0C71/05b0O01DO7P0P:RT04Q`K01hZ:00G9R<04b8O01TX9@0E924072/X01`X:00W
=CD07bd]01XX:00L;2/08C4`02Ti>00V>CL07C0^020c<@0U>3H09cXi02Pl>`0/@3l0;T9203=7B00h
CDh0?eEG04EMG`1<I6H0Df]^05M`M01KM7P0H7Un065jO`1RNh00GgQm05M`M@1@JFh0BF9W04QQIP02
04MPI@0@04]TJ@16Gf@0>EAH03MCE`0fDUH0=U1E03E>D`0dCE40=e1D03Q@D`1>HfH0;D9303Q=CP13
F5T0<TQ60357A@80<TQ60100<4I40357A@0dBTP0<TQ603=9A`0dBTP0<dU703I<BP0`AT<0<DM403Q>
B`0fC4T0<DM403M=BP0_AD80<TQ50P0fC4T0NP0gCDX0>U1=0314A00`A4@0=T]803I;AP0aASh0<TPl
03I<@00_ACP0<4Hj03U>AP0eBT@0<4Dl0395>@0aACH0:clc02Pl<P0lD4P0=4U203=8@`0dBT@0>U59
041GCP0oET/0>51303E?@P0gDDD0>UA903]DCP0lEE40?EIC045JE`0nEe@0BF9O045JEP11FUD0?EI@
03mID00kDd/0@eYB045HD012F4l0FFiU05Q]I00lD4H0>dm4041DB@0iCD80?U9703]@B00nDdX0?558
03A:?P0_ACT0<4Hj03M=@@12Ee00>e1903I:B00kCe00?51?03eBC01RMg00C65J03aABP0dBD80>e19
03iCC00kD4T0>Di703Y?B00lDDX0?U=<03YAA`0oE4/0?E9903iCBP0lD4L0>4a303I:@@0dACd0<d@l
03A5?@0a@3T0;Sdf03I7@00b@c`0<44m02Ph=`0mCD`0D61O0392@P0Y>CP09SHc02/l=@0U=Rl0:CH^
02D_9`0T;RH08B/S01`V7P0S;2L09RlZ04]DC`2U[Z/0H6UV02Tb;`0V;bh082`W02<b:`0R<BX08C0Y
02@c;00Z=c009C4Z02@_:@0U<2X08R`V01/T7`0M9R408R/W0P0S;2T0:@0P:BH072DR01hW900N9b@0
6R<P01`U8P0/=C8072DR01TR7P0K9R006bLN01XT7P0H7Q`05a/J01TJ7@0N7b@071hS02da=`0]=3`0
;cLn02`e?P0Q:300:C0h01hU;@0N8bP05a`P01lU9`0L824061`K01PJ600F61<04aD@01TL5@0];b`0
6adJ01@F4`0M7a`06A/H01PJ5`0G6AH05QPE00<051HC00D05ALD01DE4`0E5A<051@B01<C4@03018B
400701<C4@0E5A<05aLE01HF500C4Q005A4@01HA400201DA400;01@B400C4Q003`h<01<C4@0;2`T0
410>010@3`0B4Q004A0>01<B400B4@l00P0@3`d01@0B4@l051<A01@C4@0C4Q004Q4?008040l=00@0
40hA00l=400?3A003`d@0P0@3Q403@0A3a803P`?01/I700>30l04@lB018@4`0>30l0518E01/I700D
4QD03@/>014?4P0?3A000P0A3a8300h<3`0@00`<3P0?3a403Ph@00/;3@0<30h03`lA028R901oOh40
71`N00`<3P0=3@l04@l@010<3@0?2``03PX;00l;308040`=01h04Ph?00/7200?2``04Ph?03Te=P0@
30d04@d>00d92P0?2``03PX;00d92P0G4a@03`/<00X61`0?2``040`=00h:2`0>2PT03PX700h:200=
2@L030P500`81P0D40h05A4>014=2`0E4@l05A4>010<2P0>2@P300l92@0@00h8200?2@T04@/;00/5
1@0=1`L04P`<00h8200?2@T030H600h8200^:2P05Q0@018<300:10@06Q@D01dG5`804P`<00T03PP8
00`61P0;1`H03PX900l;2P0;1`H02PH500h8200@1`P00P0?1PL00`0?1@H040H70147200<01052@80
4@H:100@1@T01P0=0PH040D900h31`0=0PH040D901462QCooooo000Kooooo`0>00/D6`0e?T<02Q@F
00072@0A61H04aTE00hC3`0?4`l0418?014A4@0B4A804Q0C010@400>40l200d?3P0<00h@3`0?4A00
4A<B00h@3`0<3Pd03@l>00lA400A4a8030h=00/=300<3Pd03Q0?0P0?4A001`0:30/05aTH018D4`0C
5A@05aTH018D4`0?4@h0100>40d02`0=3``030h;01<E4P0D5Q<01@L400`>2`0?4@h03Q0=00d?300<
3P/03@l<00<03Q0=00H03@l<01@F4`072@H05aTF00/=2@0=3`X200/=2005010B3@0N81/07R0K00lA
300>40/00P0=3`X01@0>40/03a4<00h@2`0>40/03@l:008030h90P0=3`X00`0>40/03a4<00lA3002
00lA30<03Pl:00X03@h9010A300C50l0414<00@5000C50l05AHA00T:1@0@4@`03a0;0`0@4@`02@0?
40/0414<00h?2P0>3`X04Q<>01<D3`0@4@`02@/600/=200200T;1P80418=00<02`d800h@2`0A4`h0
0P0@4Pd01`0C5A004a@?014B3@0=3PT02``700`=200>3`X00P0A4Pd04@0@4@`03a0;00l@2`0@4@`0
3a0:01HG4@0L7AL04a@>00X;1@0?40X0004001LH4P061`406Q/E01`M5`082@<02``6008030d700H0
2``600d>200A4P`03@h8010A2`0A4P`3018C3@0<01<D3P0I6Q@06AXD00l@2P0H6A<05aPB01PI4`0=
3PP02``600d>200;30H02P/50P0<3@D08`0B4`/04Q<=00h?2@0>3`T03Pl:00d=2`0>3P`02PX8018B
400?3`d04a@?01@E400A4Pd030d8018C3P0H6A@03a0;018C3P0C50l0414<01@E40092PD03@h900T:
1@0;30L03Pl:00H70P0=3PT04a@?01HG4P0?40/05AHA010A300<3@L03a0900803a080`0?40X01P0>
3`X03@d;010@3P0B4Q00410>010@3@<04A8=0P0@4@`01@0=3PT00@8000T:1@0<3@P03@h9008051D@
00<04A8=010A300@4@`00P0?40/0100H6A@0DeA?01DF4@0?40/200d>2@0700h?2P0A4Pd04a@?00l@
2`0<3@P0414<018C3P0400l@2`0>00h?2P0C5Pd020/2014D3@0U9b804A<>01hP7@0D5Q<0H69O05EG
D`0:3@H03a8;01PK4P0A50d2010B3@803a4<01003Q0;018D3`0@4Pd03Q0;01@F4@0C5A004aLB030d
<`0C6AL02Q0>00X>3@093@`04aPD00/=2P0=3``04A<>0P0D5A003P0B4`d03Q0=01PJ5`0I6aP03Q0=
01DG500B51405ALD01<E4P0B514051HC01<E4P0A4a0041@C0P0D61L02P0C5aH051PG01@H5`0B5QD0
4ADD010D4`0A5A@04aLF01HJ6@0P92<201<G5P0E018F5@0H7A/03aDC00hG5017D4d03AHC01LR7P0J
9B404A`H01XP7P0F71X03aDC01<I5`0B61H05Q`J01@J600A5aD06R0N059HEP0N92803aDC00805Q`L
100E6a/03@0K8B4061hN01HL700F71`061hN01TO7`0L9B@04a`K04I?CP0P:RT04adL024[:P0G8b40
0P0F9B809`0N;BX06RTV020_;00I9BD082h^024_;`0W=CD0830_028b<@0O;bh04B@R02@g=@0^@Cl0
9CPf02Pk>P0U>CP09c/j02/o?`0aADH0=T]<03M>C`0jDU@0@EUK04ENH@17H6@0C6EY055ZKP1CK740
E6eb059[L01;I6T0AUmT04AMHP16Gf@0@EYO03iGG019HVL0Af1U03YDF@0203EAE@0Q03E?D`0eCU80
=4eA02m8B`0kDeD0=DY<02i3A00bAdP0;T=402To?@0^A480=4Y80357A@0]@d40:Clm03A:B00eBdT0
=de;03Q>C00iCdd0>U1>03]ACP0eBdP0:d4n03eCD01@IV<0@eUF02m5@P0fC4T0@5IC045GE00lDTl0
=Ta90080<DE404d0=T]703I;AP0`ACh0;d@j02a2=P0Z@3@0;dDi0315?00_A3`0<dPo02e1=@0_@cH0
=d/o04AHC`1IKFD0@EIA0399@`0gCTP0>U5903QBB@0iDdP0?EM<03E?@P0iDdL0?EM<03mHDP10FE@0
?eQE06IoO018HEh0=e1=03aED@0jDdh0B65K03UCBP0oF4l0?5=;03iEC@10ETd0<DHm03I;@P0hC480
>4a103Y>@`0lD4D0=d]003U>AP0gC4<0<dPo02m5>@0bB3`0=D/o03U?@`16Fe@0A5UB03a@CP0jCTl0
>Ti=03]@BP1cR840EfaU03eBB`0`ACh0?E9;03aABP0hCDH0=T]403M<A@0kD4T0?E9;03]BB010ED`0
?E9903aAB00hC4<0<dLn0355?0020352>P0h0393>`0b@CX0<D0i02dn=00a@SP0=TM002dm>P0`@3d0
CemM04eMFP0T=340834Z03Y;@@0/?C<09S@Z01lY800S;B@09BlW024[8`0U;bL09BlX01lX8`0i@Sl0
;CHc02</:@0Q:RL08RhY01h]9P0A81T0;3/d010O600K:240:cL`02@_:@0R;BL072HP01`U800P:B@0
8R/W024Z9`0P:BH07BHS01`U8P0O:2D0QXn<024Z9`0F7a`07RLT01/T8@0I8Ql07BPR01/V800J8b00
6AlO01PN7P0G6ah201@G700C028V;00O9Rh07RD]01TR:@0D6b<08BP^01lW:`0N8bL05AXN01PM7`0I
7Ah05ATH01LI5P0G6A@05QPC01hP6`0o@Ch08B<P00lA3P0201hP7@0301XL6@0G6AH05QPE00<051HC
00l05ALD01HF500E5A<051@B01<C4@0A4@l0410>014A3`0B4Q005ADC01PH5P0F5Q@04a8@01HB4@0G
4Q400P0F4Q403P0E4a4051<A00h=2`0B4Q001`L501<C4@0F5Q@020P6018A3`0C4Q004A0>00l>300@
3`d04Q4?0P0C4Q001@0A40h040l=00h=2`0>3@/040hA00<03P`?00H03`d@010>4@061@L05A<F00l=
400;2@`200P62@0=010>4@0D4QD05Q@G014?4P0?3A004a4D018@4`0@3Q403@/>00`:3@0?3A004a4D
018B500200`<3P0D00h>400=3@l02`/=00h>400000805aLI00X:300I6A/0518C010<3@0>2P/03@T:
00h:2`0@30d04Ph?01<?400;1`P03`/<01HB4`1;AdP201DA4P0901HB4`0H51D06ADF02DQ8P0_:b`0
5a<D00l;300A3@h03`/<008030P901<03PX9010<3@0>2PX03@T800l;300=2@T03`/:014=3P0>2PX0
4@d<00h:2`0;1PH040X:00l92@0>20P03`T9010:2P0?2@T03@L700803PP801403@L7010:2P0?2@T0
2P@400H10@0>20P0208200`61P0@2PX050h>00/51@0?2@T03PP8010:2P0=2@P03PX900l;2P0200h:
2@07014;2`0@1`P03`H700l61`0?1@H040H70147200601052@803P<7100?10P601052@803P<700@0
2`0400T00P0>10L06@hB5?ooool001_ooooo00h051hP00LA4`0H8R<06R<R00TA3`052`T0314=00dA
3@0?4@h0410@018A4P0A4A<04A<B010B4@803a4@00L0418A014C4P0=3`h030h=00X<2`0;3@`030h=
00803@l>00<02`d<00`>3@0?4A000P0?4A003`0E5aH03Q0?00020@0;3@`0004001hP7`0>40d030h;
00d?300@4Pl03a4>00d?300@4Pl030h;01PJ5`02018D4@0E01@F4`0=3``03Q0=00/=2P0=3``03Q0=
00`>2`0A4a002`d:01DG50082PL0828O00L91@0;3@P03Q0;018D3`0@4Pd051HA01HH4`0?4@`03Q0;
00803@l:100>40/0100=3`X030h900`>2@0<3PT200d?2P0A00lA300@4Pd0418=014B3@0>3`X03@h9
00h?2P0<3@P0414<01<D3`0A4Pd01`P3010A300A4Pd020T4014B3@0?40/00`0@4@`0100?40/03@h9
00h?2P0?40/2010A300@018C3P010`005ALB01hP6`0=3`X02P`700h@2`082PD02`d800lA300=3`X0
30h9010B3@0B50l04A<>00l@2`8030d800@03@h9018C3P0B4`h04A8=0P0@4@`0400A4Pd04A8<014B
300E5Q0051D?00d>200A4P`04a@>01@E3`041@002``600P90`061`403a0:00d>200?40X200h?2@0?
01@E3`0:2`D03Pl9010A2`0?40X0414;018C3@0=3PP06Q/E01/L5P0@4@/06AXD01LH4P0:2`D02``6
0080414;02T03@h8014B300?40P03a0801@E3@0E5Q004A8<01<D3P0:2`H03Ph<01<C4@0@40h04Q8@
00X:200>3`X04A8=010A300<3@P03@h900l@2`0>3`X03a0;00T:1@0=3PT04a@?00/<1`0D5A003@h9
01PI500A4Pd020T401/L5`0F5a803Pl:00X;1P0Z:bH092DP00d>200@4@X03a0800h?1`0200l@2P07
010A2`0@4@`03@d;014A3`0D51804A4?010@3@03014B3@80414<00D06AXE0083000J6aH05aPC00l@
2`04014B3@0Q010A300>3`X03Pl:00X;1P0V9b801PL2018C3P0?40/03Pl:01<D3`0E5Q405aPC010A
300:2`H03a0;01DF4@0@4@`030d800d>2@0?40/03@h901<F3`0E60l03Q4:00`>2@0E5a802P`900`>
2`0b=340<cD`00`?200520402@`500H03a4<01@05ALB00T;1P0>40/010H100/=200B50l05AXF00D;
2@0;4@l041@C00lC4P0?51003Q0=010B3`0E5a805aPC01HG4P0C50l04Q@A01LI5P8061XG00@05QPE
00lA3P0F61D051HC0P0C5A801`0B5140418?00dA400C5aH04ADD010D4`0C5aH0100A5A@0700B5QD0
51PG01@H5`0?4a803Q8A01<G5P0<40l03Q<A00X@3P0:4a00?4E200L@3@0E81`041/G00/F4P0M8b40
4aTG018H5P0D6QP05A/I01HL6P0B61H05Q`J01XP7P17CD/0728P014G5@0D6QX501DK6`0N01HL700H
7Qh05adM01LM7@0J8200728R01PQ800F7ah0FF9Q02La<00>61L07bTX01TU8`0H9b@05bHS01d/:@0F
9B806bXW01dY:@0L:RX08S0`02Le=@0K:bX06RXY03U9B00fBDL09STg01lb<00M<2h0:chm0P0X?3/0
2@0[?cl0;d=40356A`0cBT/0>E5C03mGF@12FUd0@U]O04IOH`0204QQIP0;04YSJ01;I6T0BF9W04MP
I@14GF80@EYO03]DF@0fCe@0>E9G03M@E@0dCU<00P0dD5@07`0eCe<0=DiB03A=D@0cC4l0@UYL03A9
BP0iCTl0>4e>02m4A@0]@d40<DM502i4@P0X?S`0:T0n02m5@`0fC4X0>Dm=03Q>C00fC4X0=de;03A:
B00bB4D0=Ta902m5@P0kDDh0DVQU04eSH00hCT/0>U1=03aBC`0jD4d00P0hCT/0:@0fBTT0=DU803U=
B`0hCDP0<TM00397?`0]@ST0;T@h0398?00]@ST0:Slg0397?P0_@cL0;T8e03Q<@@11ED`0Bf1J03A9
A00`Ad40>e9<041GD@0jE4/0=e5703QBA`0fD4<0>E=703eGC00oF580@5UE03mHE@1AJVL0@5UF03mH
E@1AJVH0?5E@049KE@13GE@0AUmF03U@B00lDd/0@eUA0080:d0g02T0>e1603]?A00iCD80>Ti303=7
?00gC4@0<DHm02i3>P0aAc/0=Ta003U?@`0kDDD0?U=<03aABP0jCT`0?51A03mCDP0jCdT0CfAM041E
CP0mDT/0>Tm803aABP0mDT/0>Tm803U>A`0jCdP0?E9;03mDC@0mE4X0?eA;03]@A`0iCTD0=DU00314
>`0_@cX0<D8j0393>`0cA3`0=4<l03A4>P0203=5>@1:02m0=`0V=c40;3dg03e=B@0lCDL09CH`02`m
=00gBCd09SP/02Hd:P0T;RD0:C<Z02Xd:`0R;2@092hV028/9@0J8ah0:34^02`e<P0G81d0;SLd01PT
7P11D4T0:CPa028a:P0P;bP0;CXc02@`:P0T;bT07bXT01XT7P0O:2<08R/V02</:00S;2T08R/X01dV
8`0J8b0072DR06]dL@0N9b@07bPU01<L6@0R:bP08BXW01/V800I91h06B8O01/Q8@0J82006AdP01TL
8@0F6Ah08BH/01XQ:@0G7RH03aPN01HM8`0N9RT072@W01XO8`0D6A`061hN01DI600B5QD05ALD01HH
4`0D5Q406adH01dO700F61D05aTF01PJ5`0C5A8201LI5P0601HH5@0D5Q<051HC01@F4`0E5a@051@B
0P0F5Q@00`0E5A<04Q8@00l?3@0201<C4@0601DE4`0F5Q@05ADC01<B400C3`h050l>0P0C3`h0200B
40h04A0>010?3@0@40h05aLE01TI5`0<30X08b<Q0P0C4Q00100@3`d03Pd;010?3@0C4Q02014@3P05
010?3@0?3P`03Pd;00h=2`0?3A000`0>30l200l=400501TG6P0>30l02PP;01@B5@0F51L00`0?3A00
5P0>30l03@/>00h<3`0@3Q404a4D00h<3`0:20/02@L:00l=400D4QD05aLI00h>400<30h03@d?00X:
30061PP04a<E010@4P0=3@l01`L900<31@0;20X200l;300600h:2`0?2``03`/<010<3@0D41403PX;
0P0A3@h0300Z9RL020@500l;300?2``02@D600<0000:1PL07ATJ018>3`0=2@X03`/<00d92P8030P9
00`03@T:010<3@0>2P/030P900h:2`0@30d0510A01DA4P0>2P/040`=01<?400@2``5010:2P03018<
300@2PX03PP800803@L700d03`T900d71`0B30`03PT901<=3@0400003`T900P20P0=1`L0208200h8
200=1`L03`T9008030P70`0=2@P01`0>20P040L800l61`0?1PL03`D601061`0A1`P01P0@1@T700l4
20<040D90P0A1PX01P0B1`/040D900h31`0=0PH04@H:01dB5QCooooo000Kooooo`0:00/D50084100
41TG01<I60093`d03Q@B00dA400>4A003Q0?00h>3P803@d=00L0418A00lA400>40l03Q0?00lA400@
4Q403Q0?00@03a4@00@03Q0?014C4P0<3Pd030h=0P0@4Q402P0?4A003Q0?01DG5P082PT051HE00d?
3P0@4Q403@l<00/=2P0=3``2014C400700lA3P0:30T03@l<00lA3P0;3@X04A<@00T;2002010B3`0?
00`>2`0>40d04A<@00h@3@0@4Pl01`T601/M6P0H6QL0?T0m01<E4P0<3P/03@l<01<E4P0?4@h03@l<
0080418?00D03Q0=00d?300=3``03@l<00h@300200h@2`0300d?2P0<3PT030h900D03@l:00d030h9
00h?2P0=3PT0414<01@E400>3`X03@h9018C3P0@4@`02P/600d>2@0A4Pd03a0;0080414<0P0A4Pd2
010A300:00l@2`0B4`h04Q<>00/<1`0:2`H04A8=00L9100H6QD06Q`G00/=208030h900X02`d800lA
300C5A003Q0;00d?2P0A4`h03A0=00`A3@0>4@h03A4<0P0>40/00`0A4`h0418=010A2`0300l@2P0C
01<D3P0;30H03a0:01XK5@0B4`d03@h801PI4`0=3PX04a@>00l@2P0?40/04A8=01@E3`0@4@/04Q<=
014B300?40X05aPB00`=1`02010A2`0400d>200<3@L03Pl900/<1P807QlI02D03Pl901<D3P0=3PP0
30d700l@2P0D5@l04A8<00`=1`0@4@/04Q<;00l@200C50`051D?01<D3P0F5a404Q<>00d=2`0A4@l0
410>01@D4P0<30X03Pl:00l@2`0A4Pd04Q<>014B3@0?40/03Pl:014B3@0:2`H03a0;010A300?40/0
3@h901LH4`0720@03a0;008030d800L03a0;00`=200>3`X07AhI01HG4P0A4P`04A8;00803Pl700T0
3Pl9010A2`0A4P`04Q<>00h>300C4a405aLE01<C4@0@40d00P0@4@`02`0?40/03Pl:00h?2P0;30L0
5QLB00T:1@0A4Pd020T401LH4`0?40/03Pl:00803a0;0`0@4@`0300=3PT0414<018C3P0F5a8051D@
018C3P0@4@`04Q<>01@E400C50l04Q<>014B3@80414<00D04A8=010A300@4@`03A09014D3@0200lA
300800h@2`0_<B`030h900`>2P0@4Pd04aD@01LI4`0?4P/200h@2`08010B3@0A4`h04Q@?01<E400F
61<03Q0;03Li=00B50l2014C3P06010E4@0;40`041DA00/@300A5Q804QLC0`0@5A402P0A50l04AD?
018D3`0G6AH03a4>01XL6@0C5A8051HC014C400D5Q<2018D4@0;01@F4`0E5a@04aDB00`@3`0B5QD0
3Q8A00dA400B5QD041@C014E500B5QD00P0D61L06`0C5aH04ADD01DI600B5QD05a/J018F5@0F6aT0
4ALE01DN6`0@6AH05QlL01HQ7@0X<bl08B`X01hT8P0G7A/06b4O01<I5`0E6aT05Q`J01<I5`0P9R@0
3aDC01LM6`0@5Q@06R0N01DK6`0201HL708061hN02X06AlO01HL700J82006R0P01LM7@0F71`05adM
01TR8@0B6aX0;cPg01TS8P0L9RD06bDT01dY9`0G9R<052<P01TX9@0E924072/X020/;00I9bL08c4a
028`<00L;2/0830_06MgMP1RMG<0:C`j03A7A@0/?cd093Lf02Hj>@0X?3/0;D510355AP0aATL0<dU;
03Q@DP0lE5H0?5AG03UBEP0jDeL203aEFP0303eFF`0oF5d0@EYO0080@eaQ00H0?UML041IGP13G640
>U=H03M@E@0hDUH203A@D`0603A?DP0eCe40=4i?03M@DP0]ADH0>4e>0P0[@Cl0200/@T00:Clm0316
A00_AD<0:T0n02m5@`0gCD/0=4Y80P0hCT`02P0fC4X0>Dm=03I<BP0/@Sl0<DM403M=BP0fC4T0=de:
03eCD00hCT/203U?C080=Ta904L0>4i;03U=B`0hC4X0>De;03I;AP0aAT00<dQ103=8@00_A3/0<DHm
03=8?`0aASd0=4Xn0355>@0aAST0>e5503A9@@0gCDH0=Te704=IEP0mEE40=e1:03QABP0iDdX0>UA9
03I@@`0hDTH0>UA903]DCP0mEU40?EIC04IOG012FeP0DFYW076:QP16GeX0@U]E03mID010FE00@eYB
04IME@11Edl0=T]203U>A@0hCD<0@5A903mCB00gBd00?E5603Q=A@0`AC`0<DHm03U?@`0jD4@0>4i2
03eCA`0mDT/0?eA=03iBD00gBd`0=DU803iCC@0jCdP0?U=<03Y?B012Ee00?U=<03Y?B00iCTL0>Tm8
03]@B@0203aABP0O03iEB`0nDdX0>4e403E:@@0cAch0;T8i02m3>P0cA3`0=4Dm03E6?P0gASl0>DTo
03E7>00bA3H0;d4e02/l<`0/?CD0:3Tb02`m=@0X>C00:C/_03=5=`0`@S<0;3X^024[8P0T;RD08bdT
01dW7P0Q:b<09BlW079lM00202</9`0?01`U800P:BH08BdX05QWH00d@c`082lX01`[900Z=c0082`U
02@_:@0O:R@07bTS02Pa;00V;bX07RLS008082TV00X07RLT01`U8P0N9b@06B8O01/T8@0Q:RL07bPU
01PQ7P0K92406R<P0P0G81d06@0M8b<07R@T01`Q900H7B405AXN01lT:00J8BL072<Y01/R9`0A6A`0
8RX/01TR8`0C6AX06R0P01<I600G6aX05ATH01TK600G6AH04aDB01LI500C5A805QPE01LI5P0E5a@0
0P0F61D00`0G6AH05QPE01@F4`0201@F4`0301DG500B4Q005QHD00806ATG00D051@B00l?3@0G5aD0
51@B01<C4@0201DE4`0301<B400D40l05A0?0080510?00@04a4?018A3`0D4a405aLE0P0>3P`02@0K
6aT0ADE301<B400C4Q0040l=00h=2`0@3`d051<A014@3P05018A3`0300l=400>30l03@/>00803P`?
0P0?3A001P0>30l06QPK00d;3P0@3Q403P`?014?4P803P`?0P0A3a802@0>30l040hA00h<3`0<2Pd0
2PP;00d;3P0@3Q4040h?00h<3@0200`:2`0400h<3@0A3a0030X;01<A4P<03P`=00P03``=00l;300@
30d04@d>010<3@0?2``03PX;01<?40803PX;01`04`l@00T51P0?2``04`l@014=3P0B3Pl02`L800L3
100A3@h03`/<00h:2`0?2``02`L800`82@0?2`d04PdA01@?4`0@2`l02`H:00d8300>2@d03@P<00h9
3@0=20`030L;00d8300>2@X03`T90P0B30`05@0A2`/03`T900l92@0>20P03@L700l92@0@2PX030H6
00l92@0:1@D04P`<01D?3`090`<03PP800/51@0A2`/030H600l92@0=1`L02`D500d9200400`81`07
00`61P0@1`P03`H700l61`0?1@H040H70147200601052@804PL;00@04@H:01052@0?10P03P<70P0?
10P201052@<04@H:00D03P<701872`0B1`/03P<701872`0Dooooo`006oooool030042PP03Q@A010F
500;4@l03A8@01DI600C5aH041@C00lC4P0?4A003Q0?01DG5P<0418A00@03a4@00h@3`0<3Pd03a4@
0P0A4a802`0@4Q404aDD01DG5P0C5A@04Q@C00`>3@0:30/03@l>00/=300=3`h03Q0?00<03a4@00<0
3Q0?00h@3@0>40d01@0>40d06P0A4a003a4>00h@3@0@4Pl04A<@01XL6@0>40d030h;014C40021040
6adJ00/=2P0I6aP0S8j;02LY9P0B51403Q0=01HH5@072@H0418?018D4@010`003@l<010B3`0?4@h0
30h;0P0=3``0300=3`/00080010B3@0T9R80418=00h@2`0C5A001@L201XL5`0D5Q401`T401PJ5@<0
2``700`03a0;00`=200<3@P03a0;010A30092PD03Pl:00`=200T9B003a0;00d>2@0B4`h200L80`L0
3a0;01P04A<>010B3@0>40/030h900d?2P0>40/030h905UKEP1YJfH03@l:0043000i?CL03A<?00`B
400;4@h0318>01HK5`083@L030l800d@2@0A4P`04A8:010A2@0?3`L201<D3P0800`=1`0=3PP04Q<=
00X;1@0=3PP0414;00`=1`0:2`D200l@2P0500h?2@0@4@d00`@000X;1@0B4`d00P0>3`T300l@2P05
00h?2@0<3@L03a0:00/<1P0<3@L00P0A4P`0900;30H0414;00l@2P0=3PP03a0:014B300=3PP03Pl7
014B2P0?40P03@h8010A2`0E5Q006AXE00d=2`0;2`T04A4?00`<2P0D51804a@?014B3@0?40/03@h9
010A300B4`h0414<018C3P0=3PT0414<01@E400@4@`03Pl:00l@2`0>3`X030d800h?2P80414<0P0D
5A004`0A4Pd03a0;00l@2P0<3@T0414901HG3`0=3PP0414;00h?2@0?40/0410>01<C4@0>3P`03`l=
014B3P0@4@`04Q<>01<D3`0B4`h00P0@4@`03`0?40/061TD00h?2P0E5Q403@h901<D3`0J6aH03Pl:
00`=200E5Q404Q<>01@E400B4`h04a@?010A300201<D3`0E010A300C50l05AHA01LH4`0B4`h03Pl:
00l@2`082@@051D@00`=200@4@`03Pl<01DG4P0>40/03a4<01DG4P0A4`h041<<00lB2`062@807R0K
00803@l:00H04A<?04]=B00[;BP0418=01LI500F61<200h@2`05014C3P0E5a8051HA018D3`0A4`h0
0P0<4@/03@0>4`d03Q<?00lD400@5A403aDA01<I5@0>510041HB00dC3`0<4@d030h;01LI5P0>40d0
0P0B51408`0C5A803Q0=01<E4P0I6aP05aTF014C400C5A804QHE01`P7`0?4a804ADD00hB4@0O8b80
720O00`@3`0D61L03A4@01<G5P0E6AP051PG01<G5P0B5QD04aLF01LL6`0J81h06b@Q00hG500I8Ql0
>TE1079mN@0U<2`04QPF01TO7@0J81h05adK00806R0N00H06AlM01LM6`0@5Q@051XH01XP7P0G7A/2
01HL70805adM0P0E6a/0400L8R806R0P01`R8P0N92@06AlO01DK6`0J8b805b0O01DN7@0G8B0072HU
01lY:00J9R@06BPU01XY9P0K:RL201`[:00G01TU9@0H9RH07R`/02Dc<`0O;bh07Rh]020`;`0K;R`0
7C0^028e<`0T=cD09CPg02Lk>P0bATD0>De=02/o@00^@d@0=D]=03A<CP0gCe40<d]>03M@E00lEET0
0P0gD5D0200mEU/0?eQM045JG`11FUl0?UML03]DF@0lEEX0?eQM0P0fCe@04@0hDUH0<TiA035=D00b
CDl0=4i?03I@D@0eCTh0=4a<03=9B00Z@3h0:3hl02i4@P0Y?cd0;D=10357A@0_AD<0;TA20080<TQ6
00/0:T0n0398AP0]@d40<TQ60357A@0[@Ch0<dU603Y@C@0dBTL0=D]804AJE`0203]ACP1203Y@C@0h
CT/0=Ta903E;B00/@C`0AU]F03A9A00`AD00;44l0766P00^@c`0=da502a1>00`ASX0=D/o02a2=P0e
Bch0>Dm203iDB00hCdL0=Te604AJE`10FEH0?5EA03YCC@0jEDh0?UU@03iJCP12G4l0?UQ<03A>@`12
FeD0?EIA03aEDP17H5d0@U]H041IEP13G5P0@U]F03iGD@12G5<0@e]C049ID@0oETh0>e5903Q=A00j
CdH0@eM=04QLD@0[?c@0?E56061dJ@1=HUX0?U=:03Y?AP0hCT80>U1403mEB@0lDTH0AU]D03aABP13
EeD0=TY;03M;BP0mDT`0?U=<0P0oE4d203eBB`0W03aABP0fBd@0=DY303Q=AP0jCdP0>e1904IMD`0k
D4L0>4e403U>A@0dB3l0<4@k0396?@0]?SH0<44i041AB@0iB4409cL]03=5=P0a@cD093HY03Y;@@0d
ACd08S<[02`m=@0cA3X0>T`o03I8>P0]?bl0:CLY02dg;00Z=2T07RPN01PR6@0O:B00:38Y02@^9P0N
:2007RLQ00808BXU00h08BdW02Dd;@0R<BX06bXS01h]9P0Q;RL07RXT038m=`0R;BL07bTS05MPF`0Y
<Rd07bPT01lX9@806R<P0P0L9B800`0V;b`08b`Y020Y9P02020Y9P0>01hW900I7al04ALG024W9`0=
5AL0A4a>049:C00K8bD06B4S018J7@0K82@082DY01/P900I8B<201@M700501/Q8@0M8b404QPF01`P
7`0D6AD00P0A4a00100W:BH04aDB010B3`0E5a@201TK600@01XL6@0E5a@04aDB01DG500F61D05ALD
018D4@0?4@h061PF014A3`0E5A<04Q8@01/K6@0J6QP04A4?01<C4@805ADC00@051@B01<B400B3Pd0
5A0?0P0E4A00500C4@l040l=01DD4P0D51800P8001PH5P0B4Q00410>00`;2@0F5A<06aXH01PG5@0A
40h03Pd;01DD4P0C4Q0040l=00l>300920H051<A0P0?3A0200d;3P803P`?00D040hA00d;3P0>30l0
5A<F01<A500200d;3P0=00h<3`0A3a804@lB018@4`0F51L04@lB01<A500A3a802@L:00H41`0<2Pd0
40h?00h<3@0500d;30803P`=0P0?3@h0100@3@h040`=00l;300>2P/200l;30803PX;00<040`=018>
3`0@30d00P0>2P/200l;300@00h:2`0=2@X03@T:00P51@0J5QL06ADF00/7200D41400`0001@?4P0@
2`l04PdA01@?4`0B3A4040/?00l:3P803PT=01@03@P<00`72`0<1`/03PT;00`61P0@2PX04P`<00d7
1`0>20P04`d=00l92@0;1@D03@L700l92@0@2PX030H6010:2P070P805@l?00X410L03PP800L04Ph=
00h:2@0:1PD03`/:01<?3P0>2@T040L800803`H700T03`D601061`0A1`P09AXN01@93@0J41<01`00
01H;3`0;00@01P0?10P201462P0400l4200@1@T04@H:00h31`H040D95?ooool001_ooooo00d02a8;
00hE3P0?5A403A<?00dB4@0?4a804aLF010D4`0?4a803a4@00h@3`0E5aH03a4@00@0418A0P0>40l0
1`0?4A003Q0?00`>3@0=3`h03a4@00d?3P0@4Q400P0<3Pd00`0?4A003@l>00d?3P0200h@3`<03a4@
1P0?4@h02`0:30T03@l<010B3`0B51403a4>00/=2P0?4@h02P`902<U8P0:2`T05QPE0080418?00/0
10H304I8A@0:30T04A<@00lA3P0620D07b4N01HH5@0B51408bDR00d?3002010B3`0@00d?300@4Pl0
418?00lA3@0>40/07b4L038d;`0N81/04Q@?00`>2@000@007b4L030b;@072@@030h9014B3@8030d8
00l0414<00h?2P0?40/0414<014B3@0<3@P03a0;018C3P0/;BP051D@00P9100=3PT04Q<>010A300E
5Q401P0?40/04P0A4`h0418=00h@2`0=3`X03Q0;010B3@0<3PT0>3Xe04]=B00D5Q4020X500`?2`0<
4Q0000P5010H5@073@T04ALC00T>20803Q4:00H03a0900l@200?40P0410800h?2@0=3PP200h?2@06
00l@2P0C50h030d7014B300=3PP030d70P0A4P`03`0S91h03Pl:01<D3P0G618010D0018C3@082@<0
2P/500d>200@4@/04a@>01DF400A4P`03@h800l@2P0201<D3P803@h800`0414;00l@2P0?40X04Q<=
014B300=3PH0414900l@200=3PP03a0:018C3@0>3`X200h>300;00l?3@071`D04A4?010A300?40/0
3@h900/<1`0=3PT03a0;018C3P0A4Pd00`0=3PT07P0;30L04A8=014B3@0@4@`03a0;010A300B4`h0
3@h900h?2P0=3PT030d800l@2`0A4P`061TB000100061`004Q<=01dN600<3@L03Pl:00`<2P0A4@l0
3`l=00d=2`0>3`/03a0;010A300A4Pd0414<00l@2`803Pl:00/061TD00h?2P0E5Q403Pl:00l@2`0>
3`X03a0;01HG4P0D5A003@h900h?2P02018C3P03010A300C50l04Q<>00803Pl:02004A8=018C3P0@
4@`03@h900h?2P0=3PT05aPC01@E400`<B`0;2dX014C3P0?4@`05QPC01dO6P0F6A803a8;01DH4@0?
4P/0MGMb06maK00I6aH04Q@?07n1O01BE4l05aTD00L910092`H051HA00lA300A4`h051HA018D3`80
4A<>0P0@5@l01P0?50h03Q<?00dB3P0=4Ph010X600lE4@8041HB00X051XF01DK5`0E6QH04A<@00lA
3P0G6AH0418?01PJ5`0C5A803a4>0P0@4Pl00`0G6AH092HS01TM7002010D4`0;01@H5`0J7Qd05QXI
00D9200J7Qd02@d<01LK6P0E6AP061`K01LK6P0E6AP00P0C5aH05@0E6QP05adK00PA3P0F7a`0:c@a
086<R03]mo@0IW5]030f=00J81h08RPV01HL6P0L8R00318@01LM6`0F71X04ALE01@J600H7Q`05A/I
01HL700301LM7@805Q`L00<05adM01HL700J82000P0O9BD02`0N92@0:34`028[:P0N9bH072HU01hX
9`0O:BP062@R01LV8`0H9b@06BPU00806RTV01P082`/01d[:`0R<300:CLg02@d<`0O;bh07Rh]01lb
<00T=cD09CPf028e<`0Q=C<08SHe02Pl>`0bATH0:Sho02]0@@0`ATP0;DE702m7B@0`BD`0<DY>03A=
D@0fCe<203QAEP0F03I?E00lEEX0@EYO045JG`0jDeP0>55F03iGG00jDeP0=e1E03IAE@0cCe80<TiA
035<CP0bC4d0<de<03=<B`0bBTX0<TQ602e3@@0_AD<0>Dm=0316A080<dU700l0;D=102Y0?P0]@d40
<TQ603M=B`0jD4h0=de;02To?@0bB4H0;TA103A:A`0iCd`0=D]803A:A`0mDe000P0iCd`0=@0jD4d0
>Dm<03M=BP0dBTL0A5UD02@i=00aAT40>Di902i3?P1QMW40>Di903M<A@0aASh0;48f0398?00^A3P0
=T`o03E;?`0jCdH0>E1803Q>BP0oEE80?UMD03]DD@0jDdl0>eI?03aGC`0kEd/0AEmD045KC`0gDDH0
@eaF03iGD`0mEU<0@5UF04AMFP15GU/0@eaH045JE@10FE<0?UQ?03mHC`10Edl0?UE=03aBB@0iCTD0
?eA;04EIC`0_@cP0<THk03Q<@@10E4T0@UM?0080>4e40100>Dm303Y@A00nE4P0AE]?0397@01;H5T0
=d]902m3A00kCdh0@EI@03mDC@0nDd`0?eA=041ECP11ETl0>Tm80P0fBd@01@0jCdP0?55:03aABP0n
ED/0>Tm60080>Di500d0=DU00355?00_@cX0;Slg0352>P0oD4P0>TU202`l<P0[?Bh0:cd_02Tk;P11
DTP0?e180080:S/c0140<44g03E7>P0a@cD0:cd]02Le9`0X<RL09S0U01hX7P0H8QT06bDL028/8`0R
;2@082XR024[900U;RT09RlZ02Da:`0202Dd;@0A024`:@0U=2d09c@]028^9`0T;bT05B0J02/e<01/
MG00@4U402Xc;`0X<Bh08BXW01hW900M9R<072DR01lX9@0N9b@00P0L9B802`0K9240624N01PN7P0S
:BT051XJ0418BP3;dmD0Z[:c018J700I8B<07BDX008082DY00L08BHZ01DN7@0F7a`04Q/I01@J600R
:2H06R0N008051TE00<06Q`I01`N6`0F61D00P0E5a@201TK600601PJ5`0K7AX06A/H01HH5@0E5a@0
4aDB0`0B5140200G5aD04Q8@01PH5P0E5A<07AdK01XJ600B4Q004a<A0P0D5180100C4a404a8@01<?
3P0E410201HB4@0<01@A400A40h03`h<01hN700E5A<05QHD00d=2`0F5Q@03`h<01DD4P0F5A<04a8@
0P0A40h0800;2PP03`h<01DD4P0M71X03`h<014@3P0@3Q404Q0C010>4@0?3A004@lB018@4`0E4aH0
71XM01@B5@071@P040hA01/I700D4QD0108500d;3P0>30l02@L:010>4@0610L03@/>018@4`0C4A@0
40hA00l=400@3Pl03P`=0`0=2``0100>30d03@/<00d;300=2``200h<3@0800l<3@0>2P/03PX;00h:
2`0?2``040`=00l;300>2P/3010<3@803PX;0P0?2``00`0>2P/03@T:00d92P0201HB4`0;00L31006
0P<01P8300T51P0<20X030L;00h93@0?2Ph03PT=00`72`0=20`00P0>2@d05@0=20`030L;00`72`0>
2@X03@L7010:2P0B30`03@L700l92@0@2PX03@L700`61P0>20P03`T900d71`0400004`d=01H@4004
000081XJ00`71`0600d71`0300`81`0C3`h04@d<00800`0000`040X:0107200?1PL03`H700l51P0@
1PL04@L800T00P0N4aL0ACXn00l4200;0P@800l4200400d21P0900802`0400l420L040D95?ooool0
01_ooooo00L04QL?00lE300>4`d041D@00hB40093@`04ADF00803a<D00D03Q8A00`A3P0B5a<03a4@
014C4P03018D4`04014C4P0?4A00418A00lA40803@l>00@03Q0?014C4P0D5QD04A<B0P0?4A001@0<
3Pd03Q0?00h@3`0>40l03a4@0080418A1P0@4Pl06`0=3``030h;010B3`0B514030h;00T;200D5Q<0
10H302DW900@4Pl05QPF00lA3P0>40d03a4>018D4@0?4@h030h;01`N700?4A004aDD00`>3@0O8B00
<38a010B4@0B51<04A<B00d?3P0200lA400600d?300B50l03Q0;00lA300>40/02@/60P0<3PT02P0:
30L03Q0;018D3`0>40/04A<>00l@2`0>3`X0414<00l@2`0B4`h201<D3`0:00l@2`0:2`H03Pl:01TJ
5@0>3`X04Q<>00/<1`0A4Pd0414<01@E40H03a0;01T03a4<00h@2`0=3`X03@l:00h@2`0A4`h0418=
00`>2@0B50l02@/600h@2`0J7AX0A4e:04aFE@0[=C<01Pl;00@=200<4`d03a<<00lB2`0>3`L03`l6
00l?1@0B4PP03Pl800804A8<01803@h800l@2P0B4`d030d7010A2`0<3@L02``600l@2P0>3`T020T3
010A30020`002``6018C3@092P@05aPB01@E3`0?40X300d>2003010A2`0=3PP03Pl900804Q<=00<0
3Pl900/<1P0?40X00P0<3@L00`0B4`d03@h8010A2@0201<D300:018C3@0@4@/0414;018C3P0@40h0
3`l=00h>30071`D04Q8@00l@2`804A8=00H03a0;00h?2P0?40/03Pl:00`=200@4@`200l@2`0I01<D
3`0@4@`0414<00l@2`0>3`X03a0;014B3@0K71L05AHA010A300>3`X04Q<>01DF400@4@X03Pl7010A
2@0>3`T06a`F00h?300>3`X030`:014A3`0>3P`02`/900d>2P0200l@2`0?010A300?40/03a0;01HG
4P0L7AP09RLR01@E400C50l02``7014B3@0B4`h051D@020Q700H6A@03a0;00804A8=00D04Q<>00l@
2`0B4`h04A8=00l@2`04014B3@0H018C3P0F5a805QLB01<D3`0<3@P0:b`W024R7@0>40d03@l<010B
3@0B5@h041<<00d@1`0520406QdD04mBB`11@ch04Q@?010B3`0F61<03Q0;010B3@0J71L05QPC0P0@
4Pd01@0A4`h04Q@?010B3@0@4Pd04Q@?00803a@=0`0?50h0=00>51004aTE014H500D7AX04a`I01<M
6@0<5A805Q/G014C400L7Q/09RPU01<E4P0E5a@051HC00lA3P0@4Pl04Q@A01TK600T9R<061`K01HJ
6@0D61L04QHE01@H5`0E6AP03a<B034e=00B5QD06alN01TM701dN7L06QhM01LK6P0C5aH04QHE01<H
5P0D6QP05AhK01XS800L9B80G6MS0:>^ZP0[=S806R0N04iDDP1fO7X05Q`J01DK6@0F71X05A/I01HL
6P0E6aT201HL6P0301<I5`0G7Ad061hN00806AlO0`0H7Qh00`0G7Ad061hN01hT9002024W9`0702@]
;00O:2L06b@S01TS8P0K9B@072HU01XV900201TX9@0<01/Z9`0L:bP072/X01dY:@0I9bL072XZ024_
;`0P<2l08C4`028b<@0O<S008cHd0P0V>CL0I@0V>CP08CDd02<g=P0/@400:cm002]0@@0cBD/0;DE7
02m7B@0jDeH0=4eA035:CP0eCU80=TmD03M@E@0dCE80>E9G03eFF`0nEe`0>E9G03I?E00kE5T0?5EJ
03M@E@0dCe80=51A039>C`0aC4d0<4Y:031:B@0aBTP0<DY70316A00]@d00<4I303Y@C@0cBDL0=4Y8
03=9A`0]@d40:d4o0357A@0jD4h0<DM50398AP0hCT`0=D]903A:B00/@Sl0;TA103=9AP0gCDX0>4i;
03M=BP0dBTL0=Ta903Y@C@0kDDh0>4i;03A:AP0dBD<0Ni2905mdK`0bAT@0<DE303=7A@11EE80;44k
03Y?A`0bB3d0=4Xm02a2=@0eCCl0<TXn03M>A00kDT/0>e=>03YCD00mEU<0?5EB03aFDP0nFE<0>eQ@
03QEBP19HeP0AEmC041JC`16GeT0A5eI04=LF@12FeP0C6ER04mXI@19HUh0AEiI04QQF`0oFE00@EUA
045HD010Edl0?eE=0080?eA;03T0?E5703Y>@`0fBSl0>dm303iBA`0hCDD0=4U003Q=A00lDTH0?E=7
041FBP0oEDT0>e19041ECP13EeD0LhN805EYJ00nDdd0>e1903U>A`0jCdP0?E9;03iCC00iCTL0>4e6
03Y?B00nDd`0?E9;03]@B@0iD4H0>Tm603U>A@0dBD00<4@k02m3>P0[?cH0;d0h0393>`0hBD40=dHo
0351=`0/?S009cT[02Xl<00eAS`0<T<k02Xk<`0/?CD0;d0g02i0=00Z?2h0:S`]02Xh:@0W<R@092hS
024[800P:Ql00P0N:1l04`0Q:b808bdU028/900R;2@092hV02<_:00R<BX093</02He;P0W=Rl0:3D^
02<_:@0T;bT09C0Z020Z9@0Z<bh07BHQ01dV8P0R:bP00P0L9B8201dV8`@07bPU00P07BHS01TQ7`0R
9bT051PK030e>00W;c40OXJ806I`L@80628S01@0620R01/P8`0K82<07R<U01DM6P0D7AP06B8N01LM
6@0U:bL05adI03]0?01fNgL071hK01/M6P0B51406Q`I01TK600K7AX05aTF01<E4P805ALD00/061XG
01DG500B51404Q@A01<E4P0D5Q<05QHD014A3`0F5Q@04Q8@01TI5`0201DE4`0701@D4P0B4Q004Q8@
01<C4@0E51805A4@01HA400201HB4@0G01@B400C4Q004Q4?00h=2`0E5A<05QHD01@D4P0<30X04a8@
018A3`0@3`d03`h<010?3@0B4@l04a8@010?3@0E51806QTG00`;2@0D4a4040hA018@4`0C4A@00P0?
3A0201<A500C010>4@0B41<04Q0C00`:3@0;2@`03P`?018@4`0?3A0040hA018@4`0?3A00518E00T7
2P081`T03`d@018@4`0>30h04Ph>010<2`0200l;2P03010<2`0A3@`03PX900803PX90P0?2`X01@0@
30`03`/<00l;300>2P/03`/<008040`=0P0?2``00`0>2P/03`/<00l;300300l;300I00h:2`0=2@X0
3@T:01@@4@0:1PL04Ph?01<?400?2``03PX;00d92P0<20P03@T:00h:2`0=2@T030P900d92@0>2PX0
3PX;00d92P0<20P030P900h92@0>20P040X:014;2`0200l92@8030H600X03@L700h8200>20P030H6
010;2`070P8040/;02@O7`1jM7@04@`<1P0<1PH01`0C3`h02PH500/71P0<20L03`/:00d71`0@1`P0
0P0?1PL02@0?1@H040H70147200@1PT04PL;024G6P0;0P@04`P<01462P0701052@0501872`0F2`l0
5@X>01052@0?10P01P0@1@TDooooo`006oooool03P0<4PH03aD:010E3P0>4`d03A8?00hB4`0>4QD0
3A8C00lE5@0=4a402a4>014F4P0?4A00418A100B51<03@0?4A004A<B014C4P0@4Q404Q@C01@F5@0B
51<05QPG014C4P0>40l03@l>00X<2`0?4A000P0>40l00`0?4A004A<B014C4P06010B3`0O018D4@0>
40d03Q0=00X<2@0A4a007AlL00l@3P0I6aP05ALD02`^:`3@d/l0IVQU00lA3P0F61D00P@1014C4006
20D06A/I01LI600:30/030h=00T;2P072@P05aTH014C4P0@4Q403@l>014C4P0C5A@02`d:01<E4002
018D3`0:01DG4P0<3PT051HA010B3@0620<04Q@?0001000L7QT0@dE0014B3@803Pl:00d030d800h?
2P0@4@`03@h900h?2P0@4@`051D@00d>2@092PD04A8=00h?2P092PD03Pl:00L03a0;01D030h900/=
200;3@P02`d800`>2@0?4@`03@l:00P:1@0C5A0061XE00`>2@0O8Qh0`<[90=?Og@0P;2T041/G00/D
3`093`X02a0900d@2@0@4@T00P0A4@L06@0?3`@03Pl701XK5@0B4`d030d701TJ50072080414;01@E
3`0?40X030d700d>200:2`D03a0:00X;1@0>3`T05AH@00X;1@0G61804A8<00l@2P0=3PP03Pl9014B
300D5@l00P0=3PP0100>3`T03a0:010A2`0=3PP2010A2`0500`=1`0D5@l07QlI00l@2P0A4PX00P0B
4`/02P0B4`d0414;00d>200?40/02PX800d=2`0F5Q@02@T700`<2P0?40/2018C3P80414<01004A8=
00h?2P0;30L030d800X;1P092PD030d800h?2P0?40/03Pl:00`=200>3`X0414<01PI500D5A00414<
0P0:2`H03@0<3@L04Q<<00h?1`0C50`05AH@00P90`000@004A8=01<C4@0B4Q002PX800`<2P0A4Ph0
0P0A4Pd03`0@4@`04A8=014B3@0>3`X02``701PI500=3PT04a@?00l@2`0B4`h04a@?00P9100A4Pd0
3a0;00<40002018C3P0:01<D3`0@4@`04A8=010A300B4`h05QLB01DF4@0C50l04Q<>01<D3`808b@O
01L06AXE018C3P0?40/030d8014C400B5140418>00hA2P0@4``04QD;01DH3@031P002`h800h@2`0A
4a004aDC020R7@0J71L04Q@?00h@2`0=3`X04aD@00lA3002010B3@803Q0;00@04A<>00lB2`0@4``0
3a@=0P0@5@l09@0@5a004AXE059KEP1[MG805b4P010J6@0>6AH02@h:01PJ5`0G6AH07AlL01DG500@
4Pl04A<@010B3`0F61D05aTF01@F4`0E5a@02`l>01@H5`0P92<0GF5P03Pl>`0=4A008RHU010D4`0H
71/06QhM00P<2`0T:2L061`K01DI600C5aH04QHE01DJ600F71X00P0I8Ql02@0N9b@06bHR024/:00Q
;2P07bDS01LM6`0K8Al04QPF01lU8`0201HL6P0701LM6`0I7ad061hL01HL6P0E6aT05adM01PN7P04
01TO7`0?01`R8P0K8B406R0P01XP800L8R807B<S01dV9@0K92<06R<R01/U900N:2L082XY01`X9P0J
:BH06bXW00<07B`Y00D07b/[01/Y:@0L:RX07bd]024a<00202@d<`0F01lb<00Q=3809CPf02Pk>@0V
>SP09CTh02Pl>`0[?cl0:Cdn02e2@`0dBd`0:T9402]3A@0jDeH0<DY>02a5B@0aBTl0=TmD03UBE`0f
Ce@0>E9G03YCF080>E9G00D0>U=H03QAEP0fCe@0=TmD03=>D@02035=CP03035<C00aBdX0<D]:0080
<4U600D0<TQ50316@`0_AD80;dE20316A0020398AP1B02m5@`0aAdD0>Dm=0398AP0oEE<0MXb:03E;
B@0iCdd0;D=103=9AP0bB4D0=de:045GE013FEH0?E=@03=9AP0fC4T0>U1=03]ACP0iCd`0=4Y603eB
B`2<XIP0IW]e049FE00aAD<0I7Qg06n3P@11EU40>4e502a1>00hCT40>Dm2039:?00hD4@0?5=903]D
CP0nEe<0@5UF03iHE`0oFEL0@5YG03mLE`0lFU80=eE;03eGC00jE4P0?5I;03eFD012FeL0@eaI04AM
FP16Ge`0AEiK049KE`11FUD0@U]E04ANE@13G5<0@UUA041GC`0oEDd0?eA;049GCP17G580>4a104=G
C01bQW/0?E5603]@B00eBT40=da303U?@`0kDDD0?UA804iTF01AIUl0>Tm803a@CP1_Ph@0=TY903mD
CP<0@5E>0P0oE4d08@0lDDX0>e1903eBB`0nDd`0>Di703I;A00hCdD0=da303A9@00_A3/0<4@k0396
?@0Z?SD0;d0h0352>P0^?cL0;3/d02dm<`0Z?2l09SP/0311=`0hBD40>4U303=4?P0^?cL0;Chf02Xk
<@0V>2`09cT[02Pf:00R;Al06RDG01TT5`0201dW700E01dW7@0Q:b808bdT024[8`0O:B408B/S028^
9P0O;RL08S4Z02He;P0S<R/08RlX02Lc;@0V<B/07BPR01LQ6`0@6A@06R<N01hW8`0T;BX07BHS0080
72DR02006b@Q01hW900M9R<07RLT01lX9@0M9R<0620N01XN8@0P8bP0>Ce100hF6@0U;C00:C@e01XV
9P0N:2T07RHX01LL7`0G6ah0<S@g02D[9`053`L04Q`D01HM5P0I81T05A/G01HK5`0Y;RX06adJ0001
000Z;2T07b4N01@F4`8061XG00@05QPE01PJ5`0E5a@05ALD0P0F61D04@0E5a@04aDB014C400M7A/0
4a<A018B400<30X04a<A00l?3@0F5Q@051@B018B400A4@l04a<A01@C4@0E4A005Q4@00805A4@00T0
518@01<B400A40h05aLE01HF500820H02`/9010@3P0A40h0100@3`d200h=2`0E00/:200F5A<03`h<
018A3`0c<S00518E010>4@0B41<03P`?00d;3P0B41<020H9014?4P0D4QD02PP;00d;3P0I5aX04@lB
00h<3`0<2Pd03@/>00803P`?00<0B4I902HT9`0E4aH00P0@3Q401@091`P04@d=00l;2P0?2`X040`;
00804@d<0P0=2@P200h:2@0500l;2P0A3@d04Ph?010<3@0?2``00P0=2@X200h:2`<03@T:00D03PX;
00l;300?2``03`/<00h:2`0200d92P0T02DQ8P0K5aP05a<D01/G601IEEH03`/<00/71`0>2PL03`/:
00l;2@0?2`P03PX900h:200>2PL03PX900d91`0<20D030P700d8200?2@T040X:00l92@0@2PX03`T9
00h8200=1`L02`D500T30`0:10@03PP801PB4P0N61P040X:00@0000G4A402`H61P0>20P01`0<20L0
0`0001XF5@050@003@T800/51@0@1`P00P0?1PL01`0?1@H040H70147200A1PX050T=01D:3P070000
0P0=0PH601052@0600`11@0=0PH05@X>01<8300>0`L04`P<1P0@1@TDooooo`006oooool03P0:4080
3aD8010F300>4``03Q8@014E5P0=4A@0314B00lE5@0=4a402a4<010G400?4A00418A0`0A4a800`0@
4Q403@l>00lA400200lA4004014C4P0C5A@03@l>014C4P803@l>00<03Q0?00`>3@0@4Q400P0>40l0
0`0?4A004A<B018D4`0700lA3P0G00d?300>40d02@/801HH5@0X:RL08R@Q01/M6P0?4@h02@/906]]
JP0N81d030h;01DG500:30T0418?00@60`0C5A<01PP701@F5@0n@3l0<38a010B4@082PT00`0?4A00
1P0G6AP06adL010B3`0:30L02`d800X<1`8030h900h020X500T;1P0@4Pd08B<N0084000:30L0:R/V
00l@2`0=3PT03Pl:00/<1`0<3@P04Q<>00h?2P80414<00@03@h900D60@0P8A`0414<0P0>3`X00`0C
50l04Q<>00l@2`0500l@2`0700d?2P0<3PT02`d800/=200<3PT03a4<010B3@0200d?2P0H01/M600:
30L03a8>05iXI`2CWil031PF018M6@033PX02Q8<00X?2@0;40T04A89018B200A4@L03`l400/<100G
61803a0:00h?2@0N7aT02@X401<D3P0H6A<04a@>0P0@4@/0100<3@L02P/501DF400;30H200d>2009
01DF400=3PP030d700d>200?40X04a@>01DF400>3`T0414;00<04A8<00P0414;00`=1`0>3`T02@X4
018C3@0O81X03a0:00l@20803Pl701D03a0:00h?2@0;30H02``700`<2P0G5aD092@R014A3`0>3P`0
3@h900l@2`0>3`X03@h900h?2P0@4@`02``700h?2P0=3PT04a@?01TJ5@0G61<00P0A4Pd01`0@4@`0
3a0;010A300B4`h03Pl:00l@2`0>3`X00P0<3@P07`0=3PP03Pl801DF3P0E5Ph04Q<=00P90`0Y:R@0
5QLB01@D4P0B4Q0030`:00h>300C4a004Q<>014B3@0@4@`04A8=018C3P0?40/02P/601@E400<3@P0
5AHA00l@2`0A4Pd05AHA010A300F5a8061TD00h?2P0B4`h00P0D5A001`0A4Pd04Q<>014B3@0B4`h0
5AHA01<D3`0A4Pd00P0?40/08@0H6A@05AHA00l@2`0B4`h020T400d>2P092`X03a4@01@F4P0A4`h0
4A@;00d@1P0G6Pl00`H001HI4P0?4@h06Q`I00lA40072@H02P`700lA300@4Pd03Q0;00d?2P0>40/0
3a4<010B3@0>40/03@l:00lA300D5a004aH?014F3`0200lD3P0D00dD3@0P:B@0VZ>N0;O2_P0H8R40
3ALF00/F5@0:3Pd05aTF00/=2P0>40d04Q@A01<E4P0D5Q<03Q0=014C400D5Q<05ALD01TK600;3`h2
010D4`0J04Q<B`0[;bh04QHE014E500>4Q407b<R01TM700T:2L03Q8A01HJ6@0D61L04QHE01<G5P0F
6aT061hL020Y9P0[=3409Bh[01DP700=61@06RDQ00H<2P0K8Al07bDS01`R800F71X301LM6`0701/Q
7`0I7ad05Q`J01PN700F71`05adM01PN7P0301TO7`0701XP800K8B406b4Q01XP800L8R807R@T01`U
900201XS8P0601XT8`0L9RD07BLV01XV900H9b@06BPU0P0K:RL01P0L:bP07b/[01d[:`0N;2`082h^
020`;`808C4`01H08C@b02Lj>00X>cT09CPf028e=00U>CP0:Cdl02Tm?@0Y?Ch0;D930398BP0[@dD0
;DE703M?DP0`BDd0;DI:03A=DP0jDeP0>55F039;D00gD5D0?5EJ0P0iDUL01@0kE5T0=TmD03A=DP0e
CU<0<Te?0080<De>00D0<di>039<B`0bC4T0<4Y70319AP0203I<B@0303E;B00bB4D0=4Y80080=Ta:
0P0cBDL203Q>C00=03mED`1WOG/09C/i03U?C@0`AT@0=de:03E;B00hCT/0?eEB041FD`0hCT/0=Ta9
03Q>B`0203]ACP0O03U?C00eC4L0=da503Q=A00nDd`0=DU702Tm>`1=HF00DfMU03E9A`0dBD80=D/o
03YA@P0gCSh0<DTk03]CA`0nED/0?EI@049KEP13G5T0@5YI041JF011FeP0@5eH03eKE00hET`0?5I;
03YDB010FTl0?EI@04MPF`0204QQGP0O04MPG@13G5T0@EYF041IE010FE<0@UaC045JD@0nEDd0?EA<
03aBB@0lDDP0<TLn0355>`0^@SL0@5A9049FB`15FDh0>e1803A9@00fBd80=de103Q>@P0lDTH0=4Xn
02Pm=P14FE80=d]904iRH`13EeH0?E9<03mDC@02041ECP0403eBB`0lDDX0?E9;03]@B@80?55:05L0
>4e603E:@`0eC480<TLn0356?@0cB3l0=TY103M;@P0]@CP0;d0h0311>@0[?3@09cH_02Xj<00Y>bl0
:3T_02m0=`0iBT80>T]503=4?P0[?3H0:CXd02Xk<P0Y>S009cT]02Pf:00T;b407BPJ01XU600O:Ah0
8B/P024[8@0Q:b808R`S028/900T;RH09S0X02Hb:`0Q<2T08c8[02Lf;`0R<BX082dV01l[9@0S;RP0
7bXT02H`:`0X<B`0@da7034j=P0J8b005b0M01`U8P0Q:RL09Bh[028[:00Q:RL082TV024Z9`0O:2D0
72<R00lC5P0];S<06AdR020X:`0P:R`0Ef=S01XV9P0Q;Bd072DV00lD5`0/<3<0VYbO05AJEP0J91`0
5R0H018I4P0A61404aTE014F4P0^<bl05ALD02T[:00^<2d03a4>00d?300B51400P0D5Q<0100G6AH0
5QPE01@F4`0F61D201LI5P0;01<E4P0@4Pl08B4O01LG5@0E5A<03`l=01@D4P0@40h05QHD01DE4`0C
4a400P0B4Q000`0C4Q005A4@01D@3`0201<?3P0801<A3`0C4Q002`X800d<2P092@L06ATG02<S8@0@
40h2010?3@03014@3P0B4@l040l=008030/901h040l=01dL6P0@3`d03`h<02h]:`0L6Qd03`d@018@
4`0A3a803P`?018@4`0K6A`040hA018@4`0@3Q403P`?01@B5@0]:bh00@0200h<3`0A3a801P@7018@
4`0<2Pd00P0300400P071@P03@/>00/92P0@30/200l;2P03010<2`0A3@`04Ph=00<03PX90P0?2`X0
100B3Ph04Ph?010<3@0?2``500d92P0400h:2`0=2@X03@T:00h:2`803`/<00X03PX;00d92P0=2@X0
3PX;00d92P0M6AX0;RX[071/K@0I5AH03`/9200>2PL0100=2@H030P500`81@0=20H2010:2P0?00l9
2@0A2`/03`T900l92@0>20P030H600P20P0:10@040X:00@0000:10@040X:01/E5@0400004@/;00H0
3PP800L02@D402TU901oNgX0:BDT01HB4@0?2@T040L800803`H700T03`D601061`0A1`P03@8601H;
3`0D2@d02`0401052@0D2@d01`0A1PX01@0<0@D03P<700h31`0C20`09AXN00H040D95?ooool001_o
oooo00d04QD800hA1P0?4PX04AH@014E4`0;3a00310C00`A4P0?5AD03Q@B00/A300@5Q003a8A00<0
418A00l03a4@00d?3P0?4A00418A00lA400=3`h03a4@010B4@0C5A@051HE00lA400>40l04A<B010B
4@0A4a800P0>40l00`0?4A004Q@C01<E500600lA3P803@l<01D04aDB00h@3@0>40d06A/H010B3`0>
40d04A<@00lA3`0>40d0418?00h@3@0?4@h04Q@A010B3`0?4@h02`d;00X<2`0K7A`05aTH00/=300E
5aH00P0?4A001P0>40l02`d<014C4P0D5QD051HB00P:1P80418=01X02@/601<E400?4@`04A<>00`>
2@0:30P030h900/=200>40/02``700/=200@4@`03a0;010A300C50l01`P4010A300=3PT02P`701PJ
5@2BThh0AdQ3018C3P0A4Pd03@h901@E40H03a0;02X04Q@?014C3P0?4@`03@l:00h@2`0@4Pd03@l:
01<E40092`L0418=00/=200=4@`0318@010L70094a404AXG00H=2@0<4Pd03Q8<00hB2`0?40L03`l5
010@100B4@L0414900d>200B4`d04a@>00d>200B4`d030d701<D3P0A4P`03a0:010A2`0>3`T04a@>
02TZ900A4P`02``6010A2`0I6Q@400l@2P0500h?2@0=3PP03@h800l@2`0@4@`00`0@4@/04P0E5Q00
824K018C3@0=3PP051D?00X;100B4``03a0800h?200A4P`04a@>014B300?40/030`:010@3P0H61H0
3@d;018B40803a0;0P0=3`X0200@4Pd051D@010A300G61<030d801HG4P0N7aX051D@0P0@4@`0100?
40/03Pl:00l@2`0A4Pd2010A300400l@2`0=3PT0414<018C3@80414:01`01@H1018C3@0^;bT0UiRB
01dN6@0;2`T03`l=01<C4@0A4@l0414=014B3@0?40/03Pl:00l@2`0A4Pd051D@010A300F5a803Pl:
01TJ5@0>3`X04Q<>00L80`0F5a803a0;01TJ5@0Z:bH0414<0P0F5a801@0C50l051D@018C3P0?40/0
414<00804A8=01L0414<00l@2`0>3`X0414<00`=200>3`X04A8=00l@2`0;3@`04Q@C018D400=3`T0
41<;010C2@0;3P@041<900lB2`0:30P03a4>010B400A4a004aD@014C3P0200lA3005010B3@0;3@P0
3Q0;014C3P0@4Pd00P0>40/00`0B5@h04QD=010E3P02010E3P0I010F3`0@61<0;cLb04I@C00=6AH0
5B0M00XD4P0B5a@04Q@A01HH5@0O8Ah04Q@A01<E4P0E5a@04A<@01DG500H6QL05aTF01HH5@0F6QT0
3a<B01<G5P0<40l05ATH018F5@0201@H5`0O01LK6P0>4Q405ATH018F5@0G6aX05ATI01<G5P0C5aL0
5Q/J01LM6`0A6AL06b<Q010I5P0B71T05AlK01HP7@0M8b405adK010F500I7ad041HD01/Q7`0G7A/0
5A/I01TO7@0G7A/05A/I01PN700D6QX05Q`L01LM7@0301PN7P0301XP800N92@07R@T00806b4Q00l0
728R01LP7`0G81l05b4P01TS8P0K9B@072LU01/X9@0J:BH06bXW01`[:00M;2T07B`Z01`Y:@0M:b/0
0P0M;2`0:00M;Bd0830`024a<@0O<S408cDd02Hh=`0U>3L09CTh02Hj>@0W>cX0;4100396A`0aATL0
;D=50359B`0eCDl0=4a?03=<D00dCE40=4aA03QAE@0jDUL0=TmD03M@E@0iDEH0=e1D03UBEP0gCe@0
=DeB03UBE`0fCe<0<Ta?03IAD00fDU00=E1?039<B`0`BDP0<T]903E>B`0fC4X203M=B`0C03I<B00e
C4/0>4m>03]BD@0gCTd0=Te<03U@C`0gCTd0@EQG03A;BP0eC4/0?EAC03=:B@0hCT`0=de;03Y@C@10
EU@0@UQE03iDD@0203aBC`0Z03eCD00kDDh0>Dm<03M=B@0dBD80>Tm603I;A00iCTX0;T<o03Q<BP0`
A480;T<o02e2>`0cBCd0=Tdn03mFAP0eCD00>U5603aCBP11FU@0B65M03iHE@11FeX0?eYH03eJEP0o
FeH0?EYC03UFC00oFDh0?EM;04EOE00mETl0BF9M04YSG`16Ge`0D6UU04iWI014GET0?UMB049KE@0o
FE00?eI>0P0mE4/0E`0nE4/0@5E;049GC@0oE4T0@EE:03a@A@11EDX0DfML03M<@`0fBd80?E99045G
B`0oEDT0@5I:04=ICP0oE4d0AeaF04=GE00lD500A5QF03eBB`0kD4T0>Tm703]@B00lDDX0?E9:03Y?
B00hCDH0>Di603]@B00iCTL0=da403I<@`0cB3l0=DY103U>A@0gBd80<dLn02m3>P0^?cL0<T<k02dn
=P0X=c00:c/b02ho=00_@3H0;Slf03Y;A@0jBdH0<D4m02Xk=@0Y>S@0<d@l03U:@00dACX0;3X]02Pc
9@0U<2808bhP02@_8@0V<2D09c4V02<^8`0O:B0082XQ02<]9@0T;RH08blX020^9`0R<2T09cD^024_
:00Q;RL082/U02Td;P0H8ad08B/U01`U800S;2L072DQ024Z9`0N9b@08b`Y02Xc<00]=S<09Bh[02</
:@02020Y9P0S01lX9@0N9R@07AhR01hO900E6Ah06B4T01dV:00b?Cd06RDU01/V9P0E7Qh05Q`L04=7
A`37b<P0EUeF01`U7@0E7AH041L@01dT7@0E6a@04AHB01XO6`0E5a@06Q`I01TK600J71/08R@Q02<U
8P0L7Q/05ALD01LI5P0E5a@061XG01LI5P0E5a@00`0D5Q<01P0H61H05ADC01XJ600E5A<05QHD00d=
2`<05ADC00D051@B018B400A40h0510?01<>3P02014=300;018?3P0B4@l051<A01<C4@0A4@l0DE5?
05MGE@0C4a4051<A014@3P0@3`d00P0B4@l05`0>3@/040l=014@3P0:2@P040l=00d<2P0C4A408R0S
00X82`0=2`h04Q0C00d;3P0>30l0?C/n018@4`0;2@`03P`?00l=400C4A@09bDX01@B5@0<2Pd03P`?
008040hA01804A0B01<A500C4A@03`d@00`:3@0@3Pl040`:010;2@0@2`P04@`901<=300C3P/040/9
014;2P0@30T04@d:018<2`0@30`200h:2`0:00l;300@30d04@d>00l;300<20T03PX;010<3@0>2P/0
30P900d92P803`/<00`03PX;00d92P0=2@X03@T:01@@4@0<20T040`=00l<300D41402`L500l<1`0>
2`L200h;1P0I00l<200?30L03P/600h;1`0=2PH030T400`91@0<1`H04@/;010:2P0>20P04P`<00l9
2@0<1PH03PP8010:2P0=1`L030H600l92@0?2PX05a4A00/61P0H4Q802`D5010:2P0600d71`07014=
3018A4<0`[jm024M700:1PH04@`<0107200200l61`0:00l51P0@1PL04@L800/2100C2@`03PD70146
2P0A1`X03PD701462P804@L:00l04@H:01472P0A1PX04`P<00l5200F2`h04`P<01462P0Q5QT040D9
01062@0@1PP040D901062@0@1PP05?ooool001_ooooo03@03A8>00lD400?4a803Q8A00`@400:3Pl0
2@d>01XN7`1UJFX0310A00hB4@0<40l03A4B020T9@0=4A800PH700lC500@51D02@d>00lC500B5QL0
2Ph?00dA4P0:3Pl02`l>00D9200=4A003Q8A00/?3P0C5aH03A4@00hB4@0:3Pd02`l>00dA400;3`h0
418?00lA3P0;3@X030h;00d?300:30T03Q0=014C400@4Pl030h;00d?300@4Pl051HE018D4`0@4Q40
3a4@0P0=3``020092`P03@l:010B3@0@4Pd06adH010B3P0;3@X03Q0=0P0<3P/09`0@4Pl02P`900/=
2P0<3P/03@l<00h@3@0?4@h0418>00L9100@4Pd02@/601LI50051`80418=00L910041P404Q@?00lA
300:30L0314;00/B2`0:3`T03Pl:00l@2`0>3@T03`d901PG4`0J6aH02`d801PM5`1<Dd`0JfmY02<U
800@4Pd02`d800D70P0?4@`04Q@?010B3@0300h@2`0700`>2@0<3@P03Pl:010A300=3PT030d800l@
2`03014B3@0E00l@2`0>3`X030d800l?3@0?3`l04A4@00l?3@0<30X03Pd:00/:1@0>3@P04Q0:00l<
1@0?30<04a8:00l@2P0?4P/02`h700L:0`0E61403Q4:00@02@`500@02`h700`?200?40X030d:0P0=
3PP00`0G6180ADI000l@2P0200l@2P0=010A2`0B4`d04Q<>00lA3P0>40d03a4>00@60`0>40/05ALB
00/>1`0<3`P01PT001@G3P0200hA2009010C300G6Q@030h901<E400:30L04Q@?00d?2P0A4`h0418=
00803@l:00<03a4<00T>2P0@5A400P0>4`l00`083@L02`d800d@2@0200h?2@0800h?200>3`T03Pl9
00l@2`0B4`h06AXE01LH4`0@4@`2018C3P0D01<D3`0B4`h04A8=00l@2`0>3`X04aD@010B3@0?4@`0
418=018D4@0D5Q<05QPE014C400=3``0004002@V8`0;3@T03a4<00h@2`0=3`X200lA300:00h@2`07
2@@03Q0;018D3`0;3@P04Q@?01<E400@4Pd03a4<00h@2`803@l:00L030h901@F4@0E5a8030h901<E
400D5Q403a4<0080418=01403a4<010B3@0@4Pd03@l:00/=200>40/04A<>010B3@0=3`X01@L201dO
6P0>40X041<<00d@2@0?4PX041<<014D3@02018E3P804A<>00`03Q0;00/=200F61<06adH010B3@0?
4@`07R0K010B3@0?4@`061XE018D3`0@4Pd5014C3P0;010D3P0=4P`03a@>00dB3@062`L04QLC01DJ
5P0F61<04A<>01@F4@0F61<00P0D5Q408`0G6A@051HA01DG4P0D5Q404Q@?01HH4`0A5Q8051TE01HK
5`0A5Q803a@@01XO6`0G71P04aPD00P=2@0@5A404QLC010D4`0F6Q/04aLI018F5`0D61/05ATK01@H
6@0E6A`05AXK01@J6P0E6Qd051XK018H600A5aD05adK01@J600F71X06AlM008061hL0P0L8R002@0B
61H05A/I024W9@0J81h05A/I01HL6P0E6aT061hL01hT8P0201HL6P0F01LM6`0I7ad06R0N01XP7P0O
:BD062<O01dX900L:2@06BDQ01`X900N:bT06RPX01PX9`0K:bX08C4`02<c<P0J:B`06bX]01X/;P0P
<C<02Q`N02Dg>@808C<e02L08S@f02Tk?@0X>S`09cXj02Pn?00W?C/0:3hm02]0@@0^@d@0<DI80397
BP0cB4/0=T]?03E=D@0hCE80=de@03A<C00gC4d0>Dm@03M?C`0fBd`0=Da<03E=C@0gC4d0=de>03I>
CP0fBd`0=dm@03UAD`0gCe40<d]=02m7B@0^@dH0<DI803M<C@0iCTl0=4U:03=8B@0fC4d00P0cC500
1@0iDUH0>U=G03I?D`0gD5@0=TmC0080>eAH00T0=4eA03eFFP0mEUX0?UIH03M?D@0bBT`0?UIF03Q@
D00mEE@00P0jDe008P0kE500>E9<03M@BP0eCDH0<DHo0397@00^@c`0<DHo03M<A@0`ACh0>4e402i3
>P0aAc`0<4Hi04=IC01BJ5/0>4m503QBB@0jDdd0?5EA03iGE00oEeL0?5AD03eEE00nF5D0@5UE03mI
DP0lETd0@E]@045IC@0oET`0@EQ>04IME@19H5X304IME`0@04ELEP14FUH0@UUC04=JD012Edd0?596
03I<@00iCd80@5I903mEB00lDd<0>E1003]B@P0jDD40<DPh03eBB080<TLn02@0GW=Z0;_@a`19GUD0
AU]D0397@00gC4L0B5aI049FE010EE00>e57041EC00eBcl0>e5603M<@`0hCT80>e5603U>A@0fC400
=DY003Q=A00kD4L0?51903E8@P0aA3h0=4M1041AB`0eAT00<44k03A3?P0fAD00<3lj030l>00b@CX0
;chg0391>P0gASl203e<A@0C03E4?P0V=Bh0;Sdf03A3?00_?SL0=4<l02Xi;@0T<RD08RhR01l/800N
;1l07b/Q01l/8P0L:B006RDM01dY8@0R;bP09C0Z02@_:P02020[9`16028]:@0Q;2P07RTU01lX9@0M
9R<06B8O01`U8P0N9b@06R<P01XQ800L8R805adM01lU9@0f?3`09bd[01lU8`0N92809B/W02L]:@0T
:RH09R`X01TM7P0H71l06QhP01lT9`0Q9bL07B<R01PN7P0J81h061hL01XN7@0T:BD0;34]01lT800C
61@02Pl;00hC3`0N8al061XG05UKF00`<Rl04Q@A01XL6@0E5a@061XG01`L6P0@40h071`J010@3P0P
81h05ADC01/K6@0E5A<071`J01HF500=3@/0820N01DE4`0J6QP05ADC01<C4@0F5Q@051@B00/;2@0T
928051@B01LG5@0;2`T06a/I01<A4P803`d>0P0C4A801@0?3@h0108301/I6P0C4A80OG]l00805aDF
02003P`=00l=3P0D4Q<04a4B010>3`0D4Q<030X;00l=3P0@3Pl03P`=00d;300>30d03`d@00d;3P0D
4QD04a4D00d;3P0A3a803@/>00/9300?3A004@lB010>4@0B41<05A<F00L5200:20/04@lB06YXJ`0k
>C`02`T<00h<3`803@/>01@03`d@010>4@0@3Ph05A4B00@30@0>2`/03`/<00T81P0:1`L030P901`K
6@0;20P02@D600d92P0>2P/03`/<00h:2`0?2``03PX;010<3@803@T:00X040`=00P41@0;1`P04@d=
01HB4@0E4A003`/:00H20@0A3@`040`;1@0>2PT03@0?2`X03`/800l;2P0?2`T03`/800l;2P0?2`T0
3PX700h:2@0?2`T040`9010<2`0?2PT01@0=1`L03P090`<02`D500l92@0?2@T030H600T30`0:10@0
3@L700l92@0;1@D02P@400l92@090`<04P`<0P0=1`L0200;1@D04P`<01PB4P0=1`L05a4A010:2P08
0P8040X:1@0=1`L06@0>1`L04`X=00P2100:0`D040L:00T1100=1`T03PD8024J700K5AL040L:00d5
200B2@`060h?00d3100900004`T:01@:2P0800005`d>00/20P0@1PD05`d>0188200a9bH05?ooool0
01_ooooo00<02Ph?00`@4@0>4Q<00P0?4a@02P0>4Q<06AdN01PL7@12ATL010P900lC500B5QL0<CDf
03/o@00O8b@200dA4P0C00@82@0@51D02`l@00hB4`0?4a@0310A00X>3`0=4A004ADD01`P7`0I7A`0
3a<B01<G5P0830/051PG01<G5P0=4A002Ph=00T=3002014C400500d?300?4@h0418?00d?300>40d0
0P0?4@h00`0=3``03Q0=00lA3P0300lA400@010B4@0A4a004Q@A018D4@082PD01PP3010B3@0;3PL0
4QD@00h@3@0D5Q<04Q@A010B3`0F61D0418?00lA3P803Q0=0P0<3P/06`0:30P03Q0;01TK5P0I6aH0
3Q0;01<E4017BD@071hI00lA300@4Pd02`d800X<1`0<4P/02Q@<00lD3P0?4Pd0414<018A3@0?2`P0
2`X600l@2`0<3PT05QdF03U0>@0i?cP02P`700lA300201TK5P0>00h@2`0;3@P02P`700X<1`0=3`X0
3Q0;00d?2P0>3`X0414<014B3@0>3`X03@h9010A300B4`h201<D3`06018C3P0A4Pd0414<00l>300A
3@`04`l>0P0E4A00100F4Pl04a0;018?2P0@3@P2014>1`07010?1`0<3@L041<<00X=1P0>4@X030l8
00@7000200/>1`8030l80P0=40T0;@0<3@L051D?00l@2P0<3@L01@H2014B300@4@/03a0:00h?2@0?
40X04A8<01<D3`0@4Pl03a4@018D4`0C5A802@/700h@2`0J7AH05AP@00X=100=40L03A06014D2`0A
50d03@l:00L9100>40/03@l:00h@2`0=3`X0418=00lA300=3`X03Q0;010B3@0<4Ph02a0<01XP7005
2PH03Q<=01<H4P0?4P/0414;00l@2P0300l@200401PI500>3`X03Pl:00l@2`803Pl:00@04Q<>014B
3@0A4Pd04A8=0P0@4@`07`0@4Pl03@l<00`>2`0<3P/03Q0=00lA3P0A4a0051HC01<E4P0>40d06A/H
00H8100=3`X0418=00lA300>40/03a4<018D3`0>40/04aD@01@F4@0>40/03a4<00`>2@0?4@`0418=
014C3P0@4Pd03Q0;014C3P0?4@`00P0<3PT00`082PD03@l:018D3`0200h@2`0300lA300>40/03Q0;
008030h900`03a4<018D3`0B50l04Q@?02<V7`0d=c0051L@00`?200J7AH03A0900lB2`0@4``3018E
3P09014D3@0G6A@04Q@?00/=20010`002@/603`n>@0c=C008B<N00804aD@00<03a4<018D3`0A4`h0
1P0A4`h0600?4@`07R0K01XL5`0B50l02`d801HH4`0E5a806A/F01LI500A4`h04Q@?01<E400B50l0
5ALB01@F4@0A4`h051HA01<H500D6AD06b0L01`Q7@0E6QH04QLC01DJ5P804aPD01T051TE00hC3`0D
61L05QXK01<G6P0B5QT051PK01DI700C5aX041@G00lC5P0A5AP05QXM01LK7P0D61T06AlM01/Q7`0D
6QP04aTG01LM6`0F71X05A/I02H/:P0]<c407bDS00803Q@B00<05A/I01TO7@0L8R000P0H7Q`0100N
92806R0N01XP7P0J81h201TO7@0?01LP7@0J91l06bHP01hY8`0K9b<07BTU02@`;00G9R<05bLV01PX
9`0J:RT072`[01`/;00C9BP09cTm00805BL[01T07c4e020b=P0R=3P08cDi01la=@0R=3P093Hj02Di
>P0V?3X09C/i02Dj>P0V>c`0:Cho02e2A00`ADP0<DI903=8C00dBDh0=DY?03A9B`0cBDL0=D]903U?
C@0hCT`0=D]900<0<dU700P0=Ta:03U?C@0hCT`0=Ta<03E:C@0fBdh0>4e@03Y?DP80?55D00X0>TmB
03Q=D00bAdX0<4E80316B@0fCe@0<dmC03QDF00iEET0=51D0P0fDUH03@0jEUX0?e]O03iJGP13Gf<0
=U9F039:CP0kDeL0?UII03Q@DP0jDU@0>51@03QACP0iDTl00P0jDdl0@00hDD/0=Tm803U>A`0iCTL0
<TM00315?00dBD00<DHm0316>P0gCD40?UA802To<P0bB3/0?UI903eDBP0mETl0?eQB045JE`13FeX0
A5aL05UaL@17H5h0>U=?03aED@13G5D0A5iC041GC@11FDd0@UU?04=JD016GE@0AeiF04UPF018GeP0
AeiH04IME`13FUD0@EQB04YOEP13FDd0>4i2049HB`17GDl0@5M703iEA@0fCC`0<4Le03=:>00kDT00
?5=303Y@A015FU40C65H03Q=A01RMg00;D8k03Q=AP15FUD0EV]V03=8@`11EE<0>4e803U?A00iCd<2
03aBAP0803Y@A00oEDT0>U1403U?@`0fC400=D/o03U?@`0lDDP203U<AP0603A7@@0`@cd0=TM102m0
>P0a@S`0;Sdh0P0a@3/02@0`?3P0<Cdi03=2>`0d@c`0<d8k0391>P0`?cP0<T4j02dl=@0202/j<`0A
0350>@0eA3d0=4<i03A2=@0]>bh082hQ01d[7P0S<2H0<3dc02Xg;P0N:b807BXR02@a:P0U<R/092lZ
02@]:P0R:bP00P0S;2T3024Z9`0]020Y9P0O:2D07bPU01hW900L8b<07R<V01dS8`0N92@0:S0`028X
9P0U:bT08RPV028X900O9B406R0L01/Q700O8b@07R8U01lS900P92D08BDV01lS8P0J7Qd0720O01`Q
7@0E6QH04aPD01/P6P0B51403a4>01hP7@0F61D03Q0=01PJ5`0j?3T0828O014C400K7AX061XG01XL
6@0B4Q005QHD01XJ600G5aD0Fe]I00807QhL018051@B01PH5P0F5Q@06ATG03Hf=00O7ad061PF014A
3`0?3`d0410>01<C4@0F5Q@0820N01PH5P0L71X04a<A01LG5@0C4A82018@4@804a4B00P04@l@00l=
3P0:20T03`d>02`Z:`0C4A802@L801DC50804@l@0P0?3@h0100F51D03P`=014?400@3Pl200l=3P0>
010>3`0>30l03`d@01PF6@0B41<01`D800P62@0?3A0030X=00h<3`0=2`h030X=010>4@0;2@`200l=
400900h<3`0f=3L07Q`O01DC5P0A3a8030X=00/9300>30l03`d@00803P`=00<02`T:00l=3P0=2``0
0P0A3a001@0J61T0:RPY014?400<2P/03``=00D03`/<00d03PX;00l;300@30d040`=01<?400A3@h0
2PH600X61@070`803PX900X61@0=2@P03`/:00`03PX90P0=2@P200h:2@0300l;2P0>2@T03@L700H0
3@L70P0?2@T01P0>20P02`D500d71`0<1PH03@L700h820803`T900`030H601@>3P0>20P040X:00l9
2@0H4Q80A3hn02HP800C3@d030H600/51@0<1PH600d71`0:00`6200:10H03@L900l92`0=1`T040X<
00L10`0C3@l04@/=00`620803PP:00`03@<401@:2@0?1@@0200000l71P0L4Q4050X901L=300@1PD0
3@<200l51@0[8B0Dooooo`006oooool200dA4P803Q8C0P0=4A805@0J7Ql051PI01@H6@093@h03a<D
00hB4`0:3Pl04aLH00/?400830d03Q8C00X>3`0=4A804aLH00H:2`0>4Q<04ADF00/?400:3Pd03a<B
01<G5P0200hB4@0401HJ6@0G6aX07R8Q01LK6P<03Q8A0P0@4Pl02P0<3P/03Q0=010B3`0>40d03a4>
00`>2`0=3``0418?00lA3P0=3``200lA400:00h@3`0@4Q404A<@018D4@0?4@h03@l:01@F4@0A4`l0
71lH01TK5P803@l<0P0<3P/00`0A4a003Q0=00h@3@0400h@3@09010B3P0T9R405aTD00d?2`0<3P/0
20X602d_:P0A4`h02@/600<03@l:01<02Q0:00P@2@0<4@/030l900/<1`0>3@T040l;00h=2@0>3`X0
3Q0;00L=1P0940T02Q0:01HH4`0@4Pd06adH024S7P0A4`h03Q0;008030h90P0>40/0100=3`X03a0;
010A300A4Pd200l@2`03014B3@0=3PT03@h900<03Pl:00<03@h9014@3P0A40h00P0?3P`03@0A40h0
3`h:01DD3`0A40/03Pd8010@200A4@T03Ph600/<1P0D5a003Q4:00T<1`0>4@X00P0<3`P0200>4@X0
41<<014D3@0?4P/03A0900L81@0N7aT03Pl90P0A4P`00`082@H04Q<=00l@2P0200d>200B010A2`0C
50l04aDB00h@3`0;3@`05ALD010B3`0=3`X04A@=010C2`0A50/01PT3010C2@0G6Q403Q4:01TK5P0S
9B004A<>100?4@`200h@2`0900lA300@4Pd0ATQ502h_;@0;3@X05QLD00D60`0A4`h04A@=00804A8<
00P0414900l@200?40P0414=01DF4@0A4Pd03a0;01<D3`804Q<>00L0414<00l@2`0A4Pd04a@?01DF
4@0@4Pl03Q0=00803@l<00T03Q0=00lA3P0=3``04Q@A00lA3P0:30T04A<@014C3`0@4Pd00P0A4`h0
3@0>40/03a4<010B3@0<3PT0418=00`>2@0?4@`05ALB00d?2P0>40/0418=01<E400B50l00P0@4Pd0
300:30L06Q`G03@f<@0F61<01`T400lA300@4Pd04Q@?01<E400B50l0418=014C3P804Q@?00`04A<>
018D3`0C5A003a8;018E3P0K7QL04A@=00hA2P0C5Pl03Q4:00lB2`0A50d3018E3P0<00d>2`0=3`X0
4aD@018D3`0<3PT05QPC01`N6@0A4`h03Q0;01@F4@0C5A005ALB1`0A4`h0200@4Pd051HA010B3@0K
7AP04A<>01@F4@0@4Pd04Q@?0P0D5Q406@0H6QD04aD@01<E400H6QD05aTD01DG4P0L7QT05AXF014F
4P0K81`08RLS01PM6@093PX05AXF01HK5`0C61@0724M018G4`0H7AX05ATJ018F5`0A5AH04aLH01@H
6@0C5aP00`0G6a`01@0H71d05a/L01DI6P0J81h0728P008051XH0P0I7ad00`0L8R0061hL01PN7002
01LM6`0[01XP7P0Q9bD06AlM01LM6`0E6aT061hL01hT8P0G7A/061hL01TO7@0K8Al0728P01/T8@0J
9Al07RTU01lZ9P0I9B407BTW02@`;P0F9B806RXY01d];00N;Rd06b/Z01TY:@0J;2l0@UAH08:DV00`
@TH09SPl01la=@0U=c/0:3Xn02<e>@0T=SX09SPl02Pl?@0Y?cd0:3hl02Pn?@0Y?Sl0:Sm002i3A@02
0356B@060397B`0bAd`0<dQ=03=8BP0eBdT0>4i<0P0lDU006`0hCT`0=Ta:03A:B00bB4H0=4Y803M=
B`0hCT`0>Di?03M<C`0fBdh0=DY=03M<C`0jCe80>4e@0356B@0_A4L0=4U<03Q=D00iD580>eAI03QD
F00lF5`0>eMK03IBEP0hE5P0>eMK03MCE`0203EAE@0;03iJGP0mF5`0KhN:049JF`0gCe00=4a<03M?
C`0kDe<0=Di;03M@C@0jDe000P0lEE40;P0kE500?eA>03mDC@0gC4D0;D8k02m4?@0fBd80>U1403=9
?@0jD4@0=D/n03U?@P0hD4<0?5=903aFCP0oF580@EYG049KF@12FUX0Jh>305E]K012FeL0@5UE041J
DP0lET/0@5M=049ICP14Fe40AUeC04IME016GED0Bf9J04]RF`19H5X0B5mI04EKE`13FU@0B5eD05M]
H@15Fdl0BV1C03]AA014FTd0>U5103Q??`0jDD4203aC@@0C03eDA00mDdL0A5U@03eBB@0eBT40?E9;
03]@B@1DJF80A5UD03Q=B00mDTd0AUYH045FD@0nDd/0>e1704IKDP0lDDP0@UM>04MLD`0203U>A@80
=da300`0>Tm603eBB@0nDD/0>Te703A7@@0eB480>T]503a=A`0b@cd09SD`02Th<`0_?ST2030l>005
02hm=P0c@S/0<D0i02`k=00^?CH00P0a@3T03P0R<BX07bhW0350>@0/>c@0:cX`02hl;`0[>B`08BhS
01`Y7`0R;bD0<Chd02dj<@0O;2<07R/S0P0U<R/0100V<B`09c0]02</:@0R:bP202</:@0901hW900K
924072DR01/T8@0J8b006b@Q01dT900U:Rd09bd]00807bDU01P082HT028X9P0N928082HR028X900P
9R808BPR01`P8@0M8B@0720Q01HJ6`0E6AX061`K01dQ800H71/06QlK01PM6@0D6AD0:2dW05]MFP0W
:BH0418?01/M6P0G6AH201PJ5`805aTF01<06A/H01XL6@0I6aP05QHD01dM6`0H61H0410>04E5@`0C
4a405aLE018B400G5aD051@B01<C4@0U9B<07AdK018B400K6aT07QhL00804a<A00L061PF018B400H
61H06ATG01HF500=3@/04@l@0080518C0P0B41402`0E4a@04a4B01HD5@0H5QL01083018@4@0>30d0
4a4B01HD5@0L6Q/06QPI00804Q0A00`04@l@018@4@0A3a003`d>014?400C4A8040hA00d;3P0C4A@0
40hA00l=400F51L200l=400<010>4@0=2`h04@lB01XH6`0F51L06ALJ01<A500@3Q4030X=01<A500G
5AP03`d@0`0=2`h04@0>30l040h?00d;300A3a003@/<00/92P0=2``02`T:01HD5@0Q7b003@/<00/9
2P0?30d03`/<00h:2`0?2``03PX;00803`/<0P0@30d0200>2P/05A4B018>3`0;1`L03`/:01<?3P0?
2`X04`l>0P0<20L600h:2@D03@T80`0<20L300d9200300h9200=1`L03@L700<03@L700D04`d=010:
2P0<1PH03`T9010:2P0200h8208030H600`04@/;01@>3P0A2`/02`D5014;2`0;1@D030H600/51@0A
2`/05a4A00P30`0=1`L200h820L03@L701402`D7010:300@2P`03PP:014;3@090`D03PP:00/51`09
0`D030H800l92`0:10H040L700l51P0C2@X050X;0147200200/10P0501882@0<0P<04@L800l51P0D
2P/05?ooool001_ooooo0P0?4a@02P0=4A80310A00`@4@0;3a001@T:010D5@062P/04aLH00dA4P0:
3Pl201@H6@0F014E5P0@51D03a<D00`@4@0B5QL02Ph?00T=3P0D61T02@d>00hB4`0=4A003Q8A010D
4`0E6AP09b/Z03@h=`0E6AP03a<B00T=300:3Pd02`l>00L;2P80418?00`030h;00h@3@0?4@h03@l<
00lA3P0;3@X030h;014C400?4@h030h;010B4@0?4A0200h@3`803a4>00`0418?00T;1P0E5a8061XE
0;Nj/`1^LF`061XG00`>2`0=3``03a4>014C400;3@X200d?30803a4>0280418?00/=2@0B50l051HA
010B3@0j?3L0B4Y501lQ700?4@`03Q0;018D3`0?4@`02`d800`B300=50d02Pl900lB300B4`h03`h:
00`;1`0;2PH030d800lA30093PP020l800X@2@0B50l02`d801PJ5@0@4Pd01PP300d?2P0;3@P02P`7
0P0<3PT0100:30L03a0;00h?2P0>3`X200l@2`803Pl:00<03a0;010A300A4Pd00P0@4@`0500:2@L0
3Pd;00`;2@0?3P`05QDC01HE4@0>3@P040l:014@2`0>3PH03`l7018C2`0J6aD030l8010C300930D0
3Q4:00lB2`0;3PL03Q4:0P0@4``02P0>4@X02`h702X[9@0m?SP06Q/E01@E3`0G61803a0:014B300?
40X200d>200A00l@2P0A4Pd0004001<E4P0A4a00004001HH500D5Q403Q4:00X=1P0A50d04QD<04E8
?`1/KfH02`h701HH4`0S9B000P0<3PT03P092`H0418=00lA300>40/03a4<010B3@0@4@`05A@B0040
000N7A/010@301TH500@4@`0414;0P0?40X02P0>3`L030l600`?1P092PD0004000H70P0H6A@05AHA
00L80`0A4Pd200h?2P03014B3@0E5Q405QLB00803a4>00`0418?018D4@0C5A8051HC010B3`0<3P/0
5ALD01HH5@1`LVl0GEmK01LI500=3`X200h@2`0700d?2P0?4@`04Q@?01XL5`0B50l03@l:018D3`02
00h@2`803@l:00d03a4<010B3@0A4`h02`d800h@2`0E5a802P`700P:1@0@4Pd04A<>01<E400E5a80
4aD@00<04A<>00X03a4<00h@2`0@4Pd04aD@00lB2`0<3`P0:B`U01`O60062@8041<<0P0>4@X0400@
4``04A@=014D3@0A50d0;BlZ01/M60092`H0418=01HH4`0E5a804aD@014C3P0F61<06Q`G01HH4`0=
3`X6014C3P0902d_:P0G6A@03Q0;00h@2`0E5a801@L303i0>`0R91l04aD@00<051HA00l04aD@018D
3`0C5A004A<>01@F4@0P8Qd06AhJ018G4`0D6AD05Q/G01<H500B5a<05AXF01HK5`001@400P0J7a/0
3`0A5Q805ATJ018F5`0A5AH04aLH01@H6@0C5aP06QhO02<W:00P92D05QXK018F5`0I7Ah051XH01XP
7P0201PN700M01XP7P0H7Q`041HD014G5@0D6QP06R0N01TO7@0F71X09Rl/010I5P0>5a@05AhK01HO
700G81d0624N01TR7`0K92407RLT024Z9`0R:bP072LS01/V8P0J9B406bLS01`X9P0K9bD072XZ01`/
:`0M;B`00P0N;Rh01@0O;bl09CLj02Pj?P24UYX08cDi00807c4e00H07S0d020b=P0W>Cd0;T1402Pj
?P0P=3D202<i=`0702Hl>`0Y?Sl0:Sm002i3A@0aATT0<TM:0397B`020397C00303A9B`0fBd`0>Di?
0080?E9C00<0>Di?03Q=CP0gC4d00P0dBDX01P0gC4d0>4e>03eBE00nDeH0>4e@0356B@80;D950380
<dQ;03E:C@0`ADP0=4U<03Q=D00hCe40?EIK03]DF@0mEU/0?5EJ03QAEP0jDeP0>55F03YCF00nEe`0
=e1E03UBE`0mEUX0WkNg05E^J`0mEU<0>E9?03A=BP0gD4d0=4a<03I>CP0jDU80?EEE03iFEP0nEUD0
?U9@03iCCP0jCdP0<TM003A9@P12Edh0A5U@02e2>@0oEDT0AUa@03=9?@0iDD@0?UE;03mHD@13G5H0
A5eJ04EMG014G5`0@5QH04ENG080BF9N00X0B69J04QRE`13FU00@eY?045HCP13FU00AeiE04YQF@18
GeL0BF1I0P19H5X06`18GeX0AeiH04EJD@2EZil0CVAH03mEB@1<HUD0;48e03I<?`0nE4H0BF1@04QO
C`0nED@0?eI603I<@01=HUT0=T]203]@A`0bAd00>e1904=HD@0dBD@0?E9=049GDP0dB4H0CV=N03Y?
A`02059WGP0304IKDP0nDdX0=4U00080>Tm600/0>Di503M<@`0jCdH0?55803]>B00_@S`0;T4k03a?
B@0eAT00>DY40311>`0202Lf<@0G02Pg<P0]>CD0<Shj03I5?P0eA3d0<3lh02@c;00U=2d0;C`e0391
>P0N;BH062LP02ln=`0Y>3409SD[02@b9@0Q;R@0934W02Ld:P0V<bX08BhU01h[8P0P;BH00P0R;bP0
:@0R;RX09C0/02D^:`0P:BH07BHS01lX9@0P:BH08BXW01hW900L9B8082TV02D^:`0R:bP07bHV02<X
:`0U:b/08BLW020V9P0P9R@07bDS01`R800N920082HR01/Q7@0F71L06AdN01/O8P0J7Ql05ATJ01@H
6@0I7A`092PW01HJ6@0E6QH06AhJ01<H500L8A/0;Bl/01/M6P0H6QL05aTF008061XG01l05QPE01dO
700J71T04A<@01@F4`0I6aP05aLE018B400J6QP05QHD00d=2`0J6QP05ADC01LG5@0N7Q`06ATG00h>
300@40h05aLE00l?3@0P81h09BDS01HF500C4a403`l=018B400G5aD0410>01<C4@0?3`d03`d>0080
4a4B0P0@3Pl0300D4Q<04Q0A00`;2`0;2@X0518C01HD5@0>30d03@/<01@B4`0O7Ah07A/L018@4@80
3`d>01L04@l@010>3`0>30d03`d>014?400<2Pd04a4D01/I700@3Q400P0300@21@0>30l040hA014?
4P0>30l0518E01hL7`0Q7b803P`?00`:3@0:20/05A<F010>4@0200`:3@0R018@4`0@3Q402@L:00X8
2`0=2``040h?00d;300@3Pl07Q`M00h<3@0@3Pl02`T:00`:2`0;2@X04Q0A010=3P0<20T02`L800l;
300;1`P030P9018>3`0<20T02PH700l;30091@H05A4B038^;P0=2@P02`L600h:2@0B3Pd02`L6014=
30D03PX91P0?2`X00`0>2PT03@T800d9200300h:2@0300h92@0=1`L03@L700<03@L700T04P`<00l9
2@0;1@D03@L700l92@0=1`L02P@400`61P0@2PX00P0?2@T02P0D3Ph02P@4014;2`0=1`L04@/;00h8
200=1`L04@/;00`61P0B30`200T30`03018<300=1`L03@L700@03@L701P0208400/51`0<1PP0618D
028L7P0C3@l050h@010:300=1`T02`D700X41P0<1PP040H701<92P0900002`4200L0000J41405P`=
00d3100A1`P05P`=00/10P0O5AHDooooo`006oooool400`@4@0D00lC500@51D010P900lC50093@h0
3Q8C00`@4@0A5AH020`=00L;300:3Pl02`l@00`@4@0A5AH051PI05eQHP0N8R<0310A01DI6P0830d3
00/?3P0300X>3@0@51<05ATH00802Ph=00@02`l>014E500>4Q401@T80P0C5A801@0?4@h0418?014C
400>40d03a4>00803@l<00<03a4>00h@3@0=3``00`0=3`h02`0?4A004A<@018D4@0=3``03@l:01dO
6P0[;BP0i^WR08b?RP0I6aP030h;00803a4>00l0418?00h@3@0@4Pl0418?00lA3P0>40d03@l<01DG
4`0F61<051HA018D3`16B4<0VifH061RG@0A4`h00P0=3`X200h@2`0F018F400>5@h020d700lA300D
5A003@h900l?2`0E5Q4051D@010B3@062`D020d701`O6P0K7AP03@l:018D3`0:30L03a4<00h@2`0=
3`X03Q0;018D3`8051HA00<03a0;00h?2P0=3PT00P0?40/00`0>3`X03a0;00l@2`02010A300;00l@
2`0>3`X03`h<01DD4P0?3P`01`H400/:200;2PH030/6010?2P0B4@`00P0>3PH05@0D5@d03Q4:0044
000?4P/06A`E014D3@0D5a0030l800hA2P0?4P/03Q4:00d@2@0;3PL00P<001DF40092P@030d7010A
2`0A4P`0414;00l@2P0400h?2@0O02@V8@041@<05ALD02`^:`1GFED02@/6010C300?4P/02Pd60044
000?4PT07R4J01@F4@082PD02P`700`>2@0C5A003@l:010B3@0?4@`0418=014C3P0?4@`03Pl:024N
7@0:1PD09R8Q00h<2P0D4`l030/700l?2@0200h?2@0:00h?1`0=40L03A0701PI500L7AP061TD00X;
1P0>3`X06AXE010A30803a0;00H04A8=01@E400E5Q403@l<00h@3@0?4@h2014C4009018D4@0E5a@0
1@L4010B3`0R9240WZ2M07]mN@0G6A@02`d800803Q0;00H0418=00h@2`072@@051HA01TK5P0>40/2
010B3@0B00lA300<3PT02`d800d?2P0@4Pd04aD@014C3P0<3PT01PP300X<1`0A4`h04aD@00lA300@
4Pd04A<>010B3@0?4@`03Q0;0P0=3`X02@0>40/0418=01@F4@0>4@X04aH?018E3P0@4``05aXC01<F
3`0200lB2`<041<<00T03a8;01<E400B50l04aD@01@F4@0B50l03Q0;01LI500E5a800P0D5Q400`0C
5A004A<>014C3P05014C3P0907IhL`0k?CP061XE01@F4@0=3`X0828M03do>P0R91l04aD@00<051HA
01<05QPC01LI500G6A@051HA01LI500U9b80724M01HK5`0C61@04AHB018G4`0J7a/051TE01HK5`0>
4`l04aPD01PM6@0;40`05QXI00804aLH00@051PI01DI6P0D61T04QHG0P0M8B805@0D61T04QHG01`P
8@0D6QP06b4O01XP7P0H7Q`05Q`J01<I5`0B61H05adK01TO7@0L8R006AlM01<I5`0K92403aPE01DN
6`0M9R<05b0M018K600301PQ7P<06B8O00L06bHR01TT800H8al07RXV01l[:@0K9bD07B/[00806RXY
00P06b/[01d];@0O;bl062X^04IHG01NL7@09CLk02/m@@808C<g00/08cDi02do@`0fB4`0;T14028f
=`0S>CL09C/i02To?P0/@D80;T=402m4AP0202m4A`060315B@0aAT/0<DI;03=8B`0eBT/0=T]<0P0i
CTl03P0fBd`0=4U:03=8B@0bAdP0=T]<03]@D@0lDE80?E9D03]@D`0gC4l0<dQ;0356B@0bAdX0<dQ;
0P0bAdX04`0fBdh0>DiA03aBE@0lE5P0>E9G03]DF@0jDeP0=e1E03YCF00`BDh0?5EJ05=/L@1<IFX0
?eQM039;CP12FeP0<T]703I?B`0bBdP00P0iDTl02@0fCTh0>51@03]CD`0mEED0?UIH03eEEP10E580
?eA?03mDC@0203]@B@0K04MLE039g]D0LhQo0357>`0jD4@0?E=703]CAP0lDd/0?UQ@04=LEP14GEX0
A5aK04=KF`0oEeL0A5eK045JEP0jDdl0=Dm703I@A@15G580@UY>045HCP12FDl0AeiE04]RFP16GED0
B5mH0080BF1J00l0BEmK04QOF@0mDTT0H7IZ045GB`12F4`0@EM;0316>@0gCD00>U12049IB@10EdL0
?UE404]RDP14FTd00P0eBT403@14FE00>Di704EJD`19GUL0AU]F03mDC`15FUD0KX:00397@P0mDTX0
AEYA0356?@0lDDP00P0hCD@203]@A`0A03Y?AP0hCD@0>Di503Y?AP0kCTP0<dI003M:A017FU@0;Sli
0311>`0_@3X09cHa02He<00W=S40;CTe03<o>`0_?SL00P0]?3D03P0R<BX093</02hm=P0Z>C8062LP
010O600S<R/09cH_02Th;P0T<RD072TO01dZ800U<RP09C8Y0P0N:b80200T<BX09S</024^9`0O:bL0
8bhZ02</:@0O:2D072DR0P0M9R<0200Q:RL07bPU01`U8P0R:bP09c0]02@]:P0N9BD07R<V0`0O9BD0
@P0N928082HT01/Q7`0N92008RPT01hT800I81X05a/L01PL7`0H71d05QXK01DI6P0H71/06alN01<G
5P0H7AT07b@P01PM6@0A5Q002P`901<E4P0O8Ah04A<@01DG500I6aP05aTF01TK600E5a@03a4>01<E
4P0I6aP05ADC018B400I6AL06a/I01HF500H61H05ADC01@D4P0F5Q@05ADC01<C4@0I6AL071`J010@
3P0D51805QHD018B400E5A<02@T701dM6`0@40h020P600`<2P0>3P`040h?018@4@0A3a0040h?014?
400B41405aDF01@B4`0H5QL020H701@B4`<040h?00L04Q0A014?400>30d04a4B00d;300@3Pl04@l@
00803`d>00P040h?018@4`0>30l04Q0C00h<3`0C4A@07adP010>4@803`d@01@02`T<00`:3@0C4A@0
8AlR00`:3@0C4A@02`T<01XH6`0610L02PP;00d;3P0C4A@03P`?00T72P0>30l02PP9010>3`0=2``0
5A<D02l];P806ALH00/03@/<00P61`0<2P/0518C00l<3@0;1`P030P9018>3`0<20T02`L801<?4002
00X61`04018>3`091@H06ADF051<C0804Ph=00@05a<B00d9200;1`H0510?1@0>2PT600l;2P0300h:
2@0=2@P03@T800803PX900<03`/:00h92@0=1`L01@0=1`L05`0>20P03`T900h8200=1`L030H600T3
0`0=1`L04@/;00d71`0<1PH04P`<00X4100@2PX030H6018<300?2@T03PP800l92@070@403@L700h8
200B30`03`T900H03@L701P03PP:00/51`0:10H04`d?01LA4`0:10H03PP:00d72@0>20X02`D700X4
1P0A2`d01`0000d3100;0@80:AlP00d4100>10D040H700h41@0D2P/04PP901@:2`1:@44Dooooo`00
6oooool05@0>4Q<03A4B00`@4@0<41403Q8C00lC500<41403A4B01TM7P0<41402`l@00dA4P0@51D0
310A00lC500=4A80310A01LK700Z;Rl0EUYK01dQ8P0200lC500400`@4@0A5A@03A4@00X>3@802`l>
00X02Ph=00dA400>4Q402`l>00dA400?4a803A4@01DG500D5Q<03a4>0P0>40d02`0;3@X03Q0=010B
3`0@4Pl03@l<00h@3@0@4Pl0418A00lA400>40l03@l>00<03Q0=0P0D5Q400`0C5A00<SD_038d;`02
00`>2`03018D4@0;3@X03Q0=00H03a4>00<030h:01@F4@0620@00P0:30L06P0X:RD07b4L010B3@0>
40/030h900lA300@4Pd041@>00lD3P0>40/0418=014C3P0?4@`03@l:00`>2@0>40/04A<>00d@2`0?
50h08BDO01LI500@4Pd030h900lA300C5A00418=0P0?4@`0100B50l051HA01<E400A4Pd200l@2`03
014B3@0B4`h03a0;00<04A8=01D0414<00l@2`0>3`X061PF028R800K6aT02PX800d=2`0@4@`04a@>
014B300?40X04149014B2P0@4@T03a4=03m2>`0[;RL05APA00hA2`0:3@H00P0?4P/05@0>4@X03A09
00d@2@0=40T05AH@00h?2`0B4`d06Q/E00l@2P0A4P`03Pl9010A2`0A4P`0414;00h?2@0;30H04A<>
00`>2P0E5a801PP401@F4P02010B3@0;01TK5@0D5a005aXC00lB2`0C5Pl020X7010B3@0;3@P04Q@?
00h@2`0E5a800P0?4@`03P0C5A005ALB00lA300<3@P050l?010:2P0;1`L05a<B00T50P0H5a<03Pd8
00h?2@0?40X04A8:0P0A50/0200A4Pd030d8014B3@0A4Pd0<c@_05YKEP0@4@`04A8=100B4`h3010B
3`0G00lA3P0=3``030h;00`>2`0E5a@0418?00/=2P0V:2D0828N00lA300=3`X04A<>00h@2`0H6QD0
;S0[01HH4`0=3`X051HA00`>2@0@4Pd04aD@014C3P0@4Pd00`0?4@`01`0@4Pd03Q0;00lA300C5A00
3a4<018D3`0D5Q401@0?4@`02@0C5A0051HA018D3`0@4Pd03@l:00`>2@0O8Q/0:2/T010C3@02010C
300801<F3`0A50d04A@=014D3@0@4``03Q4:00d@2@0?4@`2010B3@803a4<00<0418=014C3P0A4`h0
0P0@4Pd2018D3`H04A<>00H0828M01HH4`0B50l04Q@?01dO6P0Y:bH201DJ500<01LL5P0D6A<03a@>
018G4@0=4P`04aPB01TN600D6A<04AH@01XO6@0H7AT04QLC0P0C61@01P0@5A404QLC01PM6@0L8Ad0
EeaH01<H50804QLC00P061`K01DI600E6AP05QXI01LK6P0F6QT04ADD01@H5`805QXI01005a/J01PL
6`0B61H05adK01DK6@0F71X06R0N01TO7@0H7Q`06b4O01LM6`0H7Q`06b4O01PN700E7Q/051dJ0P0I
8Ql01@0E7Q/05b0M01LP7@0G81d0624N00<06B8O00L08B`X02D_;P0N:2L072PV01l[:`0N:RX072XZ
00806b/[00T072`/01d];@0M;2h07Blc02Dg>`0O<CD09SPl01PZ;P0T=SX00P0V>3`01`0X>Sh0;d55
02do@`0W>c`0:3hl02Y0?P0/@T400P0^@d@0200_A4H0;dA70315B00bAd/0=4U>03E:C`0hCE00>Di?
0`0fBd`03@0eBT/0<dQ903=8B@0cB4T0=da=03Y?D00iCTl0>Di@03Y?DP0hCE00=T]>03=8B`0bAdX0
0P0`ADP01P0dBD`0=DY=03M<C`0lDU@0>51D03I?D`80>55E02P0=DiB03YCE`0fCe<0>55E04ENHP13
G600?EIJ03MAD`0lEE00?UQ@03mHDP0oF5@0>E9>03I?C00jDU80>e=C03iFF00nEUT0?EEI03aDE`12
EU@0?eA?041ED00oE4l0>Di803iCC00oE4`0=4U003U>A@0iCd<0?UA803aCB00nEDd0@5YB04ENF017
H5d0AemN04ALG017Gel0B61O0P19HUh01`17HET0AEmD049IC`14Fe00AEaB04IMD`18GeH00P18GeL0
2019H5T0B5mI04QOF@17GET0AEaF04UNE`0oE4/0?E990P13FDd06@12F4`0?E=603]AA010ETT0>e92
03YA@@1>IEH0DfUM02m4>`0iCTD0>Tm603Y?B00hCDH0>Tm8049GDP0lDD`0GG9]09FYY`1=HUd0>Di8
03iCC00gC4D0HGI_03I;A00oE4d00P0nDd`01@0lDDX0>4e603M<A@0hCDH0?U5;0080=4M10140A5MA
0311>`0oD4X0<D8l028a;00T<bh0;3/f02hj=P0]>CD0:STb02@c;00Z>C8093</02Dd;@0[>S<07bhW
020_:002024`:@0@02Dd;@0O;RD07R/Q01h[8@0P;B<082dT01l/8`0P;BD08BhW01l/9@0R;bT08bl[
024]:@0S;BX08b`Y01lX9@807BHS00<072DR01/T8@0K92400P0K9240;`0L9B806b@Q01`S8`0O92L0
8bTY024W9`0K8B4082HT02`b<00S:BL0728N01hT800L8Qh06b4L01`P8@0J7R406QhO01`P8@0K7b00
5a/J01DI600H71/06AhJ01PM6@0I7QX061dG01dO700J71T07AlL018D4@0G6AH06Q`I01TK600D5Q<0
5QPE01/M6P0H6QL05QPE01@D4P0L71X05QHD01DE4`0I6AL04Q8@01PH5P0F5Q@05ADC008051@B00<0
5aLE01<C4@0D51800P0@40h02`0E5A<05aLE01/K6@0o?cd05QHD01<C4@0D51805QHD01@B4`0B4140
4@l@0080518C00P04@l@00d;300C4A8071XK06m]KP1YIfP05A<D01@B4`804Q0A03<03`d>00`:2`0A
3a003@/<01<A4P0F51D04a4B010>3`0?3@h0518E00l=400@3Q403`d@01TG6P0X9RT040hA00d;3P0@
3Q403P`?00`:3@0>30l06QPK00`:3@0G5AP03@/>00l=400<2Pd03@/>00/9300>30l030X=01PF6@0/
:Rd06ALH010>3`0C4A802`T:01hL7@0>30d03`d>018@4@0<2P/03P`=018@4@0>2``03@T:00l;300H
51D03`/<00d92P0B3Pl00`0?2``02@0:1PL03PX;01LC4`0D4A00Ee=B010<2`0;1`H08AdL00l;2`0;
00h:2@0400d9200;1`H02`L600`81`803@T800<03@P800d71`0=1`L00`0=1`L01`080P803`T901PB
4P0C3@d03@L700`61P0=1`L00P0<1PH03`0>20P03`T900l92@0N61P07aTI010:2P0?2@T030H600/5
1@0=1`L030H6010:2P070P804@/;02TS8`0600d71`0H014;3@0>20X040X<00h82P080P@03PT:010:
300<1PP040X<014;3@0>20X04P`>01D:3P0D2@d03`H804Tn@P0I3Q803`@800`31@0?10P030850187
2`0E2Ph09a`P5?ooool001_ooooo00@020`=00`@4@0=4A80310A0P0:3Pl01`0@51D020`=00`@4@0D
61T02@d>01@H6@0=4A800P0?4a@0300=4A803Q8C00lC500N8R<0:Bd^00@82@0A5AH01`/<00dA4P08
30/04QHE01DI608020`;02005ATH01lS8P0Q9B@01PX9014E50072`X03A4@00h@3@0@4Pl03Q0=00/=
2P0A4a005aTF00`>2`072@H04A<@00`>2`0A4a005ALD01<E500H6QT02`d<00h@3`0A4a0010H300T;
200B50l04aD@00h@2`0<3`P0418=01PJ5`803a4>00<01`T601HH5@0<3P/01@0=3``0100<3PX03Q0;
00h@2`0;3@P200h@2`0K00d?2P0B50l03@l:01DG4P0h>SD0<C<^01<E400=3`X05aTD014C3P000@00
<SLa01/P6P0:3`T030h9018D3`0:30L02`d801<E400?4@`0418=00h@2`0<3PT04aD@00`>2@0=3`X0
3Q0;00<03a4<0P0B4`h02`0@4@`03Pl:00d>2@0=3PT02``701<D3`1ADTd06Q/F00L80`0D5A002`/9
00803Ph<00H04A4?00H6100B4`h03@h800l@2P0@4@/200h?1`0I00`=1@0E61403Q4:01/N5`0R9Ah0
3a8;01<F3`0>4@X02`h700X=1P0<3`P03A0900/>1`0<3@L04A8<018C3@0>3`T02``600`=1`0H6A<0
3Pl900/<1P092P@04A8<00<4000200d@2@803Q4:02003a8<00lA300;3@P05QPC00h@2`0620<03a4<
018D3`0<3PT04A<>00/=20072@@030h900lA300>40/02@/600/=200N81/04A<>00H70P0A40h06QHE
014@3P0@3`d02PT501PG4`0=3@P03@h801@E3`0C50`03a0801<D30803@h900L03a0;02<T7`0J6aH0
1PL2018C3P0=3PT03Pl:00804a@?00@0414<00d?300@4Pl03a4>0P0;3@X0400=3``051HC010B3`0B
51405ALD00L91P0F61@03@l:00L9100?4@`03@l:00lA300I6aH05aTD01<E400?4@`200d?2P0A010B
3@041P403Q0;018D3`0;3@P05QPC00d?2P0D5Q403@l:01<E400D5Q401`T4010B3@0C5A004Q@?00d?
2P0@4Pd00P0?4@`01P2BU8l07AlJ01DG4P0B50l03Q0;00hA2P804A@=00d03Q4:010C300J7AH06ahG
00d@2@0A50d05APA02@W800?4P/051HA018D3`0@4Pd04A<>00804aD@00<061XE01HH4`0B50l00P0?
4@`09`0@4Pd03a4<01DG4P0H6QD02@/6018D3`0G6A@07R0K01dO6P0?4@`04Q@?01@F4@0H6QD04QLA
020W8012BD809B`U01<J4`0P9b0061lH00lF3`0E71D051/D00lF3`0G7QL04aPD010E4@0D6AD0J6eY
01@I5@0?51005AXF01HK5`0@5A403a@@01<H500A5Q804aLF01@H5`0201DI60805a/J00d05ATH01dQ
800H71/04QHE01@H5`0F6QT06b4O01PN700P9R@04QPF01HL6P0G7A/06R0N00805adK0P0J81h00`0I
7ad05R0L01DP700401HQ7@0701TT800R;BT062<O01HQ7@0L9b<051lK02<];002020Z:@0601l[:`0V
<S807RXZ020^;`0R<S808C4a0P0N;C000`0Q<3<06R``01h`=00201la=@04020b=P0R=3P0838f020b
=P809CLk01@09cTm02/o@00U>cT0:T0n02Y0?`0Z?d00<TM802i3A@0^@dH0<dQ;03=8C00aAT/0<TM<
03E:CP0`ADP0;dA70397BP0aATT0=T]>03mDE`80>4e@00D0?eAG03U>D@0fBdh0>TmB03Q=D00203U>
D@1D0315B00eBTd0>DiA02Pm@00bAdX0?eAG0397BP0iCU40=4a>03=;C@0hD580>e=E03UAD`0kDeD0
@EUK049JG013Fed0@EUK041HFP11FEX0>55;03aFC@0nEe40>U=?03eFDP0oF5D0>E5A041HF013Fed0
BF5U03E=D@17Gf80AEUH03a@CP10E580AU]F03mDC`0mDT`0?55:03I;A00gC4<0?E9903iCBP10Edd0
@UUA045JD`12FeD0A5eJ04MPGP19HF40B61P04MOGP15GUX0@eaH049KE010FTl0@UU?04QPE011F4h0
AEaB04AKDP15G5@0NY6905ieKP18GeT0BF1J04QOFP10Ee40AEYC045FCP14FE00AeaC04AJC`14FTh0
>e55049HC00^A3L0>e5403aBA@0nE4L0=de103U>A@0kD4L0?E990P0nDd`05P0oE4d0?U=>03]@B`0h
CDP0?E5?049GDP0lDD/0?E9;03aABP12Ee00A5UB041ECP0nDd`0<TM003aABP0oE4d0<dQ103eBB`0f
BD<0?U5;0395?`0mD4X203U:A00:02/l=P0O;RT08c8]0350>`0a?CT0:SHb02He;P0U=2d0:STb02Dd
;@<093</00h08c8[01d/9@0W=Rl0:STb02Pf;P0X=B`09C8Y028_9P0P;B@07b`U02@a:P0P;BH07RXV
02<_;0807RXX00<08bd[020Y9P0L9B800P0K9240400I8Ql0624N01hW901QJVL0GVMT01PQ7P0O:2D0
61lO020U:00T:RX09R`/028X:00M8b408RPV024W9@0L8Qh201LM6@0601`R7@0K7b00:2`_04E9BP0P
92D0:bl`0P0A5A@03@0B5QD05AXF01LL600G71P05Q/E01/M6P0C5A807AlL01LI5P0B51405ALD01PJ
5`0F61D00`0D5Q<00`0A4a006a/I01<C4@0201DE4`0>00h>300F5Q@04Q8@00h>300K6aT05aLE01@D
4P0?3`d0410>01<C4@0D51804Q8@014A3`0C4a42014A3`804Q8@0P0C4a4601<A4P0601TG600@3Pl0
5aDF06m]KP1WIFH0518C1P0?3@h07P0;2@X03P`=010>3`0@3Pl03P`=00`:2`0H5QT09bDX03hl?`0Q
7b8040hA00T72P0;2@`04@lB01DC5P0>30l04Q0C00l=400C4A@030X=010>4@0?3A0020H901LE600=
2`h030X=01HD5`0C4A@02PP;00h<3`L03P`=00T02PP9010>3`0=2``040h?010=3P0:1PL03`/<014=
3P0:1PL00P0@30d500h:2`04010<300B3Pd04Ph=00l;2P8030P700L03`/:01HB4@0@30/01P81018>
3@0D40l03`/:00803@T800X030P700d9200=2@P030P700l;2P0<20L03PX900d9200810<03`X90P0?
2@T200`61P0400l92@0=1`L030H600d71`804@/;00l03PP800H0000B30`05a4A00d71`0<1PH03@L7
014;2`0I4a<02PD500/51@0A2`/03@L700h8200@2PX00P0>20P00`0S7Ad0Dde=00h8200200d71`0=
00`61P0=1`L03PP800/51`0E3a402`H700d72@0;1PL02P@600T31@0>20X02P@601LA4`0200l92`03
00h31`0H3A401`0000804PL;0P0=0PH01@0?10P05@X>01H;3`0?10P04`P<01Cooooo000Kooooo`0=
00T=3P0<41403A4B00`@4@0;3a003A4B00hB4`0S9bP020`=00T=3P0B5QL01PX;00`@4@0200hB4`80
310A00L03Q8C018F5`0J7Ql01PX;010D5@0;3a0041@E00804ADD00@00PH50496A@0f>ST000810P0N
8R4010072`X03Q8A00861@0:3Pd200X<2@0K00/=2P0G6AH0<38_03do?00M7a`030h;018D4@0?4@h0
418?00lA3P0N81l08bDT01PJ6@0L7Qd07R0M01<E4P0@4Pl02P`700P:1@0:30L04A@=01<E40010`00
3Q0=00lA3P0B5140418?00H03@l<00@03@l;00lA300?4@`030h90P0?4@`04P092`H04A<>01@F4@0<
3PT05aTD01TK5P0A4`h03@l:00T;1P0E5a80>3dg0<76`01]LV`05AXD00d?2P0A4`h02P`700H80`80
3a4<00d03@l:010B3@0?4@`03a4<00X<1`0<3PT03a4<014C3P0@4Pd03Q0;018C3P0A4Pd0414<00<0
3Pl:0P0:2`H06P0c=2l04Q<>00P9100D5A0051@B0000000F5Q@020P6014A3`0J6aH030d700h?2@0=
3PP030d5010A2@0A4PX04A@=00`?200B5@h05QTB00`?200>4@X04A@=00hA2P0<3`P03A090P0>4@X0
0`0?40X02``600/<1P02010A2`0700X;1@03100030d701DF400;30H03@h800h?2@0200`?20803A09
00`03Q4;00h@2`010`0030h900lA300H6QD01`T401PJ5@092`H03a4<00h@2`0<3PT300h@2`0700/=
200>40/04Q@?00/=200@4Pd0410>00/;2@02018B400U00/<1`0H6A@0414;00d>200?40X03a0800h?
1`0?40P03@h901LH4`092PD061TD01hO6P0O81/03a0;010A300?40/04A8=01@E400F5a803a4>018D
4@0A4a003Q0=00d?300?4@h00`D200`>2`0:30T05QPE01PJ5`0J71P071hI01@F4@0F61<03@l:00`>
2@02018D3`0:010B3@0>40/03@l:00h@2`0B50l02P`7010B3@0?4@`02@/600h@2`804A<>01404Q@?
00h@2`0?4@`061XE014C3P0C5A004Q@?00h@2`0@4Pd03a4<00H7100j?3L00`D001<E400c=C006adH
00`?200200lB2`0<00/>1`0<3`P051L@01XM5P0?4P/04aH?01TL5@0X:b@05QTB00lA300>40/03a4<
0P0A4`h0100>40/05aTD01DG4P0B50l200lA300Q014C3P0N81/02@/600P:1@0F61<061XE00T;1`01
0`002`d800lA300A4`h071hI01@G4P0F6aD0EeiG0?3gl01/Lf`06B0I018I4P0@5a0031<<01DL5@0F
7AH03QD>01<J4`0M8Qh061dI01/P701IGUX07B8N01TN6P0B5a<05AXF00804AHB00<05AXF01<H500D
61L0100D61L01@0C5aH061`K01lS8P0K7ah061`K00806QhM00L0728P018H5P083P`05A/I02P^;00=
4a406R0N008061hL00@06R0N01TO7@0F7a`05b4M0P0F8Ad301LR7P0?01TT800G8Qh051lK01TT800l
Ad<0:cHb024[:P0@6QT082XY02Da<@0I9BD06RHV01`Z:`0N;Rh07Bd]00806bX]00X07B`_01la=@0Q
<cL0838f024c=`0T=SX09CLk020b=P0R=3P09SPl0P0S=CT02P0Y?Ch08CLe02@j>00[@D00:d1102m4
A@0/@D<0;T=60356B@0bAd/203=8C@0H03A9C@0bAdX0<dQ;03Q=D00dBD`0=T]>03Y?DP0fBdh0=da?
03Q=D00dBD`0<dQ;03]@D`0eBTd0:d130397BP0gC4l0<DI902e2A@0oE5L0=4U<0315B00W?3l0>e1C
0P0dC4h01P0jDU@0?5AF03Q@DP0iDE<0>e=E03aDEP<0?UIH0240?eMH03aED@0nEe40>U==03YCC`0e
CTX0>eAA03UAD@0nEUH0?eMI04aTIP1;HfL0KXJ906MkNP1FJVP0?E5?03=8@`0dBD@0?E9=045FC`0o
E4d0?E9:041EC012Edh0?UE;045HD010FU80@EYD04=LF@16Ged0B61P049JFP13FeX00P14GET06`13
G5D0@UaA049IC`13Fdl0B5mE04ELDP16GE@0CFAL05E/I019H5T0@UUC04ELEP19H5/0B5mI04=HD`0l
DDT0?U=:041EC00oE4/0@5I:055WF`0jD4@0@EM:04ILC`0eBch0@EM:03]AA@0203]@A`0T03eBB@0m
DT/0?U=<045FC`0oE4l0?E9=03]@B`0nDU00@5AB03mDCP0mDT/0>Di703Y?B00iCTL0=4U203]@B@12
Ee00>Tm80356?`0lDDX0=4U203I9@`0eB480<TDo03I9@`0^?cT0<d@n02Tj=00L:bH07RdX02dl=`0c
?c/0;c/g02Lf;`0V=Bh0:STb0P0U=2d05P0X=c00:CPa02Pg<00V=Bh0:STb02/j<`0Y=bl09S<Z02<`
9`0P;B@07b`S01l/9@0Q;RL082dV020/:00S;b`082`Z01l[:@0O:RL07RLT01`U8P0J8b0201/T8@09
01lX9@0R:bP0CEIC051IEP0R:bP0:34^01lV9P0M8RD07bDU00808BLW01H08BLU020V900P9R@07B<O
01PN6P0G7AT06b4L01PL7@0I7B007B4R01LK700N8R<05QXI018F5@0D61L05a`H01XO6`0L8Ad07B8L
01`N6`0C5A806A/H0`0E5a@04`0D5Q<04aDB01<E4P0E5a@05QPE01DG500H61H04a<A01PH5P0I6AL0
4A4?01@D4P0H61H04a<A01@D4P0?3`d05ADC00h>300E5A<00P0B4Q000`0D51805ADC018B4002014A
3`804Q8@0P0C4a46018@4@0600/92P0D4Q<00@0001DC500I5aP04Q0A1P0@3Pl07P0>30d040h?014?
400@3Pl03@/<00`:2`0N71l05Q@G01TG6P0@3Q406QPK01@B5@0B41<02PP;00H41`0F51L040hA0040
0P0:20/04a4D00h<3`0;2@`04@lB00l=400@3Q403P`?01PF6@0E4aH03@/>010>4@L03@/<00/02`T:
00d;300;2@X03`d>014>3`0;1`P030P900h:2`0<20T040`=00d92P0500h:2`0500`8200<20L03PX9
00h:2@0=2@P00P0?2`X01P060P403@T801TE500B3Pd03`/:00`81`803@T800X030P700d9200=2@P0
3`/:01DA400A3@`040`;00`81`070`803@P80P0?2@T200`61P0400l92@0>20P03`T9010:2P803@L7
00@04@/;00l92@0G4A40618B0P0?2@T0100@2PX02P@400X410080P8201@>3P0800L20P090`<02`D5
00X4100600002`D501TC4`0>20P200d71`0<00`61P0=1`L03PP800d72@05004040/<01/E5`0<1PP0
71HH01XD5P0<1PP03PP:0P0400002@0I4aD03`@801D:3P0;00@03@8601462P0G31001`0001872`02
00L0000301872`07003ooooo01?ooooo000Kooooo`0?00`@4@0=4A803A4B00`@4@0?4a@04QHG014E
5P0S9bP03A4B00/?400?4a@02Ph?00/?400>4Q<03A4B0080310A03003A4B010D5@0;3a003Q8C00/?
400<41403A4B00dA40093@`02Ph=06Q/J`1MHF005ATH00hB4@0?4a802Ph=010D4`093@`05QXI010B
3`0>40d030h;010B3`0L7Q/092HS01dO70092`P03Q0=018D4@0F61D0418?00d?3P0A4a8030h=010B
4@0C5A8030h;00lA3P0<3PT03@l:010B3@0@4``04Q@?00d?300:30T030h;020R7`082PL600h@3@04
00h@300A4`h04A<>00h@2`804A<>01h03a4<010B3@0?4@`03Q0;00d?2P0?4@`03a0;01@D400@4@`0
51HA028W8@2NY9d0CeI?00hE3P042@<04A<>01LH4`0D510051D@00d?2P0<3PT04Q@?014C3P0<3PT0
2P`700d?2P0@4Pd04Q@?010B3@0=3`X2010A300600l@2`0>3`X03a0;010A300C50l030d80P0>3`X0
300=3PT03a0;018D4@092`P0CDm<00d?300>40d051HA010C300C5Pl03a8;00`?1P804A@;00X03A09
00lB2`0=40T02Pd600hA2P0<3`P05QTB010C300=40T03Q4:0P0@4``03@0>3`T0414;00h?2@0;30H0
3@h8018C3@0S91h03@h8018C3@0?40X03Pl900l@2P0<3`H00P0=40L300d@2@0?01@F4@0?4@d07R0M
00X;2@0@4Pl03@l<00lA300<3PT03a4<010B3@0?4@`04Q@?00h@2`0:30L03Q0;00804Q@?00d04QD@
01@J5P0D6aH03A@?00X>2P0?50h03a8=014D3@0?40X030d7018C2`0E5@d03`l700804A8=00<01PL2
01`M60061`800P0@4@`02@0A4Pd0414<00h?2P0D5A006AXE00h@3@0@4Pl03a4>00h@3@0200d?300<
00lA3P0;3@/04aDB00T;200C5A803a4=00h@2`0<3PT04Q@?00h@2`0?4@`0418=0P0=3`X300h@2`06
010B3@0>40/03a4<018D3`0H6QD05aTD0P0;3@P0100D5Q403a4<00/=200D5Q42018D3`0T014C3P0?
4@`03a4<00lA300A4`h01@L2014C3P0@4Pd092HQ010B3@0@4``04QD>01DH4@0B5@h041<<01<F3`0D
5a003a8;00hA2P0A50d06QdF00lB2`0@4Pd03a4<018D3`0E5a8051HA00lA300D5Q404aD@018D3`0A
4`h04Q@?01<E400=3`X04aD@0P0D5Q403P0E5a805QPC02<U80092PL08R@O020R7@0A4`h051LB00hD
3P12BD80VJ2I04U@B@0P9b002a8;0P0@5a00400K8Q/072<L01@K500D6a@04QLC00`A3@0@5A4082DQ
01<H500>4`l03a@@01@I5@0C61@051TE01LL600D6AD201DJ5P8051TE00h04aPD018G4`0D6AD05a`H
01DJ5P0G71P06b0L01LL600A5aD07bDS05ILFP0R:2H06b4O01dS8@806AlM00@06b4O01`R800I7ad0
51dJ0P0G8Qh01@0H8al06B@P01XU8@0J9B4072LS008062<O00X07BPT05YUH@1LIf<09c4b01dW:01:
E5D0BeMG01/V:00M:2X07R`]0P0M;2l05@0L:bh07B`a01h]<P0Q<cL0838f01la=@0P<SH09CLk02Tk
?`0X>Sh0:Sa002m1A@0/?T80:ce10355AP0S>CL09C/i03E:BP0_A4D0<4E602i3A@0202e2A@0=0397
B`0fBe00=T]@03A9C@0eBTd0>DiA03aAE00gC4l0=DY=03Q=D00jCe80>DiA03Y?DP02041EF00403Y?
DP0mDUD0?U=F03I;CP80=DY=00D0<dQ;03E:C@0dBD`0=4U<03]@D`0303Q=D080?E9E04/0>TmB03eB
E@0nDeH0?eAG045FF@13F5/0A5UL04=HFP0gD4`0@5UE03iGE017H5d0<da903aEDP0jDU80AEeM04IN
GP12FUX0?5AE045IFP11EE@0A5QF049FE013EeD0B5aJ041ED00hCDP0A5UC04=HD@0mDT/0A5UA03mF
C012FE40@EYC049KE@13G5T0AUiM04MOG`16GUh0B65O04YSG`18HEd0AEiG045KD019H5H0@e]?04YQ
E`0lDdT0BF1G041GC`17GUH0B5mH04UPFP1:HE/0B5mJ04ELE`10EE00@eQA04MLE@13F540?U=;04=H
C`0fC400?UA803]AA@0`AST0@eU<03eCAP10ETX0?U=:03eBB@0nDdX0@5E>045FC`15FU<00`12Ee80
2P0oDe40?51>03aAC00lDD`0>Tm:03iCCP10EE00?55<04MLE`13F5<203aAC080?E9=00l0?U5;03I9
@`0gBT@0<D@n02m0>P0Y>S@08S<]02<b;@0Y>3<0<T4l038n>P0]>CD09SD^02Lf;`0/>c@00P0]?3D0
2P0Z>C808C0Y024`:@0W=Rl08S4Z024`:@0V=2`09C8Y02@a:00S<2P2028_:00@020/9`0R;RX0930^
028^;00U<Bl0930^01dX9@0L9B807BHS01/T8@0J8b0072DR01hW900H8Ah06R<P02</:@806b@Q00<0
82LW020U:00N92@00P0M8b<06P0P9R@0728P01dS8@0L8Qh06AlK01LM6@0I81X06alP01XN8@0I7Ah0
61`M014E5P0S9bH07b<R01hR8@0J7a/05Q/G01@I5@0C61807AlL01XL6@0K7AX051HC01PJ5`0D5Q<0
5ALD0P0D5Q<00`0F61D05aTF01HH5@0201@D4P0301`L6P0M7A/05ADC008051@B00/04Q8@01/K6@0G
5aD06ATG014A3`0J6QP04Q8@010@3P0E5A<05aLE01<C4@03014A3`<04Q8@1P0B41401P0?3@h04Q0A
01@B4`0?3@h040h?00l=3PH04@l@01h040h?014?400@3Pl040h?00l=3P0>30d03P`?014?4P0@3Q40
4Q0C01HD5`091`X03`d@01<A500@3Q402PP;02@R9@1VI6L09R@W00T72P0C4A@030X=01<A500;2@`0
30X=00X82`0@3Q403`d@00X82`0<2Pd800`:2`0:00/92P0?3@h03`d>014>3`0?2``04@d>00d92P0A
3@h05A4B00`82@D03PX;00d03`/;014=300B3Pd040`;00h:2@0?2`X04Ph=01hJ6@0`;2/03P/:018?
3P0c;bh08QhM00803@T800H030P700d9200=2@P030P7014=300?2`X200h:2@0400/71P0?2PT03PP8
00l92@803@L701H040X:00h8200?2@T03`T900/51@0:10@03`T900/51@0>20P03`T900`61P0=1`L0
3PP800`61P0;1@D040X:00l92@0<1PH03`T900h8200=1`L03`T90P0B30`05`0<1PH03PP800d71`0=
1`L030H600d71`0>20P040X<05MAD`0H4a@03`X;01TC5@0=20T030H8014<3@0910D01`83014<3@0B
3@h060dC00h42@0J3aD04@H<00803P<900H04@H<00d4200K41H0200301D<400Q5Q`Dooooo`006ooo
ool03`0<41403Q8C00dA4P0<414041@E01@H6@0B5QL02@d>00lC500F6Q/01`/<01DI6P0=4A803a<D
00hB4`0200dA4P0D00lC500O8b@041@E01@H6@093@h02`l@00lC500B5QD01PX901DI600>4Q403a<B
00861@0B5QD03a<B010D4`0=4A001PX900hB4@0?4@h2018D4@0I00lA3P0;3@X02`d:00/=2P0:30T0
418?00lA3P0E5a@04Q@A00`>3@0>40l03a4@014C4P0C5A804A<@010B3`0C5A00418=00`>2@0F6A80
7R4L05QJE`0>40d03a4>020R7`02010B3`D03Q0=00@03Q0<014C3P0A4`h03Q0;0P0A4`h05`0@4Pd0
20X500<5000@4Pd04aD@010B3@0?40/040l;018C3P0>40/000<000`C300@6Q803QD>00`A2`0A50h0
4A8=00l>2P0=3PT02`d800lA300@4Pd03@l:00<03a4<00@03Q0;00d?2P0=3`X03a4<0P0?40/200h?
2P0R00l@2`0@4@`05AHA01@E400;30L05QLB014B3@0;30L04aDB00T;200C5A801`T6014C400=3`X0
4A@=01TL5@0G6Q<04QD<01HI400?4PT02`h701<F3`0A50d03Q4:01DH4@0<3`P04aH?00lB2`0<3`P0
3A0900lB2`0>4@X03a0:014B3080414;00X04Q<=01DF4013A3h0414;00X;1@0@4@/04Q<=00`=1`0?
4PT03a880P0?4PT0:@0?4PX03a8;00/=20092`T061XG00430P0C5A@061XG00`>2@0:30L05aTD01HH
4`092`H03@l:00T;1P0K7AP02`d800h@2`0J71L00@H0010M5`001@000a09018M5`0B71@07RDN00lC
300@4@/03a0:01DE3@0E4P/03Ph600`=200C50l0414<01LH4`0S91l0JFYU01DF4@0?40/03Pl:0080
4A8=00<0414<00lA3P0@4Pl00P0A4a00200@4Pl03a4>01`N6`0:30T03a4>00X<2@0;3@X051HB0P0?
4@`00`0@4Pd030h900/=200200h@2`0A00lA300@4Pd03a4<00h@2`0@4Pd04aD@00d?2P0<3PT04A<>
00d?2P0@4Pd0?T0k01`N6@0=3`X051HA018D3`0b=2l00`0@4Pd200d?2P08010B3@0=3`X03@l:00lA
30051`804aD@00X=1P0=40T2014D3@8041<<00`05APA01LJ4`0A50d04QD>01@G400C5Pl05QPC01@F
4@0C5A0051HA01DG4P0D5Q42018D3`0T014C3P0B50l04Q@?01<E400E5a806adH01@F4@0G6A@04Q@?
01`N6@2DUY40;S0[00X;200D5Q4030h900`@2P0X;bP000L001lY8@0C7AD0:38Z014K4`0?6A403QP@
010J4P0?6A4031H>00hE3P0F6aL051TE01XO6`0>4`l06AhJ018G4`0A5Q805Q/G0P0D6AD0100F6aL0
4AHB01DJ5P0E6QH201HK5`805a`H00H051TE01HK5`0E6QH061dI01dR7P0H7AT201`R800=071fM00h
?S`03A<A018H5P0H7Q`06AlM01/Q7`0L8R0061hL01<L6@0F8Ad05R8N01LS7`0201TU8@0>01XV8P0L
:2@09C4]024]:@0I9B4041`H028^:P0O:BX031HG02@^;`0P:bd062<U02@_<@0P;S4201l^<@<08C0e
00D072hb01la=@0P<SH0838f028d>00202Li?@0a02Dg>`0V>3`093Hj02Hh?00/@44083Hd02Lm>`0a
AdH0:3dn02a1@P0_A4H0;D9502a1A00aATX0=T]@03E:C`0dBDh0=daA03Q=DP0eBTl0=4U>03E:C`0g
C540=DY?0356B`0fBe00@UML045FF`10EET0>TmB0397BP0gC4l0@UMJ03U>D@0cB4/0KhB703I;CP0Z
?d808SLj04AIG00jCe00>Di?03]@D@0jCe00>Di?04EJF`0nDe@0?E9C03iCE002045FE`0j03aADP0d
C4`0?EEE03mGE`13Fe/0<TY:03iFEP0mEU<0@EYG049KF00jDe00?eQE04AMFP0mDE00@EED03eAD00n
DU00AUYH041DDP16FeH0FVmZ05M/I@0mDT/0?U=<03eDC015G5@0@eeE04AME`15GU/0Af1N04UQH@1;
Hf<0CFET04eVHP1;I600AEmG041JC`15G580AeiC04ELDP12FDl0JX5h04YQF@16GED0@UUB04ELEP1;
HU`0C6=N04ILF@11EU40AU]E04MLE@19GUL0K85i09baZ018GE@0:d4f03I<@080A5Y>01L0?E=7041F
BP0nDdX0?U=:045FC@15FU<0AeaE04EJD`13F5<0A5UD04EJE@0oDe40>Ti<04AIE012Ee80?U=>03mD
C`0nDdh0>Di908bQW02dbL@0B5eH03]@B`0203I;AP0?03Q;A@0eB480<D@n0395?`18FE<09CH`01l`
:P0Y>3<0;chi030o>P0]>CD0:cLc02`k=00^?CH0;chg0080<3lh00@0:STb01l^9`0P;bP0:CPa0P0S
<R/03@0T<R/07b`U01l/9@0P;BH07b`U01l[9`0M:BD082`X028^;00O:bX082`/028^;P0P:RP00P0N
9b@0:P0M9R<06R<P01XS800P:BH0:34^01`U8P0O:2D08R/X01/T8@0S:RX08RLZ028X:00P9RH07R@T
01`R800J81h0728P01`R7P0I7a/05adI01TO6P2CUiP0If]^02P/;@0R9RL07b<T01TM700E6AP051PG
01<H500D6AD05AXF01PM5`0D5Q<05ALD01dO700B51404aDB01@F4`0H6QL05QPE01DG50805QPE01<0
4aDB01DE4`0E5A<06QXH01TI5`0F5Q@05aLE024Q7`0<30X071`J01DE4`0820H03`l=01@D4P0C4a40
410>00l?3@0B4Q005ADC00D04A4?00<0410>014?400A3a00100A3a001P0D4Q<02`T:01PF5`071@H0
3P`=014?40L03`d>00D03P`=00d;300>30d040h?014?400300l=40802`T<00`05aDH00l=40010080
3`d@01LE600/:Rd0NGMj038`<`071@P06ALJ00X82`0@3Q4200l=400300`:3@0?3A0040hA00803P`?
1P0>30d02`0@3Pl02@L800T7200A3a001@<400/82@0=2@X05A4B014=3P0>2P/0510A00H03PX;00d0
4Ph>01HB4@0F4Q404@d<00d9200<20L03PX902dY:019AD@03@T800<0000L61L04@d<00803@T800H0
30P700d9200=2@P02PH5018>3@0A3@`200X61@0400P40`0<1`L03@L700h820803@L70P0@2PX01@0=
1`L03PP801<=3@0D3Ph030H600802`D500H040X:014;2`0?2@T03@L701<=3@090`<200L10@0901D?
3`0=20P03PP800d71`0:10@02@<300X4100=1`L03PP800803@L700X030H600d71`0>20P040X<048l
?P0;1@L0100000P2100?2@/050h@0P0:10H03`0I4aD0;2HX0=WCe@18?D<04`T>00l42P0;00H04`P>
01@93`0J3aD060dC0146300G3180B3e301873@0Dooooo`006oooool01P0<41403Q8C00hB4`0=4A80
3a<D018F5`803A4B00D020`=010D5@0=4A803Q8C00dA4P0200lC500C00dA4P0>4Q<03a<D01`P8@0B
5QL041@E00dA4P0<414051PI00dA400;3`h05ATH00P;2P0N8R4061`K010D4`0?4a804ADD00hB4@02
00`@3`0<00h@3@0=3``03Q0=010B3`0B51404aDB00h@3@0F61D061XG00`>2`0?4@h030h;0P0:30/2
00h@3`0>00d?300?4@h0418?00d?2P092`H051HA03/n=`0o@Sd0LG=`01PJ5`0C5A804Q@A00h@3@0;
3@X500lA3P0400h@300@4Pd0418=00d?2P80418=01h030h900h@2`0B50l04Q@?00/=200=3`X0410<
00X91@0@4@`05aTD014H4@000`003AL?00`F3P0@5@l041<>00d>2@0=30P03Ph900d?2P0@4Pd03a4<
00/=200@4Pd04A<>010B3@0=3`X02`d800`>2@0?4@`2010A300500l@2`0>3`X03Pl:00l@2`0<3@P0
0P0?40/02P0G61<04A8=00`=20082PL03Q0=00830@0<3P/04A<@00d?2P0;3PL201HI4P0M01<F3@0I
71<04A@;00X=1P0A50d04QD>010C300D5a0030l800lB2`0=40T030l800d@2@0>4@X03A0901@E3`08
2@<03@h801dN600O81X03Pl902<T7P0>3`T04A8<00h?2@0A4P`04Q<;014D2`0A50X00P0@4`X03@0?
4PX03a8;010B3@0A4`l03@l<01PJ6@041PD03a4>00d?300B50l0:R`W02LY900@4Pd00P0C5A00600f
>3<05ALB00P:1@0R91l02A09051RFP1@I5/04R<K00TG400D7aL04Q`D00hD3@0>4@X04A8<010@200@
3@H04A4900h>2P0@4@`051D@01<D3`0H6A@0DeA?01HG4P803a0;00l04Q<>00l@2`0;30L030h;00/=
2P0<3P/03Q0=00d?300;3@X0>C/h02PZ9`0A4a005QPE014C400>40`00P0A4`h0100?4@`030h900`>
2@0@4Pd2014C3P0@010B3@0?4@`03Q0;00lA300B50l030h900d?2P0>40/04A<>01/M6016B4<071hI
00h@2`0C5A001@L202h`:`803a4<00`04A<>00d?2P0<3PT03a4<01`N6@051`805aTD00h@2`0A4`h0
3A0900hA2P0A50d201<F3`04018E3P0?4P/05aXC014D3@8051L@00P06ahG01@F4@0B50l03a4<014C
3P0B50l04aD@014C3PD04Q@?00L030h901LI500P8Qd06adH0043000`<Rd0=CLb00804A<>00`071hI
01hP6`0C5Q4000L001lY8@0=5`l03QP@00PB2P002P804adE010J4P0=5`l200`F3P0900dG3`0A5Q80
4QLC01HK5`0=4Ph04aPD00lD400C61@05a`H008051TE00<05Q/G018G4`0E6QH00P0F6aL01@0G71P0
6AhJ01TN6P0D6AD061dI00805AXF01806AhJ01LL600B61H06b4O02X`;P0U:bT06b4O010F500I7ad0
61hL01XP7P0K8Al06AlM01@M6P0E81`05B4M01HR7P0H920201TU8@0?05UUH@0U<Bd04alK02lk=`0D
81`05b<O028/;@0G8B8082X[01/V:00S;S00:3<e01l]<00L:bh07Rd`00808C0e00<07bhc01d_<`0R
=3P00`0S=CT04@0^@4@0<TA802do@`0[?D40:3Xn02Xl@00/@44093Xh02a2@00_A4@0:d110356A`0a
ATP0;dA702i3AP0`ADT0<dQ=0080=4U>0P0fBe005@0aAT/0<dQ=03E:C`0iCU<0=T]@03=8C@0hCE80
>TmD03eBE`11EUX0=T]>02m4A`0hCE00A5UL04MLG`0mDUD0AEYM03M<C`0eBTd0OiBG04IKGP0203]@
D@0Q03aADP0iCTl0>4e>04EJF`11EUL0?eAE041EEP14FEX0@eQI03eBD`0lE5H0>E5C03Q@D@0iDE40
?EEE03iFEP0lEE80>U=@041IE@0dCDT0=Tm;03E>BP0iCD`0?E5@049FE@18G5X0BemM049FE013F5<0
DfQS05AYHP0oE4d0@EI?0080AUeE0100A5iF04ENF015GU/0B61O04UQH@16GUh0B65O04URGP18HEd0
AEmG049LD@15G580BV5F045HCP14Fe40JH1g0P1:HET06013FU<0@eYD04YQF`1<Heh0AUaI04EJE@19
GUP0AEYC03aABP14FE40GgA[0315?010ED/0<dTm04AJCP0lDTH0AUa@03mEB@0nDdX0?eA;049GCP15
FU<0AeaE04AIDP<0@eQC00h0?e=A03a@CP0mDTd0?55<03Y?BP0nDdh0?eA?03Y?BP27W9L0Ykbg04IK
EP14FE@0=T]603iCCP80?E1:00H0>di8045DCP1WN780=TM102@e;`0V=C0202Dd;`0802lk=`0d@3`0
=4<l03A3?00_?SL0;C`e02/j<`0V=Bh202<b:`0502He;P0T<b`09C@]02Hd;@0T<BX00P0U<R/04@0T
<BX08bl[01l[9`0M:BD082`Z028^;@0K9bL07BTY028/:`0O:2D07RLT01lX9@0N9b@072DR01XS800V
;b`07bPU008072DR00L05AhK01`S8`0O92L08BLW028X:00Q9bL07R@R0080728P00X0728N01TO6`0H
7QX06b4L04iBD`0k?d803Q8C01XN7`0F6Q/06AdL0P0F6QT02@0F6aL05a`H01PM6@0I7QP05aTF010B
3`0H6QL04Q@A010B3`0201HH5@805ALD0P0G6AH04`0F61D05ADC01HF500G5aD05QHD01DE4`0H61H0
3Ph<02HV901UIF<0HV9P02h^;00=3@/04A4?01<C4@0B4Q003`l=014A3`0E5A<00`0A4@l3010@3PH0
4Q0A00H06ALH014?400I5aP030X;01<A4P0B414600l=3P06014?400?3@h03@/<00h<3@0A3a004a4B
0P0@3Q404`0?3A0020H900@21@0H5QT02`T<00d;3P0>30l040hA00400P091`X0518E01HD5`0E4aH0
1`D801<A500>30l03`d@00/9300<2Pd00P0>30l00`0=2`h03P`=00h<3@0400h<3@0:018@4@081PL0
20H700d;30010000514B00`82@0A3@h040`=00T51PL03PX;00@03`/;010<2`0A3@`03`/:0P0<20L0
1`0:1PD020@301/G5P0D40l01`<201@@3`0@30/00P0=2@P0100<20L03@T800d9200;1`H201HB4@06
00d9200>2PT030P700h92@0=1`L03PP80P0=1`L01`0A2`/04P`<00h8200@2PX06Q@D01/E5@0>20P0
0P0=1`L04@0@2PX03`T900X4100<1PH04P`<00l92@0G4A40100000L10@0E3`l03PP8014;2`0D3Ph0
40X:00h8200?2@T03PP800803@L701/030H600d71`0>20P0100001/E5`0=20T05@lA00H10P0L5QP0
3PP:00h92P06008040X<01@?402DSY00=b`b01<83P0A1P`04`P>01052`0:00D01`0200l42P0;00H0
1`0202<H7P0900@05?ooool001_ooooo00d02`lA00hC500?51D03A8D00`A4P0=4Q802Ph@018F5`0:
3Pl03A4C00/?400A5AH0310A00803Q8C0100310A00dA4P0>4Q<02@d>014E5P062P/04ADF00@82@0@
51D02`l>018F5@0<40l02`h=00lC4P062PT0310?0P0?4a80200>4Q404QHE00T=300?4@h03Q0=00lA
3P0@4Pl03a4>0P0>40d05`0I6aP06Q`I010B3`0C5A803a4>010B4@0=3`h04Q@C00lA400;3@X0418?
00lA3P0A4Pd03a4<018D3`0Q8ad06A/F01TK60082@L03a4>00H81@0B514030h;00D03a4>00@03Q0<
00lA300?4@`030h90P0?4@`0100<3PT05QPC01`N6@0C5A0200d?2P0B00l?2P0A40`020T4018D3`0=
4`d06R4J00XB2`0;4``0314;00d?2P0A4Pd04a8>01LG4`0C5A003Q0;010B3@0>40/03@l:0`0?4@`2
00h@2`0400d?2P0B4`h04Q<>010A30<03Pl:00L03a0;00X;1P0A4Pd04A8=00h?2P0=3`X030h;0080
3a@@00T02a0<010E4@0=4P`02Pl901DJ4`0@5@l02Q0701<H400;4@P00P0?4P/01`0A50d04QD>018E
3P0B5@h02`h700`?200>4@X00P0A50d03@0=40T03@h8014B300H6A<06a`F01DF400:2`D03@h800l@
2P0A4P`02@X4010A2`0?40T00P0@4`X0:@0?4PT03a8:00hA2P0>4@X04A<>00`>2P0>40d02@/905EG
E@0O8Ah04aDA00lA300P8Qd06adH010B3@0[;BP08B<N02PZ9@0<3PT03Q0;034c;P0I8AX0SYnG08jQ
V00L;bD01QL>00PD300;4``03Q@<00T=1P0D5Pl0414:01TG4@0/;BH03`l:01DF4@0C50l03a0;00P9
1P0@4@`04A8=008051D@01T04A8=00h?2P0>3`X03@l<00/=2P0>40d04Q@A010B3`0=3``05QPE00T;
200B51401`T701@F4`0<3PX03Q0;010B3@0>40/03a4<018D3`0C5A004A<>00lA300>40/03a4<0080
4A<>01P04aD@00d?2P0@4Pd02@/601HH4`0[;BP06Q`G01<E400>40/03@l:00`>2P0C5Q003a8<00hA
2`0B50h030h900/=200B50l061XE018D3`0?4@d051LA00h@2P0C5Pl3018E3P0?018E3@0A50`02Pd5
01LJ4`0?4P/04A@=00h@2P0K7AL0418=00lA300@4Pd04aD@018D3`0?4@`04Q@?00<04aD@01X04Q@?
014C3P0H6QD0<S@_01XL5`0E5a804aD@01HH4`0G6A@05ALB018D3`0A4`h03Q0;01HJ500i@3T0@Ta4
00`F3P0D7AD04Q/C018L500C71@04Q`D010J4P0@6A404Q/D018K4`805Q/F00X041D@01TN6@0@5A40
51TE018G4`0E6QH04QLC01<H500I7QX061dI0P0G71H201HK5@805AXD00d05a`F01hS7@0J7aT05AXD
01LL5P0H7AT051XH01TO7@0@5Q@0:Bl]01TO7@0H7Q`06R0N008061hL0P0J81h06@0G81d04ahL01@P
7@0E8Ah05b<P01PT8@0I9B805b<P01dY9P0C7a`07b/X028^:`0I9B807bTZ01`V9`0Q;2`09c8d024/
<00J9bX07Rd`01/Z;`0M;3408S4f024`=@0O;c@00`0Q<cL03`0R=3P09SPl02Pj?P0U=c/093Hj02Li
?@0V>3`09cTm02]0@@0Z@3h0;D9202a2@P0hCDh0?E9C0356B0020397BP090315B@0_A4T0<TM<03=8
C@0fBe00=daA0397C00eBTl0=daA0080=T]@04P0?E9G045FF`0cB4d0@UML06f2QP1MLGD0@eMJ03Y>
DP0aATT0>TmB049HF`0`AdT0?E=F049GFP23V9/0A5UL03aADP0nDe@0@eQI03eBD`0gC4d0?U=D045F
E`0oE5D0@EIG04QMGP19GUh0@EIG03eCE`0^ATX0A5aP05M_LP1eSHl0AemP04AMFP0dCDX0?UMB03I?
BP0hDDX0?eQ@04iSG`14F5L0@EEC04AHEP13EeD0AEUH04YNF`17G5P0AUYG04EIE@14FE<0A5]D04IM
EP14GUH0A5eG04ENFP17Ged0B61O04aTH`1;I640BF9N04MPF`15GUL0@eeC04MNE018H5@0@UU?04EL
DP1;HUT0C6=K04IME@17GUL204MNF00<04UOF`1:H5d0AeaG04IKEP19GUP0B5eF045FCP10EDd0?eE:
06UnL`0nE4P0JX1d0P11Ed`01010ED/0@EI>049GC`12Edh2049GD00J041ECP12Ee80@EIA03iCCP0n
DU00@5AB03eAC`0oDe40?U9@04AHEP17FeT0@eME04AHEP10E580=TY803iBD00eBDL0=T]603U<AP0_
@S`0>4]503A7@@1IJV@0:CXd02Lh<P0Z>C@202Lf<@0403I3?`11CTX0<T4j0391>P80:cXc00D0:3L`
02Dd;@0Z>C809cH_01l^9`02028a:`0Y028`:P0V<b`09c@]02Ld;P0U<Bd08bl[02<_;00O:bT0:3@b
03A0?`0P;2/072PX02D_;@0M9R<06b<P028[9`0W<2`08BXV01`U8@0T;BX09Rl/01hX9@0Q:RP08R`[
020W:00O9BH082HU01lU900M8b806b4N01hT8P0N9240728N01PN6P0I7a/07R@O01PL7@0Y;Bl05QXK
01hR8`0G6a`00P0F6QT01`0G6aX06AhJ01TN6P0I7QX05a`G0412?`0Q8b000P0H6QL01@0B51405QPE
01/M6P0I6aP05aTF00805QPE00@04aDB014A3`0E5A<05aLE0P0F5Q@0200G5aD05ADC01PH5P0M7A/0
6a/I02<S8@0G5aD05ADC0P0B4Q0201DE4`<04A4?0P0@40h200l?3@0301<A4@0C4A804a4B00<04a4B
00H03`d>014?400@3Pl03P`=01@B4`0>30d6014?400N01/I6P0G5AH040h?00l=3P0A3a004a4B014?
4P0G5AP030X=01@B5@091`X03@/>00l=400B41<03`d@00h<3`0G5AP05Q@G00d;3P0>30l04@lB018@
4`0<2Pd03P`?010>4@0<2Pd02PP;00h<3`0?3A003P`>1P0=2``0300>30d02PP900d;300=2``05A<D
04=0@@0E4A802PH7014=3P0:1PL03@T:00l;30D03PX;00X03@T900d;2@0?2`X03P/:00h:2@0?2`X0
4Ph=010<2`0>2PT03@T80P0@30/300d9200T00`81`0=2@P03@T8018>3P0U8B008alN018>3@0>2PT0
2PH500`71P0=20L03PT800d71`0>20P04@/;00d71`0<1PH03PP801<=3@0D3`l04@`;00d7200<1PL0
3`T:00d7200<1PL07ALH03`f=`0C3@h08A`L01H@4@06004030H600X51@0;1@D03@L70P0?2@T200h8
20803@L701/030H600d71`0>20P03`T;00d82@0?2P/03PT:00l:2`0=1`T04Pd>01PB500B30h03PT:
02@N800G4A<03P@901@:4@0?1@/04`P@01063@0R61l04@H>00d42P0D2Q004@H>00`42@0G3A@05?oo
ool001_ooooo00H03QHI00TA4`0U;Bl09Bd`00`D5`053@l200hC5`0G00hC5P0?4QL03a<G00lC5P0?
4a@03A4@014E500B5QD06alN020T8`0;3`h03A4@00X>3@0?4a8041@C00`@3`0A4a803Q0?00`>3@0=
3`h0418A018D4`0?4A000`0@4Q403P0>40l03@l>00X<2@0?4@h05QPE010B3`0C5A80418?00P:1`0B
514030h;01dO7029RhP06Q`I0P0;3@X0300E5a@030`:00X:200C4a4030`:010?3@0>3@/04A0>018A
3`0>3`X02a0:00`A2`803A8<00P0314=00dB3P0?5100310?00D9200;3`h02Ph=00`@2`8030h900D0
2`d800lA300C5A004Q@?00h@2`0200d?2P0L00h@2`0?4@`0418=01<D3`0@4@`03Pl:01dO6P0N81/0
4A<>00h@2`0@4Pd04A8=010A300A4Pd06AXE018D3`082PL010H100X<1`0;3@P061XE00d?2P092`P0
1PP301HH4`0:30L03a4<00h@2`8030h900<03Q0;014C3P0B50l00P0A4`h0400?4@`03@l:00`>2@0?
4@h02@/8014C400O8Ah0;Bl/00`>2`0;3@X051HA01@F4P092`H02P`700/=200A4P`2010A2@06014B
2P0@4@T03Pl700d>1P0;30@041490P0C50`02P0G61803Q4:010B3@0@4Pd04Q@?00d?2P0>40/02@/6
00d?2P0F61<2010B3@0800/=200;3PL041<<00X=1P0@4Pd03Q0;00lA30072@@2010B3@0I00d?2P13
AD40:B/V00h@2`0=3`X03a4<00T;1P0V:2<0JF]V010B3@0L7QT04Q@?00/=200I6aH041D>01TP5`0S
:R8051/C00L<1@0<4@X03A8;00X?2@0C61802@h:00h@3@02014F4P0>00hA2`0;3PL03A09010C300?
4P/03A0901<F3`0D5a003a8;00`?200I71D01PP300h@3@0=3``200P:1`0?01PJ5`0F61D0418?00h@
3@0<3P/04Q@A00`>2`0>40`04aD@00lA300<3PX05QPC00lA300@4Pd04aD@00803a4<02T051HA01LI
500D5Q401`P300h?2P0E5Q40414<01<D3`0@4@`02@X502HW8P12@ch03@h90001000@4P/03a8700lB
2@0?4PX03a4<00lA3P0<3P`05QPE014C3P0@4`/05AP?018E2P0?4P/03A09014D2`0B5@`03A05018E
2P0>4@H07b8I02d`:@0=3`X01`T601@F4`0?4@`03a8;014D3@03018E3P1=01HI4P0C5Pl041<<014D
3@0D5a005QTB01LJ4`0b=Bh092LP0085000@4``061/D01HI4P0C5Pl04QD>01HI4P0G6Q<051L@01XO
6@0E6aD04QTB05aQF`0D6Q@03QD>014F401>E4d061lH01hS7@0D6Q<02Pl901HK500L8AX06AhG01<H
4@0?50h04aPB01@I4`0C61<051TE01HK5`0E6QH04QLC0088100K8Ad05A/G01`R7P0F71P04ALC03Pn
>P0^=30061hJ01/Q7@0E6aL03A<?01LM6`0J81h07B<Q01/Q7`0G7A/051XH020V900E6aT092XX01@J
600T:RP051dL01XU9@0K9bL062@T01LS8`0P;2`05B4Q01XV9P0K9bL06BDU01hZ:P0L:2P00P0O:b/0
500Q;Bd072XZ01PV9P0I9bP06RXZ01h]<00P;c807c4c01h`=00L;S806R``02<f=`0Q=CH093Pi01hb
<`0[?d008SHg01lc=00L<3409c/l0P0]@D803`0/@D80:3dn02Xo@P0bAdX0=4U<0315B00]@TD0;dA7
0356B@0dBD`0<dQ;0397BP0`ADT0<4E:03=8C@0203M<D@1U03I;D00hCE80A5UN04iSJ01KL7D0=DY?
05U^L`3FiNP0dn3V09:QYP0kCE40@eQK03M?D@0lEUL0>59C03=<CP18GF00@UMJ03]>DP12EET0?U5E
03a?D`0oDUH0@UEI041DE@11EEH0@UIG04]OGP1<H5l0@UID03iBDP10EEX0@5AK045EG@1OM7T0LXN:
04]PHP15FeT0@5ID03A;AP0dBdD0?5=;03eDB`0nEDd0A5]C03iED01CJFH0BV1N06j3Q02=XZD0B5eP
04IKG@1dRHX0@eQI04AJF019Ge`0@5MA04QOF@13FU@0AUaI04UOG01=Hf00CfER051WH@1?IV00C6=M
04QOE`1>IE/0BV5G04ELDP14Fe<0AeiF04YQF@16GEL0@UUC041GD@13FEH0B5iK04YPG@19GE/0AeaG
04aQFP16Fe80B5iA03aBA@0cBC`0@5I:02e3=`1ZOgH0@EI@04IKEP0oEE80B5mI04=JE012FE40AeiD
04IMD`10Edd0<dY203aCC@1<HUh00P0nE580700nE540>U1=041FD`0iCd`0?E5?07>7Q@0nDU00A5ME
03Q;B@0kCT`09CPf03M:AP0iBT80=DHn03A5?@0cA3`0834[02@e;`0S=2h0:3Pe02dm>P0_?c`0>4Q5
0391?P0fACd0;chg02Pg<00V=Bh202Th<`0D041?BP0O;RT08C0/02@c<00V=C80?4Y602Xf<P0O:bL0
82`X028^:P0Q;BT08RhZ02<_:`0T<2`08bl[01l[9`0M:BL08BTV024W8`0N8al201dT700K01/U700L
9ah062<M02@_:`0H8b<0?TU=0;>na00b>C`07R<O028W8`0L8Ad082DQ020U800M8Qh07B8L02T^:00F
6aD06QlI01`Q702UYjH0HfET01`N7@0J71/061XI01TK6P0C5A@051HE00806Q`K01`061XI01hP7P0J
71T05ALD01HH5@0H6QL04aDB014C400L7Q/0=3Hc04]=BP0O8Ah01`T601HH5@0H61H03@d;01XJ6006
1P@06ATG01LG5@0F5Q@05ADC024Q7`051@<05QHD00/;2@0@40h04A4?0P0B4Q00100A4@l03`l=01HF
500G5aD201lO7@0A01TI5`0H61H03`h<01@C4@0J6AL061LE018A400E4a@03@/<00`:300I5aX04@lB
01HD5`0D4QD05aDF01<A4P0A3a000P0B4140200?3@h04Q0A010>3`0?3@h04@l@00l=3P0>30d03`d@
0P0>30l0400?3A0040hA010>4@0?3A002PP;00h<3`0Q7b807Q`O00l=400>30d01@<401HD5@0<2P/0
0`4201@B4`0<2P/200h<3@0400d;300<2P/03@/<00`;2PD030/902004A0>00H50`0?3P`03Pd;014@
3P0?3@`04@d>01<?400=2@X03PX;00l;300E4A80100101@@4@060P<06aLH00<0000=2P/02PX:00T7
200<2``020H700H41@0>30d02PP900X61`0<20T03@T:00d72@0>2@X03`/<00h:2`803`/<00X040`=
00h:2`0=2@X03`/<00h:2`0;1`P03@T:014>3P0<2`T02`P70P0?2@T05P0D2``05Pd>01892P0<1PH0
3@T800d<2P0>30`02PD901@?4`0<1`/03PT=014<400@2`l03`X>00`72`0Y92P050lC01D@500810H0
2`D500X50P0<1`@2014<2@802`H300P050l<00l:1`070P0020<001@>3@0>20X03@L900`620803PP:
01<030H800/51`0A2`d0208400l92`0A2`d04P`>00@0000H4A@02P@600d42@0?1`/0208400`3200>
1`X02`D700X11P0?1`/05a4C01Cooooo000Kooooo`0900041P0G8B<0[kVk0;o9b`0L9BP05QhQ00/C
5P0<4aH03A8F00803Q4F00X03Q8E00861`0B5QD010P701<G5P2@U9<0J6a[00lC4P0A5A@0310?0P0=
4A002@093@`04A<B00h@3`0=3`h03Q0?010B4@0A4a803@l>010B4@02018D4`0V00lA400=3`h04aDB
014C400:30T02@/800h@3@0B51404A<@00`>2`092`P05ALD04U;B00>40d02@/800lA3P072@H04Q8@
01@D4P0000003@`:010?3@0=30X04Ph=01<?3P0>3PX0314:00`A2`0=4P`0314;00`A3@0?51000`P4
00P<2`0C5aH01`/:02da<00?4`l2010B3@803Q0;00d03a4<00d?2P0;3@P02`d800d?2P0@4Pd04A<>
00`>2@0?40/04A8=00X;1P0A4Pd04a@?00803Pl:00<03a0;00h?2P0=3PT00P0>3`X03@0=3`X051HA
00/=200:30L05aTD00P:1@0=3`X051HA00@60@0;3@P051HA00lA300>40/00P0=3`X0100>40/0418=
00d?2P0>40/3010B3@0800lA300J71T04A<@018D4@0>40d05ALD00lA3P0:30T200lA3P0W00`>2`0?
4@h03@l;00l@2P0@4@T04A8:010A2@0>3`L03@h601<D300@4@T04A8:00l@200;30@03Pl700h@2`0F
61<0418=00T;1P0F61<04A<>00`>2@092`H01PP300T;1P0>40/051HA00h@2`0B50l02P`7010B3@0<
3PT03a4<018D3`0>40/04A<>00<5000E5a80004000803a4<03D04A<>00/=200S9B00Gf5L01`N6@00
0@004aD@01@F4@0;3@P030l801<D2`0?40P020T1018C2`0H6a@04A@=01@F4@0F6aL000D101DI6006
30X01@/700lB300<3`P03A09010C300>4@X030l800`>2P0B5@h01@P1014D3@031P005APA00`>2`00
0@007R0M01@F4`0=3``01`T600`>2`0;3@X04A<@00X<2@0A4a002`d900P:1@0=3`X05ALB010B3@0B
50l04aD@014C3P0200h@2`0800lA300>40/04Q<>00/<1`0>3`X0414<00/<1`0?40/200h?2P0M01hO
6P0_<2/05aPC00l@2`0B50`03a<500lB1`0?4PX03a4<010B3`0@4Q406Q`I00P:1@0V:B402@`101HJ
3@0A50/03Q4:014D2`0A50T03A05014E1`0D5``06ahC02ha:P0S9B802@/800`>300@4Pd00P0A50d2
018E3P0@01<F3`0B5@h04A@=014D3@0C5Pl051L@01<F3`0E614061/D01TL5@0@4``030l801HI4P0E
614051L@01<F3`805APA010051L@01<H4P0?50h03Q<=03Hk=@0<4@/03a@>01<H4P1hOGL0<3D_010E
3`0E6Q@05AXC00hC300C6@l051X@0P0B5a00400F6a@04QLA014F4@0C61@05Q/G01LL600E6QH09B/W
02le<@0H7QX05adI018H500A5a<051XF01PN6P0?5A4201HL600>01LM6@0G7A/06AlM01XP7P0I7ad0
5A/I01@J600C6AL05A/I01PN700C6AL06AlM01LP7`0M:2T301TT9P0601LR900=61X062<U01PS9@0@
6ad05R4S0P0M:2X0100K9bL07B/[01l];@0N;2`201`/;00302@c=P0Q<cD08C<e00808C<g00<08S@h
024e=P0O<c@00P0O<c@0;@0Z?Sl0:cm002Pl?@0V>S/0;D5202a0@@0W>c`0:Ci002a1A00^@dH0<TM:
03=8B`0bAdX0;D9502a1A00_A4L0<dQ;03E:C@0dBD`0<TM;0397C00eBTl0>4eB03U>D`0hCE80;dA9
041EFP0lDEH0IW^006EjO`1bQh`0h_3c0=ORj022SI<0BeaP04=HF`0lE5H0G7Ig06J2P`0nEeT0>DiA
03=8B`0hBdl0@eIJ045DF00203iAE@0`03mBEP0nDU<0@UIG049FE`1:GUd0BUiL049FE010E5<0>4eB
03U=E019GFD0NXnD08^PX`1?I6H0?59@03]AC`0cBTD0<dY403]BBP0nED`0<dY004=JDP19H5/0D6IT
049GF014FE`0HgQm03iCF01GK700Q9VL05I[KP1=HV<0A5YG04ELEP1CJV@0CfIP04eTGP15G5H0C6=M
04iUG`1?IV00CVEO04]RG019H5P0B5mG04MNE015G580AEaD0P16GED0A@17GUP0A5]E04=JE016G5T0
BV1M04]QGP18G5X0BUmI04eRF@12Edh0@UQ;03aC@`0mE4@0Bf5C03iDB00oE4d0AU]E045ED`14FUP0
BV1M04ELEP12FE80A5]A04=JD011F4h0>E1803YAB@15FeP0?E=A045GE@0oF5@0AUaI041FD`0jD4d0
Ef]Y09>WY@1=HEl0>Da:03I9A`0iC4X0=4M5049ED@0fAch0:c`d03Y;@`0a@SX09SLa02Pi<`0N;bT0
9SHc02`l>@0a@Ch0>TY903=3@00`?cL0;chg02He;P0P;bP09C@_02Th<`0X=c806BPU03Y9AP0X=c@0
62HV01dZ:00K9b<05b<O01l[9`02024]:@808bl[01@0930/02<_:`0P;2P07b/W01`U8@0I7QX06AhH
01`R6`0P:1d07bTN02H`:00S;RP08BdY01XW:00[>3h0NhR@038j?00W;2H08BHP028W8@8061dG0180
5a`F01HK5@0S:28061dG01hS7@0Q9R40IfUX0453@P0O8B008R@S01hP7`0H6QT051HE01DG5P0B51<0
4aDD01TK6P0E5aH201lQ7P0F01`N6`0J71T06adJ01`N6`0F61D0828O03Dg=00H6QL04A<@01HH5@0P
81h04A4?05UIE`18B4H09BDS014A400b<S0051@B00l?3@0F5Q@04Q8@01TI5`@04a<A0P0D5182014A
3`0F01LG5@0H61H04Q8@01<C4@0H5a<04a8?014@3P0@3`d05A@C02<Q8P0e<c@06QPJ00l=400F51L0
20H:00P62@0C4A@040h?00h<3@0?3@h03P`=00`:2`804@l@0P0@3Pl200l=3P04010>4@0?3A003P`?
00h<3`<03`d@00/03P`?00d;3P0E4aH04a4D00X82`0B414071XK00T7200B41406QPI00H41@0600l=
3PH030/900T01PD3020O7@1<BdT01@@300P71@071@D04Ph?01<?400?2``00P0A3@h04`091@H01P83
010<3@091@H01P8300D10P0;2@X02`/;00`<300:2PX02@T900`:2`0>30d030X;00`82@0>2P/03`/<
00l92`0=20T00`0;1`P200`82@0C00d92P0?2``040`=00d92P0<20T03PX;00X820092@L040l=018<
300A2`/03@@501<:2`0A20T03PT9010<2`0?3P`02`/:00L21P0200/6300:01@?5@0E41H0L6]a00X5
2`080`T05a8H00D01P0?2Q002PD:00l92@803PT600`03`X700h91P0;1P<04@`901HA3P0B3@X03PT6
00X50P0;1@@03PP:00d72@0<1PP200h82P0300`6200C3@l04P`>00803PP:00h0100000l92`0S7Al0
6aDG018<3P0D3Q003@L900l92`0@2P`04@/=00l92`0@2P`07aTK02lY:aCooooo000Kooooo`06018L
7@094A80=Cm004M?D@0?5QP0CUIH0`0<4A@200dA500=00dA4`0=4A804ADD010D4`0M8B00X:BS03Hj
>@0;3`h041@C00`@3`0;3`h03A4@00/?3P0200lA4080418A0P0?4A000`0>40l0418A014C4P02018D
4`0J014C4P0B51403@l<00X<2@0E5a@020X701LI5P0B51401@L400d?300@4Pl01@H400lA3P0>40d0
418?00X<2@0@4Pl05aLE01DE4`0>3P`040l=00d<2P0A3@`04Ph=00h>2P0>4@X200lA300@00h@2`0=
3``02`d:010B3`0Q8b8071hM02HX9`1IFeX03Q0=00X<1`0;3@P03a4<00h@2`0=3`X03a4<00h@2`<0
3@l:00P03Q0;00d?2P0F5a806a`G010A300>3`X04A8=010A30804A8=00l03a0;00d>2@0>3`X04A<>
00X<1`0;3@P04Q@?010B3@0:30L03a4<00/=200@4Pd04Q@?01@F4@0F61<0100?4@`00`0>40/03@l:
00lA3003010B3@803a4<00P0418?00P:1`0?4@h03Q0=018D4@0=3``03a4>010B3`803a4>00/0418?
00`>2P0>3`T04Q<;01HG3`0@4@T030d500d>1P0<3@D03Pl701<D3002010A2@0=01LH4@0I6aL02`d8
00P:1@0b=2l02P`801<E4@0:30P04a@@00X<1`0L7QT03Q0;00d?2P02014C3P0300/=200@4Pd030h9
00804A<>00D01PP301PJ5@0A4`h061XE01hP6`0200h@2`0H014C3P0;3@P061XE0412?@0g>C@02`d8
00lA300@4Pd04Q@?018E3P0C5@/08R<K01TJ4P0=3PH03Q4:014D3@0=3`X03a@@00/@300>4Q4051PF
01HL600A4`d03a8;0P0>4@X03@0=40T02`h7018E3`0=40T061/D00/>200K7QL02Pd6010B3`0:30T0
3a4>00h@3@0B51400P0>40d0>P0B51403a4>014C400E5a@03@l;00D70`0M7aX0=SPc01@F4@0;3@P0
3@l:00h@2`0=3`X03a4<010B3@0?4@`04aD@00l@2`0A4Pd03a0;00d>2@0C50l03Pl:018C3P0?40/0
3@h901DF4@0C50l03Q0800hB1@0?4PP041<;014C3P0A4a00418?010B3P0H6QD0K6mW014D2P0?4`L0
41<:010C300B5@`041<800hA1P0A5@L041<800`?100G6Q<0;Bl/00X<2@0D5Q@051HA01<F3`0B5@h0
4A@=018E3P0E614200hA2P09014D3@0C5Pl04aH?00lB2`0B5@h03a8;018E3P0G6Q<051L@00804aH?
01@05APA01HI4P0C5Pl04QD>01DH4@0Q9R005a`F018G4@0?50h041D?01PM5`0;40X061dG014F400F
6aD05AXD00/@2@0G71D05Q`B01<I3`804QL@01<03a@=01HK5@0E6QD05AXF01HK5`0D6AD04AHB01LM
6@0Q9b<05adI01DK5`0F71P05adI00lE4@0I7a/04QPD01PN6P0G7AT06AlK00805adK100F71X00`0J
81h07R@R01PN700201PN700X01hW9@0F8B805b<S01PT900E8B405b<S020/;00I9BD082`/04=?C`0]
>CT04QhN02Da<@0O:b/07B/[020^;P0R<3007Bd]01XZ:P0S<SD07c4c01h`<P0O<CD08C<g028d>00Q
=3P0:3/o02Lj?P0Z?D408cHj03]>DP0iC500:ci202Hi?@0/?d<0=DQ<03=7BP0[@4<0;T=602e2A@80
:d1300<0;D9502i3AP0`ADP00P0aATT01@0`ADP0<4E90397C00dBDh0=daA0080=T]@01P0>TmD0315
BP0mDUL0AEYO03U>D`19GV<0LX:808JAU`1CGfD0A5AI03Q<D00lDUD0>eAE03UCE00iDE<0BUmR04EJ
G@0oDUH0?4mC03iAE@10DeL0?U9C03mCE013EeP203iBD@0P049FE@11EE<0?E5?03iBD@0eBT`0?55E
03eBEP0nDeL0A5UK03Y?D@0hCT`0?59@03aBCP0iD4/0?eI@04ELEP0nEDh0?eI?049HE@12F5L0BUmP
05EZK@1:Gf@0@eQL04YOH@1CJ6X0AU]K04ILF@0oEE40DVUS05Q_J@17GUP204QOF@0804YQF`1<Hed0
CFAN04eTGP1<Hed0BV5I049ID014Fe4204IMD`1:04IME014Fe<0B5mG04MNE`17GUP0BV1M04aRG`1;
HEh0@eQC04EJE01;H5L0?eA;041FB@11F4P0?5=303Q?@@1?IET0KhAm049GD@15FEH0BEmM04]QGP17
GUP0@EQA041GC@0oET`0@UU?049ID@0iD4P0?UAA03eCD@12F5D0>eA?045HDP0iD4X0>U5;03M<A`0m
DTd0=da704EHE00fBDD0@5=?03Q;A`0aA3h0=TLn02`m=@0`@CT0<d@l05Y[I@0eAT008S<]02Lg=00X
>3D0:c/h0392@@0V=S<0:SXa02hm=P0V=Bh07bhW028a;00U=2l0:CPc02Lf<`0c@Sl07B`Y02<a<@0T
<Rl08BdY02@`;00X=3008BdY01l[9`0R;RX302<_:`0L028^:P0Q;BT08b/W02<X900Q:2408RTQ02<Z
8P0O:B007RPP01lZ900T<2`0<3`m02<^<`0O;3<07RHX02L/:00P9280724M020U8@0I7Q/061`J01HK
5`0L8Ad06QlL01lT800N8b00828Q01hP7`8071hM00d06adL01TK6P0K7A`06Q`K01HH5`0G6AP07R0O
01/M700F61D07b4N01XL6@0?4@h05aTF00806Q`I00l0418?01TK600B51407AlL01@F4`0L71X0410>
028R800D51805ADC01@D4P0U9B<04a<A01TI5`19BDL00P0D5180100B4Q004a<A01<C4@0D518201DE
4`0A010@3P0>3P`04A4?014A3`0?3`d04Q8@014@300C4Pl061LE01LF500@3`h04@l@028P8@0F51H0
3P`?01`J7@1:B4`00P0E4aH03P0C4A804Q0A01<A4P0B41403`d>00h<3@0C4A804Q0A00d;300>30d0
4Q0A018@4`0@3Q403`d@0`0>30l03@0=2`h04@lB00l=400=2`h03`d@010>4@0:2@T05aDF038`<@0V
92D02@L800l=3P0>30d00P0<2P/200d;300300h<3@0=30X03@`:00@03@`:00L040l>01`K6P19B4H0
4a8@00P71P0B40l04Ph?00804@d>00D04Ph?010<3@0>2P/04Ph?00/8200200l;300301<?400>30d0
2@T900<030`<00T040h?00`:2`0>30d03PX;010<3@0A3@h04@/=00l:300>2P/00P0?2``03P0>2P/0
3@T:00h:2`0?2``03PX;00d92P0<20T03`/<00d;2P0:2PP03@/900`61P090`<04@P90P0@1`P01`0@
2PX04@d<00h=2`0:2PP03`X>014<400=20`00P0A31005P1ED5@050lC00d8300;1PX020@700X52@0?
2Ph030H700h8200?2@X03@L800h8200C3@d04P`=00d71`0:10D040X;018<300>20T03`T;00h82P0=
1`T200l92`0C00d72@0910D040X<00T31@0C3@l04@/=00`7200;1@L040X<01@>400A2`d03`T;00X4
1P0;1@L03@L900/51`0910D02`D7010:300Dooooo`006oooool01@29Ti@092d_00TA4`032`d02@hA
0080314D100=4A@03@0=4A802Ph?00`@3`0A5A@0004001<G5P0@51<01`/:00`@3`0:3Pd0310?00hB
4@0=4A000P0?4A02010B4@0Q00lA400>40l0418A00d?3P0<3Pd03a4@01@F5@0F61L02P`900/=2P0<
3P/03a4>02d_;01jO7T030h;00T;200E5a@03@l<00D7100D5Q<02@h:00P=2@093PX051HC018D4@0A
4a004A4?014@3P0=30X03Pd;010?3@0?3`X03a8;00803a4<01803Q0;00d?300<3P/03@l<03<e=00`
<S4030h=01lQ8015Ad@051HA014C3P0D5Q403Q0;00X<1`0>40/03a4<00h@2`0<3PT200/=200700lA
300D5A004Q<>00h?2P0@4@`04Q<>014B3@02018C3P04010A300>3`X03Pl:00/<1`803Q0;00T00@<0
00L9100C5A003a4<01@F4@0M7aX03@l:00@60@0D5Q40100?4@`00`0=3`X030h9010B3@02010B3@0D
00lA300>40/03@l:01@F4`0B51403a4>00D7100D5Q<04A<@00lA3P0B51405ALD00lA3P0;3@X03Q0<
010A2`0E5Q0061TC014B300=3PP200l@2P0i010A2`0B4`d0414;00d>200C50h051HA01<E400^<2/0
Kg5/018D3`072@@0DUA?0453?P0H6QD07b4L00T;1P0<3PT03a4<00h@2`0=3`X04aD@00d?2P0F61<0
4aD@010B3@0>40/02@/6018D3`0F61<04Q@?014C3P0E5a804A<>01@F4@0W:B@01@H301HH4`0@4Pd0
2`d801<E40041`0051D=018C2`0D5@d06Q/E018E3P082`@04Q@?00lD40042@D0CU=?0;Jl^00]<bl0
41<=010C300?4P/03A09008030l802004QD>00D80@0G6Q<05QTB00d@2@0I71D05QPE020R7`14AT<0
JVaY00T;200A4a005aTF00/=2P0=3`d030h;00d?300M7a/05ALB014C3P0E5a802@/600L9100D5Q40
418=00d?2P0?4@`04Q@?01<E400C50l03Pl:014B3@80414<00`05AHA00l@2`0C50l0414<00l@2`0@
4@`03Pl:014C300?4PL03a89010C2`0A50d2014C3P0M01DG4P0O8A`05aXB01DH3`0B5@X030l600lB
2`0@4`X03a87010C200C5`T04aH;01DH3@0<3`P05aTF00<50P0?4@l05QPC01@G400B5@h04A@=018E
3P0E61404QD>010C300?4P/041<<014D3@0@4``00P0F6A805`0D5a004aH?01DH4@0F6A804QD>01DH
4@0G6Q<04QD>014D3@0E6140?T<m02T^:00E6Q@041D?014F400;40X02@h802@Y8`0H7AL02@h801HK
5@0@5@h04QL@00804AL=00D05AXC01PM5P0H7AH06AhH01LL5`0201DJ5P07018G4`0=4Ph02a4=01HL
600M8al05adI01TO6`0201@J5P0N01DK5`0?5A406b4M01hT800M8al06AlM01PN700F71X05adK01TO
7@0J81h0728P010F500N92806R0N02`b<00P:BH072LW01PT900M:BT0:3@d01TU9@0M:BT072PX020/
;01BGUh0<3`l00TE5@0T<3008Rh^0P0K:BT04@0N;2`07Bd]01`/;00R<C@08C<e028d=P0S=CT08S@h
024c=`0Q=3X06Rdc01LZ<00W>T00<TE;03Y=D`0S=S`09CPn0080;D1600H0;3m502e1AP0`ADP0=T]>
03E:C@0_A4L502i3AP80;45400<0;dA80397C00cB4d00`0cB4d0?@0^@dP0A5UN0356B`0eBTl0?55F
02a1AP18FEh0=dE805i/K`0mCU00BUiO03Y?D00cBd/0@EUI03mGE`18GEh0@EIG03]?D00gBTh0>TeA
041DE@0oDe@0@5AE04EIF00oDe80@EED045ED`0mDDl0?U9@041DDP0lDU00?E9C041EEP15FU/0AE]I
03iDDP0iCdd0@EME049HEP0lDU00?eEB04MMFP1?IF80@EMD04MMF`17G5d0AEYM04eRI@18GF00E6U/
05Q^K@1DJVL0DVUS04ELEP1DJfD0AeiH04YQF`1>IEl0EFaV049ID`1:HE/0101;HU`07@1;HUX0AEaB
04EMD014G4l0AEaB04MNE018GeD0AeiF04IMEP16GEL0BF1J04YQF`18GeT0AEYE03iCC@17G5<0@EI=
03mEB00lDTD0;dDh03]AA@16G500<4Dn04MLEP0aAT40AE]I04EKF015G5H0@EQA0080?UE;0300@EQ>
045HD00lDd/0@UQE03mED`14FUL0=Tm:04]RG010Ee40=Te704=HD`17G5L0AU]F03e@C024Ui<0//G1
03M:AP0nDD/0=dPo03M8@00a@SX0<T<k069cK@0/?CL08c@^02De<P0V=S<0<d=0049BD@0fAT<0:SXa
02Lf;`0V=Bh093</024`:`0L:bH09C@_01@S800a@3d0:STf01XX:00M:bP07BTU024]:@0S;b/07BTU
01l[9`0T<2`5028^:P0n01hX8`0J81`06R4J01dV7P0P:R808B/S020Z8`0M:28082/W020[;00S;S80
51lU02T`=00K7ah07b<T01`P800R9RD06alO01dQ8P0L81l061`L01/O800I7A`061`L01`N7@0O8B00
61XI010B4@0E5aH061XI01LI600E5aH06adL01LI600>40l071hM02PZ9`0d=S<0:bdZ01PJ5`0J71T0
5ALD01hP7@0C5A8051HC01HH5@0G6AH051HC02h^;00G5aD04a<A01lO7@0H61H03Ph<010@3P0?3`d0
2PX802PX9P0@40h05QHD01<C4@0G5aD201`L6P0401XJ600F5Q@04a<A010@3P804Q8@00X04A4?01HF
500L6aL04A0=00d<2P0<2`T03@/;01<A4P071@H05A<E0P0G5AP01`1JF5`05Q@G010>4@0?3@h040h?
014?400@3Pl00P0<2P/02@0B41404@l@00/92P0=2``04@l@018@4`0@3Q403`d@00h<3`0300d;3P07
00`:3@0>30l04@lB018@4`0D4QD030X;00D3100200P61`0300/92P0C4A803@/<00802PP90P0=2``0
0`0;2@X03@`:00d<2P0400d<2P0901<B40040`400@0001@C4@0;2PP0518A010<3@0>2P/03@T:0080
30P900`040`=00L3100K5aP03`/<028N7`0<20T04@l@00<30`020P8030`<00/;2`0;2@X200`:2`05
00d92P0?2``040`=010:300>2@X00P0=2@X01@0<20T02PH700T51P0;1`P03@T:00802`L800L030P9
00d92P0;2@P01@@202HR8@0_:BT04@/;00<03`H701l03PP800`81`0:2@L02`X800T4200A31003@P<
00h93@0B3A402@D801@?4`080`L03PT=020K7`080`L02@@800/52@0=1`T03PP;00`62P0>20X05a4D
01H@500@2P`03`T<01<=4@0A2`d02P@700l92`0>20X03@L900803`T;00@03@L900h82P0@2P`02`D7
0P0<1PP03@0T7R00:B<U00H10P0?2@/03@L900T31@0400002@<500h82P0C3@l04P`>00l92`0=1`T0
5?ooool001_ooooo00L051hO0003100D71h01@d?01DK7P011PT03A8E00@03Q8E00d03Q8C01LK6P0;
3`h03A4@01HJ6@0B5QD04ADD00dA400>4Q402`l>00hB4@0?4a802Ph=00H03a4@01H0418A00`>3@0:
30/03@l>018D4`0E5aH0;c4^010B3`0?4@h02@/800d?300k?CX0418?00lA3P0F61D02``:010B3`09
2`P02Pl;010E4@1DFED0DeEB0P082PL01`0D51804a8@00h=2`0?3P`04A0>00l?2`0?4P/00P0?4@`0
300=3`X030h;00h@3@000@003@l>00lA400A4a804Q@C04a>B`0>40/02@/600lA30803@l:00X03Q0;
00/=200;3@P030h900d?2P0?4@`051D@018C3P0<3@P03@h90P0C50l200l@2`0?010A300>3`X030d8
00d>2@0>40/05ALB00d?2P0:30L09BLR01`N6@0K7AP051HA01LI500<3PT01`T400<03a4<0`0>40/0
1@0=3`X02`d800`>2@0?4@`0418=00804A<>02@00`D200T;200F61D02P`900lA3P0=3``02P`900h@
3@0D5Q<03a4>00/=2P0C5A404Q<>01@E3`0E5Q00414;00l@2P0@4@/03@h800/<1P0?40X0414;00h?
2@0A4P`05ALB00d?2P051`806adH014C3P0?4@`061XE01<E40041P404A<>00lA300F61<200d?2P0R
00lA300F61<03Q0;01LI500<3PT04aD@00/=200:30L03@l:0084000>40/03@l:010B3@0?4@`03Q0;
01DG4P0O8A`05aTD018D3`092`H04A<>00lA300A4P/02@X200X;0`0B4`d04A@=00hA2P0<3PT0314=
00lD401DFED0bm7=04I=AP8041<<01d03a8;00d@2@0<3`P03A09010C300?4P/0;2lX00T<1@072P<0
2@`500d?2`0E5a@07AlL04e?C0010`00418?00D7100U9b@0F5YG028T8@031@802@/701HH4`0>40/0
2`d800`>2@0;3@P061XE018D3`0200h@2`803a4<02L0418=00h?2P0B4`h03Pl:010A300D5A0030d8
00l@2`0@4@`051D@00h?2P0<3@P04aD>014D2@0A50/04A@<010C300@4Pd05aTD0001000=40T03a8:
00L:0@0A4`h030l8010C300A50/03Q46014D2@0C5`T030l401@G300A50d04aDB00h@3@0@4Q005ALB
01@G400B5@h00P0A50d0100C5Pl051L@018E3P0@4``2018E3P0:014D3@0K7QL03A09018E3P0G6Q<0
2`h701PK500C5Pl051L@01DH4@804aH?01T05APA02L/9P0H7AL041D?01DJ500C6180314;01@I4`08
3@L02a0:01PM5`0M8Q`02a09018G400B60h04AL=018G400E6Q<05a`E01DJ500D6A@051TE01DJ5P0D
6AD04AHB00805A/G01806R0L00lE4@0F71P05Q`H02D[9`0O9B404ALC01TO6`0F71P03aDA01XP7P0I
7ad061hL01TO7@0K8Al0728P01lU8`0A5aD202P^;00?0457A@0_>3D06RDT010L700L:2P0A51@02Da
<@0D8200930`024];@0W<c<07BTY01XV9P0R;Rh082`/00806BLW00`07R`/028b<P0S<c<07Rd`020b
=00R=3H08cDi020b=P0O<CD07S4g01lb>@0U>3h202Pk@P0C02e0A`0R=C/093Ln02/nA@0Z?D<0:Ca3
02e1A@0`ADP0=4U<03I;CP0bAdX0;dA702e2A@0[@4<0;45402i3AP0`ADP0<DI903=8C00303E:C`80
=4U>01@0=DY?03]@E@0W?440:d1503Y?E00/@DH0<45504aKGP2ga/T0BeiP024e=P0cB4T0AUaM03]C
D`0aBDT0>4e>03U>C`10E5D0>diB03e@E080@5AE00`0?e=D045EE00nDU40@EED03mCD@0jCT`0>dm=
03eAC`0jD4d0?eEB04ILFP0oEE<203I<BP0H049HEP18GU`0B5iL049HEP15FeT0C69P04QNG00oEE<0
@eQH04aQI017G5l0E6U/04AIG01=HV<0CVAQ04UPFP19H5P0?eI>04YQF`16GEL0D6MQ04]RG01<Hed0
BV5K0`1<Hed204]RG00P04]RFP18GeD0AemB04EMD015G580AeiD04UPEP17GUH0AEaE04AKE@16GEL0
B5mI04MNF01<HE`0@EI?04YOEP12Edh0>U140398>`0lDTD0@UQ<05=XG`1GK6<0CF9K03M<A`12F5H0
@EMD04AKE@12FE80?eI<041GC@11F4h203mFCP0L04AJE`14FUP0DFMT03iGD@17GUP0Bf9L041GD@0m
DTd0=DY503]@B`0oDTh0RYfI0;K9a@0_@Sh0<D@n03U:@@0cA3`0>T]301h_9`0R<bd02Q/E02<d;P0T
=3408c<`0310?@10D4l0<D4n02Xi<@<08S4Z00d07B`W01l^:@0S<Rd05RDR03Q7A00U=3407B/[02Hc
<@0R;RX08BdY01l[9`0H92006bLS00808RhZ00P08BdY020/:00P;2P082`X024[9P0O9B407B@M01dV
7P807bTQ018072HO01TT800J92<05b8Q020[;@0E82@082L[014E5P0E6AX07B4R01DI6P0M8B806QhO
01dQ8P0G6a`0720Q01PL7@0I7Ah201lQ800T01XL6`0E5aH05aTH01HH5`0H6QT05aTH01dO7P0K7A`0
4aDD01/M700D5Q<07AlL01`N6`0D5Q<05QPE01<E4P0G6AH04aDB01DG500I6aP0418?01HH5@0S8b40
7QhL00l?3@071`D05QHD01<C4@0B4Q005QHD00`<2P0@40h04Q8@01HF500?3`d051@B0P0G5aD0100C
4a403`l=018B400?3`d2018B400C014A3`0E5A<05aHB010?300B4@l051<A01<B4@0E4a@01@<401DC
5@0>30l01`D801<A5@0B41<040hA010>3`0B41404a4B018@4@0200d;3008014?400@3Pl030X;00d;
300?3@h04Q0C010>4@0?3A0300h<3`0400l=400:20/03@/>010>4@8030X=00`02`T:01LE5P0C4A80
5Q@E018@4@0610D040h?00d;300?3@h04Q0A00l=3P0<2P/600h=2`0700`;2@0D4a402`X800L6100G
5Q@02PP800l;300200d92P0H00/7200A3@h07a/L00<0000?2``07ATJ051<C@0H51D010<301@D500?
3`l02@T900d=3@091`P03@/<00/92P0<20T03@T:00l;300?2@/040/<014=3P0?2``03@T:0P0;1`P2
00d92P0=00`82@0=2@X03PX;00d92P0=2PX00`8001lK6P0Z92@03@L700l71`0?1PL040L800l72002
00/71P0=00/:200>2P/05A0D018=4@0?2Ph03@P<01D@500>2@d020<701<>4P0Z9BT03`X>00d83002
010:3P0;00h8300;1@T030H:014;3`070@D02`D900l93@0>20`030H:00h9300@2Ph00P0>20X05@0?
2@/040X<00d72@090`D01`8301/E5`0C3@l04Pd>06IPHP1lMWP05@lA01TC5@0L5QP040X<01D?4@0:
10H02@<500L10`080P@02`D700h82P0Dooooo`006oooool01P0740l031DD00dF5@083@d03A8B00L=
3@<0310A0`0>3a400`0;3Pd03A4@01DI600200hB4@0400`@3`0A5A@03A4@00dA40806AdL00P04ADD
014C4P0>40l03@l>00h@3`0@4Q404Q@C00d?3P<03Q0?0P0=3`h02@0G6AH03@l<00lA3P0A4a00418?
00d?300@4Pl02@/800d?3002014C400O00X<2@0>4`l04aPD030e<@0f>SL0418?00lA3P0F61D05ADC
00l?3@0@3`d04Q4?014A300A4P`04A8=010A300>3`X03@d;010@3P061P@05ADE00l?3`0<30`03`l?
024R800G6A@030h900h@2`0:30L02`d800h@2`0200/=200600`>2@0=3`X03a4<01@E400B4`h03a0;
0P0B4`h00`0?40/03@h900l@2`02010A300900l@2`0@4@`0418=01DG4P0<3PT07AlJ05=ED00Q8Qh0
7b4L00803@l:00D02P`700lA300@4Pd03a4<00h@2`0200d?2P0400h@2`0A4`h03@l:00h@2`@0418=
02l0Ce5>01hP7@0>40d061XG018D4@0=3``03Q0=00X<2@0>40d0418?00/=2P0=3``04Q<>014B300>
3`T03@h800l@2P0@4@/061TC00l@2P0B4`d05QLA01<D3P0?40X0418=00h@2`0;3@P03Q0;018D3`09
2`H030h900d?2P0@4Pd03@l:00h@2`0<3PT03a4<00h@2`0C5A006Q`G00`>2@0D5Q403a4<00d?2P08
2PD04A<>010B3@0200lA300400`>2@0?4@`04A<>00lA308030h901H0418=01DG4P0>40/04Q@?00lA
300@4@/03@h801HG4@0O81X05QPC00`>2@0@4Pd02@h8014F400?50h08bXS01/R6`0>4@X041<<00lB
2`0=40T03Q4:0P0@4``00`0]<2X0FUeF01<F3`02014D3@0601<E400@4Pd02P/801<E400F61<051HA
0P0@4Pd02P0K7AT030h900d?2P0E5a803@l:01@F4@0C5A002@/6010B3@0A4`h2010B3@0@018D3`0C
5A00418=010B300@4@/04Q<=00l@2P0H6A<08B8L01PI4`0I6Q@051D?010A2`0C50h03a0:010B2P80
4aH=01P04QD=010C300?4P/03A09018E3P0A50d041<;01@G3P0@4`X041<<01DH4@0C5Pd03A0500lB
1`0>4P@05QT>00/>0`0A50d0418?01TK600D5Q@04Q@?01<F3`0B5@h2014D3@0;010C300D5a0051L@
01LJ4`0H6a@05aXC014D3@0F6A804aH?00lB2`0B5@h00P0D5a000`0F6A8051L@01<F3`0201HI4P07
01@G400A5Q003a@>01hS7@0B5a403a@>01DJ500201HK5@0L01@I4`0I7QP04QLA01LL5@0D6A805adC
01DK4@0B5a005Q/D01dR6`0F6aD05AXE01DJ5P0F6aL051TE014F4P0I7a/051XF01dS7`0=4`l05adI
01HL600A5a<06R0L01@J5P0K8Ad061hJ01LM6@<06AlM01H06R0N01/Q7`0K8Al06R0N01TO7@0L8R00
7R@R01lU8`0K92408B`[01dY9`0@71X0;CTg01hZ:00J9R@082`Z02<_;@0D81h07BTW02Da;`0O:bT0
82`/0P0Q;bl0600P;Rh08S8b02@d=00R<C@07c4c020b=00R=3P08cDi02@e?00T=cl09SQ203A6C`0Z
?DH0:Sa602/mAP0Z?4D0:C]502/mA`0[?DH0;d5;03E9C`0aATT0;T=602m4A`80<dQ;00X0<DI90315
B00`ADP0<TM:03A9C00eBTd0=T]?03E:C`0dBDh0<dQ=0P0bAd`04P0dBDh0;dA903Q=DP0cB4d0=DY?
049GG010DeH0=4M805e_L@10DeD0>De>03aADP0fBd`0@5EF03iCE012EUL0?e=D03iBD`80?E5B02<0
?U9C049FE@13EeH0@5AC04AHEP19GE/0AEUG03mDC`11EU40?eA?045HDP14FeD0Bf9M04AJE`0lDTl0
AeeJ045GE@15FeT0@eUG041EEP15FU/0C65R04YOH01HKFh0A5UJ04]PH`1AIVT0G75d05=XJ@1AIVH0
CF=O04QOE`1@Ie`0GgI/07R?Q`0204iUG`0;051WH@1=I5h0C6=M051WH@1?IV00CFAN04aSG@1;HU`0
Bf9J04IMD`18H5<00P19HE@0C@16GU80@eY@04YQE`16GE@0@eYB04ELEP18GeT0BF1I04YOE`16Fe80
D6EL04=HC`0dBCh0<DLk03mEB@1aQg`0BEiE045FC@12Edh0A5UB04=IE`11Ee@0AEaF04AKE010Edd0
@eY@045HCP0oETh0@eYB045GE01;HEl0KXB107:;Q00kDTX0@5M?03aCB`10EDh0?eA=03eBB`0aA3h0
=dY404AGD@0jCDL0<DDm0393>P0`@CT0<D8j02@e;@0S=2h0<d@n02@e;`0Z>SL0:CTf03=3@00kBdX0
9SHc02`l<`0X=c008S4Z01d/9@0M;2L072/V01LV8@0V=C808C0]045@C@1SLG409S<a02@`;00Q;BT0
82`X01/W8`0L:2@08RhZ02<_:`0Q;BT07RXV00807BTU01T092lZ02D_9`0P:R807BHP01lX8`0P:B@0
8B/W02Pc;`0H8R409S0`02La<P0P:R`07B@W05QLG`12ATT061`O01lS9P0I7B006QhQ024U:00H71l0
7B4T01@H6`0J7R007AlN00806adJ00X061XG018D4@0F61D05ALD01TK600C5A809RPU03do?00V:2D0
6A/H0P0F61D201LI5P0:01TK600G6AH051HC01TK600M7a`03Q0=01@F4`0C4a406ATG01<C4@8061PF
00/04Q8@01HF500B4Q0051@B01<C4@0E5A<0410>01DE4`0C4a404A4?00l?3@02010@3P0L014A3`0@
40h04a<A01<C4@0A4@l04a<A01DD400A40d05A@B01LF500C4A404@l@01dK700@3Q004a4D01HD5`0B
41@03P`?010>4@0A3a004a4B01DC500C4A803`d>010>3`0?3@h03P`=00l=3P803@/<00@040hA00l=
400>30l03`d@0P0@3Q401P0?3A003P`?018@4`0>30l02@L:00/930803P`=00X02`T:00`:2`0=2``0
2PP900l=3P0>30d04@l@01DC500?3@h02PP91P0>3@/0900B4@l030/:014@3P0>3@/02PT801LE500?
2``040`=014=3P0B3Pl081`M01dI6P0@30d05A4B00h:2`0E4A8040`=00/92P1GEeL0C4a<00X:2P0C
4a<02PP900/92P0<2P/030P900h:2`0?2``03`T;01@?400F4Q<04Ph?00d92P0<20T03PX;010<3@80
3`/<01004`l@01@@4@0@30d03P/;00X91`0;1`H03`L800l61`0B20T03`D601892P0F3Pl04Pd<00l;
2P0=2`T02@D60P0?2``0600;1`P02@D600l;300810D05Q8C00h:2`0G4a@04Ph?00h92`0@2Pl03@H=
00/42`0=1Pd03`P?00h73P0=1`d05PlF0109400500D04@`A03hg?P0@2Ph03`T=00h8308040X>00l0
3PP<00h9300C3A406A<G01H@500=1`/0:bDY03<];`0=20T04@/=00L20`0A2`d02P@6010:300?2@/0
0P0>20X00`0=1`T030H8ooooo`0Cooooo`006oooool06@0:4100318B00dC4`0=4a<03A8C00dA4P0C
5aP02`h?00`=3`0>3a404Q8D01LH6P0>4Q406AdL00H:2@0@51<02Ph=01@H5`093@`05ATH00hB4@07
2`X06AdL03Di>00A4a800P0?4A002`0@4Q403Q0?00`>3@082PT06adL00T;2P0A4a805aTH00L9200?
4@h02`d:00802@/800l030h;00h@3@0>40d01@L4020R7`0@4Pl08B<P00d?30093@X0318>01TO6`03
20@041DA00`A3@0?4@h00P0>40d200l?3@0F01<D3`0C50h03a0;014B3@0E5Q405QHD018B400A4@l0
4Q8B00d=3@0:2PX03@d=010A3P0B50l08B<N018D3`0:30L01`T400lA300>40/0418=00lA30802`d8
00<03Pl:010A300>3`X0100=3PT00`0>3`X03a0;010A3002010A300300h?2P0?4@`01`T400803Q0;
00L03@l:010B3@0?4@`03Q0;00`>2@0=3`X03a4<00803Q0;0`0@4Pd0200?4@`03@l:00h@2`0;3@P0
3Q0;01@F4@0:30L0418?0P0A4a000`0>40d030h;00d?300300lA3P0700d?300<3P/02`d:00l@2`0;
30L0414<00P9100200l@2`0N010A300A4Pd04A8=014B3@0@4@`03Pl:01HH4`0?4@`030h900d?2P0?
4@`03@l:00h@2`0@4Pd030h900X<1`0<3PT03@l:01XL5`0Q8ah030h9018D3`0=3`X04A<>00X<1`0@
4Pd03@l:00lA300E5a80418=0P0=3`X0<P0?4@`04A<>010B3@0<3PT04Q@?010B3@0;3@P030h900d?
2P0;3@P04A8=00d>2@0<3@P0414<00d?2P082PD03@l:00hC300=4P/0314:00XA2@0;4PX041<<01<F
3`0B5@h02Pd6018E3P0?4P/04aH?00/>1`0=40T030l801PK500@4``03Q4:01HI4P0?4P/03Q4:010C
300;3PL04A@=00hA2P0=40T03Q4:010C300?4@/04A<>01<E400>40/03@l:0P0C5A002P0G6A@02`d8
01HH4`0@4Pd02P`7014B3@0A4PX03a0800h?1`0?40P2014B2P0<01<D300G6100414900T:0P0<3@D0
2P`500hA2P0D5a004A@<00/>1@0>4@P041<:0P0A50/0300<3`L04QD>010C300>4@X03a8;01@G3P0G
6Pl05AP=014E1`0D5``04aH;018E3P804aDB00<04A<A010B3@0@4``00P0A50d2018E3P0;00hA2P0E
61405QTB00hA2P0?4P/04aH?01HI4P0?4P/071lH01HI4P0C5Pl00`0D5a002P0E61405QTB01LJ4`0I
71D03A8<00`A2`0E6Q@07b@N01<H4P0@5@l201@I4`804aPB01@05AXD01HK500D6A8051X@018H3P0B
5a006QlH02@Y8P0E6Q@05Q/F01<H500c>3@051TE01TN6P0F71P04ALC01HL600I7a/05Q`H01DK5`80
5Q`H01T05A/G01HL600G7AT05adI0457A@1LHV006b4O01LM6`0P9R@04QPF01PN700R:2H08bTW028X
9P0Y;bd0;SLd01lZ:@0V<S005R8P01DQ7`0K9bD082`Z01l[:@0N:RP082`Z0080930^01X08bl]01hZ
:P0T<S807R`/01/Y:@0S<c<0:CTi03E4A`0Q<cD08cDg020b=P0S=CT0;d17028e?@0`@T`0;T1:02<e
?`0R=3h0:Sa603A6D00Z?4H0@E=M02Dg@@0Y>dD0;T980315B0<0<TM:00X0=4U<03I;CP0dBD`0<dQ;
0397BP0dBD`0=T]>03Y?D`0eBTl0<DI;0`0dBDh03`0gC540>e1E03mDF@0jCe@0=4U>03I;D00kD580
=de;03Q<B`0mDE00>dm>03eAD00nDU40>dm>03eAD00303mCDP80?U9A00<0?e=B03eAD00mDE000P10
E5804`0kCdd0@eQC04QMF00oE4l0@EI?03I=A`14FeD0AEaF05I]I`1>IEl0?UAA05ecL01?IF80A5YH
04QNG019Ged0AeeK05abL01NM7800P1?I6D0?@1=HV<0D6EV05=XJ@1@IV@0DVQT05=ZHP1?Ie/0DVYM
05U`J01:HE/0HGQb06V0NP1CJV@0CVEO05=ZI01;HU`0BF1J04ELEP1>IEl0AEaD04ALC`17Ge40BF5C
04QPD`14G4l0@5Q;04QOE@12FDl0@EQ>04UPF01@Iel0BV5I05AYH00oEDX0D6EL03M<@`1>HeX0Ni27
03aAB010ED`0@eQ?04AID017G580Bf1G04EKF017GEX0BF1J051WH015G580AUeC04ELDP15G5@0AeiF
04YPG@19Ged0B5iK04ENE`12FE40?UE=03M>AP11ETl00P0lDDX0@@0dAd40<TDo03A7@@0bACl0;d<j
0393>P0]?SH09SL_024b:P0U=S00:S/e02Pi<`0U=C80:c/h096QWP2Q/K00=dM402hm=@0_?SL08S4Z
02He;P0X=c807bhY01XY900L:bP09C@a02Xi=P0X=SH0:3Dc02`h=00Y=C407RXV01`X900P;2P08RhZ
01l[9`0N:RH06bLS01`X900P;2P08blY020[8`0N:B<07bXU01hY9@0Q;2P08bd[02</:`0U;Rd08b`[
01hW9P0L9B@06R4R01lS9P0V:Rd061`O01lS9P0J7R407B4T03a0@`0_<cH0:Rha01hR9@0J7R006adL
008061XG00D06A/H01HH5@0H6QL051HC01`N6`02020R7`0H03Li=P0S9B805ALD018D4@0C5A8071hK
01dO700D5Q<04A<@01PJ5`0D5Q<06A/H00d?300D5Q<0820N02<S8@0L71X05ADC01HF500B4Q005aLE
010@3P0>3P`04A4?0P0B4Q003P0=3@/05aLE01PH5P0B4Q003Ph<00l?3@0@40h05ADC010@3P0<30X0
3`l=00d=2`0>3@T040l<0P0A40h0700@3`h03P`=00h<3@0>30h04Q0C010>4@0=2`l04@lB01@B5@0G
5AH02`T:010>3`0F51D02PP900/92P0A3a004Q0A01DC500Q7b000`4201<A500>30l02PP;00`:3@0?
3A003P`?010>4@0J61/2014?4P0800X82`0C4A@030X;00/92P0E4a@03`d>00/92P071@H2014?4004
00h<3@0:20T02@L800X82@802@P601002`X8010?3@0?3P`03@`:00/:200O7Q`00@00010?3@0<2`T0
2`T801TE5P0=2@X040`=00P41@0R7Ql02@D61@0>2P/0200<2P/04Q8B01LG5`0@410020P800`:2`0?
3@h030X;0`0>2P/0=`0?2@/04Pd?014=3P0>2P/04@d>01<?400?2``03@T:00h:2`0;1`P04`l@018>
3`0;1`P0<2`/024M700F4100;B@U01H=3P0@1@H04PH801882@0J4A805a4A00`81`0;1`H02@D601@@
4@070`@0BdM802hZ:`0V8R<03@T:010<3@0n>S/06QHG00X61`091PH03`P?00/42`0=1Pd04P/B0109
400A2Q402@89014:4@090PT0204802TR:@36_lH04@/?010:3P0>20`030H:00d72`0>20`00P0@2Ph0
2`0?2@d04`dA00P31P0=1`/01@0100l92`0B30h01P0201@>40080P@03`T;008040X<00<03`T;00`6
200:10H05?ooool001_ooooo02402Q0@00/A4@0<4Q803A<C00lD5@0@51D0720Q018D5P0>3a403a0B
010A4`0E5QP03a4@00dA40072`X05QXI00hB4@062PT03Q8A01hR8@0L81l0310?00H:2@0E6AP03@l>
00h@3`0?4A00418A00`>3@0;3@`051HE0001000=3`h00P0>40l00`0;3@`03a4>00`>2`0200/=2P03
00d?300>40d061XG00801@L402H02@/801LI5P0320@02a4=01`R7P27SHT0724M00D:1P083@T0418?
00h@3@0=3``03`l=014A3`0C50l04A8<00h?2P0?40/04A8=00l?3@0;2`T020P600/;2`0=3@d030`<
010@400B4a0020X501dO6P0;3@P09bTT00L9100=3`X03a4<014C3P0@4Pd03@l:00`>2@803a0;00@0
3Pl:00d>2@0=3PT03@h90P0>3`X03@0?40/0414<010A300?40/03a4<00d?2P0<3PT04A<>00P:1@0;
3@P04A<>010B3@0>40/00P0<3PT01@0=3`X03Q0;00lA300?4@`0418=00<03a4<00/04Q@?014C3P0D
5Q4061XE018D3`0<3P/02P`900P:1`092`P03@l<01<E4P0200`>2`@03@l<00L04a@?014B3@0G61<0
30d800l@2`0<3@P04A8=00<04Q<>00L04A8=00l@2`0B50l03Q0;00`>2@0?4@`04A<>00803a4<0140
51HA01DG4P0B50l03a4<00`>2@0>40/051HA00X<1`0<3PT03Q0;010B3@0D5Q403a4<014C3P0N81/0
7b4L00X<1`0200d?2P0A00h@2`0@4Pd0418=00d?2P0C5A004Q@?00h@2`0?4@`04A<>00h@2`0?40/0
3Pl:010A300A4Pd0418=014C3P0>40/00P0>4``02@0=4P/02a8:00`C2`0<3`P02`h701@G400Q91d0
71lH00T<1@0200P;100501@G400@4``02`h700/>1`0=40T00P0;3PL2014D3@0400/>1`0@4``03a8;
00hA2P803a8;00L030l900X<1`0;3@P02`d800`>2@0>40/04A<>00803Q0;00D04Q@?00/=200B50l0
418<014B2P03010A2@804A8:00H06Q/C01DF3P0=3PH04a@<014B2P0B50`201@G4009010C2`0?4PT0
51L>01PK4P0E60l04QD<01<F3P0G6Q<04aH?008041<<00`03a89010C200?4PL03Q84014D2@0@4`P0
3Q4:00lA3P0@4Pl03Q0>010B3@0@4``2014D3@804QD>00`03A0901@G400D5a003Q4:014D3@0E6140
4A@=01<F3`0:3@H030l800X=1P0M81T201@G400C01DH4@0F6A805aXC01TL5@0F6aD061dG00X?2@0<
4@/061dG00L<1P0D6A<04QLA010E3`0A5Q0051TC01HK500G71D05Q`B01DK4@0201LL5@0=01DJ4`0=
4P`051TD014F4P0I7QX082DQ00hC3`0G7AT061hJ024W8`0S:BD061hJ00lE4@0201@J5P804aTE00T0
5A/G01LM6@0J81h0<3Hd01TO7@0J81h08BLU01lU8`0J81h00P0P9R@02@0O9B<08bTW02@]:P0H8b40
6BDS02di=`0f@T0062@R01DQ7`0201`X9P0M01dY9`0P;2X08Bd[024]:`0S;bl0938b024_;`0S<C40
:CTi02Xj>P0V=CP07S0b02Dg>@0R=3P07Blc02@e?00Z?D@08C<m028e?00^@4T0=DMA02m1BP0gBU40
<TA>055TK00oDUT0=dUC02m3B@0bAdX00P0dBD`01@0cB4/0=DY=03A9C00bAdX0<dQ;00<0=DY=01P0
=da@0397C00^@dP0=DY?03A9CP0`ADX0;dA903=8C@0fBe00=4U>0397C00cB4d0=da>03E;B@0hCT`0
?eAB03]?CP0jCTd0?E1?03a>CP0lCdh0?51?03eAD010E5<203mCDP0=03iBD@0lD4l0?51?03iBD011
EE<0?eA?045FD@12Ee80?E9=03mDC@1;HU`0CfIP045HDP0204eTGP0P04UOG013FEH0?eEB045GE017
GE/0AeeJ04QNG019Ged0CF=Q04MMG01=HV<0C65R04eRH`1CJFL0D6IS05=YI@1CJV80CVIJ04iVF@1F
KFD0Bf9L05U`JP1NMFl0D6MQ04iUG`1GKVP0DFQR04]RG018GeT0CfIP04UPF016GU4204QPDP1F04IN
D@13Fdh0@5Q;04MNE018GeD0@eY@04]RFP1GKVH0BV5G05I/H011ET`0>Di50356?@1`QG`0]<W0049G
D011ETd0@UM>04AID015Fdl0@eQ?049HEP15FeP0@eYD04MNE`15G580CFAJ049IC`13FU80A5]C04EK
F014FUP0@eUF03YCC00hCdL0>e9:03iEC@18GEH0@EI?03Y?B00fBD<0=DQ203A7@@0`@cd0;D4h0393
>@0a@SX0;Chf02Hg;`0T=Bl09CH`02Xk=@0W=c@0;cll06IfL`1_Ogh0:c/h02hm=@0^?CH09SD^02dl
=@0_?ST08c8]01d/9`0N;BX093<`02Lf<`0U<c<0:CLd030l>00/>3@08BdY01hZ9P0O:bL072PT01DQ
7@0O:bL0<Shj02Da;@0J9R807b/T028]9@0R;BL092lZ01lZ9P0M:2@201lX9`0E024Z:@0O:2L06b@Q
01XS800R9bH0310C02P/;`0^<SD0Q8R;02P/;`0K7b80Si>F07b0P`0<41<020`?01lS9@0H6QT05aTF
01/M6P0M7a`061XG00805QPE02409bTV02/]:P0B51407AlL01PJ5`0F61D051HC01HH5@0O8Ah08bDR
028T8@0I6aP02P`901DG500a<c005ALD01LI5P0K6aT07AdK01PH5P0C4a405QHD01<C4@0?3`d05aLE
00H6100J6QP0>CTg010@3P0E5A<03`l=014A3`0H61H00P0A4@l00`0h>3H05QHD010@3P0200h>3003
01<C4@0?3PX04A0=00804Q4?01D04@l?00l=3P0E4a@040h@01<A500F51L04Q0D014?4P0=2`h04Q0A
01@B4`0K6AX01P@504Q6A`0d<S<02@L8018@4@0>30d03@/<00P61`0A3a800`0D4QD03`0@3Q4030X=
00T72P0100804a4D00d;3P0I5aX03@/>00`:2`081PL03@/<00D3100@3Pl05Q@E00h<3@02014?4007
00h<3@0<2P/030X;00`;2@0;2PP030/900d<2P0200`;2@0900T81P0J6AL03@`:01DD4P040`405Q<C
00h:2`0?2``04`l@00800`0000<07ATJ00h:2`0>2P/00`0>2P/0200?3@h02PX:00H61P0=3@d03`l?
00`:2`0;2@X030X;0`0>2P/04P0?2@/03PT;00/720091@H03PX;010<3@0?2``030P900T51P050@80
30P900d92P0<20T06ADE00/71P0:1@D06a8C01H<3@8050P:01804`L901D<3@0A2`/02`D500`81`0K
5aP0920Q01LC5016@T<0;b//02HR8`0=2@X020@502LS900H51D03`/<00`82@0B310200h73P0<00l8
3`0=1Pd030D<00D01@0=1Pd04``C014:4@0;10/0@CY1010:3P0?2@d03PP<0`0=1`/03`080PH02`D9
00H0100=1`/030H:014;3`0I4aD020<400l92`0O6A/0<B/]00h82P0;1@L03@L900l92`02010:3003
00h82_oooooooooo01;ooooo000Kooooo`0800hD4P0=4a40318@00lC4P0C5aH05ATH01LI600>3`l3
00d=3@0?014B4@0F61L03A4@010D4`0?4a803Q8A00/?3P093@`05ATH01TM700A5A@01@T800`@3`0=
3`h0418A00804A<B0`0?4A001@0O8B002`d<01LI600;30/04a@C00803a4>0140418?00lA3P0=3``0
3@l<00/=2P0>40d0418?00lA3P0C5A803Q<?00T?2`0>51005QXG00`A3@083@T04AHB00dB3P0200d?
300800lA3P0B4Q004a<?018A300A40`040l;00l>2P0=30X2018A3`0>014?400E4a@03@/<00`:2`0A
4Q0020X5018D3`0=3`X0@T@o00`>2@0>40/0418=014C3P0@4Pd200h@2`03010A300?40/03Pl:0080
3@h90P0>3`X02`0=3PT03Pl:010A300@4@`03a0;018C3P0C5A002P`700/=200K7AP04Q@?0080418=
00@03a4<00h@2`0=3`X03@l:0P0@4Pd400lA300800T;1P0=3`X03a4<00lA300A4`h0418=01`N6`0G
6AH3014C400<00d?300D5Q<051HC018D4@0@4Pl03a4>00h@3@0@40h04Q8@01`L6P0@40h04a<A0P0B
4Q0201<C4@804Q8@00P0410>00h@2`0=3`X03a4<014C3P0B50l0418=00d?2P803Q0;0P0=3`X0200B
50l03@l:00d?2P0B50l02@/6010B3@0<3PT0418=0P0=3`X01P0B50l05QPC010B3@0>40/03@l:00h@
2`80418=01L03Q0;00lA300@4Pd03@l:00lA300B50l03a4<00l?3@0<30X04Q8@010@3P0;3@P04Q@?
010C300A5Pl041D>00lE2`0=5@X03QH;00lB2`0@4``02`h700hA2P0201<F3`0O014D3@0?4P/03a8;
010C300>4@X09RTR01lR6`0>4@X04A@=01@G400<3`P02@`500lB2`0@4``04A@=010C300?4P/0418<
00lA300>40/04Q@?014C3P0?4@`04Q@?00P:1@0@4Pd04A<>010B3@0?4@`03Q09014B2P0301<D3080
4A8:01@04Q<;014B2P0A4P/04a@<014B2P0?4@X03a4<010C3@0C5Ph051L>014D2@0@4`P030l400X=
100C5Ph04aH?01<E400H6a@05aXC01<F3@8041<800@04QH801DH3@0C5P/04QD>0P0C5A800`0A4a40
418=010C3002014D3@804QD>00d04aH?01PK500D5a003Q4:010C300C5Pl03A0901dP6@0B5@h05aXC
01XM5P0a=2d05APA008051L@00P05APA01HI4P0H6a@04aPB01HK5@0<4@/05a`F018G4@804aPB02<0
4QLA014F400B5a4051TC01DJ4`0G71D04QP>014G3@0D6A805AXC018G400C61805Q/F01HK5`0E6QH0
5a`H01hS7`0P9R805Q`H01@J5P0E6aL061hJ01lU8@0H7QX05adI01HL600G7AT0728N01lU8@0C6AL0
5adK02D[:@0M8b405A/I01`R800201TO7@0;01XP7P0N92807R@R01`U8P0N:RH062@P01dY9@0_>cL0
9S8^02Da;@0K9b<00P0N:RH0900O:bL08BdY02<_;00R;Rh082h^01d[:`0Q;bl08c<c028b<P0R<C@0
8C<e02Dg>@0U=c/08cDi02Hh?00R=C/0;d9902e0AP0Z?D<0<dI<0313BP0cAT`0<4=903=6C00Y?480
<DA;0314B00_A4L0<4E802m4A`0]@TD0;T=60315B00aATT0=4U<03M<C`80=T]>0180=T]?0397C00a
AT/0=DY?0397C00_A4T0<dQ=03M<D@0hCE80>e1E03eBE`0lDEH0>51A03E?C00jDe00@UQF03mCDP0m
Cdl203e>CP0>03a=C@0jCDd0?51?03iBD@0jCTd0>De<03Q<B`0jCT`0?51>03mCD@12Ee80B5eH04=H
DP0jCdP203iCC00K03M=B@14FUL0C69O04aRG`17GEX0AeiH04QOF@17GUP0C6=L04eTG`17GUL0AE]E
049HD`19H5X0BV5M05=YIP1BJ6H0D6EU055WI@1?IF80DFQS05=ZH`1?IU`0DVUO05=ZHP1BJF<0DFQR
0080D6MQ0P1?IV002@1AJ680BV5K04]RG01=I5h0Bf9J04EMC`14G4d0@UY<045IB`02041HB`0I049J
C@15G540@eY@04QOE@1>IE`0@eY@03eCA`15Fdl0?eA:03aAB@0nDdd0AEYD049GDP12Ee00A5U@04ML
D`17GE40AEY@04aRG`1;HEh0AUeG04QOF01=I5X0FW5W04QOE@0204QOE`0S04ILF@14FUP0A5YG059/
HP15G580@UU?03aCB@11ETd0>e1703Q=A00iCD@0>4a303A8?`0^@ST0;40g02dn=00]?SH0:S/c02@e
;@0O<2X07RlY02Xk=@0Y>CH0<d=002/k>00_?ch0:3Pe02Ti<00T<b`08C0Y02Lf;`0U=2l07bhY020_
:P0Q<2d00P0S<Rl0@@0Q;bl0934_02Pd<00U<Bd08RhZ02@`;00Q;BT07RXV01TU8@0T<2`0?4Q402/g
<`0M:BD07BXS01dZ8@0Q;RL0:3<_02<];00P:RX07bPZ01hV:00N9bH07BDR01dS7P0N91l08RLU024U
9@0^<S<06alP02/_;`0J7Qh051PI02/_;`0X;2d08RHW01lS8`0G6a/06Q`I01XL5`0Q8ah08bDP01dO
6P0H6QD04aD@01`N6@0O8A`0418=01`N6@0H6QD05ALD01HH5@0G6AH061XG01/M6P0R92408B<P01@F
4`0G6AH0;Bl/01PJ5`0@4Pl05ADC01HF500D51804Q8@00805ADC01@03@d;01XJ600=3@/05ADC02DU
8`0<30X04a<A00d=2`0@40h05QHD018B400@40h04A4@014A3`0F5Q@04Q8@01@D4P0<30X04Q4=018A
3P804Q4?01H04Q4@018@4@0F51D03`d?018@4`0G5AP04a4E00l=400C4A@04@l@00L51P0G5AH04Q0A
06QVI`0l>S/04a4B018@4@0D4Q<03`d>00d;300=2`h030X=0P0=2`h03`0?3A004@lB010?4@0<2Pd0
5Q@G01@B5@020@<05aDH00d;300I5aP08R0Q014?400=2``03`d>00d;3002018@4@0E010>3`0>30d0
3P`=00h=2`0?3P`03Pd;00d<2P0@3`d04Q4?014@3P0<2`T03Pd;00d<2P030P403``<020M7@1RGUl0
510A01XF5`0<2@T03`/<00D03PX;00P03P`=00T92@092@T03@d=00T92@0:20T03P`=00`:2`<03PX;
00D03`T;00l:300?2``03`/<00h:2`0200d92P0O00`82@0=2@X0510A01/G600B3Pl030P900/71`0A
3@`04`d=01482@0F30d05@T;01H:300C1`T040H700`41@0:10@03PT800`81`0B3Pd02`L601@@3`0?
2`X02PH5014=30091@@02`L6014=300>2PT030P8014;3P0200`62@0900l93@0<1PT03@L;014;3`0<
1PT02P@701<=4@0C3A0030L:00803PL>0P0@2A00400>1`h030D<01XC6P0P6B0030D<00d63@0?20l0
2P@800/5200B30h03`T;00P3100@2P`030H800d72@0>20X300l92`0300h82_oooooooooo01;ooooo
000Kooooo`0500dA400;3`h020`;00P<2`0;3Pd00P0>40l08`0=3Pd051@D01LG5`0D4a<04a<C00h@
3`0:3Pd0310?00L;2P0<40l02@d<014E500=4A0020`;00/?3P062PT03A4@00h@3`0?4A003@l>00`>
3@0@4Q4051HE01DG5P2=Shh08R@S010B4@0;3@`09bTX00lA3P0A4a004Q@A014C400>40d030h;0080
3Q0=01T0418?00h@3@0R92402@h:00hE4@0020<07BHQ00hD40073@T01P`800T>2P0<4@d03A8>010B
3`0>40d03`l;010?2P0@3`/03Pd900l>2P0A40h03Pd;00X91`0<2P/03P`=008030X;00H03@d;01DG
4P0210005aTD01/M600:30L200d?2P0600h@2`0=3`X030h900d?2P0?4@`03Pl:0P0=3PT01@0>3`X0
3a0;00h?2P0=3PT03Pl:00803a0;00L03Pl:00h@2`0?4@`06A/F00X<1`0F61<03a4<008030h900@0
3Q0;00lA300?4@`03a4<0P0A4`h00`0?4@`03Q0;00h@2`0200lA3003010B3@0C5A004A<>00803Q0;
00<0EUQE0494@@0L7Q/00P092`P01@0=3``061XG01HH5@0B51403a4>00803@l<00L03`l=00h>300F
5Q@02PX8014A3`0C4a403`l=00<0410>00<03`l=00d=2`0>40/00`0@4Pd200lA300?014C3P0>40/0
3a4<00h@2`0=3`X05ALB01@F4@0A4`h06adH00d?2P0B50l02`d800h@2`0B50l04aD@00804A<>01@0
5QPC00h@2`0=3`X03@l:00lA300@4Pd03Q0;00`>2@0>40/030h900lA300A4`h03Q0;01<C4P0;2`/0
4a<C01LG5@0@4Pd04Q@?010C30804AL=00L03aD;00hF2@0?5``03Q4:00T<1@0=40T06A`E00801@P1
00P02Pd601XM5P0A50d04A@=00P;100F6A804QD<00P;0P<03A0700d051L>00hA200@4`X04A@;010C
2P0>4@P03Q0:00`>2@0>40/03a4<00`>2@0B50l05ALB00802`d802@03Q0;01/M60051`8051H?014C
200C5@X051H;01<E2P0A4`P05AL<00D7000M7a@0:bdR00h@1@0E5``04Q@=010B3@0B50l06QdE01XM
500C5P/03A4300`?100?4PT04aH>010B3@0C5A403Q4:014D3@0D5`h04A@900lB1`0?4`D04A@9010C
200?4P/2010B3`0300h@3P0@4Pd041<<00804A@=0P0B5@h03@0930D03A09010C300B5@h06A`E01hQ
6P0M81T07R4J02X]9P0>4@X06ahG018E3P0E61400`0D5a007`0E61405QTB01<H4P082`L092TS00@9
0`0E6Q@04QLA010E3`0E6Q@061dG01TN600F6aD04aPA00dB2`0E6a4061hD01DJ4`0F6a@06b0I02DZ
900E6QD07B8N01XO6`0C61@08RLS00/A3@0@5Q806R0L01/Q7@0D6QH00`0C6AD0200B61@04aTE01PN
6P0K8Ad06AlM01HL6P0L8R005Q`J0P0G7A/09@0J81h05Q`J01TO7@0O9B<07R@R01TR7`0I9B40930/
01XV8P0O:bL07RXV01dY9@0L:2@07RXV01l[9`0P;2P08BdY02<_:`0Y=CD0;C/k02Hd=00O;Bd08C4a
02<c<`0S<SD093Hh028d=P0Q<cL08cDi02@f>P0W>Sh0;T5502`o@`0^@DD08C@h02Dh?00P<cL00P0_
@TH05@0Z?D40<TE903A8C00dBD`0=DY=03A9C00bAdX0<dQ;03A9C00cB4/0<TM:03=8B`0eBTd0=da?
03Q=D@0iCU<0>TmD03E:C`0^@dP0=DY?03iCF00203]@E@1l03eBE`0nDeP0?55F03IAD00fDdh0>EA?
03]CC`0nDU00?U5?03i=C00lC4/0?U1>03mBD00mD4h0>Ti<03U=B`0fBTP0<dM503M;B@0jCT`0?55<
03mDC`1>Heh0BUmH03eBB`12Ee00?E9:04QNF`10EU@0@eUG04iTHP1CJFH0B5mI05A[H`1:HET0AEaC
04]RFP1:HEL0B5mE049IC`19H5H0AeiF04mVH01?IF80CfES05U_K@1CJFL0CfIQ04iUG`1?IUh0EFaT
04iUG`1EK6H0DFQR04iUG`1AJ680CVEO04MNF01?IV00AUeG04mVH01;HU`0C6=K04=KC@12FTX0@5Q8
045IB`14G4h0AemA04YRE@12FTd0CFEH04mVG014Fe40AUiA04]QE00lDTH0?UA804aQFP17G5H0C65L
03Y?BP12Ee40AU]B04AID015Fdl0B5iB04YPG014FUL0@5MA04IMEP13FU00BF1F04ELDP16GED0AEaD
041FD`0nE580?UAA03YDBP10Edd0AeiD041GC@17G5<0BEiE03Y?AP0gBd80=DU003=7?P0bASd0<DDl
03=4>P0Y>S808c@/02@e;@0[?3H0;Sli02Tj=00V=S<0;cll028b;`0Y>CP0;Cdj02`l<`809C@]00@0
:3L`02@c;P0O;RT08C0[0P0R<Bh0;P0Q<2d08Bl_01l]:P0O:bL07RXV020/:00W<bl0930/01dY9@0O
:bL08RhZ01XV8P0I9B406bLS01/Y8P0J:R007R/T02@`;@0R;R`08bd^028[;@0N9RP082HV01hT8@0M
91d07b@N020U800M8Qh04QHE02P]:P0I7QX0720N01<G5P0J7a/09BTW01@H5`093PX06AhK01LI500E
5a8061XE01TK5P0E5a8051HA024S7P0G6A@201DG4P0@028T7`0B50l04Q@A01HH5@0H6QL04aDB014C
400F61D03@l<01@F4`0A4a004Q@A01DG500Z;2T05aLE01DE4`8051@B01004a<A01@D4P0>3P`04A4?
01/K6@0C4a4030`:024Q7`0?3`d061PF018B40092@L03@d;01HF500<30X06a/I0P0>3P`200l?3@0`
018A3@0B4@h04Q4?018A3`0B4A004Q0A00l=3P0>30h04Q0C014?4P0=2`l040hA00h<3`0A3a0061HG
014?400=2``00@0000D3100D4Q<01`D600d;300E4a@04@l@010>4@0D4QD06ALJ00l=40050`H01P@7
014?4P0R82<02@L:00P62@0H5QT02`T<018@4@0:20T04Q0A014?400J61T071XK010>3`0?3@h03@/<
00X82@0<2P/03P`=100>3@/03P0@3`d04A0>018A3`0?3P`05QDC01@C4@0:2@L04@h>01XF5`14@440
3@X:00L3100C3a002@D61@0>2P/01P0;2@X030`<00l?3`0820P0000000@20`8030X;0`0>2P/01`0?
2@/03@P900`82@0>2P/040`=01<?400G4a@00P0C3a003P0O6a`0920Q01DA4P0=2@X030L800h8200C
2P/050X;01D;300K3Q005PL:01@82P0A1`P040L80P0?2@T020091@@03`/:00X61@0300002PH500P4
0`0<20L04@d<0P0<20L040050@003@T801<=3@0=1`L030H700l92`0>20P04@/<00h82P0B30`03`T:
00H00P0D3Ph02P@600`62P0=1Pd20109400=00l83`0=1Pd030D<01TB6@090PT03PL>014:4@0:10P0
3`T=010:300;1@L03`T;014;3@0300l92`@03PP:5?ooool001_ooooo01d04ADD00lC4P0<40l0310?
00d@3`0?4A003Q0?00h?3P0E5AD05aLG018A4@0?3`l02`d<00lC4P0;3`h05QXI01/O7P093@`03Q8A
00/?3P093@`03A4@00H:2@0;3`h03@l>00h@3`0<3Pd02@/:00h@3`02018D4`0N02T[:P031@@03a4@
01XL6`000@003a4>010B3`0A4a00418?00h@3@0<3P/03@l<01DG500@4Pl08B<P02d_;0083@T03aLB
00070P0?61<01@T60004000@5Q802a0<00dB3P0>4`l0418?00d?300=3@P03Pd80P0?3PX01@0>3@T0
40l=00l>300D4a405aDF00<03P`=00L03Pd;01lQ70072@@07R0K00L9100>40/0418=00803@l:00D0
30h900/=200>40/03a4<00h?2P0200d>2@0500h?2P0?40/03Pl:00`=200=3PT00`0>3`X02@0?4@`0
3@l:03Li=00I6aH01PP300h@300;3@P030h900h@2`0300lA300301<E400A4`h03a4<00803@l:00<0
3a4<01<E400A4`h00P0C5A005@0>40/03@l:01DG500?4@h01`T600X<2@0?4@h051HC010B3`0?4@h0
3@l<00`>2`0=3``03a4>01DE4`0@40h04Q8@00P81P0>3P`03@d;00h>300300l?3@0300h>300<30X0
3Q0;0080418=0P0>40/2010B3@0800lA300E5a804aD@00P:1@0<3PT0418=00lA300G6A@3014C3P0I
010B3@0<3PT05aTD01hP6`0F61<020X500lA300=3`X030h900h@2`0@4Pd03a4<00h@2`0A4`h03a4<
018D3`0C5A003a4<00l?3`0;2`/03Ph>01@D4P0B50l03a4<010C3002014G3@0@00lE2`0=5@P03QH9
018E3P0=40T02Pd600/>1`0C5Pl0?d8k01hQ6P0I71D03A0900lB2`0;3PL041<<010C2P803Q4800<0
2`h500lB2@0F6A000P0?4PT04@0@4`X03a8900lB2@0A4``04A<>01@F4@0F61<051HA01lQ700L7QT0
418=02<U800H6QD06A/F00L9100K7AH04A<800<04Q@901`04A<801@F2`041P007AlD02`^8`0;3@80
4Q@901@F3`0A4a003Q0;014D300D5``051P:010D1P0B5PP051L<014D300A4`h03Q0=00`>2@0B5@h0
61/B01DH3@0A50T03a<501<F2`0A50T041<<0P0A4a000`0?4@l0418=010C3002014D3@804QD>00@0
3Q4:018E3P0C5Pl04aH?0P0G6Q<01P0A50d01PT201hQ6P072P<07b8K01LJ4`805APA0`0D5a002@0E
614051TC02`a:`0<4@/06QlI00X?2@0X;BL04AH@01DJ500201XO6@0C01LL5P0C61402a0901dS6@0V
;2807b@M01HK500G71D07B8L00`A300U:RH02a0<02X_:`0P9B404QPD01DK5`0K8Ad06R0L01<I5@03
01@J5P0401DK5`0F71P061hJ01TO6`806b4O01<05A/I01HL6P0O9B<06AlM01hT8P0J81h06b4O01hT
8P0L8R005b0M01dX900F8Qh07RXV024]:@0C7a/07BTU01/W8`0J9R8072PT008082`X00l07b/W02`h
>00b@400:SPh020^;P0R<S8093@d02Dd=`0^@480:S`n02Li?@0V>3`0838f02@g>`0eB4`00P0^@DD0
3`0X>cl0DfIZ02Hi?@0V>Cd0:ci20354B00^@DD0;T9503A9C00eBTd0=4U<03=8B`0dBD`0=T]>03A9
C0020397BP0903=8B`0fBdh0>4eA03Y?E00kD5D0=DY?02m4B@0iCU<0@EIK0080?U=H06`0?E9G03]@
E@0jCe@0=U1?03EDCP0dDD`0=Da903Y>C00oCdh0?4];03i<C012DU40@EAB03iAC`0iCD/0@5AB03]?
C@0fBTP0=d]903Y>C00jCdX0?eA?04aQG01<HEX0@5E>04=HD@0oE4`0?59@04EJF`1KLG00Bf5O049H
EP13FED0KhIn061gK`1AJ5h0CVEK04UQE010F4/0?UI904EMD014Fe00CVEM051WH@1DJVP0H7Id05U_
K@1BJ6D0CVAQ04aSG@1BJF<0C6=M059YH`1AJ680D6MQ055XHP1>IEl0F6mY05YaJ`17GUP0E6]U04iU
G`1?IUh0AemA04INCP15GDd0AUi@04UQD`1<I5H0BF5D045IC01<I5L0CVEK04=JD018H5<0Aee@03U?
@@19Ge<0CV=L03aAB`0aAT40?55<049GD@15FU40A5U@04=IC014FTh0AeeI045GE00oEU00AEaE03eD
BP0oET`0AEaB04QOE`16GED0@5IC03iDDP10EU<0?eU?04eTFP1EK680?UE;03A9@00bAch0?55803A8
?`0cAch203I:@@0B03A8?`0b@cT093D]01h_9`0R<b/0;Chh0352?00Y>S@08c<`02`l>@0Z>SL0;Cdl
02Ti=P0Y>C009SD^02Lf;`0Y>3409cHa0P0S<Rd0:@0T<c008S4^020_;00Q;bl08S0]02@`;00S;b/0
8RhZ02@`;00S;b/07RXV02Xf<P0^>SH07RXV020/:00U<Bd08BlX01h^900O:bL08BdZ01dY:@0O:B/0
7bPZ01`T9P0O9BD07B<P01/R6`0L8AX06AhG01HK5`0`=C4061dI01/P700B5a<09R/W014F4P0C61@0
6QlK01hS7`0F6aH071hI008061XE01H06A/F01HH4`0H6QD06adH01LI500K7AP051HA01XL5`0F61<0
51HC01PJ5`0K7AX061XG01LI5P0J71T06A/H01XL6@0L7Q/06A/H01LI5P0k?CX06ATG0`0E5A<05P0B
4Q0051@B01<C4@0C4a404Q8@01<C4@0F5Q@05aLE00`<2P0A4@l03`l=028R800820H05ADC014A3`0K
6aT020P601`L6P0=3@/051@B018A3@0B4@h2014@3P07018@400B414040h?014?4@0D4QD04Q0C00l=
4@0201<A500=00X82@0N71d030X;01XH6@0F51D02`T:01HD5@0A3a003P`=01@B4`0Y9bP03@/>00L5
200200X82`0Q01@B5@0R82<030X=00<1100D4QD07Q`O00l=400>30l040h?00L51P0B414040h?00T7
200100004@l@00h<3@0;2@X02@L800`:2`0?3@h03`h<00h=2`0?3P`040l=00h=2`0;2PP051<A00H5
0`0920H030/900d<2P0=2PX040`=00803PX;00<04Ph?01/G600C3a001@0>2P/0200;2@X03`l?018B
4P0>3Ph051@D01HD5@0?3@h030X;0`0>2P/02`0?2@/04@`=014=3P0?2``03PX;00l;300@30d03PX;
00l;300C3a005Q8C00803PX;01X04`h>00`61P0?1PL050X;01@82P0I2Pd05@H901L82`0C20X04PT:
01D<3@0?2@T04`l>01/G5P0C3`h020@301<?3P0>2PT01P8100h:2@0@30/03@T800L30P0A3@`0618B
018<30803PP800<030H600d71`0600000P0C3@d01@0400003@L700h92@0<1PX03@H=00<03`P?00d0
3PL>00D01@0A2Q402@8900l83`0@2A0030D<00d72`070P<01000010:300>20X01P0200802`D700@0
30H800h82P0A2`d04`d?5?ooool001_ooooo02403Q8A00lC4P0?4a8041@C014D4`0A4a8051DD00l?
3`0A4A4051<C018A4P0C4a<0418A03@i=`0<4@h03A4@01`P7P0[;bd04QHE010D4P0=4@l041@B00T=
300>4Q40418A01LI600F61L04A<B00h@3`0@4Q403a4@00h@3`0=3`h00P0?4A000`0>40l03a4>00lA
3P0200lA3P803@l<02003a4>014C40092`P03Q0>01<E4P1_M7008bXU014H500:3`/03AD@00`B3P0<
4@d051TE010E4@0=4Ph03a4>014C400@40`04a4<01/G500J5a@04a4=010<2`0>2`X09B<Q02`X:00C
41005a@D01XF5`0@3`d05ALB01HH4`804A<>00H03a4<010B3@0?4@`03a4<00h@2`0=3`X2010B3@<0
3@h900D03Pl:010A300>3`X030d800d>2@0300h?2P0600l@2`0=3`X08R@O00X;200G6A@03@l;0`0@
4Pd04@0?4@`03@l:00/=200D5Q404Q@?00h@2`0<3PT03@l:00lA300C5A0030h900h@2`0D5Q40418=
00`>2@0<3P/03@l<00804A<@00l03a4>00d?300C5A804Q@A00lA3P0=3``03Q0=014C400E5A<03Ph<
01<C4@0@40h051@B00X:200@40h00P0A4@l2010@3P0900h>300<3PT03a4<00h@2`0=3`X0418=01HH
4`0H6QD03@l:00<03Q0;01H07R0K00d?2P0@4Pd03a4<01HH4`0=3`X05aTD014C3P0=3`X04Q@?01<E
400?4@`04A<>010B3@0=3`X030h900h@2`0@4Pd03a4<00h@2`0A4`h03a4<0P0A4`h05`0=3`X06QXI
028R8P0E5A@03Ph<014C3P0=3`X03a8;010F3@0@5P`03Q@:00dD2@0>5@X04A@=018E3P0>4@X05APA
06]^I`3Si]l0CE19010C300H6a@06A`E00804A@=00D04QD<01<F3@0=40L03Q4801<F3@02014D2`0Q
00lB2@0>4@P03a89010C2P0C5Pl030h900X<1`0@4Pd02@/600/=200@4Pd06A/F07anN@1?DD`04A<>
00h@2`0D5Pl04A<8010A200?4@L04187014C2@0@4@L05QP=018C2P0D5P`05AL<00d?1@0B4`d03a4=
00lA300@4`/04A@:00804AD901<05QT>01<F300C5Ph0:2XU01HH500A50h05QTB01/N5@0D5`d03a87
00lB1P0D5``04QD;014D3@0B51004aDB014C400@4Pd041<<00804A@=0P0B5@h0300A50d05APA01HI
4P0F6A805aXB018E3P0I71D030l801TL5@0E61406QdF01<F3`805APA00X051L@01<F3`0D5a005APA
014F401HGEL041@@01HK5@0C5a805a`F100D6A<201HK5@0D01DJ4`0J81H06b0H01PM5P0E6Q<05Q/D
01XO6@0F6aH05a`H01XO6`1JGe/05adI01HL600G7AT06b4M01TO6`0H7QX07bDQ01HL600H7QX201/Q
7@0801XP700H7QX05alL01XQ7`0H7ad06R8O01dU8P0L8b4201XR7`0401/S800M92807B@R01`U8P80
6BDQ02P05b<O01`X900J9R808RhZ01l[:00I9B406bTT02Hb;P0T<2`07b/W02Ld<`0Y=cL09C<c02<a
<@0S<c<08C4a02Xj?@0_@D<09CLi02Dg>`0^@4@0:Sa002Lk?00bATL08CDf02m3A019GEh0Wk>d03]?
D00fBT/0>4a=03U=CP0dB4T0<dM90356B@0cB4/0=4U<03=8B`0eBTd0=T]>0P0eBTd0>P0fBdh0=4U<
03=8B`0eBTh0<dQ=0356B`0fBe00=daA03U>E00lDEH0?U=H045FF`0mDUL0>4eA03Y?D`0hDe40>EMA
03UED00gCd`0?U=?045BD00oCTd0@4m>049AD00oDU00?U5?03a@CP12EU@0?51>03Q<B`0nDU40A5QF
04EIEP11EE40B5eG04UNF00oE4`0?eA;04AID@18GE/0CVAT06YoP01FJfT0Bf5O04UOFP17GED0@eYA
04IMD@18Ge80@e]=03iEA`0lE4H0A5a>04IND01BJF00DfYS05I/J01IKfd305I/J@0@059XI@1DJfH0
EF]W04mWH@1BJV@0EVeW05A/IP1GKfT0PIRB06j6P014G5H0E6]U04aSGP1@Iel0BV9E04YRD`<0B61A
0300AemB03eEB01:HUD0@e]>04MNE01EK680BV9E04EKCP14FTd0Bf5E03eBBP1=HU`0@eMD04IKE`12
Ee40BEiF05=XG`1CJEd0B5iB04IMF@19Ge`0AEaF04IMEP11F4l0B5mE04AKD@19H5P0AUeE03mFD@0o
EE80@UQD03YDB00mE4T0AemB03aDA`0lDTL0?E=703Y@A@0cAcd0=TXo03mCB@0jCT@0<THk02ho=P0T
=Bd08C8Z02@e;@0V=c4202Lh<P0A02<c<00b@Sl0;Shk02Ti=`0Y>CH09cH^02He;P0V=Bl08C0Z020_
:`0U=300:STe02/h=P0U<S007bdZ020];00R;b`00P0V<Rh0C`0N:RH07BTU01hZ9P0M:BD06bLS01hZ
9P0P;2P07BTU020/:00Q;RP07B/S01dZ9P0P;BT07BPY01dW:00O9bX07bLY02<Y:@0R9b@07R<M01`Q
6P0Q9R006b0K01<H4`0P9B0061dH028W8P0Z;bX04aPC01dR7@0J7aX06b0K01DJ5@0K7AP061/D01TL
5@0I71H05QTB01PK500J71H04QD>01XL5P0G6Q@06ahG01HI4`0I6aL061XG01HH5@0D5Q<05aTF01/M
6P0>40d07R0M01DG500=3``061XG01DG500F5a<04Q8?01<D400E5Q804A8>01DE4`0B4Q004a<A01DE
4`0G5aD05ADC010@3P0D51803`l=03Xj>02UYJ<08R8P018B401NGU`0VIVG01/K6@0E5A<00P0@40h0
9P0B4@d04A0=00l>300?3P`04@l?018@4@0D4Q<03`d>01<A4`0F51L04Q0C010>4@0<2P`04a4B010?
3`0>30d04@l@00l=3P0>30d04@l@00h<3@0A3a001@<401LE5P0A3a803@/>014?4P0@3Q406QPK02XX
:`0?3A004Q0C03Pf>@15@dH06ALJ02h/;P0P7Ql02PP90P0>30d00`0B41403`d>00h<3@0200l=3P0>
00d;300?3@h04Q0@00l>300?3P/05QDB028Q7@0N7AX061LD014@3@0=30T09RDS024P7`0?3@d2018?
3`0301TE5P0A3@h04Ph?00803@T:1@0>2P/0200=2``03`l?00h=3P0D51@0>STi02l];P0>30d030X;
0`0>2P/04P0?2@/04`h@018>3`0<20T03PX;014=3P0@30d03PX;010<3@0?2``04@d>00/720091@H0
3`X;010:2P0@20P04PP901L<3@805@P:02<05PT;01061`0@1`P05@d>010:2P0<1`D05Q8?00/71@0;
1PD04Ph;00/71@0<1`H01`<100`81`0>2@L040`900h91`0F40l03`X700`6100=1`H02`H300h91P0;
1P@04@`900h81P0=20H040/8018<300>1`d03@H>00d63@0>1`h03`P@014:4@0201094@0900/4300A
2Q4030D<018;4P0@2Ph04P`?00`62@0G4A@03PT;00<03@L:00@030H900d72P0A2Pd04P`?5?ooool0
01_ooooo00D06QhO00`@4@0830d0KW9c01@H6@0200`@4@0A014D5@0?4180414C00/<3P0H6QT03@l<
00`>2P072@@04A<@03Li=@3inoH0IVQU018D400B50l04Q@@014C400<3P/00`0H6QT02P0C5A@030h=
00T;2P0=3`h030h=00d?3P0@4Q403a4@00h@3`0<3P/200lA3P0400`>2`0?4@h051HC00L91P80418?
00X02`d:01XL6@0R92405a`F02hc;@011P0041D?00hC3@0D5Q402`d80P0?4@`05@0>40/03a4<01DG
4P0=3PT030/7014A300H6A@06QTE018B3P0D5A004a8>014A3@0C50l06QTG01dN700D5Q<05QPE01DG
500210405ALD00d?300200lA3P0700h@3@0?4@h03a4>00h@300=3`X03a4<00h@2`0200`>2@0800h@
2`0<3PT02`d800d?2P092`H03@l:014C3P0@4Pd200d?2P05018D3`0?4@`03@l:00lA300A4`h00P0@
4Pd01@0B50l02``702LX8`0l?CP030d800803@h901H051D@00H70P0L7AP0=CHa01PI500?40/02@/8
018D4`0E5aH0418A014C4P0>40l04A<B00X<2`0B51<0418A00H81`0B51<04Q@A00lA3P0=3``03a4>
0P0B5140100<3P/03@l<00h@3@0>40d200lA3P0K00`>2`0>40d0418?010B3`0>40d030h;030b;`0>
40d02@/801DG500>40d061XG00D70P0c=C006Q`G0084000?4@`03@l:00lA300B50l030h901DG4P0O
8A`02`d800d?2P0>40/0418=008051HA00<03@l:01<E400@4Pd00`0?4@`01`0@4Pd07AlJ02X/:@0B
50l03@l:018D3`0210000P0=3`X0300C5Pl04QD?00P;100A50d03a8;01PK500F6A804QD>02/^9`13
ASl09BPQ01@G408030l802H02`h701LJ4`0;3PL041<<01DH4@0>4@X02Pd6010C300?4P/04A@=010C
30082`@02`h701LJ4`0E61403Q4:00d@2@0B5@h051L@01<F3`0@4``06A`E01@G400930D01PT201/N
5`0>4@P06QdF00d@200S9Qd04A@=010C2`0E60l06QdF01XM5@0=40L02Pd6010C2P804aH=00d04QD=
014C3P0A4`h0418>014C3P0C5A004aH>014D2`0C5Pd030l8010C300B5@h03Q4:00803A0700d03a89
018E3P0B5@h030l800`>2@0E5a80418=02LY900@4Pd051HA01<E400C5Pl04QD<00804aH=01D041<:
010C200C5Pd05Q/D01LL5@0;40T07B8K00lD3@0A5Pl051TB00/@2@0C6140314:01@I4P0I7QL02a0:
01@I4`0@5@l04aPB00lD3P0H7AL0100E6Q@0100D6A<04QLA014H4@0D6a@201HM5P0;01@K500A6140
3QD>01DL5@0C6Q<07B@M014H4@0M8al04ALC018K600F7a`00`0H8Ah0:`0C71T06B8O01HO700K9240
5AhK01PQ7P0C7QX05b8N01PS7`0G8Qh06bHR01hY9@10BdL05b8N00`G4`0Q;2P07RTU01lZ9P0T;bT0
41/E00lJ5P0R;R/0B5AB02Pd<P0K:RP06BPU02ho>@1AHEX0<3lh01LV7`0Z>3L0:CLg020`;`0Q<C40
:3Lj01PZ;00S=CL09cTm02Lj?P0V>Cd0:3/o02/n@P0Z?D400P0Y?4002P0[?T80;T550395B@0X>cl0
CV5U07jAU@18Fel0<DA803=7B`0cB4d203A9CP0403=8C@0eBTl0=T]@03A9CP80=DY?05`0=T]@03U>
D`0hCE<0<TI=0314B`0fBU40@5AK04=GH011EE`0?E9G03aAEP0mDU@0?E=A03Y@C@0jD4h0AE]H03iD
D@0mDdd0;T<l04QMEP0jCDL0?U5;03iAC00dBD@0<dM503Y>C00dB4H0@5AB03U=C@14Ee/0BUeQ09f`
]021U9P0F6a]04MKFP19GUT0@eQA04MLD`1=HU/0?eA=05Q/IP1SMfh0EFYQ049FC@10E4/0AUa@04=H
C@17Fe00@EM;03]@A00jDTD0>e=604QOE01CJV00E6]S05M^I`1GKVP0EVeW05M^J01IL6X0F6mZ05E[
J01AJVL0DVaX04YUH01=IV00EW1X04eXG`1FL6L0DVaU04aWH014GET0GGMc04aUH@1BJF40CfMJ04eU
F01<I5L0BF5D04AKD@1:HEL0CVEK05A[H@0jDDL0CfIL03E=@016GU00EViQ05eeJ018H5<0?UE;03aC
B`80AEaD0P14Fe<0?`16GE<0AUeE04YQG012F5D0@eYD04MNE`13FU80?UE=049ID@13FU00@UU?041G
C`0oET`0@EQ>03QBA`0fD4L0?eU>03iEC00lDd/0A5]A03I;@`0aASl0=4U003E8@@0aA3h0<THm02hn
>@0W=S407RdX01`[9P0Z>C@0=D@o02Xi=00]?3L0:3Lb02@c;P0U=2l093<^02`k=P0R<B`08c8_01XY
9P0N:RX09c<c02Xf=P0[=CH09Bl_024[:P0U;bh09S4/01hY8`0M9R407BPR01lZ900O:RH07BPT01PT
800H9b@082l/01l^:`0M;2T07bXW01/T8@0201XS800401HO7P0A6QT0:S0`01hT90807B<Q02<07B<O
01`R7P0S:2L09BTZ01/O800A5AH06AdN020T9@1DF5T09RX[01TM7P0P92D06QhO014E5@0K7AX06Q`G
01PJ5P0G6AH061XE01/M6@0I6aP07b4L01/M6@0C5A805QPC01TK5`0I6QD06Q/F01HG4P0K71L04A8=
01XK5P0K71L06AXE01HG4P0201DF4@0W01<E400D5a005APA010C300B5@h061/D014B3@0G61<04A4=
00d<200?3PX05A@@01LF4P0D4`l040l;01`K5`0[:RH06APD014@301DDdl0UIB@020O6`0:2@D08b8N
014@300>3@/05QDC00/:200E51804a8@00l>300C4Q004Q4?014@3P0B41404@l@00h<3@0?3@h04@l@
00804a4B00d04@l@00l=3P0A3a0040h?018@4@0C4A8040h?00h<3@0=2``04@l@00d;300B41400@00
00804Q0A00H03@/<00h<3@0A3a003P`=00/92P0B3Ph200d9200300l;2P0A3@`04@d<00804@d<0P0@
30/03`0?2`X03PX901PG4`0F5Ph02@T0051@@`1cM6H0BDXl02<T600K6QD08b8N00l=40091Pd03@X=
00d9200201DA400<00X61@0@30/05Q8A010<2`0?2`X030P700/71P0=2@P03`/;00`:2`0>2P/03@X;
0`0>2P/01P0H51D020@5010<3@0B3Pl03@T:01@@4@D03PX;00@03`/<00h:2`0=2@X02`L80P0:1PL0
9@0<20T02`L800h92`0?2@/02P@6010:300C3@l03PP:00/51`0F418030P900T41P0;1@L02`D500d5
1`0A20/040X:00l72@0D2`h04@/;01082P0?1PT03PP801492`0>20X03`T9010:2`0=1`T030H600h8
2@0A2`d030H600T310090`D02@<301<=3`0<1PP01@0<1PX0300:10P04`dA00@00P0E3a<02PD8018<
400>2@l050lE01<>50070PP05Q0G01<<4`8050XB00@04@L?00h4300@1@d04PP@5?ooool001_ooooo
00H04QHG00dA4P0E6AX0>Cdn014E5P0?4a@200hB4`0C010D5@0;3a004ADF04a@C`0G6AH04aDA01HH
50092`L07R0L05mQG@0_<Bd03Q0<01HH500;3@T04A<?01<E4P0F61L051HE018D4`03014C4P0700lA
400=3`h03a4@014C4P0@4Q403a4@018D4@0200h@3@03010B3`0>40d030h;00804Q@A00X01PP6018D
4@0?4@h03a4>01lQ700B50l0418=018D3`072@@04A<>0P0>40/05P0=3`X030h900d?2P0B4`h02``7
00h?2P0A4Pd04a@?01LH4`0A4Pd0414<00l@2`0<3@P02``700d>2@0>40`0:2XW01TK600:30T03a4>
01HH5@0>40d200lA3P0900h@3@0?4@h03a4>00lA3@0?4@`04A<>010B3@0>40/03a4<00804Q@?0P0C
5A001P0;3@P02P`700h@2`0B50l0418=00`>2@803a4<00<03Q0;00lA300?4@`00P0<3PT00`0?4@`0
51D@00/<1`02014B3@0;00h?2P0A4Pd04a@?00`=200@4@`05QLB00T:1@0B4`h03Q0?00d?3P0?4A00
0P0A4a802`0>40l04aDD00L9200=3`h04aDD00lA400B51<03a4>014C400C5A804A<@00803a4>00L0
418?014C400@4Pl0418?014C400@4Pl03Q0=00@03a4>01D03Q0=01DG500;3@X061XG00T:200>40d0
30h;00T;1P0Q8ah04aD@00T;1P0B50l030h9010B3@0A4`h030h900/=200@4Pd03a4<01<E400>40/0
0P0B50l0100<3PT04A<>01<E400@4Pd200lA30<0418=03805ALB01HH4`0>40/03Q0;01@F4@0B50l0
30h9018D3`0E5a802`d8014C3P0B5@h041<<014D3@0=40T04A@=01XM5P0>4@X030l801<F3`0A50d0
4QD>00d@2@0C5Pl03Q4:018E3P0C5Pl04A@=01<F3`0?4P/061/D01`O600A50d03Q4:018E3P0@4``0
3A09010C300E614051L@010C300A50d02@`501XM5P0B5@h04aH?02`_:00Y;2D04QD>01DH4@803Q4:
01X071lH01DH4@0?4P/041<<018E3P0D5a005QT?01<G2@0C5P/04QD=014C3P0A4a004aDC01<E4P0@
4Pd04A@<018E2P0A50P06QdD01HI4P0@4``04A@=01@G400C5Pl04A@=018E3P@051L@00h0:2XU030b
;@0E5a805ALB010B3@0D5a004QD<01@G3P0F6A005AP=01<F2`0D5``03a@=014F3`8051TB00`04QL@
00hC300K81T03A8;01LL5@0D6A806QlH01<H4@0C61804QLA00hC3@0F6aD201<H4P0801@I4`0E6Q@0
5AXD01@I4`0C61804QLA01XQ6P0G7QL201DL5@0801LN5`0J8AX051/D02/b:`0e?3D09bhW01PO600R
:B8201HO700_01DN6`0D7AX051dJ01<L6@0K924051dJ02@]:P14CDX0>44n01@O6`0C7QX05b<O01PT
800G8al062@P01TU8@0K9b<09S8^01PT800L:2@08RhZ01LT7@0E81T0:3<]02D`:P0iAD<0/Kfm04aH
F00S<C406b/X01`]9`0X>C80834W020a:@0O;R`08c<b02Ph=`0P<300:3Xk02`n?`0U=cT09cXm02Lk
?@0W>Sh0:3e002Xo@P0]@4@00P0[?T80400/?d<0;D1402m2AP0_@TH0<4=703U<D00aA4P0;3m303I:
C`0fBe00=daA03E:C`0cB4d0=4U>03I;D00gC54203Y?E00e03I;D00cB4d0<TM<03=7C@0dB4h0>TiE
03mCF`10E5d0?E5I03]?EP0lDEH0@5EG045GE00mDe00?55?03mCDP0oDe40?U==04=HD@10ED`0>Di5
03mDB`0kD4T0=DY503mCD@0lD4l0?51>03M;B@15FET0SJ2S08bOY01OLWL0CF1U03a?DP12EUD0BEiI
04QMEP14FU00?U9804]OE@1PM6X0C61F04QLDP14F4h0B5aB04eQE`17Fe40BEeC04EIC`11ED/0@EM;
03mGBP18GeD00P1?IU`00`1BJF40DfYR05A[H`0205E/IP0@05U`J`1LMG40EVm/059]J@1AK6L0DfiW
05A_I`1BKV<0DFeR051[H`1EL6T0D6]V069mN@1PNWH0DVUQ04mVG080CVEK0180Bf9H04QOE@1;HUP0
Bf9H04YQE`1]Q7X0BF1F04QPD`13Fdh0@UY=04IND@0mEDP0?EE903M>A015G580AEaC04IME@17GUH2
04UPF00404QNF`1:HE/0BF1J04MNF080AEaD03d0A5]C04AKD@12FDl0?eI<03iFB@0oEdX0BVAK03A>
A@0fD4L0?UE=03aCB`0oETh0>Di703M;A00jCTL0=TU302`o>@0[?SP0:STd02/j=@0Z>C@09cHa02Dd
;`0V=C009cHa02Xi=00U=2l093<^02Lf<@0V=C0093<]028a;@0Q<2d08S0`02Ha<`0Y<cD0:cDg02/e
=P0U;Rd082TV028[:00T;RL08B/S01lX8`0P:R@08B`V020[9`0O:RH06bLS01/Z9`0M;2T062LT01TW
9`0L9bD08bTW028X9P0/<S00728P02D[:@0S:BL082HT00807R@R0P0O9B<01P0P9B@06alQ01XN800O
8bD08RHX01TM7`8061`N00D06AdO01PL7P0<41806QhP01TK6P0501TK600701LI5P0J71T061XG01DG
500H6QL05aTF028S7P02034b;@0A02PY900G61<05AHA01LH4`0E5Q4051D@01HG4P0G61<05QPC018E
3P0A5Ph051L?01DH4@0D5a005aPB01hO6P0H61@00P0C4Ph05@0D4Ph0510=00l>2P0C4Ph04Q4=01/J
5P0D4`l04a8>01HE4@0e=30051<?01/J5P0?3PX05QDA01XI5`0=30/02PT701DD4P0D4a405aHD01<B
4002014@3P05018A3`0A40h03Pd;014?400C4A800P0E4a@02P0C4A804@l@00l=3P0@3Pl04Q0A01DC
500C4A804Q0A01<A4P091`P200`:2`0401XH6@0@3Pl03@/<00d;30803P`=0P0?3@h0100C3`h03`/:
00l;2P0A3@`5018>3@804@d<00h040`9020O6@0P81P0<S8V0;FfY`3oonh0k>gK08j?P@0H61005aHB
010=4P0;214030P>00d920802`L600T05A4@02`X9`0Y9B@04Ph=01<?3P0A3@`03`/:010<2`0@30`0
1@0>2P/01`0:1PL05Q8C00h:2`0>2P/00`0000l;300=2@X01@0>2P/200l;300500h:2`0=2@X030P9
00d92P0?2``00P0<20T02P0=2@X02PH700`82@0>2P/0510A00h:2`0@30d03`/<00`82@0B2@`20148
2`0301<:3@0D2`h04PT<00804PT<00l040L:00l62@0?1PT040L:00h82P0?2@/040X<00d72@0<1PP0
3PP:00P2100@2P`07aTK01/E5`0@2P`0200=1`T04@0;1@L04P`>01@>400A30d0JVAX0<W4bP0F4AL0
4PdD00h9400<1Pd04``C00l53@0>10`03P@=01863`0D21404PL@01Cooooo000Kooooo`8041@E00d0
3Q8C00010P0;3a005ATJ00hB4`072``041@E01LK70052@X04QHE01<E500G6AH07R0M008051HC00@0
1`T601<E4P0<3P/0418?0P0B51400`0:30T03a4@00`>3@0200/=300300d?3P0>40l04A<B00803a4@
00d04Q@C014C4P0?4A003a4>01PJ5`0C5A8030h;00lA3P0C5A802`d:00840@0K7AX0418?00805ALD
00h06Q`G01@F4@0C5A002`d8018D3`0?4@`05ALB01<E400@4Pd03@l:010B3@0D5A003@h900h?2P80
30d800D04A8=00l@2`0C50l051D@018C3P0200h?2P0>01HG4`19BdP09RPU00d?300C5A802@/800d?
300?4@h03Q0=00d?300>40d03a4>00h@300?4@`2010B3@803Q0;00@03a4<00d?2P0@4Pd051HA0P0@
4Pd0400A4`h03a4<00`>2@0>40/04Q@?010B3@0:30L02`d800lA300C5A006A/F028T7`0:2`H06AXE
01<D3`0?40/2018C3P04010A300F5a805AHA010A30804Q<>0180418A00/=300>40l04aDD014C4P0C
5A@02@/:00X<2`0H6QT030h=00H81`0F61L030h;014C400E5a@03a4>00d?300B514200lA3P803Q0=
00<03@l<00`>2`0>40d0100?4@h06P0>40d03a4>01DG500J71T09bTV014C400N81d03Q0;018D3`0A
4`h0418=00lA300>40/03a4<018D3`0H6QD05ALB00h@2`0A4`h03@l:018D3`0?4@`02`d800`>2@0=
3`X04A<>1P0@4Pd0900?4@`06A/F00lA300;3@P06A/F00`>2@0=3`X04aD@00lA30031@002`d800hA
2P0<3`P04QD>01HI4P0D5a005APA020S700C5Pl06A`E00hA2P0I71D01`X3018E3P0=40T03Q4:010C
300?4P/03Q4:00/>1`0=40T03a8;00T<1@0:3@H04aH?01@G40<041<<020030l8010C300=40T0:bhW
08jARP072P<00`H0028U7P0V:B8051L@014D3@0<3`P071lH014D3@0B5@h03a8;018E3P0>4@X02`h7
00lB200A50T04A@;014D300A4`h04A<@01LI5P0F61<0418=014D300E60l04QD:01@G3P804A@=0180
4aH?010C300>4@X04A@=00lB2`0@4``05APA01HI4P0@4``05aTD01dO6P0I6aH05QPC00X<1`0I71D0
4QD<01@G3P0F6A0201@G300:01HI3P0C61404aPA024V7`0?50d06b0I01DJ4`0Z;bP05a`E01hS7080
3Q<<00P041D>01LL5P0B5a4041D?01lT7P0K81X04QLA01<H4P@051TC00<04QLA01TP6@0F7AH00P0C
6Q<02@0F7AH06B0I01PO600X;bP0=chg01hU7P0I81T061lH01@M6P0201<L6@0X01@M6P0H8Ah06b@Q
01DN6`0J8b004AXG01<L6@0E7Q/08RdY01<N6P0F8Qh06BDQ01PT800E8Ad0520L01hZ9P0H92006BDQ
01XV8P0G8al06BHO01`W800E81X08bhX01hZ:00]>CT07b/[01`Z:P0L;2T06R/U024b:`0O<2H09cP`
02<b<00R<S409CDd02Hf=P0V>3P05BLW02Li>`809c/l00<0:3/o02Tn@@0Y?T400P0Z?D40BP0[?T80
;T550395B@0]@4@0<TE90313A`0cATX0>4]?02i1A@0_@dP0<dQ=03I;D00hCE80>DiC03]@E@0oE5T0
?55F03I;D00bAd`0<dQ=03E:C`0aATX0;dA703A9C00jCe@0>TiE03I:D`0gBe<0>TiE03iBF@14FEd0
A5UJ045GE@16FeX0?E5@03U=B`14FED0IGYc03eBB@0fBd80>4e403Q=A`0jCT`0?e=A03I:B@0iCTT0
@eQC03eAC`0oDe80?U9C03Y>C`1:GUl0AEUH04MKF010EDh0AEYA04AJCP0jCTD0?51704UME01;GeH0
EVYQ04YNE@15FE00BUiE04AHC`1:GUD0BEeD04YNE@17GE40A5a?04UPEP1>IE/0CFAJ0P1AJ600501E
K6@0FG1Z05U`JP1TNgH0LXR505YcL01AK6P0Eg9]05MbJ`1AK680Eg=W05=_H`1AK680FGA]05IaK01G
LFd0Hgah05=ZHP1@Ied0CVEK0P1?IU`08P1=I5X0BV5G05=ZH01DJf40TJRN04eTFP19HE@0D6QK04EM
D014G4l0?UI903iFBP0eC480@EQ>04=JD@15G5@0AeiF04QOE`19H5P0B5iK04MNF016GEL0AEaF04MN
EP18GeL0A5]C04AKD@12FDl0?EA:03aDA`0mEDP0A5iE02e7?P0_BD0303]BBP0<03E:@`0hBdD0?E1:
03Q;A@0/?cT0:c`f020_:P0M;2L07RdX02<b;@0V=C009cHa0P0X=c805`0T<bh09C@_02He<00T<bh0
93</02Lf;`0O;RX08c8_02@`<00S;Rl0:S@e02Tc<P0T;RX082TT024Z9@0R;2@082XR01hW8P0O:B@0
82/U01lZ9P0L9b<06RHR00806bXW00X05bHS01d[:`0[=S@04ALE02`b<02GWI/07B<Q01DK6@0R:2H0
7R@R0P0M8b40400O9B<08BLU024V9P0I7Ah061`M01lS900K7b005QXK01DI6P0I7Ah05ATJ01hR8`0<
414061`L01LI600H6QL201/M6P0=01XL6@0H6QL05QPE01DG500F61D06A/H01/M6P0E5a@05aPC02@U
800J6aH04A8=00h?2P0201XK5P0T01PI500E5Q405AHA01DF4@0B50l05QTB00lD3@0B5@h051L@00lB
2`0B4`d0414<00l?2`0@3`/04a8>01DC3`0E4@h02PT501DD400?3PX06APD01XI5@0A40`04Q4=01/J
5P0510005QDA01<B3P0>3@T02@P602LV900B4@l0;bh/08n>S0040`404Q4?0P0A40h01@0C4Q004Q4?
00l>300A3a004Q0A00804a4B01D04Q0A014?400A3a0040h?014?400D4Q<04a4B018@4@091`P01`D6
02LU9P0Q7b00JfUZ03<a<P0E4a@05aDF01@B4`0>30d03@/<00l=3P0C3`h00P0@30/201<?3PH04Ph=
01T04Ph;01<B3P0M7AD0>SX`0;>dY@3ooo40m_OW07AdI`0>3PH04Q4=00T72`0A3QL03PX>00h:2@0A
3@`03@T800H20@070`803@T8014=300D40l04`l>010<2`0?2`X03`/;00H03PX;00D04@d>00H20`0D
41401`<4018>3`0600h:2`803`/<0P0>2P/01@0?2``040`=014=3P0=2@X030P900803PX;00D03@T:
00P41@0:1PL02@D6014=3P0200`82@06010:300@1`X03PD801072P0A20/03`H90P0@1`X03`0?1PT0
3PD800h5200>1@P03PP:00l92`0@2P`03@L900`6200>20X030H800l92`0H4Q@050h@00`6200700h8
2P0?00P2100C3@l03`T;00l92`0:10H09AlQ02TT:P0F4AL01`8800P32@0=20h0100401<94@0@1Ph0
50XB00806a0H00<05@XBooooooooool04_ooool001_ooooo00T01@T:01TM7P0K7b00310A00lC500:
3Pl04QHG00T=3P011@H00P0>4Q<01P0<40l030h=01HH5@0E5a@06Q`I010B3`805ALD00D05aTF018D
4@0C5A803a4>00T;2003010B4@0400lA400>40l03@l>014C4P803a4@00l04A<B010B4@0?4A004A<@
01<E4P0>40d030h;00/=2P072@H03Q0=04=5@P25Qh@05QPE00h@3@0I6aP00P0A4`h02P0>40/03@l:
01DG4P0<3PT05QPC01<E400@4Pd03Q0;010B3@0F5a8200l@2`0300h?2P0A4Pd05AHA00803a0;00L0
4A8=010A300>3`X03Pl:00d?2`0_<Bh04A<@00803@l<00<01PP5018D4@0>40d00`0=3``01P0>40d0
3@l;00d?2P0?4@`03Q0;00`>2@803@l:00/02`d800`>2@0@4Pd03a4<01<E400F61<03a4<00/=200D
5Q406adH01@F4@02010B3@0700lA300>40/03a4<01DG4P092PD05AHA018C3P02010A300?01LH4`0<
3@P051D@014B3@0=3PT05QLB00`=200A4a803a4@014C4P0@4Q403@l>010B4@0C5A@020X900803Q0?
00P03a4@00`>3@0;3@X03a4>014C400=3``0418?01LI5P803a4>0P0>40d00`0=3``030h;010B3`04
00lA3P0<010B3`072@H051HC03Pj=`2JW9T0?d4n00lA3P0A4`h04Q@?01<E400@4Pd03@l:0P0@4Pd0
2`0>40/04aD@01<E400?4@`04Q@?00P:1@0J71L03a4<00`>2@0F61<03@l:00H0418=00<04Q@?01<E
400C5A000P0>40/00`0C5A0030h900lA300201<E400B01HH4`0X:RD04aH?00lB2`0A50d03a8;00`?
200?4P/09bXS01HI4P0I71D030l801LJ4`072P<03A09018E3P0A50d03Q4:0P0<3`P00`0@4``04A@=
01@G400200lB2`0301PK500G6Q<041<<00803A090P0;3PL05`0S9Ql041<<024T7@0@4``082<L00lB
2`0G6Q<010L001HI4P082`@06A`E01HI4P0E61405aXC01PK500?4P/03Q4:014D2P0A50T04A@;014D
300A50d04A<>008061XE01H04A<>01<F3P0G6Q404aH;014D2`0@4``04aH?014D3@0>4@X06QdF01PK
500C5Pl04A@=01LJ4`0J7AH05APA018D3`0>40/04A<>01`N6@0B50l02Pd60`0C5Pd05`0A50T04QD:
01LJ3`0A5Pl041D>01XO60083@H05AXC01<H4@0?50d04AH?01DJ4`0<4@X0:RlX01@I4P0K81X06AhH
00X?2@0;40X0314;01XO6@0C618051TC00<05AXD00<051TC01HM5P0F7AH0100F7AH01P0E71D04QTB
01/R6`0?5Pl05A`E00`C30804a`I02`051dJ01HO700K92407RLT01<L6@0E7Q/051dJ01hW900M9R<0
7BPT01PS7`0I9B4072PT01dY9@0I9B405b<O01dY9@0hA4007b/W020/:00T<2`06RLP01DP6@0M:280
5b8L02Hb<00H92@09C4a01l];@0J:RL072dW02Tj<`0Q<RP08S<[028a;`0S<c80=TI502`l>`0V>3P0
8S@d02Pj>P0W>c`0:3`m02Xn?`80:Ci100h0:ci202Xm@@0[?T80;T550354B00dAd/0;T5502`o@`0b
ADT0=4M;03=6BP0cAd`0=DY?03Q=DP80>TmD02h0?55F03mDF@0kD5D0=DY?03=8C@0fBe00=daA03A9
B`0dBTP0>Tm@03iCE`0lDEH0>DeD03U=E@0lD5L0@5AK04EJG`16Feh0@UMJ03iBDP0lD4l0AEUG03eB
CP1<HEX0<DHm03Y?AP0aASd0>Tm904AHEP0lD4h0?51?03M<A`0nDd`0>Di:03I:B00kCdh0?e=A049F
E011EU40@eQB03]@A`13FDd0AeeA049FC@0nDTT0CV9I0P1<H5L0:P1=HEP0E6QO05M[HP1=HEP0CV9I
04]OEP1:GUD0Bf5E04QPD`1=I5X0DFQN051WG@1DJf<0CfIN05=ZHP1FKFL0EFaV05ieL01[PGh0FG9_
05=/J@1ILVh0F75[055[H@1GLFH0CVQM04mYG`1HLF/0FgA`05M`K01VOg/0E6]S055XGP1?IU`0D6MM
055XGP1@Ied0EFaR04mVG012FDl0IGab04YQE`80AemB00T0A5a>04IND@0nETT0@5Q<03]BB013FU00
AUeD04UPF01:HET00P1;HUX02P1;HEh0@5MA03iEC`14FeD0B5mG04MNEP14Fe<0A5]A049IC`0mE4X2
03aDA`0D03]BBP0eC4@0=di603]BBP0iCTL0>4e603E:@`0hBdD0?E1:03M:A00/?CL0:3Tc02Dd;`0Q
<2/08S4/02Th<`0_?ST0<3lj02`k=P0[>SD202Lf<@0E02Dd;`0P;bP093@Z02Lf;`0O;RP08S4^028^
;00Q;2/09c4`02H`;`0T;R/08R/V02<]9@0Q:b<07RPP01dV8@0N:2<07bXT01dX900L9b<072PT0080
7B`Y01<06BPU01l];@0R;2/0;S@b02<Y9`0Z<2h06AlM03Dk>@0G7A/0728P01/Q7`0L8R007R@R020V
900T:BT07R8S01`P8@0Q9BH05a/L00806alP00L04aLH014E5P0L82404ADF01dQ8@0G6AP061XG0080
6adJ00D06Q`I01PJ5`0H6QL05ALD01LI5P0201/M6P0:01HH5@0;30L05aPC01DF4@0H6A@051D@01LH
4`0J6aH05aPC01DF4@8051D@01T04Q<>01LI500@5@l04Q@?01HH4`0E5a804a@?01LH4`0E5A0051<?
01DD400D4Ph04@d:03hm>@0[:RH02@P4010?2`0I61@05QDA00l>2P0B4@d020L300`;1`0G5Q803Pd9
00802`X800X061LE01XI5`0_;R`051<A014@3P0@3`d04A0>01<B400B4@l03`h<0P0@3Pl2014?4080
40h?01<0518C014?400@3Pl04@l@010>3`0>30d0518C004000050`@02PP901`J6`030@805A<D01LE
5P0D4Q<03P`=00d;300?3@h04`l>00804@d<0P0C3`h00`0A3@`04Ph=018>3@03018>3@0I018>2`0N
7AT04A4900`<0P0m?S40LG9T07EfJ00^;R803@d501<B3P0:20/04PlH00h:3P0?2`X03PX900`81`0A
3@`061@C01DA400@30/04Ph=014=300>2PT03@T800h:2P0500h:2`06010<3@060P<00`00018>3`0?
2``02@D61P0>2P/500l;300?010<3@0?2``030P900/7200<20T03PX;00l;30030000@Cdn034];P03
00003@T:018>3`0B30h040X<00803@L900<03PP:00d72@0>20X00P0>20X02P0=1`T030H800`6200>
20X03`T;010:300=1`T030H800h82P0A2`d200/51`0300h82P0=1`T040X<00H03PP:01803`T;018<
3P0400001P02014;3@0<1PP0100501<>500R7B<00`0400d73P0F3aH040H>00`22P0?1@d05@XB01@9
4@0=0PXDooooo`006oooool0100<41405a/L00X>3`0;3a0200hB4`0C00H:2`0B5QL0310A00hB4`0;
3a003a<D00/=300@4Q003@l=00lA3`0E5aD071hL018D4P0N81h051HD00h@3P082PP04aDC00h@3`02
00d?3P0400h@3`0?4A003a4@014C4P803a4@01D0418A00lA400=3`h03Q0=00T;200;3@X0828O01lQ
7P0>40d04aDB03Tk>01bM74061XG00h@3@0?4@h03Q0;024S7P0<3PT051HA00`>2@0:30L00P0A4`h0
2`0?4@`03@l:00d?2P0>40/03Pl:01LH4`0D5A003@h9018C3P0?40/0414<00804A8=00X0414<014B
3@0<3PX04Q@A00X<2@0B514020X700lA3P0A4a003Q0=0`0=3``00`0>40d03@l;00h@2`0200lA3080
3@l:00l03a4<00h@2`0=3`X03a4<00/=200>40/04aD@018D3`0?4@`051HA01XL5`0F61<03@l:00h@
2`0?4@`00P0=3`X05P0@4Pd0;BhY00d>2@0?40/06AXE00d>2@0B4`h0414<01DF4@0?40/020T401DF
4@0A4Pd04aDD01DG5P0A4a804Q@C01PJ6@0=3`h0418A01<E500Q8b8200d?3P0301LI600=3``03Q0=
00803a4>00@04Q@A01HH5@0@4Pl04A<@0P0@4Pl0100A4a00418?014C400@4Pl200lA3P0F010B3`0A
4a003a4>01<E4P0F61D0EUQE02DW900C5A804A<>018D3`0A4`h03a4<00h@2`0@4Pd03Q0;018D3`0<
3PT02@/600lA300B50l03a4<018D3`802`d800H04Q@?00d?2P0?4@`0418=014C3P0B50l3010B3@03
014C3P0>40/03Q0;00804A<>028051HA00lA300B50l071hI02PZ9@0l?ST04QD>010C300C5Pl04A@=
00lB2`0B5@h04aH?00hA2P0D5a004A@=018E3P0<3`P041<<01HI4P0C5Pl041<<00lB2`0=40T041<<
01<F3`0J7AH05APA014D3@0D5a004QD>00hA2P0@4``04aH?0P0B5@h02@0A50d01`X501<F3`0?4P/0
51L@00`?200@4``05aXC01DH4@02018E3P0W01@G400B5@h04A@=010C300=40T04aH?01HI4@0@4`T0
41<:014D300A50d04A@>01DG4@0F618051L@01@G3`0E60l051L=01LJ4`0B5@h04aH?014D3@0@4``0
9RTR01@G400B5@h04A@=01HI4P0G6Q<04aH?01TK5P0<3PT04aD@02la;00e=c805QTB014D2`0C5Pd0
5AP?008051L<00<05QT>018G400B5a000`0C61403P0D6A805AXC01dR6`0E6Q<03A8;04Y?B00g?3D0
6b0J010E3`0I7QP0=c`f02hc;@0?50h05AXD0P0G71H201PM5`0301LL5P0E71D061lH00806R4J00P0
61lH01DL5@0E71D051/D010G400F7AH07B@M01HM5PH05QlL03`06B8O01/T8@0D7AX06B8O01PQ7P0P
:bL07RTU01`X900N:RH08BdY020/:00N:RH05b<O020/:00e@Cd0?4Q401dY9@0K:2407BPQ02<^:00N
:B<07BTW01dY:@0S;bl0:SPh01d]:P0I:R@093D^024b:00V=bl0:3Ld02De<`12DU009cLf024c<P0_
@D00:cdm02Lk>`0X?3`0;41102Xo@@0X?Cl0<4=702`o@`0[?T80:Se102/n@P0_@TH0;T5503=6BP0n
DED0>4]?03A7B`0fBTl0>e1E03iCF00mDUL0>TmD03U>D`0jCe@203M<D@0U03]@E@0lDEH0=T]@0357
A`0fC4T0>U1=03aBD`0jCe@0>dmF03mCF`13Ef00@eMO04IJH@15FEl0@UIL041EE`0oDe80>Ti=03Y>
B`0oE4l0?55:03aAB@0nDd`0?E9=03iBD00dB4L0B5aK03iCC@0jCdL0?E9;03Y?B@0mDT`0@EI@04AI
D`10EDd0B5eD049HC002049HB`0D04]PE`10EDd0B5aD04aQF@1AIUh0B5eE04YOE`1@IEd0C61H059W
G`1CIel0E6UP051XF`1>IUT0DfYP05I]H`1CJV00E6]S05I]I@1HKfL205YaJ`0R05]aK@1MLg00EVm/
05YcK`1ILV`0Eg5X05A^I01EKf<0EW1T05UcJ@1FL6L0GWMa059[IP1HLF`0F6mW05A[H@1AJ5h0DVUO
05=ZH01BJEl0CfIL04iUF`1:HEL0D6MM04UPEP0kDdH0@5Q;049JC@1:HUD0AEe@04aSF01<HeT0B5mE
04]RF@<0CVEM00h0C6=K04aRG`11F580@5MA04ELEP16GED0AEaD049ID@13FU00@EQ>03eDBP0mEDP0
?UI903aCB@80?eI=00@0?59:03U>AP0gC4@0?5590P0iBd@01@0bA3d09SL`02<d;@0T<bh0:STd0080
;C`g03L0;Sdh02ln>@0_?ST0<D0k02ln>@0^?CP0:3Lb020_:00M;B807RhT020_:@0R<B`09C4_02D`
;P0S;B`08bhZ028/:00Q:b<082XQ01hX800M9al07BHQ01lY8`0O:R@07BPT01dY9@0N:RH07B`Y01l^
:`0K:RL072XZ01dX9P0S:BL06b4O01dS8@0K8Al09R`Z01`R800J81h0728P01lU8`0P9R@08BLU02DZ
:@0F6QX03a<C01hR8P0K7al09BTY01lS8`0C5aL06AdM010D500X;2`05ATH00H06A/H03<06Q`I01HH
5@0H6QL06A/H01DG500G6AH071dH01dN6@0K71L07b0K010A300G61<05QLB01@E400C50l05AHA01HG
4P0E5a803a4=01HK5P0E5a<03@l;018D400C4a004Q<>014A300A40`04a8>01DC3`0E4@h0<c8^02@S
7`0C4Ph06QTE018A3@0<2`L05aHB014@300o?SX06QTE018A3@0G5Q8040l=038a;`0G5QD05aHD00h=
300C4Q004A0>010?3@0A40h00P0C4Q000`0@3`d040h?010>3`0200l=3P8040h?00`04a4B010>3`0=
2``03`d>00d;300<2P/03P`=00/92P0C4A803@/<01XI6@071@H200d;30803P`=0P0?3@h01P0B3Pd0
40`;014=300C3`h04Ph=010<2`<04@d<0`0B3Pd0600>30P05A<>01<A2P0D4`P08R4E02TY700E4`X0
518=00l<2@0B3a402`L>00`8300A3@`04Ph=010<2`0A3@`03PX900d9200?2`X040`;00h:2@0<20L0
3@T800h:2PD03PX;00L040`=00l;3018A4D05Q8C01DA4P091@H03`/<00D03PX;0P0@30d08@0?2``0
3PX;00h:2`0>2P/03@T:00l;300>2P/020@500X61`0=2@X040`=02hZ:`0R7Ql02`L800h:2`0=2@X0
5a4C01@>400@2P`03`T;010:300?2@/03PP:00l92`0@2P`03`T;00h82P0=1`T03PP:00l92`0@2P`0
3@L900`6200200h82P0400X41P0<1PP04P`>010:30L03@L90P0;1@L0400B30h03`T;00`6200=1`T0
4PdA01dH7@2^ZJh0EU5F00/62`0<1`/040H=00h52`0>10/040D<01463@0>0`XDooooo`006oooool0
7`0=4A804aLH00`@4@0>4Q<03a<D00hB4`0@51D02`l@00lC500E6AX02@d>01HJ6`0;3@`01`T801LI
60082PT0<C<b010B4@0B51<03@l>00T;2P0H6QT020X900d?3P0@4Q403@l>00`>3@0@4Q4061XI01/M
700@4Q400P0=3`h05P0>40l03@l>00/=300>40d06A/H014C400>40d04A<@00`>2`0;3@X051HC00`>
2`0:30T030h;010B3`0B50l0HVAO00lA300=3`X04A<>00h@2`0@4Pd2018D3`09010B3@0?4@`0414<
01lP6`0e=S409RLR00X;1P0>3`X0414<00804A8=00X03a0;00h?2P0@4@`04A8>014C400J71T06adJ
00d?300M7a`02`d:0P0=3``01`0<3P/03@l<00d?300>40`03a4<014C3P0@4Pd00`0>40/0100=3`X0
418=01<E400=3`X200`>2@80418=024020X500T;1P0>40/02@/600/=200=3`X030h900/=200<3PT0
3a0;00<4000G61D04a@?01HG4P0B4`h01PL2010A300E5Q402@X5010A300?40/0418A01<E500=3`h0
7R0O03@f=@0K7A`03a4@00d?3P0I6aX03Q0?01@F5@0E5aH00P0>40d01P0@4Pl04aDB018D4@0=3``0
30h;00d?30803Q0=0P0?4@h0;P0B5140418?00h@3@0>40d0418?018D4@0D5Q<05QPE018D4@000@00
6A/H00`>2`0>40/03@l:00T;1P0>40/04aD@00`>2@051`8092HQ028T7`0F61<05ALB00h@2`0Z;2L0
3a4<01<E400D5Q4030h901dO6P0>40/0418=014C3P0B50l04A<>010B3@0F61<04A<>01@F4@0@4Pd0
3Q0;01DG4P0C5A0030h901<E400F61<200@60@07014D3@0=40T04aH?01@G400:3@H01`X301@G4002
00lB2`0601<F3`0>4@X05aXC01@G400@4``02`h70P0A50d01`0:3@H04A@=00X=1P0=40T03Q4:010C
300C5Pl00P0?4P/04P0D5a005aXC01@G400B5@h03Q4:01@G400F6A804QD>00L:0`0G6Q<03a8;03Dh
<@0[;RL00`H0028U7P1>DDX05QTB014D3@805APA00D04aH?018E3@0?4PT03a89010C2`02014D3@0:
010C300A50d04aH?01<F3P0A50/04aH=01@G400?4P/05APA01HI4P8030l801L04A@=018E3P0G6Q<0
6ahG01TL5@0C5Pl030h9018D3`0K7AP04Q@?01HH4`0?4P/030l6018E300K7QD071lD01TL4@0E60d0
41D>01@I4P0?50d092TR01@I4P0201<H4@09014F3`0oA3d092TR014F3`0E6Q<04aPB01@I4`0@5@l0
6QlI00805a`F00<05Q/E01PM5`0I7QP00`0I7QP03@0C6Q<051/D01DL5@0E71D051/D01<J4`0530D0
6b8K01<J4`0L8a`05ahG01`S700C71T00P0E7Q/0<@0D7AX04AXG00lH5@0G81d072DR01TR7`0O:2D0
72DR01lZ9P0I92005B4M01HR7P0L:2@07BTU01/W8`0Q;BT06RHR024]:@0L:2@05b<O01dZ8`0L9b00
8RdW00lJ500Z=S@07b/[028^;P0P;Rh093@a020a:`0S=2d0:c`b03a=A@0c@Sh09SHc02Ti=P11DE00
D6=Q02`o?@0[?Cd09c/j02Tm?00]@D80:Sm002Pm?P0]@4@0:Se102Tl@00Z?D400P0[?T80;00hBdl0
=TU=03A7B`0jCE40=DQ<03U=D@0jCe@0?U=H03mDF@0mDUL0?55F03iCF00kD5D0=T]@03M<D@0iCU<0
=T]@03E;B`0kDT`0?UAA03iCD`0mDUD0@5AK04MKH`17Ff@0AUYS04EIH@13Eeh0@5AK03a@E@14F5T0
?U9A03Y>C00/@C`0Bf1K03Y?B014FE80?U=?045EE01BIVD0Oi>C049GDP0gC4<0?U=:0P0fBd801015
FU00AU]B03U?@`0oEDT203mEB00:04MMC`1?I5/0IW]d06UnM`0oE4d0@eQA04QMEP1;H5T0DFIO04mT
G@80F6eV01/0FFiV05A[H@1CJeh0EfiT05Q_I@1BJEl0CfIN05A[H`1EK6@0Fg9/065hLP1OMG40FW1]
05E^JP1PNG@0FG=Z05I`I`1ILfL0E6iQ04iXF`1FL6@0CVQO05efL01EKVT0E6eW05]bJP1FKF<00P1B
JEl0401CJV00DVUO059YG`1;HUP0AUeC055XGP16GE<0BF5D04mWFP18H580B61C04=KCP18Ge@0@eY@
04IMD`19H5L204]RFP0H04UPF017GUH0BV1M04]RG019H5X0AEaF04=JDP14Fe<0@5M?045HCP10Edd0
?UE;03eEB00oEdX0?EA:03]BB00hCdD0>e1703eBB@0lDDP0>Ti503E6?P0dACd0;d0h0P0X>C40D00Q
<2/0:CPc02Xi=00/>cH0=4<n03]:A@0^?CP0<d8m03A3?P0eA3l0;3/f02<b:`0J:R0062PN024`:P0O
;RT08bl]02Lb<@0Q:bX07bXV01hX900L9Qh0628J01/U700N:2007RLR020Z9@0P:bD07RTU01/W8`0H
920062LT020_;00O;R/07B/[01`W9@0R:2H09B/Y024W9@0R:2H03aDC01PN700I7ad07R@R028X9P0S
:BL08RPV04M<B`0o@d806QhM01PL6`0B5QD06QhM01dQ800=4A0061`K01`P7`1ZKVd0720O01/M6P0J
71T061XG01LI5P0H6QL06adJ01TK600F61D05aTF01<E4P0>40d05ALD00l@2`0I6QD0=CHa03dn>@0I
6QD05QLB01TJ5@0G61<051D@0P0C50l08P0A4`l06A/J02lc<P0[;B/030h;010B3`0F5Q@08B4O01`L
600F5A405A@@01@B3P0B3P/05QDA014@300B4@d061LC00`;1`0D4`l02PT501@C3`1CDTh03`h:01<B
3P0G5Q8030/900d<2P0K6QP03@`:010?3@0C4Q0040l=00l>300A40h201<B4003010?3@0B41404@l@
008040h?00H04@l@018@4@0?3@h030X;00X82@0=2``200h<3@0B00/92P0A3a004@l@018@4@0<2P/0
5Q@E018@4@0=2``03P`=014?400>30d02`T:010<2`0?2`X040`;018>3@0@30/03PX90P0?2`X0400@
30/04@d<014=300A3@`03`/8018?2P0F4`h05A8:01DB2@0K60l040d501@A30091@8040`=00L21P0F
4Q@200l;2P0:00h:2@0C3`h03`/:00/71P0@30/03`/:00`81`0;1`H03@T800l;2`D03PX;00L03@T:
024M7P2VXZ<061@E00d92P0@30d030P900D03PX;0P0@30d01`0?2``03PX;00`82@0<20T03PX;01XF
5`0H51D00P091@H02`0?2``00`0001DA4P0>2P/02PH7018>3`0?2``05Q0B01<=3`0>20X030H80080
3@L90P0?2@/2014;3@0700l92`0>20X03PP:00l92`0@2P`03@L900`6200200h82P0400d72@0?2@/0
3@L900P210L030H800H03`T;00`6200>20X03@L901PB500>20X200/62P0:01TD600<1`/03@L;00d7
2`0>1@X03`H;00h52P0>0`T040D;01@93aCooooo000Kooooo`04010D5@0?4a@03A4B00dA4P803Q8C
01802Ph?03Lk?00F6Q/07B4R00hB4`0?4a@05ALF018D4`0E5aH0004003/m?00A4a8030h=010B4@0?
4A002P`;00/=300>40l200lA400500h@3`0@4Q403@l>00P:2@0=3`h00P0@4Q402`0H6QT0;Bl^03Tk
>P0?4@h0418?01XL6@0@4Pl030h;01@F4`0B514061XG00803a4>01X04aDB00h@3@0@4Pd03Q0;010B
3@0C5A00418=00`>2@0A4`h030h900d?2P0B50l04A<>00`>2@0N7aX0Q8F004Q9A00E5Q402@X5014B
3@0B4`h0414<00l@2`0@4@`04Q<>01<E4@804aDB00/03a4>00/=2P0;3@X0418?014C400>40d030h;
00d?300@4Pl0418>00d?2P0200/=200500`>2@0?4@`0418=00lA300>40/00P0=3`X0100>40/03@l:
00`>2@0?4@`2010B3@L03Q0;100>3`X0700?40/04A8=01@E400A4Pd03a0;018C3P0C50l04A8=00L9
200H6QT04A<B00`>3@2SYJ@08R@S00d?3P0I6aX02`d<00d?3P0F61L05ALF01HH5@082PL0418?00h@
3@0D5Q<0418?014C400@4Pl400h@3@<0418?00H03a4>00h@3@0=3``03@l<014C400@4Pl200/=2P03
010B3`0A4`h03Q0;0080418=02403Q0;014C3P082PD03Q0;01HH4`0?4@`09BLR01TK5P0H6QD04Q@?
00d?2P0;3@P05QPC02/]:00<3PT02`d800d?2P0@4Pd01`T400h@2`0@4Pd030h900/=200B50l05aTD
00D70P0?4@`030h900d?2P0@4Pd04A<>010B3@0<3`P00P0C5Pl0<P0?4P/04A@=01@G400A50d041<<
014D3@0C5Pl04A@=00lB2`0A50d03Q4:01DH4@0:3@H03a8;01HI4P0@4``03A0900hA2P0A50d04QD>
01HI4P0/;bP06ahG010C300A50d01@P1018E3P0?4P/03Q4:01<F3`0E61404QD>028U7P0F6A8020/4
01HI4P0<3`P04QD>01hQ6P0B5@h03Q4:00d@2@0?4P/041<<00lB2`0=40T03Q4:010C2`0B5@`04aH=
0P0A50/04P0D5`h051L?01TL5@0W:R<04aH?00hA2P0C5Pl03Q4:014D3@0F6A8051L@01LJ4`0J7AH0
61/D01LJ4`0J7AH03Q0;01<E40804Q@?00X06A/F01DH4@0;3PD03a8901DH3`0G6Pl05QT>01PK400?
50d051TB0P0C61403@0I7QL051TB01/P6@083@H0F5eF018G400E6Q<06b0I014F400C61804AH@010E
3`0B5a400P0A5Q009@0F6aD010T306]`JP0I7QP05a`F01LN5`0C6Q<06R4J02<Z8`0b>C805QdF01TP
6@0H7aP05ahG01HM5P0G7QL061lH01<L6@0F7a`04a`I01LP7@0A6QL05b0M02@]:P1ZLg007bPU02L`
;@0J8b007BPT01/V8P0H92005R8N01PT800K9b<07BTU020/:00M:BD00P0L:2@01P0M:BD07BXS01hY
8P0Z=Bl062<M028^;08082`/01L09S@d01h^:`0G:280:CXc03E6?00mCTH0Df9M0310?@0W=c@0<T8o
03=6A00]@3h0:chl02i2@@0/@3l0:3`k02Lm>`0Y?Sl0:ci20313A`0_@TH0<4=702`o@`0202e0A005
03U<D01@HfL0?U5E03U<D011EEX00P0oE5T06P0nDeP0>e1E03Y?E00kD5D0?E9G03]@E@0dBDh0<DI;
03I;D00iCTh0?5==041FD`0oE5@0?E9E049FG@13Eel0BUiW04EIHP1:GVH0Ae]R03U=E00oDeL0?U9C
03eAD00hC4X0>Di90P12Ee80500nDdh0?e=A049FE@0mDE00C61P041ED017G5D0>Tm604EKC`0oEDT0
?59503aBAP0oEDP0>e5403iDA`19Ge80B5iA04QME01GK6D0GW=/0P16Fe@02@1=HU/0CfAM059WH01G
K6D0FVmX05]`J@1JKfL0E6]Q05I^H@0205YaI`0O05I]H`1AJ600GGA/05ieK@1PMg40GgI`05abKP1I
Kf`0EVaY05Q^JP1OMVh0F6mW05YbIP1FKV40GWIY05UaI@1QN6h0GgI^05Q^JP1QN780G7=[05I]H`1C
JV00EFaR05I]H`1CJV00BF1F04MNE012FDl0EFaR04iUF`0204UQE00804QPDP17Ge80AemB04MND`15
G580AUeC04MNE@1?IUh204UPF01F049ID@1<HUl0A5]E04=JE016GEL0A5]C045HD016GED0?EA:03aC
B@0oET`0?EE803UAA00mDTT0?55803mDB`0kD4L0>Ti503iBB@0hBD40;Slg02`m=@0Y>34093</02Dd
;@0U=2l0;Sdh02/j=@0X=c80;C`g02ln>@0c@Sd0;C`g02He<00M;2L072/V01h]9P0/?380:STb02<b
;00Q<2/09S8`02@_;P0O:BP07bXV01lY9@0I8a/06bDM01lY8@0N:2007bPS01dW8@0J9Al06bHR020/
:00D81`09cHc020_;017EU<0938b01TS8P0M8b40728P01XP7P0K8Al07bDS01dS8@0K8Al08RPV02H/
:P0R:2H0:Bl]07^0OP1EFEP03Q8A01hR8@0B5QD05ATH00lC4P0B5QD0720O01XN7@0E6AP06AdL01lQ
7P0L7Q/401TK600301`N6`0J71T05aTF00805ALD00<05QPE01LH4`0G61<01@0G61<07`0F5a805AHA
01@E400F5a805aTE020R8@1lP840@dE500lA40082PT05QHE01HF500D4a004Q4=018A300C4@`04Pl:
010?2`0J6AD07ahJ01DD400@3`/01`H201TH500<2`L07A`H018A3@0920D07A`H018A3`0>3@/00P0H
5aD0500?3P`05A@B01DD4P0@3`d05A@B00/:200B4@l05A@B014?400C4A803`d>028P8@0c<C804@l@
01<A4P0B41403@/<010>3`0?3@h02PP90P0@3Pl08P0A3a004Q0A01<A4P0C4A803P`=00P61`0C4A80
30X;01/I6P0E4a@05a<B00H20@0K5aH02PH500P40`0G4a803PX900d9200>2PT040`;00h:2@0<20L0
40/8014<2@0B3@T050l:01@?2@0C3PP05Q4<00P3000=20D03PP:01D?4@0?2P/2018>3@0700l;2P0<
20L03`/:014=300=2@P02`L600`81`0200h:2@0E00/71`0K5aP020@501XF5`060P<06aLH00X61`09
1@H09b<T00d92P070`@061@E014=3P0<20T02`L8018>3`091@H06ADF00T51P0>2P/02`L800803`/<
00@02PH7014=3P0Q7Ah081`M0P0?2``00`0@30d03PX;00h:2`0200`82@0H00d92P0;1`P04@d>00l;
300>2P/00`0000/7200D41406ADF00P41@0U8B802`L800T51P0?2``08adO028L7P0C3@l030H801@>
400<1PP02P@600d72@0A2`d03`T;0P0=1`T2014;3@0<00L10`0?2@/03PP:00h82P04000050h@010:
300400004@/=00H00P0>2@d03@P<0P0<1`/01P0>20`03`T=0107300@1``03`H;01052`803`@:5?oo
ool001_ooooo0P0>4Q<0200<41402`l@00`@4@0<41403Q8C01PL7@0A5AH05a/L0P0;3a001@0<3@h0
3Q0@01LH6@0@4Q804Q<D00803a4A00<03a0A00h?400=3`l00P0=3Pl00`0>40l03a4@00lA400300lA
40803Q0?010030h=00/=300>40l04A<B00h@3@0A4a0020T703Hh=@1SIF805ALD010B3`0F61D03a4>
014C400F61D04A<@0P0>40/0600@4Pd04aD@014C3P0?4@`03@l:00lA300A4`h03@l;00d?2P0B50l0
1@H301PI500=3PX051D@01<D3`0=3PT04A8=010A300A4Pd04a@?01HG4P0E5Q80418?00h@3@803a4>
00<03@l<00h@3@0?4@h00P0>40d0100?4@h04A<@010B3P0>40/200d?2P0:00lA300B50l04A<>00lA
300>40/03a4<014C3P0B50l04A<>00h@2`803@l:00<03Q0;014C3P0>40/01@0>40/200l@2`803Pl:
01`03a0;014B3@0@4@`03Pl:00d>2@0?40/04A8=010A300@4Q402P`;00/=300B51<04aDD02PZ:@0?
4A003Q0?018D4`0:30/06adL00h@3`0?4@h02P`900h@3@0?4@h04Q@A00h@3@0A4a00418?0P0>40d2
00lA3P0800h@3@0@4Pl04Q@A018D4@0C5A804Q@A00lA3P0>40d200`>2`0400h@3@0@4Pl03a4<00d?
2P804A<>01P03@l:00lA300=3`X0418=014C3P092`H05ALB00T;1P0;3@P0418=01DG4P0B50l030h9
014C3P0?4@`030h900d?2P0@4Pd02@/6018D3`0=3`X02`d801<E400=3`X200lA3003018D3`0G6A@0
5ALB00803a4<00H04Q@?00lB2`0B5@h04QD>010C300?4P/2010C300G00lB2`0@4``04A@=010C300>
4@X041<<00/>1`0930D05aXC010C300?4P/06A`E014D3@0B5@h04aH?014D3@0=40T071lH018E3P0>
4@X04QD>00T<1@0C5Pl00P0A50d3018E3P0701XM5P0D5a003a8;01DH4@0<3`P03A0901@G400301<F
3`0J018E3P0A50d041<<010B300@4``041<;014D2`0B5@/041<9014D2P0C5Pd04A@<014D3@0I71H0
3A0900lB2`0A50d0:B`U02P[900B5@h03Q4:014D3@0C5Pl04QD>014D3@0C5Pl200lA300801<E400F
61<05ALB010C300B5@`051L>01LJ4@0E60d201<F2`05018G400D6A805AXC014F3`0>4``00P0?50d0
2P0L8AX04QL@020U7P0B5a004aPA018G4@0F6aD04AH@01TN600R9b43018G4@0<00lD3P0J7aT05AXD
01<H4P0<4``06R4J01<J4`0H7aP0HVUR01dT7@0>5@h04aXC0`0G7QL03`0I81T04AXG01PQ7P0@6AH0
5QlL01XS800R:bP09Bh[07b5PP0X<Bh04AXG01hW900E81`07bXV01/W8`0201TU8@0301XV8P0K9b<0
7BTU008072PT01H07RXV024]:@0R;bP08bhW02D`:P0X<bd0<Shl02<_;`0K9bL08S0`02<c<00[?3H0
:c`e049CB@1_P7H0d]kL09j^ZP1HJ6@0<T<n02Lj=`0aA440:chl0P0]@D004@0/@3l0:d4o02e3@@0`
@dL0;T5502Tl@00/?d<0<4=70395B@0`@dL0<TE903e@E00jCE40?E1D049FF`0nDeP0?55F0080>e1E
00D0?55F03I;D00aAT/0=DY?03]@E@0203eBE`0?03Y@D00lDTl0@5IC04=HF@11EU/0@5AK04EIH@1=
HFX0@eMO04UMI01<HFL0@5AJ03iBEP10DeL0@UIG0080@UID01`0AeaG04UNF@0oE4l0Cf=Q08nSXP1<
H640@UEH04EIE`1;H5X0@UM?04QME014FTh0?UA7041FB00oEDL0@5I904EKC`18GU40B5iB04iTG@13
FE<0AUaE04UOF@1EJfD0CfEN059XHP1DJV<0F6iW0P1JL6T02@1IKfP0EFaR05I^H@1IL6H0FW5W05U`
IP1HKfL0FW5Y05]bJP0205edKP0W05]bK@1HKV/0GWA`05ecK@1PMVl0F6iT05]bIP1IL6<0Jh9e05ie
J@1JL6H0FFmW05abK01^Q7h0G7=[05U`IP1FKF<0EfiT05I]H`1CJV00B5mE04]RF01:HEL0E6]Q04QO
E@0oEdX0AUiA04ALC`18H5<0CFEH04eTF@18GeD0BV5G05=ZH@1HKfL0B5mG04AKD`15G5@0BEmL0080
DFQR00D0BF1J03mFCP0lDd/0>e9:03iEB`02041GC@1903eEB00lE4L0?59704IJD011ET`0>Tm503e@
AP0nD4L0=TLn02dm=00/?C@0:CP`02De;00W=Rl08S4/02He<00W=S40<3lj03A3?P0b@C`0<D0k02Xi
=00S<Rd072/V01d/9`0Q<2/093</01l^:00T<bl0:cTh02`h=`0Z=CD082XZ01XT900P:BL082TT01/T
7`0J91d07BLO01hW8P0M9b8072LQ01dX900Q;2P07RXV02@c<00G9R<0=DA101PV9P0M:2H08BLU02@Z
:00S:BL07B<Q01/Q7`0I7ad05adK01XP7P0N92806b4O01dS8@0S:2H0720N01TN6`0A5Q<04aLE01LL
6@0D6AH051PF01TN6`0J7a`05QXH01LL6@0201/M6P0501XL6@0F61D05QPE01TK600E5a@00`0D5Q<0
0`0F61D06A/H01LH4`0501LH4`0301@E400C50l051D@00804a@?03804aDA010A4`0`=3H0414D01@E
5`0F61P04A4A01HF500D4a004Q4=01<B3@0D4Pd04a0;01HE4@0C4Pl05A@@018A3@0K6QL0:BPT05YI
E@0K6QH04Q4=01LF4P0E51003@`801<B400?3P`040l=00d<2P0C4Q00:bXX014@3P0@3`d030/900h=
2`0U92804Q4?01DC500D4Q<030X;010>3`0H5QL03@/<014?400>30d03`d>01/I6P0G5AH02`T:014?
408040h?01D03`d>00h<3@0>30d04@l@00h<3@0=2``04a4B00L51P0B41404`l>00l;2P0<20L040`<
01`H5`0?2`X040`;00l;2P0@30/04Ph=010<2`0>2PT00P0A30X03P0B3@X04@`800l:1P0>2@H050l;
01/E500Q6a/050h>01<=3P0>2@T040`;014=300@30/03PX90P0?2`X200d9208040`;01803PX900l;
2`0=2@X02PH703/g>00:1PL03@T:010<3@0A3@h0BDE600h:2`0C3a001`<400l;300>2P/03@T:02XV
9`0C3a03014=3P802`L800H030P900T51P0<20T040`=00h:2`0810D200l;300O01<?400=2@X03`/<
014=3P070`@03@X:00l<3@0F4a@0514B014>3`0:1`P04Pl@02TV9`0;20T03@X;01HC500J5aP040`=
01PB500I4aD03`T;00d72@0E3a4040X<00h82P0<1PP02`D700`6200>20X040X<00/51`02010:3004
00h82P0:10H03@L9014;3@802PD600D07aTK00/51`0?2@/02`L900d92`0200l;3@0600h92`0<1PT0
40L;01072`0?1PX040D:0P0?10TDooooo`006oooool00`0A5AH041@E00hB4`0200hB4`0>00lC500@
51D020`=018F5`0>4Q<05ATJ00hB4`0B4aD030d?00l@4P0I6Q`03@h@00`=3`0A4Q@200d>4003014B
500?418030d?00803a4@00@0418A00h@3`0?4A0051HE0P0>40l0100@4Q4051HE01<E500B51<2014C
400;00P:1`0G6AH0=SPe00X<2@0<3P/03a4>00/=2P0=3``0418?00d?300B50l00P0A4`h04@0?4@`0
30h900X<1`0<3PT05ALB00D70P0[;BP0=3Ha00T:1P0H6A@04Q<>01HG4P051P404A8=018C3P0C50l0
4Q<>00<0414<00<0:2TU02la;P0L7Q/00P0=3``0100>40d03@l<00`>2`0>40d3014C400700lA3@0=
3`X03@l:00h@2`0@4Pd04Q@?014C3P0200h@2`05010B3@0A4`h04Q@?014C3P0>40/00P0=3`X00`0>
40/0418=00lA300500lA3006010A300?40/03Pl:00h?2P0?40/0414<0`0=3PT05@0>3`X03a0;010A
30072@P08R@S00d?3P0>40l061XI00lA400@4Q404A<B00lA400=3`h0DE=B010B4@0?4@h06A/H010B
3`0C5A803a4>00/=2P02010B3`803Q0=01003a4>010B3`0C5A804aDB018D4@0A4a003a4>00d?300@
4Pl030h;00h@3@0B51404aDB00d?300A4`h0418=0P0F61<0200@4Pd04A<>00h@2`0@4Pd03Q0;00/=
200A4`h02`d80P0B50l07@0F61<05ALB018D3`0G6A@03a4<00h@2`0@4Pd04aD@00X<1`0A4`h03Q0;
00d?2P0B50l03@l:010B3@0=3`X04Q@?01PJ5@0G6A@0418=00h@2`0@4Pd041<<00hA2P0?4P/04A@=
010C300?4P/041<<00803a8;01@04A@=00lB2`0=40T05QTB00lB2`0D5a003a8;010C301<CdP04aH?
00/>1`0@4``05QTB01@G400@4``061/D01@G400C5Pl04A@=00/>1`804A@=00L04QD>010C300>4@X0
4QD>010C300>4@X04QD>00@04A@=00H04aH?01DH4@0E61404QD>014D3@0A50h2018D3`0:014D300@
4`X041<8014D2@0D5``05QT@01@G3`0@4``04Q@?01<F3`805QTB00H0EEQA059ECP0G6Q<04A@=018E
3P0D5a0201<F3`0[018E3P0I6aH051HA01`N6@0R91l06A/F01DH4@0A50/04aH=01HI400D5``04aH;
01DH3@0?50d0314:014F3`0F6a@04aPA01LL5@0I7QL051TB01TN5`0>4``02@h701TN5`0B5a404AH@
01DJ500K81X0724K014F400=4P`05a`F01<H4P0F6aD0;S<]01LL5P0E71D03aH?01@K500B6A804APA
028Y8P0201PO600B01TP6@0K8Q/06R4J01HM5P0?61D0624N010I5P0K92408BXW01XS800H8Ah03QLD
01DN6`0G81d05AhK01PS7`0O:RH07BTU0P0K9b<07P0L:2@07BTU01XV8P0J9R806bLS01dY9@0O:bL0
7b`U028]9P0L9b409C0Z04UED`0iADD082`/02dk>`0X>3D0;d0j02m0>@1DIE/0Sj2F0>WhlP2L[JL0
@55;0393?@0X>cL0;d8n02`o?@0/@3h0;D4o02a0?`80:d4o00<0:Si00313A`0`@dL00P0dAd/0300`
@dL0<TE90395B@0fBDd0A5MK04YMH@13Ee`0>DiC03E:C`0dBDh0>4eB03aAEP80@eQM0P0mDUL203mD
F@0Z045FF012F5H0?eAE041EF@14FEh0AEUP04UMI@18G6<0@5AK045FF`14FE`0@5EH03iBE011E5P0
AEUJ04EIF@10E580?U9@03aAC019GUT0A5QG061dM@1KKg00AEQL049FE@16FUP0AEYD04QME019Ge<0
@eU<03mFAP0jDD40@UQ;04UOD`12F4`0AEY@05I]I@1AJ680D6MQ04aSG@1RNG<0E6]U0P1FKFL305U`
JP0905Q_J01GKV@0EViQ05M^I01HKfD0FG1V05]bJP1JLFT0Fg9Z0080GGA^02d0G79^05]aKP1RMg80
GgA^06=hK`1LLVH0I7Y^06IlK`1CJE`0FFmS06EkK`1SN6l0EfaV05EZH`1LLf/0G7=Y05]bJ01JLFL0
EfiT05A[H@1:HEL0C6=I04YQE`1<HeT0BV5G04YRE@11FD`0@5Q:04EMD01<I5L0C6=H04=JD016GE<0
@EQ?04ELE012FE40BF1H04IME@16G5T0DFQR05=ZI01:HE/0?eI>03]BBP0mE4`00P14Fe40:`0lDdT0
>51303UAA010ETX0BEeB03a@A@0jCT<0@U=903a=@`0hBCl0;cle02`l<P0V=R`08C4W028b:00[>SD0
;C`g02/j=@0`?cX0<d8m0350>`0Z>C@08C0[01XY900H9b8072/V020_:P0X=c808S4/02Lf=00X=SL0
:3<e02D_<`0N:2X07BLY02Xc<`0X<Bh072DR01LP6P0K9Ad07BHQ01hX8P0M:2800P0O:RH01P0Q;BT0
6BPU01l^:`0lBdP06RPX028/:`808bTW01H082HT01/Q7`0J81h0728P01PN700G7A/07R@R01dS8@0K
8Al08RPU01@I5@0=4Ph05AXF01TN6P0G71P06QlK01HK5`0H7AT06QlK01LL600E6QH06A/H0P0L7Q/0
2@0E5a@04aDB01XL6@0K7AX06Q`I01LI5P0F61D05aTF01PJ5`0301LH4`@05QLB01d05aPC01PI500H
6A@05aPC01@F4P1lOH40hNCY02d^<`0e=SX07QlQ01DE5P0F5Q@051<@018A3@0C4Pd05A<>01@A300A
40`04Q4=01<B3P1SHUh0UIB@018A3@0A40`030/701TH500@3`/030/7018A3@02018A3`0G01@C4@0A
40h040l=01`K6@0B4@l051<A00h=2`0920H071/I00X91`0L6Q/05aDF01<A4P0?3@h03@/<018@4@0A
3a003`d>00h<3@0F51D04a4B00X82@0@3Pl00P0?3@h200h<3@0C00d;301PGUl03`d>01TG60091`P0
6QPI014?400T81l03@T800`81`0C3`h01@4001HB4@0>2PT03@T800h:2@0@30/03PX900`81`03014;
2`0=010:2@0>20P03@P501hI5P0O6AT07ALG00/61P0A2`/03`X900d9200?2`X040`;00l;2P0200h:
2@0B00d9200<20L03PX900l;2P0>2PT02@D501PD5@0:1PL030T9014=3P0H51D02PL700<0000U8B80
4`l@00h:2`0C3a00:BDV0P0H51D03`0l>3T061@E00X61`0>2P/05Q8C014=3P0>2P/04Ph?014=3P0C
3a003`/<00X61`0=2@X04`l@00`82@0201<?40803`/<010030P901/G600100003`d>00P61`0=2``0
2`T:04E3A02/ZZ/0:BLX01PF5`0?3@h040h?00@20`0<1PP03@L90P0:10H01@0@2P`03PP:00l92`0@
2P`03`T;00802`D700l03`T;01<=3`090`D0208400`6200B30h02`D7014;3@0I4aD091hP05A>D00I
4aD04`d?00/7200=2@X00P0?2``01P0>2@X030H801072P0@1`X03`H901052@803`@85?ooool001_o
oooo0P0A5AH04@0?4a@03Q8C00lC500?4a@041@E014E5P0G6a`02`l@020T9@0D61T02``>014B500B
4aD03@h@01<D5P061`T04A8D00803PlA00X04Q<E010A4`0=3Q0030h=00X<2`0?4A004A<B01DG5P0L
7Qd04Q@C0P0>40l01P0?4A003Q0?00d?3P0?4@h04Q@A00lA3P803Q0=00@07R0M00h@3@0>40d02`d:
0P0<3P/05P0:30T04A<>018D3`0A4`h03Q0;00/=200:30L02`d801LI50051`80:bdX03<e<0092PD0
5aPC0001000@4@`02P/601LH4`0C50l04A8=010A300?40/200d>2@0=01hO6`0Q8b004A<@00P:1`0=
3``04A<@00lA3P0<3P/03Q0=018D4@0A4a00418?00h@300200`>2@0500d?2P0>40/03a4<00lA300>
40/00P0?4@`400h@2`803a4<00<03Q0;00d?2P0?4@`01@0?4@`2010A300400l@2`0>3`X03Pl:010A
30@03a0;00P0414<018C3P0I6aX071hM01DG5P0210<051HE018D4`80418A00`04A<B00h@3`1?DE00
418A00P:1`0M7a`03Q0=01DG500A4a003a4>010B3`0?4@h200h@3@80418?0P0B51402P0A4a003a4>
00d?300;3@X03a4>00d?300B514061XG01DG500:30T200d?2P804Q@?0P0=3`X0<@0>40/04A<>00d?
2P0?4@`0418=00lA300C5A00418=014C3P0@4Pd03a4<01@F4@0A4`h04aD@01LI500H6QD030h9018D
3`0?4@`04A<>00h@2`0H6QD08R@O00lA300>40/0418=018D3`0C5A00418=00h@2`0>4@X03A0900hA
2P0C5Pl051L@01<F3`0B5@h041<<014D3@0B5@h03a8;00d@2@0@4``03Q4:018E3P0<3`T05QTB05YM
EP0L7aP00P0C5Pl00`0E61404QD>010C300201HI4P0W01DH4@0@4``030l8010C300A50d04QD>010C
300>4@X04QD>00lB2`0@4``04aH?00lB2`0C5Pl051L@014D3@0C5Pl051L@018E3P0?4P/041<<01<E
3`0C5A004Q@?018E3@0@4`X041<8014E1`0D5``05AP?01DH400B50l04Q@@014D3@0N8AX03A09024T
7@0K7QL041<<00805APA0`0F6A803P0E61405aTD014C3P0H6QD07AlJ01DG4P0C5Pl04QD<01@G3P0F
6A0051L<01<F2`0E60d05Q/D0P0@5@h07P0D6A804aPA010E3P0E6Q<07b@M00lD3@0L8AX03A8;01<H
4@0I7QP04QLA01hS7@0O91h04QLA01HK5@0L8A/061dG00L<1P0D6A<0=S/e024V800L8a`051/D00dD
3@0I81T07RDN01`S700K8Q/05QdF01DL5@806B0I00h04aXC010I5P0G81d051dJ028[:00Q:RL04a`I
01XS800T;BX08BXW00lH5@0L9B805b8N01/V8P806bLS00<07BTU01l[9`0O:bL00P0M:BD0600N:RH0
7b/W01l[9`0O;2D07BPQ03E0>P0P:bD09S8`02Hb<P0R;Rh0;cdm02lo?00a@S`0<T<l03I7?@1<GE<0
T9nH069cK@0U=S00=4Do02/n>P0^@Cd0;D0l02a0?P80:clm00P09cdj02Hl>P0Y?3l0<4=70354B00h
Bdl0>diB03I9C@80>4]?00D0>Da@03mBEP0mD5@0>TiC03aAEP0203Y?E00603iCF012Ee`0AEYO04=H
G@0oE5T0@UML0P16Ff00:P14FEd0@UMJ045FF@12Ee`0AEUP04EIHP16FV80A5QO04=GGP0nDeL0?55B
041FE011EUL0A5MK04UMGP1:GUh0AEUG045ED`10E580@EEC04eQH017Fe`0?51A04MJGP16FU/0B5aK
04YNF`17G5D0Bf5E04EKCP0oEDP0>e5404AJCP1:GeH0A5U@04IKD`1EK6H0CfIP04UPFP1JLF/0PYVC
05acK@80F6mY0`1IL6X00`1HKfP0FG1V05Q`H`0305M^I00I05U`J01LLf/0GGA/05ieK`1OMW00GgIa
05meLP1SN7<0GgA^069gKP1KLFD0HgU]06EkKP1OMFP0GG=W05idJ01LLFP0G75[065fK`1MM6`0GgI/
05ieJ`1LLfT0F6mU05E/HP03059YG`0A04iUF`1<HeT0B61C04=KCP12FTd0AemB04aTE`1:HEH0@UU?
04IMD`18GeH0CVEM04IME@19H5P0AUeE04QNF`17GUP00P19H5X07013FU80?eI>049ID@16GE<0@UU?
03U@AP0iDD@0?EE804EJC`13Ed`0=DTn03Y>@`13E4X0>T]103I6?00/?380:c/a02Pe;00T<BP09C8Y
02dl=`0b@C`0;C`g02/j=@0`?cX0<D0k02Pg<P0O;RT201XY900L01l^:@0R<B`09C@`02@c<00Y=cL0
9cDh02/f>P0[=CX08BX_028[<00Y<S@09Rl^028[:P0M9R806bDM01dV8@0N:2807RTS020[9`0N:RH0
:cLc024`;@0E924082l/020^;P0f@3l092XX020V90806R0N01@082HT024W9@0H7Q`05adK01lU8`0P
9R@07B<Q01/Q7P0>4`l05a`H01lT800=4Ph05Q/G01/P700H7AT06AhJ01`Q7@0H7AT05AXF01/M6P80
7R0M00T05aTF01DG500L7Q/071hK01XL6@0H6QL05QPE01LI5P0H6QL00`0G61<00`0F5a805AHA01DF
4@0201PI500N01XK5P0I6QD061TD01DG4`0N7b<0GV5V01@E6@1TIFT0=cPj00l?400F5Q@051<@01<B
3P0D4`h05Q@>01DB3@0=30P05aHB01/J5P0Y:2@0;RdY00h=2@0T8al04A0<01<B3P0@3`/04A0<00d<
200C4Q004A0>0P0D4a402P0@3`d03Pd;010?3@0D4a405A@B00D40P0:2@P03@`:01@B4`0=2``2014?
400900d;300?3@h040h?018@4@0=2``040h?01<A4P0A3a003P`=00803`d>0P0@3Pl0500A3a00HEmP
00l=3P0I5aP020H701TG600@3Pl0FUIE00L30P030000;BTX00<0000A3@`03PX900d9200>2PT040`;
00h:2@0<20L04@X:0`0C2P/00`0B2@`04PT:01hE5P0201H=3P0<00/40`0D30X03`X800d9200>2PT0
40`;00l;2P0=2@P03PX900d9200:1PD02`L60P0=2@P01`0?2`/03`/<00/7200M6AX04@d>00h:2`0C
3a000P0<20T05`0B3Pl00`0001LC500X92D071PI00d92P0D414020@5018>3`0?2``06QHG01@@4@0<
20T03PX;00`82@0?2``030P900/7200@30d05A4B00h:2`091@H05A4B00803`/<01007a/L030/;@0B
41405A<D00@20`0C4A80108300d<300Z:2T0108300<10P0B41403@/<00l>3P0?2@/040X<0P0?2@/0
5P0B30h040X<010:300G4A<06Q@F010:300;1@L040X<00h82P090`D04`d?00/51`0=1`T01`4300@0
000:10H0100002DO8@05004030H800h:2`0=2@X200`82@0600h92P0?2@/040L:01072P0?1PT040D9
0P0?10PDooooo`006oooool00`0@51D03a<D00dA4P0200dA4P0=00hB4`0:3Pl03A4B00lC50052@X0
4aLH00dA4P0>3a80414D02HW:P0a<SD05aPK01HG6P03010A500F014B5@0B4aH04Q<E01`N7@0>40l0
418A00lA400;3@`0418A00lA400@4Q403Q0?00d?3P0?4A004Q@C014C400@4Pl02P`:014C4@072@H0
4Q<A014C40803Q0=00H0418?00h@3@0<3P/02`d8010B3@0A4`h200lA300?010B3@0C5A005ALB00lA
300<3PX03Q0;00d>2@0E5Q4030d801LH4`0:2`H04Q<>00l@2`0=3PT03Pl:00803a0;00/03Pl:00l@
300=3``03@l<010B3`0?4@h030h;00/=2P0>40d03a4>014C4002010B3`0300h@300=3`X03@l:0080
3Q0;00H03@l:00h@2`0>40/03a4<010B3@0?4@`200h@2`0500lA300@4Pd03a4<00lA300=3`X01P0@
4Pd00`0A4Pd0414<00l@2`0200h?2P0I00l@2`0B4`h04a@?01<D3`0@4@`03a0;018C3P0G6AP020X9
01<E500=3`h06A/J00X<2`0=3`h02P`;01HH5`0>40l05QPG00h@3`0E5a@0=CLd01<E4P0I6aP03Q0=
00d?300200lA3P803Q0=00D0418?014C400?4@h0418?014C4002010B3`0900lA3P0@4Pl03a4>018D
4@0F61D04aDB00/=2P0A4`h03a4<00804Q@?00h03a4<014C3P0@4Pd04aD@00/=200B50l030h9010B
3@0E5a804Q@?01DG4P0D5Q403@l:00`>2@803@l:00d0418=01<E40082PD03Q0;00lA300C5A003a4<
01dO6P0Y:bH051HA00/=200<3PT03Q0;00804Q@?00T04A<>00lB2`0A50d04QD>01<F3`0F6A806A`E
01<F3`0A50d00P0B5@h0200?4P/03A0901@G400@4``02Pd6010C300=40T04QD@0P0?4P/02@0@4``0
4QD>01DH4@0C5Pl030l8010C300B5@h03A0900lB2`03014D3@@04QD>01004aH?018E3P0@4``051L@
018E3P0?4P/051L@01HI4P0C5Pl03a8;010C300C5A404aDB018D3`0B5@d04QD:0`0A5@L02`0A50T0
4QD=018D3`0B514051HA01HI4P0@4``06QdF01TL5@0B5@h05QTB00805APA0P0F6A804@0C5Pl05QPC
01@F4@0B50l051HA01HH4`0F6A805QT@01LJ4@0F6A004QD:014D2@0C5P/03a@=01HK500C61403Q<<
00<05AXC00T02Pl803i3?00I7QL051TB01<H4@0C61804QLA01LL5P0H7AL00P0E6Q@01P0C61805Q/E
01XO6@0A5Q007R<M00lD3P8051/D00d072<L00`C300H7aP07B@M010G400I81T072<L01PO600E71D0
5ahG01@M6P0G81d06R<P008092dZ00X0<CXg01DN6`0I8Ql08b`Y01<L6@0G81d062<O01TT800J9R80
6bLS0P0N:RH201l[9`0H020/:00R;RX08RhZ028^:P0R;bP082/T02Xe;`0K9R0082`Z01l[:`0T<300
;cdm02Lg=00R<bd0;Chg02ho=@0a@SP0?4]403a=AP0^?cP0<d@n02Lj=@0^@C`0;d8n0P0[?cd04`0/
@3h09cdj02@j>00]@D<0;D1402/n@P0dAd/0@5=G03a?D`0hBdl0>diB049EF@14Ee/0?E1D03Q<D@0i
CU<0>e1E03eBE`0nDeP00P0oE5T0;P11EU/0AEYO04QMHP14FEh0?eAI03iCF012Eed0AUYP04MKHP16
FV80Ae]T04MKH`11EE`0B5eR04AIFP10EU<0B5iK041EEP10DeT0@eIJ04MKF`17FeX0AEUG04=GE@16
FUP0H7Ac04=GF016FEd0CF1V04MJGP14F5T0B5aJ03mDCP17G5<0@eU=03iDA`12F4/0BV1D04aQF01=
HU/0CfAO04aSGP1BJVD0EfmZ05A/I`1VOWT405Q`J`80FG5/00<0FW9/05YaI`1JLVD00P1JLFL07@1K
LVP0G7=[05ieK@1OMVh0H7Ma069iL`1TNWH0I7Yg06EjM@1QMVh0HGI]05M]H@1LLVD0Fg5S05edI@1P
MVT0H7IZ05icJP1NLf/0H7E^05edJP1RNFl0HgY`05mfK01IL6H0EVeS05U`IP1CJV00EfiT0080CfIL
00<0A5a?04MODP1:HUD00P1<I5L0@01;HUL0BF1F04IMD`1AJ5l0EVeU04MNEP1:HET0DFQP04QNF`16
GEL0AeiH04QOF@15G5@0@UUA041GC`11F4h0?UE;03]BB010F4/0AEe@04IJCP0mDDH0=d]003]>@P0m
CT<0>4Xo02`l<P0V=R/0:3P^02/h;`0/>Bl0;S/b02/j=00`?cX0;3/f02/j=@0b@C`0=4<n02Xi=00R
<B`082lZ02@c;P0X=c80:STe02dl>`0V=3@09cDg01l/<P0T;SH0;CLo02Pa>@0R:c807RH[01dU9`0U
;Bl09Bh[01dW7`0O:2<07bTS01hY8`0P:bL08B`X020/:00E924201`[:00801TW9`0T;bd08bTW01hT
8P0H7Q`06R0N028X9P0Q9bD201HL6P0801dS8@0L8R006b4O01XP7@0D6A@05a`G01<H4`0G71L301TN
6@8082DP00P06QlJ01PM600N81d07b4N01dO700I6aP061XG01/M6P8061XG00@05QPE01DG500F61D0
61XG0P0G61<0100F5a805AHA01@E400D5A0201LH4`0V01HG4P0E5Q4051D@01<D4@0I6Ql02@/B024Q
:00D5AX07b0T018B500F5QH051<@01<B3P0E50l05aD?01LD3@0A40`04A0=01<B3P0?3PX04A0<01PG
4`0@3`d03Pd901DD400A40`05QDA014@300C4Q003`h<00h=2`0A40h04a8@010?3@0?3P`04A0>01LF
500=30X201@C4@803@/<00<040h?01<A4P0B41400P0@3Pl01@0B41403P`=014?400G5AH061HG0080
3P`=00<03`d>010>3`0@3Pl00P0A3a004P0>30d030X;014?40040P<03`d>01<?3P0B3Pd04`l?03/g
=`0H51<03@T8010<2`0?2`X040`;018>3@0@30/03PX901<:2`804`X<00/04`X=0148300A20/040L:
00d41@0E30d04@T701H>2`0A30X04@d<00l;2P02010<2`<03PX900H03@T800l;2P0@30/03PX900l;
2`0@30d200h:2`0G00d92P0<20T04@d>01/G600>2P/03@T:00`82@0F4Q<030T901@@4@0;1`P03@T:
00/7200I5AH040`=028N7`0M6AX03`/<00h:2`0:1PL03PX;010<3@0>2P/00P0<20T0:`0A3@h02PH7
01@@4@0=2@X02@D601@@4@0H51D02PP900l=3P0=2``03P`=00P61`0>30d030X;00X82@0?3Ph00`82
01LE5P0L6Q/02`D700`6200>20X03@L900`6200;1@L030H8010:300B30h030H800P2100:10H02`D7
014;3@0_:B/04@/=00d72@0;1@L03@L901<=3`0910D05a4C010:300B30h00P0>2P/200`82@0600h9
2`0?2@/040L:01072P0?1PT040D90P0?10PDooooo`006oooool0100B5QL04ADF010D5@0?4a@2010D
5@0[01HJ6`0:3Pl04aLH01<G600:3Pl041@E00l@4P0G61/0QhR:0=_Lh015ATT0414C00d>4P0B4aH0
4Q<E010A500B4aL05AHH01XL6`072@P03Q0?01<E500?4A004Q@C014C4P0G6AP051HE00`>3@0:30/0
30h=018D4@0A4a00418?00d?300G6AH02`d:00`>2`092`P030h;010B3`0>40d03@l<00d?2P02014C
3P803@l:00/03Q0;02@V8@0E5a801@L200lA2`0K7AP04Q@?00L80`082@@02``700d>2@0201<D3`80
4A8=00D0414<00d>2@0<3@P02P`800`>2`0200lA3P0400`>2`0;3@X03@l<010B3`@03a4>100@4Pd0
1@0>40/03@l:00`>2@0=3`X03a4<00@04Q@?00D0418=00d?2`0<3PT030h900lA3002010B3@04010C
3@0@4Pd041<<010C30804A8=01803a0;00h?2P0>3`X03Pl:01<D3`0E5Q4051D@00h>300=3PT0410>
01<E4P0>40l04aDD00X<2`0E5aH030h=00X<2`0D5QD2014C4P0800h@3`0D5QD00@<002T[:0041P<0
4aDB00h@3@0C5A8400h@3@0;010B3`0A4a005ALD01@F4`0C5A804A<@00h@3@0<3P/04Q@A00lA3P0<
3P/00`0=3``01@0?4@`030h900d?2P0=3`X030h900803a4<00X051HA00/=200G6A@03Q0;01LI500D
5Q403@l:00`>2@0=3`X03a4<0P0D5Q4200h@2`0F014C3P0=3`X05aTD00lA300@4Pd04Q@?00`>2@0A
4`h030h900/=200A4`h0418=00`>2@0A4`h05aTD01<F3`0G6Q<05APA014D3@0E61406ahG014D3@80
3a8;02X041<<00d@2@0;3PL030l800L:0`0E614051L@018E3P0A50d041<<01@G400A50d03a8;01@G
400F6A<02P`700lA300A4`h02P`700lA300A50d03a8;00hA2P0C5Pd05AP?018E300?4PX030h900/>
1`0B5@h05QT@018E300=40L051L>01XM500I71D04QD>014C3P0B51004Q@A018D3`0B5@d2018E2P0?
01@G2`0C5P/04A@9018E3@0B50l04Q@@01DG4P0A50d04aH?00/>1`0<3`P04QD>01LJ4`0E614051L@
00805QTB00X04QD>01@F4@0F61<03@l:00/=200F61<06A`E018E300C5Pd051L>0P0C5P/0<`0G6Pl0
5Q/D02`a:P0T:B802Pl8014F3`0E6Q<05a`E01/P6@0>4``07B8K01HK500D6A803A8<01PM5`0<4@/0
5a`F02db;00G71H05AXD01LL5P0B5a406AhH014F400S:2805A`E02Xa:P0A61405QdF01@K500>5@h0
4APA030g<00f?CH08BPQ01<K500N:2005b0K01TR7`0L9B807RLT02Xc<01OJ6D05QlL01PQ7P0W<2d0
82TV01XS800P:bL06BDQ01/W8`0201`X90806bLS00<05b<O01XV8P0M:BD00`0Q;BT0E`0P;BH08RhZ
02di=@0O;2X062HV03=1@@0U=3@09cLf02Pk=`0]?SX09STc02m2?00iBDH0:3Pe02/n>P0]?c/0:3/g
02i1?@0^@Cl0:Shl02a0?P0^@T40:d4o02Pn?00Z?D40;T5502m2AP0eB4`0>Da@03a?D`0hBdl0=TU=
03mBEP0jCE40=DQ<03I:C`0jCe@0?U=H049GG010EEX0?U=H03eBE`11EU/0@eQM049GG010EEX0@eQM
04]PI@1=HVL0B5eR045EF`16FV40DfM^05=WK@0kD5D0A5UL04MLG016G5T0Bf5N04=HE`18Fel0Ae]L
04UMG@1:GUd0BEeK04eQG`1KKfd0Cf=R04YNG`12EUL0C5mS04UMGP14F5T0CF5P04EJE@1EJV<0EV]R
03Y@A015Fdl0B5eD04MLE@1@IF00DVMU061iM@1AJVH0F75]05aeL@0205E^JP80FFm/03/0FG1[05Y`
K@1KLV`0GG=_05U`IP1JLFL0GWAZ065fK`1QN700HgUa05mdK`1NMFl0H7Ia069fM01UNWL0IWai06Ai
M01QMfl0HWU_05]`I`1OMVT0GGEW05idI`1PMf/0GWE[05ebJ@1OMFd0GgI^05edK01TNg80IGab065h
KP1IL6H0EVeS09J]X`1eS880GWE[04aSF@1?IU`0AUiA04ALC`1:HUD0Bf=F04MODP19H5H0CfIL07jE
R`1FKFD0@UUA045HD01>Iel0BV5K04MNF01@If40DFQP04UPF@11F500?eI>03aCB`0303aCB@0;03mG
BP11FD`0?eE803mEB010ETT0>4a00396>P0hBSh0:S/_02De:P0W=b`00P0[>2l06`0/?380<d<m02m0
>P0/?CL0<T<m03I5@00c@Sl0:CPe02<b;`0R<Bh0:3Ld02/j=`0[>CT0:SHg01/V:00T;c<09C0f02Ha
=`0]=Sl09c0g02@]=00Q:Bl072@W01dU:00O:2H07BPP01lX8`0201hY8`0801lZ9P0Q;2P062@P018N
6P0K9b@04QhL01XV900J8b4201/Q7`0G01LM6`0E6aT05adK01XP7P0G7A/061hL01`R800H7Q`05adK
01dR7P0C618061dI02@Y900P9Al06QlJ01DJ5P0J7aT09R/V02<X900J7aT06QlK01lQ7P0L7Q/00P0I
6aP01P0G6aX061/J024S8P0O8B006adK01HH5@805QHD0P0G61<01`0F5a8051D@01@E400C50l061TD
01LH4`0D5A000P0B4`h04P0C514030dA024T:@0C51T030dA00h?4`0F5QL05QHF01@C4@0C4Ph05A@@
01LE400G50l071/G00l>2P0;2PH030/701HE4@803`h:01l03Pd900l>2P0:2@D04Q4=00/:1P0<2`T0
5A@B01LF500D4a404A0>00h=2`0F5A<051<A010?3@0G5Q@0;Rd[00l>300:20T04a4B00d;300;2@X0
4@l@010>3`0C4A804@l@00d;300B41403`d>00P61`0?3@h03P`=00803@/<0P0;2@X0200?3@h020H7
014?40091`P05aDF010>3`091@@04`l>0P0?2`X05@0G4a803`/:00h:2@0=2@P03PX9010<2`0>2PT0
30P7014;2`0C2P/040X:00h72@0<0`H02@<501@=3P0A20T04P`<00/40`0D30T0510>01@@3`0200l;
2P0@010<2`0>2PT030P700h:2@0B3Pd061@C01DA400?2`X02PH6010<3@0C3a0020@500`82@091@H0
4`l@00L3108040`=02P05A4B00L3100=2@X04@d>00P41@0A3@h02@D6018>3`0=2@X061@E01LC500:
1PL030P900T51P0810D02@D600l;300A3@h06ADF03Da<P0:1PL01`<400h:2`0D41403PX;00/8200>
2P/01P@500T61`0;1`P040h?00T71`050@807A/L00h;300D41400@00024M7P090`D02P@60P0?2@/2
00`6200?01<=3`0=1`T02@<500l92`0B30h03`T;010:3004000050h@00L10`0A2`d0100001<=3`0;
1@L05@lA00803`T;00<030H800/51`0>20X00P0A2`d01P0>20X03@@701072P0@1`X03`H901052@80
3`@85?ooool001_ooooo00T05QLI01<D5P0:2`d05AHH00h?4@0E5QP04a@F01LH6P0A4Q@00P0=3Q00
3@0;30h04a@F014B4`0H6QT08B8T01`N7P0=3`h02``>01hO800_<C005AHG01<D5P0B51<00P0A4a82
010B4@803a4@00<04A<B01@F5@0C5A@00P0>40l0900@4Q405aTF00/=2P0A4a0030h;00h@3@0@4Pl0
3Q0=00/=2P0>40d03@l<00`>2`0?4@h0410>00d=2`0>3P`0410>00l@2`0>3`X0414;00l@2P0>3`T0
3Pl800l@2P0A4`d03a4<00/=200=3`X03a4<00h@2`0?4@`04Q@?014C3P0>40/02`d800d?2P803a0;
02P04A8=018C3P0A4Pd03a0;00d>2@0>3`X04Q<>01@E400B4`h03Pl:00lA30062@800`H000lB2`0<
3`P02`h700lB2`0<3`P03A09018E3P0;3PL02Pd600lA3@0210403a4?00h@3@0J71T02`d802<V7`0I
71D03Q49018E3P0E60l03a89018C3@020`009bPS024R7@092PD04Q8@0P0>3P`03P0@40h04A4A00l?
3@0;2`X04A<@00`>2`0A4a0071hK00X<2@0;3@X04A<@00lA3P0=3``03Q0=0P0@4Pl05@0=3`h03Q0?
00d?3P0=3`h04Q@C01<E500I6aX0418A01DG5P0C5A@030h=01TK6P0C5A803Q0=014C400B51403Q0=
01@F4`0>40d04A<@01<E4P02018D4@0701<E4P0B51403Q0=00lA3P0H6QL03a4>00d?3006010B3`80
30h;01<03Q0=00lA3P0>40d02`d:00lA3P0@4Pl03@l<00lA3P0A4a003Q0=01@F4@0B50l051HA00h@
2`0<3PT04A<>01<E400?4@`03Q0;0080418=01403a4<01DG4P0@4Pd02@/603@f<@000P0061XE010B
3@0B50l04A<>00h@2`0?4@`04A<>00d?2P0>40/03a4<014C3P0201<E400k01@F4@0?4@`04aD@014C
3P0@4Pd05ALD01dN800I6Q`03@l>01@F4`0F61D05APB00L:0`0B5@`04aH;00X=0P0G6`d03a49018D
4@0B50l03a8:01<F2`0B5@X041<800d@1@0>4@H051L?0001000W:BH02`d901DH4@0?4P/04aH=01LJ
4@0H6a802`h401<F3@0K7QD05QT@00L:0`0B5@h03Q4:018E3P0A50d041<<01DH4@0D5a004aH?02<V
7`0F6A8010L001<F3`0H6a@030h9010B3@0G6A@02P`701dO6P0?4P/00P0E60l0500D5`h04aH;01<F
2`0D5``03Q<<03Hk=00`=Bh03Q<<01dR6`0C614061dF01DJ4`0C61404QL@01<H4@0G71D05a`F01@I
4`0B5a4051TC0`0F6aD00`0D6A<04aPB01DJ500201HK5@0>01LL5P0I7QP06QlI01TN600G7AL05A`E
01lY8@22S8@0_lW102D_9`0E7aL05R0H01XS7P0G81/201@M600501LP6`0I8Qd06R<N01lX8`0E7QT0
0P0H8A`0?@0N:B<072PT01`[9P0B8A`072/V02He<00P;bX08c8]01/Z9@0C8Qd07B`W01h]:00O;RT0
8C0]028a;P0Z>CH0:3Lg020`<00W=cL0:CXj02Dg=`0S=cH0:Sdm02Di>00Z?Sl0BE]O03a>D00dB4T0
<DA502a0@@0Z?Sl09c/l0396A`0_@d80;T9202a0@@0U>CX09S/o03=8C@0^@dP0<DI;041EFP0hCE80
=T]@041EFP0nDeP0=DY?03aAEP11EU/0@UML03eBE`15FUl0Efaa055VJ`0nDeP0?55F03mDF@16Ff00
AeaQ04EJG`14FE`00`16Fe`02@17G5d0B5eN04AIFP11EUL0@eQI049HEP10EU@0@EME04AJF00204MM
F`0804AJF012F5D0A5YG04QNF`16G5T0BEmL04]QG`16G5X204MMF`1[04YPGP1;HEh0AUaI06ImM`1Q
N780@5MA04AKE@1:HE/0D6MQ05I/J@1DJVL0CfQU04iWI01GKFX0FW1]05M]JP1PMg40HgQc0725P01N
Lfd0FVmZ05U^I`1XOGL0GW=/05ebJ`1SMg00FVeY05ebK@1QMG00DfIT07b@SP1LKfd0Jgem06EhM`1Y
OG`0Igih069jM01NN6l0H7M_05igKP1KMF`0HGQ`061hL01LMVd0G7=[05eeK`1QN780Jh9l07:7P@1T
NG80G75Z05]`J@1DJF80G75X05Y`I@1KLFD0EfeQ04YPE016G500BV1D04eRF@16Fe80B5eD05AZHP1F
KFD0b>;I08fVX01:Hed0A5eG04QRG01BJfD0AeiF05I]I@1AJ5h0>e9904AKD@15G580?EA:03iEB`0m
E4X0@EQ>03aCB@13Fdh0?5A604ALCP0cBcd0=T`o03A:?@0`A3P0<D@h02Pi;`0T=B/09cH_02/j=@0/
>cH0:chh02Lj=00V>C<0;3lk03A4@@0dA4<09CDd02/i>P0R<340<3i1020^<@0^>Cd00P0S;Bh06@0Z
=3H082X/02`f>012BTd07RHY01XR9@0S:bh02Q8D01DM7`0P:RP0<Chg01TT7P0Q;2H06RDO02lj=00L
9b408B`V01/V800R;2L07bPU01HO700K8al06b0L01TN6P0H7AT00P0F6aL07P0G71P061dI01XO6`0K
81`061dI01HK5`0=4`l0A4Y601TO7@0[<Bh0JFm[01LM6P0P9R@05adI01/Q7P0E6aT05adI014G500L
7Q/06Q`I018G500O8b804ALG01<H6@0e>CX0_/;302h_<00Y:BT051<A01PG50H05ADC00`0410>00l?
3@0E5A<04A4?00h>300R8b40IFMV02/_;P0@4Q403a4@01@F5@0@40l201<C4@0601<B400B4@l04a4=
01@@3@0B4@l04A0>0P0@3`d0100A40h04Q4?01@C4@0D4a44014@3P0@018@4@0F51D01P@501XH6@0D
4Q<04a4B01HD5@0=2``03P`=01HD5@0G5AH03P`=00/:200?3P`04a8@00T81P803@`:00H02`X800d<
2P0@3`d040l=00h=2`0=30X6014=30803@T800P03PX9010<2`0A3@`04@d<00`81`0=2@P03PX900l;
2P8040`;1P0?2`X0300?2`P04@`900l;200=20P03PP800h:2@0;1PD040/800l;200=2@H03PT6010<
2P8030P700/04@d<010<2`0?2`X03`/:014=300810<08alN03Hb<@0I5A@02PH500`81`0200/71P0?
010<2`0>2PT03`/:00L30P0F4Q403`/:01@@3`0300003`/;014=3P050@803`/<01XF5`0?2``040`=
00807QXK0P0=2@X200l;300S00L3100A3@h02PH7014=3P0B3Pl02`L800h:2`0B3Pl02PH7010<3@0<
20T02`L800`82@0<1`T02P@600T51P0<1`P03PP:00d92P0>2@X03PP:00d92P0>20X02@<500h82P0:
10H04P`>014;3@0=1`T03`T;00h82P0<1PP03`T;01LA4`0U7b401P0=1`/01`090`L03PP<014;3`0@
2Ph03PP<00d72`0<0`H00P0?1PT0100=10L03PD801462P0>0`L201<8300301052@0B1`/050T=01Co
oooo000Kooooo`803PlA00H03@h@014B500D5AL02P/=00h?4@0A4Q@200h?4@0=014B500=3Q004Q@C
00h@3`0@4Q4051HE01DG5P0A4a803@l>00lA400F61L03Q0?01<E5002014C4P80418A0P0?4A002@0>
40l03a4@014C4P0@4Q403Q0?010B4@0A4a80@dE201@F4`02010B3`0?014C400;3@/03Q0=00`>2`0?
4@h03Q0=00`>2`0?4@h03Ph<00l?3@0A4@l04a<A00l@2`0;30L03a0:00803Pl900<04149014B2P0@
4P/00`0?4@`200h@2`09010B3@0B50l04A<>00h@2`0=3`X03a4<010B3@0?40/0414<00<04A8=02@0
4Q<>014B3@0?40/03Pl:00l@2`0A4Pd05ALA00lB2`0>4@X06A`E01<F3`0>4@X041<<00lB2`0>4@X0
30l800hA2P0K7QL0EUQD01lQ800A4a8020X700/=2P0?4@`05APA014D3@0=40L041<:018E300@4`P0
2@X701HG4@0?40/04Q<>020Q700;2`T2010@3P804Q8B01`04A4A010@400=3``05ALD018D4@072@H0
2P`9014C400>40d0418?01@F4`0B51404A<@010B3`0<3Pd03Q0?018D4`0C5A@04A<B00h@3`0@4Q40
3@l>00`>3@0E5aH04Q@C00D71P0C5A803a4>0P0A4a001@0?4@h04aDB00d?300@4Pl04Q@A0080418?
00D04A<@05UKF019BdP05QPE00d?300200h@3@H0418?00T03a4>00h@3@0@4Pl04A<@010B3`0=3``0
3Q0=018D4@0A4a000P0C5A804P0?4@h07R0K01HH4`0C5A003Q0;00lA300F61<03a4<014C3P0D5Q40
5QPC014C3P0>40/03a4=01DG4P0J71L0?d4l00lA30805ALB00`03Q0;00d?2P0A4`h04Q@?014C3P0K
7AP05ALB010B3@0=3`X03Q0;00lA300Z;2L2010B3@0h01@F4@0A4`h04Q@C01XK7P0F5aX03@l?01<E
4P0D5Q<041<=00X=1P0H6a804QD:00T=0@0D5`/03a4:01DG500E5a804A@<01<F2`0A5@L03Q8401TM
3`0E60d04A@<01`N6@1>D4d07R0K014D2`0@4`X04A@;010C2P0B5@`08bHM028U700A50`04A@;01DH
3`0C5Pd04QD>01DH4@0C5Pl04QD>01DH4@0C5Pl04A@=01<F3`0D5a006ahG018E3P0_<R/08B<N01DG
4P0@4Pd03a4=01XL5`0E614201HI400G01DH3`0E60d05AP=01HI3P0J7aP051TB01hS700Q9Ql04aPA
01LL5@0E6Q<04aPA01DJ4`0F6a@04aPA01@I4P0G71H061dG01HK5@0D6A<05AXD01PM5`0F6aD00P0C
61801@0E6Q@05Q/E01DJ500D6A<05Q/E008061dG00`061hG01HM5P0H8QX0=3hf04==A@0I91`06bHN
01`W7`0J8ah06B8M01PQ700I8Qd201XS7P0>01LP6`0M9R406B8M01lX8`0J8ah072LQ01hZ9P0R<B`0
6RTT01`[9P0P;bX06bXU01PW8P0S<Rd201h]:00V02@c;P0M;2L07R`/02hn?@0T=3<08S8a024c<`0b
A4@0:3Xl02Tm?P0U>CX09cXn02Hk?P0bAdX0;3m50313B@0cAT`0=DQ>02i1AP0Z?D80:ci302<f>`0_
@TD0;D5402Xm@P0dAd/0<TM:02e2AP0hCE40Bf1T0356BP0iCU80>e1D03iCE`0iCU80>e1D03iCE`0k
D5@203Y?E00A041EFP14FEh0@EIK03mDF@0nDeP0?eAI04EJG`17G640AU]P04EJG015FeT0A5YH049H
EP10EU@0?eEC03iDDP0mDe400P0oEE<00`10EU@0@UQF04EKF@0204ILF@0704QNF`1:H5d0B5iK04QN
F`16G5T0B5iK04UOG00304EKF00>04UOG01:H5d0FW1]06EkN01;HEh0@UQE04EKF019Ge`0CVAQ05E[
J01IKf`0EVm/05A]JP1JL6d205]aKP0406EjM@1QMW40IGYe05Q[I@<0Gg9/00h0HWI^05]^I`1PLfd0
FVeX05U/I`1NLFh0J7]h08RKV01WNWT0K7im069eM01SMgH0Igii06=kM@80HGUc05/0H7Qb05ifL01R
NW@0HWYd05ifL01LM6h0GWI`06=jM01QMW40HgQc065fL01NLf`0Fg1Y05aaJ@1KL6L0E6UO059XG01@
IUX0AeeA04AJCP1:GeH0EfaS05=XG`1=HUX0CfEM055XH01@JF80F75Z04QQF`19I5l0Af9M04QSG016
GE@0AUeC04=JD018GeD0AEaB03YAA`0nED/0>E1603YAA`11F4h0>e9804=KCP1:HeH0BF=D03E?@00c
BSd0;dDh02e3=P0V>Rl093D/02Df;P0[>SD0;chk02hn>`0/@3/0;T8m0314?`0cAT<0;d0o02`m?00S
<c<09cDg028`<P0a?d809S@h038m@P0]=SL082TY020X:@0[=3@0<3Ti020X:@0M9BH06b@T01@K700L
92D07bPX01LR7`0W=2d04QlH01`X8P0N:B<0=3li020Z900T;BP07bPS01`T7`0M8al05adI00806AhJ
00<061dI01LL600G71P00P0G71P0;00F6aL061dI01XO6`0I7QX061dI01HL6@0K8Al05Q`J01dS8@0B
61H06b4O01LM6`0E6aT0728P00hD4P0H7Q`0=C/h01`N6`0H6QD06b0M02L];@0H7Qh05AXM01PM8010
ADP07AhP014?400H5aD05aDA01/J600J6QP061PF01LG5@0H61H06QXH01@D4P0E5A<04Q8@01LG5@0Q
8Al071dK02d_;00@5A405QPE0P0@4Pl00`0A4@l05QHD01@D4P02018A3`0301DB4@0G4a804A0>00@0
4a8@00<04A0>01@C4@0C4Q000`0A40h0200B4@l03P`=010>3`0M6a`05Q@E01<A4P0?3@h04a4B0P0?
3@h02`0B41404a4B00d;300E51804a8@04M6A00m?3X03@`:010?3@0>3@/03`h<00@040l=1P0@30/0
1`0B3Pd03`/:00h:2@0A3@`05Q8A01TE500@30/00P0?2`X200h:2@0300d9200?2`X03`/:00@03`/:
00<03`/8010<2@0?2`P00P0=2@H0400>2PL03`/8014=2P0@30T03PX700l;200@30X03PX9010<2`0C
3`h03@T800`81`0?2`X02`L600`81`0A3@`200l;2P0500h:2@0D40l061@C010<2`0=2@P0100@30/0
300=2@P04@d<01<?3P0C3`l08AdN018>3`0?2``0510A00T51P0>2P/05A4B01PD5@803`/<00H03PX;
00`82@0>2P/03@T:00l;300E4A8200`82@0801PD5@0U8B803@T:00D10P0=2@X030H800d72@0>20X2
00`62003010:300>20X03PP:00@03PP:00D04P`>01D?4@0>20X04P`>010:300200d72@803PP:00<0
30H800d72@0@2P`01P0=1`/00`0>20`030H:00/52@0200d72`0400`62P0>0`L04@H:01052@803`@8
00L040D901<9300<0PD04@H:00l4200B1`/040L901Cooooo000Kooooo`0600d>400C51H05QLI00h?
4@0L7Al03a0B0P0C51H0100>3a40414C014B500;30h200h@3`0600`>3@0;3@`03Q0?018D4`0E5aH0
4A<B0`0=3`h00`082PT03a4@00h@3`0200h@3`803@l>0P0>40l0400=3`h03Q0?010B4@0B51<030h;
00lA3P0F61D0418?01DG500F61D03Q0=00`>2`0@4Pl03Q0=00`>2`0?4@h200h>3004010@3P0B4Q00
3a0;00`=20803@h801`03Pl9010A2@0B4`/03a0:00lA300B50l0418=00/=200<3PT06adH024S7P0H
6QD03@l:00h@2`0F61<05aPC00l@2`0>3`X03a0;010A300B4`h04a@?014B3@0>3`X030d800h?2P0A
4Pd04aD?0P0>4@X04@0E61404A@=00d@2@0=40T03a8;018E3P0A50d03Q4:01<F3`0Q8al01`T8010B
4@082PL03a4>00/=2@0;3PL030l800<03Q4800T03a8801TJ500C50h01PL203@e<0000@007QhL00d=
2`0>3P`00`0>3Ph03P0A4A4020X700d?300C5A807AlL01@F4`0@4Q002`d:014C400F61D04A<@00h@
3@0A4a004aDD0P0@4Q402`0A4a803a4@018D4`0G6AP04A<B00P:2@0G6AP04aDD00T;2P0C5A804A<@
00<0418?00@04A<@00`>2`0?4@h0418?0P0>40d01`0?4@h02P`900h@3@000@004A<@01<E4P0J71T0
1P0?4@h00`0A4a00418?00lA3P02010B3`0300d?300@4Pl04aDB00804A<@00<0418?00`>2`0>40/0
0P0;3@P04P0?4@`06Q`G024S7P0I6aH0418=00`>2@0=3`X03a4<010B3@0>3``05QPC01hP6`0A4`h0
0P@00001000A4`h03Q0;00d?2P803a4<00<03Q0;01<E400?4@`00P0=3`X0100?4@`0418=01DG4P0D
5Q42014C3P0>01lQ700P8R0051HE018D4`0=3``0418?018D3`0?4@/03Q4:01LJ4`0@4`X04A@901LJ
4@0?4P/201<E400H018E3@0B5@`04A@9014E1`0=40D020/201<F3P0620<071hK01@F400;3PD041<:
018E300D5`h041<:01<F3@0A50/05AP?018E300G6Q40?D0g01HI4P0G6Q<05APA0P0C5Pl02P0B5@h0
20/401lR6`0?4P/02Pd601PK5013ASl05QPC00T;1P0@4Pd200h@2`0N01<F3`0F6A005QT@01DH3`0E
60d05QT>01PK400F6a@04aPA01DJ4`0H7AH05Q/D01<H4@0B5a004AH?01/P6@0O91d05Q/D018G400G
71H0724K01XO6@0D6A<04aPB01PM5`0G71H05AXD01@I4`0F6aD061dG0P0G71H201PM5`0_01LL5P0G
7AH05A`E018L500F81P04adE01LR6P0E81P05R4I01PQ700I8Qd06R<N01/T7`0J8ah06B8M01XS7P0O
:2<072DP01lX8`0K91l09C0Z01/W8`0P;bX06bXU01`[9P0P;bX07bhY02Xi=00Y>3<08C0[01d/9`0`
?cX0:CPc02dk>`0Z>ST062PW02Ph=`0R=3@0:C/k02Hh>P0Y?Ch0:3`m02`o@`0Y?T40<DI90395B`0^
@DL00`0/?dD0700]@4H0<4=:03A7CP0X>d80=TU@03Y=E00V>Cl0=4U<0356B@0cB4/0>e1C024f>@0k
D5<0AeaO04=HF`0eBTd0=da?03E:C@0hCE40>4eB03]@E@15FUl0?eAI03iCF013F5d0@5EJ03mDF@13
F5d204IKH00404IKG@15FeT0@eUG041FE080?UAB00`0?E=A03iDDP0oEE<0?UAB041FE013FEL0AeeJ
04EKF014FUL0BV1M04eSH018GU/204=IEP0904EKF017GEX0AUaI04MMFP0mDe00C69O04UOG01?IF80
AUaI0080AeeJ00D0C69O04mUHP1AIf@0EfeZ05Y`K@0205A]JP0<05Q^J`1KLFh0Fg5^061eL01SN7<0
G75/05IYH`1PLfd0HGA^05a_J@1TN6l0GW9Y0P1JKVD02`1WNW@0HGA^059UH@1ZOGT0H7=`06YmN`1Y
O7X0KH5o06UnN@1UO7H0HgYd0080I7]e01@0HWUc06=jM01RNG<0GWE_05acK@1OMW00HgYd06MlM`1Q
MW00IW]d06AiLP1JKfL0GW=Z07Z?QP1QMf`0CVAH04UOD`16G500BEmC055VG@80FVmV04D0E6UP04mU
G@1>IEd0CfUP04QQFP1EKVP0Af9M04IQG00oFU<0BV5H05YaI`1EK680HWU_03YAA`0oET`0>4m5059Y
G`24Vi40MXf303A;@@0hD4<0>51203M?@@0]ACL0;dDi02]1=@0]@cL07S8X020a:@0T=Bd0;chi03M6
@`0hB4D0<4A00395@`0eB4H0;d9002@d<`0P<2l08S8b02@b<`0U<c<0<Cm002Le=P0]>3X08R`/02Xc
<P0U;Rd08BXY02@];00D7A`04a`K01XS8P0[=3<06b@S00`E500H8al08BhW01DR6`0M:B808B`V034l
=P0M9b408b`W024Z9@0E7AP07B<O01XP700G7AT00`0F6aL0<`0G71P061dI01PM6@0H7AT06AhJ01XO
6`0I7QX061dI01dR7`0K8Al01P`:01PN700G7A/07bDS01@J600;4@l06R0N01dS8@0L8R005A/H01hP
7@0H6QD04AHB01LM7@0S:BT06QlR01DJ7@062`h06a`M014?400P7ad06AHC01XI5`0G5aD04a<A018B
400D518061PF01DE4`0N7Q`092@R01@D4P092@L03a0>00h@3@0730P06A/H01LI5P0D5Q<05ADC010@
3P03018A3`04018?3P0A3@`04A0>01<B40805QDC00@04a8@014@3P0B4@l04Q4?0P0@3`d0500A40h0
4Q4?00h<3@0F51D0B4I702HT9@0L6Q/03P`=010>3`0A3a0040h?00l=3P0>30d03`d>00l>300B4@l0
8B0N01PG5@0>3@/020L50`0>3@/200l>3003010?3@0?2`X03`/:00@03`/:00L0510?014=300@30/0
4Ph=01DA400F4Q4040`;00<03`/:0P0>2PT600l;2P0300h:1`0@30T03`/800803@T602L03`/8014=
2P0@30T03`/800h:1`0?2`P03@T700/71P0?2`X040`;00`81`0A3@`08QhM00T5100400003PX900d9
200D40l03PX901HB4@0K5aH04@d<00/71P0?2`X05A4@02TU900E4A0040`;00/71P0J5QD01@4100d9
2P0@30d04`l@00l;30060P<02PH700l;300B3Pl00`0>2P/03P0?2``02PH700d92P0H51D030P904Y6
A`0N6Q/01P8300<0000>2P/06ADF014=3P0<1PP03@L90P0>20X00`0?2@/04`d?00h82P0500h82P0<
01H@4P0H4Q@03@L9010:300?2@/03@L900/51`0=1`T03`T;00h82P0<1PP03@L91P0=1`/02@0>20`0
2@<700`62P0D3Q806A<G01D?4`0?10P04PL;01462P0200l4200701052@0I3Q804`P<01dB5P0C20`0
30<501`A5@0Dooooo`006oooool01@082@/03a0B018C5@051PP051DG00804A8D00P04Q<E00h?4@0>
3a40414C00/<3P0;3@`03Q0?00lA40803@l>00P0418A00430P0F61L05QPG00lA400A4a8051HE00lA
40<03Q0?0P0=3`h0100:30/02@/:00X<2`0<3Pd200d?3P0@00lA3P0@4Pl03@l<0001000>40d05aTF
00h@3@0=3``04A<@00lA3P0<3P/03a4>014A3`0=3@/030`:00l?3@80414<0P0=3PP04@0>3`T04149
018C2`0?40X03a4<018D3`0@4Pd02`d800`>2@0A4`h04Q@?00h@2`0;3@P0418=01PJ5@0G6A@0414<
00803a0;00<0414<018C3P0A4Pd00P0?40/0100>3`X03a0;00l@2`0?4@/200/>1`<03Q4:03H041<<
014D3@0A50d04A@=010C300<3`P01@L301DG50092`P01`T600`>2`0@4Pd030l800hA2P0A50d03Q48
00d@1`0>4@P020T300<4000L7AP0LG9]01TJ5@0;2`X03@d;00h>300@41003@d=00h>3P0B4Q804Q@A
00lA3P092`T030h;0001000U9b@030h;010B3`0B514030h;00/=2P0A4a003@l>00/=300@4Q404Q@C
00/=300<3Pd03@l>00lA40092`X06A/J00d?3P0C5A@200lA3P8030h;00<03@l<00`>2`0<3P/00P0?
4@h01P0>40d03@l<00h@3@0I6aP03Q0=01@F4`803Q0=00<05QPE00lA3P0?4@h0100?4@h00`0A4a00
3a4>00h@3@0200lA3P0700`>2`0B51404Q@A00h@3@0B51405QPE01@F4`02018D3`03010B3@0A4`h0
5QPC008061XE00<03Q0;00X<1`0;3@P00P0>40/01`0F61<02`d800L9100D5Q405aTD01DG4P0?4@`0
0P0F61<01P0?4@`03Q0;010B3@0;3@P03@l:00lA30<04A<>02d03Q0;01DG4P0C5A003@l:01DG4P0H
6QH04A<@010B3`0=3`X0418=014C3P0?4@`03@l:00lA300@4``05AP?01LJ4`0?4P`03Q0;00lA300B
5@d04A@;014D2@0B5@X03a8700/>1@0H6a<03A09018D3`0C5Q002@`3014D2`0?4PT06A`C00hA200M
81L06A`C014D2`0@4`X03a8901@G3P0G6Q<05QTB01DH4@0D5a000P0B5@h03@0@4``04QD>018E3P0L
7aP04QD>0413?00A4`h03a4<02PZ9@0I6aH04Q@?01HI4P0F6A000P0E60l0700F6@h05aX?01PK400A
5Pl06AhG01LL5@0A5Pl05AXC01@I4P0K81T04QL@01<H4@0F6a@041D>01LL5@0F6aD0724K01XO6@0E
6Q@04aPB01PM5`0I7QP05a`F01HK5@0H7AL06QlI01TN600G71H201PM5`0<01TN600J81X06R4J01HP
600K9Ad08bdU01PS6`0D7aL03QTA01HO6P0H8A`06B8M0P0J8ah0@00I8Qd07BHQ01/T7`0O:2<0:C8]
01`U800G8Q`07b/W01d/9`0H9b806RTT020_:P0Q<2/09SD`01TX8`0O;RT0;Sdh02`k=P0M;2L07R`/
02/k>P0R<S409CDd01la<@0/?Sh09SPj02Hj>`0Y?Ch0<dI:02Tn@@0Z?d80;d9602Xm@@0X>cl0:ci4
03=6C@0gBU40<TE=02/mA`0_@D/0<dEA0312CP0^@4X0?eAF0:Fj^`1WO7d0<dQ902Tn?`0nDe@0D6EV
04AIFP0fBd`0?E9C049GF016Fel0>4eB03Y?E017G640@eQM041EFP13F5d0@EIK041EFP13F5d204IK
H00]04=HFP10EU@0?eEC03mED`0nE580?eEC041FE012F5H0@eUG049HEP11EeD0@eUG04QNF`17GEX0
AE]H04UOG01:H5d0A5YG03mEDP12F5D0AE]H04QNF`1:H5d0Bf5N04EKF@1@IV@0CF=Q059XIP17GE/0
DFMU04aRH01DJVP0FFm]05Q^K01JL6h0F6i/05I_K01HLFh0GWAa065gM01RN7D0H7E`06IkMP1KL6/0
G6mY0080GW5[00`0HGA^05eaJ01OLfP0Ef]P05mcJ020U8/0M8Qo05IYH`1VNG<0J7]f06f0O01ZOGT2
06UnN@0H06ElMP1TNgD0IWeg06MnN01UO7H0HgYd065hLP1MM6h0Fg9/05ieK`1SNW@0Jh1i06AiLP1X
OGH0IW]d05Y_I`1KL6L0IG]_05=YG@18GU80AUa?04MMD01<HUD0D6IJ0P1>I5P0<01>HeX0BV1G04IM
D`1=Ieh0B65J07^DSP1FLFX0BVEN04AOF01gSXD0BF1F04IMD`1RNFl0>E16041GC@13FU00=di404UP
EP1:HEL0=Te304EMD00jD4<0>Dm30398?00_A3X08cL^02Di<00W>3408S<]02<d;P0]?3T0=TE203Q8
A@0bAD<0<49203=5A@0^@4009CDd02@d<`0X=SH08S0`02<b;`0Z=SH07b/[01hZ:P0T;Rd09Bh]02Tb
<@805b0O01<04a`K010I600I8R40>D9102D^;@0M9RD0;3Lc02<`:@0K:2406RHO01<N600G8Q`051hH
02L`:`0S;2L05QdI01`R7P0I7a/05a`H00805Q/G00D05a`H01PM6@0I7QX06b0L01`Q7@0201/P700P
01TN6P0G71P05Q`I010F500Y;bd07B<Q020V900A5aD0;38`01dS8@0I7ad03A<A018H5P0Y;b`07R0M
01@F4@0C61@02@l?010F5P0@5AP04QLJ01XO8P0D5QH05Q@E01XI5`0C40d061LE01DE4`0B4Q004A4?
01<C4@0F5Q@2018B400<00d=2`0P81h0<C4_01TJ5`0G6AH051TE010B3`0E5a@03@l<01TI5`0>3P`0
4a<A0P0G5Q@0100C4@l03`/:014@3P0C4Q0201HE4`0401<B400A40h04A0>014@3P8040l=00/04A0>
018A3`0<2P/040h?03lm?P0M6a`05aDF00`:2`0A3a004a4B018@4@0200l=3P08010>3`0>3@/04Q4?
00X91`030P004a8@00X91`0<2`T200d<2P<03Pd;1P0?2`X301<?3P04018>3@0?2`X03`/:00h:2@80
3`/:0`0@30/600l;2P0700h:1`0?2`P03`/800d91P0>2PL03`/8010<2@0200h:1`803`/801l03PX8
00`81`0=2@P03@T800X61@0B3Pd0:BDT014=30091@@04@d<00`81`0>2PT02@D501<?3P0D40l03`/:
00h:2@0=2@P02PH501`H5`0<20L03@T800h:2@0O6aX06aLG014=3P050@804`l@02@P8@0N6Q/03PX;
00804@d>00`03@T:00h:2`0?2``03`/<00L310091@H0510A00P41@15@D804Ph?00/7200E4A82014=
3P0700T51P0<1PP03PP:00l92`0>20X03`T;01<=3`0600h82P04014;3@0D3Q002P@600l92`803PP:
00<02@<500X41P0:10H00P090`D00`0=1`T03@L;00d72`0400d72`0900`62P0;1@T04@/?01PB5P0J
51P050hB01052@0B1`/04@H:00803`@800L040D901@93@0900801`0001H;3`0A1PX04PL;01Cooooo
000Kooooo`0I00l@4P0>3a404Q<E014B500>3a404Q<E00/<3P0C51H03a0B00`=3`0?4180414C00d?
3`0?4A40418B010A4P0?41403Pl@018C500P8R806AXK01hO7`0D5AH03a0A014C4P02010B4@803a4@
01L03Q0?014C4P0@4Q404Q@C01@F5@0A4a803Q0?00h@3@0=3``0418?00lA3P0D5Q<030h;00d?300>
40d04aDB014C400<3P/03Q0=018B400=3@/030`:00l?3@02014B3@0600l@2P0>3`T03Pl9010A2@0A
4PX0418;0`0?4@`200h@2`0700`>2@0>40/04Q@?018D3`0>40/030h900l@2`02014B3@80414<00P0
3a0;00h?2P0>3`X03a0;010A300?40/03Pl:00d?2@803A090P0>4@X01@0@4``04aH?01<F3`0>4@X0
30l800804aH?00T03a4;01/M6@082PH06Q`H00`>2P0?4@`03a8<010B300@4``00P0>4@T05P0=40P0
3@h801DF400?40/05QLC01DF4@0B4Q003`l=01<C4@0E5AD04A4A00l?3`0C4a<04Q@A01HH5@0@4Pl0
4A<@01XL6@1jO7T03a4>010B3`0A4a0200h@3@0O014C400=3`h02`d<01TK6P0O8B004A<B00lA400[
;B`0>cdl00lA400H6QT02P`;00lA400C5A805QPE010B3`0?4@h04aDB00lA3P0>40d04A<@010B3`0>
40d03@l<00h@3@0<3P/03Q0=03Pj=`0>40d0418?00`>2`0600h@3@0301<E4P0@4Pl03Q0=00803a4>
01L03@l<010B3`0A4a003Q0=01DG500L7Q/06adJ00d?2P0A4`h03a4<010B3@0C5A004Q@?00d?2P0>
40/04A<>01<E400?4@`02`d800lA300F61<04A<>00lA3@0200h@2`0;010B3@0L7QT071hI01<E400@
4Pd04aD@00lA300A4`h04Q@?01<E400@4Pd00P0?4@`01@0:30L04aD@01@F4@0?4@`03Q0;00803a4;
01`0418<010C3@0A4`d041<=00d?2P0A4`l06A/G014C3@0?4@d04aD@00d?2@0>4@X04aH>014D2`0A
50X04QD;01XM4`0?4PT02Pd501XM5P0A50h04aH>018E300U:1l03A0701/N5@0930<04QD<0P0>4@P2
01DH3`0301@G3P0G6Q<04aH?008051L@00D04A@=018E3P0<3`P071lH01@G400201HI4P07014D3@0E
5a8061XE02la;00L7QT05QPC01<F3`0301@G3P0501DH3@0F6@h061/@01@I4P0A5Pl00P0H7AH02@0?
50d05Q/D01<H4@0A5Pl08bPQ02/`:@0K81T04QL@01DJ500201PM5`0401LL5P0E6Q@05AXD01TN6080
5Q/E00<061dG01TN600H7AL00P0G71H02P0H7AL06AhH01dS700N9Ah072HN01<M5@0L9Qh062<K01TT
700C7QH301PQ700O01TR7@0K91l072DP01DN6@0S;2L07BHQ01DN6@0P:B@0E5mI02Pd<00N;BP06RTT
01l^:@0Q<2/07bhY024`:`0S<Rd082lZ01d/9`0`?cX0JGQc07J4Q00Y>CP09CDd02Hf=@0U=cL09SPh
02Pj?00U>CX09c/l03=6BP0202Pm@00E02`o@P0]@D<0;D1302/nA00]@4L0;d9903M9E00eAe@0=dUG
03Y;FP0iBU/0>D]G03eCE02K/;00D6EU03A:B@10EUD0>Dm>049HE`0cB4P0>U1?0080AU]K00d0Bf1R
03aAEP0oE5T0@UML041EFP0mDUL0?eAI045FF`12Ee`0AU]P04MLH@15FUl0@5EG00<0>e5?00H0?59@
03eCD@10EU@0A5YH04MMF`18GU`204EKF@0:04QNG01:H5d0B5iK04QNF`17GEX0A5YG049HE@17GEX0
BEmL04YPG@80CfER00D0CVAR04QNG01=Hf40F6i/05I/JP02055WI@0N05Y`KP1PMW@0G79`05]aK`1J
L6h0FW=`05aeLP1MLg00GgEb06=iMP1QMW40IGYe05I[IP1QM6h0Gg9/05e`JP1RMVh0Gg=W05ibI`1D
J5d0DVIK06YnL`1TN6h0GW9X065eJ`1]PGT0Jgmg06aoNP1[OWT0JWmj0P1WOGP02`1YOgT0JX1k06Z0
NP1WOGL0I7Ye05meK`1MLfd0HGMb06MmN01UNW<0HgQ`0080HWM_01T0G75X05AZG`1<HUH0C69F04mU
F01;HE@0@eU<04EKCP1CJEd0Bf5E04eSE`1>I5T0B5mD04IMD`17HEL0BVAK06b6OP15H5T0A5mH051[
HP1JLFP0>E1603mFC010Edd0?EA:0080@eY@03@0AEaB03aCB@14Fe40?5=903E<@P0fBcl0<TLl0315
>`0]@3P072hY024b;P0]?ST09CDc02<c<00W=c@0;Cdj02hn?@0cADH0;Sm003A5AP0a@T80;C`l0350
@00/>cT06bTV01dZ9`0S<2/09c@^02Hb;@0]=S@05QlM01lX9P0I8R0051dK01<L6P0J8b407bPV020Y
9`0M9R@0:C8`02Lb;@0J9b007BXS01/W8@0I91h062<M01hX8`0Y<Rd08BXU01XR7@0J81`051XF0`0H
7AT201TN6P0h01XO6`0L8Ad0724M01/P700I7QX05a`H01HK5`0I7a`09B/Y01XP7P0O9B<0E5YH03a2
@00k@Cl07B<Q01DK6@0K8Al07B<Q01HL6@0?4@`07b8L01@I5@0L8R00JFm^03Tn@00=4Q@08BLW01<E
5@0E51806QTE01HC400I61D05QLC01DF4P0D5A405AHB01LH500@40d06a`H00l?300M7AX0?Slk02@U
8P0@4Pl061dI03Tk>02j_;T0TYBA01hN700A4@l05ADC01TH5P0H5aD05Q<B018>3@0A40h401<B400=
014@3P0@3`d040l=00l>300@3`d04A0>018A3`0C4A803`d>01LE5P0@3Pl04@l@01<A4P05010>3`09
014?400?3P`030/901HE4`0@3`d03Pd;00T81P0;2PP03`h<00804Q4?00<03`h<00d<2P0@30/01@0@
30/01P0A3@`04Ph=018>3@0B3Pd03`/:00d920803`/:00@040`;014=300A3@`04@d<1P0?2`X01P0=
2@H03`/800l;200=2@H03`/8010<2@803@T600/040`901<?300@30T04@d;010<2`0>2PT03@T800/7
1P0>2PT04@h=00d9200200h:2@0900T5100;1`H040`;00l;2P0>2PT03@T8014=300>2PT02`L60080
4@d<00/03`/:01@@3`0E4A00514@01@@4@0b;Rl0;b//010<3@0?2``03PX;014=3P0300l;300300h:
2`0?2``040`=00803PX;00<0510A00/7200@30d00P0=2@X0100400404`l@010=3@0>20X200l92`80
3PP:00<04@/=00h82P0>20X0100>20X01P0=1`T040X<00T31@0@2P`03PP:00`6208040X<00@03PP:
00/51`0<1PP040X<1P0=1`/04P0<1PX03@L;010:3P0A2`l03`T=00/52@0B1`/050T=01872`0@1@T0
3`@801052@0K4Q@0K65U01/B500;0@@03@<601H;3aCooooo000Kooooo`0901PI6`0;30h04Q<E02@U
9`0=3Q0030d?01<D5P0N7b4061TK00803PlA00d04a@F014B500>3a4030d?00h?4@0?41803@h@018C
5@0@4A<00@8401XK7@0B4aD01`P:00804A<B0P0@4Q4200lA400S00d?3P0>40l04A<B018D4`0;3@`0
1PP700/=2P0D5Q<05QPE00lA3P0@4Pl020X700h@3@0?4@h04aDB014C400=3``03Q0=010@3P0>3P`0
3`l=014A3`0?40/03@h9010A2`0?40X03Pl900h?1`0?40P04A<<00lA300;3@P03@l:00lA300>40/0
0P0=3`X01@0<3PT02P`700/=200>40/04A<>00<04Q<>00<03a0;00d>2@0=3PT01@0>3`X07@0=3`T0
3a8;018E3P0@4``03Q4:00`?200930D041<<018E3P0<3`P03a8;010C300?4@/04Q@?00d?2P092`H0
20X5014C3P0?4@`03@l:00/>1`0=40T03a8;00hA2P0N7aT01@H0014B3@0=3PT05aPC008030`:02@0
4A4?01HF5P0@410030`<00h>3P0:30T02`d:00`>2`0M7a`04A<@018D4@0?4@h0418?018D4@0E5a@0
51HC00lA3P0C5A@02P`;00`>3@0@4Q403@l>01PJ6@2;SH`0TI>B01PJ6@0B51<04A<B00H81`0?4@h0
4Q@A00/=2P0:30T03Q0=00X<2@0?4@h2014C400900lA3P0=3``03Q0=010B3`0D5Q<00P@100d?300=
3`d05ALD00H03Q0=00<05QPE018D4@0?4@h00P0@4Pl200lA3P0>014C400>40d03a4>010B3`0=3``0
4aD@01HH4`0@4Pd04Q@?01HH4`0D5Q404aD@00lA300>40/2010B3@<03a4<00D0008001LI500<3PT0
418=00lA3002018D3`05010B3@0>40/03Q0;014C3P0>40/00`0=3`X04`0>40/04A<>010B3@0?4@`0
2P`700h@2`0C5Pl03Q4800hA2P0A50d041<<014D3@0B50h05ALB024S800Z;2T030h;00T;200I71H0
0P0@4``0400E610041<:00lB2@0C5Pd03Q4800D8000G6Q806ahG00H90P0L7aL092LN0454>`0A50/0
6A`C00L:0@0B5@`2010C2P0E01<F3@0?4PT04QD<01DH4@0@4``04QD>01@G400?4P/04A@=01@G400G
6Q<03a8;014D3@0K7QL04QD>01HH4`0A4`h05QPC01@F4@0H6QD04aH?00804QD<00D04aH=01@G300E
60d05aX?018G400201LL5@805AXC00L041D>01XO600?50d051TB01TN5`0?50d05AXC008051TC0380
5Q/E01LL5P0F6aD04aPB01HK5@0D6A<04aPB01DJ500G71H05Q/E01hS7@0K81X05a`F01HK5@0E6a@0
51/D01HP600I8a/03aTA01hY8@0@6a<082/S01/T7`0J8ah0624L01TR7@0M9R4082TT028[9P0I8Qd0
72DP02H_:P0M9R408bhX02Hb;P0J:B@07RdX02Th<`0W=S408S4/024`:`0H9b807bhY02dl=`0`?cX0
Ohj907^9R@0M;B`0<D5002De=080:C/k01D0:S`n02Lk?00U>CX0:Se102Hk?P0]@T<0;T9202i2@`0/
@440:ci20354BP0fBE00>TaG03]=F`1bQ980FV]l03I7F@1KKG/0=DY;02Y0?P16G5X00P0eBdT02P11
EeD0?59@03A:B01FK6X0D6IT02m5@`0iCU00BUmT055VJ`13F5d303iCF006045FF`13F5d0B5eR04QM
HP14FEh0@5EG0P0nE5802P0mDe40?UAB03mED`0nE580@EME04ILFP19Ged0B5iL04MMF`18GU/204YP
G@0404QNF`17GEX0BEmL04UOG080CF=P0140Bf5N051VH`1>I640DfUW04eSH@1IKfd0Bf5O055WI@1M
Lg40DfUW05]aK`1OMG<0FFm]05]aK`1NM780IWml06EnN`0205meLP0E06QnN`1YOWT0HGIa04eRG@1P
Lfd0HWE_05mbK01KKfL0G71T05=XF@1FJUh0Cf=G055UF@1QMFX0Ig]`061dJ@1^PWT0J7ac06n2N`1c
QX00JWmj0080J7eh02L0JWmj06b1O01/PG`0Jh1k06QmN01RMg80H7E`06EjM@1[P7/0IGYc06QmM@1P
MF`0GW=Z05ebJ01<HUH0CF=G04iTE`1<HUD0AUa?04EKCP1BJ5/0CVAH04eSE`1AIe/0C69F045HC@13
FU00C6IK04YTFP12G5<0B6=L04iYHP0oFU40A5]A041GC@0iD4H0?5=904eTFP0oET`00P11F4h0=`1A
J5h0AUeC02]2>00lDDP0?5150393>`0`@CT0:CTe01LW9P0O;bl08S8b020`<00R<S40:3Pf02`l>@0]
?C`0=TQ902ln@@0eADD0;Shn02Hd=00[>SL0E6=O02di=@0R;bP06bPQ028_9P0R;BD072DR024Z9`0L
9B806b@Q01`U8P0G81d04a`I028[:00O:2D041TF028[:00Q;2L062DN01`Y8P0F8Q/05R4K01@O6@0O
:B<07bPS01HO6P0L91l0728N01HL600L8Qh06b0L01XO6`0I7QX00P0J7a/00`0I7QX05a`H01HK5`02
01DJ5P0J01HK5`0G7AX03A<A01lU8`0L8R004QPF02@Z:00W;B/051XH01XP7P0G7A/04aTG01DK600I
6aH041<<01LL5P052`L092XX02D[:`0>51@00`T901XL6P0:2@D07QdI01TG4P0F5A4501DF4@0D01`M
600?40/04Q<>01HG4P0:2`H04Q<>00X<2@0M8Qh0;S0]0<G7a02;SHX061PF018B400A4@l040l=00l>
300B3`h04`l>018A3`0A40h2010?3@03014@3P0B4@l03`h<00<03`h<01X04A0>018A3`0?3@h04a4B
00@20`0H5QL04Q0A010>3`0>30d030X;00d;300?3@h04@l@00h<3@0D4a404A0>00d<2P061@<03`h<
00L6100<2`T04Q4?01LF500F5A<04A0>00h=2`H04@d<0`0?2`X01@0A3@`0510?01DA400B3Pd04@d<
008040`;0P0>2PT600l;2P0<00`81@0?2`P03`/800d91P0?2`P04@d:00/7100>2PL04`l<01LC400C
3``03`/90P0<20L06@0B3Pd040`;00h:2@0>2PT06QHE014=300>2PT040`;00D1000<20L040`;014=
300@30/04`l>018>3@0?2`X00`00018>3@0<20L0510?00@0000?2`/01`<400h:2`0E4A800`0=2@X0
4P0;1`P03@T:018>3`0@30d03@T:00l;30050@803PX;00D10P0;1`P02PH700H20`0=2@X04@d>00H2
0`0L61T02PH700h82P803`T;0P0<1PP700h82P0900`6200A2`d02`D7014;3@0?2@/02P@600P2100:
10H03@L9008030H800<03`T;00d72`0=1`/0100=1`/04P0;1@T030H:00/52@0:10P030H:00l93@0B
1`/050T=01872`0@1@T03`@801052@0X7B40bl3402PM8@0700005``@01052ACooooo000Kooooo`0?
01<D5P0B4aD04a@F01@E5`0C51H03PlA014B500R8bD04a@F00l@4P0H6A/01`P:01DF600=3Q002``>
008030d?02h0414C014B500;30h03PlA00P92`0A4Q@051DG00h@3`0;3@`01@L601LI600=3`h03a4@
01@F5@0>40l02@/:00h@3`0A4a8030h=018D4@0?4@h0418?014C40051`@02`d:014C400620D05ALD
00h@3@0G6AH010H3014A3`0=3@/02@T700h>300B4`h03Pl:010A2`0B4`d04a@>01<D300@4@T03Q09
01LI500?4@`03@l<0P0:30L04`0D5Q403Q0;00lA300>40/03@l:00lA300B50l02``701XK5P082@@0
414<01HG4P0=3PT04Q<>010A300<3@P04Q<>01DF4@0?4@/00P0:3@H0100=40T041<<010C300>4@X3
00`?200400d@2@0>4@X03a8;00hA2P803A0901/03Q4:00lA300@4Pd03Q0;00X<1`0F61<00`D0010B
3@0?40X03@h800`=200>3`X03a0;00l?3@0>3P`05ADC01@D500>3Ph0410@00l?3`0B51402P`9010B
3`0F61D071hK00X<2@0@4Pl00P0?4@h02@0>40d03a4>010B3`0;3@`030h=00l@3`0F61L020X9010B
4@0202/];006014C4P0@4Q404Q@C010B4@0:30T03Q0=0P0<3P/00`0?4@h02`d:010B3`03010B3`03
00h@3@0=3``03a4>00D03a4>00D02`d:010B3`0@4Pl051HC00X<2@0201HH5@0Y00/=2P0<3P/06Q`I
00P91`0E5a@04aDB02<U8P0N81d051HC01HH5@0J71T0418=00h@2`0=3`X03Q0;014C3P0B50l03@l:
010B3@0?4@`04A<>010B3@0?4@`030h9014C3P0D5Q404aD@00d?2P0:30L0418=00d?2P0>40/04aD@
018D3`0?4@`04A<?018D3`092`H05ALB00h@2`092`H00P0>40/0400B50l0418=00h@2`0@4``030l6
00/>1`0E61404A@=00hA2P0>40X03@l:014C400C5A8030h;00h@3@0C5Q02010C2P0Z014D300B5@h0
4QD>018E3P0<3`P061/D00/>1P1?DTT0?T4h018E300J7A@07b8I01HI400C5Pd05AP?010C2P0?4PT0
4QD<010C2P0A50/04QD<010C300A50d05APA01LJ4`0F6A805APA00lB2`0G6Q<04QD>00X=1P0;3PL0
4QD>01XL5`0:30L05QPC01TK5P0A4`h05QTB01/N5@0J7A@05QT@0P0A50T04@0G6Pl03a@=01<H4@0G
71D051TB014F3`0B5a003Q<<01<H4@0D6A804AH?01<H4@0A5Pl03A8<01PM5`0M8Q`06AhH00805AXD
00P051TC01hS7@0N8ad06b0J01`Q6`0K81X06QlI01LL5P8061dG00`06R0J01DL5@0H8QX051hF02H`
:00/=bl07RTQ01HQ6@0N9b80624L01LP6`0K91l2024Z9@1;034j=@0P:B@06R<N01dV8@0O:2<08B`V
02<_:`0P;bX09C@_01`[9P0R<B`0<d8m02Xi=00M;2L093<^02He<00X=c80<D0k03A2@P0X>3L0;cln
02/k>P0U=cL0<49202Hh>P0Y?Ch09CTj02Dh?00T>C`08SLh02e1@@0^@T40<4A503=6BP0aA4X0<4=:
03I8D`0kCE/0[;k<07:3T`0dAEL0<TAB03aAE00/@D80<TM804IKG00iCTl0AU]L03Q=CP19GUl0>4e>
04eRH`0`ADH0=da>03aAEP11EU/0@UML03I;D016Ff00AEYO04MLH@1:Gf@0@EIK049GG016Ff00@5EG
03aBD011EeD0AE]I041FE014FUP0@EME04AJF017GE/0B5iL0080BV1N00<0BEmM055WI01CJFH00P1:
H5d204]QGP0704eSH01;HEh0BEmL04UOG01>I640CVAR059WJ00205I[K00305M/K@1MLW<0FFi_0080
FVm`01D0FFi_05Y_L01OM7D0K8F2061iMP1PMW<0GG=`069hM@1RMg80GgA_065fL@1OLV`0GG1Z065d
KP1QMFd0G71T05]`H@1GJel0DfMK05M[G`1SMf`00P1RMV/01`1VNW40Jgmf06f0N@1ZOGL0J7eh06Un
N@1ZOgX00`1[P7/03`1bQh80KH9m06UnN@1YOWT0JWmj06QmN01YOWL0GgA[06=hK`1TNVh0EVaP04eS
E`1=HeH0CVAG04]QE00204]RDP0?04MNCP1?IEP0BV1C04iTE`1>I5P0BF1C04eUF01;IEX0BVAI04MQ
EP14GeH0@UeD041KDP0mE4X0@EQ>0080?UE;0280@eY@04AKD@11F4h0@eY@051WG@1:HEL0<TTo02i3
>P0/?C<0:cXc028a;00T<c408c4b01PV:@0N;C006BP[02@d=00_?ch0;Shk03Y:B@1MKFh0:CTi03E5
A@0^?3`0938b02/j=`0R;R/082`X01l/9@0S;RL0:C@/02dh<00K92407bPU0`0L9B80400C71T05QlL
01/T8@0O:2D0624N01XS800J9B009C8[01LT7@0L:24072LQ01TT7P0L9R4072DP01XS7P0I81`201TO
6`0901dR7P0F6aL05AXF01LL600E6QH0>3di0415@@0J7a/06AhJ008061dI00<06AhJ01TN6`0H7Q`0
0P0I7ad05@0H7Q`05adK00/A3`0K8Al0728P010F500c>CL04aTF020R7@0B5@h05AXD01HL600C6AL0
318B01<I6@0A5aL04Q@B01PG4`0N7AT04@l:01PG4P0201@E3`0H01PI4`0I6Q@05aPB018C3@0V9b40
5aPB01<D3P0I6Q@04a@?00h@3@0J7a/04Q@A03@f<`0Y:bP03`l=010@3P0@3`d05A@B02<R800;20L0
510?00X91`0I61H03Pd;0P0A40h01@0B4@l03@`:018A3`0C4Q004Q4?008040l=0P0E4a@010071@H0
3@/<01HD5@0C4A82014?400601HD5@040P<03P`=00h<3@0B4@l02`X90P0920H02P0A40h01@@200/:
200>3@/03`h<00h=2`0?3P`040l=00d9200@30/2018>3@05010<2`0?2`X04@d<00d9200?2`X00P0F
4Q40200D40l08alN00d9200>2PT04`l>018>3@0C3`h04@d<0P0>2PT02P0@30/03PX900d9200H5140
2@D200d91P0B3P/02`L400X60`0A3@X200l;200300h:1`0C3``02`L500D03PX900d02`L6018>3@07
0`804`l>00X61@0>2PT04`l>014=300@30/0FUIE07YfM@0<20L04`l>00803PX900`03@T800h:2@0>
2PT03PX:00d92P0?2``040`=00l;300=2@X03PX;00/7200:1PL200h:2`0400/7200=2@X03`/<00d9
2P<030P91P0=2@X2014;3@0800l92`0<1PP030H8014;3@0@2P`03`T;00h82P0<1PP200/51`0300d7
2@0<1PP030H8008030H800/02`D7018<3P090`D03PP:00X41P0I4aD02@<500d72`0:10P0208600/5
2@0200d72`H030H:00`0304500d21P0?10P04PL;01462P0>0`L05``@02XO8`0J3a<03P<701<8300=
0PHDooooo`006oooool0500A4Q@0414C014B500B4aD0414C00d>400:2`d051DG010A4`0>3a404Q<E
00/<3P0C51L030d@00h?4P0@4A@03a0C014B5@0720/04a@G0P0?41<02P0;30l020T;00d?3P0H6QT0
418A00/=300620L0418A04M9B01HFUT200lA400600P:2@0>40l02`d:00lA3P0=3``0418?0P0>40d0
100=3``06Q`I00H81@0?4@h2010B3`0700l?3@0<30X0410>014A3`0<3@P03@h900l@2P02010A2`0<
010A2@0?40P03Q0900d?2P0:2`P051HA014C3P082PD04A<>010B3@0A4`h03Q0;0`0;3@P0500C50l0
2P/601<D3`092PD03a0;010A300A4Pd0414<00d>2@0A4Pd04Q<>010B300@4``03a8;014D3@0C5Pl0
4QD>00lB2`0=40T03Q4:0`0?4P/2010C2`0L00lB2P0>4@X03Q4:00lA2`0=3`X04Q@?00lA3@0:30T0
1`T5018D400@4@/03a0:00h?2P0@4@`04A8=014A3`0@40h05ADC01DE5@0@41004A4A010@400G6AH0
3a4>00h@3@0<3P/051HC010B3`804A<@01803a4>00h@3@0>40d03a4>00lA400J71/071hM01DG5P0=
3`h04Q@C00P:2@0C5A@02@/:00lA400@4Q402`d<00h@3@0A4a0200d?300700lA3P0;3@X04A<@014C
400B51404A<@010B3`0700lA3P0C00`>2`0B51405QPE00<50`0B514030h;00/=2P0=3``0I6IS02X/
:@0N81d092HS014C400C5A80418?018D4@0C5A803Q0=00h@2`0200lA30<0418=01404aD@00lA300?
4@`04A<>010B3@0>40/04Q@?00h@2`0<3PT03@l:014C3P0B50l03Q0;00`>2@0=3`X04A<>010B3@02
00h@2`0;01/M60082PD04aD@020R7@0A4`h051HA01<E400=3`X04A<>018D3`0@4`d00P0C5@l07P0@
4P`03Q4;014C3@0?4@`04Q@?01DG4`0A4`l0418<018D400A50`04A@:018E300B5@d04A@=010C3@0C
5Q003a4;00H90`0H6a<07b8I01DH3P0C5Pd05QT@01TL4`0A50/03a89010C2P0D5`h04QD<014D2`<0
5AP?01l04QD>01<F3`0F6A805QTB01DH4@0C5Pl04A@=018E3P0D5a0061/D03@g<00E614051HA01<E
400I6aH04Q@?01@F4@0D5a005AP?01<F3@0D5`h06ahC01dP5@0H6a003a@=018G400F6a@05AXC01<H
4@0E6Q<04AH?00805AXC05P051TB01LL5@0G71D04AH@01TN600L8A/06QlI01PM5`0J7aT051TC01TN
600G71H061dG01/P6P0H7AL03Q<=01TN600D6A<06QlI01/Q6`0C6Q<04adE01PR6P0V<2P08bhV01PS
6`0L9al072DP01XS7P0H8A`06B8M01dV8@0P:B@09c0[01lX8`0Q:RD092dX020Y900M:28082`X01`[
9P0S<Rd08S4/02Pg<P0eA3l09C@_020_:P0W=S409SD`024`:`0U=2l0:CLg02Hf=@0Y>CP0:c/j02Tk
>`0]?cl0:C/m02e1@P0Z?Sl0:Se102Xo@P0X?Ch0;41002a0?`0^@T40<DE60354B@0`@dT0<dE=0395
CP0iBeH0?U1M02`nC011Deh0<dQ;03eBEP0_A4H0=T]>05=XK017G5l0G75c08fRYP1:Gf80@eQJ04QM
H@19GV80>TmD0`11EU/02@0iCU<0AEYO03iCF00nDeP0AU]P041EFP0oE5T0@eQJ045GE@0204=IE`03
04YPGP1=Hf40AE]I0080B5iL0140AeeK04QNG01;HEl0BV1N04aRG`1>I640Bf5N04aRG`1>I640BV1M
04]QGP1AIf@0DVQU04mUHP1>I640CV=T059WJ00205U^K`0505Q]KP1IKVl0G75b05aaLP1NLg@00P1R
MgP03@1PMGH0I7ej05igM01UNgP0HGMd06=iMP1WO7L0I7Ud06EjM@1QM6h0GW5[069eK`1SMfl00P1M
LFD0101JKV<0FFeQ05]_I01TN6h206UmL`0706]nM`1^PWX0KH1k06YmN01YOGT0Jgmk06b0N`0206b0
O00J06b0N`1]PG`0K81k06b0O01]PG`0Jgmj06IjM01XOG@0Igeb06=iKP1PMVX0F6iR059XG015Fdh0
C69E04YPDP13FTX0A5];04iUE01?IUL0CVAF055WFP1@IUX0BV5D04YRE@18HUH204MQEP0704IQE`15
HEL0A5mF04MNE019H5H0A5]A04=JD00204ELDP0d04AKD@0hCdD0>e9803I=@`0^AC/0<DHm02hm=00c
@CX0;C/g02lk?@0/>Sh0934h02Le?00O;S<09C@g0351@@0_@3d0>4Q603E5A@0c@T80;3`j02Pg=00`
?C/09S<`02Hb;P0^>SD0;3Pb02<^:00S;BH09c4[024Z9@0M9R808R/W01HO6`0V;b/0>T<o01hW8`0G
81`072DQ01hW8`0M9R806bHQ01/X8@0F8a`07BTS02/f<01XLfd082XT01lX8`0L9B006B4L01LM6@80
5Q`H00T051TE01PM6@0M8Qh05a`H01hS7`0S:2@06b0L01XO6`0I7QX00P0H7AT0;00I7Q/06AlM01TO
7@0I7ad05Q`J01@J600Q9bD051XH00lE4`0P9R@03aDC018H5@0B5@l04QD=01@I4`0A5a<04aTE01HL
6P0G7A`020d;01HH5@0Q81`06QTD01DC3@0H5a805AH@01@E3`0F5a405aPB01DF400C50h07b0J01dN
600I6Q@03Pl9014C300D5Q<02Pl;01DG500@4Pl051HC01<C4@0?3`d051@B0P0@3`d08`0J61H04@d<
01LF500B4@l020L5020O7@0>3@/061LE01`K6@0C4Q0030/900d<2P0B4@l05A@B018@4@0=2``07Q`M
00h<3@0A3a004a4B07=aLP18ATL020L701/I6P0C4A801`H600H50`0B4@l02`X801TH5P0=30X051<A
00X91`0>3@/03`h<00803Pd;00<03`h<018>3@0D40l00P0F4Q401@0D40l04`l>01<?3P0B3Pd04@d<
00@040`;00<030P7014=300D40l00P0?2`X03@0A3@`03PX900h:2@0@30/03PX900d9200K5a@04Ph;
01@@3`0A3@/03@X8018>2`0=2@H00P0A3@X00`0=2@H04Ph;00/71@0500h:2@0<00l;2P0@30`0F5AC
01LC4P0?2`X04Ph=01@@3`0<20P03`/:04Y6A@1/J6L05A4A0`0>2PT01@0=2@P03PX900h:2@0?2`/0
3@T:00<030P90P0=2@X00`0?2``04@d>010<3@0200`82@0300l;300@30d03`/<00803PX;00<03`/<
00d92P0=2@X0100=2@X02`0>20X03`T;00l92`0=1`T030H800l92`0=1`T03PP:00l92`0>20X03@L9
00@030H80P0=1`T02`0>20X04`d?00X41P0?2P/05Q0B02@N800C3@l02P@800/52@0=1`/03PP<00P0
3@L;00X04PL;01462P0A1PX04PL;01052@0<0@D03@8601H;3`0C20`03`@80P0A1PXDooooo`006ooo
ool03@0D5AL04Q<E018C5@0C51H04Q<E00l@4P0=3Q003PlA01<D5P0B4aD03a0B01<D5P0F5a/00P0>
3a<0:00?41@03PlC014B5P061`/030dA00H72`0?41@030dA01DF600<3@h020X900`>3@0J71/04A<B
00T;2P0D5QD01PP7014C4P0=3`h04Q@C00h@3`0<3P/051HC00lA3P0A4a006A/H00lA3P0=3``01PP5
01TK600K7AX01`T6018D4@1:BTP0410>00X:200=3@/01@H100@5000>3`T200l@2P0M00l@200>3`L0
1`T400`>2@0L7QT0BTa703Pj=@0>40/020X500`>2@0>40/03@l:00`>2@0=3`X02`d802DV8@0=3PT0
71dH00P9100F5a803@h901@E400E5Q4051D@01<D3`0B4`h0418<00lB2`0=40T00P0>4@X02P0=40T0
30l800d@2@0@4``04QD>014D3@0?4P/04A@<018E300@4`X300hA2P0?00P:1@0E5a802P`900X<2@0U
9b@02P`9014B3@0?40X03Pl:010A300B4`h04Q8@00d=2`0?3`d03`l?00803@d=00X030`<00X<2@0:
30T04aDB00lA3P0D5Q<04aDB018D4@0A4a00418?0`0>40d03P0620L051HE01@F5@0<3Pd04A<B018D
4`0E5aH061XI00/=300?4A00418A014C4P0>40d0418?0P0<3P/01@0?4@h03@l<00`>2`0=3``03Q0=
00803@l<00<030h;00lA3P0?4@h0100?4@h03`092`P03@l<01dO700A4a004aDB01LI5P0E5a@04aDB
0001000<3P/06Q`I01@F4`0C5A803@l<00/=2P0201<E4P0300`>2`0=3`X03a4<00804A<>00h03a4<
00h@2`0@4Pd02`d800h@2`0B50l03a4<00h@2`0A4`h05QPC01TK5P0H6QD04Q@?00lA30<03Q0;0P0?
4@`09@0>40/051HA00@60@0C5A006Q`G01LI500620<061XE01TK5P0=3`X04aD@01DG4P0A4`l04A<@
00d?300=3`X05ALB014C3P0>40/07AlJ01hP6`0@4``05AP?01@G400<3`D03Q46010C2P0C5Ph04aH?
018D3`0L7QT0?d4l010B3@0>4@T03A0700T<0@0=40H00P0B5@`0100@4`X04A@;018E300D5`h200d@
1`0401HI400B5@`061/B01@G40805APA01L051L@018E3P0A50d06A`E00/>1`0F6A805aXC03/n=`0D
5a0061XE00lA300>40/03@l:01PJ5@0K7QL051L>01<F3@0G6Q4082<H028U6P0L7a@04QL@01<H4@02
01DJ4`8051TB02@05Q/D01LL5@0D6A804QL@01@I4P0A5Pl041D?01@I4`0F6aD05AXD01HK5@0I7QP0
61dG01LL5P0D6A<06AhH01hS7@0I7QP04QLA00`A2`0R9b4061dG01@J500F7AH082XR01dW7`0J91`0
51lG01<N5P0P:b<06R<N01`U800J8ah05b0K01TR7@0O:2<201PQ700<020Y900U;RT08BXU01lZ900[
=c<082lZ01h]:00L:bH06bXU01l^:@0Q<2/08S4/0P0Z>C@0;`0V=C00:3Lb02/i>@0_?ch0;3`k02dm
?00/?Sh0:C/k02Tk?@0^@T<0;41102/n@P0Z?d809c`m02Hj>P0kCdh0@EED03Y>C`0aADH0<4=70313
B00fBDl0=4M=03M:D@0_@TT0=4M>02i3B@0_@dX0>4eB04EIG`0lD5L0@5EK04QMHP1ZOXD0?e=I04ML
H@1<H6L0?eAI03A9CP1LLGH0?eAI04IKH00lDEH0AEYO04iSJ01BIf`0CF9W0080@eQM00`0AeaN045G
E@13FEL0AE]I05ecL@1RN7H0Bf5O04MMF`1<HV00CfES04YPGP1;HEl404eSH00304iTH@1@IV<0CVAQ
00<0C69O00<0CVAQ05E[J01GK6d00P1GK6d08P1HKFh0G75b06=hN@1YOWl0HWMh05Y_L01MLW<0HGIg
05mdM@1TOGX0GgQe06MmNP1RN7D0I7Yg06IkMP1TNG@0IGYe065dKP1OLV`0I7Ma06MjM01PM6/0H7AY
05mcJ01PM6T0HWI]06IjL@1YO7H0J7]e06YmN01]P7`0K7mk06UlN01[OWX406f0O00O06aoN`1[OWX0
JWei06]nNP1]P7`0Jgij06QkM@1OM6/0I7Y^05idJ01IKf<0EfeQ04iTE`1UNfh0DFMI04IMC@17GTh0
BV5@04]RD01?IUH0D6MH05=YG01AIeX0Bf9E04MODP13GE00AEmC04IPE@17HeL0BFAJ04UTF`0204EL
DP0M041GC@0oET`0@5M=03iEB`0mE4X0>4m503YAA`0dBd40:D0f02Xn=@0^>S80<Sdi02`h=P0/=c/0
;cU202/h@@0]>T<0<T5803=2A`0iBDX0<DA203I9A@0kBTH0;chk01h]:00fAD40B5A@02Hb;P0N:RH0
0P0Y=3005@0R;BP082TV024Z9@0W<2/072DP02D^:@0I8Qd092dX04=<A`0Q:RD0624L01/T7`0P:B@0
7RLR01hY8`0D8AX05B8K01PT7P0c?SP0JgI`01dW8@0201XS7P0301XQ7@0J81`06R0L00806QlK00h0
61dI01DJ5P0H7AT05Q/G01DJ5P0H7AT05a`H01TN6P0J7a/06b0L01PM6P0C6AL05A/I01LM6`8061hL
01@05Q`J01TO7@0^=380FEmM02D[:@0F71T05aXC01lR6@0F6a@03A@=00hD400J81h0728P01PN700J
71P03`h901dL5`0G5@h05aHA01DF408051D?0P0C50h0=`0I6Q@06a`F01LH4P0E5Q004Q<=01DG4@0C
5A001@X601@F4`0>40d05QPE014A3`0F5Q@040l=01PG5@0<2`T05Q@B01PD4`0@3`d05QDC00`;2@0G
5Q@020L501DD4P0C4Q0040l=018A3`0F5A<04Q4?00T81P0H5QL020H7018@4@0;2@X0518C00`:2`0k
>CX06QPI020N7`0610D0?C/l02@R8`0@3`d01PD301LF50071P@051<A00d<2P0:2@L03@`:00h=2`0=
30X030/900d<2P0>2PT00P0?2`X01P0@30/03PX900d9200A3@`0510?018>3@8030P700<03PX900l;
2P0=2@P00P0<20L00`0?2`X04`l>014=300200h:2@0?010<2`0>2PT03@T8014=2P0E4@h06aLD00P4
0P050@002PH300d91P0@30T03@T600`81@0K5a@0510>00D03PX900d03`/:01@@3`1oNgX0920O00/7
1P0@30/02PH500h:2@0F4Q401`@300d9200300004Ph=00803PX900@03@T800h:2@0>2PT03PX:1@0=
2@X01P0<20T03@T:00h:2`0;1`P030P900d92P<03`/<0P0>2P/00`0?2``03PX;00h:2`0300d92P0O
00`82@0:10H030H800h82P0=1`T030H800h82P0;1@L030H800l92`0@2P`03`T;00d72@0:10H02`D7
00`6200=1`T03PP:00l92`0400002@<501LA4`0F41805@lA018<3P0:10P02`D900X420070@D02P@8
010:3P0600h8300<00h31`0=0PH03@8600l4200@1@T03P<701@93@0>0`L04`P<01@93@0<0@D03`@8
5?ooool001_ooooo00h04A8D00h?4@0=3Q003PlA00l@4P0<3@l04A8D00l@4P0D5AL04Q<E00d>400C
51H07QlS01<D60<0414E0P0D5AT0900;31003a0D010A5@0<3A4061TK014B4`0:30/03a4@02DW9P0K
7A`03Q0?00X<2`0>40l0418A00L9200H6QT02`d<00lA3P092`P06A/H00`>2`0;3@X03Q0=00`>2`02
10406A/H00lA3P0620D04A<@01TI5`020P003Ph<01/K6@0G61<061TD010A2`803a0:00P03a08010A
2@0G61800040014C3P0@4Pl0004001TK5P803@l:00<03Q0;00d?2P0<3PT00P0>40/01P082@@0414<
05EFD@0A4Pd05QLB018C3P80414<00D04A8=00h?2P0=3PT03Q0:00d@2@0300`?20802`h702H03A09
010C300B5@h04A@=00lB2`0@4`/04QD:010C2P0>4@P03A0700d@2@0:30L02`d800/=2P1CEE@0O7im
00X<2P0A4Pd03a0:00h?2P0@4@`04Q<>018B400A4@l0410>014A4@0B4Q80410@00l?3`0:30T02`d:
014C40082PL03@l<010B3`0A4a00418?00lA3P803Q0=00l03a4>00d?3P0C5A@04A<B00h@3`0I6aX0
5ALF00h@3`0A4a802@/:010B4@0B51<05aTH00`>2`0>40d00P0;3@X00`0@4Pl03a4>00`>2`0200d?
300300h@3@0=3``030h;00H03a4>01@01PP501hO7@0;3@X05aTF00T;20072@H04A<@00lA3P0=3``0
71hK05EGE00c=C803a4>00d?30092`P03@l<010B3`0=3``03@l:00lA30804A<>00@03a4<00h@2`0?
4@`030h90P0A4`h0200;3@P030h900lA300H6QD071hI01XL5`0A4`h03@l:0`0@4Pd200lA300`010B
3@0c=C006A/F01@F4@092`H06A/F01dO6P0D5Q405aTD00h@2`0@4Pd04A<>018D4P0E5aH04A<B00`>
2`0@4Pl04Q@?010C3@0I71D06QdF00lB2@0F6@h05AP?00hA1P0@4`P04QD<01<F3P0B50l04A<@04i@
C@29RhH0:2XU00L:0P0E60l051L<01LJ400G6Q4051L>01<F3@0B5@`04aH=01@G3P0@4`X04aH=01LJ
4@0@4`X06A`C0`0E61402`0C5Pl04A@=010C300L7aP020/401LJ4`0@4``0:2/T01XM5P0n@3/0828M
00804Q@?00D04aD@01LJ4`0A50/04QD<01DH3`0201DH3@0301LJ3`0F6a@05AXC00805AXC00@051TB
01<H4@0F6a@05a`E0P0D6A800`0G71D04QL@018G4@0301@I4`0?01HK5@0H7AL051TC01<H4P0@5@l0
51TC01XO6@0D6A<061dG02P]9`0O91h06QlI01<I4P0G7QL072HN00805R0H0P0G8QX01P0I91`06R<N
01dV8@0K91l0624L01XS7P807bPS00H072DP020Y900S;2L08BXU028]9`0T<2`201`[9P0601l^:@0P
;bX08S4/028a;00S<Rd09cHa0P0X=c800`0[>SD0;3Xj0351@00202lo?P0302i0@00/?Sh09CLi0080
;D5202d0<4=70356B@0_A4D0<4A404QLF`1:GUd0>Ti=0396A@0dB4T0<DA702Dh?00gBTh0;D1405=V
JP0fBDl0<dM>03A8D@0oDeX0;41804EIHP19GFD0CV9Y04iRJ`18G6@0DFE/04AHH@0oE5X0AeaQ08>H
W@15FUl0@EIK04AIGP0mDUL0GG9g06AiOP11EU/0=DY?03Q=DP17G5h0B5iL04ILFP12F5H0DVQV05E[
J@1:H5h00P1@IV@01@1>I680AE]I04QNG01AIfD0DFMT00D0D6IS0P1?IF801`1@IV<0DVQU05Q^K01O
M7D0GG9e05]`L`1JKg800P1KL7<03P1UNWd0H7Eh05ebM@1RMgX0IGYm061eM`1UOW/0GGIc06AjM`1S
NGH0J7ik06UnN@1QMW40HWMb0P1QM6h0201WNW@0JWeg06=gKP1RMVd0HgM^06AhK`1VNG<0JGaf0P1/
Og/01@1_PWl0LhJ407>6Q01`Ph40KH1l00@0KX5m0280K7mk06j1O@1[OWX0JGah06YmN@1/Og/0Jgih
06IkLP1XOW80HWQ/05idI`1HKV40CVAG05A[F`14Fd/0@eY:04YQC`1?IU@0DfYH04iUE@1AJ5P0DVUI
051VF@1<HeD0AUi@049LC`14GU40AV1C04MSE`1:IUX0BfMK04QOE@17GU@0@eY@0P14Fe40:011F4h0
?eI<03=:@00_AS`0;D@j02i5>`0cAch0<Cdf038m>@0[=CH0:38h030jA00e?d/0=D5=04ECG00mC5<0
=TI702Lj>00[?SX0;C`f01/Z9@0G9Ql0=T8n04EAC@0[=c<07RTU01lY:00Q:bX08b`Z020Y:00N9b@0
8BXU01lX8`0X<B`06b@O00PA300M9R407bPS01hW8P0M9R4201hW8P07028]9`0K:24062DN014M5P0U
<2X082/U01DO6P0201XS7P0901/R7P0K8Ad06R0L01PN6P0I7QX05a`H014F4P0G71P06b0L00806QlK
00P06AhJ01PM6@0H7AT06AhJ01HL6@0C6AL05A/I01LM6`8061hL01<020h<01DK6@0C6AL0;38`01XP
7P0?5A8061/D01XM500@5@h06R4J01@J5P0:40h01P`:00P>300N81`020L2018A300J6A405QH>0080
5AH>00D04a@<018C2`0C50`061TA018C2`0201`M5@0700d>1P0@4P/03a4<018G4`0>40d02`d:010B
3`0201HF500M01<C4@0A40h03@`:01<A3`0I5A@040l=01LF500B4@l051<A01hM6`0>3@/04A0>018A
3`0I61H07ahL01TH5P0=30X05Q@E024O800D4Q<03`d>01@B4`0<2P/00@00018@4@0D4Q<05Q@E014?
40040P<00P0H5aD02`05108040l=00T81`0@3`d02`X800h=2`0?3P`03@`:00`;2@0=30X04@d<00<0
4Ph=0P0A3@`00`0>2PT04Ph=014=300200d920803`/:00H040`;00h:2@0>2PT04Ph=01@@3`0A3@`2
00h:2@0?010<2`0>2PT03@T8014=2P050@00510=014=2P0E4@h04@d:00/7100<20D02`L401<?300`
;2T08AdK00D03PX900d04Ph=00<0000L61L01`<200d9200E4A001`<300`81`0@30/04Ph=01lK6P0B
3Pd03`/:00803PX900l03@T800h:2@0>2PT03PX:00h:2`0@30d04Ph?010<3@0>2P/02`L800`82@0:
1PL01`<400h:2`0?2``01@0=2@X400h:2`0600d92P0<20T030P900T31@0<1PP03PP:0P0=1`T01`0>
20X030H800d72@0?2@/040X<00l92`0>20X00P0;1@L0100=1`T03PP:00l92`0@2P`2014;3@0:00d7
2@090`D0100000H00P0>20`03`T=010:3P0=1`/02P@800T31`H03PP<00`04@H:00l4200?10P040D9
01462P0?10P05``@00d21P0D2@d05@X>00`11@0>0`LDooooo`006oooool00`0D5AL0414C00l@4P02
010A4`803a0B02X0414C00l@4P0=3Q003@h@00l@4P0D5AT03@hB00`=4P0=3Q802``A00d>4`0E5QX0
30dA01HG6`0<3A805QLL00H72`0=3Pl05QPG00/=300A4a803Q0?00d?3P0N81l04A<B00H81`0D5QD0
2`d<018D4`0?4@h071hK00d?300O8Ah0>cdj00h@3@0:30T04aDB00P:1`0A4a003@l<00h@3@0=3@/2
014A3`0?00P81`0<3@X05AHA014B300?40X03Pl900l@200@4@T03@h8010B3@0;3@P04A<>018D3`09
2`H03a4<00804Q@?01P03a4<00`>2@0<3PT0414<00P91@0A4Pd0;RlZ00l@2`0@4@`03Pl:010A300?
40/04Q<>00l@2`0@4@`04Q@>00hA2P0=40T03Q4:00lB2`0=40T030l800d@2@0>4@X300lB2`0300lB
2@0?4PL03Q4800803A0700`03A0900lA300?4@`03Q0=0453@P1@DU403@l=010A300?40X03Pl:010A
300A4Pd2014A3`0;00d=2`0>3Ph04Q8B00l?3`0>3Ph0418?00d?300?4@h02P`901HH5@0V:2D0100?
4@h01`0@4Pl04A<@018D4`0@4Q405QPG01@F5@0C5A@00P0=3`h03`0A4a803Q0?01@F5@0>40l04A<B
014C400B51403@l<00`>2`0A4a00418?00lA3P0@4Pl04A<@018D4@02014C40H03a4>00L05aTF03Dg
=0092`T04aDB014C400E5a@04Q@A00803Q0=00X0418@01HH5P0I6aP04Q@A01<E4P0?4@h0418?01<E
4P0A4a003Q0;0P0?4@`3010B3@06014C3P0?4@`051HA00lA300=3`X05ALB1`0A4`h0500B50l04A<>
00lA300?4@`04A<>03Tk=P0];b/05ALB02@V8P0H6QD020T600d?2P0?4@`0418=00`>2@0@4Pd08R@S
01hO8P0D5AP051HE0P0>40d0500>4@/03Q4:00lB2@0?4PL04aL:01@G2`0C5`T05AT;01@G300C5Ph0
4aD@01<E4P0G6AL09BLT01<E400G6Q804QD:01XN4`0l?c@071lF0P0D5`h0100B5@`04A@;014D2`0C
5Pd201@G3P0601PK4P0E60l05APA01DH4@0D5a004QD>0P0A50d04`0F6A803Q4:01LJ4`0@4``06QdF
01hQ6P0c=C0061XE014C3P0C5A004Q@?01HI4P0H6a805aXA01HI400C5P/051L<01HI3P0F6a@00P0D
6A802`0F6a@05a`E01HK500B5a0051TB01HK500L8AX082DN01TN5`0G71H05Q/E00<05a`F0P0F6aD0
4P0J7aT061dG01PM5`0J7aT05Q/E01LL5P17C4H041D?024V800I7aP06B0I01LQ6@0K9Ad09c4Y02hi
<@0X<b/05b8J01/T7`8072DP00d07BHQ01lX8`0O:2<0;CHa02H_:P0S;2L08BXU01lX8`0T;bT09S8^
028a;00P;bX08C0[00808S4/01X09C@_02Lf<@0V=C009C@_02Lf<@0Y>3<09cDe02`l>`0`@3l0;Cdl
02`n?P0cADD0=4I803Q<C@0eBDX0<DA802a1A00X?Ch0=DU903M;BP0dB4L0;D5002e1?`0`A480<DE3
0396A@80>4a;03@0L8B303mCD`18G6@0A5QR03Q<EP1hS9H0F6af051TKP12EV00@5AN04]OJ@13Ef40
A5QR045EG@15FUl0J7f204IKH012Ee`0Bf1U04EJG`1cR8d0LXN<04UNH`12Ee`0@5EJ04aQH`19Ged0
BV1N04UOG@1?IF<0DFMU04aRH01;HEl0BEmM04YPGP19Ged0EVaZ069hM@1EJfP0DFMT05=YIP1@IV<0
CfER051VH`1BJ6D0FW1]05]aKP1IKf`0F6i/05aaLP1KL7<0GG9e0P1QMWT02P1NLgH0Fg1c05icMP1V
Ngh0K86406UnP@1RMgT0H7Qh05mhM@1^Q84206QnN`0306^0N`1SN7<0IW]f0080IgYd00L0Jgih06ao
N@1YOGD0IgYc06IiL`1XNgH0K7mj0080KH1m00H0K7ml06n1P01bQH@0LXB306n1P01_PWl20723O`0O
06n2OP1^PGd0KH1l07:5P@1^PGd0Jgij06aoN`1]P7`0Jgih06UnM@1UNfl0HgU]05Y`H`1DJU`0HgY[
08NNSP1RNFT0CVED04iUD`1=I580DFQF04aSD`1AJ5P0CVEE04eSE@1=I5H0AemA04EODP16H5<0Af5D
04MSE`0204YVFP0f04UPEP16GE<0@EQ>04=JD011F4h0?EA:03A;@@0gCT@0=Te30317?@0W?S@09CT`
02`g<00]=c<09c0b028[<P0^>4<0>T=A045=FP19Ef80=4=:0311@`0Y?3X0;3li028b:00S<bX09SH]
02Hc:`0[=S408bhY02@_:`0Q:RT08B/Z028Z:`0M9BH0624P01dW8@0G8AX05R0I01`V7`0H8Q/06B<L
020Y8`0T;RL07bTR01hX8@0P:R<07RTR01/X8@0L:B806RHP02<^:00<5a4082XT0P0L9B001@0L8al0
6AlK01LM6@0E6aL05Q/G00805a`H00T05Q/G01TN6P0M8Qh07B8N01`Q7@0I7QX05a`H01HK5`0H7AX0
0`0I7ad04@0F71X051XH01DK6@0N92804QPF014G5@0J81h051XG018E3@0N8AP05Q/D01HM5P0=50d0
?dE206]aKP0M8al04A<>00805QD@00@05aH>01DE3@0E5Ph05aP@0P0D5@d0600F5`l07b0H06i_I`1d
MFd04a@<010A2@0B50`06A/F01HK5`0D5Q<03a4>01HH5@0@40h02`/9018A3`0Q81h0CDa:01HC4P0>
2PT061LE01@C4@0@3`d05aHD02d/:P804A0>0P0@3`d05P0C4Q005A@B01@C4@0=2``0=38c02PV9`0@
3Pl03`d>01<A4P0>30d04@l@00H41@0E4a@04Q0A01hL7@1GEU@0Hf9P04m>C00B4@l05aHD00/:2@0>
3@/2014@3P0400l>300>3@/03Pd;018>3@804@d<0`0@30/01`0=2@P040`;014=300B3Pd040`;00l;
2P0;1`H00P0B3Pd0100D40l04`l>00l;2P0A3@`200h:2@0?010<2`0>2PT03@T8014=2P0c;b`0A40m
010<2@0A3P`03PX7010<2@0=2@H02`L400`81@0L61D0510>00D03PX900d03`/:014=30050P40510?
00d9200D40l02`P7014=300:1PH03`/:018>3@0<20L03`/:00803PX901003@T800h:2@0>2PT03PX:
00h:2`0B3Pl0510A018>3`0>2P/02`L801DA4P0K5aP04@d>010<3@0?2``030P90`0=2@X03@0>2P/0
3`/<00l;300?2``03PX;00d92P0<20T02`L800`6200=1`T03PP:00d72@0>20X00P0A2`d01@0@2P`0
3`T;00d72@0>20X03`T;00803@L90P0>20X200l92`0703D_<@0X8R@030L8014;3@0<1PP04@/=00h9
300200/52@03010:3P0A2`l03@L;00H03@L;00D06@hB01D:3P0B1`/04PL;01462P0200l4200500d2
1P0A1PX04@H:00h31`0@1@T05?ooool001_ooooo01<04Q<E00h?4@0<3@l03@h@00h?4@0=3Q0030d?
018C5@0=3Q002``>014B500?41@03@hB00`=4P0D5AT05aPM014B5`0?41@03a0E00803a0D02h051DI
04I7C00J6al03Pl@01HH5`031@@03a4@00`>3@0830/03Q8A018F5@0;3`h03a8A03e1@00L81l0414?
00H6100B4Q004A8?01/K6@010`003Q0=00P:1`0N81d0ATQ501@F4`0620D0410>00d=2`092@L03@d;
00/<1`041@003a0:00`=1`0;30H030d600h?2@0>40X03@l:03do>P0J71L0004001lQ700:30L0418=
0P0A4`h04`0?4@`04A<>01DG4P0720<01@H1010A300?40/01@H101DF4@0;30L02@X500h?2P0;30L0
3Pl:014C3@0<3`P02`h700d@2@0>4@X00P0=40T300`?200P00d@2@0>4@X03Q4900`?1P0;3PD02`h7
00`?200=40T030h900X<1`0?4@h05aTF00840@0B51803a0;00d>2@0<3@P03Pl:00l@2`0?3`d051@B
00h>300@41005QHF018B4P0@41005ALD014C400B51402P`9014C400E5a@200d?300H00h@3@0?4@h0
418?01<E4P0<3Pd02`d<024S8P0L7Qd03Q0?00d?3P0D5QD0418A00L9200>40l03a4@01/M700J71T0
6A/H014C400>40d04A<@00h@3@0=3``03Q0=100@4Pl600lA3P0?01DG500:30T04aDB00`>2`0C5A80
DeEB04Y<B@0A4a002@/800H81@0A4a003a4>010B3`0>40d030h;00804A<@00L02`d:010B3@0>40/0
3@l:00h@2`0A4`h04Q@?008030h900@04Q@?00lA300J71L0;2hY0P0A4`h2018D3`05014C3P0@4Pd0
3a4<014C3P0@4Pd00P0<3PT0:00?4@`030h901PJ5@0=3`X07R0K0043000E5a804aD@00h@2`0E5a80
3@l:01HH4`28RXP0QXN902DV:00<3Ph07R0M02<U8P0O8A`04QD>014D2`0E60h041<800hB100A5@L0
41@600lB1`0B5@d061XE01dO6P0I6aP02P`7010B3@0B5@d05aX?00X>000[<2D04QL@00X@1P0B5@`2
01@G3P0901DH3`0G7A<05Q`B01hT6P0e?C808RTQ01@G400C5Pl04QD>00804A@=00<04QD>00lB2`0I
71D00P0B5@h0>`0J7AH03Q4:00d?2P0?4@`061XE01<E400J71L061/D01TL5@0D5`h04A@<01HI400G
6Q404A@;018G400@5@h04AH?01LL5@0J7aP06b0I014F3`0C61405Q/D01`Q6P0O91d04aPA01DJ4`0E
6Q@05AXC01HK5@0C61803a@=01<H4P0L8AX06QlH01HK5@0F6a@04aPB01`Q6`0E6a@072<L01dR700J
8AX07bHO01hX800P:R808bdU02Ha:@0S;RH05b8J01dV8@0J8ah072DP020Y900S;2L082TT02D^:@0Q
:RD082TT00807bPS00T09C0Z024]:@0R<B`07bhY01h]:00Q<2/0830]028a;P0Y>CH00P0Z>SL02@0/
?3T0;Cdj02`l>`0/?3/0<TE302Xk>P0V>3P0<dE502`n@00203=7B00M0396A`0_A4L0;4520314@P0Z
?S`0<4A203iBD00kCdd0=4Q60355@`10E580;D8m03A9A@0lD4h0?E=A041DG01>HVd0Cf=/05M[M@15
FF@0E6Qb03mCG01=HF`0D6A^03]?F01?Hfh0Ae]S04AIGP0`ADX00P18GF803011EU/0@UML05Y_LP1>
HfH0A5UL04YOHP10EEP0Bf1R045FE`17G5d0CF9S04UNG`80CV=T00/0CF9S055VI`1EJV/0BEiO04iS
I01KLFl0DVQV04iTHP1BJ6H0D6IS04mUH`0305=YIP0X059XI@1CJFH0FFm]082EV01eRXl0HGIj05Q]
L01JKg80GgAg06MlO`1VNgh0HWMi05aaM01LLG80H7Ef05mgM`1[Q840PYRE06^1O`1PMW<0I7Qf06Um
N`1]PGl0KH9m06aoN`1]PWd0JWii06j1O@1YOWT0IWYe06YmN@1]PWd0L8>107>6Q01aQH<0LXJ407F8
QP1bQH@0KX5o0723O`80L8=m00@0L8=o06n2OP1]P7`0LHB00`1`Pgl05P1/Og/0IgYd06=hL@1RMfh0
Igea05Y^HP1MLV80TJJE0?;omP2:Whh0AEY904eTE01AJ5P0A5Y=04YPD`1?IEP0BV1C04UODP1>IEP0
B61C04UQE019HEH204QRE`80BF=H01l0C6=K04IME@10Edd0@5M=03aCB@0fCD<0?5=903M>A00`B3/0
:T4f02To<`0Y?C80:C@_030i>00]=cT09c4i03@nBP0oBeT0IgB104mMIP0Y>3l0:SXk02Hf<`0V=c40
8c<Z02<c:@0V=R`0:CH^034l=P0X<bd07bXU008092l[02407BLV01TR8@0H8Ah051dG024[8`0O:B40
51hF01XT700M9al092hV02H`:00O:B408B/S02<]9@0L9b006bHP020[9@0Q;2H05B0J02lh<`0L9B00
624L01XS7P0L91l0728N01/Q7@0Q9b<07B8N01LL600J7a/05Q/G01DJ5P0H7AT00P0G71P0DP0I7QX0
6QlK01`Q7@0K81d061hL01TO7`0I7ah061hL01LM700K8B404aTG01`R8@0K8B4061hL01TN700L7aP0
5AP?00`@2@0V:bD03a@>024V8P11AT802Pl;01HG4P0A4P`05A@?01TI4@0D50`05AH>01PI4P0E5Q00
5AH>01TJ4`0B4`d07AhF02d^9`0H6A<04Q<;00h?2@26R8<0=CLd014C400C4a40A4A203Ph=P0M7A/0
4Q4?07QgM@3Ddm40928P01/G5P0@3`d05QDC00/:20081`D02`X901`K6@0?3P`04Q4?01<B400A40h0
40l=014@3P0B414040h?01PF5`02004040h?01DC500I5aP020H701lM7P091`P040h?00l=3P0S8R00
Lg9`05UHEP0@3`d02`X801PG5@0@3`d2018A3`0400l>300>3@/03`h<018>3@8040`;0`0?2`X03@0@
30/03`/:014=300D40l03`/:00/71P0D40l03PX900H20@0:1PD03PX900X61@0A3@`00P0>2PT02`0@
30/03PX900d9200C3``04@d:02HR7`0:1P@04@d:00H2000:1P<040`90080510=00<04`l<00X61@0>
2PT0100>2PT03@0;1`H04`l>00P40`0810<02@D400h:2@0@30/06ADD00L30P0?2`X02@D400D1000C
3`h00P0>2PT0100=2@P03PX900h:2@0>2PX200h:2`0800l;300>2P/03PX;00/7200S7b00=30a024M
7P0>2P/200d92P<03PX;00P03P`=00l=3P0=2``03@/<00d:2`0=2@X030P900/720<03PP:00P030H8
00h82P0D3Q005@lA01<=3`0>20X02`D700`620<03`T;100>20X0300600804`d?014;3@0>20X01000
01D?4@1:A4P0=2hb010:3P0500<03PP<018<40H030H:00@04PL;00l4200=0PH03P<70P0?10P01P0>
0`L04`P<01462P0?10P040D900l421Cooooo000Kooooo`0800hB5@0:3Q403A4D00lC5P0<3a803@hB
00`=4@0@41@2018A5P0?01<B5`0D4aP03PdB01@C5`0o?d40BDQ=02<S9P0?3a403@`A014@50051@L0
6a/N07elP@0I6A/03`l?00803Q0?0P0<40l200/A3`0L00PA3P0=5Q<06b@Q0>kim@25RhT04Q0>014@
3P0@3`d03`l=00l>300>3P`03Q0=00D7100A4a00;C8^01/P70021`<03a0;018C3P0>3`X04Q<>01<D
3`0:2`H03Pl:010A300<3@P030d700d>2@802P/601H061TD00H70P0@4@`03Pl:01HG4P0=3PT04Q<>
00X;1P0A4Pd03Pl:01XK5P0=3PT01`P3010A300>3`X03@h9014B3@0>3`X02``700`=200?40/0414<
0P0?40/0:00@4@`04A8=014B3@0A4Pd0414<01hO6P0=3PT030d9010A30031000414<018C3@0?40X0
30d8018C3P0A4Pd0414<00/<1`0:2`H04a@?01DF4@0@4@d03@d;00l?3@0B4Q004a<A014A3`0>3P`0
30`:00h>300<30X03@d;014A3`0>3P`03a4>00d?300B51405aTF018D4@0<3P/300d?30802`d:00l0
3Q0=01<E500;3@`04aDD01HH5`0<3Pd06A/J03Xl>`072@P07b4P00L9200J71/07AlN00lA400>40l0
0P0=3`h06P0>40l03a4@01@F5@0C5A@0418A00lA400>40l03@l>01@F4`0<3P/01`T6018D4@0@4Pl0
1`T6014C400:30T04Q@A00`>2`0G6AH0C4i;04M7A@0G5aD02`/901<C4@0@40h051@B100C4a405P0A
4@l0410>018D4@0@4Pl04A<@01<E4P0A4a003a4>010B3`031@8051HC01DG500;3@X05aTF01DG500F
61D03a4>00/=2P0A4a0051HC018D4@0A4a02010B3`0A00h@3@0>40/04A@>010C300?4P/03Q4:00d@
2@0<3`P041<<00d@2@0C5Pl04QD>014D3@0l?SX0=cTf01HH5@0?4@h00P0C5A008@0>40/04A<>010C
300=40T030l800hA2P0@4`T04A@901<F2`0@4`T03A0700hA200B5@`04A@;010C2P0?4PP03a87010C
200=4`X01`h701DL500B5`l02a4701LM4@0=4`L05QhA01HP5@0a?380_L[007R6O@0K81T04A@=01<F
3`02010C30<04aH?00d05APA01@G400C5Pl04A@=00lA300C5A0051HA01HH4`0K7AP04aD@01TK5P0G
6Q<051H@00<041<<00T061dG01XO6@0A5Q0082DO01HK5@0l@C/061dG01LL5P0F6aD00P0H7AL06`0G
71D05aXC01TL500I71<05aXC01LJ4P0H6a8061/D01XM5@0H6a8061/D01`O5`0K81T07bHO01/S7027
THT0HfYS014K4`0Q:b<08bdU03<m=@2f`;P0@de502/e;@0B71@082/S01dX800202<^9P0?01dX800O
:R806bHN01lZ8P0M:2006bHN024/900]>38082`X02Hf<`0G9b@08S8_02@d<@0U>3H08c@c00809STg
04@09SPh02Pl>`0[?ch0:3Xj02Hh>00Y?C`0=dY902Xn?@0W>cX0<TI503A8A`0/@3l0=TY903Y>C`0/
@3l0<dI203A7@`0R=C40@eIC03U=B`0U>CL0;T900316@`0dBTL0<DM403I<BP11EUL0>DiD03eAFP10
E5/0@eMO04EIHP15FF40?51G04IJH`15FF40?U9I04AHH@0nDUT0BEeT04IJH@18G680DfQ]04aQI019
GV40Bf1Q04MLG@11EUH0AeeK04QNG016Fed0DVMZ04=HF`19GV40DfQ[04QMH01<HF@0CV=V059WJP1F
Jfh0Jh2304QMH01dR8`0K821059VI`1@I6D0E6QW05Q/K@80EFUX00h0E6QV05EYI`19GE/0F6a[0<CI
gP2P];/0HGIl05aaMP1PMGX0GgAg05Y_L01LLG80H7Ie06=hN@80I7Yh0380IW]l06MlO@1YOgh0JGio
06UoO@1[PGl0LXR606j4PP1YOgd0JWim06Z0OP1]PX00JGek06QnN`1ZOgd0KH5o06j4P@1`QX40L8F0
0727P@1bR880LXN20726P@1_Q7d0JGed07>4N`1eQWh0P96;08FETP1/O7/0M8B307>3P@1aPGh0Kh1j
06ioN@1[OWP0J7eh069fL@1PM6/0G6iR05QZF@1SM640UJJC07J8M@1@HU80CF5E04YOE@1=HUT0D6EL
04mTF`80CV=J0P1?I5/0<01<HEP0Bf5I04aSF`1>IEd0C6=K04QOE`18H5X0?eQB041JD@15G5@0?EA:
03M>A00fC400>U1403I<?`0aAc/0:clc02Hg;@0W<S0082X/02D`=00/>D<0:3I304EBHP15DV40:SQ1
02/j?`0]>c`07RXV02Db:`0V<Rl0;CTe02@`;00]>S@0=d@m02dj<`0S<2P07b`S020]900L:1l06bHN
020[8`0c?CD05R0H020Z8P0G8AT05R0H01dW7`8072HN00@07bTQ02D_9`0Q:b<07RLQ0P0R:bP0400O
:2D06b@Q01lU8`0P9R@092XX01@J600L8R005Q`J01LM6`0N92406QlK01dR7P0J7a/07B8N01DJ5P0M
8Qh201TN6P0K01XO6`0M8Qh08bPT02P/;0093@h07R8U01@H6P0F6Q/05QXL01LK7P0H71d0>Si008:6
R@0;3a004aLH01DG4P082@<05aPC014C3P0L7QT09bTT020R7@0F61<051D@01TJ5@0F5a805AD@0080
4a8=01H051<>01@C3`0E50l05A@@00l>2P0I61<051<>010?2`0L6aH03@`901TI5`0D51803Ph<010?
3@0B4@l051<A01LF500@3`d081lM03<b<00D4a4061LE0P0D4a42018A3`0A014@3P0@3`d030/900h=
2`0J6AL03Pd;01<B400F5A<02@D401<?3P0H51<04@d<01TE500D40l040`;01HB4@0B3Pd00P0A3@`0
1@091@@04`l>01PD4`0I5A@0510?00<04@d<0P0B3Pd0100@30/03@T800`81`0>2PT201<?3P03014=
300810<04`l>00<03@T80`0?2`X04P0@30T01P80014=2P0?2`P03@T6014=2P0B3P/03PX700l;200>
2PL0510=00d91P0>2PT02@D4010<2`0;1`H06QHE00L30P<02`L601D030P700H20@0:1`H03@T801LC
4P0:1PD03`/:020L6`0:1PD03@T800/71P0:1PD02`L600d9200?2`X040`;00l;2P0>2PT03@T800`8
1`0=2@P00P0>2PT0100=2@P03PX900h:2@0;1PH200h8200E00l92@0]9bL05@l?00h8200C3@d0618B
01H@400?2@T03PP8014;30050@805A8C00d;300;2`/05aLG02l_;`0000004Q4A0040000I5AH03@P:
00803@L70P0>20P200l92@06010:2P0P6QX01@0001@>3P090`<030H61P0=1`T600h82P030:ZTZ01Q
Fel040X>00802`D900<03`T=00/52@0<1PX00`0>20`00`0=1`/04@H<00h32@0201P=4`0800l42P0E
2Q004`P>01D:400<0@L02`0600X11@0G318Dooooo`006oooool02P0;41<02@hA00lC5P0B5QT03a8E
010A5@0?41@0410D010?500>3A8200d<4@0>014A4`0;2`d05QHH01XJ700@41803@d?018B500=3@l0
6ATK010@4P0e=CL030`>00l?3`0?40l200h@3`0900d@3`0<4@l02a8?018J5`053``02A<@049<B@0S
:BL04Pl>00804Ph=00`040l=00l>300>3P`03`l=00T;20082PL04AHB00`B3P0A5Q803a0;00d>2@0>
3`X2014B3@0E010A300=3PT03Pl:00l@2`0:2`H030d800l@2`0E5Q401PL301@E400>3``04Q<>00l@
2`0=3PT051D@00h?2P0D5A002``7010A300?40/03Pl:0080414<00X03@h900/<1`0=3PT0414<014B
3@0B4`h051D@018C3P0?40/0414<0P0A4Pd05@0@4@`03@h901<D3`0?40/03a0<00`=200e=S40DE9=
00T:1@0M7QT0>CXe01<D3`0=3PT030d801@E400A4Pd02``700l@2`0>3`X03`l=010@3P03014A3`09
010@3P0>3P`0410>00h>300?3`d051@B014A3`0<3P/02`d:00803a4>00@030h;00h@3@0A4a00418?
0`0>40d03`0;3@X03@l>00d?3P0>40l04Q@C01DG5P0?4A00EEMF018D4`0?4A003Q0?01@F5@0;3@`0
3a4@010B4@02014C4P0;010B4@0?4A004Q@C00lA400<3Pd03@l>018D4`0E5aH02P`901PJ5`0720H0
0P0>40d03@0C5A8051HC010B3`0C5A803a4>00P:1`0B5140410>00d=2`0A4@l04a<A018B400E5A<0
0P0B4Q00600C4a404Q8@010@3P0?3`d04A<@00lA3P0@4Pl04Q@A010B3`0>40d04A<@01LI5P0?4@h0
418?01PJ5`0C5A80418?01/M6P0I6aP04aDB00h@3@0:30T04Q@A014C4080418?00H03Q0=00h@2`0A
4`d041<<00lB2`0>4@X200d@2@0;01<F3`0?4P/04A@=010C300C5Pl05QPB01<E400H6QD03Q0;014C
3P0G6A@00`0B50l0100C5A0051HA01<E400C5Ph301@G30@04aH;01H04QD:010C200?4PL03a8700hC
300E7AH06b4J014F3P0@5@/051T=00dC1`0D70l05b4F041=@P32dLL0Kgif01PO600L7aP04aH?01LJ
4`0M81T051L@100F6A80100E614051L@01DG4P0F61<201<E400501PJ5@0E5a806A/F01PJ5@0F61<0
0P0E5a80200G6A@03a@>01XO6@0H7AL05Q/E00`A2`0M8Q`05AXD0P0D6A<0100F6aD05a`F01HK500K
7QL201dP5`1901`O5P0M81L07b8I01dP5`0I71<061/B01/N5@0M81L06R0F01PO600K9Ad0@Ta402/e
;@0J91`0628J01TS6`0nB400/K^c05IPF00O:B407BLO01dX8@0L9b008RdV02<^9`0Q;2D092lX01lZ
8`0R;BH08bhW028]9P0S;RL0934Z02Pd<00S<c00830]03];B00^@Cl07S4_02Li>@0Y?C`0:3`k02Lk
?00W?3d0:Cho02/o?P0/@3l0<4A302Tm?00fBTT0FVi]03M;BP0[?ch0<4A303=7AP0^@T40;d=10395
@@0jCDP0=4M202i1?@0[?cd0@5AB03A8AP0`AT@0>4i<03eCD@0gCdh0=Ti?045EF`13Eeh0@UIM04=G
GP0204EIH00Q04MKHP1:GVD0AUYQ04EIH012EUd0@5AK04=GGP18GF<0FFic04MLH@0oE5L0C65S04UN
G`16G5X0@eUG04UOG01:H5d0AeaM04YOI018GF80CfAY05AYKP1>HfP0CfAY04aQIP1DJFh0H7Ej07>8
S@1HKG80FFea04ePI01?HVH0Ffia0080FFe^00@0EFUY05Q/J`1EJFL0GG5_0P1GJfT03`1UNGl0I7R0
05iaN01WNh00HgMm069fN@1UNGX0IWYk06QmN`1ZOgd0Jh1o06f2P01WO7d0JGio06^0P@0206YoP00:
06f2P`1[P840KX>40766Q`1_Ph@0KH6206^0P@1[P7l0K86006n4PP80LHJ30240L8J00726P@1aQh80
LhV10767P01^Q7`0JWmf06b0M@1_P7D0KGif07J7P@1lSHT0Jg]j0761P01bPX00LX9o0721N`1]OWL0
J7]e06QkN01QM700GW9X05e]H@1EIE<0EVE@05ASCP1IJEH0E6IF05QZG@1<HEP0C65K04mTG@1>He`0
0P1=HU/01@1@IEh0DVMP04iSG01<HEX0Bf1I0080C65J01T0B5mG04ALEP14GEL0@5UC03aCB`0kDTP0
?EA:03mEB@0hCD40;d@h02a0=00X?Bl09CH/02@_;`0O:Rh08Bhd02@b>`0U=D80@51N0392C`0W=Ch0
:3Ll02/g=`0P:bH0:C@^00809c<a01/08bl]02@`;00T<BX08BhW02@a:00O;2<07R/R01PU6`0H9QX0
7R/Q02@^9`0G81X07BHP01`U7`0M9b0082TS01hW8@0L9Al05b0J01/T7P0L9Ql07bHS02<Y9`0R:2H0
7bDS01`R800M8b400P0K8Al02P0<4Q006R0N018H5P0I7ad07R<P01@I5@0O92006AhJ01LL600?5102
01TN6P0:01PM6@0G71P05a`H01TN6P0Z;Rh0720R02P/;P0G6ad04aLI01HJ70806QhP00D07R8T01PL
7P0@51H06alP01`L6P0201@E400701HG4P0G61<071dH01DF4@0C50l05QLB01TJ5@0201DF4@804a8>
0P0D4`l201DD400D01HE4@0I61@03Pd900d<200G5Q804a8>01<B400H5aD06aXH01HE4`0C4Q005QDC
00d<2P0K6QP0H5mM05eLFP0F5A<03Pd;010?3@0A40h2018A3`8051<A00L04a8@00l>300C4Q00R8N5
01PG5@0D4a405a<B00804Ph=00<04`l>00d9200E4A000P0E4A001P0?2`X040`;01@@3`0>2PT040`;
018>3@804`l>00<04@d<00h:2@0@30/00P0A3@`02`0@30/03@T800`81`0B3Pd05a<B00/71P0A3@`0
3PX9018>3@0>2PT03`/:00<040`;00d03`/:010<2@0B3P/02`L500l;200C3``02`L5018>2`0V8Ql0
;BTV01/G500D40d030P500803`/:01402`L602hZ:@0T8B0040d<01/G5P0A3@`03PX9010<2`0:1PD0
5A4@00`81`0B3Pd030P700`9200E4A0030T800d9200300`81`0700d9200?2`X040`;010<2`0?2`X0
3PX900d9200300h:2@0900d9200>2PT03PX9018=3@080P805a4A010:2P0?2@T03@L700803PP80100
4P`<010:2P0<1PH03@L7014;300<1PP02PL801<C4`0=3@d0Oh600<_=c011@d803`l?00X82@0A3@h0
3`T;0P0=1`L200h820803`T900H06A<C03Xd=00G4A403`T900h8200<1PH600d72@H03PP:01P05a8E
00h9300>20`03`T=00/52@0B310040X>00l93@0<1PX03@L;010:3P0B310091TO01873@0A1P`04`P>
00h32@0A1P`040D;00h42@0?10X040L;01@:3`0C20hDooooo`006oooool01@0;41<02`lB014E600D
61/0418F00803a0D00/03`lC00l>4`0A41D04Q4F014@5@0@41804a<E010@4P0>3Q00410B00h>4002
00d=3`0401XJ700=3@l01@D700`<3P<03`l?00d03a0?00h@3`0>40l02Pd<00lC4P083P`03aLD0088
1P0A5A@04@l=018>3@0A3@`03`h<00803@d;02403Ph<01`N6`092`P00@@103<h=01jOg/06a`G010A
300C50l03a0;00/<1`0A4Pd03Pl:00/<1`0H6A@05AHA00d>2@0E5Q404A8=01/L5`0I6QD00040014B
3@0D5A002``701<D3`0=3PT05AHA00/<1`0:2`H0414<018C3P0<3@P00P0?40/02@0=3PT04a@?01<D
3`0@4@`061TD02LX8`0P8A`03Pl:00l@2`04010A300F00X;1P092PD061TD00D60@0D5A00<c@_0042
000=3PT0:BXU00D60@082@@03Pl:014B3@0:2`H061TD02d^:@0M7QT04A4?010@3P0?3`d03Ph<00l?
3@804A4?01404Q8@00l?3@0>3P`04A4?00d=2`0@4Pl030h;00lA3P0E5a@04aDB018D4@0<3P/03Q0=
00lA3P0;3@X030h;01@F4`0200h@3`802P`;0P0@4Q4020010`803@l>01LI600B51<01PP701TK6P0=
3`h0418A0P0B51<06P0@4Q403@l>010B4@0>40l03@l>00h@3`0B51<05ALF01@F4`082PL00P@1020R
7`092`P05QPE00h@3@0=3``02`d:010B3`0G6AH04aDB00h>300J6QP04a<A00`<2P0A4@l051@B0P0@
40h2014A3`803`l=01803a4>00h@3@0?4@h04A<@00lA3P0=3``04Q@A0002000I6aP03@l<00`>2`0=
3``051HC01DG500?4@h03@l<010B3`0?4@h2014C4080418?00<03a4>00lA300B50h00P0A50d02@0@
4``03a8;00lB2`0D5a002Pd600hA2P0D5a006A`E01`N6002018D3`0B00d?2P0C5A0061XE01@F4@0C
5A003Q0;014C3P0E5a804Q@?00lB2P0=40D02`h300d@1@0?4PL03A0500hA1P0B5@X04A@90P0@4`P0
4`0A50T04aL@00L>1`000`003A4901LJ4@0?4PL04QD:014G2`0A6@h03AP>01/X7P0N:R803Q<=01PK
500@4``06A`E01XM5P0B5@h00P0F6A8301DH4@0701HI4P0G6A@05aTD01DG4P0D5Q405ALB01@F4@02
01HH4`0B01DG4P0G6A@06A/F01`N6@0C61807B8L01hS7@0E6Q@041D?01DJ500F6aD05AXD01HK5@0H
7AL06QlI01TN600G6Q<06QdD0P0K7QD05P0L7aH07b8I01dP5`0I71<07B0G024T6`0N8AP061dF024X
8@0D7QH072HN01PR6P0G8AT06bDM020Z8P0C7AD072HN01DO5`0U;bL082XR01hY8`0M:28201lZ9080
7RTS0P0Q;2H0200S;RP09C0Z02@_:@0P;BH07bh[02Dd<@0N;R/0:CTf0P0bAD<02@0V>3P09SXi02Hj
>@0V>S/09CXk02Hk?00/@3l0:3`k02e1@00202i2@@0D04=GEP0cAdH0;T910396A@0V>ST09c/j03I:
B00^@Ch09STe02Dh=00dAd<0RIfK0=CXiP11EE<0<TQ603=9A`0nE580@5QH03iFF010E5X204AHG`0M
049FG@13Eeh0AEUP051TJ`17Ff80@5AK04QLH`0oDeX0?U9I03Q<D`0nDeP0HGIk059WK00nDeH0AEYL
04EJF`13FEL0AE]I04YPGP1;HEh0Bf1Q04IKH01;H6D0BUmT04MLH@1?I6T0DFI[05=XK@1LLGH00P1?
I6T03`1HKG80FVib05EXK01OLWH0H7Af05IZJ`1KKg00F6a/05a`K`1HK6X0Gg=a061dLP1IKF/0FVec
06EhO`0206YmP`0;05mbN01QM7P0J7am06QlO@1WNgX0JGel06]oOP1^PX40JGel06]oP01]PH800P1/
P8401`1_Ph@0L8B50765QP1_Ph@0K82107:6Q`24V9T00P1cQhH307:6Q00<07:7PP1cR8<0LhR307:7
P01`QGh0KhAm06j3NP1eQW`0Kh1g06]lM01_P7X0MHF30P1`P7l04`1cPh40M8B107:3O@1]OWH0IWYa
06MjM01NLVX0F6aP05UZFP1CHe00CEa705]ZE@1NKUX0DfIC05EWF@1=HUL0DVMP05=XH@1@IEh00P1=
HU/0101?I5d0DVMP04mTG@1;H5T204QMEP0e04UNE`18GEH0@EUC04=LEP10FE<0?EA<041GC@15G580
@5I:03Q<@@0aACX0;T8f02Lk;`0P<BL09C0_01hY;@0P;C<08S0h02Pi@`0hB5D0?TiJ03M5CP0]?440
9c8b01`W8`0S;RP0930]028^;00W<c40930/020]9P0U<R/0934X01l/8`0N:b806RLM01`Y7`0R;bH0
9RlZ02L`;@0R:bL08b`W02@]:P0T;BT09c0[02H_;00M9R807RLR028[:00R:RL082HT01lU8`0L8R00
0P0I7ad03@0O9B<0<CLe01/Q7`0G7A/07R@R028X9P0G71T05AXF02<X900I7QX05a`H010E4@0I7QX0
0P0L8Ad06@0H7AT05a`H01LL600M8B004QHG01/O800G6a`08RHW03Tm?P0B5QL05QXK01TM7P0J7Ql0
51PI01DI6@0E5A<071dH014B3@0J6aH04a@?01HG4P0C50l061TD020Q700M7QT00P0G61<601@C3`0B
014@300D4`l061LC00l>2P0C4Ph04A0<00d<2P0C4Q0061LE01@C4@0A40h04Q4?010?3@0F5A<0Ogil
06i]J`0D4a403Pd;0P0D4a42018A3`0G014@3P0@3`d03Pd;018A3`0D4a409B@R014@3P0M71X04`l>
01@@3`0?2`X05A4@00d9200G4a8040`;014=300C3`h05a<B01<?3P0:1PD03`/:00d9200?2`X00P0B
3Pd01@0=2@P04`l>01<?3P0C3`h04Ph=00804@d<00P03`/:01LC4P0A3@`03`/:00X61@0K5aH03`/:
014=30804Ph=00T040`;00h:2@0A3@X02PH301@@3@0B3P/01P80010<2@091@800P0E4@h05@060P00
2PH300X60`0=2PT04Ph=010<2`0Q7A`081`K00d9200F4Q403PX900X61@0=2@P03`/:01<?3P0N6QT0
?c/j01<?3P0<20L05a<B00`81`0200d9200400`81`0=2@P03@T800h:2@803@T800@030P700/71P0;
1`H03@T80P0>2PT01P0=2@P03PX900h:2@0A30/01P0001@>3P8030H600@0208200d71`0?2@T040X:
0P0?2@T03@0C3@d03PP9010:30091PH03@/<00/;2`11@d80Kg5`01lQ800920T030P901@@4@0>20X0
1P0>20P01P090`<050h>00/51@0B30`01@0001<=3@H03@L91P0>20X0200G4AD05Q0D00l93@0=1`/0
3`T=00X4200=1`/030H:0P0:10P03P0=1`/03`T=01hC6@0B1`d04@H<01<83P0A1P`04`P>00l42P0=
0PP060dC01X?5@0R5ad04`P>5?ooool001_ooooo01P03a@G00dA500A5AP04QHI00h@500=3Q803PlC
00`<400;2Pl03@`A00l>4`0=314020P:018B500@41803Ph@014A4`0<30h03@d?01DE5`0<30h0410B
00X:300@4183010>3`0:010?3`0?3`l03Q0?00h@3`0;3@`03A4@00X?3P0@51<03@l>014?3@<03`h<
0P0=3@/0700:2PP05ALD00X<2@0J71T0N7ei0=?He00K71L0414<018C3P0>3`X030d8018C3P0;30L0
51D@02d^:@0/;BP03Pl:00L80`010P002P/600H7100j>cH04Q<>00L8100:2`H04a@?00T:1@0C50l2
00`=2004010A300A4Pd02P/600l@2`80414<00P051D@01<D3`0?40/05AHA028S7P0M7QT03Pl:00l@
2`80414<01/03a0;01@E400=3PT01PL201DF4@0D5A004Q<>01dN6@0?40/03Pl:01@E400>3`X04Q<>
010A300B4`h020T4014B3@0T9B004A8=014A3`0@40h03Ph<00d=2`0>3P`04A4?010@3P0B4Q000P0@
40h0700D51804A4?018D4@0;3@X03a4>01/M6P0J71T0418?00d?300C5A805ALD00d?300@4Pl09BLT
01DG5P0D5QD07b4P01hP7`0@4Q4061XI01`N7@0C5A@020X900lA40082PT04Q@C00`>3@0>40l2014C
4P0400h@3`0<3Pd03a4@010B4@<04A<B01D03a4@00h@3@0=3``06adJ01PJ5`0A4a003a4>00d?300?
4@h020X700T;200@4Pl03Q0=00T91`0D51802`/900T91`0C4a404A4?00l?3@0@40h00P0A4@l0200@
40h03`l=00lA3P0>40d03a4>014C400?4@h03@l<0P0@4Pl0200?4@h03Q0=01@F4`0=3``05ALD014C
400:30T02`d:0`0A4a03010B3`0300lA3P0?4@`04aH@00<04QD>0P0A50d03@0R9Ah03A0900hA2P0A
50d03a8;00X<1P010`003a4<01HH4`082PD04Q@?01dO6P0F61<00P0?4@`02@0C5A004A<>018E3@0A
50/03Q48014D2`0C5Pd041<:00lB2@02010C2P0C014D2`0B5@`04aH=01XN600<4@/04A<>02h`:@0R
8a/05aT>01PJ3`0=40D04A@;01PP5`0@718051lH018G4@0C5Pl051L@01PK5002018E3P8051L@100E
614201DG4P0501PJ5@0G6A@051HA018D3`0E5a800P0D5Q402P0F61<061XE01/M600H7AL07R<M024V
800M8Q`05Q/E01<H4P0G71H201HK5@0501PM5`0I7QP061dG01DH4@0H6a@00P0I71D06`0J7AH07B0I
01/N5`0I71D08bHO02HY8P0O8Q/06AhG01lV7`0I8a/05b4I01dW7`0H8QX06R@L018L500S;BD08B/S
01lY8@0P:R806R@L02D`:P0S<2T07b`U01dZ8`0L:B806BHO020]9P0201h[900=024^9`0T<BX0934Z
01d/:@0W=c@07bl/020`;@0bAD<0>4]902@f=P0T>3L09CTh02Pl?@0202Pm?P1=02/o?P0Z?Sd09c/j
0314@`0X?3/09c/j02e1@00_@d80<dM60355A00[?ch0;40n02<f<`0gBTH0>di:02m2@017FeT0HgMe
03eAD00dBTP0<TQ603Y?D00oEeL0@5QJ03Y?E@13Eeh0AEUP04IJH@1:GVD0BemV059VK@16FV40@EEL
04YNI@12EUd0AEYP04MLH@0oE5T0AEYN04QMH019GV40CF9T04=HF@12EeP0AeaL04YPGP1;HEl0CF9T
049GG017G640FFic05]`M@1FJg00CV=X04mTJ@1BIf`0Fg1e05mdN@1PMGX0DFEY05Q[K`1[OX80Jgn1
05U]KP1GJf`0E6QX05mcLP1KKfd0GG5_05ibL01MLG00GW5e06AgO@1SMW`0IgZ0069eN@1XNgl00P1W
Ng`01`1VNWT0Ig]j06UmO01/P7l0JWim06b0O`1^PX400P1]PH00301`Q8<0Kh>206n3PP1^PX40L8B3
07fAT02FZZT0N8b;07J:R@1bQX@0LHF307:6Q080MX^600X0M8V40766O`1`QGh0M8V207N<P`1fQgd0
Kh1g06ioM`1`PG/0LH5o0P1cPh80101eQH<0MHF207>4OP1]OWH206IjL@0C05eaI`1DJEX0EVME05IV
DP1AH4T0E6=<05QXE01EJ5D0G6iP05=XG@1AIUd0EV]T05=XH@1?I5d0CV=L04mTG@1@IEh0CfAM04YO
F00304MLE@0d04EJD`0kDTX0>U5903]BBP0nEDd0@EI=041EC00lDDP0<dLl02/o=00Z?S<0:S``02Hf
;00T;bh072L[024^=00U<S/0:CY402hoB@0iBU<0<d9902Pg>P0Y=C@08bhZ02Pc;@0S;b/08BdY02Te
<@0V<Rh08BhW02Pe;P0N:b@06bPO01`Y800K:1l07R/Q02@a:00R:bP09c0_020Y9`0P:BH07bPW02</
:P0^=c@0;CHe028[:@0M9R<072DT01dU8P0N9280728P01/Q7`806AlM01005Q`J01LM6`0;4@l08RPV
020V900K8Al04aTF014F4P0M8Qh051TE01PM6@0A5Q8061dI01`Q7@0N8al06AhJ0P0J7a/04@0E6AP0
2`l@01<G600A5AH041@E01lS901LH640S92A02L[;00D61T061`M010D500A4@l07QlJ01DF4@0I6QD0
4a@?00805AHA00D07AhI02@U800L7AP05aPC01HG4P0601@C3`08018A3@0F5A40;RdY01XI5@0K6QH0
4a8>014@3P0@3`d2014@3P08018A3`0A40h04Q4?010?3@0E51802@P601LF500>3@/201@C4@804Q4?
00`04A0>010?3@0B4@l03`h<01dL6P01000061LE00H50`0;1`H0510?00l;2P0A3@`201<?3P09014=
300?2`X04Ph=01@@3`0A3@`03@T8010<2`0>2PT03`/:00804`l>00<03`/:01<?3P0C3`h0100B3Pd0
5P091@@061@C00@0000E4A004Ph=00/71P0@30/04@d<018>3@0A3@`03`/:00h:2@0B3P/05A4>01/G
500=2@H00`0001<?300E4@h040`900h:1`091@<201PD4@04014=3@0E4A008QhM06]WIP800`0000`0
2`L600d9200<20L04@d<01/G5P0R7Qd00`0001LC4P0:1PD0100000/71P0A3@`200d9200300h:2@0=
2@P03@T800@03PX90P0=2@P300h:2@0:00d9200>2PT03PX900d81`0=1`L03`T900`61P0S7Ad03`T9
00d71`<040X:00h04P`<01D?3`0C3@h030H8014=3P091`P030`<00L9200H6QT010H5010?3`0<20T0
4@d>00X41PH03PP800H03`T9014;2`0:1@D050h>00L10@0?2@T600d72@H03PP:00@01@0300l93@0B
31002P@80P0=1`/00`0:10P02`D900`62P0300`62P0<00l42P0D2@l06@hD01H;4@0A1P`04`P>00h3
2@0A1P`02`0600L00P0@1P/050T?5?ooool001_ooooo00T04QLJ00dA500>4QD03a<F00`?4P0=3Q80
6AXN018B5`0?3Q<00P0A41D00`0=31403`lA00l?4@0200h>4008014A4`0B4Q@04Q8D01TI6`092@/0
3Ph@01TI6`0=3@l4010>408040l@00H03@d>018A4P0A4Q<03a4A01DF5P0<3@d200l>300;00h>300>
3@/03@d;00`<2P0B4Q002P/900d>2`0@4Pl03Q0=01hP7@0A4Pd00P0<3@P03P0?40/04A8=014B3@0B
4`h02``7014B3@0G61<0414<00d>2@0D5A001@H201/L5`2PXI`0ATM20P0A4Pd01@0O81/03@h9014B
3@0=3PT04A8=00803@h900`03a0;010A300?40/03@h900h?2P0?40/03Pl:00`=200=3PT03Pl:00d>
2@0>3`X300l@2`0:014B3@0?40/03Pl;00d>2@0>3`/04a@?010A3@0?40/04A8=010A30804A8=02@0
20T4014B3@0@4@`02``7014B3@0B4`h0410>00l?3@0>3P`03@d;00h>300@40h03Ph<010@3P0A4@l0
4a<A01PH5P0F5Q@03a4>00X<2@0?4@h05aTF01<E4P0<3P/02`d:010B3`0B51402`d:00h@3@0O8Ah0
3Q0?018D4`0X:RT09bTX00lA400@4Q42014C4P0500d?3P0@4Q40418A014C4P0>40l0100?4A000`0>
40l0418A014C4P02018D4`0:010B4@0=3`h02`d:014C400?4@h06adK010B3`0E5a@03@l<010B3`80
4Q@A00D03a4>00`>2`0>3P`04A4?010@3P02018B400500P81P0@40h04A4?018B400C4a400P0B4Q00
4P0A4a003a4>010B3`0B5140418?00h@3@0A4a003a4>00P:1`0M7a`04Q@A01PJ5`0@4Pl04A<@00lA
3P0B51404aDB00lA3PD0418?00<0418=018D3P0B5@h0100B5@h02`0H6a@03A09014D3@0B5@h04A@=
02PZ900K7AP03Q0;01DG4P0?4@`04Q@?00805aTD00H04aD@018D3`0C5A004aD@01<F3`0C5Pd2018E
3004014D2`0@4`X04QD<018E30804A@;0P0B5@`0600@50d051TC02DW8P0c=Bh05aP@00d<0P0F50/0
5aP>01LH400?4`/041P@01@L5P0D6A<030l801DH4@0=40T07B0I01/N5`0B5@h04aH?01LJ4`0H6a@0
5aXC01@G408051HA0P0I6aH0100D5Q405ALB01LI500F61<201DG4P0;01HH4`0I6aH04AH@014F400G
71H06AhH01HK5@0U:R@05a`F01HK5@0E6Q@00P0F6aD01`0D6A<05a/D01TM5P0I7AH061`E01TM5P0K
7aP00P0I7AH202<W800K01hR6`0V:b@07bHO024[8`0?6A407BLO01/U7@0]=bl082XR01PR6P0P:R80
7BLO01TS6`0T;bL0:3<]02Pd;`0P;BL07RXU020]9`0L:2<07RXU024]:00Q;RP082dW028_:@0U<Bd0
7RdZ00808S8_01408c<`02Xm>`0P<c40:3Xj02Hj>@0W>cX0;41102a1@P0Z?d00;40o0355A00W>cX0
:cln02e1@00bATD0<DE402a0?`020396A@0703A8A`0nDU40;T4n02Tl>@0aA440:chl03=7A@0202m3
@P0M03I;B`0gC4`0?55B03eEEP0jDU@0@EIL049FG@0oDeX0?51G04AHG`1;GfH0A5QO04=GGP1:GVD0
B5aS04=GGP13Eed0FFib05aaM@1<HFD0AeaO04]PH`1>HfD0@eQI049GF019GUl0BUmO04]PH01=HV@0
0`1DJFh204QMHP0Z05M/L@1WO840FVmd05AYKP1;H6D0FFic05Y^L`1FJFd0GG1d05M[K@1DJ6T0Gg=d
05ibLP1PM7<0HGEc06QlNP1SMgD0HWIe065dM`1UMgX0I7Ij06aoPP1WNWd0J7Ym06UlOP1ZOGh0Jgin
06aoO`1]P7l0KX6006f0O`1^PH40L8>306n2PP1`Ph80LXF507B7QP1dQhL0LhJ50764Q01cQXH0NHb;
0P1gRXT08P1eRHL0M8R607F8QP1gRhL0Mh^607F9Q01cQh40LhN007J:Q01iS8H0LX=k06n0N01hRH<0
MhN406moO@1cPh80MhN607J6Q01cQ7h0Kh1h06UjL01RMV/0HGEY05idI@1CJ5L0DfAB05EUD@1CHT`0
D5m904eMB@11E440AeU904AIC@1:H5D3055VGP05051UG@1?I5`0CV=K04eRFP1:GeL00P17G5@06P15
FU80@EI>03iEC00jDDP0?EA;04EKD`11ETd0>Tm603I;@P0`@cT09SP_02<f:`0/?C80;She02Td=00^
>Cd0=D9802llA00cA4d0;d1903A5C@0/>d008S4c02lk>P0U<2`07BPS0P0P;2L08`0T<2/08BdX01`Y
8P0N:b@062DN01PU7@0L:B406bPO01`Y7`0Q;RH07RLV024Y:P0R:R/08BTZ020X:@0K8b@072@U01lW
:00O:2P08BXZ020Y:@0N9B@0728P01XP7P0K8Al0728P01/Q7`0L8R005adK01<I5`10AT@082HT01@J
600K8Ah051TE0080724M00H0:c0/01hS7`0H7AT0724M01dR7P0E6QH201XO6`0:01@H5P0E6AT06QhN
01PL700?4a<07B4Q06Q/K02BUYH08bLW01/O7`805QXJ00L05aLE01`M600J6aH06AXE028S7P0D5A00
5AHA008071dH0P0D5A00100C50l05A@@01DD400E510201@C3`0@01<B3P0E51003`h:02XY9@0C4Ph0
5QDA010?2`0D4a404Q4?010?3@0A40h04a8@01@C4@0A40h03`h<014@3P8051<A00<04A0>010?3@0A
40h00P0B4@l301@C4@0<01DD4P0<2`T05QDC00T81P0K6QP0>SHe018>3@0E4A0030P701@@3`0=2@P0
5Q8A0P0C3`h00`0A3@`03PX901DA4004014=3006018>3@0C3`h040`;010<2`0>2PT03`/:0P0@30/0
200N6QT0EU9A01HB4@0<20L06ADD00h:2@0A3@`03`/:0P0>2PT200l;2P0L014=2P08104030P502hZ
9`0M6AH04@d:00h:1`0:1P<03@T600h:1`0C3``030P6010=300;20L03``;01PE500B3Pd04Ph>01<?
3P0@30/030P700/71P091PD04Ph=01HC4P0m>CP0510?018>3@803PX900H03@T800h:2@0?2`X03PX9
00d9200?2`X6010<2`803PX900T03@T800h:2@0>2PT03PT800l92@0A2`/040X:02PR8P0D3Ph00P0?
2@T0400>20P03`T9014;2`0B30`05@h?00H10P0>2PX02PP800L51P0C51804Q<B00P81`0:20P030P8
00T41@0C2`d300l92@803PP800L03@L700X4100F41003PP800/51@0>20P03`T900H03@L91P0>20X0
1`0R72005@lC00L11@0=1`/040X>00P21P0<1PX00`0>20`03P0?2@d03PP<00`11`0E2Q0060dC01<8
3P0>0`T03`@:01D:400A1``040H;03db>00e:S003P@95?ooool001_ooooo01P041DH00T>4@0:3Q40
310C00d?4`0A4QH05QLK00l?500=31404A0E01<B5`0@3a@04A4C00d=3`0D51H05ADG00h>400=3@l0
4A4C00d=3`0F5QP02PX<01/K7@0;2`d6010>4@08014?4P0K6A`01P@701HF6000008071`L00h>3@0>
3P`200d=2`8030`:00H03Ph<00@40P0D51809RHT01@D4P0820H2014B3@0>00X;1P0@4@`051D@00d>
2@0?40/05AHA014B3@0?40/03Pl:00l@2`0>3`X051D@00`=200B4`h200`=200D01TJ5@0/;BP051D@
014B3@0;30L0414<00P910092PD05aPC01<D3`0<3@P03Pl:00d>2@0;30L030d8010A300A4Pd03a0;
00d>2@0>3`X300l@2`0B010A300:2`H04a@?01DF4@0720<02P/600h?2P061`803Pl:01dN6@051P40
414<01DF4@0?40/030d8014B3@0B4`h030d81P0>3P`03P0@40h04A4?00h>300=3@/03`l=00/;2@0<
3P/03Q0=018D4@0=3``020X700lA3P0A4a00418?0P0?4@h200h@3@0>00h@3`0D5QD051HE010B4@0C
5A@03@l>00X<2`0>40l04A<B00X<2`0<3Pd00`D4014C4P0@4Q4200lA4004010B4@0A4a804A<B010B
4@803a4@01H04A<B018D4`0I6aP03Q0=02<U8P2k_KX08bDR018D4@0H6QL030h;00h@3@0A4a003Q0=
00lA3P0>3P`02PX800`<2P0?3`d0410>018B400A4@l04Q8@100C4a404P0B5140418?014C400C5A80
4A<@00lA3P12A4407b4N00`>2`1PHUl0CU1=00H81@0C5A804A<@00h@3@0D5Q<06A/H01LI5PD0418?
00<0418=00lA2`0?4P/0100?4P/06`0>4@X04aH?01<F3`0<3`P041<<01TK5@0B50l051HA018D3`0A
4`h05ALB00d?2P0>40/04Q@?01@F4@0B50l04A<>014D3P0D5`h05QT@018E300?4PT04A@;01DH3`0F
6A0051L>014D2`0200lB2@0Q00/?200M8Q`03a4<00h@2`0N7QH04Pl601XG3P0A3PD030`401`N5P0A
5Pl03a@?01PJ5@0@4``06ahG018E3P19C4D0?3lh014D3@0D5a006QdF01`O600J7AH05APA01HH4`0C
5A005aTD01HH4`0B50l06A/F01XL5`0I6aH05aTD00805ALB00T05aTD01/P6P0E6Q@05a`F01XO6@0`
=Bl0L7E_01/P6P0I7QP00`0G71H0100D6A<05AXC01LL5@0G71D201DJ4`0E01HK500K81T061dF01hS
700K81T07B8K038i<@0i@c/05R0H01<M5@0U;bL03aTA061ZHP0I8a/07BLO01hX800@6Q808B/S018M
5@0L:2@082`X00806RHR02`08BdY01l[9`0M:BD09S8^02Te<@0T<2`082`X028^:P0U=340;Shk02`l
>@0P<2d0:chl02Hi=`0Y>c/093Pg02Hj>@0Y?Ch09c`m02@i>P0_@d809CTh02a0?`0eBDP0;40o03=7
AP0[?ch0<4A303Q<B`0^@T40LXJ50<?GeP14EeD08cHd03=6A00bAD<0<dM602e1@00cAdH0=4U:03=8
B@10EEH0AemQ04ALGP80?E5H01<0?51G04MKHP1SMgh0HWIm041DF`1=HFP0H7Ak059VK@1>HVT0B5eQ
04QMH012EeX0B5eP04aQI012EeX0AEYL04=HF@12EeP0Bf1Q0080BEiO0240CfAX05EZK`1?I6T0QIZO
08fRY`1KL7D0D6EZ06^0Q@1BIf`0GG9g05Q]LP1GK740Ffmc05Y]L@1OLWH0FFa_05M[K01LL740GW9b
05ibL@1TN7H0NHf;06f1O`1RMW@0J7Yj06YlOP1UMgT0J7Yl069dMP1SMGL0JWan06]mO`1^P8000P1_
PH4206j0P00b0722PP1aPh<0LH>30763P`1dQXH0NH^;07N9R@1fR8P0NXb<07j@T021Ti<0LH>307>5
Q@1iS8X0NXf;07R;R@1dQh<0LhJ207B7P`1gRX@0MXV307>6P01`Pgd0LX=k07B5OP25UY00Pi>@07>3
P@1gQhH0N8R707F5PP1^OgL0JGY`06AfJP1NLf@0FVmP05meI01FJeP0DV=@055QC@1>GDP0>dXe051P
C@1CIED0DF=E03]@A00iCd<0AeaC04]PE`1?I5/2051UG00b04iSFP1;H5L0BUmF04QME017G5<0@eQ?
03eBB@0nED/0?5=903mFC011ETd0>4e40356?@0_@cX0?4e503Q9@@0^?cD0:CX`02Pg<00P:b`0=d96
03e;CP0X=Sd0;d1702/l@`0`@DL0:STl02Lg=`10C4/0<C`h01dX900K:2407b`U01h[900O;2D07BXS
01XW800K:2407R/T028_:00O;2<07BXQ024^9`0O:2P072@V02<[;@0N9RP06b<U01lW:@0P:2X201hV
:00E024Y:`0N9RP06R8Q01XP7P0H7Q`06b4O01hT8P0M8b4061hL02L]:`0M8b406AlM01DK6@0J81h0
61dJ010E4@0G71P08BHR03Pm>@0S:2@05a`H008082DQ00D05AXF01TN6P0J7a/061`J01/O7P02018F
5@0501dQ801;Cdh051PG02@X9`0H71/00P0I7A`03@0=4Pl06ATG010A300F5a8071dH03Pi=00I6QD0
5AHA01TJ5@0E5Q40414<01@E400E5Q400`0E51003`0D4`l04a8>01<B3P0Q81`030/701HE4@081`<0
3`h:01@C3`0;2PP040l=01@C4@0?3P`03@`:01@C4@0201DD4P0400X91`0D4a4030/901TH5P8051<A
0P0B4@l0100A40h040l=01@C4@0>3@/200l>30806aXH00X0Pgmn01@@3`0P71/040`;01<?3P0?2`X0
3@T801TE500U8B007QXI0P0>2PT0500?2`X04Ph=014=300>2PT03`/:01<?3P0A3@`040`;00h:2@0?
2`X04@d<018>3@0?2`X081`K00<0000A3@`03PX900`81`0B3Pd03@T80P0;1`H02`0>2PT040`;00/7
100C3``06QHC018?3@0300005Q8?00d91P0B3P/05Q8?008040`901P01`<000/81`0W8b800`0000d9
200H51<0510?014=30091@@030P701HB4@0<20L04`l>00<0000Q7A`03@T8018>3@0810<03`/:00d9
200?2`X040`;00l;2P0=2@P600`81`<03PX900X03@T800h:2@0>2PT04Pd<00@0000E3`l03PP800X4
100;1@D04@/;0P0?2@T03`0@2PX04P`<014;2`0>1PL07A@E00`61P0I5A@02`X800D5100000004A4?
014>3@0<1PH03PP800h61P0300l92@0900h8200=1`L03@L700h8200:10@050h>014;2`04000040X:
00H03@L91P0>20X020090`L02`D9018<400>20`0208601D?4`0=1`/02P@80P080PH01P0<1PX03`T=
0146300@1@/0304700d220804PL=00H03P<901H;4@070080:1dS02DL800L4ALDooooo`006oooool0
2P0<4A@03Q<F00hB5@0;3a802Pd@00/<400<3A40410D010?500>3A8200`;400801DE5`0=3@l030`>
00h>400?3a404a<E010@4P0C4aD200X:300D014A4`0C4aD03Ph@010@4P0H61X020H901DC5P0A3a80
61HI03Hd=`0D4QD02PP;01LE600>3Ph03`l>00d=2`0C4a40410>014A3`0;2`T200l?3@80410>01@0
3`l=00h>300C51000040014B3@0D5A0020T400`=200G61<01@H100T:1@0=3PT05AHA00h?2P0<3@P0
2``700`=200=3PT030d800/<1`803@h900l03Pl:00l@2`0?40/05AHA01<D3`000@004a@?00d>2@0I
6QD02``700l@2`061`805aPC00`=200?40/00P0>3`X0100A4Pd04Q<>00l@2`0>3`X2010A30803a0;
00@0414<018C3P0D5A003Pl:0P0=3PT01@0F5a804A8=014B3@0?40/03@h900<03Pl:1P0>3P`02`0E
5A<0410>00l?3@0?3`d03@d;014A3`0B51401`T600lA3P0B514030h;00@04A<@00D0418?00lA3P0?
4@h030h=00d?3P02010B4@0D00h@3`0<3Pd030h=01@F5@0=3`h02@/:00lA400B51<030h=00X<2`0;
3@`03a4@010B4@0<3Pd020X9018D4`0D5QD0418A00lA400B51<200/=2P0F01<E4P0[;BX04aDB00h@
3@0D5Q<04aDB018D4@0A4a00418?00lA3P0A4@l04a<A00d=2`0>3P`04Q8@00/;2@0=3@/04Q8@01<C
4@0<30X04Q8@00`<2PH03a4>00h06A/H00h@3@0=3``04aDB01DG500C5A80418?018D4@0@4Pl030h;
00h@3@0@4Pl0EUQE010B3`8030h;00H07b4N00/=200@4P`051L@00d@2@0C5Pl201DH4@803a8;00P0
41<<014D3@0A50d03@l9010B3@0F61<04Q@?010B3@803a4<1@0A4`h0:`0@4`d04A@=018E3P0A50d0
41<<018E3P0C5Pl06A`E0002000I71D051L@018E3P0=4@/05ahG0002000L7QH04a<;01@A200F4`X0
4@h5014A2@0E5`l041D>01<H4`0E5a804aH?014D3@0F6A806A`E01LJ4`0A50d04aH?01@G400C5Pl0
5QTB01hQ6P0E5a807AlJ01@F4@0G6A@06A/F04i@B`0H6QD00P0G6A@02P0F61<05aTD01PJ5@0B5a40
41D?01<H4P0J7aT0724K01DJ500@5@l201@I4`0301<H4P0D6A<041D?00<05ahG00/061lH01TP6@0J
8AX061lH01`S700940T06B0I01XQ6P0T:b@06B<K01XT700201/U7@0301`V7P0M9al072HN00806bDM
00H08R`T02<]9@0D7aL06RHR02He<00>7AP201l^:@0F024`:`0M;2L0:CPc02/j=@0U=2l093<^02`k
=P1PKf`0<T4n01l_;00V=S<09cXh02`o?@0]?cl0:Cdl02Di>00aADH0:Cho02@i>P0/@3l0<TI50314
@`80<dM600P0;D500314@`0`A4<0;d=20355A00iCD`0?U9A03A7A@80;d9002L0=4I60355A00^@T40
>4a=0315B00bAdX0CF9U03]CE@14G5h0@EEL041DF`0iCE@0BEeT082DV`1iSI@0Ae]R04EIH01BIVd0
EVYa04iRJ@19GV80AU]L04=HF@12EeP0AEYK04UNG`1;H680DFIY05AYK01=HVD0Bf1S04iSIP1AIVX0
D6EZ05AYKP1YOX<0L8F:069gO01CJ6d00P1AIV/0301DJFh0EFY_05Y_M01IKG40FFa`05e`M01JKW00
Ffm`065eMP1UNGT0HGEd069fM080IGUg01l0JWil06eoO`1KKFd0RifM07>5Q@1MKfl0IWQh06anOP1[
OGd0Kh610763Q@1`PX@0LH>407>5Q@1eR8H0MhZ807F8QP1dQhD0MHR608RKV@1jSH/0M8N507N:R01e
R8H0NXf;07B6QP1cQHD0MXV707R;R@1gRXP0N8^70080MhZ602P0MXV307N:Q01cQX00JGaf06]lMP1f
QX80NHV607F5Q01cPh80MHF407N7QP1cPh00KGif06UjL01RM6P0Fg1Q05EZF@1HKUX0EfaI05=TD@1;
FdP0BUU603i=>P18EdL0AeU;03i@@P0eBSh0?59604UNE@1?I5/0EfaS09V^Y@1JKfH0L8El04MLD`1>
HeX0BUmF045FC@0mDTT0@EI=0P1:H5@06P0nE4P0=DY102/o=P0O<bX0;Slg02dn=P0/?CD0:CPa02@c
;00S<Rd09S4b03M2AP0e@dH0:SPm02Hh?00[?D40:S`o02dl?`0U=CD0930_02@_:`0P:bL08RlW01`Y
800Q;RD08BhW0P0J9b0201l/9@0F020]9P0Q;RL062DN020/:00S:b`09bla01hV:00O9bT08RX/01lW
:@0P:2X08RX/020X:P0N9RP082PZ024X:00H7Q`05Q`J01XP7P0G7A/06R0N01`R808061hL00@05Q`J
01DK6@0E6aT06R0M0P0J7a/04@0N8al06AhJ01DJ5P0F6aL07B8N01TN6P0B5a<06b0L01TN6P0@5180
61`K01TM700@51<0HVIU0>7Ui00k?ch061`K008051PG00h05a/J01TN6`0J6QP06Q/F01HG4P0C50l0
5AHA01<D3`0H6A@03Pl:01@E400G61<06AXE01@E40804Q4=0P0G5Q80200D4`l05QDA01LF4P0A40`0
30/7018A3@0E510040l;1P0C4Q000`0H5aD040l=00P71@0201@C4@03014@3P0B4@l04A0>008040l=
00@04A0>018A3`0C4Q004Q4?0P0@3`d2014@3P0501PD4`0:1PD05A4@01`H5`0B3Pd00P0?2`X02@0E
4A004@d<014=300<20L07ATH020L6`0?2`X040`;00d9200301HB4@0401<?3P0;1`H02PH501TE5080
4@d<0180510?00d9200=2@P07ATH00X61@0B3Pd04@d<010<2`0?2`X030P700/71P0B3P/00`0000l;
200N6QL0VYJC02XV8`0?2`P300h:1`803@T600`03@T8010<2`0>2PT04@d<018>3@0?2`X03PX900d9
20091@@03PX900/71P0>2PT500`81`803PX900<030P700/71P0<20L00`0>2PT00`0A3@`03`/:00h:
2@02010<2`0700P40`0?2`X0<bl^01HB4@0300003@P700d71`02010:2P803@L700X030H600/51@0>
20P04`d=014;2`0=1`L03@D600l61`0>20P03@T80P0<2`T02P081`D030/900l;2P0:10@0208200l6
1`0E3`l0100001TC4`04000201LA4@0<014;2`0<1PH030H600d71`0;1@D03@L7010:300:10H04P`>
00`620090`D030H81P0=1`T03@0<1PX03@L;00h8300>20`03@L;00`62P0@2Ph03@L;00`62P0>20`0
3@L;00X4200700800P0F2a401@0700803@880146300@1@/04@H<00804PL=00<04@H<01052oooool0
4oooool001_ooooo00D02PlB00`A500=4A@02`lB00/=4@0200d>4P05010@5@0B4AH040lD00h=4P0?
3Q<00P0C4aD01P0=3@l030`>010@4P0@41803`lA00`<3P804A4C0P0<30h04`0>3a802@T<010@4`0=
3A005A@H010?4`0A41@07adQ00h<400?3A40518F00`<3P0?4Pl03a0>00/<2P0?40d051@B00`<2P0>
3P`00`0?3`d04`0@3@`03`h<00l@2`0B4`h05AHA00l@300K71L030d802h_:P0G61<04A8=00h?2P0A
4Pd02``800d>2@0>3`X04A8=018C3P0?40/01P0>3`X0300:2`L07AhI00`=200N7aX051D@00/<1`0C
50l051D@00D60P0?40/03Pl:01HG4P803Pl:00D0414<014B3@0>3`X03@h900h?2P0200l@2`80414<
00d04A8=00l@2`0;30L04A8=01<D3`061`8092DP01<D3`0A4Pd03a0;010A300A4Pd0414<00H03Ph<
00`03`l=014A3`0?3`d03Ph<01<C4@0E5A<04A<@024S800k?CX051HC01HH5@0?4@h2014C4080418?
0P0?4@h00`0=3`h03Q0?00lA400200lA400600d?3P092`X0418A00h@3`0=3`h0418A0P0>40l0400@
4Q404Q@C018D4`0A4a803a4@010B4@0B51<02`d<00lA400F61L02@/:00d?300F61D020T700`>2`0?
4@h3014C40803a4>00D03Q0=00d?300<30X03`l=010@3P0200l?3@0701<C4@0A4@l03`l=01<C4@0B
4Q0051@B00`<2P0600lA3P0601HH5@0>40d03@l<010B3`0?4@h03@l<0P0C5A803P0A4a003a4>010B
3`0B5140>3Xg01@F4`0E5a@03Q0=01/M6P0>40/04A<=01@G400=40T04QD>0P0D5a00300A50d05APA
01LJ4`0F6A804aH?01<E3`0C5A00418=00h@2`0E5a8051HA018D3`804aD@00D04Q@?010B3@0?4@`0
4Q@?014D3P0200h@2P0E018D3P0D5Q004QD?01PK5@0B50h0A4M101/M5`051`@04ALB018J4`0E7QH0
310801@E3@0I6Q0061L=01HF300C4`/04aD=018E3P0G71L04aD@00804aH?0P0D5a003P0E61405QTB
01LJ4`0G6Q<051L@01<F3`0F6A805QPC01XL5`0C5A006adH01@F4@0B50l061XE0P0G6A@00`0F61<0
5aTD01PJ5@0201LL5P0F01/P6P0P9Al07R<M01<H4P0H7AL06b0J01TN600H7AL07B8L01hS7@0H7QT0
5A`F01LM600F7AL05Q`G01`S7@0H7aT05A/F024W8P0K8Q`07bHP01`S7@H06bDM00/072HN020Z8P0M
9al07BLO01lY8@0L9b409C8^01HU8@0W=S805bLS01h^:P0201d/:00A02<b;P0U=C408c<_02@c;`0X
=c<0;chk03A3@00iBDH0:SXg028e<`0[?S`09cTi02a0?`0^@T40:3`m0315AP0^@d@00P0cAdH0100_
@d80<DE40396A@0_@d820396A@0O0314@`0^@T40<4A30396A@0eAdH0=dU803E8A`0cADD0=4Q803I:
BP0fBT`0>TmB03eBE@0mDUH0?5AG055YK@1>HVT0D6A[04iRJ@19GF@0B5aS04UMI016FV40B5aS04mS
JP1<H6L0BUiU04YOH`19GUh0BUmO04]PH00204]PH@0c04]PHP1AIVT0E6U/04mTI`1?I6P0DVM[05=X
K01EJVl0F6eb05aaMP1JKg@0EFY_059WK01YOX<0NHjC05icN01KL7D0HgQm05U]L@1ML7@0H7=g061d
MP1PM7D0HWIg06AhN01QMG@0IGUg06QlNP1WNgT0Jgmm06aoO@1[O7X0NHZ906UjNP1TMG@0HgAc06am
O@1^Ogl0LX>30761Q01`P8<0LX>40763P@1dQH<0MhR607J8Q@1fQhD0N8Z707R9Q`1jRhT0Nhf:0080
N8Z700T0OHj<07R9R@1hRHT0NX^:07Z<RP1jRhX0NXb807V:Q`1hRXH00P1iRhD06`1dQX00KGmi06]l
M`1hR8D0MHF307B4Q01iRHP0Lh>207F5Q01`P7`0IGI^05m`IP1MKf80GW=R05AYEP1IKe`0CfAA04aM
B`1;FTX0A59203]9>`0lBSh0=4Hk0353>00mDTP0DFIM059WGP0204mUFP0306MmLP15FU00D6IK0080
C65G02d0B5iC04AJC`12F4d0A5Y>041FBP0kD4@0=T/o02m3>@0[?SD0:Sdd02/l=00W=c409SH`02Lf
<00V=Bl093<_02df>@16DED0AUAG03M5B@0_@D@0<dE602m1@@0]?C`09cLf02Te<`0W<Bl08B`X020]
900V<bX0:cP_02@a:@0M:R<082dV02Db:`0P;2L08c0Z01h[9@0S;bX082`X02</;00T;Bd082TY028Z
:`0Q:BX00P0L9BD02`0N9RL07bPX01hW9`0M9BH07BDS01XP7P0H7Q`06R0N01HL6P0E6aT06AlM0080
61hL01l06b4O01dS8@0N92806AlL01LL600L8Ad07R<O01HK5`0H7AT07R<O01`Q7@0H7AT06QlK02P]
:@0U:RH061dI01XN700G6aT06b0M034e<`1iOG/08bLU01@I5P0G71T03a@A010E4P0G71P051D@01DF
4@0F5a8051D@00804a@?00L061TD018C3P0G61<0414<018C3P0D5A0061LC008051<?00D04a8>014@
300I61@06APD01HE4@0201<B3P0301@C3`0C4Ph04a8@00D04a8@00P03Pd;01HE4`0Y:2H061LE00/:
2@0E51804Q4?014@3P8040l=00<04A0>018A3`0A40h00`0B4@l0800A40h03`h<00`81`0G4a802@D4
01TE500`;2/03PX9010<2`0A3@`03@T801<?3P0G4a80:bLV06MSHP0@30/06ADD00X71P0F4Q404Ph=
06=OGP0G4a804`l>014=30091@@04@d<00l;2P0>2PT030P7010<2`0=2@P040`;0P0?2`X02P0>2PT0
3`/:01<?3P0G4a803PX700d91P0<2@L06aLD08f9QP0_:bP200h:1`803@T60P0<20D00`0?2`X04@d<
00h:2@02010<2`0700d9200?2`X03@T8010<2`0;1`L04@d<00h:2@0500`81`0500d9200>2PT03@T8
00`81`0=2@P00`0>2PT0300@30/03PX900d9200>2PT04@d<00T5100>2PT081`K010<2`091@@03PT9
00h8208040X:00@03@L700h8200G4A405@l?0P0;1@D2018<300N0108200@1PH03`P700d91`0>2PP0
30/800X91P0=30T040`:00`71@0<10<04@P800P10@0E3`l0@S`l01D?3`0A2`/040X:00`61P0:10@0
3`T9018<300?2@T03PP802lY:`0J5AH03`T;00d72@0@2P`04P`>1P0=1`T02@0<1PX03@L;00h8300>
20`03@L;00`62P0?2@d03@L;00`62P0200h8300900/52@0I3Q@03`@:00d2200H3A<03`D:01<83P0@
1@/04@H<00804PL=00<04@H<01052oooool04oooool001_ooooo00X0314D00lC5P0?4aH03Q8E010C
5P0D5AT04Q<G01@D600C4QL040lD0P0>3A80200B4Q@02PX<00d=3`0>3Q006ATK038b=00Y:B/03`lA
0P0=3@l04`0;2`d04A8D00`@4`072`h041@G00L93@0@4AD04a@H00d<4@0;2Pl03@/@00l=4P0=2a00
3@d?00d@3P0<3P/02P`900h@3@0;2`T00P0=3@/04`0>3@/03`h<00l>300@30/03@`:00`<1`0?40/0
414<00/<1`0L7AP0UiRC06UZI@061`804A8=01@E400>3`X05AHA00`=200>3`X00P0D5A001@0A4Pd0
3a0;00l@2`0?40/03Pl:00803@h9010030d800P910051P4030d800/<1`0<3@P010D101PI500;30L0
:2TT01HG4P051P40414<00h?2P0A4Pd0414<100>3`X0300?40/04A8=014B3@0?40/04Q<>01PI500?
40/06AXE00`=200o@3/04a@?014B3@803a0;00<0414<00l@2`0>3P`01@0>3P`0300F5Q@07QhL01@D
4P0:2PP04A4?00X:200A4a000P@101HH5@0>40d02@/800P:1`<0418?0P0?4@h00`0>40d03Q0?00h@
3`0600h@3`0F00lA400A4a804Q@C00lA400;3@`0418A014C4P0@4Q4051HE01XL6`0@4Q404aDD00d?
3P0H6QT0;2h]01hP7`0E5a@01@L401TK600H6QL02P`900lA3P804Q@A0P0A4a02010B3`0501<C4@0?
3`d051@B01<C4@0?3`d00P0D51801@0C4a406ATG01DE4`0C4a402`/900H03Q0=00H030h;00/=2P0=
3``04Q@A014C400?4@h2014C4080418?00d04A<@018D4@0=3``02@/8014C400<3P/051HC00d?2P0;
3@L04QD>00hA2P0B5@h04A@=00803Q4:00X04A@=01@G400B5@h04A@=014D3P0B50l03Q0;00/=200B
50l04aD@0`0B50l0900A4`h0418=010B3@0C5A00418=00/=200?4@`05ALB01@F4@0>40/04A<>01PJ
5@041P<04aD@02@V8@063@P02aH>03@o=`0D71<06QdD01PK400I6a0071hC01PI4@0F6A404aPA01XO
6P0B50l05APA01LJ4`0C5Pl04A@=01@G400C5Pl051L@01HI4P<05APA00L03@l:01HH4`0D5Q404A<>
01@F4@0I6aH061XE00805aTD01/05QPC01LI500H6QD05a`F01HK5@0H7AL06QlI01PM5`0@5@l061dG
01/P6P0I7QP061dG01dR700N8ad051XF020V8P1KHEd0EeeI01TO6`0B61@05adI02`b;P0;4@d0318>
02hd<00N92000P0L9Qh0400K9Ad06R@L01XT700I8a/05b4I01hX800L9Qh06R@L01`V7P0H8ad072/V
028b;`0Z>SL0:c/h024a;P0O;b`2024a;P0802<c<00V=S<0:3Pe02Lg=00^?CX0:CPe02hn>`0_?c`2
02Hi=`0802@f=P0X?3/07S8a04AHF@1WO7d0;T=403M;BP0fBTT303E9B00303A8A`0bATD0=d]:0080
>4a;00<0=d]:03Q<B`0bA4@00P0dATH03P0bA4@0=4Q903M;C013EUX0=da?03U>D@0oE5T0DVY^04EM
H@1?HfX0AUYQ04=GGP16FV40B5aS0P1:GVD01@1<H6L0D6A[04aPI`1;GfH0C65T0080BV1N00P0BEiN
04MLG@16Fe`0AeaN04eRI@1@IFP0CF9V051UJP80DVM/00`0EFY_05Q]LP1GK740EFY_05Q]LP1JKg@0
O96F09V^/`1YOX<0DFI[06EjO`1RMW/2065dN00706IiO01TN7T0HgMh06MkN`1YOG`0KH5o06n3P@02
06]oO@0M06alN@1fQX<0KGej06moOP1ZNWT0J7Qg06]kN`1bPX80MHF5071oPP1aP8<0MHB607>3PP1e
QH80MhN407J6P`1eQH80MhN407B4P@1kRhP0N8R507Z:Q`29VIH0UjNT07b<S01nSXh0O8b;07Z:R@1l
S8/00P1kRhP0<01iRHH0NX^507Z;Q@1eQX00LhAn07f=RP1hR8H0Nh^:07B4Q01[Ng/0NXZ90720O`1]
OWP0HW=Y05Y/H01JK5d0GW=R04YOC01=He00DFIE051QD@14DdH0?T]1034n=@0]>c<0;3de03Q9@`1<
H5T0E6UR04]PE`1:H5@0DVQL04AJCP1<HUH0CfEI04iTF017GE40@eU=04AJCP15Fdl0@eU=03eCAP0e
BCh0=TXo02m3>00/?CD0<T<k02Pi<@808C0[01009cHa02Pg<P0Y=C<09Rlc045<D012D5<0<3m102Tk
>`0_@T00<DA202Ti>00V=SD0:SHd02H`;`0P:bL082dT0`0O;2<0500V<b`0;3Tb034n=`0T<2`0:3@`
01dY9@0]>CD07b/W02@]:P0Q:RT08R/Y02</:@0O:2L07RLU024Z9`0Q:RT08b`Z028[:00L9B@06B4N
0`0K8Al0800G7A/05Q`J01LM6`0M8b408RPV020V900I7ad05adK01HK600F6aL06QlK01`Q7@0F6aL0
6AhJ01`Q7@0G71P051TE01PM6@0U:RH08bPT01PM6@0L8Ad041DA01PM6@0:3`/06QlK020U8@0G71P0
5AXF01lT800U:RH061dI0P0H6A@201XK5P805AHA018061TD01@E400E5Q403@h9018C3P0G61<061LC
01@C3`0B4@d04A0<010?2`0H5a<05aHB01TH500H5a<04a8>010?2`0B4@d601<B400800d<2P0E5180
5QDC00X91`0Z:BL030/9018A3`0A40h2010?3@04014@3P0B4@l03`h<014@3P804a8@00P040l=00d<
2P0C3`h030P700l;2P0I5A@06aLF010<2`80510?02<04@d<01@@3`0710<02@D400<0000A3@`03`/:
01hJ6@0=2PT06QHE00/71P070`<05A4@01<?3P0@30/020@3018>3@0?2`X03PX901DA40060P406ADD
00l;2P0B3Pd040`;00d9200@30/0510?01DA3P0H51404`l<01HB3`0:1P<00`00010<2@0200l;2080
3PX700<03@T6014=300B3Pd00P0?2`X0200>2PT02PH5010<2`0B3Pd02@D402/W9P1<B4L04Ph=2`0=
2@P300h:2@0Y00d9200;1`H02`L600h:2@060P402`L600X61@091@@040`;00d81`0@2PX04@/;00l9
2@0=1`L03PP801D?3`0D3Ph03`T9010:2P0B30`03`T900l61P0A1`H040P600h91P0=2@H030X600/:
1P0=30P040`901081P0?1`D04`T801/B4`0600002PD500@0000F41004P`<00`61P0;1@D00P0>20P0
1@0:10@02`D502`V:00G4A<04@/=00804P`>00<02@@500d72@0=1`T0100=1`T02@0<1PX03@L;00h8
300>20`03@L;00`62P0>20`03@L;00`62P0200h8300800`62P0A1P`04PL=00l42P0D2@l02P4500h3
2@0?10X40146300300l42_oooooooooo01;ooooo000Kooooo`0E00dB5@0?4aH03a<F00hB5@0A51L0
5QLK010A5@0B4QL04Q4F010?500A41D04Q4F01PH6P0=3@l05ADG00X:300B4Q@0CdmA02d];`0>3Q00
2PX<008030`>02@04a@F00D;3P0730l041DH01DJ7@0830l01`/>00d>4P0:2`l04A0E00/:3`0920d0
3`lA00`@3@083@T03a@@01@F4`092@L061PF00d=2`0>3@/03`h<014=300@30/03@`:00`<1`092PD0
4a@?00/<1`0U9R40^[^f07AeL00<3@P04A8=00X;1P000@0200/<1`0400d>2@0B4`h04a@?010A30<0
3a0;02L03Pl:00d>2@0=3PT04Q<>01HG4P0J6aH03a0;00/<1`0=3PT0414<00h?2P082@@0;2dX00/<
1`051P404a@?010A300A4Pd0414<00h?2P0?40/03Pl:00d>2@0?40/04A8=010A300?40/02``701LH
4`0?40/06a`G00d>2@0E5Q404A8=00l@2`0=3PT03Pl:00l@2`0>3`X01P0>3P`0300;2`T05ADC010@
3P0<30X05QHD01<C4@0L7Q/03a4>00d?300M7a`05QPE01TK6080418?0P0?4@h200h@3@H03Q0?00@0
418A00d?3P0=3`h03a4@0P0@4Q404P0=3`h03Q0?00d?3P0<3Pd04aDD01dO7P0A4a805ALF00/=300>
40l06adL018D4`0<3P/04A<@00h@3@000@004Q@A00`>2`804Q@A0`0A4a003@0@4Pl04Q8@00`<2P0@
40h051@B01<C4@0B4Q004A4?000000051@<0410>01LG5@0A4@l01P0>40d01`0;3@X03@l<00lA3P0C
5A804Q@A014C400@4Pl00P0>40d3010B3`0=01TK600D5Q<05aTF01@F4`0B51402`d800h@2P0I71D0
5QTB01XM5P0F6A804QD>00lB2`0200hA2P0900lB2`0@4``04Q@>01LI500H6QD04aD@01@F4@0F61<0
4Q@?0080418=00P04A<>018D3`0B50l04aD@00lA300=3`X04Q@?01HH4`804Q@?00/01@L201XL5`0E
5a80418=01/M600=5@l02aP?030m=00E81D04a/@00lE2@0201HI3P0C01@G3P0E610041D>01<H4`0C
5A005QTB01TL5@0E61404aH?01HI4P0C5Pl051L@01DH4@0F6A805aXC01HI4P0<3PT051HA01dO6P02
01HH4`0>01DG4P0H6QD05aTD01LI500F61<05aTD01PJ5@0E6Q@051TC01<H4P0D6A<05AXD01@I4`0E
6Q@201TN600?01PM5`0J7aT05a`F01HL600<5A007RLR01`U800=5Q408BXU020Y901:Ddh07BHQ030i
=00U;RT04Q/F00807BLO00L072HN01/U7@0J91`06R@L01/U7@0P:R808B/S008092hV01/06RDO028a
;00O;b`07Rh[06MgM00X>3D0;Cdj020`;@0N;R/07bl/02<c<00U=C808c<`03U8A@0X=c@093@a02dm
>P0X>cT09CPf0312@P0bATD0;D5005ibL`25VY/0BUmP02m3@P0aAD@00P0cAdH0500aAD@0<4A302/o
?P0bATD0=DU803I:B@0eBDP0=TY903=5A@0`@T80<TA403I8BP0fBT/0=DU:03iAE@0oE5T0D6EZ03Y?
E01?If/0?UIJ0`1<H6L0601:GVD0AEUP04QLH`17Ff80AUYQ04eQJ01;GfH0Ae]R04]PHP1=Hf00B5iL
04AJF013FEL0AEYK04YOH@1BIfX0E6U^059WK01FJg00F6ac05EZL01DJFh0EV]`05Y_M080G75f0P1M
LWL01@1UNWl0H7Ej05mdN@1VNh00HgMk0080HGAh00L0Ig]m06EiNP1TN7T0J7al06QlN`1]PGl0Kh>1
0080Jgmm01@0KGej07J7P@1_P7X0MXJ306IfL`1XN7L0K7al07>3P`1eQHD0LX6407J5R01gQhP0MhN6
07R8Q@1iRHH0MXJ307>3P01dQ840O8b907j>R`80MXJ300X0Pi>@08JFT`1nSXh0PI6A07f=S01iRHP0
O8b;07Z:Q`1kRhP0N8R50P1kS8H08`1dQGl0MhR208NGU01cPh80JGUh07R8R027UiL0OHf<06moOP1^
OgT0IWM]05maI@1KKEh0Fg1M051UDP1<HU00GgAS05i^H@12DDL0?T]2045>A`0fA3h0<T<m049BC`1E
JF@0D6EP04aQF01=HeL0F6iR03iDB01>I5P0B5iB04eSE`14FTh0?eE90080@EM;00P0?UA803E9?@0_
@cL0<dLk02i2=`0[?380<T<i02Lf;`808C0[0100:3@b02`h=P0/>3P0:S@g03m:CP0mBdh0;Sdn02do
?`0eB4H0<4=002Hf<`0T=340:3@b02<];00O:RH082dS0P0K:1h05@0T<BP0:cP_02`i<00[>34082`X
02Hb;P0M:BL0;SXh020/:00U;RX082TV028[9`0R:bH07RLT024Z9P0U;RT08b`Y02@]:@0Q:RD06R<P
01PO7@0301`R800901/Q7`0J81h06AlM02D[:@0`=S@0:Bl]01TO7@0G7A/06R0M00805a`H00@06b0L
01PM6@0H7AT061dI0`0F6aL01`0J7a/06b0L01DJ5P0O92004aPD01PM6@0L8Ad00P0P9B403`0K81`0
51TE01`Q7@0J7a/03a@@01@E400@4@`04a@?01PI500F5a806AXE020Q700I6QD061TD01HG4P02024R
7@0<01DD400C4Ph05A@@01@C3`0@3`/05A@@01@C3`0G5Q8061LC014@300>3@T04A0<1P0C4Q0201@C
4@06014@3P0=30X0<c8`014@3P0B4@l04A0>0P0@3`d02P0A40h04Q4?00h=2`0A40h04a8@018A3`0?
3P`030/901LC4P0:1PD201DA400K00P40`0A3@`040`;01<?3P0D40l06QHE010<2`0C3`h06QHE01HB
4@0810<061@C00`8200D40l04Ph=01/G5P0?2`X01P<201HB4@0B3Pd03@T801<?3P0B3Pd04`l>00X6
1@0A3@`03PX900804@d<0P0=2@P0200?2`X020D301TE4P08104020D3020L6@0300004@d:0`0@30T2
00l;20804Ph=0P0?2`X0200>2PT02PH5018>3@0G4a802@D401lK6P0n>ST030P72`0=2@P200h:2@80
3@T80P0<20L01`0>2PT030P7010<2`0;1`H03@T801@@3`0?2PX00P0A2`/01@0?2@T03@L700h8200>
20P03`T900804P`<00H03PP800d71`0@1`L04@L601081P0>2@H300d91P0G00h:1`0@2`P04@T70108
1P0C2@P05@`=00h8200D3Ph01@00018<300?2@T03PP800`61P0=1`L030H600X4100B30`04P`>00D0
0@0:10H03PP:010:300<1PP01P0=1`T01`0<1PX03@L;00h8300>20`03@L;00`62P0>20`00P0<1PX0
100>20`03`T=00`62P0;00H201@93`0501052`0K41H02@0400l42P0@1@/00P0A1P`00`0@1@/03`@:
ooooo`0Cooooo`006oooool0200<4A@03A4D00`@4`0:3Q403Q0D01<D600<3A403PhC0P0@3a@08@0C
4QL05aHK04Q8BP0B4Q@02PX<018B500;2`d04Q8D01@D5P0:2P`030`>014A4`0>3Q0030d?01DL7P0@
6A/05b0R03Lo@@0@5aX0314D00hA5@092a00418G00/;400:2@h03a0C00hC4@0=4Ph01@X6014C4006
1`@05ADC00h>3002010?3@0:018>3@0A30`04@d<00d=2@082@@03a0;014B3@0@4@`08R<N01`M6080
2``700<03Pl:01@E400<3@T00P0<3@P0100?40/0414<00h?2P0=3PT500h?2P0C010A300>3`X00P<0
01@E400e=S40414<018C3P082@@04Q<>038c;P0@4@`03a0;00/<1`0>3`X03a0;00h?2P0=3PT03Pl:
00l@2`0200h?2P<03a0;00T0414<01@E400;30L04A8=01<D3`0?40/04Q<>010A300>3`X00P0?40/0
0`0>3`X03Ph<00h>300400h>300900`<2P0@40h03`l=00l?3@0B4Q004A4?00T;200H6QL04A<@0080
3a4>00@03@l<00lA3P0?4@h03a4>0`0>40d200lA400<00h@3`0=3`h03a4@00lA400=3`h03a4@01<E
500A4a802`d<00h@3`0D5QD0418A0P0=3`h0100A4a8051HE00h@3`0>40l200`>3@0800h@3`0A4a80
3a4>01@F4`0i>cP04A<@00/=2P0D5Q<600lA3P0500/;2@0D51803Ph<00h>300E5A<00P0A4@l01@0/
;2X0<S8`010@3P0=3@/05QHD00H0418?0`0A4a001P0@4Pl03a4>00lA3P0@4Pl03@l<00h@3@804A<@
01D0418?00lA3P0=3``03Q0=014C400@4Pl0418=01DH4P0J7AH051L@01HI4P0C5Pl041<<018E3P0@
4``03a8;014D3@0B5@h041<=01<E400E5a800P0A4`h01@0B50l0418=00lA300@4Pd04Q@?00804aD@
00D04Q@?010B3@0@4Pd04aD@01@F4@02018D3`0K01@F4@0O8A`061XE01LI500:30L051lH02Lg;@0J
:R002aL<018L4@0=5@P05Q/@01@H3@0E6A005a`D014H400B61<04QLA01DH4@0H6a@06A`E01PK500G
6Q<061/D01HI4P0E614061/D00806A`E00L06adH00lA300H6QD051HA01DG4P0I6aH061XE00805aTD
00<05QPC01LI500H6QD00P0F6aD201@I4`0301DJ500I7QP05AXD00806AhH00l061dG01XO6@0F71H0
3Q@@01dV8@0G81/04a`G01TR7@0F7aX07RLR02/d;`0N9b80>T<n010I500Q:RD01P0N:200>00L9Qh0
8B/S024[8`0S;BD09c4Y028]9`0O;RX08c<a05EUH`38emH0AEEC028b<00V=S@09CDc02@d<P0U=C<0
9cLe02Ph=P0^?CX0;C`i02dm>P0_?c`0:Sdk02Lj>00]?cl0:Shm02e1@00^@T<0=da=0397B00`A4<0
<TI503M;BP0eBDP0<TI503A8A`0^@T40=4Q703I:B@0dB4L0<TI50355A00eAdL0<dE603E7B00kCDl0
>dmA03Y>D014Ee/0@eQM03mDF@1SN7d0^=3D06Z2QP1=HFP0B5aS0P15FF005019GF@0Cf=Z04iRJ@1<
H6L0D6A[04eQJ01;GfH0CfEV04iTH@18GU`0@eUG04MMF`1<HF80D6EW05=XJ`1DJFh0DfQ]05Q]L`1I
KG@0F6ab0P1HKG80701LLGH0GgAi05icN01MLWL0G75f05U^L`1VNh00GgAi05U^L`1XO800HWEi06=f
NP1ZOX00Ig]l06]oP01^PX80I7Qg06IjN01XO7X0IGUg06QkN01[O7H0L81j06inN01dQ800JGUe06Uh
MP1_OWh207F4Q00407R6R@20Si80O8^=07^:R@80O8b900<0N8N407F4P@1eQ8400P1gQX<0C@1kRhP0
PY6>08:ASP1lRhP0QIBD08VHV@22TI00NhZ9082?S`1nSHX0OHf:07V8Q@1mSHP0O8b707F5O`1lS8L0
Nh^:0761P01aPH40Y;Bd0<?Cd`1lS8/0M8B306n0N@1YNW00IGM[05i`H01DJEH0DfQF04iTDP1DJEX0
E6AI04=AB@0kAd<0FVIS05=PG`17EeH0CUiN05Q[JP1>Heh0AU]B04ILC`1@IUT0Aee@04mUF01;HE@0
Bf5E04EKC`10ETT0?UA703Y@A00fC3l0AEU=03a@A00cAc/0:Sdb02Df;00T=B/093</02@c;P0R<B`0
9C4_02Xf=@0^>SX0;CHj03E0A00a?d80:STi02m2@00gBTL0;d8n02Lg=00U=C808bl]020Z:@0Q;2P0
82dS00808c0V00h0:CH/02Pe;00Q;RD06BHO01TU8@0Q;BT082`Z02Hb<@0T<2h09c0Z024Z900Q:b@0
72HO01dV80<082XS00L07bTR01/U7P0I8Q`06R8N01lU8`0N92806R0N0080728P00`05Q`J01`R800U
:bT08BLU01HL6P0G7A/0724N01PM6@0G71P06QlK01LL600F6aL301TN6P0P01LL600E6QH05a`H01HK
5P0L8A`04aPC00lD3`0J7aX05AXE00`A300D6A@05a`G01TN6@0>4`h09R/V03<d;`0R8ah05QLB01TJ
5@0E5Q404a@?01XK5P0F5a8051D@018C3P0O81/07AhI01<B3P0B4@d05aHB01HE4@0A40`2018A3@05
01@C3`0F5A404Q4=010?2`0A40`01P0C4Q001@0?3P`03Pd;01PG5@0B4@l04a8@00804Q4?00L04A0>
010?3@0@3`d04A0>018A3`0@3`d04A0>008040l=00/03`h<00h=2`0?2`X0510?014=300@30/04`l>
018>3@0@30/04@d<00h:2@0201<?3P0602<O7P2ETI0081`K01DA400:1PH05a<B0P0?2`X060091PD0
510?00l;2P0>2PT030P800l;2P0F4Q403PX901@@3`1BCTd0>cLf01<?3P0?2`X03PX9014=300@30/0
3`/:00l;2@0=2PP030P5010<2@0;1`H05a<@010<2@<03`/80P0>2PL00`0A3@`04Ph=00l;2P0200l;
2P802`L600<04@d<01DA400:1PD00P0@30/500h:2@803@T80`0>2PT04P0=2@P03PX900h:2@0=2@P0
3PX9010<2`0>2PT030P700l;2P0<20L02`L600`81`0;1`H04@`;01<=3@0B30`03`T900d71`<03PP8
02803`T900d71`0;1@D03`T901<:2P0C20L04@P600h91P0>2@D030T500d91@0<2@D03PT501491P0B
20L04`P700d51@0>20P04P`<00X4100D3Ph03PP800l92@0>20P040X:00h8200=1`L06A<C020J700B
30h03`T;00X51P0;1@L040X<1P0=1`T01`0<1PX03@L;00h8300>20`03@L;00`62P0=1`/00P0<1PX0
2P0>20`03`T=00d72`0B1`d040H;0146300I3Q@0:QlU00X11@0?10X401052`0300l42_oooooooooo
01;ooooo000Kooooo`0B00lB5`0?4QH0310C00/?4P0?4AD04a@H018C5`0B4QL040lD00d<4@0>3A80
40lD01LG6@0B4Q@020P:00X:300A4A<03Ph@0P0@4180300<30h04A4C014A4`092Ph04ALK00082`03
2`h03ADH00052@0;41<03A0D00<72P803@hB02003PdB00`=3`0Z;b`09b`X0043000@4Pl02`d:00X:
200?3`d040l=014@3P0B3`h04Ph=014=300@4@d0410>01PJ5@1LGEX05QHD00H80`0B4a0010@200X<
1`0@4@d05QHD00l@2`0>3`X03@h900h?2P0?40/03Pl:00`=20803@h902@03Pl:00l@2`0?40/0414<
00P9100G5aD030d801`M600=3PT01`P501lP6`041@003Pl900`=1`031000414;00/<1P0<3@P02P/6
00T:100;30L03Pl:00h?2@0=3PT030d800h?2@0@4@`03a0;00X;1P0E5Q403Pl:00T:1@0:2`H04a@?
014B3@0?40/3010A30H03Ph<00`03`l=00/;2@0>3P`0410>00d=2`0>3P`05aTF00D7100?4@h051HC
00h@3@0<3P/300lA3P0=00h@3@0=3``03@l<010B4@0?4A003@l>00`>3@0>40l0418A00d?3P0F61L0
8B<R01/M700200d?3P0B00lA400>40l0418A01@F5@0E5aH0418A01HH5`0:30/04Q@C01@F5@0=3`h0
4aDD01DG50082PL08bDR00T;200M7a`01PP51@0A4a002P0B51403a4>02PZ9`0E5a@01`T6014C400>
40d03@l<00P:1`0D5Q<2014C400300lA3P0A4a004A<@00@04A<@00T03Q0=00lA3P0>40d03a4>014C
400C5A804A<@00d?300?4@h00P0C5A800`0A4a00418?01DG5002010B3`0400lA3P0F61<08bDO01dP
6@8041<<0P0A50d01`0>4@X041<<014D3@0A50d041<<014D3P0A4`h00P0>40/00`0D5Q404Q@?00lA
3008014C3P80418=00h04Q@?01XL5`072@@05aTD00h@2`0F61<03a4<014K4`1=GE<07BXP01@P5@0Z
=2T06R8G01<J3P8041H<01H04aT@00lF3P0A614041D?014D3@0D5a006A`E01XM5P0E614051L@014D
3@0B5@h06A`E01hQ6P0Q91d0418=01@F4@0o@C`0:bdX01@F4@0K7AP061XE0P0G6A@02`0F61<05aTD
01LJ5@0D6A<05AXD01HK5@0E6Q@051TC01DJ500D6A<05a`F008051TC00h06AhH01XP6P0M91d03aTA
01hX800O:B408bdU04UBC@0K91l05b0K01TR7@0R:bH06R@O02D^:@807RPP02X07bTQ020Z8P0P:b<0
82/S01lZ8P0W<RX08RdU01lZ8P0Y=2`0=44j01TX8`0Q<Bh0830]05UYIP0`@3h07Rh]02Hf=@0W=cH0
9CDd028b<@0T=3<09cLf02`l>@0U=C80:C`h03Y<B00cAT@09STg02/m?@0^@T409c/j02e1@00_A4D0
<dU703E9B00`A4<0<dM60314@`0^@T40<dM602e1@00bATD203=7AP0S0355A00bATD0<4A403I8BP0e
BDX0=4M903U<D00mD5@0?4mC03Y?E01NLgP0CV=X08NOX`1EKG40B61T04=GGP14FEh0C65W04eQJ01=
HFL0CfAY055UK01?HfT0AU]P04QLH`1=HVD0B5iL04EKF@14FUT0BUmP055VI`1FJfh0F6e`05Q]LP1G
K7800P1LL7L0:01JKg@0GG9g05ebM`1MLWL0H7Ej06AiOP1SN7d0Igb105aaMP1dRHh0MX^@05e`MP1W
Ngl0I7Qi06IjN`1]P7l0JG]k07B4Q01lS8/0KWim06QkM`1TMg<0GW9`05icK`1SM6h0JWUb06MfL@1_
OWT0OXf807F4P@1aOgl0MH>307B2P`1lRXd0R9JI082>T01jR8P0O8^807f<R@1jRHH207R7Q00[07N6
P`1dPh00O8^807j=RP1hQh@0PY2?08ZHV@2@WYl0QYBE07j<S024TY80PY2?07j=RP1iR8D0OXf907f<
Q`1eQ7l0Ohj;0;o?cP21TI00JWYj07j>SP27UiL0OHf<07^;R01_P7T0IWM]06IhK01NL680DfEE04eR
D@1BIeH0?e53041BAP1CHUX0AEA=04MFD@1MK6X0GFe/05MZJ01EJFL0BUmJ051XF`0204YRE00m05A/
G`1?IeX0D6IJ04]QE@19Ge<0@UQ<03eCAP0eBch0<DLj03iCA00gBCd0:3X^02Hh;00/?C<09cP`01l^
:00U=2l08c8_020/:`0V<S80;3Li02Pc=P0Y=cX0:3Hg02Hf=@0[?SX0<4<o02m2?P0Y>CH0:3Ld020]
:`0O:BP09C0/02Db:@0X=B`07b`S01`Y800P;B@07b`U01PU7P0N:RH08bl[02Da;`0K9bD08Rh/02Pa
:`0R:bH082TS01PR6P0L9B007bPR01/U7@0N9b8072HO01XT700M9R4082PT028X9P0N92805A/I01PN
700201TO7@0^01XP7P0H7Q`05adK01PN700I7ad05adJ01HL600J7a/06AhJ018G4`0F6aL07R<O01LL
600C61@05a`H01PM6@0F6aL05Q/F01@I4`0G71H07B8L01hS7@0G71H06AhH01@I4`0?50h07B8L00dB
300W;2H0=cTd01dO6P0<3PT05aPC01PI500G61<0414<01@E400E5Q402P/601@E400F5a8051<?01DA
3P0E510051<?00l>2P804Q4=00D04a8>01@C3`0E510051<?01@@3@0601<B4008018A3`0F5A<01PD3
010?3@0G5Q@030/9018A3`0A40h2010?3@04014@3P0B4@l04A0>010?3@<03Pd;00D03`h<018>3@0<
20L03PX9018>3@02010?3@0U00P61`0B4@l05A4@01LC4P0B3Pd08AdL01lK6P0=2@P030P700H20@0>
2PT040`;01HB4@0>2PT04@d<00l;2P0D40l03PX9010<2`0C3`h03@T804E1@03kmoH0i>3O02<O7P0@
30/02`L600l;2P0@30/03@T8010<2@0C3``05a<@00/71P0O6aP0100000d91P0300`81@802`L400<0
40`;014=300>2PT00P0?2`X01@0<20L03PX900T510091@@0510?00802PH51@0>2PT05`0=2@P030P7
00h:2@0?2`X03PX900`81`0>2PT03@T800`81`0?2`X04Ph=014=300>2PT0510?00X61@0=2@P030P7
00@0000D3`l04`d=018<300?2@T03@L700803PP801L030H600d71`0B30`04@/;00d71`0?1@D04PP6
01481P0>2@H03@P400`91@0;1`@02PL200`70`0@20H04PP601471P0<0`@04P`>014;2`0400002`H3
00`71002010;1`08014<2@0;1@D01@0000/51`0G4A<01`4300P210090`D200/51`H03@L900L030H:
00d72`0>20`03PP<00d72`0<1PX03@L;008030H:00/03PP<00l93@0=1`/03`@:0146300900@04PL=
00d4200B1`d03P<900l42P0201052`0300l42P0>0`Wooooo01?ooooo000Kooooo`0801LG7`0A4QP0
2``A00l@5@0C51T02P/@00h?4`0>3a8300h?4@0900d>400?3Q<030/@01TH7@0;2Pl07QdR00l>4`0H
5a`00`8700803`hC00<03PdB018A5P0@4AH00P0A4QH01@0@4AD03PlC00`=3`0O82<06AXL00802`/=
00P04Q8D00`<301;CDX09RPU0041000@40h04Q8@010@3P804A4?01004a<A00h=2`081`D06QXH01HI
5P051`H01P/704Y=B`0620L041DA00X=2`0I6aX06QlK00P;2@0@4Q402``90P0?3`d0400<30X02PX8
00`<2P0>3P`0410>00d=2`0;2`T06ATG01DE4`0?3`d01`L5034a<@0A4@l00P8001hO6P0;30L200h?
2@0d00l@2@0@4@T0414900`=1@0G61002``600l@2@0?40P05aPB00h?200:2`<02P/500d>1`0@4@T0
3a0:00/<1P0=3PT04Q<>00/<1`092PD04Q<>01HG4P092PD04A8=01@E400720<0414<00/;2@0A4@l0
3`l=00T91`0<30X04A4?00/;2@092@L09bLU00`<2P092@L04Q8@00h@3`0C5A@02`d<01@F5@0F61L0
2`d<00lA400>40l03@l>00h@3`0?4A004Q@C010@3P803`l=00D03Ph<00l?3@0@40h03`l=010@3P02
00l?3@0;018B400E5a@04Q@C00/?3P0J7Qd01PX900hB4@0<40l03A4@010D4`0A5A@00`0?4a806@0<
3P/04A<@00d?300<3P/061XG00/=2P092`P04Q@A010B3`0D5Q<0=SPe01LI5P083@T0>Slk00@91@0:
3`/06QlK01DJ5P0?51004QLC00D:1P0<4@d00PL301@I5@0D5Q<00P0>40d0100B514061XG00`>2`0@
4Pl200lA3P0G010B3`0A4a004Q@A00`>2@0;3@P04A<>018D3`0?4@`0418=00/=200B50l030h900h@
2`0G6A@03Q0;01dO6P0W:B@092HQ01DG4P0?4@`04Q@?014C3P0B50l00P0D5Q401@0B50l04A<>018D
3`0B50l04A<>00804Q@?02805aTD01DG4P0=3`X03Q0;02<U800@4Pd03a4;01<F3`0D5a004aH?018E
3P0C5Pl05APA00hA2P0N8AX05APA01TL5@072P<05adE00/E300=50`041L?01LN5P0F6a@03A8:010E
3P0I7QL061dF01<H4@0A5Pl041D?01@I4`0C61803a@>0P0B5a40>`0<4@/082DO00dB300G71H0=S/e
07YoN@0n@cl07R<O01`Q7@0F6aL051TE018G4`0?51004QLC01DJ5P0Q9R804QLC01XO6`0E6Q@05QdF
01DL5@0G7QL06R4J01LN5`0E71D04aXC01TP6@0F7AH07bHO01PO600I81P06R4I01@K4`0B71<06B<J
01TS6`0A71@05R4I01/V7P0L9b406RHO01PS7@0M:2006bHN01XU7@0L9al07BTP01`Y800I9Qd08c4X
01l_9@0K:b40=DDk05a/HP0O<2P07S4[024d;P0P<bd08SD`0080;D0l07<083<`02Hi=`0S=S@0:3/i
02`o?@0V>CL09CPf02Hj>00[?S`0:clm02Xn?00X?3X0;D4o02a0?P0]@Cl0;d=202e1@00_@D40=TQ8
03Q:BP0cADD0;d510394A00cADD0>4Y:03E7A`0fB4P0;T100314@`0hC4h0>4]?03I;CP0mDE@0=da?
03aAE00iCU40B5eP04aQI019GV40B5eP04UQH`16Gf40AEeQ045IF`1<I6L0CFEY04]QI@1;H6<0BEaR
04YMHP1;GV80BeiT04QLH016Feh0AEYM04YOHP1>HfH0D6EX05EZK`1NLgP0FVmd06AiOP1WO840GgAi
06AkO`1JLW@0FG5c06=iO01SN7/0L8F805mcMP1NLGD0HGAh06YmP@1TMg/0HgEi06QmOP1VO7T0KX:0
06YkN01bOWX0Mh9n09NPV`1cOWP0KWag06ioN@1TNG@0IGag06f0NP1YNW@0K7eg07>3P01bPWl0L81o
06moO`20T900L7n207b;SP1gQXT0Pi:F07Z:Q`1kS8H0N8V306n0NP1^OgT0MXJ307V9QP1fQX<0Nh^:
082@S`1lS8/0P92?086AT@21T9<0PI6B0080PI6A03/0PI6@07n?SP1nSX/0NHV607B4P@1gQh@0OHf:
0:bl^`1nSXd0NHV807n?SP1bPX00Lh>007B4P@1^OgT0MHIn05a]I@1?H5H0GFmS05EWE`1BIE80BE];
04EGA`13EDP0>Ta004mPEP1FJV00G71W05U^I`1BIf40Bf9J04QSE01;IUL0BfEH04]UFP1<IUd0D6MQ
059YH`11F500@UU?04EKC`0hCT40?55203Q:?P0hB3d0>d]002<c:@0T<b`07RdV02<b;P0U=3409cDe
01TW9`0S<C80:cTj02dm?@0/?3`08S8a01lb<00202Lg=00702Ti=P0X=c809SD`024`:`0M:BD06bLS
02Db:`0202<`:@0Y024^9`0O;2D082`X01DQ7@0^>SH05B4M020/:00M:BD062@P01/T800K924072DQ
020Y900U;R/08b`X01TR7@0H8Ah06B8N01@M600I8Ql082PU018H5P0L8R008BLU01dS8@0N92807B<Q
02<Y9`0L8R007B<Q01hT8P0H7Q`05Q`I01DN6@0J81`061hJ01dS7`0R:2@06AlK01TN6P0J71T00P0I
6aP09P0J71T071hK01@F4`0F61D07R0M00lA3P0H6QL06Q`I01@F4`0?4@h06A/H00T;200C5a<061dI
00/@300C61@06A/H00/=2P0F61D0418?018D4@0F5Q@05aLE01DE4`0D4a007ATF010;1`0A3P/07A`G
01@C3P0H6A<04a@>010A2`0C4Pd05a@?01@A300G4Ph05a<B0P0?3P`01@0E51804Q4?00h=2`0H5aD0
4Q4?00803`h<0P0B4@l02P0F4Q40510?018>3@0A3@`04`l>01@@3`0C3`h04Ph=010<2`0?2`X200h:
2@0B01@?300F4@h020@3010?3@0<30`02`/;00l?4@0D51@03@`:01DA400D3``03@P501XF5@0C3`h0
510?01HB4@0?2`X03@T80`0>2PT03`0?2`X04@d<014=300@30/02`L601HB4@0T81l0T8b;09:>S@0G
4a803`/:00d9200>2PT04@d<018>3@0200l:1`04010;200A30T04@`9014<2@H03PT60`0?2PL02@0A
30T04Pd:018=2P0B3@X040/800/60`0<1`@03PT600d81@0500d91P0500h:1`0@30T040`9014=2P0?
2`P00P0=2@H01P0D3``020<001D@3@2h/k00DDa900l:1`D030L400<03@P600h8200>20P0100>20P2
00d71`0L00h8200?2@T03`T900/51@0F3P`03PT701D?3`0400003`X900d71`0=20D03@P600d71`0?
1`D03`H700T31`0A2`l030L600@0000D40L03PX400/7000?2`003`/501<>2`0>20X030H:00h82P80
3@L900`030H800d72@0>20X0>38d02dW:@0H4Q@02P@600T31@0<1PP02P@600d72@0?2@/200`62007
00d72@0<1PP02P@600/51`0>20X03`T;00/51`0200h32@0801H;4@070080>2dc00`11`0A1P`04`P>
01873@0?10X200d221Cooooo000Kooooo`0800/;4`0A4AT03PhF00d>4`0?41D02``A00h?4`0>3a82
00l@4P80414C0P0@3a@0;P0E51T01`H;02TX;@0f=CX02@P=01LF6`0?3Q<05A@I00h=4P0=31402`X@
00h=4P0?3Q<040lD00d=3`0;2`d03`lA018B4P0;2`/03`l?018B4P0=3@d03`l>00X:200B4Q003@d;
01PH5P0=3@/04Q8@00/;2@0:2PP03@d;01HF500^;R`071lN01PK6P0930/04Q@C05=FE@062@P041<B
00L:2@0930/03A0?00`>3@0>3`d200l?3@0A00d=2`0;2`T03@d;010@3P0A4@l03Ph<018B400Q8Al0
71`J00`<2`0D51@0OWin01dM700B4Q0030d:01<D3`0?40X00`0?40P0200?4@H03a4700X;1@0F5a00
4A8;00X;100A4P/03a090P0A4P/01P0?40T03Pl8014B2`0C50l04A8=00l@2`80414<00D03@h900T:
1P0C50l0414<01<D3`02010A300J01HF500>3P`030`:01@D4P0C4a403Ph<014A3`0E5A<0<30^018B
400:2PP04A4?00h@3`0B51<030h=00d?3P0:30/05ALF014C4P0@4Q403a4@00h@3`0?4A00418A010@
3P0A4@l2018B400c014A3`0@40h0410>014A3`0@40h04A4?01<C4@0E5A<05ALF00d@3`0]<2l06ahM
00`?3P0@4a802`h=00d@3`0<3`h02`h=00`?3P0?4Q404Q@A00`>2`0G6AH051HC01<E4P0;3@X051HC
00lA3P0<3P/03a4>02@V8`0B51405Q/G00L<200G7AT03A8>08:7P`0^=3002Pl;01XP70052PH03Q<?
00`B3P052PH0418?01@F4`0C5A803Q0=01<E4P0:30T03a4>00803Q0=00H0418?014C400A4a0051HA
00h@2`0@4Pd2014C3P0<01@F4@0@4Pd04A<>014C3P0?4@`0418=00`>2@0@4Pd051HA01<E400?4@`0
418=0P0C5A000`0?4@`0418=018D3`02018D3`80418=02803a4<010B3@0@4Pd0418=01LI500>40/0
5ALB00T;1P0B50l04aH@01@G400E61404aH?014D3@0B5@h04aH?00hA2P0?4P/04aH?01hQ6P0l?cP0
5QXC01DJ4`0C61405Q/D028W800K81T04QL@010E3P0F6a@05AXC018G400D6A8041D?0P0C6180300D
6A<05a`F01<H4P0G71H03A8<020U7`0X;BL0HFIP0>7Uh012Ad<09b`X01/P70804AHB00h06QlK01LL
600b=c<06b0L01<H500E6QH0724M018I4P0I81T06b8K01HM5P0G7QL06R4J02dd;@805QdF00d06R4J
01/R6`0H7aP05ahF01dU6P0L91T06R@J01`V700G8AP07BPP01TT700H8a/06RLP00807R/T00T06RDN
01/V7`0L9b006bPP01`Y8@0K:2006RXQ01l_9P0M;RD00P0J:b803P0M;RD08SH]01X^9P0K;bL07S4[
01ha;00Q=2l0;3lk02<f<`0Z?C/09STg02Lj>00T=cD09c/i0P0X?3X0:P0W>cT0:Shl02e1?`0dB4H0
<4A202e1?`0aAD<0=4Q60355@`0a@d<0<TA40353@`0^@400<TA403M9B@0fB4P0>Ta<03Q:BP0iBd/0
=4I603]?CP13Ee/0?55D03M<C`0nDeH0?eAG04MLG`24VI`0A5UL041EF017G5l0@eQK04ALGP1:Hf@0
@UaM04=MGP1?IfT0@UYL04mUJ018GF00BEaP04aOH`80CV5U00D0Cf=W04iSJ01>HfP0D6EZ059WK002
05AYKP0S05Y_M01HKG80I7Un06QmPP1TNGh0IWf005eeM`1LM7H0W;>e07F:S@1HKG00JGf006QkO`1W
NWh0IgUm06QjOP1ZO800JGim06QnN`1bQh80Kgih07^4O`2>UHh0/[Na07=jL`1aO7H0L85k06QmN01T
NWH0IGQd0762O01eQX00L81m07:2O`1gQhH00P1hR8P01`1mS8l0M8>607V8R`1nSI40Nh^807f>R01o
T8X00P1nShT02020T8d0PY:?07n?S020T8l0PI6@07b<R`1mSHd0Q9>F0P23TYD01P21TI40P92@082@
T022TY40PI6@07f=RP80MhN402H0NHV607j>S@1aPH00M8B307N7Q01eQH40NXZ60721N`1cQ7d0IGI_
05i_I`1OL6P0D65G05AUE@1EIeD0CF1=04QJBP15F4T0?eA504UMD@1AIUX0EF]O05AYH01>I5/0Af5F
04]VE`19IED0BFEG04]VG@1<IUl0BfAO04eTG`1>IEh0B5mE04mTF`1aQgX0=4Tj0311=P80=DDj01<0
9CD[02/j<`0V=Bh07bh[02Pf=P0S<C40<T11028`<@0O;bl0:CXj02Pk>@0R=C<09CPf0351?P0c@d00
:3Pe02@c;P0P;bX07RdX00807b/W00`082`X02Da;@0T<2`07BTU01XV8P0L:2@07b/W02Hb;P0J9R80
8BdY02di=@0O:bL2020Y9P807bPU02008BXW020Y9P0J8b006R<P01/T8@0G81d06b@Q028Z9`0R:2H0
8BLU01dS8@0P9R@07bDS01hT8P0I7ad051XH01HL6P0I7ad05A/I01@L600A6QD05b0K01TP700D6QH0
6R0L01dS7`0O92007R0M01/M6P0J71T071hK01XL6@806A/H02L05QPE01PJ5`0G6AH06A/H018D4@0P
8Ql07AlL01HH5@0E61D05Q/G01XP700P9B40;C8^00X?2`0F61D04A<@018D4@0E5A<051@B01<C4@0A
40h061<@014<200F4`l05A@?010?2P0?40/05AHA018C3P0D4`h05A8>014>2P0D3`/05Q8A018A3`0F
5A<051<A00l>300@3`d00P0A40h0100C4Q005A@B01<B400?3P`201@@3`804`l>0P0B3Pd00`0C3`h0
4Ph=010<2`0200l;2P0A00l;200>2@H03PX601HE4@0@3Pl0@41101DF600;30h03`l@02l_;@0C3`h0
4`l=01PC3`0=2PT04Pl>01DA400@30/00P0T81l200l;2P0300h:2@0?2`X040`;00804@d<00P02PH5
01DA400<20L09B4P01DA400D40l03`/:00h:2@<03`/:0P0?2PL0100@2`P04@`9014<2@0A30T600h9
1P0400l:1`0A30T04Pd:01<>2`804@`900H030L4010;200@2`P050l<01D@3@0@2`P500d91P0=00`8
1@0=2@H040`9010<2@0=2@H03PX700l;200:1@@04Pd:00h91P1=B4D0:RDR00d81@0500h91P0300h9
1`0>20P03PP800@03PP800<03@L700h8200>20P00P0?2@T01P0B30`02`D5010:2P0400006A<C03La
<@D03@L700h03@L800h8300@2Pd04@`:00l;0`0@30808alB01@A0P0;1`406QH=010;1`0>20P050hB
00h82P803@L9018030H800d72@0>20X04@/=00h82P0:10H02`D700d72@0>20X030H8010:300C3@l0
3@L900/51`0@2P`030H800/51`0<1PP200h82P0:00/51`0900@040D;01L<4P0B1`d0;b@Z01P=4`0?
10X04@H<01<83P804@H<00<04PL=ooooooooool04_ooool001_ooooo00X03PhF00l?5`0821001`P=
00l@5@0A4QL03@hB00h?4P0?4180414C0P0B4aD0600=31403`hC01<B5`0<2a00:bX_04A3B00P7b@0
4a8G02DT:@1JFEh05aHK00@3200@3aD04A0E018A5P0@3a@030`>00X:300@41804a<C010@400A4A40
410@00/;2`80410>00`06ATG00`<2P0?3`d02`/900P81P0@40h051@B00l?3@010@002@T700`>3@01
0`82018D4`080001000?4A003Pl>028T8`0A4a803@l>00T;2P0A4Q4200l?3@0500d=2`0<30X03Ph<
00d=2`0>3P`00P0=3@/02P0B4Q003Ph<00d=300Q8B400P8201hN7@000000=cPc00h?2P0@4@/200l@
200;00d>1P0=3`@04Q<<0042000J6aH030d800H70@0C50l04A8=00l@2P0A4Pd00P0>3`T05@0E5Q40
6Q/F018C3P0>3`X04Q<>01<D3`0;30L04A8=010A30051P<08B8M00d>2@0?40/0Fe]I03Ph=P0C4a40
2@T700<30@0:2PP04a<A00H6100200P81P09014A3`0E5A<030h=00`>3@0>40l05QPG014C4P0[;B`0
4A<B0080418A0`0>40l01`0>3P`0410>01<C4@0C4a404A4?00h>300?3`d00P0>3P`00`0@40h04A4?
010@3P0200h@3`0L02X/:`0N81l03@l>00lA400A4a804Q@C010B4@0?4A004Q@C01LI600;3@X05QPE
00d?300A4a00;S0]00T;200=3``03Q0=01HH5@0B5140418?00`>2`0G71P051TE00X?2`0K81`04aPD
014F4P8041DA00X051TE00P=2@0<4@d05AXF00T;200>40d03a4>00d?300F61D03a4>0P0@4Pl01P0?
4@h04A<@018D4@0B51403a4<00h@2`804Q@?0P0>40/01`0D5Q405ALB01XL5`0H6QD03Q0;010B3@0E
5a800`0B50l01@0A4`h0418=014C3P0>40/03a4<00804A<>0`0B50l04P0A4`h04Q@?018D3`0D5Q40
JfeX01hP6`0<3PX07AlJ014C3P0G6A<04aH?01@G400B5@h03a8;010C300E61405aXC01<F3`8051L@
00T0:B`U00lC300E6Q<02a09018G400Y;RL07b@M01DJ4`0?50d00P0F6a@03`0D6A805a`E01<H4P0D
6A<05AXD01/P6P0O91h05Q/E01`Q6`0O91h02a0:01XO6@0N8ad0EU]E01lT800201LL600B01@I5@0A
5Q804aPD0003000Y;RX061dI01@I5@0F6aL02a0<018I4P0I81T06b8K01DL5@0F7AH06B0I01lV7`0D
6a@06B0I0P0C6Q<04@0H7aL05A`D01/S600K8aP06B<J01XT6`0E7aH082/S01lZ8P0R;BD0934Z01l/
9@0F8a`07BPR020[9@0Q;2H082dV00807b`U07T08C0Y01PX8@0D9Ad06BXR02<d;00W>3008CD/01/_
9`0N<B/08SD_02@g<P0V>CD093Lc020c<00X>cT09STg02i1?`0[?S`09c/i02a0?P0[?cd09c/i02e1
?`0cAdD0=4Q602e1?`0Z?S`0<TI403A8AP0^@T009cTi02@f=P0X>SX0=dU903Y<C00dATH0>4Y:03A6
AP0hBTX0@E=C03]=C@10E5<0?E5E03eBE@0lDE@0@EII03U>D@0mDUD0C65T03aAE016Feh0B5eP03]@
D`0jDU@0B65S05=]KP19Hf@0Bf=U059ZK014Fed0B5eP04YMH@1?HVH0D6=W04mRIP1?HfL0DVM/05]`
M@1HKG80FFic069gO01NLgP0G75f05Y_M01LLGH0EV]`05=XK@1RNG`0KhN905M_L@1aQhX0J7f006=h
N`1ZOX80J7]o06anPP1[OH40KX2406anPP1/Ogl0LHF307:5P@1dPgh0VjBO0=GLe@3Nh]d0O8=l07R3
O@1^OW/0K7mk06n3P@1iS8P0S9fG08RIT`1dQ840MhN407V9R020T900Jg]k08RGVP1fQHP0R9NJ07f<
T01kRhP0Nhb607f>R021TX`0PY>=086ASP22TXl0P92=0080PI6@02L0P92?08:BTP25U9L0QIBG08BC
UP21TI40P92@07n?S`20T8l0PI6@082@S@1kRhP0N8R507N7Q01hR8L0OHf<07R8Q`1cPh00LhAo07>4
OP1ZNgD0QYN@06enMP1VMfl0Gg1X05UZH01>Gdl0EVQE055TD@1<GTh0CV9B051UEP1:GU80CfAH059X
G01AIUd0CVAK04YTF@1>JEX00P17HeD0901<IUd0CFIO04IOF@1IL6X0?EA=04ELDP1KL6L0KhEh02]0
<@0dACX0=4@i02dm<P0Y>Bl0:CPa024`:@0L:bP0;C/k03E3@`1@GUl08c4b02@d=00V=cL09CPf02@g
=@0W>SP0;Shk02lo?00Z>SL09cHa02@c;P0S<Rd09C4]02Hb;P0M:BD08BdY01l[9`807BTU00h072PT
01dY9@0L:2@0<Cdi01dY9@0W<bl07BTU01dV8`0Q:RL08R/X024Z9`0R:bP082TV01`U8P<06b@Q01<0
7BHS01lV900F71X051XH02H/:P0;4@l06AlM03Y0?P0L8R0061hL01XP7P0L8R006AlM01LO6`0C71L0
8R/V02`c;`0G7AT05Q`H00807B8N00D071hK01TK600I6aP06adJ01XL6@0201PJ5`0?01`N6`0N81d0
5ALD00d?300>40d0DUAA038d<@0A4a008BDQ0:jc[`21Qh<04aPD020U8@0C61@0418?00804aDB01h0
51@B01<C4@0A4@l0410>01hJ5`0>2@H09R8O00d<200M7QT04aD@01HH4`0C5A005AD@01LC400C3``0
5A0=01TE500B4@l04A0>018A3`0@3`d05A@B01@C4@0F5A<06aXH01dL6P0J6AL05A@B018>3@0C3`h2
01@@3`04018>3@0?2`X04`l>018>3@<040`;01L040`900L2000H4a001PD101XH6@21PX<05QLI0000
0P0F5QL0DU9@01DA400=2@D0?STe05EAD00A3@`06aLF00<0000?2`X0D4a;010<2`0?2`X03PX900l;
2P02010<2`0701PD4`050@003@T8010<2`0B3Pd04`l>010<2`0200h:2@0300l;2P0=2@P02`L60080
3`X700@040/8014<2@0A30T04@`91P0?2PL00`0@2`P03`X700l:1`03010;2006014<2@0D3``04Pd:
01<>2`0B3@X03PX71@0=2@H0100A3@X061@A01XF4`0F4Pl200l;200600`81@060@004@`900h91P04
00004Pd:1P0>2@H00`0?2@P03`T900h8200200h8200300d71`0>20P03PP800@03PP800H02`D501lI
6@0>20P0618B01@>3P0;1PH600d71`0=010:300>20X03@P500l;0P0J5PX0QX=d06AQDP0J5`P06QH<
00h91@070P002`D700h82P0200d72@0900`6200=1`T03PP:00l92`0>20X040X<014;3@0?2@/02P@6
00802`D700@03@L900h82P0>20X03@L90P0<1PP01P0=1`T03PP:00h82P0<1PP03@8801@93`804@H<
00D030<700X01@0=0PP040D;0146300200l42P0301052ooooooooooo01;ooooo000Kooooo`03014A
6@0B4QX04Q8J00805aPM01@02P/@00`=4@0=3Q403PlA00l@4P0@4A<04A8D018A5P0A41D04Q4F00h=
4P0=31403PdB00X93P0A41D03`lC01LF6`071P/061LL00h=4`803PdB02403`hC010@4P0@41804A4C
010@400>3Ph03`l?010@400?3`l03`l=014A3`0820H04a<A00L71@0?3`d04A4?00h>300:2PP03@d;
00`<2P0F5Q@03@l>018D4`0?4A00418A00P:2@0@4Q409bTX03do?P0@4Q402``;014C4P0:2`X00P0?
3`d0200>3P`03@d;00l?3@0>3P`0410>01<C4@0?3`d03@d;0P0?3`d01P061P@0410>00X:2@0B4Q00
4Q<>010A2`803a0:01003Pl800d>1P0=3PH03@h9014A3P0@40h04A4>00/<200@40h03`l<010@3@0@
40h03@d:00/<200A4@l051@@0P0A4Pd200l@2`0I010A300D5A000`@001LH4`1IFUD09BHQ00l@300L
71X0410>00h>300C4a403@d;018B400=3@/04A4?01HF500?3`d030`:00h>300D5QD04A<B00h@3`0D
5QD02`d<014C4P04010B4@0400lA400>40l03@d;00h>30804A4?00D03`l=00d=2`0C4a404A4?018B
400201@D4P05010@3P0A4a803a4@00X<2`092`X00P0B51<0600>40l03a4@00d?3P0;3@`03Q0?018D
4`0@4Pl030d;00X<2@0B5140:R`Y01<E4P0>40d03@l<010B3`072@H0418?02LY9P0^<bl02a0<00dB
3P0B5a<03A4=014F4P80314=00D04QLC00/@300<4@d03Q<?01LI5P02010B3`0401DG500O8Ah05QPE
018D4@804A<@00T04Q@A01<E4P0D5Q<06adH014C3P0@4Pd03Q0;00d?2P0@4Pd00P0C5A001P082PD0
5ALB00h@2`0E5a804A<>010B3@804Q@?00H03@l:00X<1`0@4Pd0418=018D3`0C5A02010B3@804A<>
0100418=014C3P0A4`h04Q@?018D4@0W:B@0DUA?00h@2`0J71L04A@>01@G400E61404aH?014D3@0B
5@h051L@0P0C5Pl01@0?4P/061/D00X=1`0X;2D04aPA00<051TB01/04aPA00lD3@0@5@h06AhG01/P
6@0F6a@05AXC014F400B5a4051TC01PM5`0L8A/04aPB014F400I7QP0=CXd02@Y8`0F6aD0724K01PM
6@0K81`061dI01`Q7@0G71P05Q/G01LL600Q9R800P0G71P0100H7AT05Q/G01HM5P0H7aP201HM5P0E
01TP6@0E71D05ahG01DL5@0J8AX08RTR03<j<`0K8Q/06b8J01dT6`0H7aL05R0G01`V7P0K9Ad05B0H
01HQ6P0H8ad06RLP01`X8`0K9b<07BPR00808B`V01007BXS01h[900R;bP0<3lh02/k=00S=2`07c0X
01d^9P0N;bL07C0Z024d;P0V>C<08cH`020c;P0U>3@0:chl0P0U>3H02P0Q<c<0;3hn02Tk>`0X?3X0
;D4o02i2@00]@Cl0<DE303I:B00_@d4202i2@080=DU700H0;T9003Y<C01?HF40B5YJ03M9B@0fB4P2
03U;B`110312@P0kCDd0CEmO03i@D00lD4l0?51C03Y?DP0hCE00?U=F03Y?DP10EEP0AEYM04QMH011
EUT0@eQK04UNH@13Fed0A5eO04IPH@1=IfP0Rj>U0;G=c`1>IFL0Bf1S04ePI01?HVH0D6=W04mRIP1>
HVH0DfQ]06AiOP1IKW<0EFY_06=hO@1NLgP0FVmd05ebM`1PMGX0GW=h069gO01PMGT0HGIg069gN01W
O7d0HWMh0765QP1UNGX0J7am06YlOP1]Oh40KX22071oPP1^P840M8R607R:Q`1gQ800NXAn09ZRW02L
Xi`0NX=k07N2O@1fQH80MhV507^>S01dQH<00P1oSh`03P1iRHH0P92=07n?SP1lS8`0QYJF0:jn_P21
T9<0OHb?086@TP20T8d0OXn907f>R01nShT0Oi2:0P21THh03`23Ti00P92?082@S`23Ti80Q9BD08JE
V025U9L0Q9>F08:BTP21TI40P92@07f=S01nSXd0Ohn<07b<R@0207Z:Q`80MXJ303D0L81m06moO01d
QH00LX=m0721N@1[O7@0DfAL06MhKP1@HEL0G6iR04eNCP1AHe00BEa904EGA`1;Gdl0D6EF059VFP1E
JUh0E6YN059WGP1AIel0DFUO04mYG019I5H0BF=G04]UF`1<I5`0AeiG03]BC019GeP0@eQ?03aAB00e
BSh0:clc0352=P0Y>Bh0:3P]02lo=@0Q<2T07B`U028a;P0J:2P07bd]02Hd=@0E8b@0:c/k02Xk>`0Y
?3X0;3lm02Xm>`0V=S<09CDb02Lg=00202Pg<P0C02Dd;`0T<2`08bl[02Da;@0T<2`082`X02@`;00W
<bl08RhZ020/:00W<bl0Ce]G02Te<@0L:2@08BdY01lX9@0S;2T08R/X01hW900201dV8`0301`U8P0K
92406R<P00807RLT00P07bHT02<Y9`0O9B<07R@R02<Y9`1EFeT0GF=Q01/Q7`<061hL01805Q`J01PO
700B6aH06R<N01lV8P0A5a<05A/G01PN6P0E6QH05QPE01DG500G6AH06Q`I01/M6P0A4a005ALD02DW
900J71T201HH5@0;00lA3P0L7Q/02P`901/M6P0U:2D0Jg1/05iTH00J7a/03a@@00`A3@0B51400P0E
5a@07@0E5A<051@B01<C4@0C4Q003`/801`G501FDe005aLB01HG4P0A4`h04Q@?00lA300B4`h05Q<@
01@@3@0F4Pl05A<A00l>300F5A<092<Q024P7P0D4a404A0>010?3@0A40h04a8@01@C4@0A40h04Ph=
00<04`l>00@04@d<010<2`0C3`h04Ph=0P0A3@`05P0B3Pd04Ph;01XE4P0A3@X03Pd900/92P0F5QL0
EeQJ03/l?P0<30d05ADC010<2`0A3@T08A`H03`h=`0=2PT06ADD01PD4`0E4A009B4P014=300@30/2
00h:2@0>00l;2P0@30/030P700h:2@0D40l04`l>00d9200<20L03`/:00d9200>2PT040`;00h:2@0<
20L200l:1`04010;200A30T04@`9014<2@H040/800`04@`900d81@0;1P<030L400l:1`0A30T050l<
018=2P0=20D03PT6014<2@0>2@H500d91P0<00h:1`0?2`P04@d:010<2@0=2@H02`L400`81@0C3P/0
3@P501D@3@0A30T050l<1P0<1`@0100>2@L040X:00l92@0>20P200d71`0300h8200?2@T03PP800<0
3PP800H03`T900h92@0:10@03`T900T4100@2PX600d71`0=00l92@0A30X04`h801XF2`15@CD0jNSH
0=_Ha`1?C3d05A4500`80@0=20<06A<C00h82P0200d72@0400`6200=1`T03PP:00d72@8030H800@0
3@L900h82P0=1`T04@/=0P0<1PP0100F4180618D010:300<1PP200l92`0400h82P0=1`T03@L900`1
1`804@H<00L05P/A00h32@0D2@l04`P>01H;4@0E2Q004PL=008040D;5?ooool001_ooooo00P04a<K
01TI8@0J6R8071dR01TJ7`0<3A8030dA00`=40@03@h@00T04Q4F00l>4`0?3Q<051<H00`;400@3a@0
7A`Q00X93P0510T00P0<2a003@0A41D04Q4G00h=4P0<2a003@`A010@4P0B4Q@02`/=00X:2P0<30`0
3@d=00h>3P0@41000P0B4Q002`0C4a404A4?00/;2@0:2PP01`L500/;2@0<30X04Q8@00d=2`0A4@l0
4A4@00804a<A00X020P601TI5`0H61H05ADC01XJ600f=S@08R8P00h>300B4a403@l<0P0>40d0400=
3``03a4>014C400=3``02`d:00`>2`0>40d03a4>00P91`0K71L07AhI010A30020`001`P300X;1P0=
3PT300d>200;00h?2@0F5a<0BDU900L71`0B4Q8051@D01DE5@0C4a<04A4A010@400>3Ph00P0<30`0
0`0=3PX03a0;010A300200d>2@0K00l@2`0:2`H03a0;01LH4`0B4`h00@8000`=200=3@/02PX800T9
1`0<30X04A4?01LG5@0J6QP04Q8@00@40P0B4Q0061PF01<C4@0=3`h04Q@C00h@3`0D5QD04A<B00lA
400=3`h03Q0?00<0418A00<03a4@010@3P0@40h0100@40h01@0D51804A4?018B400F5Q@051@B0080
3Ph<02403@d;01<C4@0L71X04A4?0000000B4Q004a<A018B400@40h03`l=010@3P0I6aP04A<@01HH
5@0=3``02P`900d?30092`P0418?01PJ5`0<3P/01PP500D710000@0051HC00d?300E5a@030h;00X<
2@0?4@h02P`900L91P0U9b@00P0?4@h01`0B51403Q0=00`>2`0<3P/05QPE00d?300@4Pl00P0?4@h0
200@4Pl04A<@018D4@0L7QT04Q@?014C3P0?4@`03Q0;0P0A4`h01@0o@C`0<S@_04=5@00F61<01`T4
00<04aD@0P0B50l01`0C5A004Q@?010B3@0B50l04aD@018D3`0A4`h00P0@4Pd01`0?4@`0418=010B
3@0H6QD04A<>00X<1`0B50l00P0C5A000`0;3@L03A0900hA2P0200hA2P0400lB2`0C5Pl06A`E014D
3@803a8;00T030l802X^9`0A5Pl08RLP024V7`0:3`P0724J01DJ4`0@5@h00P0G71D0100C61404QL@
010E3`0D6A<201<H4P0E01DJ500C6180724K00lD3P0U:R@010T300`A2`0N8ad061dI01hS7`0?5100
5a`H01HK5`0D6AD041DA01HK5`0m@Sh0<cPd02/`;00D6AD05A`E00806B0I00T05A`E01LN5`0F7AH0
7RDN01@K500F7AH092/T03@k=00J8AX00P0N9Ad07P0H7aL05R0H01hX800N:2005b8L01`W8@0M:280
72PT028^:P0Z=S807BPT020[9`0M:2@06BDQ01`X900T<2`0;chi02@d;`0I:R@062TS01h_:@0S=2h0
8cH`02Lj=@0^@Cd0;D0l02@g=00R=C<0:3/i02Lj>@80:S`l00@0>Ta<03E7A`0Z?S`0;D4o0P0_@d40
D`0]@Cl0;40n0355@`0bAT@0;d=10396A00dB4H0<DE30353@`17FET0?4i>0312@P0kCDd0@E=C03M9
B@0hBTX0B5YJ05=UI@0nD500?U9A03iBEP0kD5<0>4e@041EF00oE5L0AeaO045FF@0oE5L0?U=F04=H
F`14FE`0?EEG04]TI@1LMWL0D6Y[04eUI`1WOh40CF=V04]PH`1;GV80CV5U055TJ01BIFT0DVI[06Un
P`2=XZL0KH:705EZK`1cR8d0KhB905U^L`1NLgP0GgAi05Y_M01RMg`0GgAg06^0P@1PMGH0I7Uj065e
MP1YOGh0JGam06IhNP1/Ngh0N8N:06]jO@1WMWT0Kgn107>6Q01`P7l0MH=o07V4OP2DWIP0PHZ50:2Y
Y01hPgl0NXV6082@S`1kSXd0OXj=086?S`22T900P8j>0080Ohf=00h0PY2@08FCT`1jR8T0NXR907f;
S024TY<0Ohj;08:AS025U8l0PY6<086@R`24Ti00PY6>08FDT@80PY2@00<0RING08ZHV@24TiH00P24
TiH0B023Ti<0PY:B08:BTP1mSH`0OXj=07f=RP1iRHH0MhN407R8Q@1mSHX0NXZ707N7Q01dQGl0L85k
07:3N`1UMVh0KGie06n0MP2IZZ00FV]Q045CA`1:Fd/0AeU603e@?@0oDD40Bem?051UEP1GJel0EV]O
05=YG@1@IE`0D6IM059YG`1=IeX0C6IJ04YTF@1;HUP0BF1F04MNE01@IEh0B5eD03=8?`0Y?C@0=d]0
02i2=`0c@cP0;cld03Q8?@0kBd409C@]0391>P0U=340<Clo02Hd=00R<3408Bl`024a<@0[?3`09STg
02Xm>`0Y?3X09CDb02Hf<`0/?3T0:STd02Pg<P0V=C009S8^02Da;@0T<2`0<3`h02Hb;P807b/W00L0
6bLS01dY9@0S;b/0<Shj02Da;@0I9B407BTU00808R/X01407RLT01TR7`0H8Ah06R<P01/T8@0J8b00
6B8O01lX9@0N9b@05AdJ01/Q7`0S:BL05Q`J028X9P0e>cT0:c4_01`R800401XP7P0801`S800E7QT0
5QlJ01@K5`0E6aL06b4M01LL600E6QH501PJ5`0A01@F4`0F61D06adJ01DG500I6aP0828O00T;200G
6AH06Q`I01TK602CUi<0ADY601`R7P0D6AD05a`H01PM6@0D5Q<00P0C5A8301<C4@0401@C4@0B3Pd0
510?01PF50803`l=01L04QDB01<H500B514051@B01HE4`0C4Q005a<B01DD4P0?3P`051<A01hM6`0K
6QP040l=01<B400A40h040l=014@3P0B4@l03`h<01<?3P0B3Pd04@d<010<2`02014=300J01<?3P0B
3Pd04@d<014=300B3Pd04`l<018=2P0G4Pl02`X600d;30051@H09BHX01TJ700=3Pl05ADC01<?3P0F
4Ph050l;010<2`0P71/0]k>b028N7@0:1PH0AT91014=300@30/300h:2@0=00l;2P0E4A00510?00/7
1P0810@04Ph=00H20@0?2`X03@T800h:2@0@30/03`/:00h:2@0200l:1`04010;200A30T04@`9014<
2@H040/80`0A30T00`0@2`P03`X700l:1`02010;200400d81@0?2PL04@`900h:1`D03@T600d03PX7
00d91P0<20D04@d:01@@3@0@30T03PX700T40@0;1P<03PT601<>2`0;1P<02PD300D03@P500L03`T8
010:2P0?2@T03PP800d71`0<1PH03PP800803`T900T03PP800d71`0=1`L040X:00P20P0M5aL040X:
00l92@0@2PX01P0=1`L03@0<1`@04@`801@?200C3`@0=30T092=OP1gM6D081d>00d9000D40L061<=
00h:200>20P00P0=1`T0200<1PP03@L900h82P0E3a404P`>00h82P0=1`T030H80P0:10H01P090`D0
2P@600h82P0>20X030H800d72@8040X<00X03@L900`6200>20X04PL=0146300>0`T03@8800h32@0<
0@L04`P>0P0E2Q000`0C20h04@H<01873@0Dooooo`006oooool0200>3QH0410H00T94@061``02``A
00`=4P0<3A4030d@0P0<3@l200/<3P0a018A5P0A41D040lD01@C600:2@h04Q4F01DD6@0@3a@030/@
00l>4`0G5Q/03PdB01dL8P0E51T03`hC00`;400>3Q003`lA00`<3P0=3@d03`l?00h>3P0<30`03@d=
014A3`092@L06ATG00P81P0G5aD0410>014A3`0?3`d02PX800h>300;2`T03`l=00/;2@0P81h02`/9
01<C4@0B4Q001PH400T91`0F5Q@06ATG00/;2@0E5A<030d:00d?300200h@3@0B00d?300?4@h05aTF
01<E4P0:30T03Q0=018D4@0?4@h04Q<?00P910061`8051D@01HG4P041@00414<00`=200<3@L03@h8
0P0>3`T03P0`<2d0Ph>301<C4`0=3@d02PX:00d=3@0>3Ph03`l?00h>3P0?3`l0410@00l?3`0?3`d0
3a0;0P0>3`X200d>2@0600P9100=3PT020T500@5000T9B00414<0P0C4a42010@3P0401<C4@0:2PP0
1PH401<C4@805QHD00@03Ph<00/;2@0:30/05ALF0`0?4A00100>40l030h=00d?3P0@4Q42014C4P0G
010B4@0B4Q004A4?014A3`0@40h04A4?018B400A4@l03@d;00h>300B4Q004A4?00X:200W9bD03Ph<
00d=2`0I6AL03Ph<00l?3@0A4@l04a<A018B400?3`d00P0=3@/01@000@005ALD018D4@0620D04A<@
00804Q@A01P03Q0=014C400=3``051HC014C400H6QL03Q0=010B3`0<3P/05ALD00/=2P0=3``06Q`I
03<e<P1GFEH02`d:00h@3@0=3``04A<@010B3`0=3``05aTF014C400>40d200d?300F00h@3@0?4@h0
418?00d?2P0@4Pd061XE01LI500=3`X02`d801XL5`0`<Rd02`d802PZ9@0E5a804Q@?01DG4P0C5A00
418=00d?2P0@4Pd04aD@01@F4@80418=0`0C5A02018D3`06014C3P0B50l04Q@?01<E4002100071hI
0P0A4`h00`0K7AP03Q4;014D3@0201<F3`0=01@G400F6A8041<<01HI4P0=40T05aXC00d@2@0N8AX0
2`l802X_:028SHH0O85j010E3P0201<H4@09010E3P0E6Q<04QL@00lD3@0B5a0051TC01PM5`0G71H0
51TC00805Q/E00T04AH@01/P6P0<4@/07b@N020U7`0B5a404AHB01/P700?51000P0M8Qh201HK5`08
014F4P0Y;RX0314=01TN6P0P9B404aXC01/R6`0M91d201DL5@0a01PO600I81T041L@01LN5`0D6a@0
5ahG01HM5P0J8AT072<K01LN5P0F81P06bDM01XT700E81X08B`V02Ha:`0Q;BT07RXV028^:P0P:bL0
8RdY01hY9@0I9B407RXV02Lc;`0L:bH07blY02Lh<P0/?CL09SLa01TZ900M<2X07S4/02Xm>@0^@Cd0
9CPe01d`;P0W>SP0:3Xi02Xl?00W>CT0<D=302Pj>P0]@Cl0;T9002m3@@0^@T00:3`j02Di=`020396
A080;40n0P0bAT@01@0fB4P0;d5102Pj>P0fB4P0?e5A0080=TQ80400@59B051RHP1CIFD0?U1@045E
E00iCE00?E9E03mDE`16Feh0?U=F049GFP17G5l0@EII04EJG@11EUT0AEYM04iVJ01=IVP0>59C03mI
FP1CJfd0BV9T051WJ@1:Gf80BUeQ04iQI@1CIVX0EFQ/05EYKP1AIV/0I7Un05icN01QMW/0KH:705eb
M`1FJg00GG9g061eNP1MLWL0Igb106MlOP2=XZ<0KH:306AhN@1aQHH0JWio06]nP01[OGl0NXV<092O
XP1eQ8L0IgIi06]jO01/OWh0JGUh07F2P@1gPgl0SYVC08N@R`3<em40OHV607N5Q@20T8l0O8b<0P1m
Rh/02023TI40PHn?07b:RP22T900MhF508fKV`23TI80RYRI0P1lRX/03@1iR8D0P8n:08RGTP25U8l0
PY6<08BCT01mS8T0PY6>08:@T025Ti<0SYbL09:PX@24TiH00P23TYD308>CT`80P92?0500OHf:07N7
Q01eQH80MXJ307:2O`1dQ840NX^507J7P@1_P7T0N8V10721N@1]OWD0BU]A06enM015ET`0BeeA04MH
B012E440>Tdj045C@`1BIUH0FVmP05M[G`1FJel0D6IJ04eRF@1=HeX0D6MO04aVF`1=Ie/0BfEJ04UP
EP17GU@0B5mE03iCBP0mDTT0C65H0355?00bAS`0<44g02De:P0W=b`0<T8g02`l<P0C8Q/0:cXc02<b
;`0c@D405R@T01`Z:`0a?d009CDe02Pi>@0O<S008cHd02Dh=P0V=S<0:SXg02Ti=P0U=2l08C0[01l^
:@0Q;BT08RhZ02Te<@10C4P0=40l028^:P0O:bL07RXV020/:00O:bL062@P028^:P0O:bL072PT01lX
9@0P:BH07BHS01XS80<06b@Q00X06B8O01PQ7P0O:2D07BHS028Y9`0J81h0728P020V900R:2H09R`Z
0P0H7Q`0200G7A/06AlM01XP7P0K8Al05ahK014J5@0G81/05ahJ0P0I7a/0600B61@061dI01/M6P0L
7Q/06Q`I01PJ5`0F61D06A/H01PJ5`0@4Pl05ALD01/M6P0?4@h04Q@A01`N6`0K7AX08bDR0;^o^`1M
HUh04ALC018G4`0J7a/06AhJ018D4@804A<@0P0A4@l0400B4Q004a<A018>3@0T81l04Q4?01`L6P06
20D04QLC01XO6`0F6aL06AXG01XI5`0F5A<06ADD01/J600A40h200T81P0300/:200B4@l04A0>0080
40l=00D04A0>010?3@0<2`T0510?018>3@0200l;2P04014=300B3Pd04Ph=018>3@804@d<01H04`l>
01<?300?2PL05Q4>00/:1P0<2P/04Q8C010A4`082@/030`=014A3`0300004Pd:010;1`0C3`h03``;
02@P7`060P405A4@00L30P0A3@`040`;100>2PT01`091PD05A4@01<?3P0F4Q409b<R00h:2@0@30/0
0P0=2@P2010<2`0400l;2P0?2PL03`X7010;20<04@`91P0@2`P0200A30T05A0=01HA3P0E40d03`X7
00d81@0@2`P04`h;0P0A30T00`0?2PL030P500d91P0400d91P0=010<2@0>2PL02`L4014=2P0D40d0
3PX700l:1`0400004@`900l:1`0@2`P03@P5014<2@0500h91P0700l:200@2PX03`T900h8200=1`L0
30H600h8200200l92@0900h8200=1`L03@L700X4100R71`03`X:014;2`0?2@T03@P800D03@L700h0
3@P601D@300I50h061@<00X6000C3`<08AhA03Lc9`0>2P003`/200d9000F4@/03@P700h820803@L9
00@030H800d72@0>20X02`D70P0:10H0600<1PP03@L900/51`0:10H03PP:014;3@0<1PP02P@600h8
2P0=1`T04@/=010:300=1`T030H800h82P0B1`d03`@:00h32@0;00H05P/A00l42P0=0PP040D;0146
308040D;00<04@H<ooooooooool04_ooool001_ooooo01H04A4I01TI8@0@41P03a0E01@E6P0:2a00
4a@H00d>4@0H6A/00@4301DF60082@/04A0E01<B5`081``030/@04E4B@0Q82D04a8G00`;400?3Q<0
4Q4F0P0>3A804`0@3aD040lD00`;400@3a@01`L900h>400@4180410@00/;2`0@41004Q8B00d=3@0@
40h03Ph=00l?3@0@40h05QHD00@40P0>3P`00P0A4@l00`0?3`d03Ph<00l?3@0200d=2`0700h>300?
3`d03`l=00l?3@0=3@/03Ph<00l?3@02010@3P0=00l@3P082PL0418?00`>2`0C5A803Q0=061RG`1J
G5T06A/H00h@3@082PL0418?00h@2`0400l@2P04010A300?40/03Pl:01DF4@803a0;01004a@?01DE
4`0@41003@d=014A4@0E5AD04Q8B01@D501IFET0Bd];014A4@0E5AD02`/;010A3P0=3PT03Pl:0`0?
40/01P0>3`X03a0;018C3P0B4`h04A8=00l@2`803Ph<00<0410>014A3`0@40h0100@40h0100>3P`0
3`l=014A3`0G6AP201<E500?00h@3`0?4A00418A00d?3P0C5A@03Q0?00lA400I6aX09BLV00l?3@0E
5A<03Ph<014A3`0B4Q004A4?00803`l=0P0>3P`200l?3@803Ph<0P0?3`d2010@3P0=00h>300@40h0
30`:01DE4`0L71X02PX800lA3P0A4a003a4>00h@3@0@4Pl051HC038d<@02014C400400`>2`0>40d0
4A<@00h@3@<03a4>01`0418?014C400B5140418?014C400D5Q<04aDB018D4@0@4Pl03Q0=00`>2`0=
3``03Q0=00d?300B514071hK01@F4`0A4a0051HC00h@3@0A4`h04aD@01@F4@0C5A00418=00h@2`0@
4Pd04Q@?0P0C5A02010B3@80>C/f00@030h901<E400?4@`05ALB0`0B50l201<E4003018D3`0A4`h0
4Q@?00<04aD@00L04Q@?010B3@0@4Pd0418=01DG4P0M7aX06adG00804aH?00H051L@01<F3`0B5@h0
41<<014D3@0C5Pl2014D3@0=01<F3`0H71D07B8K092ESP1dNG8051TB03Hk=00T:B8041D>01<H4@0F
6a@04QL@01@I4P0201<H4P8051TC0P0E6Q@00`0B5a404aPB01DJ500301DJ500>01XO6`0H7AT05a`H
01LL600;40`05a`H01HK5`0K81`06QlK01<H500F6aL061dI02L^9`0N9Ah201XQ6P0601PO600K8Q/0
5A`E01PO600K8Q/06R4J0P0G7QL0300M91d072<L01XQ6P0H8QX06R<M01XS7P0M:28062<N01/V8P0I
9B<06bLU024]:`8082/W02P07bXV01hZ9P0P;2P08BdY01l^:@0L;2L0DfAN01h_:@0O<2X08C8/02@g
<`0P<bl09cXf01ha;`0oDU009CPf02Hh>00]?cl09cTi02/m?`0eAdT0:C/l02Tm>`0^@T00<dM50314
@P0aAD<0>4a:0314@P0aAD<0=4Q603I:B00dB4H0<4A203Q:BP0bA4@0<D=303e?C`0_@D40?e5A0P0k
CDd0E00lCTh0?Dm?04EGE`0gBdX0?E5E049GFP13F5/0@EII04=HF`17G5l0B5eP04UNH@15FUd0AU]N
04aQI01:HV@0BV=T055[K01CKFh0I7an05ifN01;HV@0CF9U051SI`1DIf/0DfIZ05EXK01JKW<0Fg1e
05aaMP1OM7T0H7Ej065fN`1RMg`0HGIk05mdN@1RMg`0IW^006EjO`1TNG/0M8R706j2P@1XO7/0HgMf
06=eM@1bPh<0Lh>307N7Q`1gQXH0K7Yk06]iNP1ZNWX0IgMg06ajNP1fPh80Oh^808:=R01mR880NHF0
07^7Q@1lRXX0OHb<07n>SP21SXl0QI2B08RCU@26TI<0Q8nA08NCT`24T900QI6A08JBTP23Shl0P8b<
086=S025THh0PXj:08B@S027Thl0Q92<08JBT023Shd0RiNE08nKV`80RIFE0340RIFG08NFV@23TYD0
QIBG08NGU`22TY80Pi>C086AT01nSXd0OHf:07R8Q@1_Og`0Lh>007V:Q01gR880MHJ007B5OP1`PGT0
Jgad06MhKP1NKfD0F6UO05=UF@18FTh0A5I8045B@P0oDCh0>D`i04IHB01KKel0EfaM05M[G`1FJel0
EfeQ059WGP1;HEP0DfYR04aSFP1=I5X0CfIL051WG@1ZPGD0IWa`04QNDP0mDTL0>Ti503U:@P0^?cL0
:S/b00809CDZ0180:CT^02<c:@0Q<2T08c8[02He<P0T<S809S@d07N5QP0d@T<0:CTi02dn?P0R=C<0
>4]902Xm>`0^?S/0:c/h02Lg=00X=c8202Lf<@0302Te<@0X=3009c<_00808bl[00H08RhZ01dY9@0I
9B40930/02Da;@0S;b/201l[9`05020/:00N9b@072DR01`U8P0J8b000`0G81d0@`0H8Ah07bPU01`U
8P0J8b007B@R020V900O9B<0728P01PN700I7ad06R0N01LM6`0F71X0728P01hT8P0K8Al05QdJ01@M
600C71L05AdH01LM6@0H7QX05Q`H01TN6P0O8Ah071hK01LI5P0J71T07b4N014C400G6AH05QPE01PJ
5`0Q8b008R@Q01@F4`0E5a@071hK01PJ5`0[;R/0724M01LM6@0C61@04AHB018G4`0D5Q<06adJ02DW
900C4a4071`J010@3P0B4Q004Pl>01<A3`0C4a405AHD00/>2`0@5A403A8>00lD400C5A804a<A014@
3P0E4Q405A@B01@C4@0B4@l00P0?3P`00`0C4Q004A0>014@3P02010?3@803`h<00<04Ph=010<2`0A
3@`00P0D40l00`0@30/03`/:014=3003018>3@0F014=2P0B3@X03`/8018A3@0?3@h0H65R03/l?P0=
3Q003@d>00X:2@0B3Pd04`h<00l:1P0>2PT04@d<010<2`0C3`h05a<B00l;2P0=2@P04Ph=00l;2P80
4Ph=01l030P7010<2`0@30/04Ph=01DA400B3Pd03`/:014=300@30/03`/:014=300B3Pd04`l>02XU
8P0;1P@03@T7010;200C3P/06QDB018=2P0;1P<020<101@?300A30T04`h;00d81@0A30T050l<010;
200<1`@04@`9008040/80P0?2PL03P0>2@H030P501<?300;1`D03@T700h:2@0<20L05Q8?014=2P0@
30T03@T600X60`0<20D03`X70P0>2@H02P0=20D030L4010;200Y92406QDB00X5100?2PL030L400l:
1`0@2`T500l92@0400h8200=1`L03PP800h820803`T900D03PP803D_;`0?2@T040X:018<300600h8
200700h91`0910404Pd700h90`0@30804@d301@@1@0300h:0@0400h:0P0>2@<03PT400d71`D03@L9
1P0<1PP600l92`0601@>4024OX00MFma01H@4P0?2@/03@L90P0A1P`00`0@1@/04PL=00h32@020146
300500l42P0F2a405P/A00l42P0A1P`05?ooool001_ooooo01<04a<K01PH800A4AT0414F01@E6P0>
3a@0414E00`=400A4Q@01`P:00X;3@0<3@l051<H00/:3`0A41D030/@04i=DP0>3A805A@I00802`X?
01/040lD00h=4P0?3Q<030/A018A5P0E51T02`X?00l?4@0@41803@d?00l?3`0<30`03@d=00h>3P0;
2`/03@d;00L71@030`4030`:0000000H61H030`:00l?3@0@40h03`l=010@3P0A4@l00P0>3@T05P0?
3PX040l;010?2`0@3`/04A0<00d<200;2PH030/700h=2@0@4@d03a@@00/@300?51004AHB01lT802b
][<0XJJR02ld<0083@T03A8>014F4P0:30H200l@200F00l@2@0?40X03a0:018C3@0m?ST0820N01PH
5P0?3`d051@B01HF500?3`d030`:010@3P0B4Q00410>00/;2@0R8R00820N00P81P071`D02@T700l@
3080414<0`0?40/300h?2P<03@h90P0>3P`01@0?3`d03Ph<00h>300=3@/04Q8@00805ADC00/030`:
00X:200B4Q000@<201@F5@1HFUT051HE0001000G6AP030h=01hP7`0200`>3@0802d_;P0[;B`03`l=
01LG5@0@40h0000000T91`0G5aD2010@3P803`l=0P0@40h200l>2P8040l;0P0A40`0200;2PH04a8>
00l>2P0=30P04a8>00l@2`0?4@h0418?0`0?4@h01`0@4Pl02`d:00`>2`092`P0418?00h@3@0=3``0
0P0A4@l3010@3P0@00l?3@0B4Q00410>010@3P0B4Q004A4?00l?3@0C5A803Q0=010B3`0B51403Q0=
00/=2P0D5Q<06adJ01<E4P80418?00L030h;01<E400C5A004aD@014C3P0>40/030h900804A<>0P0B
50l04@0A4`h0418=00h@2`0210005QPC014C3P0I6aH030h9010B3@0A4`h04aD@01@F4@0E5a804aD@
00lA300@4Pd04Q@?00804A<>0P0@4Pd01`0A4`h0418=00h@2`0@4Pd05aTC01TL5@0F6A800P0B5@h0
300D5a004aH?00d@2@0?4P/05QTB00d@2@0;3PL04QH?00dB2`0S:24061dF014F3`803a@=00D04QL@
01DJ4`0@5@h05AXC01@I4P0201<H4P8051TC0P0E6Q@201<H4P@051TC00X05AXF01HK5`0G71P0724M
0456@P0J7a/061dI01DJ5P0F6aL06AhJ0P0H7AT0100H7aP051/D01@K500F7AH201<J4`0901HM5P0H
7aP06B0I01LN5`0H7aP06b8K01TP6@0J8AX06b8K00806B8M00L0624L014L600R;BX06B<R024]:`0H
92806RHT00807bTX01T07RPW01hZ:00P;2X082`Z02@c<00U=34062PU02De<P0Y>CH08C4^01lb<00Q
=3808SDc02<f=00^@3l0;Clo02Pj>P0Y>c`0:cdo02`n@00/?T40:S`n02i2@@0aAD<0=TY80080<TI4
04P0>4a:0396A00`A480<TI403I:B00hC4X0=d]902do?`0fB4P0>4Y:03e?C`12E5@0A5IF03I8B00k
CDd0>D];03mAD@0iBd/0=DU8049FF@0oE5L0BEiQ04MLG`10EEP0A5UL04QMH01;H6<0AeaO04QMH01>
HfH0Bf=U04URH`1;IFH0CFMX05I^L01=IFL0BV5S051UJ01BIFT0F6]_05MZKP1HJfl0FVic05U^L`1L
LGH0HGIk06AiOP1WO840J7f206EjO`1TNGh0IW^006MlP@1VNh00Jh2206f1P01]Ogl0MHN706IhN01j
RXX0S9bL0761P@1ePh@0MXB506mmOP1`OWl0M8:407>1PP1ePh@0NhZ807j=RP1oRhL207^7P`0A082=
R`21Shl0Ohf>07b:S@22SI40Q8nC08NBUP26TI<0QI2B08JAT`21SHd0PXj>08>?S@21SH/0P8b:08:>
S028U9000P25THd0H@23Sh/0PHf908ZFU02:UY@0T9bJ096MW@2;UiL0SIVI08jKW02:V9/0QiJI08RG
VP28V9P0QIFE08JFUP22TY40Ohn>07f=RP1iRHH0MXJ307Z:Q`1nShT0NHZ307>4O01`PGT0K7ed06Mh
KP1SM6X0GVmT05U[G`1AHeL0AEM:04AFB012Dd<0@eE2041C@01:G4`0F6aL059WF01=HED0DVMK04aR
EP19GUD0C69J04iUG@1BJF40BF1H04AKD@17G5<0K89f07J<O`0iCD40=DPm03E6?P0a@SX0:3Tc02Df
<00V=R`08S8W024a9P0^?S@07RdV02Lf;`0b@Ch0;cdm01HT900lBT/0@Dm@05YZJP0[?3`07C0^03]>
C00_@T00:SXg0310?@0U=C80:3Lb02Th<`0X=c809S8^02Da;@0Q;BT07b/W020/:00Q;BT07RXV01`X
900T<2`08BdY01l[9`0N:RH06bLS01TU8@0O:2D06b@Q01XS800I8Ql00`0G81d0200K924092dZ020Y
9P0K92406b8P01TO7@0H7Q`06AlM0P0K8Al02P0J81h05A/I018H5P0F71X06R0N01LM6`0G7Q/0624L
01LP6`0G7QX301HL600301LL600I6aP06A/H00806A/H02@06adJ014C400H6QL05aTF01`N6`0T9R<0
7AlL01DG500C5A805aTF01DG500B5A804aPD010F4P0A5Q804aPD01@I5@0E5a@03Q0=01TK600?3`d0
5aLE010@3P0E5A<040h?01`J6`092@T01`T801lS8P0;3P`04QPF00lE4`0C5QD05ADE00T92@0;2@X2
010?3@04014@3P0@3`d04A0>01HE4`804A0>0P0@3`d200l>300801@@3`0E4A004`l>014=300@30/0
4@d<00h:2@0?2`X2010<2`0H00l;2P0>2PL04`h;01@@30081`<00@0002LW:00G61X0BT]=028R8`0E
5A<00`0002@P70070P003PX9010<2`0?2`X040`;018>3@0<20L040`;01@@3`0>2PT030P70`0@30/0
2@0>2PT03`/:018>3@0B3Pd04@d<00`81`0=2@P03PX900l;2P0200h:2@0A01D@3@0<1`@04@`900l:
1`0910402`H300/61@0G4Pl05Q4>00d81P0400001`8000h91P0B3@X05a8?01<>2`0>2@H00`0@2`P2
00l:1`0J00h91P0>2PL07a/H00`81@070`800`00044m>P1eLFh061@A00d91P0<20D04@d:00h:1`0<
1`@03@P500/60`0?2PL04Pd:014<2@0G4Pl0100000`7100k=S<06A@A00D0000;1PD6010:2P0500l9
2@0>20P03PP800h8200=1`L00P0;1@D0100>2@T01`4100X4100=1`L500h8200700h91`0>2@D03PT5
00`70`0C3PP030L101<?1`0300h90`803PT500<03PT600d71`0=1`T0100=1`T600`620H03`T;00`0
2@<509jHVP2MUiT03`T;014<3@0D3Q003`@:0146300D2@l030470146300<0@L2014630805@X@0P0A
1P`Dooooo`006oooool0800821003@dE00X:4P0<3A8051DJ018C60082@d04a@G01LH6P0A4Q@010D7
00l@4P0:2@h030/@01@C600H5a`01`H;01LF6`0=314030/@014@5@0?3Q<030/@00h=4P0:2@l051<H
00l>4`0:2@h06ATK00P82P0?3a40410@0P0>3Ph02@0?3`l0410@00d=2`0G5aD0820N01@D4P0F5Q@0
1@D300d=2`02010@3P803Ph<00@03`l=00h=2@0>3@T03`h:0`0@3`/0;@0B4@d03`h:00d<200<2`L0
3@`800P91@0:3`/03A8>00D:1P0;40`06AhJ05MLF01BEe<05a`H00/@30093PX03Q<?00P;1@0<3@D0
3@h600l@2@0A4P`04Q<=04]<A`2GV9<0=3@b010@3P0;2`T03`l=010@3P0>3`X030`:00h?2`0@4@`0
3Ph<01PI5@0>3`X01PH401HF4`0I6QD04a<A00l@2`0B4`h04A8=010A300200l@2`03014B3@0@4@`0
3a0;00803Pl:02403a0;00l?3@0?3`d0410>00l?3@0>3P`03@d;00h>300B4Q005ADC010@3P0=3@/0
3Ph<00H81`0M7ah07b4P07EgMP0/;Rd01@H500T;2P0@4Q404A<B00X<2`082PT03a4@010@3P0=3@/0
6ATG01LG5@0?3`d030`:014A3`0@40h00P0?3`d0100@40h04A4?00l>2P0?3PX2010?2`804A0<00X0
3Pd901DD400@3`/03@`8018A3@0A4Pd04A4?01LI5P0H6QL04Q@A0P0<3P/020082PL061XG00/=2P0D
5Q<03Q0=00/=2P0B4Q004A4?0P0@40h00`0?3`d03Ph<018B4002010@3P0<014A3`0?3`d03@d;00/=
2P0B51405ALD010B3`0>40d04aDB018D4@0G6AH04Q@A0P0@4Pl01@0=3``03Q0;00lA300@4Pd04A<>
00803a4<1P0A4`h01P0B50l061XE01PJ5@0;3@P06A/F00H80`803a4<00L0418=014C3P0A4`h04A<>
00lA300@4Pd04A<>00<0418=00P04Q@?01DG4P0D5Q40418=00lA300D5Q005QTB01<F3`8041<<00P0
4QD>01PK500B5@h041<<01@G400<3`P05APA02@X8@803A8;00T04aPA02<X8@0G71D04aPA01XO600L
8AX04AH?01TN5`0F6a@00P0C618201@I4`805AXD0P0G71H201HK5@0E01LL5P0H7AL06QlK010E4@0F
6aL08RLS05MLF00Q9R805a`H01@I5@0G71P06AhJ01@I5@0F6aL05A`E01<J4`0E71D06B0I01/R6`0L
8a`05ahG008061lH00l05QdF01PO600N9Ah06B0I01/R6`0M91d06b@O01XS7P0H8A`051lK01TT8@0J
92<05b<Q020/:P0J9R@00`0N:2L07`0N:RP082`Z024]:`0N;BX09cLd00lO700^?S/09SHc01h^:`0D
9bD08cHd02Tl>P0aA4808S@c02@f=P0dATH0;Cm003A6B00gBD/0;Cm202Xl?P0^@T40;d=103=7A@0_
@d40;T9003=7A@0aAD<0;d=10314@P0fBTP00P0jCT`203Y<C00G03I8B00dATH0?e5A03U;B`0nD500
>de=03a>CP0nD500=DM704eQH016FUd0AU]N04QMH016Feh0@5EH03iCEP18GF00Bf1S04QMH01:Gf80
CfAW04aTIP18HF800P1;IFH01@1GKg40CVIX05=YK01AIVT0DfIZ00<0FVea02d0Ffmd05Y_M01LLGH0
H7Ej06AiOP1WO840IGYo069gO01SN7d0IW^006QmPP1YOX<0KH:406YnO@1/OWh0LhF506MiN@1kRh/0
Ri^K07F5Q@1gQHH0N8J707B2P`1fQ8D0NhV;07^9S01mRh`0P8j?082?S01oRhL0NhN307f9Q@22THl0
Q9:C082>S`1jR8/0OhZ>08:=T@29U9P0RIBF08NBU023SY00P8b<086=S@22SX`00P21SH/01P24T8h0
Qi>?08NCS`29UI40Q92<086=R@80RiNE00H0Si^I08fIV@29UID0S9RH08jIV`29UiX208JEV01508JF
UP25UID0QYJF086AT01oShh0OHf:07b<R@1nSX/0PY:?07j?R@1gR840L85i06enMP1ZNg80IWM]06Qi
K`1SMFX0GFmS05AVFP17FD`0AeU904=DA015Ed@0A5M404aNCP1DJ5P0CF9C04UMD@1@IET0B5iB04IK
DP1?IEd0CFAL05A[I@1GKVL0EfiT04eRF@19Ge<0=de003]?@`0kCD80>T]103E6@00]?ST0:CXd01LW
700[>c005bLL028b:00K:R<0;3/d01h]:P0jB4P0<Clo02Pf=`0W=CH08c<c02<d=00O<S00;T4o024d
<P0T=340;cll02<c<00X=c80:CPc02Pg<P0U<Bd08bl[00<07b/W00@08BdY020/:00P;2P08bl[0P0N
:RH01@0P;2P07BTU01XV8P0Q:RL06b@Q00806B8O0P0H8Ah00`0E7Q/051dJ01XS800201XS800801lV
900M8b406R0N01dS8@0P9R@07bDS01/Q7`0H7Q`201LM6`0M01TO7@0K8Al072<P01TR7@0H8A`061lK
01LM6@0H7QX07R@P01lT800K7AX06A/H01XL6@0I6aP05aTF014C400O8Ah0828O01dO700D5Q<04Q@A
01@F4`0C5A805QPE01XL6@0F6QH03a@@00hD400@5A400P0D6AD0500C5A804A<@01TK600B4Q005ADC
010@3P0B4Q0040h?00h<3@0I6QX041@C00T=300H7Q`07B<Q05QNG00I7A`03Q0?01@D500D4Q<04A0>
0P0B4@l200l>3003018A3`0A40h04A0>008040l=0P0?3P`01`0B3Pd05A4@01<?3P0?2`X03PX9018>
3@0A3@`00P0B3Pd2014=300?00l;200B3@X04Pd:01XI5@0G5AH00`<400h?4@1dMGL05aPI01HF500V
8R40HUiJ01TD400D40l040`;00802PH500T03`/:010<2`0C3`h06ADD01HB4@0?2`X04@d<01DA400?
2`X00P0<20L0100>2PT040`;014=300>2PT200d9200<00h:2@0?2`X040`;00P30@0?2PL05A0=014<
2@0?2PL05A0=00l:1`0@2`P03`X70P0B3@X01`0P6aP04@`900d81@0?2PL03@P500l:1`0D3``00P0@
2`P200l:1`0A00h91P091@<0510=00l;200E4@h01P8000<0000R7Q/04@d:00P40@0:1P<04Ph;00l;
20091@802`H300d81@0>2@H00P0B3@X01`0?2PL01`8000h91P0:1@@01000018=2P0F4@l01@0?2@T0
100@2PX03`T900l92@0>20P200d71`0601<=3@0L5QH040X:00T30`0<1PH02`D51P0>20P01P0?2PL0
30L300h91@0H4a003@P4014<20<03PT500@03PT600h91@0>2@H03@L72`0=1`T700h82P0=02hX:P11
>cd040X<020J700U7b404`P>00h32@0A1P`02P0501D:400?10X03P<900l42P020146300300l42P0>
0`Wooooo01?ooooo000Kooooo`0401<C6`0A4AT03@dE00`=4P80414F01T0414E00d>4@082@/04a@F
014B500?41805A@I00l>4`061PX030/@00d<4@0B4AH030/@00h=4P0@3a@03@`A01TH7@0V9BX03PdC
00X93P0D4aP030/@00l?4@0>3Q00410B00803`l?00l030`<00l?3`0D51@03@d;030`;P2XZ:H0:BTW
010@3P0>3P`0410>014A3`0@40h030`:00X:200;2`T00P0>3@T01@0?3PX040l;010?2`0@3`/04Q4=
00804a8>01404A0<00d<200?4@d01``800dB3P0@5A402Pl;01TN6P083@T04aPD00/@300?51001P/7
00hC3`0;3`P03a4600l@2002010A2@08010A2`0T9Al0DE9=018B400=3@`04Q8B010@400=3PX200h?
2@0300h?2P0?40X03Pl:008030d700D04Q<=00/<1`0A4P`061TC010A3002014B3@03010A300?40/0
3a0;0080414<00D03a0;00h?2P0=3PT03@h9010@3P03014A3`0F010@3P0?3`d09BDS01`L6P0?3`d0
3Ph<010@3P0?3`d03@l>00L81`0A4a80:B/Z00X<2`0@4Q404A<B00/=300=3`h04Q@C00d?3P0A4a80
6QXH00P81`804A4@00@03@d;010@3P0A4@l0410>0P0?3`d0100@40h04A4?00l>2P0?3PX2010?2`@0
4A0<01803Pd9010?2`0A40`03@d900/;2@0K7AX07b4N01DG500=3``0418?014C400L7Q/03@l<014C
400?4@h03@l<018B400A4@l3010@3P0800l?3@0B4Q003`l=00l?3@0A4@l0410>00h>300X:RL200X<
2@09010B3`0?4@h03Q0=00lA3P0A4a00418?014C400B51404A<@00<04aD@00@04Q@?014C3P0A4`h0
4Q@?100A4`h03@0B50l04aD@01<E40082PD04Q@?00/=200B50l04aD@018D3`0A4`h0418=00lA300@
4Pd00P0A4`h01@0B50l0418=00lA300?4@`04A<>008051HA00<04Q@?014C3P0B50h00`0B5@h201<F
3`0B01@G400B5@h05APA01LJ4`0@4``07B0I02lc;00>4@d05a`E01TN5`0D6A804aPA01@I4P0N8a`0
7B8K018G400G71D051TB0P0C618201@I4`805AXD00/06AhH01PM5`0G71H05AXD01HK5@0H7AL0724M
014F4P0L8Ad04aPD02P]:@0201@I5@0301LL600I7QX05a`H00805AXF00H06B0I01PO600D6a@05QdF
01/R6`0M91d301TP6@0?01LN5`0H7aP07RDN01/Q7@0M8al07R@P01dV8@0M9R8072DR02@_:`0nBDH0
7BLV01TU9@0N:RX09S8b00<082XY01/082`Z028^;00S;bd07bh[02Dd<@0N;R/0;cll02Hf<`0eAD80
:Sdk02@g=@0Y?3X0AeUI03Q:BP0Z?3`0BeeO0312A00[?Cl0<D=70312AP0bA4H0;d=202i2@00bAT@0
<4A202i2@00aAD<00P0`A480200bAT@0>4a:03Y>C00iCD/0<TA403=5A@0gBDT0>de=0P11De<204mQ
H@0L04=EE@18FUX0C5iN05EYJ01?HfH0C65T04=HF`15FUd0B5eP041EF01=HVD0D6EX04iSIP1@IFP0
E6U/055YJ`1>IfT0CfUZ04]UIP1?IfT0AemQ05AZK@1BIfX0E6M[05a_L`1ML7@0Ffib05eaMP80GW=h
00D0GgAi065fN`1SN7d0IW^006QmPP0206YoQ080J7f205T0Jgn006f0OP1bQH<0LHB207:5P`1jRXT0
NhZ907^9R@1jR8P0OHZ:07^7Q`1lR8P0Q8nB08F@U023TI80QI>C08BCT@21T8`0Ohj9086@S026U9@0
QYBE08>ATP20Rhl0QXnF08VBV@2@VIh0U9fR096JW`29TiD0QHn@08J@T@26T8l0Q8n;08F@S02:UI40
RIB@08ZET@2?VYH0S9NC08JAS@2;UI@0SINF092JV@2=UiP0RYBE08jHV@2?VI/0RYRK08ZIW027UYT0
QIFE08NGU`28V9P0Pi>B086AT01lS8T0NXZ707b<R@1jRXH0NX^507B5O@1]OWH0JW]a06IgK@1RLfT0
HWAX05QZGP1@HUH0Bee?045CA@10DT80A5E504MIAP1:GDX0CV1@04mSD`19GTl0BEeA04mTF01;HED0
C65H05=YH01@Iel0DVMR04mTGP1=HUT0@eQ?03mDB00203M<?@0L03A7>`0_@3H0;Sdh02Xi=@0Q<2/0
72`Q02Lg;00M;B80CemE03e<A@0S<R/0:3Ld02Hd=00J:2P0;C/l02@b<`0[>c/0:c`l02Xm>`0/?cd0
>Te;02hn>`0I:BH08S8_02Lf<@0Y>3<0:3Lb02@`;0<08BdY0P0P;2P0>P0R;RX08bl[01hZ9P0L:2@0
7RXV028^:P0Q;BT082`X024Z9`0L9B806b@Q01XS800I8Ql05b0M01<L6@0E7Q/072DR01TR7`0G81d0
6b8P01/Q7`0I7ad06R0N01`R800K8Al06AlM01hT8P0Q9bD0728P01TO7@0Q9bD08BPU01PQ700G81/0
620K01TO6`0J81`082DQ01hS7`0I6aP05QPE01XL6@0K7AX0828O01TK600M7a`05ALD01/M6P0H6QL0
4aDB01TK600H6QL04Q@A01@F4`0F6QH04AHB010F4P0B5a<201<H500F014C400B514051HC018B400C
4a4051@B010@3P0A3a005QDE010A400I7A`0BDe<02hd<P18CT`0^Knm02``;`0=3`h05AHE00d<3@0?
3P`040l=014@3P8040l=00<04Q4?014@3P0A40h00P0@3`d200l>3008010<2`0B3Pd04@d<00l;2P0@
30/0510?010<2`0A3@`2018>3@0I014=300@30T04Pd:014=2P0Z:BD04Q0A00d>3`0?41803PlA00l?
40092@L05A4@01TE4@0;1P<04Ph=01@@3`0H51<05Q8A014=300@30/04@d<01LC4P0J5QD04`l>00l;
2P02018>3@0M010<2`0?2`X03`/:01<?3P0E4A004Ph=00l;2P0>2PT03`/:01<?3P0E4A004@`900X5
0`0?2PL05A0=00d81@0910<03PT700`71@0@2`P040/900L20@0A30/04@`9010;200E40d050l<010;
200A30T00P0@2`P200l:1`0:00h91P0A3@X01`@200l;200=2@L02`P6018>2`0=2@L040`900l;20<0
3PX700d03PT601PC400M61D040/800`7100@2`P050l<00h91P0>2@L03@P501HA3P0G4Pl030L600D0
3@L70`0?2@T200h8200700d71`0B30`0<B/[00d71`0<1PH04`d=00l92@0600h820803@P500P04@`:
01dG5`0A30X03PP700h9200>2@L03PT800h820803PT700<03@L800d72@0=1`T00`0=1`T<00h82P0>
00l92`0A2`d04P`>01@>400910D05a4C00h32@0=0PP04PL=01D:400>10T04`P>00l42P0A1P`200l4
2P030146300?10[ooooo01?ooooo000Kooooo`0C00d=5@092A4020P@00X;400@4AH05QLL010A5@0J
6ah03PlA00H72@0@4A<02@X<00D42@0:2@h01`H;02`[<00=31404Q4F014@5@0200`;400N00d<4@0E
51T07QdR018A5`0F5AX04A0E00d<4@0<30h05aLI00d=3`0A4A405ADE00h>3P0<30`04Q8B01@D4P0O
7ad0CTi<00P81`0A4@l061PF00l?3@0@40h03`l=00`<2P0:2PP02`/900l=2@0@3@P04@h91P0B3`X0
6`0A3PT040d800P:1P0F71P01`d900P>2P052`L03aDA00`B3P0E6aL02@l;00P>2P093`/051XF00lC
300B50T04A8:00l@200=3PH030d701@E400T9B006a/I00l?3P0;2`/03`l?010A3@0300l@20803Pl7
00L05AH>00X;0`0720005AH>00L8000310003Pl900803Pl:100?40/2010A300300l@2`0>3`X030d8
00803Ph<0`0@40h06@0?3`d0<S8`02LW9@0D51802`/900`<2P0=3@/061XI0001000J71/0008100h@
3`0C51<04Q@C014C4P0620L02P`;018D4`072@P01PH402DU8`1@D4h03@d;018B4@0D51800P0?3`d2
00h>30803`l=00@03`h:014>2@0B3`X04Pl:0P0C40/201@A300A01HC3P0H5A005Q<>014@300<30X0
418?018D4@0?4@h030h;00d?300C5A803Q0=00d?30092`P03a4>00`>2`0?3`d00`0@40h3014A3`0>
00l?3@0@40h04Q8@014A3`0@40h0>C/h00h@3@0<3P/04Q@A00X<2@0620D03a4>00h@3@0?4@h3010B
3`0401HH4`0D5Q404Q@?014C3P80418=00@04Q@?010B3@0@4Pd0418=0P0B50l01`0C5A003a4<00h@
2`0E5a8010H101LI500C5A000P0B50l2010B3@09014C3P0B50l04Q@?01<E400A4`h0418=00lA300@
4Pd04A<>0080418=00@04Q@?01HH4P0E61404aH?0P0B5@h301@G400801LJ4`0D5a0030l800/>1`0D
61403Q<<01HK500;40T2018G400601HK500E6Q<05AXC018G400A5Pl051TB0P0C618201@I4`805AXD
01L06QlI01TN600F6aD051TC01DJ500G71H07R<O00`A3@0=4Ph082DQ01hS7`0I7QX05AXF01XO6`0F
6aL0724M02P]:@0K81`07RDN01lV7`0K8Q/06B0I01dT7@0401XQ6P8061lH00d072<L01`R7P0L8Qh0
728N01/T8@0M9R<07RLT00dG5P1aNgX0;cTh028^;P0T<3005b<S00808B//01P08R`]028^;P0U<C40
9S8b028`<00P;bh072`[02De=00Q<C00;Shm02Hi=`0]@3h08cHd02<e=@0S=CH0;Cm103e?D@0a@dH0
:C/o02Xl@00`@TH0=4I80355A00^@T0203=7A@0]0314@P0cAdD0<DE303I:B00kCdd0?U9@03Y>C00g
BdT0?U1@03Y<C00iBd/0=4I60312@P1=Gel0GFm_04YLG01=Gel0D69R04]MG@0nDU40G71c04EJG@1<
HF@0D6EX04AIG011EUT0B5eP04iSIP1<HF@0CV=V059WJP1>IVP0CFIX04QRH`1DKVl0DFU[05E]K`1I
L780EFY]05IYK@1PLgL0HGAh05iaM@1PM7P0HGIk0080H7Ej00l0HWMl06AiOP1XOH80KH:706n4R@1/
PHH0IGYo06AiOP1VNW/0IGQf06j1O`1aPh40OHf<08BDT`1iR8P00P1kRHT02022Shl0PXj>08>?S`27
TYD0R9>G08JAT`26Ti@0R9JF0P27Ui@02028V9D0RYRH08bGV@2;UYP0RYFJ08bEW02;U9/0S9FJ0P2@
VIh02@2<UYP0RiFF08^EUP2:U9<0R9>?08VDT02=V9@0SiZF08bGT`0208fHU00<08ZET@2<UYD0SYRG
092JV@2>V9T0S9JG092JV`2>VI/0RYRK08^JW@27UYT0Pi>C0P28V9P0@P25UI@0QYJE086ASP1nSX/0
P92=07R9P`1fQh40LH9j06]lM01WN6h0H75W05UZH01DIUX0@eE803i@@P10DT@0?e5303i@@019FTX0
BUa:04mRC`1AHe<0Cf=C04aQDP1<H5@0C65E059XG01DJF00DFMO055XH01DJF@0CfAN04]PE`10E4/0
>dm303I;?00jC3h0=4Hj0311=`0hAd80@4m;03I5@P0Z>S00:SX_020`9@0U=B/0;Sdf02ln=`0]?3T0
8Bl_02Xh>00T<S<0@Dm@01XZ:P0Y>SX0:3/i02e0?P17FUP0<D4n01XZ9`0Q<Bh09C@_02Lf<@0U=2l0
8bl[024]:@808RhZ00D082`X01`X900N:RH082`X01`X900201hZ9P0401dY9@0O:bL082`X020Y9P80
7BHS00X06b@Q01PQ7P0H8Ah0624N01/T8@0S;2T07BHS01LP7@0H7ad06R0N0`0K8Al02`0M8b40728P
01TO7@0I7ad05Q`J01DK6@0H7Q`06R4N01PQ700G81/05ahJ00<05adI00/05Q/G01LI5P0H6QL061XG
01LI5P0E5a@03a4>01TK600H6QL07R0M014C4002010B3`0701@F4`0F61D051HC01DI5@0C61@04ALC
018G4`0201<H500F018D4@0H6QL04Q@A01@D4P0H61H0820N01DE4`0F5QH02`/;01HH5`0;3`h0720O
01PO7@0740d06R0N00hB4@0Y:bX03@l>00l?3`0=30X03`h<014@3P8040l=00<04Q4?014@3P0A40h0
0P0@3`d200l>300401PD4`0D40l04@d<014=30804`l>00<03@T800l;2P0A3@`00P0C3`h08@0C3``0
100001XF4P010000518C00h>3`0F5aT020T;00d=3P0M7A/01`<201<?2`0K5Q802`L600l;2P0G4a80
510?00`81`0>2PT040`;00h:2@0C3`h040`;00`81`0@30/03@T800h:2@0=2@P02`L600h:2@0A3@`0
3@T800h:2@02010<2`803PX901804@`901D@3@0@2`P02PD201HA3P0P6aP03`X7014<2@0910402PD3
03Pc<01/If@040/801<>2`0L5a@06aHC010;200<1`@2010;20803`X701X03PT601<?300300000`00
018>2`0G4a005Q8?014=2P0F4Pl04`l<00l;200=2@H03PX7018=2P0O6QL081/H00l:1`0<1`@040/8
00d81@070P0040/8014<2@0500002`H300d81PL03@L70`0>20P01@0?2@T02`D501@>3P0@2PX02@<3
00802`D51P0>20P02P0;1@D03`T900`6200D3Q004P`>00`62@0>20`03PP:00h82`0>20X200h820H0
3@L91P0>20X600d72@0>00T31@0A2`d02@<500/51`0F41805a4C00T0100@1@/03P<901X?5@0;0PH0
AS]100l42P0B1`d200h32@0301873@0?10[ooooo01?ooooo000Kooooo`0U018B6P0=3AD02``A00`=
4P0@4AH05aPL00`=4@0l?Cl0<S<e00T:300<3@l0414C00D42@0E51T04A0E0000100=31403PdB014@
5@0;2Pl03`hC00h=4P040`P0000402l^=011@4D04A0E00l>4`0C4aD020P:00h>400F5QH071`L01@D
500=3@d04Q8B00X;200200/;2@0401LG5@0:2PP030`:00d=2`803`l=00H03@d;00`<2P0>3@T03`d9
010=200A3PT3018?2P0=01<@2`0@3@P03P/600l<1`0@3@P03@d9059GD`0_=300314=00lD40093PX0
1``801@I5@0200hC3`0300X?2`0B5a<030l90080414901L03a0900h?2@0>3`T03Pl:0083000@40h0
30`:00l?3@0@41003`l;00l@200@4@/0414:00h?1`0?40X030d601TJ4P0G618030d601<D300@4@/0
30d700`=200200h?2P803a0;00H04A8=018C3P0D5A004a@?014B3@0=3PT200`=200400h?2P0?40/0
3a0;00l?3@802@T70P0:2PP05P0<30X03`l=00h>3P0A4a802`d<01<E500=3`h03Q4@00X<2`0>40l0
51HE01<E500;3@`02@X:01lO7@051@<06a/I00`<2P0=3@/04Q8@00l?3@0>3P`200d=2`0A00h>300?
3`d03`h:010>2P0@3`X04Ph;018@300A40/03@T600l=2@0C4Pd0510=010=2@0?3PX07AdK01@F4`0@
4Pl00P0B51405@0?4@h05ALD00X;2@0@4Pl01PP500h@3@092`P03Ph<00l@300@4@`0410>014B3P0B
4`h0414=00l?3@0@4@`04a<@01<C4@0B4Q003@l<00L91P0200lA3P0400d?300E5a@04A<@00h@3@80
3a4>00<03@l<00h@3@0?4@`00P0>40/03`0?4@`0418=010B3@0C5A00418=00lA300@4Pd04Q@?01<E
400620D06Q`G01@F4@0<3PT04A<>01LI500500lA300X014C3P0C5Pl04aD@01<F400B5@h04A<>018D
3P0C5Pl04Q@?010B300@4``04aD@01TL5@0H6a@04QD>00hA2P0?4P/04aH?01DH4@0F6A8051L@01DH
4@0L7aP06A`E00lC300F6a@061dF00dB2`0Q9Ql03A8;014F3`0A5Q004QLA01DJ500A5Q0061dG01<H
4P0C614051TB01@I4`805AXD00<07B8L01/P6P0H7AP00P0G71P03`0J7a/03a<B018F5@0D61L0720O
00`A3@0M8Ql05a`H01/P700C61@08BHR03Hk=`0N91l05QdF01/R6`0201XQ6P0301hU7P0H7aP06R4J
00806b8K0P0H7aP03@0K8Q/06b4M01/Q7@0J81`06B8M01`U8@0N9b@08bhZ01dX900G8al09S8`028^
;00S;bd00P0Q;B/02P0R;R`08C0]02@c<@0V=3@09cDe02Ph=`0M;B`0;3`k02<c<P0I;2X202Dh=P1?
01lb<00U=cL0;T1102Tk?@0W>C/0<TA603E7B@0bA4P0<49502e1@P0_@d80;40n0355@`0bAT@0<4A2
0396A00cAdD0>De;03mCDP12EUD0>dm>03M;BP0eBDL0=4M503E9A`0oDe40D6=Q08VMW02[_[h0Cf5S
05U]KP1;GV00CEmQ05ibL`2DZJX0BEiQ04QMGP16Fed0?eAG04mTI@1;H680DFIY04mTI@1BIfT0EFY]
05AYK01?J6T0@UaM05QbL`1=IFL0EFe_05I]K`1FJfh0Efa_069fN@1SN7/0H7=g061eN@1RMg`0H7Ej
065fN`1TNGh0Igb106MlO`1XOH00KH2406YmP@1UN7`0I7Mk06UlO01SMW@0LX:107^;RP25UI@0Tj>S
08FDU@1lRX/0OXb=08NDU@0208VDUP0608^FVP27TYP0QI2D08NBU029UiP0RiVI0P2=Vi/02P2=VY/0
SYVK08jIW@2?VZ00UYnV096JW`2=UY/0T9VN09>LX@2DWZ0208jHV@0V08bFUP29Ti80RYBC08nIV02D
WYd0SYVE08^ET`2<UYD0RiFD08jHU`2<UYD0SYRG08bGU`2<UYL0SYZJ08bFV027UIP0RIRK08BCUP20
Si80QIFE08JFUP1kRh/0OHf<07b<RP1mSHX0PI6>07V9QP1gR800LX=k06]lLP1VMfd0G6eS05=UF@18
FTh0=TPj0353<`0hBSX203]=?@0P04YLC01<GTh0CfAC05=UE`1@IEH0Cf=G04eQE@19GU80E6YN05M/
H`1?IE/0DFQP04iUG`16FUL0@5E>03U=A00mD4@0@eE703e?@@0b@cP09cP`02dn>00b@T008c<`02hn
=@0R<RP0;cle02hm=P0]?3D0;3/f02Pg=00[>SL202Pf=P0=02dk>`0/?3/0:c`l02/n?00W>SP09STf
01DU8P0H:B<08S8]02@c;P0U=2l09C<^02<_:`02028^:P0<02<^:P0N:RH06RHR01`W8`0N:RH072LS
020[9`0M:BD06RHR01`W8`0O:RH082TV0P0N9b@02`0L9B80624N01LP7@0D7AX04AXG01DN6`0B6aP0
4AXG01<J600F71X06AlM008061hL00/07B<Q028X9P0M8b406AlM01XP7P0K8Al061hL01TO700J8ah0
6R0L01LM6@0201DK5`0C01DJ5P0G71P071hK01dO700G6AH04aDB01DH5@0C61@06QlK01LJ5`0Q8b00
5QPE01TK600B51405QPE01/M6P0E5A<03Pl=01<H5002014F4P0F01DG500F61D05ALD01PJ5`0?4@h0
410>01DE4`0N7Q`03`l=01@D50061PH05ALF00D71P0<40l041DC01TO7@000@004a@C014A4@0G5aL0
3@/<018A3`804a8@00<03`h<00d<2P0=30X00P0A40h2010?3@803`h<01T07QXI01LC4`0B3Pd04`l@
01@@400A3@`03`/<018>3P0D40l05Q8C01LC4`0H51<05a8?00h:1`0J5QD030/9014A4@0<30`0>CTk
00l?3`040`4040`;00h:200?2PL05Q8A008040`;0P0>2PT0500J5QD04`l>00/71P0?2`X040`;00h:
2@0B3Pd03`/:018>3@0A3@`03PX9014=300D40l040`;01HB4@0J5QD06ADD01<?3P0@30/040/80P09
1042010;200=00X50P0B3@X030L401<>2`0E40d02@@101<>2`0A30T03`X701D@3@0F4@h040/800l:
1`02010;20803`X700`03PT600X60`0E4@h03`/800P40P0<20D01@40014=2P0D40d03PX700`81@0>
2PL2010<2@0<01PC400G4Pl02PD200l:1`0B3@X03PT600d81@0A30T020@200`7100E40d040X91@0>
20P300d71`0800h8200?2@T03`T9018<300;1@D09R0P018<300<1PH700h8200600/51@0A2`/01`83
00d72`0@2Ph030H:0`0>20`200h82P0300h8200=1`T03@L900@03@L91P0>20X600d72@0>01@>400;
1@L0618D00X41P0@2P`0100000`11`0B20d01`0201H;4@0C2Ph0Mfab00`11`0@1@/200/01P030105
2`0<0@Oooooo01?ooooo000Kooooo`0=00d<4P0@3aD04Q4F010?500?3Q<03`lA00P82P0T92H08R8R
010@400;2`/051@D00d=3`02010@4P803Ph@00<04A4C010@4P0@41800P0?3a402`0>3Q003PdA018A
5`0M72406APM00/:3`0A4A<03@d?010@4P0?3`l03Ph>00803`l?00`0414@00X=301:CD`0CU5@018D
4`0A4a0030h;00h>300?40/0414<010?2`0?3PT200h=2@803`h:00`03@`800h=2@0?3PX040l;014@
300@3`/03Pd9010?2`0B4@d04A4<010@2`0?3`X200h>2P0700l?2P0@40/03`l;00d=2@0A4@d0410;
00h>2P02010A2`0<00l@2`0>3`X03Pl:00`=200@4@`05QLB010A300=3PT08b<P02TZ9@0C50h04A8=
0P0>3`X01P0?40/04A8=010A2`0>3`X03@h900h?2P80414<00H03Pl9014B300D5@l04a@>00l@2P0>
3`T2010A2`0E00`=1`0?40X04a@>018C300?40T04Q<<01<D3P0@4@/04A8<00h?2P0?40/03Ph<01@D
4P0L71X05aLE010?3@0<30X05aPE01<E4P0D6AD04aTE00803A8>00L03A4=00l@3P0@40h03@d;00l?
3@0<30X0410>00804A4?00<04Q8@00l?3@0C4a400P0@40h01@0C4a403`l=014A3`0@40d03a0<0080
4A0>01`03`l<014A3`0B4@l03Ph;010?3@0B4Pl030`:02<U8P0@4Pl04A<@01<E4P0>40d04A<@00lA
3P0];b`04Q@A01DG500>3`d03Q0=018D3`0@4`d03Q4:00d@2P0>4@X03a8;01DH4@0H6aD04QD>0P0@
4`d00`0=3`X04Q8@014A3`02010@3P0501<C4@0=3@/04Q8@014A3`0@40h00P0A4@l01P0B4Q004a@?
010A300A4Pd051D@018C3P80414<00T04Q<>01@E400C50l0414<00l@2`0@4@`051D@01DF4@0B4`h0
0P0@4@`00`0P8A`08B8M014B3@0201<D3`0801DG4@0B5@`03a8:018E3@0D5`h051L?018E3@0A50/2
018E3@0301<F3@0C5Ph04aH=00804QD<00@04A@;01<F3@0D5`h05AP?0P0@4`X0:00E60l05aXA01PK
4P0C5`h04QP>01@J4@0E6Q804aPA01<H4P0G71H05Q/G010D4`0F6QX06alO05AHF00D6a<04a/@018I
400B6A4051/C01LN5`0B61@05A/G01@J5`0C6AP05adL01PN7@0K82<05a`P01@I6`0G7Ad06R0O01/Q
800D6QL061hJ01DK5`0Q:2405ahG01TP6@0F7QP201PQ700301LP6`0J8ah06B8M00807BHQ02D09BhY
024Z9@0F7aX07RLR01dW7`0U;bL07RPP01TS6`0N:2407bXS01`W800N:R8082dU01l^9@0N;RD072`T
01l`:@0O<RX083<[024c;@0R=2h08C8^02@e<P0S=S<08cHd02@g=@0V>CL09cXh02@g=P0X?3/0:cln
02e1@00/@3l0:Shm0396A@0aAD@0;T910080;d=303X0;D500397B00bB4H0;TA203I<B@0gCDX0?E=@
03I<B@0^A4<0>4e>03E:CP0oDeT0>4e?03YAB00kDDL0>E1603U?A`1AIf40N8j;08nTY01;Gf<0CF9V
04QMH`1;GVH0DFA[051TI019GEd0B5aK04]OGP1<H600BemN05Q/J`1@I6@0DFET05M[J`1FJVX0DFIV
06ImO`1ILG<0E6a^05I^L01KLgD0EVi`05eeM`1KLgD0G7=f05YbM01IKg80H7Ij06j3R01JKg@0KX:6
06f0Q01[OX40K82006YmOP1/Ogh0KX1o0P1_PGh01P1aP800NHR806ilO@20SY00OXb>08^IW080PY2D
00D0PXnD08>@UP28UI`0RIJM08ZEW00208ZCVP0;08bEV`2>V9d0T9ZP092JW`2EWj@0TI^P09JOY@2C
W:<0TY^Q09ZSZ02?VI/00P2FX:8209BNX00<09:LWP26T980SINI08^EUP2DWZ00SINH08nGV@2?V9P0
TIVJ092JV`2AVi`0T9ZK0P2<V9P03@2=Vi/0SibL08fKV`2;V9T0RiVL08ZGW@29UY`0QiBJ08JCV024
TYD0P8jA07n=S`1mRh`00P1oSHd04@1lRhP0LhAl0762N01WNFd0H79V05]]H@1IJed0FVaM03e??P0d
Ac@0>4/g03Y=>@14F4D0I7U[05I[G`1<HUD0CF9F0080CfEI00<0DVQL055WF`1AIe/00P1CJEd03P1@
IUd0AEaF04EKEP12Ee00?e9903e=@`0mC440>4Ll02ho=@0/?SH0:Sdh02Hk>00/@Cl0<T=20`0c@d40
=@0[>cP093@a02/k>00W>3<0?Tm:0352?@0M;RT08S8_02Ph>00]?Cd09SHd028c;P0]?3D08C4X020]
9@0X=Bd08BhV02Da:`0N:BD0:cHb028/9`0W<2/0:38/02D_:P0P:B@07BLQ01/T7`0O:2<07bTS01`V
8@0M9R407RLR020W8`0P9R807bDQ01XP700O9B409B/W01`R7P0H7QX05adI01DK5`0H7QX072@O01XS
7P0I8Qd06b@O01dV8@0L9B006B8M020Y900K91l0624L00807BHQ00@07B@P01TN700I7A`06AdL0P0G
6aX0300l@3l06alN01/O7P0I7A`03a<B01@H5`0H7A/04APF01DK6@0F6aX05Q/I018F5@805QPG00P0
61PH01LF5P0E4a@04a4B01<C4@0C514051DB01@D4P805ADC02X06ATG01@D4P0@40h04a<A01HF500D
51806QXH00l?3@0C4a40410>014A3`0G5Q@07ahL01HE4`0C40l0518@018@3P0C3`h04Pl>014@3P0F
5A<05A@B010?3@0C4Q005aHD02DT8P0C4Q004A0>00h=2`0C4Q006QHG05=?DP0g<cD04@`@014<3`0=
2@/04@`@014=400A3@l04@`@014=400A3@h2010<2`0;014=300B3Pd04@l=014?3@0e<S804@l=014=
300G4a803`/:01<?3P0>20P00P0F41001@0B30`03`T900h8200@2PX04@/;00804`d=0P0@2PX01P0?
2`X02`L600l;2P0<20L06QHE00d920803`/:010040`;00l;2P0=2@P030P700l:1`0@2`P04@`9018=
2P0A30T040/801@?300J5A804`h;00h91P0E40d04`h;0P0A30T02`0@2`P03`X7010;200B3@X03@P6
00h91P0:1@<04@`900/60`0B3@X040/800@03`X700L040/800`7100F4@h04Pd;00h91P0G4Pl03@P6
00803@P500@040/8014<2@0?2PL03`X70P0@2`P05@0?2PL03PT600h91P0>2@H03`X700h91P0<1`@0
3`X7010;200?2PP02`H300d81P0A30T03PT701D@3@0L5aH04P`<010:2P0A2`/03@L700l92@0200d7
1`0801@>3P0E3`l03@L700`61P090`D06Q@F069LGP0`:R`200l92`0300h82P0;1@L02`D700803@L9
01<04P`>00d72@0;1@L03PP:00d72@0;1@L0618D00h82P0@2P`04P`>00T31@0E3a40618D00h82P06
008030L801@>400@2P`03@L900803`T;0P0>20X00`0=1`T030H801052@0501052@0601@93@0>0`L0
60dA00l6200B1`/03@<65?ooool001_ooooo00P040lE018A5P0A41D04A0E01@D5`0I6A/030`>010@
4@803Ph>00<04a<C018B4P0>3Q000P0@41800`0>3Q003`lA010@4P03010@4P<04A4C00T04Q4G02LV
:`0d<cP06APM010@4P0E5AL0410B00l?3`0>3Ph00P0?3`l02`0?4A004QDD01LK6P0K7ah03a4@00L7
1@0<30X03`l=00l>2P0>3@T03@`800803@`700D03`h:014@300@3`/03@`800`;1`0200d<2003018A
3@0C4Ph04Q4=00@040l;0`0?3PX0100@3`/04Q4=00l>2P0=30P201<B3P03010@300A4Pd04A8=0080
414<0P0?40/0300=3PT051D@01LH4`0>3`X0;RlZ03Hg<P0@4@`03Pl:00d>2@0>3`X03a0;00h?2P80
3@h900H03Pl:00l@2`0?40/04Q<>01<D3P0@4@/200`=1`03014B300=3PP02P/50080414;02802@X4
00l@2P0C50`0414901<D300E5Q004A8<018C3@0>3`X03a0;014A3`0F5Q@06ATG01<C4@0C4Q008R4O
01XK6@0G6AH03Q<?01LM6@052`L02Q0<010E4@0<30X02@T7010?3@0E5A<01PH404I6A00=3@/030`:
01hN700@40h051@B0P0B4Q00:@0D5180410>01<C4@0B4Q0030`:01PH5P0<30X04A4?00h>300@40h0
3@d;00l?3@0C4a403Ph<00<50P0:30T05QPE01<E4P082PL030h;00/=2P0H6QL0FUaI02X/:@0=3``0
3Q0=01/M600E5a803Q0;00`>2@0=3`X03a4<01<E400G6A@0418=00`>2@0@4Pd04Q@?018B400N7Q`0
5aLE00803@d;00@06a/I018B400A4@l0410>0P0A4@l01P0B4Q004a@?014B3@0A4Pd04a@?018C3P<0
4A8=0P0B4`h3014B3@0301@E400E5Q404a@?00804Q<>00<061TD01LH4`0<3@P00P0?40/01`0@4P/0
5QT@018E300B5@`0=CP_03<f;@0F6A000P0B5@`301<F3@03018E300A50/04QD<00<04aH=00P03A07
01DH3`0>4@P03Q4801LJ4@0?4PT04AD=018G408051TC00/04aPB01<H500F6aL05AXF014E500B5QD0
20`;01hR800E71D05A`D01DL5@0301HM5P0W01<I5@0F71P05A/G01@J600H7Q`061hM03@i?00X;C00
61dP01DK6`0D6QX02a4?020V900B61H05Q`H01`S700940T06R4J01HO6P0G81/0624L01dV8@0P:B@0
5QlJ01hW8P0K91l082TT024Z9@0I8Qd072DP01dV8@0R:bH07RLR01XU7`0M:2807bXT01dZ8`0O;2D0
82dV00807bhW01407RlW02<d;00U>C4093La024d;P0P<bh08cHb02@g<`0T=c@09CPf02Hi=`0Y?3X0
:chl02Pl>`0Z?Sd0:cln02a0?`0302i2@@0B02m3@P0aAD@0<TI503A8A`0eBDP0;d=402e1@@0bATD0
<TI404EJE@1ZOgX0=DU703A8B@0lD540>DaB03a?EP0dAd/0?EA<0P0iD4P02P12FE@0>e5>03eCD@16
Fe`0AEYO059WK01DJ6l0AEUP04aQIP18G5`204UMG00604YNG@1=HF00Cf=R059VI@1CIfH0E6QW0P1F
JVT02@1EJFP0FVmb05EZK@1GK6l0G75d05icMP1FJfh0G75d06^0P`0205ebM@0;06YoPP1TNGd0H7Ej
0766R@1YOH00Kh:606j0PP1YNg`0KGmo0761P01cPh400P1cPh00801gQXD0O8Z;075oP01oSHl0Pi6D
08ZHV`23TID0R9FK08ZGW@28UI`0QY>K08ZGW`2=V:00RY>J08^DV`2?V9l0TY^R09FNY@2GX:L0TibS
09FNY@2FWjH0RiBK0;S1a`2ka<T0V::T09FOX@2LYZP0U9jP09FOX@2FX:80RYBF0P23SHl0;@2AVid0
T9ZL096IV`2BVY`0UIfO09BNW`2BW9d0T9ZK09:NWP2AWId0S9ZJ08^IV@2AWil0X:j_09:PX`2@WJ<0
RiRN08FCUP23TI@0PY2C07j<S@1mRh`0O8Z;07j<S01oSHd0O8^807F6OP1bQ7T0Gg5U065cI`1PLVD0
?e530312<P0cAC@0>Tdj03Q;=`0mD3`0DFIC08>GR`1WO7<0CV=J04YOEP1>HeX0DFIM05EZH@0305AY
H00/051UG01;H5L0B5mG04=IDP0lDDP0>da203Q9?P0hB3d0>DTo0392>@0/?cT0:chj02Xo?@0_@d@0
<45102hn?@0dA4<0<40o02Ph=@0Z>SL0:c/h03]<AP1KK6H0?Tm901h_:@0/?3T0;3`l0310@00[>cP0
9CH`02dl=@0S<bT07b`S02Tf;@0W=2/0:C@^01lZ9P0R;BT08BXU02H_:P0X<B`09BhY01lX8`0L9B02
020Y900501lX8`0M9R407bPS020Y900M8al00P0N9200100L8Qh08BLS02H/:00K8Ad201TO6`0B01<I
5@0N92009RdY01PQ700G81/0624L01TR7@0H8A`07BHQ01hW8P0G81/072DP01@M600C71L0;S@a01dQ
800G6aX061`K0P0M8B00300I7A`051PG02<W9P0=3`h05ATH01`P7`0E6QT03Q@B018H5P0I7Q`061`K
01HJ6@805ALF00@05QHF01LE5P0F51D0518C0P0C4a4301@D4P0401DE4`0B4Q004a<A018B40803`l=
01l051@B018B400>3P`06ATG01@D4P0B4Q005aHD01PG5@0?3P`03@T801@@3`0G4a806QDE00`81`0?
3P`04Q4?010?3@0A40h040l=0040000D4a406APF00T81P0N7A/02PT700l;300M6AX061@E014=3P0?
2``02`L800H04@d>0P0B3Pd2014=308040`;00h02@D400l;2P0F4Q404`l>00l;2P0D40l07ALG00P3
0`0400002`D501@>3P0L5QH040X:014;2`804P`<00X04@/;010:2P0B3Pd0510?01TE500?2`X06aLF
00h:2@0@30/03`/:100>2PT300l:1`09010;200A30T04@`9018=2P0A30T07QTF034/:@0D3``03PT6
00804Pd:00P040/800h91P0>2@H040/801@?300>2@H04`h;00/60`<03@P50P0@2`P200h91P0=01@?
30050000100000`71@0>2@H04`h;01TD4@0C3P/03@P500X50P0<1`@03@P500l:1`02010;200E00l:
1`0>2@H03PT6010;200;1P<02PD2014<2@0<1`@02PD2018=2P0H4a004Pd:00H1000B3@X05A0=00l:
200;1@D030H600l92@0=1`L03PP8008040X:010050h>01<=3@0>20P03`T9014;3@0400005@lA01XD
5P0F41804@/=00`6200A2`d02`D700H00P0<1PP02`D70P0=1`T0200?2@/03PP:00/51`0B30h03PP:
00l92`0B30h01P020P0=1`T01P0>20X05a4C00P2100C3@l04P`>00l92`<03@L90`0<1PP601052@06
00L0000C20`01`0000h31`0X7B405``@5?ooool001_ooooo00`04A0F01<B600D4aP04a8G01DD600H
61X04Q8D00h>3`0<30`03`l?014A4@0>3Ph600l?4@0300h>400?3a403`lA00<04A4C00T040lE01TH
7@0O7R<03@`A00h>400A4A<0410B00l?3`0>3Ph00P0?3`l02`0@41001`X900T=300<40l030h=00T9
1`0W9bD04a<A014@300?3PX03Pd900803`h900<03@`8014@300B4@d00P0A40`00`0B4@d030/7010?
2`07014@308040l;00@051<?01LF4P0C4Ph03`h:0P0C4Ph0100A4@`04A8=010A300@4@`200l@2`07
018C3P082@@01@H1010A300=3PT03a0;01DF4@02010A300700l@2`0@4@`04A8=00l@2`0=3PT03Pl:
00l@2`0200h?2P0@014B300E5Q004Q<=00d>200>3`T05QLA01DF400;30H04A8<01TJ500?40X0414;
018C2`0@4@T04a@<01@E3`804A8<00l051D@01<D3`0@40h03`l=00h>300820H07QdK04Q7A@0?40h0
71hK010E4@0A5a<061hJ010F4P0:3`/00P0=3@/02@0B4@l03@d;010@3P2j^[P0:RXX010@3P0>3P`0
3`l=01@D4P02014A3`0M01@D4P0?3`d05QHD014A3`0=3@/04A4?02PX9P0T92804A4?018B400?3`d0
4A4?01@D4P0?3`d03a4>01PJ5`0S9B80828O01LI5P0J71T03a4>00/=2P1ZK6T0:2XW00d?300B5140
61XE01@F4@0?4@`00P0=3`X00`0>40/0418=018D3`02010B3@0;018D3`0D5Q403Ph<018B400K6aT0
5ADC01<C4@0c<c404Q8@014A3`0@40h00P0A4@l0100B4Q004Q<>014B3@0B4`h201<D3`03018C3P0C
50l04A8=00804A8=00<04Q<>01<D3`0A4Pd00P0E5Q402P0D5A004a@?01@E400@4@`051D@014B3@0F
5a805AHA01@F400F6A0201<F3@03038e;00a=2/05aXA00804QD<0P0C5Pd301@G3P0G01DH3`0G6Q40
5aXA01DH3`0D5`h0:RdT01`O5P0B5@`071lF00lB2@0C5a004QLA01@I5@0D6A@04QLC01<H500E6QH0
4aPD01@I5@0G71T041DA01DI5`0E71D00P0F7AH03`0F71P05QdF01DL5@0B61@05A/G01@J5P0C6AD0
5adI01PN700R:2P06b0S01<H6`0F71`06R0P01TO7@0201`R800601HL600;4P/05QdF01TP6@0E7QT0
624L0P0I8Qd01`0L9B00624L01dV8@0I8Qd072DP01lX8`0K91l00P0J8ah0600M9R4072DP01TT7P0J
9Al07BPR01l/9@0P;BH08BhW020_:00Q<2T0834Y01d^9P0R=Rh093La028e;`0U>3<0;D0l02Hi=@0W
>SL0:3/i02Tl>P0/?cd0;T4o02Tm?080:3`k00D0:Cdl02a0?`0_@d80;d=203A8A`0203a@C`0Q03I:
B@0dB4L0<dM803Y>CP0_@d80=4Q604EJE@1GK6L0=d]903A8A`0jCTl0AEQM04AGGP0jCE<0?UA@04=I
EP0jD4d0@5ID04EKF@1;H640CV=U05=XJ`1BIf`0EFU`04EIH01?I6T0C61P051TH`1?Hf80CF5P04iR
H@1AIF@0EFUX0080FFe/00H0EFUX05=WIP1DJ6L0Efa_05EZK@1KL7<205mdM`0@05icMP1IKW40FFia
05ebM@1XOH00LhR;0725R@1/PHH0VJja07:6RP1^PHD0MHN906j0P@1/OWh0Kgmn07:2P@80Lh>001`0
M8>307R6Q`1dPX<0NXR:08:@T`29UiX0QI>G08FBV02:Uid0SY^R08^HX02:Uil0SYRP08nHW`2@VJ00
TY^R09FNY@2FWjH0VJ:Y09>LX`2BVj80UIjU08nHW`2ka<X0^<7609^UY`2DWZ00UZ2R0P2CWIl05P2B
W9h0T9ZL09>MW`2DWZ00UInQ08jHVP2CVid0UIfO09RPXP2GXJ80U9jO092JV`2DX:00TinO08^IV@27
UID0TInO0:Vg]`2DXZD0TIjT08^HWP25TiH208BBU@0I07j<S@1mRh`0OH^<082>SP22T900P8n<07N8
P01]Og@0HG=W069dJ01GJE`0=dTk0394=00jC3/0@EA103e@?@11E400DfQG06AhK@1KL6L0CfAK04YO
EP19GUD0BUmF05EZH@0305I[HP10055VG@1:GeH0@eY@03eCBP0hCT80>T]103e=@`0nCT<0>TY003M7
@@0cAT80<DA202a0@00[?d009CHf02Hf=@0c@d80<40o02Lg=00^?S/08C4^02m0>P12Ddd0;d0j01l`
:P0[>cP0:3Ph02hn?P0[>cP09CH`02dl=@0T=2X082dT02@a:00O;2<092lY024/:00N:BD08BXU01dV
8@0K91l072DP01hW8P0O:2<07RLR01`U800K91l06R<N01`U800M9R408RPT024W8`0M8al06R0L01`R
7P0R:2@06R0L01PN6P0M8al05A/G01lU8@0V;BT0624L01HO6P805b0K00@05AhI01PQ700K91l05QlJ
0P0J8ah04`0L9B00KgAa059FE@0L81l05QXI018F5@0M8B0041@C01<G5P072`X06alN01DI600G6aX0
5a`K01hT8P0@5Q@09R/Y01@H5`0@51<00P0D5QD0100E5AD05Q@E01HD5@0E4a@601@D4P03018B400C
4a404a<A0080410>00T051@B010@3P0B4Q009BDS01dM6`0D51804A0>01@C4@0A40h00P0C3`h0700@
30/04Pd=018>3@0D4a404Q4?00h=2`0C4Q004Q4?01@C4@0F5A<010<102DT8P0R8Al0>cXh02<O7P0:
1PH04Ph=01hJ6`0C3`l040`;018>3`0B3Ph04Ph=018>3`0B3Ph04Ph=00l;2P0@30/2014=30804`l>
00`040`;01TE500D40l03@T8010<2`0G4a80T8Z:03hh>00A2`/04`d=010:2P0>20P6014;2`08018>
3@0>2PT03`/:00@0000G4a803`/:014=300?2`X200d920803`/:00d04@`900h91P0=20D03`X7010;
200A30T04Pd:00T40@0M61D0?3Ld00h91P0:1@803`X7008040/801T03`X7018=2P0D3``0;RTV00T4
0@0@2`P03`X701<>2`0<1`@03PT600l:1`0D3``05A0=018=2P091@<03`X702HQ7P1YI640?cXg00P3
000E40d05Q4>010;200=20D03`X700@040/801803`X700h91P0>2@H03`X700T40@0<1`@05A0=00d8
1@0B3@X0@Sdj03<^:`0@2`P06A@A01@?300<1`@04P`;010:2P0?2@T2010:2P0I00h8200<1PH03@L7
00h8200<1PH02P@400/51@0B30h01@0100L20`070@<01P0201<=3`090`D04P`>00d72@080P@04P`>
00l92`0<1PP03PP:010:300>20X030H800l92`0200d72@0:018<3P090`D03PP:00h82P0400004@/=
00X41P0F4180100001H@4P8030H8100;1@L601052@0601872`0C2P`05``@00X00`14>Cd01`005?oo
ool001_ooooo00d02`X@010?5@0C4QL04A0E00h=4@0<30h02`/=00h>3`0A4A40410@00d=3@0?3`l0
410B00803`lA0P0@4180100?3a403@d?00d=3`0>3Q0300l?4@09014@5P0@3a@02`X?00`;400F5QP0
20P:010@4P0?3`l03Ph>00803`l?00/0410@010B4@0>40l030h=010B4@0?3`d0;bl]018A3`0@3`/0
3`h:010<2@02010=2004014@300E51005QDA01<B3P<04Q4=0`0A40`201@C3`0<014@300B4@d051<?
01<B3P0B4@d05aHB01/J5P0F5A404A0<01<B3P0B4@d03`l:0`0?40/01P0>3`X03@h900T:1@0A4Pd0
61TD010A30804A8=1P0?40/3010A30803a0;0P0=3PT0800?40X04A8<010A2`0@4@/05AH@01hO6@0A
4P`04a@>024R700J6aD04Q<=014B2P0>3`L04A8:01<D3P0?40X0414;01HG4P0A4Pd03`l=010@3P0A
4@l05QHD018A3`0Y:2H08R<Q00/=2P0D6AD08bTU028X900A5a<02a0<0P0J6QP01P0A40h05QHD01<C
4@1ZJVP0@40n01XJ60803Ph<00`04Q8@010@3P0@40h04Q8@00h>300=3@/03Ph<01TI5`0=3@/0@D4o
01`L6P0=3@/2010@3P0I01@D4P0J6QP05aLE024S800J71T05ALD01@F4`0A4a003@l<01@F4`0B5140
418?00d?300C5A803Q0=00lA300A4`h04Q@?014C3P0?4@`03@l:018D3`0@4Pd04Q@?01<E4002018D
3`0901PH5P0B4Q005QHD01DE4`0C4a40410>018B400A4@l0410>00804A4?00<04Q8@014B3@0B4`h0
0P0B4`h01@0C50l05AHA01<D3`0C50l04Q<>00<04a@?00L04A8=01@E400D5A004a@?01@E400F5a80
4a@?00805aPC00H05AHA00d>2@0A4`d03a8;00hA2P0@4``2014D3@03018E3P0C5Pl04aH?00@051L@
01P04aH?01@G400E61405APA01@G400H6a@0;S4Z020S700D5a006ahG01<F3`0G6QH04aPE01@H5`0C
5aD04QLD01@I5@0E6QH04AHA01<H4`0F6aH06AhH01HK5P0D6QL301DK6@0401DK600E6aL04aTE01HL
608051/D00D061lH01PN6P0J82006R0Q01PN7P0201<I6@0>01TO7@0G7A/051XH01/Q7@0C6AD07R@P
01LN600G81/07RLR01dV8@0E7QT0624L020Y900O:2<201dV8@05020Y900O:2<07RLR01/T7`0K9B00
0P0N:B<0100L:2807R/T020]9P0O;BH201l^9`08024`:@0Q<RX072hX024d;P0R=Bl08C@^02Hi=00^
@Cd202Hi=`0402Lj>00X>SX0:S`l02/m?@80;40o00H0:cln02a0?`0`A4<0<dM603A8A`0bATD203E9
B00K03M;BP14F5L0Cf=T03M;B`0iCD`0?E9=0356@@0kD4/0>Di904MKFP0oDe<0@EAH04EHG`19G6<0
@EIJ04=HF`0kD5<0AeaO04]PH`1>HfH0D6EX04eRI@16Feh0CV=W04QMHP1=HVD0C61P0080D6AS00@0
DFET05AXI`1GJfX0DFET0P1FJVT205AXI`0W05M[JP1LLG@0F6e`05mdM`1RMgX0H7Eh069gNP1YOX40
LXN:08ZOXP1_Q8L0GgAg06n3QP1WNWh0QiZN06n2Q@1_Ph@0LXB606n0P@1bPX80M8B407N6QP1iQhL0
NXR807f9RP26TI<0T9^M08B?TP2;UYX0SYVM09bW[02DWjD0RiJL09:LY02BW:D0TI^T09FNYP2GWZH0
V9nW00<0VJ2X00L0UijV09bSZ`2KXZX0XZVa09nV[P2DVj80VJ2V0080UinR01P0TIVL09fUZ02NYZT0
UinR09:JW@2EWJ00Vj>V08jFV@2JXZD0UIfO09JNX02IXJ<0V::S09JPX@2BW9d0SYZJ096MW@2BX:00
SI^K08^IV@2?WId0T9jQ08jKX@2:V9/208JDU`0808JDU@25Ti@0PY2A07n=S@1nS8`0NhV907R7Q01e
QW`206MiK@0?05i`I013EDP0?e5304AFAP11Dd<0@EA204=EA01:GD/0DVMG04mSF01HKF@0FFiU05=X
G`1AIUd0EfaS00@0DVMN02L0CV=J04QME015GE40?EA703Q=@@0lCd<0@556041@A`0b@CX0>d]703iA
D00nD5<0=DU=02Xm@@0T=CH0:SXi03E5A00`@3l0:3Pe02dm>P0[>cP0<T<m02`m=`0]?SP0:c`f02De
<P0R<S80:3Ph02Xj=`0T=2l0:STb02@d:P0R;bH08c0W034n=@0]>3808B`X01TT800Q:RD01@0P:B@0
100L9B006B8M01TR7@0K91l201`U800302<Y9@0Q9b<0728N00806b4M00@07bDQ01`R7P0I7a/082HR
0P0K8Ad00`0M8al061hJ01LM6@0201PN6P0501LM6@0F71P08bTU01dS7`0D6QH00P0L8Qh04P0e>SL0
82@S01@H5`0L81l06AdL01dQ800H71/06QhM01@H5`0L81l051PG06]_KP0O92<03aDC01DI600I7A`0
Bdm>05IHE`805QPG100E5AD201DE4`@051@B00D05QHD01@D4P0C4a405ADC01HF500201@D4P0?014A
3`0N7Q`05QHD010@3P0E51804A0>01<B400G4a80510?01HB4@0[9RD06QHE01DD4P0A40h040l=0080
4A0>00`051<A00h=2`0C4Q00=C@b03hm>`0M71X04Ph<01DA3`0:1P<03PX901@A3P0E4@h201<?3@04
01<?300C3`d04`l=01<?3@<04Ph=0`0A3@`02P0>2PT04Ph=00l;2P0?2`X0510?01<?3P0]9bL04`d=
018<300G4A42014;2`03018<300A2`/04@/;00804@/;00T04P`<018>3@0<20L040`;01<?3P0g<c80
=S8a018>3@0@30/00`0?2`X00`0@30/04@`900l:1`0200h91P803`X700H04@`900/60`0;1P<05A0=
00L2000I5142014<2@08010;200?2PL040/8018=2P0O6QL02PD2014<2@0>2@H201<>2`0@014<2@0>
2@H05Q4>01`G500E40d040/801D@3@0C3P/07aXH01LB3`0>2@P04Pd:010;200?2PL040/8014<2@@0
40/800D03`X700h91P0>2@H03PT600d81@02014<2@0?00L20@0D3``0J6=P05]FD`0E40h02`H400h9
1P0;1P<040/9010:2P0?2@T040X:01<=3@0@2PX03@L7008040X:00X030H600d71`0>20P04@/=00h8
2P0H4Q@050h@00/51`0A2`d01`830`0?2@/201TC5@0300d72@0?2@/03`T;00803PP:00d030H8010:
300=1`T04P`>00P2100:10H02`D700d82@0910D06aHG04@n@00A30d081XL00<03PP:0`0?2@/60105
2@0600`31@0F30l0DTM;01/B500C2@`03PD75?ooool001_ooooo00d03@`B014@5P0B4AH04A0E010@
4`0A4A<03@d?010@4@0G5aL05ADE01<C4`0K6a/04A4C00803Ph@0P0@41800`0=3@l03`lA00l?4@02
00l?4@803Ph@00T03@`B00d<4@0>3A803PdB018B500820X0410B00l?3`0>3Ph00P0?3`l02`0@4100
51HE014C4P072@P01@D500T81P0J6AL03Pd;010<2@0A3@X040`900803``700@04A0<01DD400F5A40
4Q4=0P0>3@T0100=30P03Pd900h=2@0<2`L300h=2@0<010?2`0B4@d04A0<010?2`0B4@d05A@@01<B
3P0@3`/04Q4=010?2`0>3PX0414<0P0?40/200h?2P07010A300?40/02``700/<1`0C50l04A8=00d>
2@0300h?2P0900`=200;30L03@h900l@2`0>3`X03a0;014B3@0C50l04A8<00802``600H03Pl9010A
2`0@4@/04A8<00h?2@0=3PP2014B300500/<1P0A4PX03a08018C2`0C50h00P0@4@/06P0F5a804A8=
00l?3@0=3@/02PX800l?3@0G5Q@01PD301DF500:30T04AHB00lE4@0A5a<0318>00dB3P0;2`T010@2
018A3`0=3@/02`/901<C4@1iNGL092@R00D50`0>3P`04a<A0P0@40h02@0C4a403Ph<01<C4@0B4Q00
410>01<C4@0J6QP0000000/;2@0200h>3006018B400I6AL05ADC01TK600A4a002`d:0P0<3P/02@07
2@H04Q@A00X<2@0P8Ql04Q@A00lA3P0E5a@04aDB01@F4`0301DG500@01<E4P0>40d03a4>00lA3P0:
30T04Q@A01lQ7P0N7Q`03Ph<028R800C4a40820N01LG5@0B4Q004A4?010@3P804A4?00P04Q8@00l@
2`0C50l04a@?014B3@0D5A005QLB018C3P<051D@00<04Q<>014B3@0@4@`00`0A4Pd0100C50l05AHA
01<D3`0C50l201TJ5@08018C3P0D5Q0030l800hA2P0E61404A@=01@G400H6a@201<F3`8051L@00<0
5APA01<F3`0A50d00P0A50d00`0B5@h04aH?01HI4P0201/N5`0401PK500F6A8061/D01LJ5`804aLH
02P04QHG018F5@0D6AD05AXE010E3`0F6aD05Q/D020V700K81X05A/K01DJ7@0D6Q/051XJ01HL6P0I
7ad05A/G01PN6P0G7QL05QdE01XQ6@0K8QX04ALE01<I6@0G7A`061hL01XP7P0N92809B/Y010F500K
8Al06AlM018H500f?3P04a`G01XS7P0I8Qd04Q/F01@M600K91l06B8M0P0J8ah02P0I8Qd06R<N01`U
800L9b<06RDQ024/:00R;RX07b/W024]:@0N;BP201d/9`0501`]9`0O<2X08C8/02<f<00R=C000P0Q
=300100U>3D0:3/i02Pk>@0W>CP202Hh>00e02Li>@0X>SX0;D5002i2@@0_@d80<4A30396A@0dB4L0
>Ti=0396A@0eBDP0=4Q703Y>C@1@I6<0Nhf=041BDP0hBdT0<dI202Xm=`17FU@0>Te904IHF00lCTh0
BUaP04AEG011E5/0BEeV04EIHP18G6D0F6ac04iRJ@1;H6D0DFI[051UJ01BIfX0C65S04]PH`16Fe`0
CF5P04YNG@1<H5l0DFET05IZJ@1GJfX0DVIU05=WIP1DJ6L0EVYY05U]K01KKfh0HGAh05Q[K`1PLgL0
0P1RMGT0401PLgL0Jgj208bOX`2U^;`0M8N;05a_L`1WNWd0M8R906MkO01hRhd0OHnA07^;R`1hR8P0
NXZ:07f;S020SXl208:@T@0@08RDUP2BWIl0Xjj`092KWP2JYJT0UJ2T0:>^/`2IY:X0T9^Q09FPY`2D
WZL0UZ2Y09ZSZ`2JXJT0W:>[09jU[@80WJB/0180W:>[0:B[/`2IX:P0WZF]0:B[/`2SZ[40WjJ/09bT
Y`2OYjX0UIfP09RPX`2IXJ@0UinR09JNX@2maLP0g^KY0:fe^02DW9l209FMW`0U09NOX@2FX:40UZ2Q
09FOX02Q[Jd0W:RX08nMW@28UYH0RING08nMW@2<VYd0RiVL08VGVP27UIH0QI>D08BBT`2;VIT0R9JF
08>AT@1oSX/0NXV607F4O`1aPWP0JG]_069dJ01DIUX0@E=604AFB016F4X0@59403mA@`17FD/0E6IG
05EYG@1LL6L0Fg1Y05M/I@0205AYHP0]05Q]IP1JKfP0EfaU05AYHP1BIf00CV=L04UNE@1:H5<0@EM7
03Y?@00kCd<0?4m403U:@P0cA3h0@E5?04=EE`12E5P0>4]B02Tl@P0Y>S/0;cln0310?`0]?C`0;Cdj
02hn>`0W=c@0;Chh028c;@0U=S008C8/01XZ9`0V=SH0:SXj02dm>P0U=C009cH_02<c:@0U<RT08BhU
069_IP15D4X05R4M02<^:P0J8ah07RLR008082TT00D06b@O01PQ700J8ah06B8M01/T7`0201lX8`07
01`U800M8al07B<O01XP700O9B407R@P01XP700201dS7`805adI02805Q`H01<I5@0C6AD04QPD01<I
5@0E6aL051XF01PN6P0U:bL082HR01/Q7@0J81`05Q`H01hS8@0S9bH07R8Q00hB4@0C5aH07B4P01<G
5P0_<c8092PW01LK6P0K7ah0:bl^00hB4@0I7A`06QhM01dP7`2[[J`0Wj6P01PJ6@0G6AP051HE0P0B
51<01@0C5A@05ADC01DE4`0E5A<051@B00804a<A00T04Q8@01<C4@0E5A<04a<A018B400D51805QHD
00d=2`0B4Q000P0>3P`06@0D4a407QdK01TH5P0E4A0040`;00h:2@0H4a806ADD00h=2`0F5A<07QdK
01@C4@0B4@l030/901XI5`0A40h01PD301dL6P0A40h03`/800l<2P0P7AP0924L00P50P0300001@0C
40/0400C3``0510?01@@3`0B3Pd040`;00l;2P0>2PT05Q8A018>3@0C3`h0510?00l;2P0;1`H02P@4
018<300C3@d200h8200301@>3P0B30`04@/;008040X:0P0B30`01`060`803@T801TE500C3`h06ADD
00L30P0@30/00P0A3@`00`0@30/03`/:00h:2@0400l:1`0800d81@0<1`@03`X700`7100?2PL06QDB
00h91P040002018=2P0:010;200>2@H03PT6010;200810803`X700h91P0=20D02`H3014<2@8030L4
0P0=20D0300<1`@03PT600T40@0A30T03`X901@?300M61D02`H300d81@0<1`@03PT600l:1`803PT6
0P0@2`P02P0?2PL03PT600h91P0=20D03`X7014<2@0<1`@020<000`7100C3P/201/F4`0400l:1`0<
1`@04@`900l:20803@L700l03PP8018<300=1`L02@<300l92@0>20P02P@400`61P0;1@D07QPH01<=
3@0H4Q803@L700X4100A2`/00P0?2@T05@0>20P02`D500T30`070@403@L9010:300=1`T02`D700l9
2`0=1`T04P`>00d72@0A2`d02@<500X41P0?2@/06Q@F00P2100:10H06aDG00T31@0300X41P802`D7
0P0<1PP601052@0600X00`0A20X0?34e00/01008004091TM5?ooool001_ooooo00d02`X@00d<4@0=
314030/@00l>4P0C4aD03`lA00d=3P0B4Q804A4A00l?3`0G5aL04A4C00803Ph@0P0@41800`0=3@l0
4Q8D014A4`02010@4P0;00l?4@0>3Q003`hD00`;400D4aP030/@010@4P0E5AL0410B00l?3`0>3Ph0
0P0?3`l01@0@410020X901HH5`0B51<03`l?00802`X800X03`h<01<?300D40d0510=018?2P0A3PT0
30/7018A3@0D4`l04Q4=0P0@3`/02P0?3PX04a8>01<B3P0@3`/03Pd900d<200<2`L03Pd9014@300@
3`/200h=2@06010?2`0?3PX03Pd9018A3@0@3`/03Ph:0P0A4Pd02P0@4@`03a0;00l@2`0A4Pd030d8
00d>2@0C50l030d800h?2P0C50l2014B3@03010A300>3`X03@h900<03@h900L03a0;01<D3`0G61<0
5aPB00l@2P0;30H03Pl900804A8<00@03@h801<D3P0C50h03@h80P0?40X05@0C50`0414901<D300D
5@l04A8<018C3@0A4Pd03Pl:010@3P0A4@l03@d;014A3`081`D07A`J00`=2`0G6AH000D100hD401B
F5@0:c4]00T>2P0201HF500900/:20092@L07alM00`<2P0B4Q0020P701LG5@0@40h051@B00804A4?
01h051@B010@3P0G5aD04Q8@00D50`0S8b404a<A01LG5@0@40h04A4?00h>300?3`d04Q8@00d=2`0:
30T030h;00h@3@0A4a0051HC014C400;3@X05ALD0001000C5A8051HC00`>2`0A4a00418?00h@3@0=
3``300lA3P0>01HH5@0E5a@03Q0=024S800h>SL0RXZ80000000J6QP03@d;014A3`0<30X04Q8@014A
3`0@40h2014A3`0O018B400?40/04a@?01<D3`0A4Pd051D@01HG4P0A4Pd051D@01HG4P0E5Q404Q<>
010A300?40/04A8=010A300A4Pd04a@?01DF4@0C50l03Pl:014B3@0@4@`02``701DG4@0F6A8051L@
018E3P0@4``03a8;014D3@0201<F3`0M01@G400E61405APA01DH4@0C5Pl04QD>014D3@0C5Pl05APA
01@G400=40T05APA01LJ4`0>4@X04A@=014D4P0C5aX04aLH018F5`0B5QD051PG01LL5`0E6Q@06QlH
018G3`0H7Q@03Q@=01LM7@0F6al00P0E6Qd02P0H7Qh06b4P01LM6`0J81`06B0J01PO600M91`07B@M
01hT8P0L8R0201XP7P0901TO7@0E6aT06b4O010F500J81h09R`Z03Y0?P2?UI805QlJ00806b@O00@0
6B8M01`U800K91l06R<N0P0M9R402@0K91l07BHQ020Y900K9R8062<O020[9`0Q;BT07RXV020/:002
01d/9`0<01`[9P0L;BL07RlY024b;00T=c408C@_020c;`0S=S809cXg02Pk>@0/?cd0:cdl0P0Y>c/2
02Xl?00402/o?P0/@3l0;T9102m3@P80<DE401l0<dM60355A00iCD`0=TY90396A@11EE@0@eEE03E8
AP0fBDD0?4m;03]>B01:GEL0AUUE03a?C@0lCTh0JG]n05EVK@0kCUD0@eIP04EII01:GVT0E6Qa055U
K01JKWD0C65V051UJ01HKG00CF9S05EZJ`1>Hf@0DfMV0080C61O00L0DVIU05AXI`1DJ6L0Ffm^05Q/
J`1GJfX0FFe/0080Ffm^02L0H7=g05IYK@1NLGD0HGAh06=fNP1/Oh<0GW5e06EhO01/Oh<0IWUm06j1
Q@1[OX40P9BE06EiNP1lSi00M8J807J6QP1mSHd0Nh^;07j<S@21Si00Pi6B08BBT`23Si40Q8nA09NR
Y027TYD0Uj:V08fHW02EX:D0T9^Q09:MX`2MZ:l0Uj6Z09JPZ@2KXj/0VZ6Y09bSZ`2OYZh00P2PYjl0
6P2KXZX0XJR`09nV[P2OYZh0VZ6Y09bSZP2RZJl0UIfP09^SYP2JXZD0UinR09bTY`2h`<<0WZJY0:J^
/@36c]40W:BW09RPX`2DW9h0UIfO09JNX02EWj00UZ2Q09NQXP2BWYh0TIfM0P2AWil05@2@WYh0RiVI
08^IVP2;VI`0RYRK08NEUP24TY<0PHn@08:@T020SXh0OH^;07b;R01iR8D0MHAo06n0MP1^P7@0G6iR
04mQE@17FD`0A5I804EGB@02049DAP0T04YLCP1GJE/0F6aP06=gKP1KL6T0EfaU05Q]IP1EJV<0CfAM
05Y_J01EJV<0D6EN04eRF`18GEH0@eQ?04QOC`10EDD0>Tm003a@A00kCdD0=TU303e=BP16F5P0A5IJ
041AF00fAdl09CHm02Pg>@0/?3/09cLf02Xj>@0a@Ch0<T8o02lo?00b@cd0;3dg0P0[?3H03P0a@Ch0
;3`l02lo?`0a@Ch09SHa02Lf;`0R<RP0:SL^01dZ8@0T<BP09C0Z02Xe<@0I92007RLR0P0L9B000`0M
9R407RLR01lX8`0201LP6`0c01XS7P0P:B@07RLR01/T7`0M8al07R@P01XP700O9B407R@P01XP700W
;BT0:S0/01/Q7@0L8Qh07bDQ01/Q7@0I7a/061hJ01XP700M8al0728N01PN6P0E6aL051XF01hT800G
7AT051XF01lT8@0F6QT051PG02<W9P0J7Qd03Q8A01HJ6@0;3`h04QHE01TM700g>cX0;C4`01`P7`0M
8B001PX901dP7`0[;B`0>C/j01TK6P0H6QT051HE018D4`0A4a804Q@C00<05ADC02L051@B01<C4@0C
4a403@d;01<C4@0G5aD0410>00d=2`0D51805ADC00h>300I6AL05QHD014A3`0;2PP04a8@00h=2`0D
40l06aLF01LC4P0A30`05a<B00X91`0L6aT0:RTW01TH5P0E51803@`:01@C4@0@3`d04a8@00P71P0B
4@d040`901/H4`050P001P<001DB3@0F4`h01P0C40/6014=300301@@3`0:1PD030P700803PX902H0
5A4@01@>3P0A2`/02`D500l92@0C3@d02@<301<=3@0A2`/03`T9010:2P0B30`04`d=01@@3`0<20L0
40`;00`81`0I5A@02`L6010<2`0A3@`04Ph=014=300>2PT03@T800h91P0?2PL040/800l:1`0<1`@0
2`H300d81@0E40d03@P500P30P0D3``03@P500l:1`8040/801H03`X7018=2P0D3``050l<00h91P05
00004Pd:00T40@0>2@H04Pd:01@?300>2@H02@@100d81@0U81d04Pd:00T40@0D3``02@@100d81@0B
3@X040/80P0>2@H300l:1`8040/801@03`X700h91P0>2@H030L400h91P0?2PL03@P5010;200=20D0
30L500/60`060@003PT601@?300@2`P03@L6018<300?2@T03PP8014;2`802P@40P0A2`/07`0=1`L0
3`T900`61P0A2`/01000014;2`0>20P04@/;00l92@0=1`L02P@400l92@0B30`03`T9018<300=1`T0
40X<00`6200:10H040X<00h82P0B30h02`D7018<3P0=1`T040X<01PB500;1@L03`T;01@>40060080
0P0?2@/200d72@803PP:00<03`T;010:300@1@T01P0@1@T01@0B1`/03`@801462P0G31001`0001Co
oooo000Kooooo`0800h=4`0@3aD04a8G01<B5`0@41<03Ph@010@4P0@4144010@400600l?4@0A4A<0
3@d?00`<3P0@41804A4C1P0?3a40200=31803@`A00X93P0=31403`lA00d=3`0>3Q003`l?100>3Ph0
1`0?3`l04A4A00l?3`0@3Pl03`h<00d<2P0B3Pd00P0?2`P0100C3P/04Pd9014=2@0@3PX500l>2P04
01<B3P0?3PX03Pd900l>2P804Q4=0`0?3PX01@0@3`/04A0<010?2`0>3@T040l;00804Q4=00P040l;
00`<200I6QD020T4014B3@0=3PT0:R/V014B3@804Q<>01P02``700h?2P0J6aH06Q/F00l@2`0A4Pd0
4Q<>010A300>3`X03a0;00T:1@0<3@P03Pl;01HG4P0R8ah06Q/F018C3@0?40X04A8<018C3@0A4P`0
51D?018C3@0A4P`2018C3@04010A2`0B4`/04A8:014B2P80414;03803a0:00`=200D5A0051@B02/[
:@0C4a403Ph<014@3P0D4a404Q<A010B3`0?51003A<?01XP700=4`l02a0<01DE4`0A4@l040l>01@D
4P0A4@l03`l=010@3P0B4Q004A4?00h>300A4@l03Ph<00l?3@0B4Q003`l=00d=2`0C4a403`l=02LW
9@0D51802PX800d=2`0?3`d02`/901@D4P0L71X03@d;00/=2P0D5Q<03Q0=01<E4P0?4@h04Q@A00h@
3@803@l<02P03a4>00d?300A4a002@/8014C400:30T061XG01DF500G6AH03a4>00`>2`0?4@h04A<@
01<E4P0G6AH0;Rh/010@3P0A4@l04Q8@00h>300D51804a<A01@D4P0B4Q0051@B00h>300G5aD03a0;
03ho>P0[;2L03Pl:00/<1`0D5A004a@?00h?2P0E5Q4061TD01HG4P0C50l04Q<>0P0A4Pd01@0C50l0
51D@01DF4@0@4@`04A8=00<04Q<>00P04a@?018D3`0@4Pd0418=018D3`0D5Q405aTD00lA3@805ALB
02d02`d801hP6`0C5A003@l:01HH4`0B50l071hI010B3@0G6A@051HA018D3`0E5a805aTD01DG4P0E
61L0720R00hB4`0D61T05a/J01<G5@0G71L051TC01DJ4`0F71@04aT?01PM5P0B61P05Q/O01DJ7P0D
6A`05a`N01DK6P0G7A/0Ff5N02P^:P0B61<09bhW01LN5`0E6aL06b4N01hT8P0I7ad04aTG01/Q7`0L
8R000P0J81h01@0E6aT0:S0^02le=00C71P06R<N0080624L00H08BXU01hW8P0I8Qd06R<N01dV8@0N
9b8201lX8`0@01hY9@0K9b<07b/W01TU8@0Q;bX08c8]01d/9`0M;BP07RlY020a:`0Q<bd08SD_01lb
;P0R=C409CPd02Lj>080:Sdk0P0Z?3`09P0Y>c/0:3Xl02/m?`0_@D<0;40o02i2@@0bATD0=DU803A8
A`0bATD0>De<03Q<B`0oDe80@5AC03Y>C@0lD4l0=DQ603Q;B@0cAT80=dY403e@BP11E4h0>di904QK
F00nDE00LhF604MIG@12E5X0BUeY04iRK@1?Hfd0Cf=[055UK01CJ6h0CfAY051UJ01@IFL0CfAU0P1>
I682055UI00?04eQH01EJFP0DFET05]_KP1JKVd0FFe/05Q/J`1KKfh0Gg=b065eM01QM7P0Jgj2065d
N01/Oh<0JWf10080IgYn00P0JGb006f0Q01^PHD0KX650722Q01cQHD0MHN707V:RP80Nh^;0100NHR8
07R6Q`1jR8/0PHjA08RCU`2;UYX0SIRK08bFV02>V9X0TY^O092IWP2CW:40W:F[09^TZ`2HXJP0VZ>[
0P2LYJh0102OYJl0Y:Ra0:>W/02SYk020::V[`030:>W/02UZK80Y:Ra0080XZJ_00@0XJJ]09nTZP2O
Y:P0WjBX0`2NXjL01P2h_L40Y:V]09ZOX`2OY:P0Vj2T09VNXP80VJ6S00P0V:2R09RRX`2HXZ<0VJ>T
09BPX02CWil0T9jN08nMW@80SYbL0180SI^L08nMWP2>W9d0R9JG08FCU026U9@0PHn?082?S@20Sh`0
Ohj;07N6PP1^OGH0HgEY06anL01hRW`0IWQ/04EGB`18FTh204]MD@0l04eOD`1AHeL0FF]O05eaIP1L
L6P0GG9[05aaJP1KL6T0EV]T059WH01DJF80EFYS05=XH@1?I5d0BUmH04QLD`16FD`0@5=403U=@00c
Ac`0?E590396@`10De80B5YL04]MH@1BHfX0?DiE02hmA00U=3H09SHe02De=00W=cH0;Shk03A4@@0f
AT<0;3dg02/l=P0^?cT0:S/e02Hf<`0Z>SX0:c/k0310?@0Z>cD09SD^02/k<@0W=2/08c0W01`Y800P
:bD08bhZ028]:@0M9R406b@O01`U800P:B@07bPS01hW8P0I8Qd05b0K0P0M9R405`0I8Qd07bPS028X
900S:BD06b4M01XP700I7a/05A/G030f<P0nA4006b4M01TO6`0S:BD06QlK020U8@0K81`05a`H01HK
5`0J7a/082DQ01lT800M8Qh05a`H00806QlK00@06AhK01<G5P0E6AP07b<R0P0@51<0100H71/06AdL
01TM700E6AP201XN7@0301DH5`0F61L05QPG00@05QPG0P0E5aH01P0E6AP04aLF014D4`0C514051@B
01DE4`805aLE00H061PF01<C4@0I6AL04Q8@01dM6`0E5A<2018B400<00`<2P0A4@l0410>01/K6@0C
4Q005A@B00`;2@0J5QD0=c<b01DA400E41006ADD0P0@3`d04@0D4a404A0>014@3P0A40h08b8P020O
7@0Q81h040l=010?300B3P/06AHB01/H4`0/:B@04a0;00l<1`0D4@`04Pl:008040d800H04@h9018>
2P0D40l04`l>014=300@30/300l;2P0601DA400B3Pd040`;018>3@0?2`X040X:100A2`/7010:2P05
00l;2P0@30/03PX900`81`0>2PT00P0B3Pd2010<2`0400h:2@0?2`X04Ph=01@?30803PT601/02`H4
01TD4@0810804Pd:014<2@0@2`P03`X7010;200B3@X040/8018=2P0@2`P030L4018=2P0G4Pl040/9
00d81`0>2@H03PX701<>2`0;1PD040/8014<2P0A30T040/800d81P0>2@H00P0?2PL02P0@2`P03`X7
00l:1`0E40d04`h;014<2@0@2`P030L604Q3@00C3P/200l:1`0@00h91P0=20D03@P500l:1`0>2@H0
3@P500l:1`0@2`P03`X700d81@0>2@H03`X7010;200?2PL03PT600h91`803PP800X03@L700h8200?
2@T040X:00T30`0@2PX03PP8010:2P0A2`/03`T90P0>20P01`0=1`L03PP800l92@0F41004`d=00h8
200<1PH00P0>20P06P0b;2h0;RPZ00h92P0B30h040X<00d72@0<1PP02084014;3@0;1PL03PP:01<=
3`0?2P/04`d?00`7200:10H09b4S05A>D00@2P`030H800d72@0<1PP040X<014;3@0@1@T04@H:0P0C
20`01@0A1PX040D901882`0A1PX040D900803`@800<03P<7ooooooooool04_ooool001_ooooo0P0@
3aD2010?500>010@4`0@41803Ph@00l?400?3`l0410@014A4@0B4Q804A4C01<C5@0?3a40410B01<C
5@0>3Q0600l?4@0:010?5@0E51T03@`A00/:3`0?3a4030`>014A4`0@41003`l?00d=3@802`/;00d0
3`l?014?400B41404@l@014=300@30/03PX9018=2P0C3P/04@`901491P0@2`L040h:00D03`h:00<0
4A0<010?2`0?3PX00P0@3`/0200A40`03`h:00l>2P0?3PX040l;014@300@3`/03Pd90`0?3PX04P0@
3`/03Ph901HG4P0:2`H051D@01LH4`0d=C009BHQ02X[9P0X:B@061TD00X;1P0>3`X0414<00d>2@0>
3`X0414<00l@2`803Pl:00h04A8=00`=200=3PT03Pl:00X;1P0@4@`0414;00h?2@0?40X0414;00l@
2P0B4`d0414;00l@2P80414;00@03a0:00l@200?40P041490P0@4@/0600A4P`03Pl:00T:1@0?3`d0
6a/I010@3P0?3`d03@`:00`;2@0B4a404Q@A00X?2`0C6AD092XV02T_:`0C61@04a<A014A3`0@3`d0
4a<A014A3`0?3`d04A4?018B40804A4?01L051@B010@3P0@40h04a<A00l?3@0Y:BL07AdK01@D4P03
0`4030`:014A3`0<30X04Q8@010@3P0C4a405aLE00d=2`072@H03a4>00`>2`0A4a00418?00X<2@02
014C400D01@F4`0:30T06Q`I010B3`0I6aX05ALF00P:2@000@00A4I5034c<P0E5aH03@l>018D4`0A
4a803Q0?01<E500;2`T051@B01LG5@0E5A<201<C4@80410>00X03@d;010@3P0;2`T04Q8@010A300O
81/04A8=01@E400;30L051D@0P0C50l0100N7aX0;c0[01<D3`0A4Pd200l@2`06010A300C50l05QLB
01LH4`0@4@`04a@?0P0E5Q400`0C50l04aDA01<E4P02018D4@0?01<E4P0E5a@05ALD00`>2`0I6aP0
5ALD01HH5@0I6aP05QPE01DG500=3``04aDB018D4@0J71T05ALD008051HC01h04aDB018D4@0D5Q<0
>3/i08>7QP0c=cH061`K010D4`0E6QH051TE01HK5@0D6A<05Q/E01@I4P0E6QD03aDE01<H6`0D6A`0
5AXM01PM800H7Qh06AlO00X@3P0F71X03aDC01<I5@0K8Ad082HR00XA2P0G7AT2020V8P0T01LM6`0O
9B<07bDS01TO7`0J82005A/K01TO800M9R<08R/V01dV8@0H8A`07BHQ01/T7`0H8A`06B8M01/T7`0M
9R407RLR01hX8P0=61@0:CDc020/:P0L:bP06BPU024`;@0O;b`0830]01lb;P0P<bl08C@`028e<@0R
=C<093Le02Hi=`0W>SP0:3/j0P0X>SX0200]?d00;d5302do@@0Z?3l0:3Xl02e1@00aAD@0=DU80P0g
BdX0500fBTT0>Ti=03iBD@16FUT0AEUH03Y>C@0dB4L0>4]9045AC`0jBTL0@E9<03U:@P11DTX0@55;
04MGE00lC4/0@U5C03i=DP1>GfH0CV5Z0P1?Hf`0301=HFT0CV9Y051UJP1>HfL0C65T04aQHP1>I6<0
DFMU059XIP1AIF@0DfMV05AXI`<0Ef]Z00l0DfMV05IZJ@1IKF`0GW9a069fM@1SMgH0J7Yn06UkO`1V
N7`0O8jB07>5R@1YNgl0Jgf106eoP`1`PXH00P1bQ8P06@1eQhP0MhZ807Z:R@1jRXX0NHV907Z8R@1j
R8X0Ohf@08JAU@2:UIX0S9NM092IX02DWJ40TifO09FOX@2JXjL0VJ:W09bUZP2X/KL0Y:fd09VRZ@2L
YJd0Y:ff0:>/]@2SZK800P2VZK820:FX/@030:BW/02VZK80YjZc0080YjZc00L0YZVb0:JY/@2TYjh0
XjJ[0::UZP2PXjP0Wj:W0080WZ6V00/0VYfR09fPY@2LWj@0UYVN09^OX`2EWIl0UYjP09RPXP2GXJ80
UZ2Q09BNW`02096MW@@0SifM00@0SYbM08nMWP2=Vi`0R9JF0P26U9@0@P22THh0P8n<07j=R@1lRhH0
M8=n06YiLP1`PWH0H79T05U[G@1@HUH0AeU=05MYG@1=GU@0Cf1F059SF@1FIed0GFiU061dJ`1OLV`0
FFiY05M/I`1HKFP0EfaW059WHP1HKFP0EV]V055VH@1>Heh0Bf1K04YNE@1@HUH0?4i103Q<@@0fBT40
?U9>03iDDP12EeP0B5aO05i`M01TMWX0AUAI04EBF00V=SL09CDd02<c<P0W=cH0<40m03E5@P0[>cP0
:S/e02/l=P0]?SP0;Sli02lo?00]?Cd0;3`l02Lg=00U=C009cH_02Hf;00]>S4082dT049?AP0V<B/0
4ahJ02<^:P8072DP02h06b@O01XS7P0J8ah072DP04A=B00B6aH07BHQ02hg<P0N9b808BXU01lU8@0T
:RH06b4M01TO6`0N92008RPT01XP700B61@07bDQ028X900G7AT051TE01`N6`0G6AH08B<P01`N6`0E
5a@0828O01lQ7P0R92406adJ01TK600L7Q/06QdK018F5@0e>CP0If]Z02lc<P0>4Q4051PG01PL6`0K
7ah06AdL01HJ6@0B5QD04A@C100G5aL201HH5`0601@F5@0F6QT00`L600D9200F6aT04aDB1@0D5180
5P0G5aD07QhL01HF501cLg40Kfm]01HF500>3P`06ATG01HF500>3P`01`L5010?3@0?3P`020L5018>
3@0X92<03PX9010;2P0I5A@04Q4?014@3P0B4@l200l>300<014@3P0U92808B0N01LF500:2@L05A@B
01<?300A3@X0:RHS02TU8P0>2PL061@A0P0A3@X2010<2@05018>2`0C3``05A4@01@@3`0B3Pd00`0A
3@`01`0<20L04@d<01@@3`0@30/03@T801@@3`0A2`/0100B30`00`0A2`/040X:010:2P04010:2P03
00l;2P0A3@`04@d<00803`/:00l040`;01PD4`0C3`h02`L600l;2P0E4A0040`;04U4@@0M61D07aXG
00d81@0P6aP03`X701<>2`0@2`P00P0?2PL2010;200B014<2@0B3@X040/800`7100?2PL04`h;00l:
200F4@h01`8000l:1`0A30T071LD018=2P0@2`P01P8000l:1`0J5A802PD40P0@2`P0100A30T040/8
010;200?2PL200@00005010;200<1`@03@P500`7100?2PL0100@2`P01P0A30T03PT600d81@0?2PL0
40/800l:1`<03PT600P03@P500h91P0>2@H040X9010:2P0?2@T03PP800l92@@040X:0P0>20P01P0=
1`L03`X700h91P0>2@H03@P500h91P803`X70P0A30T0700<1`@02`H3014;2P0E3a405Q0B00X41P0A
2`d04P`>01D?4@0C3@l03PP:00/51`0F41803`T;00L20`0<1PP0100001dG6@0=1`T030H8014;3@0B
30h02`D701D?4@070@<030H8018<3P0@1@T401462P0701052@0V6al060dA00l4200A1PX04`P<00h3
1`0Dooooo`006oooool01@0A41H040lE00l>4`0?3Q<0410C00804A4C00/04A4B010@400?3`l03Ph>
00d=3@0=3@l04Q8D00X:300820X04Q8D01@D5P0600l?4@08010?5@0I61d07A`Q018A5P0;2`d03Ph@
010@4P0?3`l200h>3P8030`<00L04Q8B00h<3@0=2``03@/<014=300E4A0040`;008050l<00@04@`9
01<;200C3PX040h:1@0?3PX0100D4`l04a8>018A3@0A40`500l>2P04010?2`0A40`04A0<00l>2P<0
3Pd901003`h:00h>2P0A4Pd02@X500l@2`0@4@`092DP018C3P0I6QD09BHQ024R7@0@4@`02P/600/<
1`0<3@P03Pl:0P0@4@`02@0?40/03Pl:01PI500A4Pd04Q<>01@E400?40/05QLA00l@2P0300h?2@04
00d>200@4@/03a0:00h?2@80414;00T03Pl900h?1`0?40P04149010A2`0A4P`04Q<=01XK5P0;30L0
0P092@L05P0;2`T05ADC014@3P0:2@L03Pl=00lA3P0;40`08bTU0=GKe`2=Thl051TE00l?3@0:2PP0
3`h<01<C4@0A4@l0410>014A3`0B4Q00410>00l?3@0C4a42010@3P1101@D4P0A4@l0>CTg02/[:@0O
7ad02PX8010@3P0D5180410>01HF500A4@l03Ph<00`<2P0410803a4>01@F4`0<3P/02P`901@F4`0F
61D02P`900d?300E5a@02@/802LY9P0H6QL03Q0?00d?3P0>40l06Q`K09nQX02a/k805ALF01/M700C
5A@02`d<00lA400B51<05ADC01/K6@0C4a404Q8@01LG5@0E5A<05QHD01DE4`0@40h05ADC014A3`0E
5A<0414<01<D3`092PD05AHA00X;1P0D5A005aPC00l@2`0A4Pd08b@O00X;1P0E5Q405aPC01DF4@0D
5A000`0C50l01`0E5Q405aPC01PI500C50l0414<014B3P0C5A800`0B51408@0C5A8051HC01PJ5`0G
6AH03a4>01PJ5`051`@04Q@A01XL6@0:30T061XG01@F4`0W:BH05aTF01@F4`0H6QL05ALD014C400D
5Q<05APE03Pm>@0>4Q4020`:018G4`0P9B406AhJ01<H500B5a<05a`G01HK5@0F6aL04QPH01HL7002
01HK7P0Y01TN8@0H7Qh082HV01DK6`0N92<04ALG01TO7`0I7ah051XF014H4@0V;2P05Q`H02dc;`0O
9B<05A/I024W9@0H7Qh07B<S01HL700G7Ah0;CHc02df<@0P:B@05AhI01PQ700J8ah06B8M01XS7P0L
9B007RLR01lX8`0O:B<0<Cdk02Lc<@0?6aT07B`Y02/j=`0M;2T07Rh[01l`;@0N<Bd00`0O<Rh03`0T
=cD09STg02Lj>00X>cT0:3/j02Pj>P0U=cL0:cdn0312A00_@D<0;T1302do@@0_@d@0=4Q703U=C002
03Y>C@0X03]?CP0iCD`0?U9A04AHE`13EeH0>Ti=03=7AP0kBdX0=4A103]<AP0mCTP0CUmG04AEC@19
FU@0?De:04MGEP1AH680DV5V04mQI@1<GfH0C61W04eQJ01?HfT0DFI[059WJP1AIVP0CV=T04aQHP1=
Hf40CfES055WI@1EJFP0DVIU05IZJ@1CIfH0G71_05=WIP1IKF`0G71_05ibL@<0HGEd00h0HgEi07:4
R01[OH40L8:606n1Q@1`PXH0KGn306j0Q01aPhL0LhF907B6RP1gRHX0NHb:07b<R`80O8b<01@0O8Z;
07b:S023TI@0SIRL08nJW`2=V9h0TY^R09NPYP2FX:80Uj6S09VRYP2FWj@0V:6V0:>//P2RZk80VjB[
09jW[`2V[kP0Z;6j0:N]]PD0YjZc1@2XZk@05@2XZk<0Y:N^0:BW[02SYZ/0XZFZ0:6TZ@2PXjP0XZFZ
0:2SZ02RYJX0W9nT09FHW@2HW:00VIjQ09RPXP2KXjD0VJ>T09NQXP2DWYl0T9bL096MW@0308nMW@0e
092NWP2?WIh0SifN08bJV`29UiL0QiFE08FCT`26UI80PY6>07j=R01mS8L0MHAo06UhL@1]Og<0EfUK
04eOD@19Fdl0AEM;04mQE@1=GU@0Cf1F05=TFP1GJ600GFiV05iaJ`1DIf<0GG9]05aaK01DJF@0CV=N
055VH@1GK6L0DfQS04mTG`1@IF00DFIQ059UG`1BHeT0@51603mCBP0iC4H0?59>04EJF`12EeX0?E5E
045DF017EU/0<3m2034o@P0R<S809SHe02Ph=`0Y>CP00P0W=c@0300/?3T0;Sli02dn>00Z>cD0;3dg
02hn>`0b@T80<D5102Hf<`0V=S40:cXc02Lg;@80:cP_00/0F6EL03@o>@0B7AT08B`X024Z9@0R:bH0
7bPS01/T7`0L9B007bPS04M@B`0201LP6`0302`e<00O:2<08R/V008082HR00l06AlK01LM6@0K8Ad0
7B<O01`R7P0D6QH082HR01dS7`0D6QH0720L020R7`0G6AH08R@Q02HX9@0F61D00P0J71T0300K7AX0
6Q`I01TK600J71T071lM01TM700H71/06AdL018F5@0D61L06QhM01TM70806QhM00<05QXI01<G5P0E
5QH0100F5QH0200E5aH07R0O00lA400F6QT082@S02@X9`093P`04aDB0P0D51805P0C4a404Q8@018B
400@40h04A4?03De<`2][J/0YjNU018B400K6aT051@B00X:200P81h06QXH01LF500K6QP04A0>00X7
1P0H51<02`L601TD500C3`h400l>300E010?3@0C4Q003Pd;00h=2`0G5Q@051<A00/:200G4a804`l=
018>2`0:1PD04Ph<01DA3P0@30/040`:010<2@0A3@`04Ph<01<?3P0D40l04`l>00@04@d<00P04`l>
014=300E4A004`l>00d9200B3Pd04@/;018<30804`d=00<04P`<014;2`0@2PX01@0@2PX0100?2`X0
4@d<018>3@0A3@`200l;2P0701`H5`0X92<05Q8A00T5100C3`h0510?01`G500200@0000600/60`0A
30T03PT6018=2P0?2PL03@P50`0>2@H04P0A30T04Pd:00l:1`0=20D03PT6010;2008108081/H01TD
4@0@2`P05A0=04Q3@00F4@h0100000h91P0?2PL02`H300`710803PT600X03`X700h91P0>2@H03@P5
014<2@0O6QL02`H301HA3P0:1@8040/80P0A30T04@0B3@X04`h;01<>2`0C3P/04@`9010;200A30T0
4`h;018=2P0@2`P03`X700d81@0<1`@03@P500l:1`0@2`T03`T900<03PP800@040X:00d71`0C3@d0
3`T90P0>20P09@0=1`L03`X700h91P0>2@H03@P500h91P0?2PL0100000/60`0F4@h03@P500D0000>
2@H0100000X41P0=1`T040X<00h82P0<1PP02`D7014;3@0;1@L03`T;00D00@0M5aT05@lA014;3@0b
;2h030H800P3100H4Q@05Q0B00`6200F4180208400d82@0?2@/00P0@1@T201462P8040D900H07A8F
01<8300=0PH03`@801872`0@1@TDooooo`006oooool0200A41H040lE010?500@3a@0410C014A4`0?
3a403`l@100?3`l01P092@/06a/M01@D5P0<30h0410B00h>40H03`lA00L03`hD01PG700^;C807A`Q
00L72@0C4aD03Ph@00803Ph>0`0?3`l01`0@3Pl04Q0A01TG600G4a@03`/:014=300F41000P0E40d0
100G3`d05`l<01D@300@3PX500l>2P03014@300@3`/040l;00<040l;0`0?3PX05P0@3`/04A0<018A
3@0A40`040l;00l>2P0@3`/03`h:00l?2`0=3PT03a0;010A300>3`X05AHA00`=200@4@`04Q<>00l@
2`0<3@P03a0;014B3@0?40/2010A30804A8=00H0414<018C3P0=3PT0824L02PY900F5a8200l@2P05
010A2`0>3`T03@h800d>200@4@/00P0?40X00`0@4@/04A8<010A2`0200l@2004010A2@0@4@/04A8<
018C3@802P/601404A4?00h>300@40h03`l=00l>300;2PP04A8?014C400;40`06b4M07EkM`1EFeL0
3a@@01<C4@0E5A<03`h<018B4002014A3`0@01<C4@0B4Q003`l=00d=2`0A4@l03`l=010@3P0D5180
4Q8@00l?3@0C4a403Ph<01LG5@0?3`d03Ph<00d=2`804Q8@00X04A4?010@3P0@40h030h;018D4@0A
4a003a4>01dO700@4Pl04aDB0P0B51406@041P<05QPE00L91P0@4Q4051HE00/=300E5aH0;S0_02d_
;P0C5A@05aTH00X<2`0L7Qd092HU00lA400G5aD051@B00`<2P0B4Q005aLE014A3`0E5A<04Q8@00X:
200B4Q000P0?3`d0400A4Pd04a@?014B3@0C50l03@h901<D3`0B4`h03Pl:00/<1`0E5Q402P/601/L
5`0G61<051D@018C3P0A4Pd2010A300701@E400F5a805aPC01DF4@0B4`h04A<?018D4@04014C400>
010B3`0P8Ql05QPE010B3`0U9b@0:2XW01TK600K7AX0418?01LI5P0C5A808B<P01HH5@0D5Q<201/M
6P0Z01DG500F61D05aXF00/>2P0J7aX051TC018G4P0H7AT05a`H01DJ5P0F6aP06QhM01HJ600H71/0
5adK01XP7P0J81l05adM01XP800H7Qh041DH01/P8`0F6ad06b0S01LL7`0I7R407B<O01PO600F7AH0
6R0L055GD`0J81h04QPF02D[:@0L8R806b0S01lT9`0K8B805AhK01XS7P0O:2<06b@O0P0J8ah00`0L
9B007BHQ020Y9002028[9P0@028/9`0I9B<0:3Ld07f<R@0_?S/07Rh[02Hf<`0P<2d08C<_028e<@0S
=S808SHb024f<@0V>CL09cXh02Tl>P<0:C/k00T0;Cm102m1@`0^@480;Cm302m1A@0a@dD0;T9303I:
B@0iCD`00P0hC4/0100jCTd0=TY903Y>C@0jCTd203]?CP0D03Q;BP14E5<0>TY703m@BP1oT8T0cmgH
07>4O019FU<0B5QE04aLFP12DU80CUeP04]MH01@IFL0CF9U04aQH`1>I6D0CfAV04mTI01?IF@204iT
HP0<051VI01DJVP0EVaZ05U]K01BIVD0Ffm^05IZJ@1cQhH0H7Ac05a`K`1OLg80HWIe0`1SMgH0301W
NGd0LH>706UkO`1[OH40KX2407B6RP1_PHD0L8:607:4R01eQh/0MXR<07Z;S080OHf:01H0PI2>08>A
T@25Ti@0QY:E08ZEV@2AW:80TYbS09:KXP2DWJH0VJ6W09NOXP2IXJ@0Vj>W09VPYP2KXZP0X:N^0::Y
/@2TZk<0XjZc0::Y/`2TZkD0Z:jg102Z[KH20:^^]`80ZZff00D0ZJbe0:R[]02WZ[80Y:N^0:BW[004
0:FX[@030:BW[02OXZL0W9nT0080WZ6V00L0X:BY09^PX`2IXJ<0VZ:T09RRX`2FX:40TYbM0080TIfM
0`2?WId2092NWP0>08jLW02<VYX0RYRH08RFUP25U940Pi:?07f<R@1hQh80NHR307:1N`1UMF/0G6iR
04aND01;GDl304mQE@0G059SF@1FIeh0FV]S05a]I`1OL6X0GG1Z05iaK@1HKFP0EV]V05U^J@1JKfX0
EfaW04mTG`19GUT0AEYE04MLE`19GUT0BEaG041AB00jBd<0?e9=03M:A`0lD5400P16Feh03016FUh0
=d]=03a<C@0a@4009C<c02`l?00X>3L09SHe02De=00T=3408c<`02Xj=`80;Sli00<0:c`f02`m=`0_
?c`00P0eADD03`0]?CX0:S/e02dl=@0Y>Bl09c@[02<`9`0`?C@08bhX01`W8`0Z=C408b`W028[9P0O
:2<072DP01hW8P02024Z9@0<01hW8P0H8A`07RLR01lX8`0Q:RD082HR01LM6@0L8Qh07bDQ01dS7`0L
8Qh08BLS0P0J81`00`0O9B406R0L01TM6P0202@V8`0=01TK600L7Q/07R0M020R7`0J71T05ALD01`N
6`0P8Ql07AlL01LJ600J7Qd06alN01DI600201HJ6@0701LK6P0E6AP05ATH01`P7`0E6AP051PG01XK
6P0201LE5P0301LF5P0F5QH05ALF00804aLF00D03Q8A01LM6`0N92804QLE01@F4`0201@D4P0H01<C
4@0B4Q004Q8@01hN70092@L05QHD01/K6@0W9bD051@B00h>300D51805QHD014A3`0M7A/05A@B010?
3@0B4@l04`l>01`H5`0B3Pd04Pd=01HB4@0F5A<051<A0P0@3`d0400A40h04Q4?01@C4@0D4a4030/9
00h=2`0A40h04@d=00h:2`0C3`l04`l@018>3`0>2PX03`/<014=3@0B3Ph2018>3`05018>3P0B3Pd0
4@d<010<2`0?2`X00`0@30/01`0?2`X04@d<018>3@0B3Pd040`;014;2`0B30`00P0C3@d00`0B30`0
4@/;010:2P05010:2P0H010<2`0?2`X04@d<018>3@0@30/03PX901HB4@0O6aX05A4@00l;2P0A3@`0
30P700l:1`0I51403PT602@O700810803PT6010;200>2@H03`X7018=2P0?2PL030L40P0@2`P0400?
2PL03PT600h91P0>2@H050l=01dH5`0A30/04Pd;018=300=20D050l<00/60`0B3@/03PT600P40P0B
3@X200l:1`0:010;200?2PL03`X700`7100g<Rl0IV5N018=2P0<1`@04@`900h91`803PT60P0?2PL0
6P0@2`P04@`9010;200?2PL040/8018=2P0A30T040/800l:1`0>2@H03@P500h91P0?2PL03`X800h8
200=1`L030H600d71`0>20P02PD501XD500>20P040X:014;2`0@2PX03`X70P0>2@H06`0=20D03PT6
00l:1`0C3P/030L400/6100>2@H030L401@?300@2P/03@L9014;3@0;1@L03`T;01H@4P0910D03PP:
00`6200A2`d03@L902LQ8`0>2@X030H800l:2`0A2`d05Q4B00/51`0200h82P0400`6200:10H040/<
00h82P8040D90P0?10P201052@0300l4200B1`/04PL;00803`@800<040D9ooooooooool04_ooool0
01_ooooo00X03PdC010?5@0B4AH04Q4F010@4`0>3Q0030`>00d=3P0>3Ph03`l?0P0@41001@0A4A<0
7QhP01HF600D51H06a/M00L03`lA00L030/A014@5@0K6Ql061LL010@4P0C4aD03`lA00<03Ph>0P0=
3@d03@0>30d04@l@01/I6P0H51D030P700l;2P0@2PX04@T701H>300K4a404`/800T4000@3PX01@0?
3PX0100E51004Q4=00l>2P0>3@T2010?2`<03`h:00@040l;014@300B4@d04Q4=0P0C4Ph03P0A40`0
40l;014A30092PD04A8=010A300A4Pd04Q<>00d>2@0;30L03Pl:01DF4@0G61<04a@?0P0@4@`500l@
2`0<00`=200>3`X01`P400H70P0B4`h04A8=00l@2P0B4`d03a0:00d>200>3`T0414;0P0?40X00`0A
4P`04a@>018C3@02014B2P0N010A2@0@4@/0414;00l@2P0B4`h07b0K014A3`0>3P`06ATG02/[:@0>
3@/04A0>01<D4P0A4a003A8>00/A3@042PH061hJ01LL600:2PP03@d;00d<2P0A4@l0410>014A3`0C
4a404Q8@00h>300B4Q0051@B0P0@40h0300B4Q003`l=00h>300D518030`:01TI5`0<30X03@d;01TI
5`0E5A<04Q8@014A3`80410>00`07R0M00h@3@0K7AX0<C<`04A6@`0C5A804Q@A014C400@4Pl03a4>
018D4@0A4a0300d?3P0601@F5@0@4Q404aDD010B4@0:30/02`d<0P0N81l0100?4A004A4?014A3`0B
4Q0201HF500C01@D4P0U9B<08B4O01LG5@0Q8Al07alM01dM6`0@4@`03a0;01PI500=3PT06AXE01<D
3`0@4@`04a@?01PI500J6aH05QLB01TJ5@0300l@2`05010A300A4Pd04A8=014B3@0B4`h00`0E5Q40
100D5A404aDB01<E4P0C5A82014C400>02DW902SYJ80Bde:01lQ7P0B51400040018D4@0C5A806A/H
014C400B51403Q0=01<E4P0D5Q<201LI5P0;01DG500G6AH07R4K01PN500G71D07R<L018G400I7QP0
5Q/F01PM6@0H71/00P0H71d0;P0Y;Bh051XH01LM6@0G7AT05Q`J01TO7@0G7Ad06AhQ01PM800G7200
7b@X01<H7P0J7b@06R0L01/R6P0J8AX041HB00lE4@0B61D08BLU01`R8P0N92@06AhQ01/P8`0I7R40
6R<P024Z9@0[=2l09c0[01lX8`0J8ah072DP01dV8@0P:B@08BXU028[9P0R;2L0:cLe01d[:`1EHf<0
:SPh020_;`0A8B007S4_028e<`0U>3H202Hj>00:02@h=P0U>3H09cXh02Tl>P0Z?3`0:cdn02Xl?P0a
@dD0<D=602m1A@80;T1403L0<D=502m3A00gBdX0>Ti=03M;BP0eBDP0>4a;03A8A`0iCD`0=TY903M;
BP0jCTd0=dY803Y:B@0oCTX0=dI107b;Q02da;X0IgM]04IECP1;FUL0AeIC04mMGP1IIfX0CEaO05AY
I`1=Hf40Bf5O04eSH01=Hf40Bf5O04eSH@1?IF<0DFMU05E[J@1HKV`0FFm]05AXI`1@I6<0HgMf05mc
LP2;Wih0KH6005]_KP1OLg80HWIe06IjN@1YOG`0JWim06eoP`1^P8@0JWb007:4R01^P8@0LhF90080
LXB800@0M8J:07N9S@1iRhl0OXn@0P21THh04`24Ti40R9JF08^IVP2=VY`0SiZN09:KXP2EWZH0Uj2Y
09RQZP2KXjT0VZ:U09bTY`2OYj/0WJBZ0:2W[@2U[;<0YJbd0:N^]P2W[[L00P2U[;H00`2Y[[L0Zjjg
0:b_^0030:f`^@80[k:k00D0[K2i0:Z]]P2Y[;D0Z:^c0:NZ/@020:NZ[`<0YZV^00<0ZJba0:JY[P2P
XjP00P2MX:D02`2LX:@0WZ>V09^SY@2IXJ<0UZ2Q09BNW`2BW9d0TinO09:NWP2@WYh0SifM0080SYbL
01T0TInO08jLW02;VIT0RYRH08VGU`25U940OXf807N6P@1`OgX0M8=l06mnM`1RLVP0BeeA04=EA`18
FT`0DF=G05EWG01DIE/0EVMO05Y[I01NKfT0Gg1Z05i_JP1JKFT0G6m]00<0Ffm]01P0FFe[05AXIP1>
HV00Ae]I04EIE`18G5X0BEeK04IIE@16EE00?De803M:AP0a@d<0>4e?02m7B`0W?d<0=TY=03A8B@0d
A4@093<a02He<P0c@d809SHe024a<00R<S4202De<P0@02<c<00W>380:CXd02Xk=@0[?3H0;3`i02Xj
>P0]?Cd0;cll02Ti=00R<BX093@Z020]900S<2L09c@[02Ha:`808bhZ00@08R/V01dV8@0K91l072DP
0P0N9b80200P:B@07BHQ02lh<`0K91l082TT01/T7`0L8Qh05Q`H0P0N9200100L8Qh07R@P01XP700K
8Ad201TO6`0>01lU8@0X;2P05ALD01PJ5`0P8Ql06adJ02@V8`0L7Q/05QPE018D4@0M7a`092HS02LY
9P0S9R@201HJ6@0F01TM700D61L05a/J01LK6P0?4a807b<R03Di>00O8b803a<B01@D500H51D05Q@E
01HE5@0E5AD051HE01`P7`0E6AP06AlM08N=R`2:T8h02a0>01<E4P8051@B0`0C4a403P0@40h01PH4
014A3`0<30X03@d;00l?3@0L71X03@d;00X:2@18B4H0]kNe0491?`0H5aD071/I0P0C3`h01P0E4A00
6A@D01LC4P0I61H05QDC00d<2P803`h<00d040l=00T81P0@3`d02PT701<B400>3@/05Q8C01/F6P0:
1@T04@`@00d8300E41@040/?00<04PdA00@04@`@00l;300A3@`04@d<0P0@30/02@0A3@`04Ph=00d9
200N6QT04`l>00`81`0C3`h03`/:010:2P04014;2`L040X:01P040`;00`81`0=2@P040`;00l;2P0=
2@P03PX900/71P0=2@P04@d<00h:2@0:1PD03`X7010;200:1@804@`9018=2P0M61D040/8014<2@0E
40d06QDB01@?300>2@H200d81@0@00h91P0?2PL03`X700h91P0R7AX0ZZFR01hI5P0@30X01`8001TD
4@0:1@8061<@014<2P0=20D06QDB00d81@8040/800L04@`9010;200@2`P03@P501TD4@0^:BH03`X7
00804Pd:00@02`H5014<2@0A30T04@`90`0@2`P01P0=20D030L400h91P0?2PL03PT600d81@803PT6
00D03`X700h91P0>2@H03PT700h8200300d71`0800l92@0I4a<0;bTY01LA4@0D3Ph03`T900/51@0?
2PL200h91@0F00d8100>2@D03`X600X50@0>2@D05A0<00/60P080`00:B@Q01dG5`0>20X03`T;00@0
00090`D04@/=01D?4@0<1PP03@L900T31@0:10H01`8300l92`805Q0B00T04@/=01H@4P0C3@l03@L9
02HP8P0:10H030H800h82P0?2@/00P0@1@T200h31`8040D90P0B1`/201<8300301462P0=0PKooooo
01?ooooo000Kooooo`0800d<4P0@3a@04a8G01<B5`0@41<03@d?010@4P0@414200h>3P0800d=3@0<
30`03`lA00h>400000801@D701XJ700C4aD600l?4@803@`A00<020P:010@4`0G5aT00P0A4A<04P0@
41003`l?00d=3@0<30`02`/;00l>3@091`P03`h<00d92@0;1`H04`l>01<>3P0D3``071LD02<N6`0E
40`02@@0010>2PD03`h:00D08B0L01XI5@0D4`l03`h:00h=2@0400l>2P0H010?2`0A40`04Q4=018A
3@0D4`l05A@@018A3@0@3`/0410<00L80`0>3`X02P/600d>2@0>3`X05AHA01@E400?40/04Q<>01HG
4P0C50l03a0;010A300?40/03Pl:0P0=3PT03@0B4`h01@H100X;1P0A4Pd05QLB01LH4`092PD0414;
01<D3P0?40X03@h800h?2@0A4P`00P0@4@/01`0B4`d04a@>018C3@0B4`d04A8:014B300@4@/00P0?
40X06`0<3@P08b@O010@3P0A4@l07AdK038b<00B4Q805ADE014B4P0<40l041@C00lE4`0F71X03A<A
01DJ5`0J71T04a<A00d=2`0A4@l0410>014A3`0C4a404Q8@00h>300F5Q@061PF01<C4@02014A3`0C
00d=2`0B4Q004a<A00/;2@0?3`d030`:01<C4@0F5Q@0410>00h>300@40h04A4?018B40071`D0418?
018D4@072@H06adJ00/=2P0200`>2`0[00/=2P0B514030h;01@F4`0E5a@03Q0>010B3`0;3@`04A<A
00lA3P0<3P`03a4@01@F4`0;3@/02@/:01<E4P0C4a404A4?010@3P0<30X03Ph<018B400E5A80414<
00D60@0@4@`03a0;00/<1`0@4@`02P/601PI500;30L0824L01<D3`0@4@`02``7018C3P0A4Pd04Q<>
00`=200B4`h04A8=010A3002014B3@03018C3P0C50l04a@?00<04a@?020051DA01@F4`0D5Q<051HC
01<E4P0A4a005ALD08J8Q@0m?c`051HC00X<2@0L7Q/05QPE00`>2`0M7a`0418?01PJ5`0:30T05QPE
01@F4`0C5A804Q@A01@F4`0H6QL05APB02D[8@042P008BLN01PM5P0R9b405Q/E01DJ5P805QXI00@0
7B4P03Xn?P0@5Q@051XF0P0E6aT06@0H7Q`05adM01TN8@0E6Qd06AhQ01HK7`0N8bL08BH[02H/:P0A
5a<04QPE02P^;00630X08bTW02P^;00A5aD07B<Q01XP7P0E6a/061hM01PQ700K9Ad07RLR01XS7P0F
7aX00P0K91l05P0L9B007bPS020Y900Q:RD08B/T01XV8P1@Ge`09cHc020_;00Q<Bh09cLd01/^:P0O
<Rh08cHb02@h=P0U>CL08cLe02Dh=P0W>SP0:C`j02/m?@0/?Sl202`n@00V02m1A00a@dL0<4960394
B00dATX0<dM803a@C`0nDU40>De<03M;BP0jCT`0=4Q703Y>C@0hC4/0>4a=03Y>C`0dATP0?4a<04=A
DP0nC4`0BUUF04aME`18FE<0?De905QXI@1<G5/0BEUI04iMH013EEL0DFIT04]QG`1:H5h0CVAR051V
I01>I680D6IT059XIP1DJVP305E[J@0B05U]K01BIVD0H7Ac051TH`1eRHP0Cf=R065eM01SMgH0IGUh
06UmO01/P7l0KH6006YlP01fR8`0L8:606j0Q01[OH40MXR<0P1dQXX0101gQh`0NH^?07f<T@22TI<2
08>CTP0C08JEU029UiP0S9ZK092MW`2BWJ40TY^R09JOYP2JXjX0VjB]09fU[02NYJ/0WjJ/0:2W[@2L
XjT0WJB/0:F[/`2VZ[<0YJVb0:Z^^0020:jb_@0E0:f`^P2/[kP0[Zjh0:j`^@2^/KX0/;2j0;:c_@2b
]Kh0/;:k0:j^^02Z[KH0ZZ^e0:Z]]02Z[K80ZJbb0:NZ[`2VZJh0YJR]0:>VZ`2UZ:d0Y:N/0080X:>X
0240XJFY0::WZP2OYjT0WJ>V09RPXP2GWj40UYnP09FOX02CWil0TYjN092LW02>W9`0SY^K096OW`2>
W9`0RiVI08ZHV029V9D0QIBA07j=R01gQX40L7mj07F4O@1`OgP0I7AZ05][H019Fdd0A5I804aNDP1J
K640HgAZ05EVGP1IJV800P1MKVP0;`1KK6H0EVUU051UH01_Q800MX^6069fM01@IF40EV]V04MKF@13
Ee@0@eQC04UMF`1;H5`0AeaG04IGD@0jBTH0<DA003=7A@13F5P0=4U:0397BP0lDE40A5IF03i>C@0[
>CD0@U5>02`k>P0U=C@093@a02@d<P0Q<Bh07bl/02<c<00U=S009cPb02Pi<`0W>3809cLd02/k>`0_
?ch0=dM602ho>P0T<b`0:3L`02Hc;00P;BH09S</00<09S4]02L092dX01`U800K91l07bPS020Y900O
:2<08b`W05MPF`1nQh808BXU01HO6P0R:bH06R4K01TO6`0L8ad05A`E01@J5P0J8A/05ahG02@Z9P0N
91l03A@=01lU8@1MHUh0<cDb00d?300I6aP07R0M02/]:P0S9B80828O01XL6@0K7AX061XG01XL6@0G
6QP05ATH01TM700G6aX00`0H71/01P0B5QD05QXI02DY:00E6AP041@C01PH60805Q@E00X05QDE01DE
5@0D5QD030h=01HJ6@0D61L0Ngmn07f1P00E6QT04aDB1@0D5180600E5A<06ATG01<C4@0L71X04a<A
01@D4P0<30X061PF01TI5`0g=cD0`/;003He<`0?3P`05aHD018>3@0A3@`04`l>014=300?2`X04a8@
014@3P0:2@L03@`:00l>30804A0>00/05aHD00P71@0?3P`040l=014=3P0j=SL040`=01DA4P0F4Q<0
2@D6014<400201<>4P03018=4@0@2`l03PX;00804Ph=0P0A3@`301<?3P0702l[:P0K5aH02PH5014=
300>2PT03`T9010:2P02014;2`03010:2P0?2@T040X:00D040X:00<040`;00/71P0;1`H00P0?2`X0
4`0>2PT03`/:014=300A3@`020@300X61@0C3`h040/:01HA3P0U81d03PT601<>2`070P004@`901<>
2`0I51407aXG01LB3`0A30T00P0<1`@0400>2@H040/800l:1`0>2@H03@P501hI5P0?2PL05Q4>00l:
1`0D3``02PD204a7A015@3d0100001PC400:1@<200h91P0:00l:1`0>2@H03PT6010;200=20D03`X7
00h91`0400002`H300l:1`803PT600T03@P500`7100;1P<03PT600l:1`0>2@H03`X7010;200?2PL0
0P0=20D04@0?2PL040/800l:1`0=20D03PT700l92@0@20T040L800l92@0A2@X02`8302<M7@0>20P0
4PT:00l92@0>20H03`X700803PT502<03@P400h91@0?2PH04@`800X50@0>2@D03`X600L2000=20D0
4P`<00H00P0C2`h03@@7014;3@0C2`h04@P;00T31@0B2Pd01P0000d72@0E3A004@P;00X41P0=1PP0
2002014:300@2P`06A0C03lg>P0A2`d04@P;00`51`0@1`X04@H:00l4200200d21P0300l4200A1PX0
4`P<00803@@70P0C2Pd00`0=10Ooooooooooo`0Booooo`006oooool0100E5AP04A4C00h>400@4182
014A4`06018B500;2`d04a<E00X:300@41803@d?1P0@3Pl0100?3@h05Q@E00l=3P0A3a0201<A4P05
018@4P0=2`d03@/<01<A4`0C4A800P0A3a001@0>30d03@/<014?400D4Q<051<B00803`h;0P0?3PX0
4P0>3@T03`h:018A3@0B40`04a4=01@B3P0A3`/03P`8010?3@0A40h02@P6018A3`0:2@L040l=01@C
4@0A40h03`h<00h=2`803`h<00P03`l=010@3P0?3`d0410>01@D4P0D51<02`/:010@3P803@d;00T0
410>010?300=30P03Pd9010?2`0?3PX03@`801PG4`0I61@00`0@3`/01P0A40`05ADA01@E400@4@`0
3@h900h?2P<04A8=01<04a@?014B3@0@4@`04Q<>010A300G61<06Q/F00l@2`0>3`X04a@?00T:1@0E
5Q403Pl:01@E40092PD04a@?014B3@0A4P`0414<00803a0;00@0414<00`=200C50l05QLB0P0A4Pd0
6`0?40d03@hB01HH7P0R92/0Q8N=04]>D`0?4aH08BDW069VI`0F6QX041@C00hA400@4Q403Ph>014A
4@0@41003`l?014A4@0?3`l04a<C010@400<30`05ADE014A4@0@41004Q4?014@3P02010?3@09014@
3P0B4@l040l=018A3`0C4Q004A0>018A3`0C4a40410>00804Q8@01h0410>014A3`0C4a404A4?01<C
4@0?3`d0410>01@D4P0=3@/04Q<?010A3@14AD00DE9>018C3`0A4Pd051DA00l?300=3PT0410<014A
3P0@40d04aDB01@F4`0@4Pl0418>00X<1`0A4`h03@l:01<F3`0A50`2018E3@0E010C300B4`h04Q<>
010A300B4`h04a@?014B3@0B4`h04A8=010A300A4Pd04Q<>01<D3`0@4@`04Q<>01@E400C50l04A8=
00l@2`0B4`h04a@?00<051D@00P07R0L02HX9@0I6aP051HC01<E4P0>40d04Q@A01PJ5`804aDB00H0
5ALD00lA3P0C5A806Q`I01TK600H6QL201<E4P0901@F4`0`<Rl03Q0=01TK600Q8b006adJ01HI500K
81T06QlH00806AhG03d0:RlX0415?P0K81X0724K01LL5@0O91h051TC01@J600E6aX061hN024W9`0@
5QH06AlO014G5`0D6QX06R0P01<I6P0E6Q`07B<U01XR9P0G7R<05alR01/S9@0H82805b0N01dV8`0K
91l06B<K01XT6`0I8aT05b4G01dT6`0H7aL082LP01hT800Q9b<08BXW028[:01BFeP07bXT02/f;P0L
9al08RlU020]900T<RX093<[028a:@0R<b/09CH_01TZ8`0X>S@09CPb02Hi=00T=c<0:3/i02Lk>P0]
@D00:Cdl02m3A00/@440<4A50080;d9600H0;3m30354BP0eB4h0=DQ=0395B@0dB4X203M;BP0A03M;
B00eBTD0<TM303I:B@0hBdh0?U5F04QKHP0oD5X0@U1J04MDGP1<FV<0AEEL03e?D`14EUX0@UIG04=J
F@18Geh00P18H5d05@1<Hf<0C61T05MZK`1EJ6d0DFAY05=WJ@1GJVd0G71b05eaLP1CIfP0EVY[05]_
KP1DJ6L0EFMW05Y/K01iRh/0KX2005MYJ@1VN7P0I7If06IhN00206]mO@090722PP1hRXX0L8>706j1
Q@1aQ8P0LH>707>5R@1iRHh0NXV>0080NhV>00<0O8Z?07n<TP24TYH00P26U9H01P2:UiT0T9^O09>N
XP2HXZH0U9fR09FLXP80WjJ/00@0WZF/0::Y/@2PYk00XjNa0P2WZkD05P2XZkL0Zjfi0:na_@2a/[h0
[k2l0;6b_P2c/[l0];?00;:a_P2b/;d0][G10;Bc`02d/[l0]KC00;Je`P2d/[l0/Jnl0;>b_`2][;P0
[:nh0:V^]@2X[;D20:V^]0040:N//P2VZjl0XjR/0:6VZ@80XZNZ00@0XJJY0:6UZP2PY:T0WZ:V0P2L
X:D0702LXZH0Vj>V09VRY02FWj40TifO09BNX02FXJ80TYjN096MV`2>VYP0S9RF08VET`23Sh`0P8b8
07f9Q@1kQh<0Mh=o06mkM`1YMVl0E65G04mND@1DI5L0FFUL05QYG01IJel0DfAJ05U[H@1HK68205AX
G`0705U/I@1DJF80FG1X05=ZHP1>IEh0CVEM04]RFP0204AKE00/04AKD`13FU<0AEaD04IME@0nE4d0
?UA<03Y@B@0gC4H0=T]503Q<AP0iBdL0<D4m03a;A`0M:RL0;c/g02Th<`0Z>SD08C4]01l`:P0S=2l0
8c@^020a:`0W>380<T<m02Pi<`0dACl0;d0j02Tj=@0Z>3L0:3Hf02Le=@0W=C@0:3@c02Lc<P0W<C40
9S0`02<];@0Q:BX08RX[02@]:`0W<BT07BLO01lY8@0R;2@2024Z9@0803Q1?00_>3D0@T]801/T8@0O
:2D04a`G01`R6`0L8AX301dR6`0801/P6P0Q9Ql092TR01dR6`0Q9Ql051TB024V8@0K81`2024V8P04
01TN6P0O92006b0L01PM6@807B8N02<06b0L01<H500L8Ad05AXF01TN6P0H7AT051TE01PM6@0D6AD0
6b0L02DZ9P2FViL092TU01HK5`10@T005QHF00h>3P0F5QH0820P02@T900G5aL06AXI01/L6`0G61P0
5QLF01<D500C4a<051@D01HF5P0G5aL05QHF01DE5@0@410051@D01HF5P03018B4P0801@C4@0B4@l0
51<A01/J600L6aT05QDC01PG5@0B4@l301<B4008018@3P0C3`h04`l>018>3@0E4A00510?01HB4@0C
3`h2010<2`804`l>00<03`/9018>2`0B3P/00P0A3@/0100B3Pd04`l>018>3P0A3@h2010<3@03014=
3P0B3Pl040X:00804P`<00D040X:014;2`0B30`04@/;010:2P0200l92@0D010:2P0A2`/04`d=00l9
2@0G4A406Q@D01<=3@0B30`04`d=018<300@2PX03`T900h8200?2@T04P`<010:2P0?2@T040X:014;
2`0B30`6010:2P0600`7100C3P/071LD00/6100?2PL030L40P0?2PL2010;200300l:1`0>2@H03`X5
00803`X50`0?2PH00`0B3@X02@@4014;2`0200l92@0=00`71@0I514081/H01@?300<1`@03PT600l:
1`0<1`@02PD200h91P0B3@X03`X700d81@0200h91P0400l:1`0>2@H03PT600h91P803`X701h040/8
00l:1`0?2PL03`T800h8200=1`L03PP800l92@0>20P03`T9010:2P0>20P03`T9014;2`0D3Ph06A4A
024G600D2``04`T:01892P0@1`P050X;01<92P0A1`P03`D601061`0A20P030H300d8100@2`L200d8
1004010;1`0=20@030L300h91@804@`800L03`X600h41@0@1`P04`T:01061`0?1@H04@L8008040H7
0P0A1`P201882@0601<92P0A1`P03`D601061`0F3@h06a8C0P0A1`P201061`803`D600`040@80145
2@0?0`L03@<600l5200C2Pd030@700d82@0>2@X02`L800/82@0<2``Dooooo`006oooool00`0B4Q@0
410B00l?4@02010@4P0700d=3`0A4A<04A4C00<31@0?3a4051@F00D51`06014?400800H41@091`P0
1P@500`:2`0D4Q<020H701<A4P0A3a02010>3`<04@l@01X0518C018@4@0?3@h04a4B01PG5@0@3``0
3`h:018A3@0E510040l;00`;1`0B4@d040l;014@300B4@d040l;00d<200>3@/03`h<00`;2@0D4a40
2`X800d<2P0D4a404Q4?014@3P8040l=0`0?3`d200h>3008014A3`0I6AL04A4?014A3`0H61H02PX8
00`<2P0?3``200l>2P04010?2`0A40`04Q4=01PG4`806QTE00D06aXF010?2`0;2PH03@d800l@2`02
010A300h00l@2`0=3PT03@h900l@2`0>3`X03@h900l@2`0C50l04Q<>01DF4@0H6A@04Q<>010A300>
3`X08R<N00@5000J6aH02``701DF4@0<3@P04Q<>010A300?40/04a@?01@E400A4Pd030d801LH4`0J
6aH03Pl:00`=200@4@d051DI014B5`0?3aH0ZJZ_04Y;C`0A4QD09RLY09^LWP0D5QH01`T801<E4P0?
4@h051@D01DE5@0>3Ph05QHF00X:2P0L71`00P8201XJ6P0>3Ph05ADE00d=3@0A4A4201<B40804A0>
0P0C4Q000`0A40h051<A01@C4@0201<B400601DD4P0E5A<05QHD01@D4P0A4@l03`l=0P0@40h03`0D
51804a<A01@D4P0A4@l020P600L80`0C50l09bPS03Df<@0I6QD02P/600/<1`0720<02@X5018C3P02
01LH4`0B01@F500?4A002`d:014C400?4@h05aTD01HH4P0E61404A@=03Tl=@0k?SL05APA01HG4P0B
4`h051D@00l@2`0B4`h07AhI0P0?40/01P0A4Pd051D@01LH4`0H6A@04Q<>01<D3`8051D@00@04Q<>
014B3@0@4@`04A8=0P0C50l0100D5A00:2TU03<e<P0M7a`300h@3@0U018D4@0C5A80418?018D4@0D
5Q<04A<@01@F4`0G6AH01PP5010B3`0Q8b005ALD01hP7@0g>CH061XG01<E4P0G6AH05QPE014D400>
4`d04QLA01`Q6`0b=c40Ri2:0<[?b@0l@C/05AXD01LL5P0H7AL07B8M02@Z:00D6QX05Q`L014G5`0C
6AT05A/K01dS8`0201`R8P0B02<Y:@0F71`0@4E7020X:`0K8bH06B4T01/S9@0I8B<06R<Q01/T8@0I
8Qd06B<K01XT700K9A`06B<J02T`:00S:R809RdV0P0L8Qh0?@0K92806bDT030k=`0J9Al08BhU01PU
700U<RP08c0W024_:00R<BX09SD^02De;P0P<B/0<44k01d^:`0C9R808cHb02m2@00T=cD0:cln02e1
@00X?3/0<4A502a0@@0]@D808cHj03E8C013EUX0;d9803I9C`0gBU00<dI:03E9B`0hC4/0>dm>041D
DP12EU@0<4A203eAD00dAd/0>diD03I9D@0oD5X0AeEP05MUL01]NhH0Cf1X04MJH00nDEL0@eQK04EJ
F`1<HF80Bf=S04MPG@17Gel0BemT05MZL01_PXP0G6me04AGF`1BIFT00`1DJ6T0501DJ6L0EFUX05AX
I`1KKFd0EVQX05AVIP1KKFd0J7Yj06eoO`1YNg/0J7Yj06]mO@1]Ogl0LhF507Z<S01bQHT0LXB807F7
R`1fR8`0N8N<0P1jRHh05`1nRi40P8fC07n<TP20SI<0QY:G08ZEV@2;UYX0SiZN09:MX@2FWj@0VJ:W
09JOY02GWZ@0WZF[0::Y[`2VZk40XjR`0:FY]02X[;L0Y:Nb0:b^^P2b]<00/;6m0080]KG100<0/[6m
0;Zha@2h]/<00P2e/l001@2d/[l0]kG20;Fc`02g]L80][C100<0/[2m00D0];:o0:j]^P2^/KX0[K2i
0:^^]`020:^^]@050:R[/P2WZZl0YJR]0:FY[02X[:l00P2Z[[402@2QY:T0X:>X09nRY`2NXJH0Wj:W
09nTZ02JXZD0VJ6T09JNX@0209>MW`1G09FOX@2EXJ40TIfM08fIV@2=VIL0RYJD082<RP1lR8@0NXJ2
07J3O01aOWL0K7Ub06EbJ@1AGU@0FVUL05m_HP1HJ5d0DF9F05QZGP1KK680FF]Q05M[H01GJf80EVYQ
05AXG`1>He`0E6UR051UGP1=HU/0C65J04QMEP19GUL0A5UB03eBB`0lDDX0?U=<045FC`12Ee00>e19
0397@00aA3h0<TDo03E8@P0W>380>4Q202/j=@0g@cl09C4]02<b;@0T=2l0<44k02m0>P0V=c40:3Tc
02m0>P0S=2h0;Chh02`m=`0`@C/08c@^02Df<00W=S<0:STf02Pg=00T<c009S8`02Te<`0U;bh092h]
024[:P0O:2L082TX028[:00Y<b/07RPP01lY8@0R;2@08R/V02@]:00N9b8072DR02</:@0J8b009c0]
02Xc;P0R9b407B8L00807R<M01<06b0J01XO6@0E6Q@02Pl901LL5P0V:bD0GfAN02db;@0E6QH0:c0/
0497@`0O92003A8>01dR7P0I7QX06QlK01<H500I7QX08BHR00804aPD00d06AhJ01XO6`0H7AT06QlK
01<H500J7a/04QLC02@Y9@0>4`l051TE020R800N7Qh03`l?008051@D00L04A4A01@D500E5AD051@D
018B4P0C4a<07AdM00<05QHF00`05ADE01@D500B4Q805QHF010@400B4Q804A4A00X:2P0?3`l03`h<
014@3P0D4a42014@3P0H01DD4P0R8Al09bHT014@3P0?3P`03Pd;01TH5P0[9bH03PX9010<2`0=2@P0
2`L600l;2P0E4A004`l>018>3@0C3`h04Ph=010<2@0F4Pl05A4=01<?300B3P/04Ph<0P0B3Pd01P0A
3@d040`=010<3@0A3@h04Ph?010:2P804P`<00<040X:014;2`0B30`00P0A2`/2010:2P804@/;00`0
40X:00l92@0D3Ph05Q0@018<300@2PX03PP8010:2P0C3@d04P`<00l92@0=1`L2010:2P804@/;00<0
40X:00l92@0@2PX01@0@2PX00`0G4Pl03`X700X50P0200l:1`0301XE4P0?2PL03`X7008040/800<0
3`X700h91@0?2PD00P0?2P@300l:1P0800T40@0>20P02`D501<=3@0Q6a/04@/:010;200C3P/200d8
1@803`X700<03PT600d81@0<1`@00`0=20D200h91P0300l:1`0>2@H03PT600803PT60`0?2PL0200>
2@H03PT7010:2P0A2`/030H600X4100?2@T04P`<0`0?2@T0100A2`/04`d=01D=3P0M4a@201882@05
01<92P0@1PL04`T:01882@0A1`P00P0@1PL0100A1`P03PH400h91P0?2PL200d81@0300l:1`0:1@80
3PT600802`H300D04@`900T40`0@1PL04@L801882@0201061`0401882@0@1PL040H701061`<04@L8
00H03@<400h41@0?1@H03`D600d3100;0@820147208040H70P0?1@H0300@1@T03P<701072P0C2Pd0
3PD800H0000;1@L03PP:00d92P0;1`P030P900`:2aCooooo000Kooooo`09010@4P0?3a403`lA010@
4P0?3a4030`>00d=3`0A4A<03Ph@00803`lA00<02@T;010>3`0@3Pl01@0@3Pl01P0J61T02`T:034_
<00A3a0020H700h<3@<04@l@00l04a4B01DC500@3Pl04Q0A014?400?3@h04Q0A01DD4P0A40d040l;
01<B3P0H5a<04Q4=00/:1P0B4@d00P0@3`/0200A40`03`h:00h=2@0F5A<03Pd;00X91`0?3P`040l=
0P0A40h01`0@3`d03`h<00h=2`0>3@/03`h<00l?3@0>3P`00P0=3@/200h>300600D50`061P@01`L5
01<C4@0P81h020P60`0@3`/2014@300>00T81P0:2@D061LC01hM6@0@3`/030/700h>2P0?40/0414<
014B3@0@4@`03Pl:00l@2`0@4@`300l@2`03014B3@0?40/03Pl:00@0414<02X01`P300H70P0<3@P0
20T401HG4P0E5Q402P/600h?2P0F5a806Q/F01PI500C50l02@X5014B3@0D5A003@h900h?2P0A4Ph0
4A8D00l@500@4AD04a@H014B500A4Q<030d?01lQ800>40h02P`900lA3P0>40d051@D014A4@0@4100
3@d=018B4P0@41006a/K00D51@0W9bL06ATI01DE5@0;2`/2010?3@803Pd;0`0@3`d201<B400`018A
3`0C4Q005A@B018B400C4a404A4?00h>300=3@/03Ph<01<C4@0@40h030`:00d=2`0?3`d03@d;00T:
1@0>3`X02``701TJ5@0B4`h02P/6018C3P0C50l04A8=00X;1P061`801PH400lA400>40l04aDD024S
8@0E5a@04Q@A01DG4`0:30L01PT2034d;@0_<R/01`X301HG4P0A4Pd05QLB00l@2`0D5A009RLR01@E
400C50l04Q<>0P0C50l00`0D5A004a@?01@E400201@E400<01<D3`0B4`h03a0;010A300B4`h04a@?
01@E400H6AD06Q`I010B3`0?4@h04aDB0P0?4@h2014C400@01HH5@0A4a002`d:01HH5@0A4a007b4N
010B3`1_LFh09RPU01dO700T9R<06A/H01HH5@0H6QL05ALD01@G4`8051TC00D06QlI038g<@29SXP0
bLk803Tn>00201<H4P1Z018G4@0M8Qd0728P01<I6@0d>SX0318B01XP800I7al05adM01`R8P0A5aL0
7B<S014G5`0k@D408RX/01`T9P0I8B806R8T01TR8@0K92806R<P01PQ700I8Q`06b@O01`V7P0K9Ad0
82LO01TP600M91d05adI01`R800R:bX06R@S01dW9P0J9B007BXQ01HS6P0U<RP0934Z02Dc;00W=Rl0
:3Lb02Lg<@0T=3408S8_02Hh=00W>SP08cHd02e0?P0^@Cl0:3`k02m3@P0/@3l0<4A502e1@P0dB4T0
PYFI0395B@0U>3`09CPn03U<DP0/?dD0>4]?03U<C`0jCTl0?E5@04AHEP18G5X0=DU703a@D00cATX0
AEQN03Y<E@12E5h0AEIP065_NP1fQ8d0AUMO04iQI`1;GV@0AEYM04aQHP1BIfP0C6AT04QQGP1;Hf<0
F6]`06n2R02>XJL0N8^A05AWJ`1JKG40EFUZ05=WJ01GJf`0EFUX059VI@1EJFP0G6i^05e_K`1JK6`0
HG=c06YlO01YNg/0Jgem06UkN`80K7in00@0KX2007>5Q`1`PhL0M8J:0P1kSI409`1gQX/0NXV>07n>
T`23T9H0Q96G08FBV026TiT0RYJK08fHW02?VYh0TYfQ09JQY@2IXZL0VjBY09ZSZ02JXJL0WZF[0::Y
[`2W[;80Yj^e0;6e`02c]l80YjZe0;2b_P2g^LD0/kC00;:b_P2d]<00]KC10;Fc`02i]l@0`;k;0;Zh
a@2e/l00^[S50;^iaP2h]/<0][C10;Bb_`020;:`_@050;Bb_`2a/;`0/[:l0:ja^P2/[kP00P2/[kH0
1`2Y[;<0YZV^0:FX[@2TZ:/0Yj^^0:R/[`2Y[K00102PXjP07P2QY:T0X:FY09ZRY@2IXJ@0UinR09BN
X02CWIl0U9jP09BOX@2?Vi/0RiNG08fIV@2;UiD0PHf;07b8Q01jQh00L7ee06EbJ@1NJf80EF9H05ES
EP1CHUD0FVYM05i^H`1IJUh0EFMK05e^I01LKV@0F6aQ05EYH080E6QO00P0CfAM05=XH@1>He`0Bf1I
04YOF014FE80@EI?03aABP80>4e60P0kD4T01010EDh0>Tm803=8@@0bACl203A7@@0W03A5?`0R<Rd0
7RdX02Da;@0Q;BT09SD`02Hf<@0fAd40=DI002/l=P0`@C/0>4U30311>`0^?cT0:S/e02Hg<@0K;2H0
9CH`02Dd<@0Z>CH0:3Ld028a;P0U<Bl0:CDc02@^;@0S;B`082XY01hW9P0O:2L08BXW02@^9@0K9Ad0
7BLO024[8`0T;BP0:C8]020Y900U;R/082TV00807BHS02d08R/V024V8@0Q9R007R<M01`Q6`0K81X0
7R<M01lT7P0J7aT061dG010E3`0S:2805AXE01TN6P0P9B409BXV01DJ5P0H7AT08bPT01TN6P0J7a/0
61dI030e<@19CTX092TU01LL600K81`061dI01LL600J7a/05Q/G02/`;00/<Bd04AHB020U8@0N8al0
5APF01lO7`0F5QH05aLG01<C4`0@41006QXJ01<C4`0A4A400P0E5AD0100B4Q805ADE01DE5@0E5AD2
01@D500:01<C4`0U9BD05aLG01LG5`0O7al05aLG01TI6@0D4a405A@B01HE4`8051<A00l05aHD00<2
000:2@L02`X801TH5P0=30X0BTU705UEE00P71/04Ph=010<2`0C3`h0510?01HB4@0E4A000P0C3`h0
2P0B3Pd040`901HB3`0E4@d04Ph;014=2P0A3@/04@d<018>3@0A3@d2010<3@03014=3P0B3Pl040X:
00804P`<00D040X:014;2`0B30`04P`<014;2`02010:2P0@014;2`0B30`03`T900l92@0B30`04`d=
010:2P0>20P03@L700l92@0A2`/04P`<014;2`0@2PX03`T9014;2`804P`<00<03`T900h8200@2PX0
1@0@2PX01P0910801`8000@0000D3``01`8001@?30803`X70P0@2`P00`0?2PL03PT500l:1@0200l:
10<03`X601805A0=01PB4P0H4Q801`8200@0000@2PT03PT600d81@0:1@803PT600l:1`0>2@H03`X7
010;200>2@H02`H300X50P0<1`@200h91P0500l:1`0>2@H03PT600d81@0>2@H00`0?2PL02@0>2@H0
3@P600h8200?2@T03@L700/51@0=1`L03PP800`61P0200/51@0600d71`0>20P030D501061`0:0@80
40H70P0C2@X00`0B20T04@L8014720030147200300l71@0>2@H03PT600803PT600L03`X700L2000C
3P/04@`900@00009104040/800805@/<00@04PP900l51P0=0`@03@<41@0@1PL00`0A1`P03`D60106
1`020147200400h41@0<0P<04@L80147208040H70P0?1@H01`0?1PT03@@701072P0D2`h04PT<00`3
1P0<1PP00P0>20X00`0<1PP03@L900h82P0Dooooo`006oooool00`0A4A<0410B00l?4@02010@4P07
00d=3`0A4A<04A4C02`/;P0B4Q@02`/=01PH6P0600h<3@0701DC500Z:2T040h?030^;`0:20T04@l@
010>3`05018@4@0=010>3`0<2P/03@/<014?400@3Pl03@`:014@3@0@3`/04a8>01LF4P0A40`030/7
018A3@0200l>2P06010?2`0?3PX03Pd901LF500E51805aHD0P0?3P`00`0<2`T040l=014@3P02014@
3P04010?3@0?3`d03Ph<00d=2`@03Ph<00H05aLE00H61@0B4Q002`/901TI5`0B4Pl2014@300D018A
3@0@3`/03`h:018A3@0?3PX030/701LF4P0H5a<04a8>014A3@0B4`h0414<00l@2`0@4@`04a@?014B
3@0>3`X03a0;018C3P0D5A0201<D3`0@014B3@0@4@`03a0;00h?2P0@4@`06Q/F05AED00J6aH061TD
00/<1`0?40/0414<018C3P0E5Q404A8=010A30<04a@?01h0414<014B3@0E5Q40410<01<E4`0@4Q40
2``<01@F5P0D5Q@03Q0=01<E4`0@4@h030h901<E400>40/0418=01LG5@071`L0410@00d=3@0A4A40
30`<00/;2`0l?3`0a/K604];B`0A4A406ATI014@3P0@3`d200l>3003010?3@0A40h03`h<00804Q4?
00H04A0>018A3`0D4a403`l=014A3`0B4Q02014A3`0X01@D4P0>3P`03Ph<01<C4@0E5A<04Q8@014A
3`0I6QD03a0;00d>2`0I6QD03Pl:018C3P0?40/05AHA018C3P0A4Pd0824L02d]:`0A4Q<02``>01@E
5P0Z;2/06adL01<E4`0A4a005ALD014C3`0?4@`04Q@?01<E400B4`h03a0;01@E400A4Pd05aPC02HW
8P0F5a8051D@01<D3`<04Q<>1`0C50l07@0A4Pd04Q<>01<D3`0E5Q4051HB01DG500@4Pl05ALD01LI
5P0@4Pl051HC01HH5@0A4a004aDB014C400C5A806adJ018D4@0E5a@06Q`I04a>B`0N81d05QPE00d?
300I6aP04aDB01HH5@0H6QL04QDA00@05AXD01P08RLQ03Pm=`0A5Q005Q/E01/P6P0L8A/05a`G020V
900D6QX07R@T01lU9@0E6a/061hN018H600U:b/07B<S028X:00J820061hN01hW9@0I8R005b0N01TR
800H8Ah201XS80806B8O04d072DR01dV8P0L9B007bHO01TP600Q:28082TU028[:00M9RD08bd/01/U
900Q;BP08RlW024^9@0W=2X082`W02Hd<00W=S808c8_02<b<00X>3L0:CTh0393@P0fB4P08S@d02Tk
>`0X>SX08cLf0355A00`A4<0<TI70355AP0oDe@0UjZ^03a?D`0jCE40=dY@03=6C00fBDl0>4]?03I9
C00eBDX0=TY903]?CP0nDU40?51?03mCE01>HFH0J7^205=UKP1;GVH0E6E]055RJP1DIFd0@E9I059U
J`1;GV@0BUeQ05EZK@1HKG00CfAU04eUI@1EK6d0DFAY05IYK`1KKW@0EfY^05=VJP1GJfd0FFe^05Q/
J`1JKVd0FFe/05M[JP1IKF`0Ffe_05a^L00206EgN@0>061bM01UMgT0KGn106]mO`1`PX@0LXB60763
Q@1dQXP0O8jB07>5R@1eQh/0NH^?07j=TP23TIH208FBV00S08JBV02:UI/0SYVO09:MX`2BW:<0UIjU
09VRZ@2LYJ`0WjJ^0:>Z/P2X[kL0ZJff0:N[]02Z[[L0[[6j0;:d_`2o`Ld0_/3<0;6c_`2e]/80^KW5
0;Vha@2f]<40^KO40<2mbP2f//00`[k<0>?Ok@3Fe>40`;k;0;fkb031_l`0_[c90;bja`2i]l@00P2g
]L801@2f]<40];>o0;>c_@2`/k`0[[6j0080[k:i00<0[K2g0:^^/`2Y[;400`2WZjh00`2UZJ`0XZFZ
0::UZP030:>VZ`0R0:6VZP2LY:L0Vj>V09ZRY@2FX:80UInQ09BNX02@Vih0SYVL08bGV@2;UiP0RYJF
08>?S01iQX00N8Em06UfK01LJEh0F6IH04aJC01FI5L0EfIJ05][H01JJUl0EfQM05a]H`1KK680Gg9X
05Y^I@1AIE`0D6AL05Q[I@1EJV<0DfQQ04aQFP80BUmH00<0A5UB03mDC@0kD4T00P0hCDH03`0fBd@0
<DHo03U<AP0gBT@0>4]503a=A`0iBT@0<d@n03=2?@0Y>3<0HG1[02lk=`0X=300:STd02Tj=00202`m
=`0402dn>00b@cd0=TM102Hg<@80:CXd01409SLa01`]9`0X>C<08c8_02Th=@0X=c@08c8_02Da;`0W
<c4092h]028/:`0P:RT07RLV01lX9`0Q:RL082XQ01XT700201`V7P0401dV8@0R:bH0;3D`02/d<@80
7RLT02L07BHS02</:00N8ah092TS01hS7@0I7QP0724K024V800K81X06QlI028W8P0n@cd05Q/E01/P
6`0F6aL07b@P01HK5`0K81`09BXV01LL600P9B406QlK01TN6P0N8al0<cPd01<H500H7AT06QlK01<H
500J7a/08BHR01/P700A5Q807B8N01PM6@0B5a<03A8>01HI5`0A4A400P0G5aL0200N7Qh07AdM01@D
500E5AD05aLG01@D500G5aL0=cLg0`0C4a<201@D500:01HF5P0D51@04A4A01PH600F5QH03@d=01XJ
6P0F5A<051<A018A3`8051<A00P04Q4?00h=2`0H5aD04Q4?01HE4`0;2PT07A`J03Da<0804`l>0140
2@D400P4100F4Q40510?01DA400D40l04Ph=014=300B3P/0510=01<@300A3@X040`9010<2P0@30/0
4Ph=014=3@02010<3@03014=3P0B3Pl040X:00804P`<00<040X:014;2`0B30`00P0B30`2014;2`80
4P`<00h03PP8018<300A2`/03`T9010:2P0>20P04@/;00l92@0>20P040X:018<300D3Ph040X:014;
2`804P`<00<040X:00l92@0@2PX01@0@2PX01@0?2PL05a8?01dH5@0U81d03@P600<03`X70P0@2`P0
0`0?2PL03PT500l:1@0200l:10<03`X600/04`h;02/V9P0G4A40@cdm02HP800C3@`040/800l:1`0;
1P<03PT600l:1`0200`7100400h91P0@2`P03`X700l:1`<03PT600<03`X700h91P0>2@H00P0=20D0
1`0>2@H03`X700h91P0=20D03PT700h8200?2@T00P0D3Ph00`0?2@T03@L7010:2P04010:2P030149
2P0I3a004@L800804`T:00<03`D601061`0A1`P00`0B20T0100A1`P04PX800h91P0>2@H200l:1`09
00h91P0;1P@03`X7010;200>2@H03`X700/71@0H3Pl05@/<00@04PP9200@1PL0100?1@H040H70188
2@0C2@X20147208040H700h03`D600h51P0>2@/03PT:00d82P0=1`T03`T;010:300?1PT04@P;0107
2P0>1@P03`D801062QCooooo000Kooooo`0<01@D5P0A4A<03Ph@010@4P0A4A<0410B01HF600@4180
8B4S01<C5@0=3@l04a<E1P0>30d0500J61T03`h>01lM7P0100009B<T00H41@0B414040h?014?400D
4Q<040h?00d;300?3@h03P`=00l=3P0@3Pl03`d>00h=2`0?3P/03`h:0P0@3`/01@0?3PX03Pd9018A
3@0>3@T03@`800803`h:00P03Pd900d<2P0I61H08B0N00d<2P0?3P`02PT7010?3@804Q4?01`04a8@
014@3P0@3`d03Ph<00d=2`0?3`d04A4?00l?3@092@L06ATG01hN700<30X0JVYX0:6QW`0G5Q<04A0<
00l>2P0>3@T04A0<01DD400>3@X02`X601LF4P0I61@03@`800h=2@0C4`l0414<0P0>3`X0100@4@`0
4Q<>01DF4@0A4Pd200`=20803a0;0240414<00h?2P0C50l0414<00X;1P0;30L00@8002PY900;30L0
51D@00`=200C50l05QLB018C3P0?40/051D@01HG4P0B4`h05AHA01HG4P0B4`h0414<01<D3`0@4@`0
3a0;00X;1P0H61D04A4?010A300A4Pd0004001hO6@0<3@L00P0B4`d03@0@4@`05aLE04U9B@0K6a/0
5ADE00d=3@0A4A4071`L01HF5P1BDU808B4Q01<C4`0;2`/00P0D4a42018A3`8051<A00P040l=018A
3`0B4@l04A0>018A3`0D4a403`l=014A3`804Q8@02004a<A01HF500?3`d0410>01XJ600M7A/051@B
010@3P0B4`h03@h901@E400P8A`030d800d>2@0I6QD05AHA010A300B4`h07QlJ02LW9@0?41<02P/=
00/<3P0E5QP03a4@014C4P0C5A@020X700d?300C5A803@l:00T;1P80414<00D04A8=01<D3`0E5Q40
5aPC018C3P03014B3@03018C3P0C50l04Q<>00<04A8=0P0B4`h02`0G61<051D@018C3P0C50l05AHA
01@F4P0D5Q<030h;00lA3P0F61D04aDB00806A/H00d04Q@A01<E4P0@4Pl05QPE02PZ9`0R92402@/8
01LI5P041P<06adJ02HX9@0<3P/09BLT00805ALD00P06adJ01TM6@0K81`04aPD01HK5`0J7a/05a`H
01`Q7@807b@P03H04aPD01`Q7@0I7QX0318@020V9P1dNWX051XJ01LM7@0L8R8051XJ01XP800D6QX0
41HF01PN7P0N92@06B8O01DN6@0G81/06b@O01TR7@0J8b006b@Q01XS800J8b8072DT01dV9@0K9280
92dX01LQ6@0L9B00:C8_03@m>P0a>c/07bTZ01dY9`0O:bL082lX02De:`0O;bH08Rh/02<`<00P;Rh0
7bd]028a<@0V=SH052@T06YkO028VY`0?e5C028d=P0a@dD09SXi02e1@00/@3l203=7B00903U=CP1:
GF40<dI:045DF013EU`0>TeC04YMH`0lCe<0>dm@0080>De>0580>dm@03a@D@0kCe00?4mC051SJ@1F
JG00C5mV05MZL@1JKG@0D6=Y04EHGP1;GV@0D6=Y04YMH`1;GV@0Cf9V05AWJ`1CJ6/0DVMZ05I[KP1?
HVH0E6M[05Q[K`1GJVh0DfMX05AXJ@1DJ6P0Ef]Z059VI@1IKF/0Gg=a05]_KP1RM7H0HG=e06IhNP1X
NW`0JWan06n1P`1eQhT0K7j006j0PP1`PX@0LXB607F7R@2BY:P0P8nD07b;T01mS940PHjD08FBV026
TiT0RYFK08^FW02=V9h0TIbR09BNY@2GWZH0VZ6Y09nV[P2QZ;00Y:Ra0:JZ/`2^/[/0/KBm0:f`^@2`
/k`0];Bn0;2`^`2^[[X0/;2l0;Bd`02i]l@0_;[70;fja`2m^LL0_[[80;njb035_ld0b/CB0=KBh03A
cM/0`;c:0P2l^<H0202k]lD0^[K40;Jb`02n^/P0`[k<0;^ga@2d/Kh0/k>m0P2b/[`01P2c/k/0];Bl
0;>c^`2`/KH0[Jjc0:Z[[`80ZJZ^00<0YjR/0:BW[02UZ:d00P2UZ:d07@2SYZ/0XJJZ09jVZ@2NYZT0
WJFX09VSY@2GXJ<0UInQ092KW`2AW:00T9^N08RCU@22SXh0P8b907B1NP1ePWT0IG=W05UWF01KJEP0
DEm>05]YG01OKF<0Hg=X05i^I01GIed0FV]Q05a]I@1LKfH0EVYQ0080D6=M00H0EVUS05EXHP1@Hed0
AeYD04QKE@1>HE/204YME`0B049EC`0nDD/0?e9<03e@BP0gBT@0=DI003=4?P0fAd40>TU403E4?`0[
>SD0:3Lb02Lf<@0kBTD05bHQ020_:P0fAD00:SXg0P0W=c@04P0/?3T0;cll02lo?00]?CX0=TI302lo
?00Z>SL07BdZ02@d<@0R<B`093<^02He<00U=2l0930/02<_:`0T;b/08bhZ020[9`807bPU00/08BXU
01lY800L9Qh07BLO01TS6`0F7aX06R<N02D^:@0M9R<051dJ010I5P0201<L6@08020U8@0N8al07B8N
01/P700J7a/05AXF01XO6`0Q9R8201/P700W01HK5`0R9b<06b0L01PM6@0B5a<06QlK02@Y9@0I7QX0
9R/W010E4@0J7a/07b@P03m4@00S:2@05Q/G01TN6P0C61@07B8N02DZ9P0A5Q804aPD01XO6`0?5100
51TE01`Q7@0=40h05aLG01XJ6P0I6AT09RHV02<S8`0E5AD04Q8B014A4@0@41008R8R06IVIP0D51@0
4a<C00804Q8B01004a<C01DE5@0M7Ad04Q8B00d=3@0M7Ad08B4Q01<C4`0E51805QDC01PG5@0E5180
4a8@018A3`0G5Q@06QTG0P0D4a402@0E51801`H500l;2P0C3`h07ATH01LC4P0C3`h081`K010<2`02
01<?3P8040`;0P0C3``0100B3`/04@d:014=2P0B3P`2018>3@06014=3@0@30d040`=014=3P0B3Pl0
40X:0P0B30`01@0@2PX04@/;018<300C3@d04P`<00804@/;00P04P`<01<=3@0>20P05@l?010:2P0>
20P04@/;00l92@8040X:00<03`T9010:2P0A2`/00P0A2`/01@0@2PX03`T9010:2P0@2PX04@/;00H0
40X:00H06A@A00`7100>2@H02PD401<>2`0D3``200l:1`8040/800<03`X700h91@0?2PD00P0?2P@3
00l:1P0@00d81`0H4Q805@l?02PR8P0H4Q802P@3010;200A30T030L400h91P0@2`P05A0=01@?300=
20D02PD200d81@@03PT600<03`X700h91P0>2@H00`0=20D02@0>2@H03@P500d81@0=1`H03PP800l9
2@0B30`04@/;00h8200300d71`0B00h8200=1`L03@L700/3100C2@X03P@501882@0C2@X04@L800h4
1@0?1@H04PP901<92P0B20T04@L801<:2`0?2@T03@L70P0?2@T03@0<1PH050h>00d71`0<1PH02`D5
00L10@0E3`l04@L800h41@0;0@803P@501061`0A1`P00`0@1PL00`0?1@H03P@500h41@0201472004
01061`0A1`P04PP901<92P804@L80P0@1PL03P0?1@H03PD600T51P0:20T040h?01HB4`0@2`d01`43
00l62@0A1`/04@H:00l4200@10P04@D95?ooool001_ooooo00`05QHH014A4`0>3Q003`lA018B500A
4A<05QHH00h>40092@/04A4C00h>40071`T600l=3P0;00H41@0C4A800@0001DC50071@H05aDF00l=
3P0<2P/040h?01LE5P0D4Q<00P0?3@h0200D4Q<04a4B00h<3@0?3@h04A0>00h=2P0?3PX03Pd90P0=
30P0100?3PX04Q4=00h=2@0=30P200l>2P0500h=2@0;2PP05A@B01`K6@071P@00P0B4@l0100>3@/0
3`h<010?3@0A40h200l>300H00d=2`0<30X0410>018B400@40h04Q8@00l?3@0000004A4?01lO7@18
B4H05QDB014@300=30P02`X601<B3P0K6QH08b8N01LF4P0<2`L03Pd9018A3@0A40`0410<0`0>3`X0
1@0?40/04A8=01hO6P0Q8Qd05aPC0080414<01@04Q<>010A300?40/06Q/F01TJ5@0A4Pd04Q<>010A
300<3@P04a@?01DF4@0D5A004Q<>010A300<3@P04a@?02DV8@0W:2<04a@?00d>2@804A8=01d03@h9
010A300B4`h0414<010A2`0=3PT0414<00d>200F5a407AhH0083000G618000400083000A4Pd051@B
08j>SP0V9RH04Q8B01@D500;2`/03@d=01dM7@0E5AD051@D018B4P0:2PX051<A01<B4002018A3`09
01<B400D4a404A0>01<B400D4a404Q4?01<B400E51803@d;0080410>00h03`l=010@3P0B4Q005QHD
010@3P0D51805ADC014A3`0C4a403a0;01HG4P000@003@h901PI50803Pl:01T030d800h?2P0C50l0
4a@?014A3`0A4QD05aPJ01@E5`0C51H02`d<018D4`0C5A@061XG01DG500B51404A<>00lA300A4Pd0
4Q<>00l@2`0C50l04Q<>00d>2@0C50l04A8=00@0414<00<04Q<>014B3@0@4@`00P0A4Pd00`0B4`h0
6AXE01DF4@0201<D3`0^01@E400G61@061XG010B3`0B51405ALD00lA3P0C5A805QPE01DG500J71T0
3Q0=00`>2`0I6aP02`d:01/M6P0H6QL06Q`I00h@3@0K7AX01@L402HX9@0F61D04Q@A01@F4`0A5A40
5AXF018G4`0H7AT04QLC00hC3`0F6aL07B8N01XO6`0F6aL07R<O018G4`0M8b<041HF02D[:`0L8R80
5A/K01PN7P0C6AT051XJ01hT90805Q`L00X06AlN01PQ7P0D7AP0624L01dV8@0K91l06b@Q01`U8P0K
92406R<R0P0L9B@0800K9280FF9M03a6?P0P:B@06B8O020Z:@0N:2T07b/[02@`<00R;R/09C@_02dl
=@0R<RT0:3@b028_;`0N;2`08Bl_02Dd=00V=SH0<T9202m0@@0dATP06R`^02do@P0/?T00:Sho02Tm
?00W>cX0=4Q903=7B00aADH0<dI:0P0dAd/01@0jCE<0<DA:03Q;C`0lCe<0?51A0080>dm@00d0?E5B
03e@E014Ee/0?E1F04AGG@0hBe80@5=J06UlP`1;GV@0F6]a04]NI017FV00AUUO0080C5mU01T0AeYN
04mRIP1EJVd0DfQ[059WJP1GJVh0E6M[05a_L`1HJfh0EFUZ05a`L@1IKF`0GG5`05IZJ@1PM780K81n
06EiN01PLW@0I7Ih069dMP1ZO7h0L8:406eoP@27VI/0MXR:0080LXB601X0M8J807R:S01nT9@0N8N<
07f<T@23TYL0Q96G08FBV028UI/0SYVO096LXP2BWJ<0TijT09JNYP2HWjL0Vj:Z0:2W[`2SZ[80YJVb
0:>W/02[[[L0[k:k0:^^]`2a/K/0/k>m0;Ng`P80][K201d0_;_70;Vga02g]L80_;W60<S4dP36`]00
`K_90=G?g@3Bc=X0`Kc:0;nkb@31_L/0aL7?0;nkb@2k]lD0^[K40;^ga@39aM<0dLgK0<O3d@2k^<H0
/k6l0;6a^`2b/[`0];Bl0;Jf_P2e]Kd0[Jjc0:^//@020:RY[@030:VZ[P2WZ:`0YJR]0080YZV^00<0
YJR]0:>VZ`2PYJT00P2OYjX06@2NYZT0VZBV09RRY02FX:80TIbR09BOY@2BWJ40QY6C07j:RP1mRHD0
Lh1g07B1M`1TLV@0EVAC05YYEP1?GD`0Hg5T05YXGP1RLVL0JWY`065aI`1BHeT0GVmW05U/H`1CIeh0
0P1BIEl205=VH00404ePFP14Ee40AUUC04mRG080CV5K00X0AEQB03mBC013EU00AEQB04=FD00eAT00
<T8l0391?00eA3l0<3lj0P0V=C00=@0W=S4062LR02Xi=00a@3/0>4M202`l>@0[>cP0;3`i02hn>`0_
?c`0;Shk02dm>P0a@Ch09CDb02@d<@0R<Rl0:SXg024`:`0R<B`093<^02He<00U<Bd08RhZ02D`;00T
;b/08B`X01lX9@0P:BH08R/V01/U700K9Ad07RPP01XT700H8A`06b@O01dV8@0O:2D08b`Y024Z9`0T
;BX07RLT02<X900I7QX0724M01lT800H7AT05AXF01LL600E6QH082DQ01PM6@0`=C405Q/G008061dI
02008RLS01/P700D6AD05Q/G02`a;@0E6QH08RLS01DJ5P0W;2P061dI01TN6P0M8Qh05AXF01dR7P0Q
9R806AhJ01<H500@5A406b0L00P=2@0J7a/04A<A01lO7`0I6AT04a<C01dM7@0E5AD06QXJ018B4P0D
51@05ADE00h>3P805QHF00H05ADE01<C4`0A4A404A4A01<C4`0>3Ph2014A4@0F010@400C4a<03Ph>
00l>300F5A<06QTG018A3`0=30X040l=01HE4`081`D03Pd;00d<2P0:2@L05QDC014=300C3`h02PH5
018>3@0C3`h04@d<00h:2@804Ph=0P0@30/201<?300701<?2`0B3P/04Ph;01@@3P0D40l04Ph=014=
3@02010<3@03014=3P0B3Pl040X:00804P`<00D040X:014;2`0B30`04`d=018<3002014;2`0:018<
300C3@d03PP801H@400A2`/03@L7014;2`0?2@T03PP8010:2P804P`<00P03`T900h8200B30`03`T9
00h8200?2@T04@/;018<30H040X:0P0>2@H0100L5a@03@T701@?300;1P<200l:1`8040/800<03`X7
00h91@0?2PD00P0?2P@300l:1P0B01<>2`04000050h>00l92@0>20P03PT700h91P0B3@X03@P500h9
1P0A30T091lL02TT8@0I51403`X7010;200A30T03`X70P0>2@H00`0?2PL03PT600h91P0300d81@09
00h91P0=20D03@P500X50`0;1@D03PP800/51@080P802P@400803PP80P0?2@T01@0>20P03@L700h6
1P0G3@h04@L800804`T:00d03`D600h41@0?1@H04PP901<92P0B20T04@P901<:2`0?2@T03@L700l9
2@0@2PX030H600802`D500X040X:00H0000:10@0BD=301L=3P0C2@X03P@501061`0B20T04@L80`0@
1PL00`0?1@H03P@500h41@0201<92P0401D;300D2P/04`T:01882@804@L80P0@1PL02`0?1@H03PD6
00/92P0?3Pl081hO02`X:@0S7R003PP:00l62@0A1`/04@H:008040@800<04@D9ooooooooool04_oo
ool001_ooooo0P0?3a40100@418020P:00d=3`0=3@l2014A4`80410B0P0?3a40200>30d040h?018@
4@0B414040h?00h<3@0A3a0040h?0P0>30d03`0?3@h040h?01HD5@19AdP06aTJ014?40091`P04a4B
00h<3@0A3a004Q0A014?400=2``030/900h=2P0200h=2@0400l>2P0@3`/040l;010?2`804Q4=03P0
4A0<010?2`0A40`03`h=01PG5@0=30X040l=014@3P0:2@L040l=018A3`0D4a404a8@010?3@0?3P`0
3@d;00`<2P0=3@/03`l=00h>300?3`d04A4?010@3P0?3`d03Ph<00l?3@0=30T05QDA01/J5P0B4@d0
3`h:014@300C4Ph04A0<00h=2@0?3PX04A0<010?2`0>3PX03a0;014B3@0B4`h04A8=00l@2`0>3`X0
3a0;00/<1`0A4Pd04Q<>010A300Q8Qd04a@?01@E400<3@P03Pl:014B3@804a@?00d04Q<>014B3@0A
4Pd04A8=00d>2@0@4@`03a0;051AC01LGEP04a@?010A300A4Pd0414<00803@h900D0414;00l@2P0?
40P04149010A2P02014B2P0301@E3`0B4`d0414;00804A8<00T03Pl:01@D4P0C4a<05ADE018B4P0<
30`03`l?00d=3@0C4a<00P0A4A40200G5aL06QXJ018A3`0C4Q004A0>00l>300B4@l05A@B1P0@3`d0
300<30X03`l=00h>300=3@/03`l=00h>300F5Q@04a<A010@3P0?3`d0410>014A3`804Q<>00@051D@
018C3P0D5A007AhI0P0B4`h05P0@4@`04A8=014B3@0@40h09BLW02l`<P0C5AD051HE010B4@0G6AL0
5ALC00d?300L7QX03a4;014C3P0C5A004A8=01HG4P0F5a@04A8=010A300C50l2014B3@05018C3P0D
5A005AHA01DF4@0D5A000P0B4`h0500C50l051D@01DF4@0K71P0824L018C3P0A4Pd05QLB01DG4`0G
6AH05ALD014C400@4Pl051HC01HH5@0A4a003a4>01PJ5`16B4D07R0M0P0F61D08`0D5Q<04aDB01DG
500F61D05aTF010B3`0G6AH06adJ010B3`0H6QL061`H01@I5@0E6QH05Q/G01LL600F6aL06QlK018G
4`0F6aL0;C8^01lT800G71P061hN01<I6@0a=cL0ATa<01`R8P0F71`05adM01`R8P0K8B406AlO01hT
900P9RH051dJ0080624L01d05b0K01XS7P0I8Ql05b0M01`U8P0O:2L06R<R01/T8`0W<2h0QHj903]4
?P0P:bL072HU024[:P0M:BT07b/[01XV9P0N;BX0:CPc01/Z900U=Bd08bl]02Ld=01FI6@0EfEU02Pg
=`0S<c<09cLg02/l?@0202Li>`0D02/m@00W>C/0;4100314@`0_@d80;d=40396A`0]@D80<DA803M:
CP0jCE40>TeC03U<DP0jCE40>De?03U=CP0kCe00?E1D03mBE`0nDEL2045DF`0G04IIH01=H6L0@5=J
05AWK@1AIVX0CfAW04YOHP19G600B5]Q04YMH`1FJFl0Gg9h06AgO@1FJFl0DFAZ05a_M@1EJ6`0F6a]
05]_L01GJf`0EFUY05U]K01KKfh00P1FJVP01@1OLg40Jgmm061dL`1UMgX0JWb00080K7j200<0KGn3
06n1Q@1cQHT00P1cQHT06@1fR8`0NXb@07^=T@1lRi00PY6F08nNX`20SI<0SibR08NCV@2>VIl0TIbR
09FOY@2GX:L0VZ>Z09ZPZP2f^/D0_l?>0:Z^^@2TYk80ZJ^g0;6c_`2a/Kd0];C00;Rg``2j^<D00P2k
^LH0302n_<T0`;k;0<6nc031_L/0`[k<0<Foc@36`<h0b<7@0<_3dP3:`]40bL7@0<O1c`80a<3>0180
aL7?0<C0cP33_ld0`[k<0<6mb`30_<X0_KW70;bhaP2k^<H0^KO20;Rh`P2i^L<0^;S00;Ng_`2e]Kd0
/;6f0:j_]02[[;020:VZ[P040:^//02XZk00YJR]0:BW[080YZV^0340XZN[09nWZP2OYjX0VZ:U09NQ
X`2IXjD0U9jP09FPY@2;UY/0SIRL086<S@1kQhH0O8R3071mM01[N6h0JgU[065_GP1CHTl0G6YI05MU
F@1OKV@0HW9X06YjL01KK6<0KWmg08VJTP1LKVL0CV5K059UH@1<Ge/0D6=O05IYH`1;GUP0DVEO05EX
HP1>HE/0D6=M04IID`10Ddd0>Te703mBC011E4h0=TM103E3?P0T<Bd0<Shj02Te<@0[=c<09c<_00<0
93<^01D0:3Lb030o>P0`?cX0<D4n02@d<@0c@d009cLd02Ti=P0U=C80;cll02Xj=`0^?S/0;3`i02Lg
=00Y>CH0:3Lb028a;00S<Rd08S4/02Da;@0Z=S800P0Q;2P0500S;RX08BXW01dV8`0P:B@072HN01hX
800Q:b<07bTQ01dV8@0Q:RD06b@O024Z9`0M9R<06b@Q01lX9@0P:BH06AhJ02<X900K81`04QLC0`0J
7a/06P0L8Ad07B8N01/P700J7a/07b@P07AiM@1_M7008bPT01@I5@0N8al06AhJ01/P700J7a/05a`H
01<H500F6aL07B8N01@I5@0K81`061dI018G4`0J7a/051TE01<H500F6aL061dI0P0A5Q806`0G6AL0
5ADE01HF5P0H61P04a<C01DE5@0F5QH04Q8B01HF5P0];Bd071`L01DE5@0A4A4051@D01TI6@0>3Ph0
6a/K018B4P0F5QH04a<C01@D500>3Ph0410@018B4P0A40h04Q4?01<B4002014@3P08018A3`0C4Q00
4Q4?014@3P0@3`d04A0>01<B400F4Q43018>3@0400l;2P0C3`h04@d<014=30804Ph=01L04`l>01<?
300E4@h04Ph:014=2P0C3``04`l=00l;2P0A3@`05A4A00`82@0H51D0510A07=_L02?RHT06aHF01LA
4@0?2@T05@l?01<=3@0A2`/050h>01<=3@02010:2P0F018<300G4A406A<C018<300@2PX04`d=00h8
200Y8b<04P`<01LA4@0C3@d04P`<00l92@0B30`0208202lY:@0K5QH040/;00l92@0@2PX03`T900h8
20803`T900<040X:00l:1`0?2PL00P0@2`P0100?2PL03PT600l:1`0?2PL200h91P0>00l:1`0A30P0
4@`801<>2P0<1`@06aHB07IaK@1`JfL05a8?00d71`0<1PH040X:00h8200<1`D200l:1`0=00`7100@
2`P04@`901@?300P6aP0<bh[02<N6`0H4a003@P700h91P0=20D03PT6010;200300l:1`D03PT600L0
3@P600h8200@2PX03`T900d71`0>20P03`T900D03@L700@03`L70147200B20T04PP9200A1`P04P0D
2``030H600h8200;1@D030H600l92@0@2PX02@@401PB4P0A2`/020<305mIF@0L4Q<06@l@01882@0>
10D03`D601<92PH04PP91@0@1PL04`0?1@H060h?01892P0<0`@03P@50147200A20T02@H700h<3@2B
T940iN7R03Td=P0=1`T02@4301H<3`0B1`/03`D701862P0<0@@05?ooool001_ooooo00<0CdmA00X:
300G5aT00P0>3Q00100J6Q`04A4C010@4P0@418300l?4@0300h<3@0?3@h03`d>00803`d>100>30d0
400@3Pl04@l@018@4@0@3Pl0:2HW018@4@0D4Q<02PP9018@4@0<2P/03P`=010>3`0A3a0040h?00l>
300?3P/200l>2P<040l;00`04A0<00h=2@0;2PH02`X6010?2`0D4`l01PD300`;2@071P@03Pd;01<B
400?3P`5018A3`0600l>300:2PP02PX800h>300A4@l0410>0P0?3`d200h>300<00l?3@0@40h040l<
01<B3P0D4`l03`h:010?2`0A40`03`h:010?2`0A40`040l;0P0>3@T04P0?3`X03a0;014B3@0B4`h0
4A8=00l@2`0D5A003a0;00H70P0:2`H03Pl:00d>2@0C50l02``700h?2P0=3PT03a0;010A30<04Q<>
0`0A4Pd02@0K71L01`P301LH4`0:2`H07b0K01LH4`0>3`X03a0;010A300200h?2P03014B3@0A40/0
4A4900804Q8:00@04a<;01<B3@0G5Q4051<>0P0>3@T03`0@3`/04A0=01`L700E5AD0410@00l?3`0<
30`03Ph>01DE5@0A4A404a<C00h>3P0H61P0?Cdm010?3@0201LF500301<B400B4@l05aHD00H04Q4?
00H07alM01PH5P0G5aD04A4?00T91`0B4Q06014A3`0N01@E400?40/03Pl:00d>2@0?40/061TD014B
3@0>3`X04A8=01@E400>3`X02@X501HH5@0F61L04aDB01DG500C5A804Q@?010C3@0C5A0071lH018E
3@0D5a004A@=01@E400L7AP0GUmJ028S7P0C50l06AXE100D5A0201DF4@<04a@?00T04Q<>010A300?
40/0=cPc01<D3`0B4`h03@h901LH4`0A4`l00P0E5a@02`0B51403a4>014C400C5A8061XG010B3`0G
6AH0OX1m02LY9P0H6QL051HC00804A<@00D051HC01LI5P0J71T04aDB01HH5@0201PJ5`0601/M6P0E
61H04aLF014E500@51<04QHE0P0E6AP05@0C5aH061`K028V9@0M8B0041@C01XP800G7Ad08BLW02dc
<`0E6a/06AlO010F5P0I7al07R@T01/Q8@0M8b<08BLW01XS800L9B80624N01HO700301XS808072DR
01L0624N01LP7@0I8Ql092lY01HQ6`0G8Qh09c<a03<o?`0/=cT09C<d02Hd=00Q;bh07c0Z01h_:@0Z
>S80:cLc028_;@1DHf00DV5N024`;P0a@D00:SXi02dn?@0202Tk>`0302/m?@0W>CT0;40o0080<TI5
03h0<TI703A8B@0_@d@0>TeA03Q;C`0iC500>TeC03Q;D@0bADT0=TY;03Q<C00jCTl0>diB03a?EP0l
CUP0BE]U041BG00jC5H0>4]B05=VK01GJW00CV=V04YPH@17G5d0B5eP04aOH`1>HFD0DfI/05QYL01N
KgH0FFYb05MXL01OL7L0FVi`05Q/K@1LL740G71_05Q/J`1JKVd0EVYX06EiM`1WNgT0GgA_06EjM@1P
M780Jgf006j0Q01_PHD0KX2406n1Q@1`PXH0M8J:07F7R`1fR8`0N8Z>07^=T@1mSi<0PY2F092MX`2o
c=80RIJL086<TP80UZ6W0100VZ>Z09bU[02LYJ`0WjJ^09fR[02WZKH0ZJ^h0:RZ]`2b/Kl0`L3>0<O5
d`2f]<80]kG30;Zga@2n^/T0`;c;0P30_<X03033_ld0aKo=0<Bnc035_ld0b<3?0<[2d@3=`]80clCD
0<k3d`3=`]80bL;A0<S2d080bL?A00<0al7?0<K0cP35_ld00P34_/`00`33_L/0`[c:0<6lbP020;fk
aP070;^ia02i^<00^KS00;Vh`02i^;h0][Fk0:n^/`020:^Z[`0V0:j^/P2VZJh0Z:^`0:V//@2UZ:d0
Y:N/0:J[[`2LY:L0X:R[09jVZ@2FX:80UInQ096KW@2=V9X0RYFG08RCU01nRXP0PHf907B0N`1aOWD0
F6EK061^H01VM6<0BeU8061^G`1PKF<0H6iU05][H@1OKVL0GViW07R9P@2W^;80JWag05AWH`1NLFd0
EfYV04YMF@1GJ68204mPFP1204eNF01@HE/0Gg1Z049CC@10DD/0>T]503U:A00dACl0:3Lb030k=`0[
=S80:C@`02Pc;`0b?CT06bLS02Hb;P0Q;RX093<^02/j=@0_?ST0;3/f01l_;@0V=SD0:c/j0392@@0_
?ch0<T9102dm?00[>cX0;Shm02`l>`0V=SD09CDb02He;`0T<b`09cH_02Dd;@0T<BX09S</02<^:00Q
;2H08bhX028[9P0N9b8082TT01DO5`0F81P06B<K01LQ6@0H8A`07BHQ01XS7P0M9R<07bPU01`U8P0M
9R<08R/X01lS8P0?4a804ADD01XN7@0L81l06AdL01hR8@0K7ah06QhM0P0K7ah0200F6aP0?D8n030e
<@0H7AT051TE024V8P0L8Ad061dI0P0F6aL201PM6@0=01LL600C61@0;C8^02db;P0730P03Q<?01<H
500B5a<051TE01LL600B5a<04aPD01PK6@0201PH600F01/K6`0E5AD051@D01LG5`0@410061PH03/k
>`0^;Rh04Q8B01LG5`0T92@0;Bd]01XJ6P0H61P05aLG00L71`0J6QX02`/;01hN7P0@41004A4A014@
3P804Q4?0P0?3P`00`0B4@l040l=014@3P02018A3`804A0>00L03@T801<?3P0M6AP06ADD010<2`0B
3Pd04@d<00<04Ph=01D04`l>01<?300D40d04Pl;014=2P0C3``04Ph<010<2`0E4A00510@00T51P0:
1PL03`/<03Da<P0l=SH02P@401H@400E3`l08A/K00h8200?2@T00P0B30`0600@2PX04@/;01<=3@0=
1`L03`T900d71`0>20P04`d=018<300Y8b<04P`<01<=3@0A2`/05a4A01H@400?2@T040X:04@n?P0[
9BD07QPH01<=3@0@2PX03`T900h820803`T900<040X:00l:1`0?2PL00P0@2`P04@0?2PL03PT600h9
1P0<1`@03PT601<>2`0A30T03PT500h9100:1@007QTC01/F4P3RgMT0]:n[01dH5@0@2PX030H60080
3@L700@03`T801<>2`0B3@X03PT60P0@2`P01`0A30T03`X700D0000L5aD0AT4n020K600>2@H00P0=
20D0100>2@H03@P500`7100=20D500h91P0600l9200?2@T03`T9018<300A2`/03`T91P0=1`L0100?
1`L04@L801882@0B20T80147200B00/21@0H4Q@050h@01D?4@0:10H05Q0B00H00P0B30h03`T;00h8
2P0I4aD030L800d3100>10D04@L801882@0A1`P040H71`0B20T20147200E01061`0?1@H03`D600L0
000@1PL0718C00h41@0A1`P01P00014=3P0;1`P08alP04I0@P0G4A<04`d?01@;3P0=10L02`8500X1
100>0`L06@hB01Cooooo000Kooooo`0601LG6@0=3@l0DE5C01@D5P0A4A<000020P0@418300l?4@03
00h>400?3@h03P`=00803@/<00<03P`=00l=3P0>30d00P0>30d2010>3`09014?40081PL02@L800L5
1P0H5QL03@/<010>3`0=2``03`d>00<040h?00<03`h<010?300@3`/0100@3`/0200A40`03Pd900`;
1`0;2PH040l;01<B3P0E51804Q4?0P0>3@/02`0@3`d03@`:010?3@0?3P`03Pd;00l>300@3`d03`h<
00`<2P0;2`T03Ph<0080410>00X03`l=00h>300>3P`03`l=010@3P0A4@l04Q4>014@300@3`/03`h:
0P0@3`/0100>3@T04A0<01@C3`0B4@d200h=2@0A010@300@4@`04A8=014B3@0@4@`03a0;00h?2P0A
4Pd07QlJ01`M600<3@P03Pl:014B3@0<3@P03a0;010A300A4Pd01P0@4@`02P0?40/06Q/F0042000B
4`h04A8=02<T7`0<3@T03@h900h?2P0?40/200h?2P03018C3@0@3`X0410800<0410800/040l:01HE
400C4Ph03`h:00l>300A40h04A0?01DE5@0>3Ph03@d=018B4P02014A4@0<00l?3`0C4a<05QHF010@
400B4Q80:2PX00h=2`0G5Q@06APF01@C4@0A40h05QDC1P0A40h02019BDL08B4O01@D4P0E5A<030`:
00h>300?3`d04A4?0`0B4Q002`0A4@l030d8010A300H6A@05aPC00h?2P0<3@P0414<00h?2P0B4`h0
4a@?00804A8=0180418=00lA3P0J71L04Q@@00X<1`0520404QD=01`O600N8AP04QD;01LJ4@0D5`h0
51D?00h?2P18BD@061TD00/<1`0I6QD401@E40804a@?00`0414<018C3P0C50l051D@018C3P0A4Pd0
?Chi01@E400G61<03a0;01DF4@0@4Ph201@F4`0901<E4P0@4Pl03a4>01@F4`0;3@X06A/H01@F4`0a
<c0030h;00804Q@A00`04A<@01<E4P0A4a004aDB01HH5@0@4Pl05QPE01LI5P0H6QL06Q`I01<F500C
5aH2018F5@0<01<G5P0D61L06AdL01`P7`0G6aX04ADD01XN7@0M8B003A<C02H/;00A5aL020h>0P0J
82002P0C6AT0728R024W9`0J82005Q`L01XP800T;B`09Bh]01hW9@0H8B0201XS800O01TR7`0J8b00
6b@P01hW900N9b8072DP01/V800I91h09S0^02Xf=P0G8b<0BEAF0390@@0Q;c008S0`00lO700E9R00
8S<[01/W8`0Z>3<0;3/f02Th=@0X=c@093@c02Ti>00[?3/0:cdm02`n?P0^@400;Clo02/o?P020396
A@1;03=7B00dB4T0;d=403M:CP0iC500>4]?03M:D00fBDl0=4M;03I:B`0kCdl0?e9F041CF@12E5d0
A5IP04UKI@0lCUP0CEmY041CFP14Eeh0D6EX04aQHP17GEh0AEYK04UNH@1?HVH0D6=W051SJ@1BHfX0
EfQ_05MXL01EIVh0FV]b05]_L@1GJf`0Ffm`05eaL01JKVd0FFe/05M[J@1YOG/0KH5o061eL01TNG@0
HWId06QjO@1/OX80KX2406n1Q@1bQ8P0M8J:07J8S01gRHd0NH^?07^=T@1mSi<0OY2D08JCV@2CX:H0
^LK<08jKX@25T9H0Uj:X09JQY`2JXjX0W:F/09fV[@2PYjl0YZVd0:^]^P2Z[;T0/;6n0:f/^P2`[kd0
_Kc:0080^;K400<0^kS60;nkbP32_/d00P33_ld20<S2d0090<O1c`39`M00bl?B0<g5e03@aMD0dLKF
0=35e@3?a=@0cLCC00<0blGC00<0bL?A0<S2d036`<h00`35_ld01@34_/`0`kk<0<6nb@2n_<L0^kW4
0080^KS000P0^[W10;Zi_`2f]K/0[jjc0:b[/02][;40/K6f0:f^/`80Zjjc03l0Z:^`0:JY[P2UZZh0
WJFX0:>[[P2RZZd0Uj6S09BNX02AVid0RYJF08nKV@2=VIL0OXZ608FBR`1cP7P0FVMM04aIC`2MZih0
a]C506QfIP1KJEX0HVmU05m^I01OKfD0H6mX05][H`1RLf/0IGI`05QZI@1LKf/0GG1/05Q[I`1LKf/0
Gg1Z05AUG`1=GUP0BU]E04UJE01CI5h0@55;03a=A`0fAd40<d@n02ho>@0W=S40;3Lc02D^:`0[=S80
9c8^028]:@0Z=S807b/W01l]:00X=c80;C`g02`k=P0[>SD09cLf03a<B`0X>3L0=DE402<c<P0`@3l0
0P0/?3/08P0^?Sd0;Cdl02Hf=@0S<c0093<]028a:P0T<b`08S4Z024^9`0T<BX082/U01dX8P0P:bD0
82TT01`U800M9al06bDM01XT700M9al072HN01hW8P0T;BP07BHQ01hW900Q:RL07RLT01`U8P0S;2T0
720O02da<00S9bH04aLF01XN7@0M8B02024U900901dQ800J7Qd06alN020T8P083@T05AXF01hS7`0F
6aL03A8>008061dI0P0K81`02P0J7a/05Q/G018G4`0V:bL0E5UE04Q=B@0C61@0724M01XO6`0C61@2
01@I5@804QLC01005aTG01HF5P0F5QH06a/K01LG5`0E5AD0410@018B4P0D51@0820P01LG5`0C4a<0
4A4A01TI6@0Q8B40410@0P0?3`l02P1fMWH0KFe]00l?3`0K6a/03@d=01@D500@3`d04Q4?01DD4P0C
4Q02018A3`0<00l>300@3`d04a8@01<B400B4@l040l=010<2`0E4A007a/J01dI600D40l04`l>1@0B
3Pd00`0B3P/04`l<01<?2`02018>2`0?018>300A3@`030P7018>3P0<20T03@T:01LC500300001P00
018<300E3`l0100001XD500B30`03`T900<04@/;00@04P`<01<=3@0@2PX04@/;0P0>20P0200@2PX0
3`T900d71`080`<0618B01LA4@0D3Ph03@L70P0@2PX01`0E3`l05a4A03Xd=00C3@d040X:00l92@0>
20P00P0?2@T00`0@2PX03`X700l:1`02010;200F00l:1`0>2@H03`X700`7100?2PL05Q4>018=2P0=
20@020@101lJ500<1`4040/704E0?016@Cd05A0=00h8200<1PH03PP8010:2P0C3@`05a8?01D@3@80
3PT600h03@P500`7100400008ahK01<>3@0Q71T0;bXW014<2@0>2@H03`X700h91P0=20D030L400d8
1@D03PT600H04@/:014;2`0A2`/050h>01D?3`0A2`/600h8200400l7200A1`P04PP901882@P04@L8
01808APK02DO8@080`@04`d?00P2100:1@H04`d?01@>400<1PP0208400h82P0@2P`0308300d3100@
1PL04PP90147200@1PL80147200F01061`0?1@H03P@500d3100A1`P03`H702<I6P0>10D04PP901XA
4P0;1@L02P@600@0000;1@L02@<500/51`0B2@`02`8501@;3P0E30l03PD801P?4QCooooo000Koooo
o`0600h>400H61X0GEeO02DU9`0@418061PJ0P0@418200l?4@803Ph@00<03`d>00h<3@0>30d00P0>
30d03P0?3@h040h?014?400@3Pl03`d>00h<3@0=2``04Q0A014?400F51D040h?00X82@0C4A804@l@
0P0@3Pl0100?3@h03P`=00d<2P0@3``5010?2`0F00l>2P0B4@d04Q4=010?2`0?3PX040l;01<B4007
1P@02`X800d<2P0C4Q005A@B018A3`0?3P`03Pd;00l>300A40h04Q4?00l?3@0>3P`03`l=010@3P80
3Ph<00l03`l=00h>300?3`d0410>014A3`0C4Pl040l;00l>2P0A40`040l;00l>2P0@3`/04a8>01DD
400C4Ph00P0@3`/0100B4Pd04Q<>014B3@0A4Pd200l@2`0<01<D3`0:2`H04Q<>018C3P0<3@P04a@?
00l@2`0H6A@051D@01HG4P0E5Q40414<1@0>3`X200l@2`0401HG4P0?40/0414<018C3P803Pl:00H0
3a0;010A300>3`X03Pl:018C3@0B4@`2018B2P804A0;01P04A0<018A3P0A40h04A0?01<A4P0C4A<0
3`d?00h>3P0;2`/03`l?01DE5@0B4Q804A4A00d=3@0F5QH0410@00h>3P0D51@03@d=00d<2P0C4Q00
5QDC01<B400@3`d7014@3P0802LW9@0B4Q00410>014A3`0=3@/05ADC00l?3@0@40h3018B400301<C
4@0C50l051D@00807AhI01`051D@010A300A4Pd04a@?01DF4@0@4@`05QLB028S7P0O8A/030h801<F
3`0@4``071lG02lb:00K7Q@0>3/a03Xm<@0N8QD06A`@01/N4`0H6A@030d801<D3`0G61<030d801HG
4P0B4`h04a@?100B4`h201@E400601DF4@0C50l04A8=010A300D5A0030d80`0E5Q40F`0F5a<04aDB
01<E4P0D5Q<04aDB014C400?4@h04aDB00h@3@0G6AH01`T601TK600F61D04A<@01<E4P0F61D03a4>
014C400I6aP04A<@01@F4`0G6AH04aDB01HH5@0C5Q@051PG01HJ6@0H71/05a/J01HJ6@0B5QD06QhM
01dQ800E6AP0720O01XN7@0I7al0728R01DK6`0G7Ad04QPH01/Q8@0I7al07B<S02@Z:P0N92@05adM
01XO800P:2/08BT/01`U9P0H82806b@T01/T8P0I8Ql06B8M01`V7P0O:2807bTQ01`V7P0O:R@07RTT
01`X9P0S;bl0930`08:?T010CTl0938c04ADD`0R<Rl08C8]02<d;@0S<BX09C</02Xi<P0X=c409CD_
02ho>P0_?c/0;Sll02m2?`0`@d00;T4o02m2@00_@d80=4Q703=7AP0eBDX0>4a=03A8B@0cATX00P0n
DED203Q;D@0V049EF@0hC4d0@5AE04MJG`19G680C5iX051RKP1HJWL0C5iZ04EGH@1>H6T0AUUP051U
J01;HF80AUiM04EMG@1=HV<0CfAW04iSIP1HJg40FFYb05a]M@1MJgH0G6Ye05][L`1KKW40EVYY05U]
K01KKfh0FFe[05Y^K01IKF/0HGIa06IkMP1OM6l0J7eh06UmN`1aPXP307:3RP0607F6S@1gR8l0NX^B
07b=U01nSiH0P96H0P21TYT03`25TYP0RYNM08^HWP2@Vj40TYfS09:LX`2HXJP0W:F/0:2X/02SZ[80
YZfe0:^^^@2^[K/0[:^i0;Je``020;Fc`@0C0<2mc02m^LP0_KW80<2kbP35_/h0b<7A0<W3dP3;aM<0
cLOE0<k7eP3>a]D0clOF0=;8f03DbMT0e/WJ0=O:f`3Eb=T0e<OH0=;8f0020=3:f0040<o9e`3<a]@0
blGC0<W3d@80al7?0P36`<h01@35`<h0`Kk90;nmb02l^/D0^[W10080^KS000T0][Fk0;>b^02^[K80
[Jba0;2_]02d];T0][Nl0:nb]`2Z[K800P2[[[<08@2RYj/0X:R[0:F]/02RZZd0VJ>U09JPXP2BW9h0
RYJC09FQV`2EXI`0OHZ3082=Q@1bOgL0GFYP04mLDP1OKF00L7ia05e[GP1TLFH0JWM^05e[I01MK6D0
G6]T05i^J01FIf40F6US05IXH`1DIf<0CF1N051SH@1TMg<0H71/05=TGP0204aME`0L04IGD@0oD4X0
@E9<03M8@P0a@S`0<44k02ho>@0^?CP0:C8_02P`;P0Y<Rl0<3Tf02Ha;@0T;b/07RXV024_:P0/>cH0
;Sdh02Ph<`0[?3L0;cln03a<B`0^?Sd0;cln0310?`0V=SD0;cln0310?`80;cln00h0:SXi02De<P0W
=S008S4Z02<b:`0Q<2T08RlX02Hc;00Q;2H07BPR020[9@0R:bH072DP01dW7`806B<K00P06bDM01TS
6`0J8ah082TT01lX8`0O:2D07RLT01dV8`8072DR01808BDT01XN7@0J7Qd07B4P020T8`0I7A`08BDT
02P/:`0R9RD061`K01/O7P0N8R007B8N06Y_J`0L8Ad08BHR01@I5@0J7a/201hS7`0:01HK5`0I7QX0
6QlK01PM6@0B5a<06b0L01XO6`0Z;b/0<SLc01LL608051TE00H05Q/G01/P700K81`06adK01DE5@0B
4Q8301LG5`0301XJ6P0L71`04a<C00805ADE00l051@D01PH600@41005ADE00h>3P0J6QX05ADE05AD
E01EEED051@D01/K6`0;2`/03`l?00h=2`0B4@l00P0I61H0100E51804A0>010?3@0A40h201<B4008
018A3`0A40h05A4@018>3@0E4A0061@C01@@3`0A3@`201<?3P<04Ph=01@04Ph;01<?300D40`04`l<
018>2`0A3@/04Ph=01TE500<20P04Ph?00d92P0A3@h05A4B01PB4P0;1PH050h>014;2`0C3@d030H6
014;2`8040X:00@04P`<01<=3@0B30`050h>0`0A2`/04@0?2@T04@/;01XD500@2PX04P`<00l92@0D
3Ph03`T9014;2`0?2@T05Q0@00l92@0J51@01@00010:2P0?2@T03PP800803`T900<040X:00l:1`0?
2PL00P0@2`P05`0?2PL03PT6010;200=20D03`X701@?300A30T030L300h91@0B3@T02`H301@?2`0:
1P@05A0<00d81@0=1`L03PP800l92@0>20P03`T8018=2P0A30T03PT600804@`900L03`X7010;2@0D
3``03@T601TD4@0=2@L03PT600<040/800<03`X700h91P0>2@H01@0>2@H01@0?2PP03PP800d71`0@
2PX04P`<00L03`T900@040P80147200B20T04PP9200A1`P0100R6A`0:bDW014;3@0D3Q02018<3P09
00`6200B30h05@lA01LA4`0I4aD04@/=01<92P0B20T04@L8008040H71`0A1`P00`0@1PL03`D600l5
1P0200l51P0;00h41@0C2@X04PP904<i>P0a9bP04@P900`4100A1`/04@L:01482`0<1@H00P0@1`X0
1P0/9RP050h@00h92`0@2`d061<E02l[;1Cooooo000Kooooo`06020P8P0410H02PX<01@D5P0?3a40
2@T;0P0?3a4300h>400300d=3`0>30d040h?00804@l@00<040h?00h<3@0>30d00`0@3Pl02@0>30d0
3@/<00h<3@0100003`d>01DC500A3a002PP9010>3`0400l=3P0400l>300@3``03`h:00l>2P803Pd9
0P0=30P00`0A40`04Q4=00l>2P0200d<200703Th=P0M71X07A`J010?3@0<2`T03@`:014@3P03010?
3@0:014@3P0@40h03Ph<00d=2`0?3`d04A4?010@3P0?3`d0410>00l?3@803Ph<00X03`l=014A3P0@
3`/04A0<01DD400?3PX03Pd9018A3@0A40`03`h:0P0@3`/04P0?3PX04A4<018C3P0A4Pd0414<00l@
2`0>3`X01`P5024R7@1OH5/0A4E00042000>3`X051D@01dN6@0C50l05QLB01@E40<03Pl:00/03a0;
010A300@4@`04A8=00L80`0=3PT02``701XK5P0K71L0414<00l@2`02010A30803@h901l0414<01<B
3@0E4Pd05A8=01@@3@0C3``04`l>01@@4@0C3a004PdA01<>4P0D3aD04PlC010@400>3Ph04A4A010@
400=3@d0410@01@D500B4Q803@d=00l?3`0C4a<04Q8B010?3@0?3P`04A0>01<B400B4@l03@`:00H0
4Q4?01802`/901<C4@0E5A<03`l=00`<2P0A4@l04Q8@014A3`0?3`d0410>018B400C4a4051D@00`=
200=3PT0414<00l@2`0A4Pd201<D3`0B01LH4`0@4@`04a@?020Q700N8AT030l600lB2@0F6@l03Q46
02LZ7`0U:1`0Qh]m0:^_X01aMFH0<3@U02DY6`0E5Q004A8=0P0B4`h00`0D5A00414<014B3@02018C
3P<051D@00@06AXE01HG4P0D5A004a@?0`0A4Pd07@0D5A005aPC00l@2`0B4`h051HB018D4@0A4a00
51HC01HH5@0E5a@051HC01hP7@0>40d04aDB01XL6@0H6QL051HC018D4@0C5A805aTF018D4@0I6aP0
=3Hc01dO700?4@h061XG01@F4`0F61D05QTG00805QXI0`0G6aX0<P0J7Qd08bLV028V9@0F6QT061`K
020T8`0<4Q808BLW01lU9@0N92@07bDU01LM7@0D6QX04aTI01XP800K8B405Q`L01TN800E72806B0V
01PP900H82<06b<U01/T8P0J8b006b@O01`V7@0K9A`06bDJ01/U6`0H8ad0930/024]:`0K9bL0930`
04=AD`0/>Sd05bDV02De=00V>CD0;d8n01DW800K:R<0;Sdc02/k<@0/?380<T<j02<d;00cA3`0;d4k
0P0bACl02@0]@3`0<4=102m3@P0bATD0;d=20314A@0fBT/0=DU:03I9C@0203iAE@0`03U<DP0kCU@0
@eIJ03I:B`11EEH0B5]Q04MJH@19FfH0CEm]04aNK013EF80CEmY0:>e_`1/OhH0?E9E04aTI017HEh0
BF9O04iVIP1>HfH0BUmR05EXKP1LKGD0GFif05e[MP1LJ7@0FfUb05Y]KP1HK6/0FVi]05Q/J`1HK6X0
GG5_065eL`1VNgH0Jh1k06IkM01fRh@0OY:@07N9SP1gR8l0MXN>07B5S01gR8l0NHZA07b=U01nSiH0
PI:I0`23U9/05@2>Vj40RYNM08bIW`2EX:H0V:6X09^TZ`2MYZd0XZVa0:F/]02V[KD0ZK2h0;:e`02m
_<X0^;K40;Vga@2h]/@0]k?20<2lb`32_/d0a[o?0<W2dP020<c5e@0C0<k7eP3Bb]T0e<cK0=G=g03D
c=/0elcL0=S<g@3Ic=d0f/gN0=_=gP3Ibm`0elWJ0=K:fP3Dc=/0dl_J0=;:f@3@b=L0c/KE0<g5e002
0<c4d`0S0<[2d@39`M00al3?0<:obP31_lX0`;k90;fla02k^/80^KS00;Fd^P2c/[P0/:nd0:n^/`2a
/;D0/k>h0;:c^02]/;D0ZZfb0:^^/`2Z[K80YJZ^0:6Y[02RZZd0W:BW09JPXP2GXJ<0TI^M08VFS`2;
V8h0RYN>07J3NP1cP7H0Hg1V05YWG@1PKF<00`1QKV@03`1GI5X0IW=Z05aZH`1LJf@0DV5L05i^J@1K
K6H0H71]05Y/J01KKVX0GG1^05MZJ01BIF40DV9O055PF`0204iMF00J04]JE@13DTd0@U5<0391?00a
@3/0=D@o0350>`0`?3P08R/X02H/:P0L8R008BXW01hX9@0f@Cd0;3Pd01`Y9@0Q<2/0:STd02/k=P0_
?c`0;3`k0720P010D500AUIF01/[:`0Z>SX202Ph>00S02@d=00V=SH09CDe01h^;@0W=Rh093@Z02De
:`0R<RP08BhU02<`9`0R;BD072LO020[8`0S;BD07BLO01`V7P0Q:b808B/S02@^9P0P:R807RLR028[
9P0N9b808R/X01XS800P:BH09Bh[01/T8@0P92<0HfMV04eAD00F6QT05a/J01`P7`0K7ah00P0M8B00
5P0K7ah06QhM01`Q7P0F6aL0=S/g01/P700I7QX041DA01PM6@0I7QX04aPD018G4`0R9b<082DQ01DJ
5P0A5Q806QlK01DJ5P0I7QX082DQ018G4`0F6aL201@I5@807B8N01l07b4O01XJ6P0C4a<05ADE01HF
5P0G5aL06QXJ01/K6`0A4A4061PH01hN7P0>3Ph06QXJ010@400B4Q8030`<014A4@092@T0410@01@D
500?3`l02`/;00X:2P0H61P03Pd;014@3P0E518051<A018A3`0@3`d04Q4?00804A0>00T040l=014@
3P0B4@l04Ph=00l;2P0A3@`040`;00d9200?2`X00P0C3`h2018>3@0E014=300A3@X04@d:01@A3@0C
3``04@d:010<2P0C3`h03`/:018>3P0D4140:bLX03@`<@091@H03`T901hH60080P80100001XD500@
2PX04`d=008040X:0P0B30`00`0?2@T04`d=00h82002018<300=010:2P0E3`l02`D500`61P0C3@d0
40X:01<=3@0:10@04@/;01<=3@0:10@03`T901@>3P02010:2P0500l92@0>20P03`T900l92@0@2PX0
0P0?2PL2010;200400l:1`0>2@H04@`900l:1`803PT600T03@P500d8100A30L01`8001TD3P0;1P80
6A@@00@0000?2PL00P0?2@T200d71`0500d71P0?2PL03`X700d81@0A30T00P0B3@X0200C3P/01000
04<n>`1WHUl05Q4>00/60`0=20D03PT60P0?2PL700h91P0700d71P0<1PH030H600/51@0=1`L040X:
014;2`0500l92@040108200A1`P04PP901882@P04@L800`071<F00T31@0:10H0DD]=06]UI`0G4A<0
4@/=018<3P090`D040X<01hH6P0>2@X201882@040147200@1PL040H7014720H040H700@03`D60106
1`0A1`P04@L80P0C2@X04P0<0P<04@L800L0000700006Q0A00L0000900404@H901L<400B1`/03@D7
00`31P0>20X03PT:01PD5@0K5aP040h?00X:2QCooooo000Kooooo`06014A4`0B4Q@06ATK00L72@0;
2`d051@F0P0?3a4200h>40803@d?01803P`=010>3`0C4A804a4B010>3`0>30d030X;00h<3@0@3Pl0
4@l@010>3`0?3@h030X;00l=3P0H5QL02@L800l=3P0B414300h<3@05010>3`0A3a004Q4?00l>2`0?
3PX00P0>3@T00`0=30P030/700`;1`0200l>2P0900d<200<2`L03@`8020O7@081`D040l=00h=2`0B
4@l05aHD00H03Pd;0P0<30X00`0?3`d04Q8@018B4002014A3`0D010@3P0?3`d03Ph<00h>300@3``0
40l;01<B3P0G5Q803`h:00h=2@0C4Ph03`h:00/:1P0<2`L03`h:00h=2@0@40/04Q<>014B3@0@4@`2
00h?2P0<018C3P082@@06a`G01LH4`092PD05QLB00/<1`0M7QT0414<01@E400B4`h03@h90P0@4@`2
014B3@0O018C3P0C50l061TD01@E400B4`h01PL200X;1P0D5A00414<014B3@0@4@`03@h900`=200?
3`/04A0<01<@2`0C3``04Ph;014=2P0A3@`05a<D01@@4@0@2`h04@`@01<>4P0D4A@0410@00l?3`0@
41003@d=00/=300201@F5@0600d?3P0E5AD051@D00`<300D51@04a8@0P0?3P`00`0D4a404a8@00d<
2P0601<B4008014B3@0?40/02P/600l@2`0D5A403@d;01@D4P0A4@l200h>3006014A3`0C4a404A8=
00/<1`0?40/04Q<>0P0@4@`06`0D5A00414<01LH4`0B4`h03Pl:01LH4`0B5@d06A`E02X]900e>2h0
30l401PK4015BC`0e][<0?kol`2i_Jh0@4@e024U5`0G61<051D@02DV8@0;30P07QlJ01HG4P0B4`h0
4a@?01@E400201HG4P805aPC00h05AHA01@E400D5A005AHA01HG4P0E5Q404a@?01DF4@092PD04a@?
01<E4@0B5140418?01<E4P805aTF010061XG00lA3P0M7a`05QPE01@F4`0;3@X061XG01@F4`0B5140
5aTF01@F4`0P8Ql0ATQ502LY9P0<3P/06A/H0P0G6AH01@0I71X05QXI01DI600D61L05QXI008061`K
00P07b<R02<W9P0K7ah051PG01DI600E6Qd07R<V01<I6P804aTI0P0J81h0CP0F71X06b4O01hT900I
7al06R0Q01LO8P0K8RP06b<V01TQ8`0L92H06R<Q01TR7@0K91l07BLO01`V7@0K9a/07bXN01XW7P0J
9b008BdY02<_;@0O;Bd07bd_01`Z;@0R<S807Bd/01`_:`0/?cT09cTc02Pg<00Q<2T08C8Z02Dd;@0X
>C40;Slg0352>P0]?cP0<dI003A7@@0`@cd0=DQ402/o?P0]@D80:Cdn02Xn?`0bADP0<TE903M:CP0j
CE40>Da@03M:CP0hBe00?4mC03E8C010DeP0AEQN04=FG@13EEl0AeUS04EGH@14EV00EfUc0:^na@1?
HVT0DFAZ04eUI@19HF40Bf=S055VI`1=HVD0BEaP05AWK01OL7L0H75h05m]MP1OK7D0GVed05]^K`80
Ffm^00X0Ef]Z05U]J`1OLg40H7=a06QkM`1]P7`0IGQc07V<R025V9H0LhB90`1dQH`01@1iRY40NhbC
07j=U022TIP0Q9>J0080QYFL0200QYFJ092LXP2;UY`0WJR^09>MX`2?V9l0XJV`09nV[P2RZK40YJ^c
0:B[/`2X[;L0ZZ^h0;Jd`P2h]/@0_K_90<>ocP2o^lX0`ko>0<Joc`39`]80cLKF0<o8f03@amP0dLSI
0=C<f`3FcMh0elkN0=K>g@3Ic]l0f/kO0=[=gP80flkP00<0fLcM0=S9g03Gbm/00P3Gc=`04P3Eb]X0
dlSH0=76eP3@amH0clOF0<k6e@3;`m80b/;A0<W1d033`</0`/3;0<?0b`31_/T0_Kc40;Zi`@2g][h0
][Fk0;>b^080/K2e06l0/[:g0:b]/P2[[[D0[:nf0:V//`2XZk00ZJfc0:>X[02OYjX0V:2S09JNX@2G
XJ<0T9ZL09:MU`2<VHl0RIF;07V6O01ePWP0HW1S06MeJ01KJE`0I79V06YgK@1IIU`0Hg1V05YZH01K
JV<0Gg1Z04iMF01GIf@0EVIS06=cLP1KK6X0EFQT05AWH`1EJ6@0EfYV04iOF@1BHed0Cf1J04aME`1;
FUD0BEQC045@B`0b@3/0=40l03Y6A00c?cd0;CLf02Pa;P0V;b`0;CHc02`e<P0`>cL0T9ZI05=OG@0^
>cT09SDb02hm>P0[>SL0:3Pg02Lf=P17EED09CDd02@c<P0Z>3P0:3Pg02Xi>00Y=cL08c<b02Lf=@0W
=CD082l/02<a:@0U<RT0:3D/02@a:00M:R407bXR020[8`0I91`07BPP024[8`0K9Ad06B<K01`V7@0O
9Ql082XR01/T7P0G81/06R<P020Y9P0W<2l06R@S02D_;P0]=cH082TX02X_;@0e>CP0:Bd/01TM700N
8R407B4P01PL6`0C5aH061`K01dQ800K7ah05ATG01`Q7@0=4Ph00P0H7AT05@0M8Qh06b0L01TN6P0G
71P08bPT03Hk=`0X;BT06AhJ01DJ5P0J7a/061dI018G4`0K81`06A`I01/M6P0G6AH04Q@A01PJ5`0G
6AH07AhM01lO7`0301DE5@0:01HF5P0E5AD07AdM01DE5@0C4a<06QXJ01<C4`0?3`l030`<01DE5@80
61PH00X05aLG01@D500=3@d06QXJ01DE5@0H61P03`l?00l>300@3`d04A0>0P0>3@/03@0A40h04a8@
018A3`0@3`d03`h<010?3@0C4Q0040`;018>3@0F4Q404@d<00/71P0B3Pd00P0C3`h2018>3@804@d<
01l04@d:01@@3@0D40d040`9010<2P0C3`h05Q8A018>3P0T8240;b//01LC500E4A805Q0@00l92@0F
41005a4A00h8200A2`/05@l?014;2`0@2PX04P`<014;2`0=1`L050h>00l92@0B30`04@/;00d71`0B
30`05Q0@008040X:00`03@L701@>3P0>20P04@/;00d71`0@2PX03PP800@0000G4A4040X:00l92@0>
20P200l92@03010:2P0?2PL03`X7008040/801003`X700h91P0A30T040/800d81@0;1P<030L400h9
1P0E40/061<?00/60P0>2@H03PT5018=2@0?2PL03`T90P0=1`L0400@2PX04P`;018=2P0C2`T03@H4
00d81@0?1`D03PP500l:1`080000:bDR03Xe<P0<10804@`900/60`0<1`@900h91P0700h81`0>20P0
3`T900d71`0>20P050h>01D?3`0500l92@040108200A1`P04PP901882@P04@L800h01P0000H00P0A
2`d08A/M03H`<P0=20T04P`>00`6200=1`T050h@018<3P0>20X03P@500l51P<04@L8200@1PL00`0A
1`P04PP901@:2`0201H<3@0;03@Z:`0=1@D040H701/A4P0:0@406a4B00T00@0E2`d050P<00l4200=
0`H00P0@1`X01@090`D02`D700d92P0<2@X02@L801Cooooo000Kooooo`0400l=3P0B41404Q0A010>
3`803`d>00P020H7014?400=2``030X;014?400>30d040h?00l=3P803P`=0P0?3@h01`0>30d05aDF
06aZJ`0R82403@/<00h<3@0?3P`00P0<2`T02@0=30X03`h<014@3P0D4a4040l=01@C4@0?3P`04a8@
010?3@0500l>3007010?3@0=30X051<A00`;2@0L6aT05aHD014@3P0300d<2P0600l>300A40h04Q4?
00l>300>3@/03@`:0P0>3@/04`0A40h040l=00d<2P0A40h05A@B01<B400B4@l02`X801@C4@0A40h0
30/901@C4@0=30X01`L501@D4P0T92803`l=01@D4P0>3P`00P0@40h0600A4@l03Ph<00d=2`0?3``0
4Q<>01@E400A4Pd03Pl:010A300E5Q40H65L038c;P0@4@`02``701<D3`0?3`/05A@@028Q7@0A40`0
51<?014@300E510051<?01<B3P804A0<00D04Q4=00h=2@0C4Ph04A0<00d<2002018A3@<04a8>0P0@
3`/01@0A40`03`h;018A3P0B4@l051<A00804a8@0P0@3`d07@0@3`h040h>010>3P0@3Ph03`l=01/K
6@0D5Q<02`l;014F4P0?5a8031@?00`A3@0>4Ph03a4>00h?300C4a405QHD010@3P0?3`d0410>01@D
4P0>3P`04Q8@010@3P0>3P`0410>014A3`0?40/03a0:0080414:00/04A8<014B3@0B4`d03@h900h?
2`0E5A<02PX8010@3P0C4a40410>018B400201<C4@0K018B400@40h04a<A00l?3@0@40h05ADC00d=
2`0A4Ph04aD@018D3`0A50h04QD>01PK4`0K7Q@0@D@i09ZNT@3Lh=80PXIh01`P4@0D60X05AH@01<D
3`0D5A005AHA018C3P0@4@`04A8=0080414<01<05aPC010A300F5a8051D@018C3P0C50l05QLB01DF
4@0D5A005aPC01<D3`0F5a805aPC01DF4@0D5Q8051HC018D4@0C5A805ALD008051HC00L06A/H01HH
5@0F61D06A/H01HH5@0H6aP05a`H008061dI0`0F6aL0;`0C61@041DA01DJ5P0I7QX05a`H01DI5`0=
4A00=SXi04a@C`0K7ah061`K01DI600M8B00;S8a02``;`0I7A`061`L05QMHP25RY007R<W01<I6@0J
81d061lI01`S6`0I81T07R@O020V900L8R006R0P01lT9P0P9BL0728Q01`U8`0T;B/092dZ01`W8@0M
:2807BPQ01`X8@0N:b<07RXQ01`Z7P0M:al07blU024`:P0R<Bh08C0`00808C4a05/08C<a020c;`0P
<bd08cH_02<d<@0Y>SP0:Sdj02Tk>00X>cP0:chi02/n>00Z?CL0;T4k0314>`0cAch0=dY603=7B@0_
@TP0<4=902e0AP0gBTl0<dI;03U<D00mD5@0>diB03M:CP0gBdd0=4M=045BG@13E640@E9L049CF`17
F5h0A5II04IHF`11DUL0DV=Y07F6S@1LKGH0E6M^04eQI`1?HfL0DfM[05AWJ`1FJFd0Ffea05i`L`1Q
L7@0Y[Fi0:2_/@1PKW00IWEg061bL@1ML6h0GW5_065dLP1PLG00GFm]06MgMP1_OWd0LX6007:1P@1d
PH40Lh:207:3QP1gRHd0NH^?07^:S`1nS940OhfB08:?U@29UI/0QY:H08NCV@2=VIl0SiZP0:>]/P2I
XJL0UinU09fUZP2QYZl0Y:Va0:R/]@2Z[KT0[[2m0;6d`02c]L80^[W80;nkc030_<d0a;oA0080b<7C
00h0b/?E0<k5f03?a]T0dlWL0=G;gP3Gbml0f<cP0=W=h03Jc^80g<oS0=_@hP3Kcn<0gM7U0=oCiP80
g];V01@0gM7T0=kAi@3OdN<0g/kP0=c<gP3KcMh0fLcM0=O:f`3Eb=T0dlOH0=76eP3?a=@0cL;B0<_1
d@39`]40b<?A0<O2c`34_/X0`Kc80;fja@<0]kJn06P0]KJk0;Be^P2c/kT0/k>m0;2`^`2][KP0[:bf
0:Z[]02UZK00Z:fc09^PYP2PYZT0V:2S09:JW@2OYjT0S9FB08J@RP1hPgX0JgM]06IbIP1ULF<0H6iN
06AbHP1/OFh0JGU/061`I01RLfP0IGI/05IYH@1KKVP0G6e[061cLP1JK6d0HWAe05QZJP1HJfL0FFaX
05=VG`1BIeh0EV]T06=hLP1>HU`0AeYD04AED@16EE80?de:03]6A@0c?3`0?DA6030f>@0Z<S@09S0_
02<^:P0Y=3007bXX01l[:P15DE40>DA5030k?@0f@D@0<Ca0030k@00c?d<0;3Pf03I2?`0V<c00;CXg
038n>`0_?3T0:3Db02`h=@0/>CH0:SHc02Da;P0Q;BT09S0[02<]:00T;RT08bdW024[9@0L9B008BXU
020Y900Q:RD08b`W01hW8P0J8ad08RPR02L/:00M8Qh082HS01TR800L9B@0:S@d018M7P0V<S<06RLW
020];`0P:R`08bTV02P]:@0R9b<082DQ01hS7`80724M00D06QlK01/P700L8Ad06QlK01/N700201`N
7@0A01XL6`0M7ah07R0O01hP7`0I6aX05aTH01/M700L7Qd06adL01XM700H71/061XI01TK6P0J71/0
6Q/J01TJ6P0I6AT00P0G5QH03P0I61P071TJ01lM7@0E51804A0>01PG5@0F5A<061LE01DD4P0F5A<0
61LE01LF500E518051<A1@0C4Q003@0D4a404a8@01HE4`0F5A<040l=00l>300G5Q@0L6m]00l>300D
4a806APF018A3`0?3P`01P0A40h00`0B3P/04Pl;018>2`02018>2`804Ph=00L04@d=010<3@0B3Pl0
4Ph?010<300C3`h04Ph=00<040`;00T04@d<00/71P0B3Pd0FeMF061LF`0@30/03PX9018>3@0A3@`0
0P0@30/04@0A3@`04Ph=00`81`0A3@`03`/:010<2`0D40l02`L600d81@0>2@H03`X700h91P0@2`P0
5Q4>01D@3@0D3``03`X7008050l<00P03`X700l:1P0@2`P03@P500l:1`0B30`03`T9010:2P@040X<
00X040X:034/:P0?2PP03PT6010;200:1@8030L4010;200?2PL03PT60P0?2PL0200@2`P04@`902DP
7@0D3``03PT600`7100@2`P03`X70`0@2`P01P0>2@H03`P601481P0C2@P050X9018920804@L600H0
4@P601471P0A20H04@P601471P0@20L500h8200500l92@0>20P03@L700d71`0>20P00P0@2PX01@0B
30`04`d=010:2P0B30`040X:00803PP800/03`T9014;2`0;1@D030H600l71`0D2P/04@L801D;300B
20T03`D60147200301061`0A0147200C2@X04PT:00l92@0=1`L030H600h8200A2`/03`T900`61P0?
2@T040X:00h8200?2@T04`T:01882@0A1`P00P0@1PL02`0A1`P03@<401882@0B20T03`D601882@0C
2@X03P@500l51P0@1PL04@L800804`T:00<07A<D01<92P0D2P/00P0?1@H00`0E2``03`D601061`02
01882@0601061`0?1@H050X;01882@0@1PL03`D60P0@1`PDooooo`006oooool02@0@3Pl03P`=00d;
300?3@h040h?00l=3P0N71d03`d>00d;300201<A4P@03`d>00<040h?018@4@0C4A800P0=2``04P0^
;2d030X;01LE5P0>30d03@`:00h=2`0?3P`04A0>018A3`0C4Q0061LE01DD4P0G5Q@030/900l>300>
3@/04A0>010?3@803`h<00T03Pd;00d<2P0?3P`05A@B00h=2`0K6QP05QDC018A3`0?3P`00`0>3@/3
00l>30<03Pd;01@03`h<014@3P0>3@/030/901@C4@0I61H05A@B018A3`0;2PP04A0>01DD4P0?3P`0
4Q4?01<B400?3`d04A4?00d=2`0>3P`051@B014A3`<0410>01<03Ph<00/;2@0<3@T04Q<>00l@2`0=
3PT05aPC01DF4@061`<0@T<n02d^:@041@40;c0[0411?00=3@T030/700h=2@0?3PX04Q4=00<04a8>
00L04Q4=014@300A40`04Q4=00d<200A40`04Q4=00803Pd900d030/701DD400A40`03@`800l>2P0B
4@d04A0<01TH5P061@<04A0>01HE4`0R8Al02PT700H04A0>01`051<A01PH5P0=3``00PL300dB3P0A
5a<03A<?00/A3@0?51004A<@00d>300A40h071`J018B400N7Q`0410>00h>300@40h061PF01@D4P0A
4@l0410>00l?3@0<3@P03a0:00l@200@4@T0414;0P0A4P`01@0?40/03@d:01<C4@0=3@/05ADC0080
4Q8@02T04A4?010@3P0@40h04A4?018B400@40h04a<A018B400@40h04Q8@01@D4P0@4Pl04A<@014C
3P0B50h05APA01PK4P0I7180:RdR02P[8010A3L06Ad?00hA1P0B4`d04A8=018C3P0E5Q404a@?018C
3P0C50l04Q<>00l@2`0C50l030d8010A300E5Q404a@?01@E400G61<05QLB01DF4@0301<D3`0601@E
400F5a8061TE01DG500C5A805ALD0P0F61D03@0E5a@05aTF01@F4`0P8Ql08bDR01DG500E61D05a`H
01DJ5P0C61@051TE01HK5`0E6QH00P0B5a<301@I5@0G01/O7@0>4Q405ATH01lS8P0E6AP06QhM01PL
6`0@51<04ADD02HZ:@0Z;Rd06alO03Tn@P18CE<07b@X01@J6P0P9R805QdF01XQ6@0G7QH06B0I01XP
7P0G7A/00P0I7al0:00K8B406R0N01XS800N9b@072DR01dX900I920092lY02dj<`0U<R/07BXR01dZ
800N;1l07RhT020_:00P;b`07bl^020`<00Y>CT0;D0m02<f<P0N<B/09cXc02/n>P0X>cT0:C`j02`o
?@0^@Ch0:chj02Lj=P0^@C`0:chh0313?@0nDDX0?U5=02Lk?00lCe@0@eIJ03U<D016FEh204MJH00[
03E8CP19G680A5MM03Q;D00dAdh0@e=R04eMK01;G6H0AUMO049CF@0kCDl0A5IH04=EF00oDED0BEYQ
05=TK@1?HVT0B5]R05IZL01CIV`0DfIZ05i`M01OLGD0Gg5c05]ZK@2GYZT0Ri^K06AbL`1LK6`0GVm^
069eL`1KKV`0HWEc06MgMP1OKfh0JWYi071nOP1bP800M8:207V5Q@1iQhP0MhJ:07^:S`0207b;T00N
07j;T@20SI<0QY>I08jIW`2;UY`0RYFK096JX@2CW:<0U9^Q09VPYP2LXjT0XJR`0:b`^@2_/[d0[Jnk
0:na_@2d]<40^;O50;Zia`2l^/X0`[k?0<S1d`39`]@0b<7C0<_2e@3@amX0e<_N0=O;g`3Jc^80g=3T
0P3NdND07@3Od^H0hM;W0>;Dj03Qe>P0hM;W0>;Dj03ReNT0h]?X0>;Dj03PdnL0hM;W0>;BiP3Qd><0
glkQ0=k>h@3LcN00f/_N0=O9g03FbM/0e<OI0=35eP3?a=D0cL?D0<_3dP3:a=80bL?A0<Fob`33_LT0
_kc70080^KJo04D0^;No0;Nf_02f]K/0/kBj0;>c_@2a/K/0[Zjh0:f]]`2[ZkD0YZV`0:N//P2KX:@0
XjR/0:F][`2]]KL0YJj^08fFT`25SXT0L7Ya05eYG`1LJ5`0J7AV06UgIP1]NfX0KWm_06=cIP1VMV`0
NX^10762NP1KKfL0GG1Z05e`KP1RMGD0Gg5c061bM01IJf/0EfYV05EXI01CIUl0E6UP04aQFP1KLFX0
?U=<03U<AP0nD4/0>4Q5041<BP11C4/0F69S03U1@`0W;C00:C4c02H`;`0]>CL09C4_02Hb<P0^>SX0
82`/01/V:01gPX@0;3Li02/f>00/=c/09S4c034m>P0M:BD0>DE102Te<@11CDT00P0]>CD0300/>3@0
:cLc02Te<@0V<Rh09C4]02Xc;P0Q:RD092dX02/d;`0F7aX09RlZ02</9`8082TT00L08BXU01lX8`0M
9R408bPT02D[9`0L8Qh08bTW00806b@S00/0MX2103E1@@0L:2P0;3Li01HT9@0U<C408BHS02DZ9P0Q
9R8082DQ01lT800201dR7P0>01/P700M8Qh07B8N01`Q7@0L81d071hM01TK6P0G6AP061XI01XL6`0H
6QT05aTH01XL6`0K7A`201XL6`0501/N7@0D61L051HE01/M700G6AP00P0F5QH04P0E5AD061HG01LE
5P0H5QL07a/L051>C@0i>3H061LE01/J600Q81h06QTG01hM6`0J6AL051<A01DD4P0G5Q@05QDC01DD
4P8051<A00l04a8@018A3`0B4@l05A@B01@C4@0C4Q004Q4?01<B400E51807A`J00P71@061@@05QDC
01lN701KFUP01@0A40h00`0A40d04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<
3@0C3`h04Ph=00<040`;00@04@d<010<2`0D40l01P810P0:1PD00`0G4a8040`;00l;2P0200h:2@0>
00l;2P0@30/04Ph=01@@3`0C3`h04Ph=00`81`0A3@`03`X701@?300:1@801P4000/60`080`0201LB
3`0;010;200A30T040/800`7100?2PH04@`900h91P0?2PL03`T900/51@0>20P0100>20X0200>20P0
5Q0?00D000080`003PT6010;200E40d03PT60P0=20D200h91P0>00l:1`0C3P/0<bh[020K600<1`@0
2@@101D@3@0=20D03PT600l:1`0A30T040/801491`0A1`H301881`L04@L600<040L700d71`0=1`L0
0`0=1`L02P0>20P03@L700d71`0=1`L03PP800l92@0A2`/050h>018<300>20P200l92@0<00/51@0>
20P05@l?01@>3P0:10@02`D50108200F30d03P@500P0000700005@/<0P0A1`P201061`040147200B
2@X03`H700d71`803PP800@03`T9010:2P0?2@T03@L70P0@2PX01@0;1@D02P@401<92P0B20T04@L8
008040H700L04@L801@:2`0A1`P03@<401D;300L4Q<04`T:00803@<400`03P@500l51P0@1PL04@L8
01H<3@0900401`0001882@0A20P04@L800l51P0@1PL20147200401061`0?1@H03P@5014720804`T:
00<040H700`20oooool04oooool001_ooooo00<030X;00l=3P0@3Pl00P0?3@h01`0@3Pl0<c4b01HD
5@0=2``040h?00h<3@0C4A800`0>30d02@0?3@h04Q0A01<A4P071@H03`d>00`:2`050`@06aTJ00D3
1002010?3@0;014@3P0@3`d03Pd;00h=2`0D4a404a8@01HE4`0>3@/04a8@01@C4@0B4@l00P0@3`d0
2`0>3@/03@`:00`;2@0@3`d04a8@00/:200B4@l02PT700L6100A40h03`h<00@03Pd;030040l=00h=
2`0>3@/03Pd;00l>300<2`T03Pd;01@C4@0@3`d030/9018A3`0D4a4030/901DD4P0Q81h04a8@00h=
2`0<2`T04A4?00@40P0:2PP05QHD0000000C4a40410>00h>300;2`T03Ph<01HF500E5Q8030d800X;
1P0>3`X04a@?014B3@0?40/030d800X;1P0K71L0@D8m059CCP0B4Pd02`X601<B3P0I61@051<?010?
2`0C4Ph2018A3@804A0<01<04Q4=01DD400E510040l;00X91@0=30P05QDA01XI5@0D4`l03Pd9018A
3@0F5A4051<?02@S8@0O7Q`05QDC01LF500U92806APF00H04Q4?01@05aHD01@C4@0<3@/03A8>01DJ
5P0<4Ph03aDA00/@300<4@d03Q0=00h=2`0A40h06QXH00/;2@0C4a402PX801@D4P0B4Q005aLE01<C
4@80410>01003`l=00`=200D5@l04a@<014B2P0?40X03Pl900`=1`0I6QD02PX7014A3`0H61H092@R
010@3P0C4a404A4?0P0?3`d0100A4@l04a<A010@3P0B4Q0200l?3@0?01DE4`0>3P`04Q@A01<E4P0B
5140418>010B3@0A50d04A@<01LJ4@0X:b804QD;024T6@0?4PT05QLA008051D@01P05AHA018C3P0?
40/06Q/F01/L5`0F5a806Q/F01@E400H6A@051D@018C3P0C50l05QLB01DF4@0D5A004a@?01TJ5@0G
61<04a@?01DF4@0H6AD051HC01<E4P0D5Q<201HH5@0901PJ5`0E5a@030h;01lQ7P0W:BH05ALD018F
4P0G71P05Q/G00805AXF0P0F6aL201PM6@0O01@I5@0@5A404AHB01LK6@0A5A@03a<B018F5@0G6aX0
720O01XN7@0K7ah05QXI01@H5`0C5aH082@T01lT:00I7R805adN00lE5@0Q9bD06R0K01HM5P0E71@0
6R4J01`R7P0I7ad0728R01HL700H7Qh0728P01hW9002020Y9P0601`W8`0H8al0:cH`03U6?`0Z=c00
7BXR0P0N:b40?00N;R@07bhY020_:P0O;bd0:3Ph02lo?`0cAT@0:3/g028e;`0W>S@0:Sdk02`o?@0^
@Cl0;d9002i1?P0/?c/09STe0313?P0Y?3H0;T4k041DC00lCd/0>Ti=03mCE@15F5`0=TU=03U<D@10
DeT0<4=903e@EP0gBU00A5MM041CF@10DU`0GVim06AdPP1LKGL0DfA^055RJ@1AHfL0A5IH04UKGP1C
IFT0C5eT05AUK@1AI6/0C5mU05U]L`1BIF/0EfY^069dN01MKg<0IgUk05e/K`1VMGP0G6a/06ilO@1N
KVh0Kh1o05a_K@80H7=a04T0HW9a06YjN@1[NgX0L7in07:0P01dPX80NXJ607^9RP1kRHd0OHbA07j=
TP1mS940P8fC086>U027U9X0RiJL08ZEV`2@Vj40UYnV09FNY@2FWJ<0W:>Y0:2W[@2TZk<0[;2i0:nb
_@2`/[h0/K>o0;Jga02k^/P0_;_90<2mc@33_m00al3B0<[3e@3<aML0dLSK0=G<g`3Gc^40floS0=kB
iP3Pe>P0hMCX0>;Dj03Se>T0i]CZ0>KEj`3Ue^/0i]CZ0>KFj`3Ue^/0imG[0>KEj`3TeNX0i]CZ0>KD
j@3Sd^D0hM3S0>3@h`3Ncn80g<gP0=W;gP3Gb]`0e/WK0=;7f03Aa]L0clCE0<g5e03;aM<0b/CB0<O1
c@35_l/0`;g80080^kS104P0^[W10;Rg_@2g][`0];Fj0;Bd_02b/[`0[jni0:f]]`2/[;@0YZV`0:>X
[02RYj/0XJJZ0;6i^`3Dg=h0U9bM08:;R01mQX40KGM_05iZH01PK600Kg]]075oKP1/NVT0J7UZ06Yj
K`1YNFh0K7ec05m`J01WNW<0L8=m05]^K01CIVD0Gg5c05QZK01JK6/0FfiZ05U/J01DIf00DVIM04=H
D@13FE40@5E>049EC`0hBTD0A5=@03a8AP13CTh0HVa]03Dm?`0d>Sd0<CTl03Do@00b?Sd08Rh^02Te
=@0lB4P0<Cdm03E0@P2R[Jl0@4a<03M2A00b?Cl0:SHf030l>@0R;RX0=T8n02Te<@0lB4@0:3@`02Hb
;P0W<bl202Xf<P0;02Hb;P0X=300:C8]020Y900U;RT0<CXe01DN6@0Y<Rd08BXU01hW8P0M9R400`0L
9B003P0P9B408bTU01dS7`0X;R`06b@S01PQ800X<S<03a/K010L700I92H0<Cm002@`<00O9B8092TU
0`0P9B400`0N8al0724M01/P700201`Q7@0801/P700L81d071hM01XL6`0K7A`06Q`K01/M700M7ah2
01/M700N01TK6P0K7A`06adL01XM700A5A@04A<B01XL6`0D5QD04Q8B01HF5P0I6AT071XK01LE5P0C
4A806QHG02TW9P0E51804Q4?00d<2P0100006aXH02/Z:00Q81h04a8@01DD4P0M71X08R4O01HE4`0E
518051<A0P0B4@l03@0A40h05QDC01<B400A40h04a8@01DD4P0C4Q002@P601TH5P0J6AL05QDC00D4
0P0Q81h01@0B4@l00`0B4@h04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<3@0C
3`h04Ph=00<040`;00L04@d<01@@3`0F4Q404Ph=01dI600?2`X0510?008040`;0P0>2PT2010<2`04
018>3@0:1PD03PX901PD4`802@D400@07APE03<^:`0T7a`05A0=0P0H4a0201D@3@<03`X700<030L4
010;1`0B3@X00P0?2PL00`0>20P02P@400h8200400h82P0800h8200:10<03PT601HA3P0E40d03@P5
00`7100@2`P200l:1`05010;200A30T04Pd:00l:1`0M61D00P0C3P/0100<1`@03PT600h91P0?2PL3
010;200401091`0A1`H04@L601881`P04@L600<040L700d71`0=1`L01P0=1`L200h820803`T901<0
40X:00l92@0<1PH04@/;01<=3@0@2PX03`T9018<300D3Ph030H600d71`0@20T04@L800h41@0M4a@0
7Q@E01X@4@0B20T04@L8008040H700@04@L801882@0?1PL03PP80P0?2@T02`0>20P03@L7010:2P0=
1`L03PP800l92@0<1PH03PP801<92P0B20T04@L8008040H700L04@L801D;300B20T03`D601L=3P0M
4a@05@/<00803P@500X03`D601061`0@1PL04@L800X00@0G3@h060h?01dC500@20P04`T:1P0@1PL0
1P0B20T040H700h41@0=0`@040H7014721Cooooo000Kooooo`0700X82@0C4A805A<D010>3`0=2``0
40h?01HD5@0300d;300300/92P0A3a003@/<00803@/<00T03P`=010>3`0A3a005A<D00h<3@0?3@h0
3@/<010>3`0>30d00P0>3@/400l>300501<B400@3`d051<A00l>300D4a400P0B4@l2010?3@0800l>
300>3@/03@`:00`;2@0A40h02`X801@C4@0?3P`2018A3`03010?3@0?3P`03Pd;00803`h<00@040l=
00l>300?3P`03`h<0P0@3`d200l>300F010?3@0B4@l05A@B01@C4@0>3@/04A0>01`K6@0<2`T02`X8
028R8018B4H0DE5?00`<2P0H61H030`:00h>300@40h051@B00l?3@0>3P`061PF01/K60803@h900l0
4a@?00X;1P0:2`H04A8=01<D3`0;30P0414<00L80`0?40/05QHA01@C3`0F5A404a8>00d<200@3`/0
0P0?3PX200h=2@0;00l>2P0@3`/04A0<01<B3P0E51004Q4=01<B3P0N7AT092<O01dL600E51000P0C
4Ph01P0?3PX04Q4?01XI5`0T8b80>cXh00P71PL04Q4?01<02`X800l>300C4a4041<@038h=01GGET0
728N00lD400<3``03Pl=014A3`0G5Q@030`:01<C4@0D51803`l=010@3P0>3P`04A4?00803Ph<00@0
3`l=014A3`0?40/04Q<=0P0A4PX2010A2`0900l@2P0A4Pd04A4>01<C4@0>3P`06QXH010@3P0C4a40
4Q8@0080410>00<04Q8@01<C4@0A4@l00P0@40h0900J6QP0:BTW014A3`0@4Q404Q@C014C4P0@4Q40
4Q@B01<E4@0@4Ph06adI05QKE@0I6aH0418<01LJ500A4Pd0414<018C3P0C50l04Q<>010A300C50l0
61TD010A300D5A004A8=01@E400B4`h0414<014B3@0D5A004a@?018C3P0E5Q407QlJ01/L5`804a@?
00@05AHB018D4@0A4a004aDB0`0E5a@04P0G6AH05ALD01`N6`0H6QL04A<@01LJ5`0C61@051TE01DJ
5P0C61@04AHB01<H500H7AT06QlK01LL600C61@05AXF01LK6@807B4P01@061`K01HJ6@0D61L04aLF
024U900L81l061`K01hR8@0G6a/082DX018G6`0M8R@04aTI01/Q7`0I7a/05ahH01PO600M91d0728N
01LM6@806R0N05@06b4O020V900O:2D072DR01dV8`0O:RH062<O01lZ9P0U<Bd072PT01dY9@0Q;RD0
8BhT020`9P0P;bT08C0[024a;P0S<c8093@c02@g=@0W>SH09cXe02Dh<`0U>3H0<49203E7A`0`@d40
;3lm02e0?P0X>cL0<D@o02Xm=`0/?cT0>Da603A7@`25VIL0BEeL03a@D00mDE80@5=F041CE`1<GfD0
SJ2V03Q;DP0mD5P0@59K05U[MP15EF<0Cem]04iOJ@19FV<0B5UP04EGF`17FEd0A5IJ05]]L@1?H6L0
D65Y05MZL@1CIfd0Ef]`05=VK01RMGT0KGn306AfNP1QLgD0NXV<086@T`1QLG40IWAe05][J`1YNgT0
Ffi/05e`KP1/Ogd0L81o06]kNP1^OWd0Lh6107F3P`1fQ8@0NhN707b9RP1nSI42082?U00^086>U024
TIL0QY>I08^FW027TYP0RYFK09ZSZP2MYZd0UYjV0:2UZ`2QYJh0YZZc0:b`^@2^/;`0/;6m0;Fe`@2g
]/@0^k[80;nmb`31_ld0a/;B0<[3e@3<`mH0d<OJ0=G<g`3Jc^80g=3T0=gAi@3PdnL0hmKZ0>CGj`3U
f>`0imO/0>WGk@3/enh0k=W_0>_Ik`3]f>l0k=W_0>cJl03^fO00kMW_0>_Ik`3/f>h0j]S]0>OFj@80
iMCW00P0i=?V0>3Ai03Mc^40g<gP0=W<gP3FbM/0eLSJ0=?8f@80clOF00@0c/KE0<[4d037`Ld0aKo;
0P2n^l@0DP2m_<@0^k[00;Vh_P2h]kd0][Jn0;>c^`2`/;P0[jng0:j^]@2XZk40Y:V]0:2UZ02KX:<0
SiNI09nWZ027T8h0O8F107V3O01bO7<0JWI[06YfJP1_Nfd0IG=T06YhJ@1bPWH0KWic06=bJP1RLf/0
HG9Z06aoN020Thh0KX5n05]^K@1MKfl0G6i^05Q[JP1CIV80EFQT05Q[I@1EJF40BUmH04aPFP11E4h0
@eA>03I6@P0a@3d0=D4o03E0@00g@D807bLY04A<C`14CE00?DQ:030k?@0U<3809S4c02dh>@0c?cl0
;SXj03Y6A@0[=cD0>4A302<_;@0a?CX0;CTe03E1?@0T<2`0;3Pd02di=@0_>cL0:3@`02/g<`0b?SX0
;CTe02<_:`0T<2`08R/V01lX8`0N9b809RlZ02</9`0K91l2028[9P0H024Z9@0N9b807RLR01lX8`0R
:2H061hL01hT8P0oB4D0;SLf01/T8`0N:2L08bd^02H`<@0S;bl06RDW01`V9`0O9B808bPT01lT800P
9B408BHR01hS7`0K81`06QlK0P0K81`01@0J7a/06alL01TK6P0I6aX07b4P00806Q`K028071hM01/M
700I6aX05QPG01hP7`0O8B0061/J01HJ6@0J71/06adL01@F5@0D51@05aLG01XJ6P0M6a`061HG01<A
4P0G4a@05Q@C010?3@0E5180:2LU01lN700K6QP06APF01DD4P0B4@l05QDC01TH5P0H5aD05QDC01DD
4P0D4a404a8@0P0B4@l0300E51804Q4?014@3P0D4a405QDC01<B400B4@l05QDC00`;2@0B4@l03`h<
01HE50D04Q4?00<04Q4>018>2`0B3`X00`0B3P/2018>3@07014=3@0@30d04Ph?018>3`0@30d04`l>
018>3@03010<2`07014=300G4a804@d<00h:2P0V8R404Ph=00h:2@02018>3@8040`;0P0B3Pd0500E
4A004Ph=01<?3P0V8R404`l?00h:2@0;1`D050l<00h91P0=20H04`h;00P3000>2@H04@`900d81@0>
2@H04@`900l:1`0C3PX04`h;0P0?2PL00`0@2PX030H6010:2P04010:3003010:2P0@2PT03@P50080
3@P500<04@`901HA3P0?2PL00P0>2@H02`0@2`P04@`9018=2P0>2@H04Pd:00/60`0@2`P030L4014<
2@0@2`P04@`9008040/800D03PT600l81P0A1`H04@L601061@0801471P0301081`0>20P03PP800@0
3PP800<03@L700h8200?2@T00`0?2@T03P0@2PX03`T900`61P0@2PX04@/;01@>3P0@2PX02P@400l9
2@0A2`/03`T90108200>10D04PT:0P0b:2T0100B2@X04`T:01882@0A1`P201061`0:01482@0C2P/0
40X:010:2P0>20P03@L700`61P0B30`03PP800d71`8040X:00@05Q0@01<92P0B20T04@L80P0@1PL0
0`0A1`P03P@501061`0201061`0301<92P0B20T04@L800D04@L800L05P`=00l51P0=10D030<401<9
2P0?1@H04@L800@040H700L04@L800d3100@1PL04`T:01@:2`0A1`P03P@501Cooooo000Kooooo`03
01PF5`0B41403`d>00804@l@00L03P`=00l=3P0D4Q<04Q0A010>3`0?3@h02@L800803`d>0P0>30d0
500?3@h040h?00@20`0K6AX030X;01DC500@3Pl0108300h=2`0=30X03Pd;010?3@0C4Q0051<A01DD
4P0<2`T04A0>00l>300@3`d02@P61P0?3P`0200>3@/04A0>00X91`0=30X01PD300/:200A40h040l=
0P0?3P`2010?3@03014@3P0@3`d03`h<008040l=01D04a8@00h=2`0;2PP05A@B01/J600D4a403Pd;
00l>300;2PP051<A00H50`0A40h0A4=106a/JP2ATHl06ATG00L71@0B4Q004A4?00/;2@0=3@/00P0>
3P`01@0?3`d03a0<01<D3`0B4`h0414<008071dH00/0414<0001000E5Q40414<014B3@0F5a801PH4
01`K5`0?3PX020L300`;1`05018A3@0801<B3P0E51004A0<014@300E51003Pd900P70`0A40`300`;
1`0900h=2@0@3`/04Q4=00P71@0A40h0>3Le05EDDP0@3`d02`X800H04A0>01<05Q8A00l>300=3@/0
5aTF07b1O@3Wk>P0:Rl[01TM6@0?4@h03Ph<00/;2@0<2`T0;2`Z010@3P0E5A<0<30^01DE4`0A4@l0
410>00803Ph<00@0410>018B400A4Pd03@h80P0?40P02`0A4P`04Q<=01<D3P0:2`H04a<@01<C4@08
20H05QHD014A3`0@40h04A4?00804Q8@00<04A4?010@3P0>3P`00P0E5A<0100R8R00?Shl020P7P0?
414200l@4P09014B500F5aT06Q`K01XL6`0A4a808R@Q06Y/JP0B51400P@100803a0;00P04Q<>01DF
4@0E5Q404a@?02`]:00_<2/0824L01`M60805AHA00l04Q<>010A300A4Pd051D@01<D3`0B4`h04A8=
01@E400B4`h03a0;010A300C51004Q@A014C400C5A800P0F61D01`0E5a@051HC01HH5@0`<Rl0:B/X
010B3`0B5A800`0G71P201HK5`8051TE0P0F6aL0500G71P061dI010D4P0F6QT07B4P01hR8@0G6aX0
4aLF028V9@1GFeX0DUIE01TM700?4a806alO02@Y;00S:2/06b0S01HL700B61H07bDR0P0J81`02`0L
8Qh06AlK01LM6@0R:2@05Q`J01DK6@0L8R007BHS01/T8@0Q:RT08B/Z00808bd/01007BTW01/W9@0Q
;B`09C8[02@a:00Q<BL08C0Y028a:P0S=2h09SHc02De<P0T=c<0:Sdi02e0?00/?c/0:C`j0P0^@400
1@0/?Sh0:cdl02`o?@0[?S`0;D0l0080;d8n02/0<4<n02m2?00_A3l0=DU703]?C@0dB4L0?U9D04=F
FP0aA4X0EFQ`03Q:E01;GFT0AeUU03e?F`10DUh0BE]W04YLIP1:GF@0B5]R041CF@1@HfT0BUeS04eP
IP1:GF<0E6M]05MZL01JKg@0E6Q^059UJ`1GJVh0FVa`05QZKP1UMgT0HG1c06AcMP1JJVX0HFm`06Yj
NP1LKV`0HGAb05mbL01`Ph40O8b;0080Lh>200H0NHN707^9R@1kRHT0O8R807f8RP20SI8208:?U@04
08>@UP2:UI/0SIRN08bGW@80SYNN01P0Uj2W09bSZ`2IX:P0XjN`0:V/]@2/[kP0[k6m0;Bd`02h]l@0
^kW70;bjb031_/d0a<3A0<K2d`38`]@0e<_N0>3Dj03MdND0e<SL0=O:gP3NdND0hMCX0>CEjP3Wf>d2
0>WJk`0H0>kJl@3`f_40l][b0??Lm03cgO@0lm_c0??Ll`3bg?<0lm_c0?;KlP3afo80lMWa0>oJl@3[
f>h0jMK/0>SEj`3WeN/0iM?Y0>7AiP3Ncn@0g<gR0=W<h03Gb]h0eLWL0P3AbMP0B@3?amH0c<CA0<[2
c`37`Ld0`kg70<6na`30_LH0_K[10;^h_`2h]kd0][Nl0;Be^P2a/[L0/;6f0:j_]02Y[;00ZZnb09BJ
VP2JX:00UYnN08B=RP1jPh00QXn:07j8P01aNg<0K7Q/06eiK@1/N6X0GF]N06EcIP1]OG80IGE[06=b
K01aPW`0VJZT06aoN`1SMW80Gg9^05e`K@1QM780G6m]05IYI`1@Hel0EfYV05a_J`1AI5h0BEaF04]N
F00fBD<0>da603U9A@0^?CX0:SHd038n?@0_>c/0>TA504I@DP15Ce40;cXn02hi?@0/=c/0;CPj02lk
?00c?cl0;CTg03A0?P0W<bl08RhZ02<`:@0W=2d0>4A002Xf<P0N:RH00P0X=3003P11CDT0;c/g02di
=@0d@3`0:cLc020/:00T<2`08b`W02H_:P0M9R409RlZ05aUH00Y<Rd08b`W0P0V;bX0:`0Q:RD082TT
024Z9@0J8b409c0_01lX9`0T;B`09Bh]02`e=00e?ch0:38a02/e=00B71d0;CLh01hW9P0P9B808bPT
01dR7P0N8al07b@P01hS7`0K81`06QlK01/P700L8Ad06QlK020T8@0N81l06A/J01`N7@0E5aH05aTH
01XL6`0R92<0:2XY01/M700I6aX071hM01<F5@0K7ah08bDT01DG5P0B51<00P0E5AD03@0F5QH05aDF
01PF5`0G5AH06ADF01LE500F5A<06QTG010?3@0?3P`08R4O01@C4@0F5A<00P0I61H00`0G5Q@04a8@
01<B400501<B40<04Q4?0P0C4Q001`0B4@l06QTG0040000P7ad010<101/J600;2PT01@0A40h00`0A
40d04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<3@0C3`h04Ph=00<040`;00L0
4@d<01<?3P0>2PT0:RHU04a8A`0@30/03`/:00804@d<0P0?2`X2014=300>01LC4P0k=cH0:2@S01hJ
6@0;20L0920O01<>2`0<1`@020<000/60`0A30T040/800d81@0C3P/200l:1`804`h;00L08QdI01`G
500D3``040/800l92@0<1PH03`T900@03`T;00L03`T901@?3@0G4Pl05Q4>01<>2`0=20D02PD20080
30L400/03@P500l:1`0@2`P04@`900l:1`0H4a004@`900h91P0:1@805A0=00l:1`03010;200600h9
1P0@20H04@L601061@0?1@@040H51`0A1`H00`0A20P03`T900l92@0300l92@0500h8200=1`L03PP8
010:2P0?2@T00P0>20P2010:2P0<00d71`0@2PX03`T9010:2P0>20P02P@400l92@0>20P03@L700d5
1P0H3Pl040H70P070000100D2P/04`T:01882@0A1`P201061`030107200A20T03PP800<03@L700X0
40X:00l92@0<1PH03`T9018<300@2PX04`d=01<92P0B20T04@L80P0@1PL20147200501@:2`0C2@X0
40H701882@0A1`P01P0@1PL020070000?cDf05eCE00J41402`8301882@0A1`P040H70P0?1@H0100@
1PL04@L800d3100E2``201dC500301L=3P0@1POooooo01?ooooo000Kooooo`0601`J6`0B41403@/<
010>3`0A3a003@/<0P0C4A806@0=2``03P`=01@B4`0@3Pl04a4B010>3`0>30d03`d>010>3`0?3@h0
40h?00h<3@0=2``040h?00H51@0F51D05A@B00T81`0E51803`h<010?3@0?3P`04Q4?00`;2@0?3P`0
0P0@3`d0100;2PP03`h<014@3P0@3`d200h=2`803`h<00L04A0>00h=2`0?3P`02`X800l>300A40h0
40l=00D03`h<01h04a8@018A3`0@3`d040l=00h=2`0F5A<02PT801LF500@3`d030/900h=2`0A40h0
3`h<01<B400;2PP04Q4?02DT8P0>3P`06a/I00h>300G5aD01`L5018B400820L0410>00d=2`0E5A<0
6ATG00l?300F5a8201@E400902h_:P0Z:bH04Q<>01@E400=3PT02``801@E400Q8Qd05QHA008051<?
00T03`h:00`;1`0B4@d04a8>00l>2P0>3@T030/701PG4`0@3`/00P0?3PX2010?2`03018A3@0I61@0
4A0<008040l;00P04Q4=01<B3P0B4@d05A@B01<B400A40h051<A00l>30@04Q4?01`04A0>018A3`0B
4@l05Q8A01<?3P0C4Q004Q8@020T800b=c<05Q/G00`?300@4@l06aXH01/I5`0@3`d0ATE301PH5P0B
4Q00;Rh/01`L6P0>3P`04A4?010@3P0?3`d04A4?01HF500E5Q403a0:0P0@4@T3010A2`0501LH4`0<
30T02PX8020P7P11@Cl00P0@40h0100A4@l04a<A01<C4@0B4Q02010@3P0901TI5`0?3`d03`l=020P
7P0=3@/04A8D01XK7@0@4A<04Q<E008051DG00T03Q0@01HH600O82404Q@D01lP8`0A4Q<051DA01HG
4P0A4Pd0100E5Q401P0J6aH05QLB010A300?40/04Q<>01@E40804Q<>00d04a@?018C3P0B4`h051D@
01PI500G61<04Q<>01HG4P0C51005ALD014C400C5A805QPE00804aDB0P0F61D0100E5a@051HC01DG
500O8Ql301LL600500hC3`0B5a<05AXF01<H500D6AD00`0F6aL00`0G6aT05QXI00hB4@0201XN7@0<
014E500E6AP0=c/j02hb<@0F6QT07b<R01@H5`0G7Ad06AlP01dR900T:RX05Q`L0P0K8Al06P0O9B80
6AlK01hU7`0K8Q`0=S`g01`R7`0Q9b@0:Bl]01hW900L9B8072DT01PR8P0S;Bd08bd^02Te=P0h@d@0
9c<c02Da;00T<BT08S8Y02<b:`0T<b`093D^02Ph=00X>C@0:3/g0P0[?S/0>00Z?C/0;d5102do@00/
?Sl0;3hn02do?`0/?Sd0<4=102i1?`0aA440<TE10313?P0_@Sd0=DY503a@C@0dB4H0;d=203Y>C`0f
BDd0A5MN041CF`1;GFL0BE]W04IHI@11Df40H79n05MYL`19FfD0AUUQ04UKI017FV40BeiT04mRJ@1;
GV@0BeiS059UJP1@HfP0DFI[05AXKP1EJ6h0FFa`05e_L`1LKW80G6i`05i]L01OKW40J7Qh06EcM01N
KVh0IGIe06AgM@1ZOG/0K7mm07B4P`1mSH`0N8R70`1kRHT00`1oRh/0PHb>08>AU@0208BAU`0Q08RD
VP2<Uid0SiZP096KX@2EWJD0U9bT09JNY@2LXj/0XJF^0:NY]02_/K/0/K:m0;:b_P2g]/<0_K_80;jk
bP31_/h0a/3B0<W4e@3<a]T0d<OJ0=kBiP3[go<0j=__0=c@i03OdNH0iMO/0>OGk03ZfNl0kMgb0?3N
m03`gO<0lmoe0080m]kf103ggoL20?KNmP1H0?GMm@3dg?@0lm_c0?;Kl`3_f_40kM[`0>_HkP3Yend0
imG[0>?Bi`3Pd>D0g/oT0=_=hP3Jc>00f<[N0=O<g@3Db]X0d<OF0<c4d@3;`m00b<7>0<:laP34_/P0
`[k70;fj`@2k^;l0^k[00;Be^@2b/kP0[Znd0;6b]`2][[40ZJf^0::XZ02LXZ40UYbK08RASP23S8P0
Q8f808F?Q`1mQgl0LG]b06ahK01]NFd0JgMZ06EcI`1SLFD0HW9X06EdKP1YN7@0K7aj07N7Q@1SMW<0
G6m[05U/J01JKFX0Ffi[059UHP1FJFH0FVeY0723O`1jSHX0A5MC04]ME`0oDD/0=4I003E5@00a@Cd0
<d8o02Le<P0Y=SD082`/034l?00e@440>dI803E0A00a?400:SDg02Pc=@0Z=SH0:cLe04IBD00Z=S80
9C8[02Xg<00S<2P09S<Z04EAC@80:cLc00L08RhZ02Da;@0d@3`0;CTe02/g<`0^>SH0:CDa00808RhZ
01/07RLR02@]:00P:B@09BhY04mHD`0]=S407bPS02L`:`0P:B@0;3D`01`U800Q:RL09Rl_04mHF00R
:b/08BXY020Y:00K92<082TX01XS8P0J92<08B/[01XS8`0N9bH07b@Q028W8`0N8al00P0L8Ad0200N
8al041DA024V8P0O92007R<O01DJ5P0T9bD08R@S0P0M7ah01P0H6QT06A/J01/M700Y:bX0=CLf02HX
9`805aTH00T061/J01/O7P0S9B@05QPG01<E500K6a/05aLG01HF5P0F51D00P0H5QL0100G4a@04a4@
014@3P0H5aD201<B400701@C4@0Q81h0=SDc01PG5@0D4a405aHD01@C4@0301<B408051<A00H04a8@
00h=2`0?3P`051<A01HE4`0C4Q02014@3P0I01@C4@0?3P`05A@B00h=2`0B4@l051<A00T81`0D4a40
4A0>00l>300@3``03PX701DB3@0@30T04Ph;014=2P0C3`h04@d<010<300A3@h04Ph?014=3P0@30d0
4`l>018>3@03010<2`0400l;2P0=2@P05A4@00X71P804@d<01D04`l>00h:2@0?2`X05A4@00h:2@0?
2`X0510?00h:2@0D40l02@D5018>3@0?2`X040`;00l:1`0C3P/04Pd:00h91P0E40d09b8O014<2@0D
3``00P0A30T2018=2P04018=2@0@2`P03@P500h91P804P`<00X040X:00/51`0;1@L03`T;014;3@0?
2@T03`T8010;200>2@H03`X70P0@2`P00`0B3@X04`h;014<2@0200l:1`08010;200>2@H040/800l:
1`0B3@X03@P500l:1`0=20D2010;20803`X700<050`:00d40`0=0`800P0A1`H02@0B20L05@/:0188
1`0A1`H04PP701<9200B20L04`X:00X51@0200l92@0500h8200C3@d030H600d71`0>20P00P0?2@T0
200>20P03@L700P30`0A2`/050h>00d71`0@2PX03@L70P0>20P02@0@2PX03@L700d71`0A2@T04PP9
00l51P0F30d05@/<0147200201<92P0701882@0A1`P040H701061`0D2``02@<300d71`0200`61P05
018<300?2@T03PP8010:2P0A2`/00P0?2@T201882@@04@L80`0@1PL06`0?1@H04@L800l51P0=0`@0
2`<30147200>10D040H701882@0F30d05@`=01hD5@0<0`@050X;00`3100@1PL03`D60147200@1PL0
3`D601H<3@0>10D04@L801/A4P1EBd`04@L801882@0Dooooo`006oooool01P0C4A804Q0A010>3`0?
3@h03P`=00d;30804Q0A0P0A3a005@0@3Pl03P`=018@4@0?3@h03@/<00h<3@0?3@h03P`=00L51P0I
5aP06QPI00/92P0I5aP00@0003@c<@0O7Q`02`X8014@3P0B4@l03Pd;010?3@02018A3`06014@3P0>
3@/03@`:00h=2`0A40h040l=0P0=30X00`0>3@/03`h<010?3@02010?3@803Pd;00@040l=00l>300?
3P`03`h<0P0>3@/2018A3`0:014@3P0@3`d03Pd;00l>30081`D051<A00d<2P0:2@L040l=00l>30<0
40l=00X04A0>018A3`0B4Q00410>01HF50051@<02@T701@D4P0o?cd061PF0P0A4@l200T91`0C01<C
400B4`h04Q<>018C3P0H6A@05AHA00d>2@0?40/06Q/F01DF4@0F5a80<34/01PH4`0920@02`X601@C
3`081`<03`h:01hM6@0201HE4@0@014@300P7a/03@`8018A3@0D4`l04Q4=014@300B4@d03@`801<B
3P0?3PX03Pd901<B3P0E51004A0<014@3P8040l=00@04A0>018A3`0B4@l04a8@0P0B4@l04P0A40h0
4Q4?01<B400F4Q40510?014>3@0>3P`04A8@018G4`0?51003Pl=01<C4@0L6aT06aPG010<2`0@3`d0
4A4?00l?3@804A4?00X020P6010@3P0K6aT03Ph<01<C4@092@P06AXE00h?2@0@4@T04A8:0P0A4P`0
200@4@/02@X501LG500820H03Ph<01hN700=3@/03Ph<0P0?3`d06P0@40h04Q8@018B400A4@l01PH4
00h>300D518030`:00P81P0D5QD03@h@018C5@0C51H020T;04m@DP0Y:R`02P/=010A4`0D5AT06a`P
00P92`0E5A805aPC01PI500B4`h01PL20P0B4`h01@051P404Q<>010A300=3PT05QLB00804A8=00`0
4Q<>01<D3`0D5A0051D@020Q700;30L03a0;01LH4`0B4`h051DA01XL6@0G6AH201`N6`0>014C400D
5Q<04aDB01`N6`0Y:bP07R0M01DG500Q92406QlK018G4`0C61@06AhJ01hS7`0F6aL201DJ5P0m01TN
6P0K81`06AhJ01DI5`0F6QT051PG01/O7P0H71/041@C01TM700/<2l05QXI01DI600R9RD07b<R01TO
7`0C6AT082HV02L];@0K8B406R0P02D[:`0S:BL051XG028Y8P0K8Q/051/D01XP700R:2@08BLU01DN
6`0G81d05QlN01/U9P0U;c007RPZ02Ha<`0lAd/0:SDh02<_;@0S<2T08S4Z02<b:`0T<b`093D]02@e
;`0U=S00:3/g02/n?00/?cd0:cdl02Tk?@0[?Cl0;Cm102do?`0^@400;Clo03I9A`0cAT@0<DA203=6
@P0203A7@`0=03A9A00gBdT0>4a:03Q<B`0nDE@0A5MK04QKH@13EUh0FF]e04eOJ`0nD5`0BUaX04YL
IP0204UKI@80BUaV00/0BE]U04YLIP1@HfX0D6=Y04ePI01>HFD0E6M[05Q]LP1GJg40EfY`05U/L002
05e_L`0;05maL`1SLWD0JWUl06YjNP1XMWL0JWYj06QiN01ZOG/0KH1n07:5P`1hR8L00P1iRHP09P1j
R8P0NHN707Z8R021SHd0Q8nA08JDV026TiT0R9FK08bGW@2?VZ00TIbR09FNY@2GWZH0V9nW09bSZ`2R
ZK40Z:be0:^[]`2`/;`0/k>o0;Rf``2m^lT0`;g<0<>ocP38`M<0blCF0<g6f03@b=d0eL[O0=_>hP3Q
e>P0i=O[0>CEjP3Ven`0j]W_0>gKl@3_gO<0ln7g0P3eh_P00`3hhOT0nN7i0?WQn@040?WQn@80n>3h
01H0mmog0?GMm@3egOD0m=gd0?;Ll`3_g?80k]_a0>_HkP3Ye^`0j=K/0>OEj`3RdnP0g/oT0=_<h@3J
bn00el[L0=G:fP3Cb=P0clOD0<g5dP3:`/l0a;k80P33_LL0<P30_L@0_K[10;Vf_@2c/[L0]kRl0:VZ
[@2XZJ/0ZJZ/0:FYZ@2PYZ@0VZ2N08Z@S@1oR8<0P8V408><Q`25ShL0OhV107AnM@1/N6`0JGEY06Mc
I`1aOW@0Kgab06]kLP1[NWL0JgUi06UiN01TM7<0GW5_05IYI@1GJVH0GW5]05mbK01EJ6@0FVeY05IY
I@1TMg<0Kh9o04=FE015EE80@55;03E6@00eA3l0=DA002hm>P0X=c@09C8a02Pd=00hA4@0=T930P0d
?d402`0^>C/0:SHf02Lc<`0W<c40;c/i02`h=00U<R`0:3D^02`i<P0/>C00<3df0080:SHb00`0:CDa
02Xf<P0]>CD0;c/g02Pd<00U<Bd0930/024]:@0K9b<062@P01/T7`0Q:RD202</9`<08BXU02007RLR
02Xc;P0T;BP06B8M01LP7@1?FET0n?oo075kO00J92<09Bl^01hX9`0O:2L07BHU01LP7`0R:bX092d/
01XP7P0O92009R/W02DZ9P0O92007B8N01HK5`0k@3`0HfQT01@I5@0X;BT07b@P01LJ600J71/06adL
01`N7@806adL024071hM01lQ800P8R406Q`K01HH5`0I6aX06A`K02@X9`0>40l07R0O02X/:`0=3@d0
5QHF01LG5`0I5aP061HG01XH6@0J5QL061DE01PG5@0G5Q@04a8@010?3@0D4a402@P602/Z:00=30X0
4A0>01TH5P0E518051<A018A3`0C4Q000P0D4a406`0B4@l07A`J00l>30030P0020L500d<2P0A40h0
40l=018A3`0C4Q004A0>010?3@0?3P`01PD302LV900;2PP02PT701<B400F5A80920M01DB3@0C3``0
7QXG00/7100>2PT03`/:01<?3`0201HB4`0301<?400?2``04@d<00803`/:00d04@d<018>3@0?2`X0
4`l>00d9200?2`X05Q8A014=300300005Q8A01<?3P0300005A4@008030P70P0?2`X200h:2@8040`;
00<05A0=018=2P0@2`P00P0@2`P00`0>2@H03`X700l:1`0200l:1`803@P501<04Pd9010;200?2PL0
3`X7010:2P0A2`/09R0P02<M7`0F41802`D700h82P0:10@03PT7014<2@0@2`P03@P500h91P0@2`P0
3PT600803`X700<03PT600l:1`0@2`P01`0=20D2014<2@0E00h91P0=20D02`D401/A400N51<04`X:
01471P0D2PT03@@401061@0?1@@04@L601<9200A1`H040P700T30`0E3`l040X:01dG5`0Z92@04@/;
00D03PP800L03`T900P20P0I4a<08adM01@>3P0F410040X:00803PP800T03`T900h8200>20P04@T:
00/10P0D2P/06a4B00l51P0D2P/00`0B20T03`0A1`P040H701061`0:0@8071HF010;2`1ZI6@0Dde=
00X4100A2`/040X:00l92@0=1`L03PP800l92@060147208040H70P0A1`P201882@0601dC500@1PL0
4@L800`20`0=0`@02`421P0@1PL01@0>10D04PP90147200B20T05@/<00804PP900D040L702HL7@1J
D5404PP900l51P0Dooooo`006oooool2014?4004010>3`0?3@h03`d>00h<3@@040h?0P0?3@h2010>
3`0?00l=3P0=2``03P`=010>3`0U8b@0C4Y;00/92P0=2``04@l@018@4@0h=cD09bHT0040000A40h0
2PT700803`h<00H04a8@01DD4P0D4a403Pd;00`;2@0=30X2010?3@0500l>300>3@/03`h<00h=2`0?
3P`00P0@3`d200l>300400h=2`0?3P`03`h<00l>308040l=01<04A0>00`;2@0>3@/05A@B01@C4@0C
4Q000@0002d/:P0;2PP03@`:01HE4`0=30X03Pd;00l>300F5A<06APF01DD4P0?3`d03Ph<00804A4?
0P0K6aT02`0^;R`03@d;01PH5P0A4@l03@d;00/;2@0B4Pl051D@01LH4`0A4Pd03Pl:0080414<01H0
4a@?02l`:`0K71L051D@01XK5P0B4Ph03Pd900/:1P0V9B405aHB014@300W9R805aHB01@C3`0A40`0
71/G018A3@0<2`L040l;00l>2P0=30P040l;0P0B4@d01@0?3PX03Pd9018A3@0D4`l04A0<00804Q4?
00<040l=00h=2`0?3P`00P0C4Q02018A3`0N014@3P0B4@l04a8@01@@3`0C3`h04Pl>010@3P0A4Q00
4A<@00lA3P0A4Pl04A4?014@3P0C3Pd04Ph=014@3P0A4@l06ATG01XJ600B4Q003@d;010@3P0<30X0
000001PH5P0T92803a0;00l@2P0A4PX04Q<;0P0B4`d02@0A4P`03Pl:018B3`0820H04A4?00P81P0?
3`d051@B018B4002010@3P0M018B400C4a4030`:01LG5@0A4@l03`l=018B400A4@l04A<@01<E500G
6AP04aDD03Xl>`3Adm80EEIH00`=3`0@4A<04Q<G00/<400F5aT051@A018C3P0P8A`061TD00l@2`0/
;BP05AHA01<D3`0@4@`00`0C50l2014B3@0=018C3P0C50l051D@01@E400<3@X06Q/F01PI50082@@0
004001TJ5P0G6AH02P`900T;200200lA3P0=01/M6P0B51407R0M03Li=P0L7Q/03a4>014D4@0?5100
6QlK01@I5@0H7AT07b@P01PM6@0201HK5`0H01TN6P0K81`06QlK01<G5@0I7A`061`K01TM700K7ah0
5QXI01@H5`0N8R405ATH028V9@0O8b804ADD01PN700G7A/0728R01lT9`0L8B@0728S018H600I7ad0
7R@Q0P0P9b00CP0N9Ad06b4M01lU8@0M8al05QlL01`U8P0S;2/072HW02D_<@0T;C807bX^02Ha=`0Q
;3008Rh/028^:P0R<BX08S8X02<c:@0S=2X09SL_02Lh<00W>SD0:C`j02/n?00/?Sh09cTk02Tk?P0]
?d40;T120312@`0a@d<0=TQ80395A00aA480<dI403M:B00hBdT0=DU703M;BP0lD4l0@EEF04IJG017
FUh0@EAJ04MJH@0aA4/0;T1:04mQJ`0oDE/0@eMP04MKHP1<H6L0BemX04MKI@12EUl0C61Y04mSJP1?
I6T0C65T04mTIP1EJVd0G75f05M[L@1JKG<0FFa`05U[K`1NL7@0G6i`061_LP1UM7L0IWIf06IdM@1W
MgL0JW]j06]nO01^PGl0LhJ407V9R080NXZ90P1lRXX09`1mRh/0PXj>08F@TP28TiP0RIBJ08^FW02?
VZ00TibS09FNY@2GWZH0VZ6Y09bSZ`2RYZl0ZJff0:fa^P2_[[/0]K?00;Ne`P2l^<L0`Kg<0<K0d@39
`]@0cLCI0<o6f`3Ab=d0dl[O0=W>h`3PdNH0hmCY0>OHk@3[fNl0k=[`0>oLlP3bgoD0ln3f0?KRn03i
hoX0n^Ck0?cUo@050?gUo@070?cTo03jh_X0nN7i0?SPn03ggoL0m]kf0?GMmP020??LmP0N0?7Jm03/
f?40j]K_0>[Gl03Zf?00i]C/0>3Aj03Od>L0g/oU0=K9f`3FbMX0eL[J0=76e03>`m40b<3=0<S0b`35
_LP0`kg70<G0a`32_L@0]k>j0:f//@2h^K/0[:f_0:Z[[@2`/[40ZJf/0:2VY02HWYX0Ri6<0P22S8@2
08F?Q`0_07j8P01bO7<0JWIZ06YfJP1/N6`0N8Ek07>0M`1[NW@0K7]h06ilO01[Ng/0IWIf05]^K01I
K6P0G6m[05iaJ`1PM6/0DfIP05Y]I`1AI600Cf9N04]NG@14EeD0AeMD03e<A`0jBD@0>dY503=2?P0]
?3T0=4=002Xh=`0fA4@0AeEE03U7B00hATL0;3Ph02Lc<`0U<Bl0930^02Da;`0^>SH0930/02Te<@0`
?CH0;CXc02Tf;`0^>c@00P0X=3008`0Y=C40;3Pd02Xf<P0Y=C40:SHb02@`;00Q;BT082`X01dY9@0K
9b<072DP020Y900Q:RD08R/V02</9`0T;BP082TT03i7@P1RJfH06B8M01`U800I8Ql09c8c07=oO`0n
BTX0:38c01TS8P0P:RT0>450059KF00`>CH04QPF028X9P0[<Bl082DQ00809b`X00/08RLS01hS7`0O
92005a`H02/`;00U:RH07B8N00L<200J7Q/061XI01TK6P0301XL6`0J01/M700G6AP04aDD01<E500G
6AP06A/J01HI600S9bH030h=01<E500T9RD03`l?01HF5P0J6QX071XK01DC500F51D05a<D01PE5@0K
6QP061LE01<B400A40h05A@B00X91`0H5aD2014@3P0301DD4P0C4Q0051<A00804Q4?00<04a8@01@C
4@0B4@l00P0D4a401@0J6AL06APF01<B400C4Q004A0>00<040l=0P0?3P`03P0T8b40M7=a01XI5`06
1@<04Q4?00L60`081040;2TT02hZ9`0@30T07QXG01@@3`0?2`X0510@0P0I5AH03@0D41403`/<00l;
2P0>2PT03`/:014=300C3`h04@d<00d9200D40l05Q8A018>3@0>2PT00P0?2`X01@0A3Pd0;2PW00P4
0`0J5QD01`<2008040`;0P0>2PT200l;2P0701@?300@2`P03`X7014<2@0>2@H02@@100h91P0200l:
1`0400h91P0=20D030L4010;1`803`X701@040/8014;2`0B30`05@l?00L10`0C3@l05a4C01@>400A
2`/04@/:014<2@0@2`P03PT600d81@0>2@H02`H300X50P0<1`@040/8014<2@L040/800<03@P5010;
200@2`P00P0>2@H04`0A2@L02P0000L0000A1`H06a4@01T?3P0?1@@040H500h40`0@1PD04@L60106
1@0?1PH03PP801H@400;1@D081XJ02`V9P0A2`/01P0>20P00`090`<0618B024K6`0201@>3P0400l9
2@0>20P03PP800l92@803PP800H03`L700h41@0e:b`0AC/l02DK700@1PL301882@0=0147200@1PL0
40H700H0000Q6a/030L706QRHP1=AdL030L7014;2`0@2PX03`T900d71`0200h820H04@L80P0@1PL2
014720804PP900H0;28S01T?400B20T040H701882@0:004601061`0<00h41@0E2``0308300h41@0F
30d0200000l51P0D2P/0D4I704<i>P0G3@h01`005?ooool001_ooooo1@0?3@h00`0@3Pl03`d>00l=
3P0200h<3@0F010>3`0A3a003P`=018@4@0A3a003P`=00d;300A3a00>cTj04a:B`0E4a@040h?01dK
700G5AH04a8@00`;2@0?3P`04Q4?00X91`0B4@l03`h<010?3@804A0>0P0>3@/0100=30X03`h<010?
3@0A40h2010?3@0300d<2P0>3@/03`h<00<040l=0P0>3@/00`0?3P`040l=010?3@02014@3P0300h=
2`0C4Q0051<A008040l=00H0:bXX030_;@0H5aD04a8@00l>300@3`d200h=2`0/01DD4P0I61H051<A
010?3@0?3`d04A4?01DE4`0820H04A4?06i^K00N7Q`03Ph<014A3`0820H05ADC018B3`0B4`h051D@
010A300=3PT03Pl:014B3@0<3@P09bPS01<D3`0F5a803Pl:010@2`0D4`l04A0<02l^:P0I61@03Pd9
03hm>@0Q81`04A0<00h=2@0B4@d03`h:01/J5P0N7AT061LC00h=2@0?3PX2014@3006010?2`0?3PX0
4A0<018A3@0@3`/04A0>0P0C4Q00100?3P`03@`:018A3`0C4Q02018A3`0A014@3P0B4@l04a8@01<=
3@0D3Ph0510?018A3`0@4@l03Q0=010B3`0@4@l03Pd;00h:2@0A30`05A4@01@C4@0A4@l00P0L71X0
2`0B4Q0051@B01<C4@0R8R003`l=01@D4P1EEE<05AHA00h?2@0@4@T04A8:00<04A8<02/05AHA01DF
4P0F5Q@05aLE01<C4@0?3`d07QhL01XJ600D51804Q8@014A3`0B4Q00410>00h>300C4a403`l=00d=
2`0C4a404A@?014C3`0?4@d05QPE00d>300Q8b406A/K01PI6`0:2`d05QLJ01<D600E5QP05QHC00h?
2P0C50l04A8=01@E400b<bh08B8M03Xk=P0E5Q404a@?01dN6@0=3PT05AHA008051D@00/04a@?018C
3P0A4Pd05aPC01DF4@0H6A@05AHA01TJ5@0E5Q805ALD00lA3P0201DG501600lA3P0J71T04aDB01DG
500O8Ah051HC018D4@0]<2d08bPT01<H500A5Q805Q/G01PM6@0C61@051TE01<H500E6QH05a`H01HK
5`0I7A/0:Bd/02@X9`0F6QT061`K01HJ6@0K7ah04ADD01DI600P92<05a/J01/O7P0H7Q/06b4N01PN
7P0G71l0724T01hS9P0S:2/061hN01`R7`0H7QX061lH01TP600K8Q/06b4M03Dk=`0C71T07RLT01/T
900N:2X082X/02</<P0N:C0072L^01lZ;`0R;Rh08RhZ028a:`0R<RP08c<Y02<e:P0Y>S40:S/c02Pk
=@0X>cT0:C`j02i0@@0]?d<0;d540353AP80<TA603<0<TA503=5A@0`@T80<49103=6A00hBdT0>Te<
03Y>CP0iCDh0@EAG04ULG`1:GF40@eIK045DFP1EJ6l0EfY`04IIH01:G6@0AEQN04aPIP1<HFL0BemV
04UMIP1:GVT0CF5/059VL@1BIVh0D6EZ04mTI`1CJ6T0F6e^05U^L@1OLgP0G6me05e`M01QLgL0Gg5e
05]]K`1OKW40HW5d06EeM@1WMGH0IWIf06YkNP1[OW`0KX5o07:5P`1gQhH0N8R707V9R01oSHd00P20
SXh08024T900QY6C08RCV029U9X0S9NM096KXP2FWjH0V:6X09VPZ02NY:`0XJN_0:N[]02]/KX0/[Fn
0;Bb`02j]lD0_;W70<6kb`35_m00blCE0<o7fP3CbMh0e<[O0=G;h03HcN@0gm;W0>CDj@3VeN/0k=[`
0?3Nm03ag_@0m>7g0P3ghoT08@3iho/0o>Gm0?kWo`3ojOl0o^Wo0?oXo`3ojOl0o^Wo0?oXo`3nj?h0
nnOm0?cUo03jiO/0n>Cj0?WRn@3ghOT0mmoi0?KOn@3dgOL0lM[d0>gIlP3/f?40jMK_0>GCj`3Rd^T0
hm?Z0>GFk03JcMl0fLcM0=G9f@3=`]00bl3>0<_2c`020<NobP0>0<Bmb031_<<0`;_20;jj`02c/kD0
/[>d0:j`[`2_/K00XZBR0:2UX@2LXYh0TYRC08R?R024SXD2086;P`0I07R2N@1dOWH0L7Ya071lL01d
P7@0N8Ah07F2N01aOWD0JGQc06UgM`1XMWP0Hg9e06]jO@1OLW40H7=_065dL01LKfP0FfmV05=WGP1G
Jf<0CV5K04mRH01DIVD0CemN04QGE00203Q5@@0>03Q6@@0^?3T0;C`i0391?P0nC4/0@e5A04UGE`0g
ADD0:cTi02di=P0Z=S80:SLa02Pd<@0X=30302lk=`0<02`h=@0Z=S<0;3Pd030l>00Z=S809c<_02Hb
;P0Y=C40:3@`02Lc;`0Z=S808bl[0`0O:bL01P0N:RH08R/V028[9P0Q:RD082TT024Z9@808b`W0140
<c`g04QAC00I8Qd07BHQ01hY9@0M:RX092l`01dX:@0R;Bd05b4Q02<];@0T;B`08bXX01hU8`0Q9b@0
9BXW02<Y9P0201lT800;020U8@0N8al07B8N01/P700P9B406b0L01dR7P1<DDd0;C8^01PK6@0K7A`0
0P0L7Qd05P0J71/061XI01LI600G6AP06A/J01`N7@0K7A`05QPG01HI600>4Q40;c4`01TK6P0=3`h0
:RXZ018B4P0F5QH05aDF01PF5`0M6a`06aLH01DC4P0G5Q@401DD4P0301PG5@0;2PP061LE008040l=
00D04a8@01@C4@0B4@l04A0>018A3`0201<B400J01PG5@0A40h04A0>01<B400<2`T03Pd;01DD4P0?
3P`03Pd;014@3P0?3P`04A0>01LF5016AD<04a8@00T81P0N7A/03`h;01TE4P1WI5l0LVi[00l;2@0@
30X04Ph=014=300C3`l201@@4@0501<?400A3@h04@d<010<2`0?2`X00P0A3@`03@0?2`X03@T800l;
2P0=2@P02`L600l;2P0G4a8030P801dJ6@1BCTd030T8018>3@0D40l00P0A3@`05@0?2`X03PX900h:
2@0>2PT04@`9018=2P0A30T040/8014<2@0C3P/040/8014<2@0B3@X04@`900h91P0=20D03`X600l:
1`0@2`P04@`9014;2`02018<300A018<3P0=20T0B494055;C@0H4Q804`h<018=2P0A30T03`X700h9
1P0=20D04@`900`7100=20D040/800h91P0:1@801P0>2@H500l:1`0701081P0X81l0OG=b020F5@0=
10<03@@401@:2@0501471P0701D=300B30`04@/;00`61P0?2@T050h>00d71`0600h8200600d71`0B
30`05@l?00`61P0;1@D030H60P0>20P0200?2@T03PP800h8200A2@X040H701<:2P0F3@d040H7100B
20T02@0A1`P040H701061`0F3@h02`D500l92@0@2PX03`T900h8200300l92@0300h8200=1`L03@L7
00H04@L80P0@1PL2014720804PP900D06a4B00l51P0B20T040H701<92P0701061`0<01882@0@1PL0
3`D600d3100=10D05`d>01<92P0G3Ph0H5IG05E;C00C2@X04@L85?ooool001_ooooo100>30d200l=
3P07018@4@0@3Pl03P`=00h<3@0@3Pl04@l@00h<3@02014?400:00l=3P0>30d03P`=00l=3P0@3Pl0
6QPI014?400I5aP03@/<00d<2P<03Pd;00<071/I00T81P0=30X00P0<2`T0200=30X03Pd;00l>300?
3P`03Pd;010?3@0B4@l040l=0P0>3@/00`0?3P`040l=010?3@0200l>300400h=2`0?3P`03`h<00l>
308040l=0P0;2PP07`0A40h03Pd;00`;2@0A40h0BdY801DD4P0?3P`03Pd;00L6100F5A<040l=00h=
2`0@3`d04Q4?010?3@0A4@l02PX8010@3P0F5Q@04Q8@02d]:`2EUI<0:BTW010@3P0F5Q@02PX801TI
5`0?3``03Pl:00d>2@0A4Pd00P0@4@`0600E5Q404a@?01HG4P0>3`X04Q<>00d>2@0C4`l051<?00/:
1`0G5Q801`H2010?2`0K6QH03Pd9018A3@0D4`l04a8>00d<200G5Q806APD01@C3`0=30P03`h:014@
30<040l;0`0?3PX00`0:2@L030/900l>300200l>300>014@3P0C4Q004Q4?018A3`0A40h04Q4?01@A
400C3@d050h>01<?3P0A40h03`l=00d?300@4Pl200l>300@01<?3P0F4A005A4@014@3P0@40h04a<A
018B400>3P`04Q8@00H6100D51800P8000/;2@0E5A<01`P300d>20803a080P0@4@/02@0?40X020T4
01TI5P0L71X01`L5018B400<30X051@B018B4002010@3P0N018B400C4a403`l=01lO7@0@40h06QXH
02DU8`0F5a803Q4:01XM5P0A50d010H301LI5P0D5Q<051HE010A4`0O82807AhP00H72`0:2`d05AHB
01DF4@0A4Pd0414<00/<1`0B4`h092DP01@E400<3@P04A8=0P0E5Q400`0B4`h04a@?01<D3`0201DF
4@0=01HG4P0E5Q40Gf1K04Y;AP0?40/09BHQ01TK5`0E5a@03a4>01TK600G6AH0418?01@F4`0201DG
5007014C400H6QL06A/H03Pk>00[<2`03a@@01HK5`0201TN6P0401LL600F6aL051TE01DJ5P805a`H
03006AdK028V9@0L81l05QXI01PL6`0F6QT05ATH00/?3P0/<2l0@TI502X^;@0E6AP061hJ01XP700H
7Q`061dP01`Q900M8RH06AhQ01hS9P0S:BL08BPQ01dT700P:1d09RdV02D[9`1=Ddl07bPU02/d<@0P
:2X07bT[01`U:P0N9bh08R`e02<]=P0T;SH08bl_02<_;@0S<R`093</02@d:P0T=RX0:CX`02/l<P0Z
?CL09cXh02Pj>P0^@4830312AP0>0312A00_@D<0;Cm103A6AP0cADD0=DM703U<BP0mD4h0?Dm?03U<
D00jCE80@UEI04YMH@1:GF8204=FG00H05=VK01dQhd0Gg9h045DF@18Ff40@EIK04YOI@1?HfX0CV9]
04iQKP1@Hg40E6Qc05AXL@1CJ6d0E6U/05I/J`1IKVl0Efa_05a`M@1EJ6h0EVU]061bMP1RM7P0H79d
0P1UM7L0201ZNWX0Kgen06alO01_P7l0L8>107:5P`1fRHL0Nh^:0P1lS8/0:@21Shl0PY2@08BBTP27
Ti<0RIBF08ZEVP2<Uid0SYVO09BMY02HXJP0VZ>Z09^RZP2SYk00YZZc0:^_^02`];d0];O00;Vfa02n
^/T0`;c;0<Bmc@39`]@0c/KH0=?:g@3Gbn40fLgS0=_?i@3Nd^X0i=G/0>WGk@3[fNl0kmgc0?;PmP3e
h_P0n>Cj0?_Uo03li_d0o^On0?oWo`3oj?l0o^[o00L0oN[o00T0o>Wo0?_XoP3jiod0nNKl0?WTo03j
h_`0nN;l0?OPnP3dgOL00P3`g?D03P3^f_<0jMO_0>CBjP3Rd>P0h=3V0=_<g`3Ic=d0eLSI0<o4dP3A
a]@0f/oM0<NobP38`</0a[k90P2m^;l02P34`LL0_Kfo0:V[ZP2RY:<0Z:ZW09NIUP2^/jl0YZfV096H
T@1iP7T2075kLP0a07Z4N`1cOG@0LWac07=mM01fPWH0N8Ah07N3N01dPGP0Lh1i06imN@1YMgP0IG=g
069aMP1VMGP0IgUi06=fLP1PLfl0GW5Z05M[HP1BIUd0BemG04ULEP12EE<0E6IV04=CD`0mC4T0=D4m
034m>@0_>cL0:cTe02`k>00[>SL0AUEC03i<C00iAdL0;C/l020^;P0_>cL0;S/c034n=`0^>c@0:CD`
02`h=00Z=S80:cLd02/g=@0`?3X0;c/i02@`;P0202Te<@809c<_00D0:SHb02di=@0T<2`07b/W01hZ
9P0201l[9`0H01hZ9P0U;RT09BhY028[9P0O:2<07RLR020Y900N9b80624L00lH4`0N9b806R<N01lZ
9P0S<34041/M02Lb=00O:b/06B<T01lY:P0Z<c80:2h/02`b<00O9B405a`H0P0Q9R801`0K81`06QlK
01dR7P0O92007R<O018G4`0>4`l00P0P9B401@0G71P06QdK01PJ6@0I6aX071hM00<07AlN02407R0O
01lQ800J71/05QPG01LI600H6aX04QHE020R8@0E5aH03@l>01lO7`0P82005aLG01@B4`0I5aP04a4B
010<3@0A3`h04Q4?01<B400F5A<061LE01DD4P0K6QP01@@201HE4`0>3@/040l=01DD4P0D4a404Q4?
00l>300@3`d00P0B4@l06P081`D02`X800l>30030P0030/9051?C@0L6aT04A0>00d<2P0B4@l03Pd;
014@3P0G5Q@03@`:018A3`0=30X051<A00P7100;1`@040d801hJ5`0A3@X01`<001@@3`0E4A00510@
0P0B3Pl0100D41405A4B01<?3P0A3@`2010<2`0>00l;2P0=2@P03PX901LC4P0I5A@05A4@00l;2P0=
2@P07a/J00h:2@0G4a807QXI00P5100?2`X2010<2`803PX90P0?2`X00`0@2`P04`h;014<2@0200h9
1P09010;200>2@H040/8018=2P0@2`P03@P500/60`0?2PH040/800804@`90P0@2PX01`0=20P04P`>
00`6200M61T07aTK00@0000@2`T00P0=20D0100>2@H03@P500/60`0>2@H200`7100300d81@0<1`@0
2`H300H040/800<04@`900h91P0>2@H00P0@2`P04`0@20H08QPG09J<R`0M4a803`D400L0000A1`H0
4PP701@:2@0B20L04@L601881`0E30`02P@400L10@0A2`/02`D500`61P0B30`01@0>20P00`0=1`L0
3PP800`61P0300d71`04010:2P0>20P03PP800l92@803PP800H02`@401@:2`0J41406@l@01X@4@0?
1@H301882@070147200@1PL040H701892P0A2`/03@L7010:2P0200l92@803PP800@03`T900h8200=
1`L030H61P0A1`P201061`804@L80P0B20T01P0?1@H0308301X@4@0C2@X04@L801882@H040H700`0
5@/<00l51P0L4Q<05`d>01<92P0e:b`03P@501061`0?1@H0:R0Q00T10@0A1`PDooooo`006oooool2
00l=3P@03P`=01X0518C018@4@0?3@h03P`=010>3`0A3a0040h?00l=3P0@3Pl04@l@00l=3P0<2P/0
2PP9014?40081PL0518C00D3100K6AX040l=01DD4P030P003@`:01<B400:2@L030/900h=2`803`h<
0P0>3@/01`0A40h03`h<010?3@0B4@l03`h<00d<2P0?3P`00`0@3`d200h=2`04010?3@0?3P`03`h<
00l>30803Pd;00<04a8@00P71@0?3P`00P0A40h01`0E5180;2/Y018A3`0920H040l=00T81P0D4a40
0P0@3`d2014@3P0S010?3@0E518030`:00l?3@092@L02PX800<30@0K6aT02@T701/K6@0H61H06QXH
01LG5@0=3@X03a0;00h?2P0A4Pd03Pl:00l@2`0F5a807AhI014B3@0B4`h02@X500/<1`0C4`h04A0<
00h=2@0C4Ph01`H201<B3P030P002@P401/J5P0E51000P0B4@d01P0920@02`X600T8100<2`L04Q4=
01<B3P<040l;00D03`h:00h=2@0>3@T04a8@014@3P0200l>3003010?3@0A40h04a8@00804Q4?00P0
4A0>018A3`0D4A005@l?01@>3P0C3`h040l=00l>30803Ph<01@04A0>01<B400D40l050l?01D?3`0@
3`d05ADC01<C4@0@40h04A4?00l?3@0E5A<02PX800P81P0O7ad03`l=014B3@0>3`T03a08010A2@80
4A8<00P0414;014B3@0?40`0410>018B400G5aD03`l=00h>30803`l=0280410>018B400B4Q005aLE
00X:20051@<0@T9003Xj>0000@0030l:00d@1`0G6Q4082<L01DG4P0:30L04aDB020R8@1eMgH0H65S
01TJ700O8B004a<@01<D3`0D5A006AXE00l@2`0D5A006a`G00<4000?40/04Q<>00l@2`0F5a804Q<>
0P0C50l201DF4@0@01HG4P0B4`h07AhI01PI50082@@05AHA00T:1P0D5Q<092HS03m1?P0];b`0418?
00h@3@0G6AH061XG01@F4`806Q`I00X06AdI01DJ5P0J7a/0724M01<H500H7AT06QlK01LL600E6QH0
5Q/G0P0H7AT02P0C61D04aLF01<G5P0M8B007b<R01XN7@0P92<06alN01dQ800T:2L201lS8P0U01TO
6`0H7QX06R0N01`Q900K82<0724U028W:`1<DE@0?dE301/R6`0F7AD06R8G01@K500F7AH0;38^01<L
6@0Q:RL07RHX020Z;00P:Bh07bP_028/=@0U;cP092lg02@`<00U<Bl093<]02Dd;@0V=R`09CL[02Pj
;P0[?380;3li02Pk>@0W>CT0;Cm20312AP020353A`0b0312AP0_@D@0;T1203A6B00eAdP0>4Y:03a?
C@0mD4h0>de=03e@E00nDEP0A5MM04QKH@16FEl0@EAJ03mBEP11E5P0@5=G045DF01>HV@0>diB049G
FP1;HVL0D6M]04eSKP1:H6`0Bf5^05=YM01CJW80E6a`05E]K`1FKfd0EVm/05Q]L01JKW@0KH26065d
N01FJ6`0HG=g061bM01VMGP0I7=f06YjNP1`OWl0KGem07>4P`1cQX@0MXV707V<RP1nSXd207n?SP0U
08BBTP25Ti<0QiFE08bHV02>VI/0SYVN092IX02BVj80Uj2W09bSZ`2MY:`0WjJ^0:N[]02Z[[L0[[:k
0;>g`02f^L80_[W80<>lc035_/h0al3@0<g4e`3Ab=`0eLcQ0=[>i03MdNP0gm?[0>?EkP3WfO00kM_a
0?7Om@3bgoD0m>7g0?SUn`3mj?l0o^So0?oXo`020?o[o`030?oZo`3ojol0o^co00D0o^co0P3mjol0
4P3lj_l0n^Sn0?[XoP3ki_h0o>Cn0?_So@3ihO/0mMkh0?CMm`3bgOH0l=ce0>_Il@3Ve>`0hm7Y0=o>
i@3Ib]d0f/gN0=O:f`80d<CB04H0elcJ0<c2c@3;`L`0a[k90<6l``30^l80`Kg30;2`/P2SYJ@0WInL
0:FWY02KWIX0]KZd0:>ZX`2=U8d0Mgif079lL`1aNg80NXAi07EoMP1dOWD0MGmf07J2MP1gPgL0MX9h
07N4N`1hQGh0LH1l06IdM@1TLWH0J7Ml06AcMP1`PX80I7Mc05a_J`1NLFX0DVIK04MKD01:GEH0I7Ma
04AGE@10DU80=DE50350?@0f@Sh0<3`h02`h=00/>CH0:STf02ln>`0kBTP0=4920392@@0X>3L0:CLg
02Ld;@0Y=Rd0;c`c02dj<@0U<RX09C8[02hj=P0`?3T0;SXh030l?00[=cL072PX02hj=`0b?SX0;c/g
0P0V<Rh0800Z=S80930/02<_:`0U<Bd09S8^02@`;00R;RX092dX02D^:@0S;2L082TT01lX8`0P:B@0
6B8M02Pa;00S;2L08R/V01lX8`0Q;2P06RHY028`<@0B8240;cXl06YdM@0jA4D06b@S00T?3@0D6QP0
:Rl[020U7`0C61807b@P0P0J7a/201hS7`0901lT800M8Qh06AhJ01hS7`0R9b<09BXV01LK600F61L0
61XI00806adL02<071hM01dO7P0L7Qd06A/J01DG5P0C5A@05QPG01PK6P0C5aH05ALF01PJ6@0A4a80
5aLG02HV9P0H61P0518C01TG60091`P04@d>01dK6P0E51804a8@01HE4`0H5aD05QDC01`K6@0;2PP0
5aHD018A3`0C4Q004Q4?01@C4@0B4@l03`h<010?3@02018A3`0J014@3P0D4a404a8@00T81P0];2X0
/[6_024P7P0C4Q003Pd;01<B400>3@/04A0>010?3@0J6AL051<A01LF500F5A<061LD01PD4@0E4Pd0
2@H401HB3`0I5A803`/:01<?3P0C3`l2018>3`804`l@00<04Ph=010<2`0?2`X00P0A3@`03@0>2PT0
2PH5024M700U8B005A4@00`81`0E4A006QHE00P5100>2PT03`/:01DA400;1`H00P0?2`X200h:2@80
40`;00d03`X700h91P0A30T05Q4>018=2P0910403PT6014<2@0C3P/04Pd:00h91P0<1`@040/700<0
4@`901403`T900h8200C3@d01P0201XD5P0?2@/0100001@>3P0A30X03PT600l:1`0B3@X040/800h9
1P0@2`P04@`9010;200200l:1`03010;200C3P/04`h;00@04`h;00<04Pd:00d81@0=20D00P0A30T0
4`0I4Q001`00028H5`0C2PT07A<B01471P0C2@P04PP701<9200A1`H03`D401471P0@20L030H600P2
0P0=1`L03PP800/51@0@2PX01@0>20P01`0;1@D03`T900/51@0;1@D03@L700X4100?2@T00P0>20P0
2@0?2@T03PP800h8200A2@X04@L800/10P0900003P@501H<3@0301882@090147200@1PL040H700H0
000F41002@@400d71`090`<04P`<00803@L700@03`T900h8200=1`L030H61P0A1`P201061`804@L8
0P0B20T01P0C2@X04@L801hD5@0E2``04PP901<92PH040H700`04`T:0147200J41405P`=01<92P0X
7Ql03@<401061`0700004@L800d41009000Dooooo`006oooool04P0@3Q806ALJ02HT9P0?3A404@lB
00`:300B41@06ALJ00h<3P0?3A403@/>018@4P0B414030X;01<A4P0@3Pl0518C00T720803`d>01P0
5Q@E00h<3@0@3Pl03@/<00h=3P0D4a@02`X;014@4P0:2@/051<E00d<3P0920X081lQ014@4P0<2`d0
2PP:014?3P0@3P`04@l=018@3P0@3P`03P`:014?3@0@3P`2014>3@0<00l<2`0>2`X04Q4?014@3P0=
30X03`h<010?3@0=30X07QdK010?3@0?3P`04Q4?0P0?3P`0;`0;2PP05QDC00d<2`0C4Q003Pd;00d<
2P0B4@l040l=01HE4`0C4Q002`X8014@3P0<30X05aLE00/;2@0?3`d05ADC010?3@0:2PP04A0>01LF
500E518030`:028S800I6QH03@d:014B3P0=3@X0=cLd028S7`0C4a003@d:014B3P0<30T051@A010@
300=30P04A0<01<B3P0=30P03`h:014@300I61@08R4M01<B3P0=30P051<?00<03`h:00H04Q4=01@C
3`0@3`/040l;018A3@0C4Ph200l>2P0801<B3P18B4D08b<P010@300E5A404Q8>010@3@0B4Pl2018B
3P0M014A3P0B4Ph04a8?01<?3@0D3`h04Pl=014@3@0@3``03`l<00/;200F5A804Q4>018@3@0A3@/0
50l=00l<2P0H5a@02@T8014?3@0C4Q4020L7010=3`0<2`X03Pd;01<@3`0?3@X051@?00h?2@0@4@`0
0P0C50h09P0B4Ph03a0<01HF4`0D514020P6010@3P0<30X04Q8@018A3`0D4a405A@B014@3P0C4a40
8B4O03Lg=@0B4a40:R/Y01dN700=3P/05ALC01@F4@0K7AP0F5YE01XK5`0>3``0:b`X018C400D5A80
;Rl^02LX9`0E5Q<03a0<01@E400?40/04Q<>01DF4@0@4@`051D@0P0C50l0100F5a804a@?018C3P0B
4`h201@F40804aD?0P0B50h201@F400I01HH4P0E5a405ALA01DH4`0=4Pl03aDB01DH5P0E5aD04Q@A
01PI5`0M71X07adK01PE4`0P7Q/08QlM01HF4`0D6AD05AXF01HK5`0E6QH05Q/G01LL600E6QH051TE
01DJ5P0201@I5@0@01HK600D6AL051TG01dR8P0G6ad04aLI01XN800H7Al09BX/02hc<P0L8B00724N
01PM6P0G71X0724P01lT9080724S07L06b0S03Ll?P0U;2`0620M024Y9@0O9b807RHP01`W800O:280
6R@M028/9P0R;2P08B/Y028];00R:bd08B``02@^=00T;SD08Rh`02<b<00W>3@0:CTd02Li<`0X>S80
9cX`02Xl<`0/?cL0:chh02/o>@0_@T00<4=403=6B00aADP0>4]?03]>DP0[?d@0;T1503U=DP0jCU80
>4]?03iAEP0iC5D0BE]Z04AGIP1:G6P0B5aU03mBF011EUL0@EIE03iCD@15FUT0@EIF03mDE@11EUL0
B65O04aSI01=HfP0CF=Z059WL01GK7L0E6Mb05IYL`1GJg40Ef]_05U]KP1KL6l0GG5c061cMP1jSI00
Kh:405a/L01RLg@0HgAe06imO`1WMWP0KGal07N3Q@1cPH80MHF707R9R`1iRX`0O8^>082>T@22T9<0
QY>F08NCU`27U9L0SINK096KX02DWZ<0U9jT09JOYP2HXJP0W:B/0::W/@2TZK<0YZVd0:n__02b/l00
][K30;Rha@2k^/L0`Ko=0<O2d@3:`m<0c/GF0=?8g@3GbN00f/_S0=k>i`3Sdnd0i]K`0>WHm03]foD0
l]of0?GRnP3fhoX0mnGk0?_YoP020?k/oP060?o]o`3ol?h0oo7n0?oaoP3olOl0o_;o1@3ol?l07`3o
kol0o^ko0?k]o`3mjoh0o>[m0?gYoP3ki_h0n^Gn0?[So@3hh?`0m]kj0?GMn@3bfoH0kmWd0>_Hl03X
eNh0i=;X0=c<gP3Ocn00flcL0=74d`3>`]00cl?@0<k4c`3:`</0a;c70<6la02o^/80^;Fl0:NWY`2U
Yj<00P2LWYX0BP2LWYT0Vj2J08^BRP23RX80MGac07=mL`1dOW@0N89h07N1N@1dOWL0MX5j079nMP1c
OgL0Mh=m07N4OP1fQH00KGaj06EdM01[NW/0Jg]l06IiN01ZOg`0IGUd05Y^J@1EJV<0C65I049EC`1J
KVP0UJRU05QZJ00mCTh0;3`j02Xf;`0hAC`0:cL_02/h<P0^>cL0<Sln030o?@0_?C`09C<b02Lg<`0R
<Rd09SLa020_:P0]>cH0:cTd030n>@0Y=c809C8_02dj=`0`?S/0;S`i02dj>00]>cT0;3Pg05QTH00c
?CT0=D4m02/f<P0S;BX0:CDa02Ha;@0U;b`09S8^02Pc;`0U;b/082XV02</9P0^=S00:S8/02<[9@0M
9Al082PR0P0N9R007@0R:R@07bLQ02<[9@0L9b<0<3m2014O8P0M;2d08Bl_034l>`0Q:bT0<c`i02@Z
9`0Q9b@07B4N01dP7P0P9B406R4L01/Q700L8Qd07B<N01dS7@0K8A`06AhI01dP700L7a/04QDA01`P
6`0I71X061/J00805aXI00@06QdL01TL6`0E61L05APG0P0F6AP201DH5`0I018F5@0G6aX08RDT03`o
?P0I71/05aXI01`N7@0?410061TH04M8A`0T9BD06a/K02XY:00D4a4071/I01HE4`0E51805QDC01<B
400=30X04a8@01@C4@0F5A<051<A01TF5@02014?3@803P`:01/04a0?01XH5P0@3P`05A8A010>300H
5A@08R0N02HT8@0I5Q@04@h<01<@3P0@3P/04a0>01PF4`0Y9b@04Pl=01LD4P0=2PP040d:00P40P0F
4Q004Ph<01dI5`091@<04Ph=00h:2@0A3@`00P0@30`0500B3Ph040`<014=300>2PT04Ph=01<?3P0A
3@`0510?01HB4@0B3Pd0510?01HB4@0<20L05a<B02LS8P0H51<03@T800H20@0C3`h02`L70P0>2PT0
4@0;1`H04@d<010<2`0A3@`04Ph;00d:1`0B3``071LD01PE4@0;2@D040`9014=2P0B3``04Pl;018=
2P0A3@X03PX600804@`900H03`/8010;2@0A30/06aHE01HA3`0C3Pd2014<300>00l:2P0C3@`04@/:
014<2@0C3P/04Pd:018=200C3PX050l;00l:200K5Q<03PT701D@3P0?2PP200d81P803`T800h03PT7
01LA400E3`h040X9018<2`0?2PP03`T70109200D2PX040P8014:2@0C2@T04PT900d61@804@P80380
2`@300l61P0@2@T05Q0@018<300=1`L04`d=00l92@0=1`L03PP800l92@0@2PX03`T900h8200?20P0
50`=01<92P0A20T040P900h41@0@1`P040P901482@0B2@X040P901482@0?1PL05@h>00l71`0M51D0
2P<401<;2`0?1PL03`P801482@0?1PL03PL701D<3@0A20T040P901892P0D2P/04P/;00l61`0C2@X0
3`L800d51@0A1`P04PX;01061`H04@L800X04PP900`3100B20T040H700h41@0C2@X04PP901061`0E
2``04PP90P0@1PL04P0D2P/03P@500d3100A1`P04PP90147200@1PH04@L701061P0>10@03`D50106
1P0G3@d03`D501D;2`0@1PH04@L700l51ACooooo000Kooooo`0901HD6@0D4QL05A<H01LE6P081P/0
4a4F010>4`0A3a@02PP=00804Q0E00T02`T<00d;300A3a005A<D00800@0@3Pl06ALH00h<3@0?3@h0
0P0@3Pl0400?3@h03P`=00d=400>3A804A0E00l>4`081``05QDJ00X93P0H5a`040lD00/:3`0>3A80
820R014=3@0A3@`2018>3@05014=300@30/03PX900h:2@0@30/00P0E4A002P0D40l020L5014@3P0C
4Q001@@3010?3@0W9R@04Q4?010?3@0>3@/2018A3`0300l>300@3`d040l=008040l=00D04A0>00d<
2P0J6AL04Q4?00D40P0200X91`0I018A3`0C4Q004a8@014@3P0C4Q003@`:014@3P0@3`d02`X8014@
3P0?3P`02PT7010?3@0@40h01PH400l?3@0[:bT0X:2N07EeL`0C4a40410>018B400=3@/02`/900/:
1`02014@3009010?2`0?3PX03`h:01@C3`0C4Ph040l;00h=2@0=30P02PT500803@`800<03`h:014@
300A40`00P0?3PX02`0C4Ph05aHB018A3@0@3`/04a8>01TJ5@0<3@P03a0;01<D3`0H6A@02``700H0
414<0P0>3@T01`0@3`/04A0<014@300A40`051<?01`K5`0@3`/00P0B4@d0500D4`l01`@001LC3`0M
6AH071PI018>400J5AT05A0D018=400A3@`04`l>018?2`0=30L04A4?01<C4@0D51804a<A010@3P0>
3P`0410>0P0?3`d05`0B4Q007AdK01TI5`0G4a805A8A01DD4P0C4Q0051@B024Q7`0j>SP03@l<01<E
4P0>40d04QLC014F4P0C4a<02PX:04i>CP0S8b<07QhL00d=2`0F5Q@051D@00804Q<>0P0B4`d01P0F
5a8051D@01DF4@0E5Q404a@?010A30804a@?0P0D5A000`0C50l04Q<>01<F3`0501<F3`0;01LJ4`0E
61405aXC01PK500G6Q<051TD01PQ7P1RJ6H06AhM01LK6P0S9B800P0H5aD01@0H514071DC01491`0B
20H06QLD00806b0L01L05a`H01@I5@0E6QH05Q/G018G4`0D6AD06AhJ01@I5@0B5a<05a`H01HL600D
6QP05Q`L01@I700D6Ad07B8V014F6P0K82<07R@T018H5P0S:BD06alN01dO7P0301`P7`0E01/Q8@0O
9BD082HV01hV:00K8bD06R8T01/S9@0L9b<072LQ03@o>00]>3007b/Q02@`9P0R;BD08bhV02@^;00U
;c009Bla02H`=00O;bl0838b008093Le03d09CPf02Xm>@0Z?CL0:Sdg02/o=P0/@3D0;D4f02i2>00d
B4L0;T=40315AP0hCE00>DiB02a1AP0dB4l0>dmH0396D@15FF@0@EEQ04MJJ`1CIGd0DF9j04ePL@16
FVD0?55E03]ACP0lDdd0@EQA03mEDP11EeD0AU]M04AIFP1?J6D0CfIS04iSI01@IFP0EFQ`05U[M@1U
Mh<0EFM`05Y[LP1PLGP0FVa_05AVJ01OLG40GW1`061bLP1TMWH0IWIf06EeM@1[Ng/0JGMh06mmOP1d
PX<0NHB607J1Q@1fQ8X0O8VA07f:TP1lRI40PXbE0080QY2I02T0RY>L08fFW`2@VJ80TY^T09>LY@2I
XZT0UYnV09jW[P2QZ;80XJF`0:NY]@2/ZkT0]K;30;Vfa`2m^LX0_[[;0;nkc034`]00bLGD0<g6eP3B
amX0fL[Q0=k;i@3QcNP0hlo[0>WDlP3/eoH0kM[h0?7Nn@3ehOX0mn?l0?[Wo@3ljoh0oNcn0?g^oP3m
ko`0oO3j0?kbn`3om?`0ooCj0?oeo0020?oeo@030?odo@3olod0oo7n0080oo7n0P3okol0;P3okOd0
o^cl0?k/oP3kj_d0nNKl0?[SoP3jhOh0nMkm0?OLn`3ef_T0lMWe0>kGl@3Zend0iMCV0=c9g03OcMd0
fLSH0<focP3<_/d0bko;0<k4c`3:`</0`;S30;^e_`2h/[`0/k6h0:FUX`2OXI`0W9jI09fOVP2NX9/0
WjBM08V@R031b<00[;BY06QbI`1/MV/0NXAj07n:Q01aO7P0MH1l07Z6PP1oRhL0NhN506mnN`1bPGh2
06alN`0c07F5Q01YO7X0HGIa05acK01TNgD0G75/05=XH`17G5L0?e9@04QKF@1HJfT0?4a;02dm?@0b
@C`0=dDh038n<@0L:1h09c8Z02hj=`0lB4P0<Cdm01HT8`0N;BP0:STd01l`9`0`@CT0>4I602Pf=`0c
@D80>TQ802<a<@0e@d<0;Sdj02dl>@0`?c`0;C`g02Xi=00e@Cd0>48o020Y9P0`>CH0:S<`01hW900L
9B8092dZ024Z9`0S;2T09Bh[02@]:P0O:2D08bXT0080VZ6J02X09bhW02/b:`0/<b`08bXS020W800O
9Ql082LP01lV7`0L9b<0YkNk04AFF00L;2`03ahM01dY9`0T;b/07bPS01HL600O9B408B<R01`N7@0R
9RD072@N018L500@61407RDN01lV7`0H7QL06AhH020R7@0S9B00828M02<U800M81h0720O01XN7@0L
81l082@S01/O7P0D61L05QXI01LK6P0F6QT201<G5P0F018F5@0A5A@0310?01DI600<40l04aLF04mC
DP0C5aH06AdL02@X9`0D61L06AdL00`=2`0B4@l08b8P014@3P061@<04Q4?01@C4@0B4@l03`h<014@
3P804Q4?00@01P8101HB4@0G4a803PX90P0H51<0800300004@d<01/G5P0300005A4@01LC4P0E4@h0
40`9018>2`0F4Pl0510=01<?300:1P<05Q8?01/G500@30T04Ph;01<?300P71/00`0001DA400B3Pd0
61@C01@@3`0F4Q405a<B00l;2P0=2@P03`/:00`81`0A3@`03PX90P0A3@`05@0>2PT04@d<00d9200E
4A00100001LC4P0J5QD04`l>024M700<20L00`0001/G5P0@30/05Q8A00`81`0@30/030P7010<2`0=
2@P04@d<00`;1`0200d<200700`;1`0>3@T040l;018A3@0@3`/03Pd900d<200200`;1`03018>2`0D
40d04`l<00804Ph;00@0510=01<?300A3@X03`/80`0>2PL0100A2`d040X:010;200?2PL200l:1004
00X5000L5a<06A@@02lY:@802P@601P04@/;00`61P0;1@D02`D500T30`080P8040X:01<=3@0;1@D0
3`T900`61P0=1`L03PP800`61P0D3Ph040X:00/51@0B30`0208200`61P0?2@T02@<300h8200=1`L2
00h8200300X4100;1@D03PP800803PP80`0@2PX01@0>20P040P901882@0B20T04@L8008040H700@0
4@L801882@0B20T04`T:0P0B20T03P0F3@h0AClo01LA4@0E3`l03@L700d8200=1`L03`T9010:2P0;
1@D030H601<=3@0@1PL04@L80P0B20T20147200400T0000?1@H050X;01882@8040H71P0A1`P01P0C
2@X040H701061`0=0`@05`d>01<92P8050X;00D04`T:0147200A1`P040H700T0000201@:2`0500T0
000?1`L0:b4R01061@0?1@@00P0>10<0200?1@@040H501H<2`0;0P804@L601881`0:0P4050X95?oo
ool001_ooooo00X02`T<010>4@0<2Pd0518E00d;3P0M6ah030X=01hL7`0Q7b8040hA0P0>30l0200;
2@X02@L800l=3P0<2P/03P`=00T7200>30d03`d>0P0@3Pl0400?3@h03P`=00X:300E5AL020P:00d=
3`0@41802PX<01/K7@1[Jfd02@T;010@4P0<30h00002014=3@0A3@`2018>3@0C014=300@30/03`/:
00l;2P0A3@`05A4@01HB4@0E4A006QTG01<B400J6AL05QDC03hm>`1`Kfd04Q4?014@3P0?3P`04Q4?
01<B400200l>30803Pd;02403`h<010?3@0@3`d03`h<00d<2P0B4@l06APF01LF500@3`d06QTG014@
3P0?3P`06QTG00d<2P0>3@/03`h<00h=2`0A40h03`h<018A3`0F5A<071`J014A3`0>3P`0000002LW
9@0L71X00`<100L71@0C4a403`l=01DE4`0D51400P0A40`00`0@3`/03`h:00l>2P02010?2`0400`;
1`0D4`l07QdI01DD40804A0<00h040l;00l>2P0?3PX03Pd900l>2P0D4`l061LC01@C3`0@3`/03`h:
00H70P0>3`X061TD00/<1`805QLB1P0@4@`200l>2P8040l;00D03`h:00h=2@0C4Ph05QDA00/:1P02
010?2`0=01<B3P0S8Qd03`h:01DD400D4Q<030X<00d;3P0@3Q403`d?00l>300<2`T05QD@00h=2002
01DE4`0T01<C4@0B4Q00410>00l?3@0A4@l030`:01LG5@0E5A<09bLU01`L6P0H51<04Pl>01@C4@0F
5A<04a8@014A3`0;2`T05QPE010B3`0;3@X041DA00@91@0A4A403`l?01DE5@0B4Q80820N00D50`0E
5A<04a@?018C3P0A4Pd04A8<018C3@0G61<05AHA0P0F5a80100D5A004A8=018C3P0D5A0201DF4@03
018C3P0A4Pd04A<>00D04A<>03/05QPC01@F4@0E5a805aTD01DG4P0A5Q4041TF06idLP0G71X07R8Q
02HX9@0D51806APF01XF4`0S7Q/07QTF02@L6@0Z9b@04aPD01TN6P0D6AD05Q/G01dR7P0G71P05AXF
01TN6P0N8al06AhJ01HK5`0G71P05adI01HL6P0G71d07B8U01`Q9@0K82@05Q/O01@I700H7Qh06R0N
01lU8@0P92<07b<R01`P7`0J7Qd06alN01dS8`0O9BD082HV01lW:@0J92D06B<T01/U9P0S;B`06RDO
03@o>00b?CD072LO024]8`0202Lb:P0502Lb;`0W<C809c4c02La=@0T=3@00P0R=3@00`0R=C<09CPf
02`o>`0202`o>@0f02a0=`0[?cH0:clf02/o=@0gBdX0;4520397B00gC4l0=DY>03Y?E00nDUT0@UIO
049FH@1XO8L0AeYW041CI01@HWX0EfV004ePL@17FfH0AEYN03Y@C@0lDdd0@EMC041FD`14FUP0CF9T
04iSIP1@JFH0D6QU055VI`1BIfX0EVYa05U[M@1MKgT0DF=/05UZL@1NKgH0F6Y]05IXJP1SMGD0Gg5a
05i`L01SMGD0J7Qh06UiN@1[Ng/0I79c07:0P@1_OGh0LGan07AoP`1iQXd0OX^C0P1oS9@09024SYL0
R9:K08NAVP2?V:40TibU09NNZ02EW:H0U9^U09BMY02EW:@0WjJ^0:FY]02TY[80ZJ^g0:n^_02h]LH0
_;W:0;nkc033_<h0`[k?0<K4dP3;amH0clSH0=C9g03Jbn80hm3Y0>KBk@3Xe>l0jmOc0>oKm`3`gOT0
mN7m0?STo@3hi_h0nnWo0?k]o`80o_3o00H0o_3m0?gan`3olo`0ooGm0?ofn`3omod20?ofoP1D0?oe
oP3om?h0oo?m0?ocoP3ol_l0oo7n0?o_oP3ok_h0ongm0?k]oP3kj_d0n^Om0?_To`3kh_l0n]on0?OL
n`3ef_T0lMWf0>oHlP3[f>h0iMCV0>3=h03Td^80gLcL0<k0c@3=_l`0cl??0<o5d03:`</0`;W10;Vd
^`2f/KP0/:jd0::RX02JW9L0Wj:K0::UWP2IW9D0XJJO08jES@32bL40YjnT06UcJ01dOW<0N89h07N2
O01fPGd0NhJ2075mN@1ePGd0MH5o06YiMP1_OW/0KWim0761P01dQ8@0IWQh05mcL@1OMG40HWQe05Y^
K01CIV<0?E1<04=FDP1@HEh0BEUF04iNF`0b@T00?di9049>@P0_>Rd082XQ02dg;`0_>CL0=T9002/g
=`0X=3<07bhY02<b;@0Y>C009SD^02hl?00/>S/0<Cm00P0gADD0<P0e@d<0@4m<02`k=`0Z>C@0;3/f
02dl=`0mBDD09S0]02Xc<00X<Bh07RLT02</:@0O:2D08R/X01dV8`0O:2D08b`Y02D^:`0R:bP0:Bl[
04mED@17CDT08bTU01lU8@0W;BT092XV01`R7P0K8Ad08BLS028X900M:2@0HW9f0391A00R<S807B/Z
01TU8`0E81`06R<N01dS7`0Q9b<0828Q01`M7`0M8B006R4M01<L5`0S:RH05adI01DK5`0H7AT051TE
0P0O8Ah201XL6@0601@F500H6QT06Q`K01hP7`0T9RD0828Q0`0I6aX06@0F61L04Q@C01<E500I6aX0
4aDD01`N7@0A4a806Q`K01lQ801gNGP05QPG018D4`0>40l030h=024S8P0I6QT040l=01@C4@0C4Q00
4A0>01PG5@0B4@l04A0>00l>300@3`d00P0A40h02P0L61L0510?00h:2@0I5A@03`/:00L30P0X92<0
AT91044m?00A3@`200l;2P0J018>2`0@30T0510=01@@3@0A3@X0510=010<2@0:1P<05a<@00/7100?
2`P061@A01`H5`0D40l03`/:00@0000A3@`03@T801/G5P0I5A@040`;00d9200>2PT02`L600l;2P0B
3Pd200l;2P0A014=300?2`X03@T8018>3@091@@03PX900H20P0=2@P0510?00h:2@0M6AP03`/:00H2
0P0F4Q404@d<01DA400B3Pd00P0@30/01`0D40l030/7010?2`0>3@T02PT500/:1P0B4@d00P0>3@T0
1@0?3PX04Q4=01@C3`0E51004`l<00<04Ph;00`03PX700/7100@30T030P500T50P0:1P<03@T600h:
1`0@2P`04@/;014<2@0@2`L200h90`0T00d80P0H4`l02PD101dG5`0<1PP03@L9014;2`0=1`L030H6
00d71`0<1PH02P@400d71`0@2PX02`D5010:2P0<1PH040X:00l92@0;1@D04@/;00T30`04000040X:
00T30`0=1`L03`T900/51@0?2@T030H600d71`0>20P030H600L10@090`<03PP80P0?2@T01@0@2PX0
3`T900l92@0@20T04PP900<04@L800<040H70147200A1`P00`0B20T03`0A1`P04PT:03hh>00E3`l0
3`T9014;2`0>2@T03`T9014;2`0B30`03@L700/51@0?2@T040H70147200201882@804@L800H050X;
01<92P0@1PL03P@501061`0F30d60147200600d3100C2@X03`D601882@0^92D08QPI0P0D2P/0300C
2@X04@L801061`0?1@H02@0001<92P0@1PL03@<403dc=024NW/040H500l510803P@300P03`D40106
1@0C2@P03`D4034W9P0_9B@0308201881aCooooo000Kooooo`0D024O8P0?3A005A<F00H41`0E4aH0
30X=00l=400D4aD07adP00d;3P0A3a803@/>01@B4`0@3Pl02`T:01LE5P0@3Pl0518C00h<3@0?3@h2
010>3`0@00l=3P0>30d0410B01lO8@1]KFl0=cLi00l?4@0A4A<07QhP06m_L@0T92H03@d?00/;3@0C
4a<04@d=014=30804Ph=01H04@d<010<2`0H51<0510?018>3@0C3`h04@d<00l;2P0C4Q0030/9018A
3`0@3`d03Pd;01DD4P0B4@l04a8@010?3@0B4@l04a8@01@C4@0F5A<04a8@0P0@3`d02`0A40h05A@B
00`;2@0C4Q0061LE00X91`0=30X04Q4?00`;2@0=30X04a8@00803@`:01<04A0>01LF500O7Q`05QDC
00X91`0J6AL071`J01TI5`092@L030`:014A3`0D51803Ph<010@3P0B4Q003Ph<01LG5@0J6QP03`l<
00804A0<00X040l;00l>2P0?3PX02`X6014@300>3@T04Q4=024P700I61@04A0<0P0B4@d03`0@3`/0
3`h:01<B3P0@3`/04Q4=01@C3`0B4@d04A0<018A3@0B4`h02@X5010A300A4Pd05QLB010A300600l@
2`804Q4=03D04a8>018A3@0@3`/03Pd900d<200B4@d03Pd901@C3`0A40`051<?00/;1P0@4@`04a@?
03@c=018B4X051@F01LF6@0?3a005AHC010?3@0@40/0414;01@D4P0B4Q00410>00l?3@0A4@l04Q8@
01DE4`0@40h02`/9014A3`0H61H04Q8@01DA400C4@l04Q4?01@C4@0B4@l03`l=010@3P0H6QL02@/9
014C400E6QH03a@@01PH600=3@d051@D00l?3`0B4Q005ADC014A3`02014B3@0?01<D3`0D5@l05AH@
01<D3`0B4`h051D@01LH4`0F5a8051D@01DF4@0C50l04Q<>01<D3`0D5A005AHA00H051HA01/05ALB
01<E400D5Q405ALB01@F4@0E6aL02a<@01LM6`0E6QP06AdL01HH5@0O81h0CTi<04E3?`0O71T08alL
01`E4P0T8al05a`H01DJ5P0L8Ad061dI01TN6P0F6aL051TE01DJ5P0H7AT00P0E6QH0300F6aL05adI
01DK6@0F71`08bP[020U:@0D6Ad07B8V01/P8`0J82007B<Q01HL60<07B4P01H07B8Q01lT8P0P9RH0
6R8Q01/T8`0M9RL072HW01dW:00P:R`08bh/01HR7P0P;2H08RhW020/8`0Q;B@0:cL_02Xf<00Z=C<0
:C@d02Pc=@0W<cH0:CTi0P0W>CT02P0Y?3X0:chl02i1?P0Z?CT0:chi02`o>@0/@3P0;D0i02e1>P0_
@d8203I;C00R03Q=D011EUX0@eQM049FG@0mDEX0@eMR05AXL`1IK7T0A5MV04=EJ`19Fg40CV5a04iR
K@1?HfP0D6IT045GE015FeL0A5YH04MLG@1BIf/0E6U/051YI`1CJFT0EFY]05I[L01HK780FFad05Q[
L`1dQXh0IgQo05EWJ`1IJfh0Gg5c061bLP80Gg5a0180HgEe06IfMP1VMWH0IgMg075oP01bP840NHN8
082;S@22SI40OhbB08BAV025TYT0QI6H08ZEW02>VJ00SYNO09BLY02GWjP209^RZ`0U09ZQZP2V[[D0
][_40:^`^@2Y[;L0[Znk0:VZ]P2d//00^kS90;jkc033_Ll0a[oA0<S1d`3:amD0d<[J0=?<g03Ic>00
g/oU0>ODk@3[eo40jmOb0>kJm@3bg_T0m>7l0?SUoP3jj?d0nnWn0?g]o`3nl?l0oo7o0?oco`3olod0
ooCn0?ogo`3on?h0ooWn0?oio`020?oho`040?ogo`3om_l0ooGo0?oeo`80oo?o0300oo7o0?o_oP3o
kol0onko0?g/o`3kj?h0o>Kn0?cSo`3kh?l0nMkm0?KKnP3bf_D0l=Wc0>_HkP3VeNL0iM;U0>SFiP3P
cmh0cl7>0<k0c@3AaM00bl7;0<Vob032^l<0^kJl0;B_]@2WYZX0V9RE09ZMU@2PXi/0WZ6I09NJTP2:
ShL0PhZ107j5O01YLFH0IW1U06UcJ01iPgT0NhJ007n:QP1iQ800PHf90::^ZP28U980K7]h06imNP1/
O7/206emO00g065cL`1TN7L0H7Ec05M/JP1>HV00Cf9O03]>BP18FUD0Cf1K04AECP15EE40:c/e030n
=P0h@cX0;SH/03<k<`0f?ST0;SDb02/d<P0L9RH092l]02Xf<P0U<2`0;c`f02lm=`0/>ST0<d5203e;
B`10CTh0>4M602ln?015E540;Sdi02He<00U=2l0;C`g04aHD`0]=c<0:c@a02L`;@0O:2D0:34^02L`
;@0^=c@092dZ028[:00S;2T092dZ024Z9`0L8Qh07R@P02<Y9@0R:2@09R`X01lU8@0201hT800j01lU
8@0R:2@09R`X02D^:`0V=3P03ahQ01l^;`0P;B`062<O02D`:`0S;2L07bDQ01TO6`0O8R8092DX020T
9@0G7a/08R/V01DM600C6AD06R0L01TN6P0H7AT08B<P01dO700K7AX07R0M01`N700S9B@0828Q01`N
7@0N81l06adL01PJ6@0I6aX061XI01HH5`0E5aH05aTH01DG5P0C5A@04Q@C01PJ6@0B51<04A<B034c
<P0F61L071hM01@F5@0N81l02`d<02DU900U92805aHD01TH5P0<2`T05QDC01<B40804Q4?0P0C4Q00
2`0B4@l03`/:01LC4P0B3Pd04@d<010=300F4Q4081`K01TE500D40l05A4@00804`l>0180510=014=
2P0?2`P03PX701<?300X9240EU9?01PD4@0B3P`0510=00h:1`0B3P/05a<B07EaL00M6AP05A4@00/7
1P0F4Q4201@@3`0?00h:2@0=2@P04Ph=014=300>2PT05A4@010<2`0A3@`06ADD01<?3P0@30/04@d=
010<2`0P71/0A40o00804Ph=01<05a<B069NG@0F4Q404`l?00T61@0D40l03PX9010<2`0:1PD04Ph=
014=300B4@d040l;00d<200<2`L03@`800h=2@0D4`l04a8>00804Q4=0P0C4Ph01`0B3P/04@d:01<?
300F4@h040`900/7100?2PL00P0>2@H01`0?2PL03`/8010<2@0>20X03`T900l:1`0?2PH00P0=2080
100A30H05A0<00L30@0=1`L200l92`0600l92@0=1`L040X:01H@400H4Q806A<C0P0>20P05@0=1`L0
4@/;00T30`0@2PX05Q0@00l92@0=1`L050h>00h8200@2PX03@L701@>3P0H4Q805@l?01<=3@0?2@T0
3PP800d71`0A2`/03PP800d71`0600l92@0301082@0A1`P04@L800D04@L80`0B20T03`0A1`P03`H7
01<=3@0;1@D04`d=00H10@0A2`/03PP8010:2P0B30`040X:00h8200=1`L040H70147200201882@80
4@L800H0CTA503D[;00E2``040H701882@0A1`P801061`040147200?1@H081HG01X@4@8040H70P0A
1`P0200B20T04`T:01061`0?1@H04PP9018:2P0A1`P050X;1P0?1@@01P0>10<04@P702@J6@0S6AP0
3`H500l511Cooooo000Kooooo`0=01HD5`0<2Pd030X=01PF6@0B41<0OWao02LU:00;2@`0108500H4
1`0@3Q403P`?00/92P0200h<3@0502XX:@0<2P/01`D600h<3@0?3@h00P0@3Pl03P0?3@h03P`=00/;
3@0k>cd0b/[<06i^L00>3Q001@D700X:300;2`d04A4C00X:300B4Q@07adN0P0A3@`2018>3@05014=
300@30/05Q8A014=300@30/00P0B3Pd02@0A3@`02@P701`K6@0F5A<05A@B01<B40061@<040l=01<B
400200l>3005014@3P0C4Q0051<A014@3P0>3@/00P0=30X07`0:2@L04A0>01<B400A40h06aXH01@C
4@0;2PP00@0001dL6P0g=S@04Q4?00d<2P0D4a404Q4?010?3@0A40h03@`:00l>300=3@/06a/I01lO
7@0G5aD04A4?00l?3@0E5A<05QHD014A3`0J6QP0CDe;04U9A`0H61D00P0A40`0400@3`/03`h:00l>
2P0<2`L04Q4=010?2`0:2@D03`h:00d<200<2`L03`h:014@300>3@T03@`8018A3@0A40`3010?2`08
018A3@0E51003a0;014B3@0B4`h07AhI03Lh<`0E5Q46010A300400h=2@0?3PX04Q4=01@C3`805QDA
01@040l;01DD400C4Ph05A@@00d<200E5Q406A`E014C3@0?4@`0FE]J08B6QP0@4A<0000200/=3@0C
5A806adJ00X=1`0<3`P0410>00l?3@803Ph<01h04A4?01<C4@0D518051@B00<30@0?3`d03Ph<018B
400@30/05A<A014@3P0?3P`04Q8@01@D4P0B4Q002P`900T;200N81d02a0<00`A3@0E5AD02@T900l?
3`0I6AT03@d;00l?3@0D51804Q<>014B3@0@4@`2010A2`0<01DF4@0C50l04a@?01@E400A4Pd03a0;
01DF4@0B4`h0414<014B3@0D5A005QLB1P0C5A00L@0E5a804aD@01@F4@0E5a8051HA010E4P0I7ad0
4QPF01TN7@0830/08bDR00h?3@0T92809B@P01XH500O6aP071TD02HV8P0M8Qh03Q<?01dR7P0K81`0
41DA01`Q7@0H7AT05Q/G01LL600D6AD05Q/G01/P700J81`05adK01DK6`0I7R405a`P01<H700K82@0
7b@W01LM7@0B61H05A/G01PL6`0I7A`07B4P01lU8`0P9R@08BLW01`U900N9bH07RPY01`V9`0K9BH0
7BLY01LS8`0L:2H09S8_01PT800J9b00934Y02Xg<00Y=Rl0:CDa02Pd=00W<c<09S<e02Lg=`0U=cL0
:3Xj02`o?@0]@3h0:Sdk02Pk>@0Y?3P0;3lk02m2?P0aA3h0<TI202e3@@0oE5D0=T]<03A9C010EET0
=T]@04EIH00oDe`0@eMR02m3CP1EJGD0@5=R04UKL@16F6d0CV5`04eQK017Ff00CfAU04EKF@18GU`0
AeaM04UNH@1AIVX0DFI[04mWJ@1CJF`0Efa_05Q]LP1IKG<0F6]b05]^M@1aPhT0FV]b051RIP1MKg80
DF=U0080GFm_03@0Gg5a06=eM@1TM7@0Hg=c07N7Q`1jR8T0NHN80:Jd]@2U/;80TIbN07n<TP24TIL0
QI:H08JAU`2:UI/0SYVO08nHW`2AV:00TiZR09NNYP2KXZX0W:>[0:R_]`30a<d0[;2i0:Z/^02h^<@0
/;2l0;Rfa02n^//0`Kg>0<Jod@39`]@0c<GG0=39f@3DcMd0elkO0=g?h`3SdNL0jMK]0>cHl@3]fO80
lMgh0?GQo03fi?h0n^Sn0?[/o@3kk?l0oNoo0?kbo`3olol0ooCo0P3omol01@3onOl0oo_o0?oko`3o
nol0oo[o0080ooWo00@0ooSo0?ogo`3om_l0ooGo0P3olol0;P3olOh0onoo0?o_o`3mk?l0o>Wo0?gW
o`3mi?l0o>7o0?WNo@3fg?T0l][f0?3Jl@3/fNd0i]GW0>;@h03SdN40f/[G0<k0c@3?`/`0cL7;0<Nm
aP36_<@0`K_00;Ze^`2b[K40Xj:R09NHTP2PXiX0WZ6H09RKTP2IW9<0PHMm07R0M@1eOG80J71U06af
J`1_NFh0NH=i07n:Q022SHT0Mh9n08NCS`2`_;P0T9bJ07F4P@1bPGh206alN`1P06YjNP1RM7@0HWAf
05]_L01CIfH0BEeL04mRG`19G5P0EVMQ055RFP1:Fe<0>4Pn03E5>`0f@cT0;cH^02T_9P0_=2d09b`V
02X`;@0[<Bl0?TA4028[:@0S;RX09S4]045<A`0e@3`0<Cdk04=AD@0_?Cd0=dE50391?`0d@d00:cXg
02dl=`0/>cH09SD`02He;`0d@CX082XV01TR7`0U;R/092dZ02D^:`0T;BX0=Chk02Tb;`0U;R/08R/X
01lX9@0K92408RPT01@J5P0M8al08bTU02dc;`0P9R808BLS02D[9`0T:RH07bDQ024W8`0R:bX062@W
01`Z:`0M:BT08Rh[01dX900I91h072DP01/Q7@0K8Al08bLX02@U:@0L824072@P01`U800c>SH092XV
01HL600D6QH04aPD01PJ5`0G6AH08bDR02X/:@0P8R008R@S01hP7`0G6AP06Q`K01`N7@0I6aX061XI
01TK6P0H6QT05aTH0P0I6aX04P0P8R402`d<01TK6P0C5A@08bDT014C4P092`X092HU01@F5@0F61L0
4aDD06a/J`2?SX`0:RTW01<B400G5Q@0<C0^014@3P8040l=0P0B4@l03@0?3P`05a<B00X61@0A3@`0
6aLF02HR8@0I5A@061@C020L6`0>2PT01`<201DA400C3`h00P0A3@X0@P0C3``04@d:010<2@0L61D0
;2PU01LC400D40d03PX701DA3P0C3``0:BDT01lK6P0E4A001000010<2`0;1`H04@d<01<?3P0>2PT0
3@T8010<2`0=2@P02`L600l;2P0>2PT040`;01DA400C3`h04@d<00d9200@30/081`K05MCDP091@@0
3PX9014=300J5QD0Ad=201LC4P0?2`X05A4@014=300L61L03PX901HB4@0?2`X03@`800X91@0<2`L0
4Q4=01@C3`0?3PX04Q4=010?2`0=30P02`X600X91@0<20D03`X7010;200B3@X050l<018=2P0@2`P0
3@P500l:1`8040/801803PT600d81@0<1PP030H600`7100>2@D03`X4010;1@0>2@<05a8>01<>2P0B
30`040X<00X41P0?2@T03@L700h8200C3@d201@>3P0B00`61P0;1@D03`T901H@400>20P03`T901PB
4P0F41003PP800l92@070@4020<300X4100B30`06A<C01hH600M5aL030H60P090`<0100;1@D04P`<
010:2P0>20P200l92@0500h8200?2@T03`T901082@0@1PL00`0A1`P00`0B20T04@L801061`030147
200401061`0@1`P040X:010:2P803@L700T040X:00d71`0>20P040X:014;2`0@2PX03`T901061`0A
1`P00P0B20T2014720801`0000@04`T:01H<3@0?1@H04`T:1P0?1@H01P0D2P/02P0101882@0;0@80
1`0000h41@803@<400H03`D60147200C2@X050X;01T?400>10D200T0000400/20P0A1`P03P@300l5
108040H500P03`D400h40`0<0P404PP700T0000<0P405P`;00d30QCooooo000Kooooo`0D00800@0A
3a004@l@01TG600F51D0SXb=02/Y:P0G5AH040h?01`J6`0H5QL0518C01`J6`0E4a@06QPI04a:B`0P
7Ql00`4200h<3@0?3@h2010>3`0>00l=3P0>30d040h?01HD5@0l>S/07A/L01@B4`0<2P/03@/<00l=
3P040P<04Q0A010>3`010002014=30804Ph=00H04@d<010<2`0C3`h03`/:00h:2@0B3Pd201<?3P0<
020O7@0S8R003@`:00L61@0D4a404A0>00h=2`0B4@l03Pd;00d<2P0@3`d03Pd;0P0=30X300`;2@0O
010?3@0F5A<02`X800/:20071P@020L501XI5`0>3@/07A`J03@c<@0I61H03@`:018A3`0:2@L020L5
014@3P0B4@l03`h<018A3`0?3P`030/900L6100?3P`040l=01<B400B4@l03@`:00T81P0T8b408B0N
00T81P02014@3005010?2`0?3PX03`h:00d<200>3@T00P0@3`/01`0B4@d04a8>00h=2@0C4Ph05QDA
014@300?3PX00P0A40`01@0@3`/04A0<018A3@0B4@d04A0<00803Pd900@02@P600L60P0O7QX03`h:
1P0A40`0100?3PX040l;018A3@0C4Ph201@C3`0B00h=2@0E51004Q4=018A3@0?3PX08B8M00<6000C
61802Pl900@81`0V:RX04ADF00D92P0P92@010T501@I5@0=4P`03a8;0P0B4Q02010@3P<04A4?01/0
51@B00`<2P0=3@/04A4?01@D4P0@30/05A<A014@3P0?3P`04Q4?00h>300H61H06adJ01lQ7P0e=c@0
4aPD018G4`0?3`l05QHF01<C4`0A4A403`l=01HF500D51804Q<>014B3@0@4@`00P0@4@/01P0F5a80
51D@01@E400E5Q404Q<>010A30H04a@?1P0A4a006`0E5a@04aDB01DG500F61D05ALD00dA3`0?5A<0
728P01DJ6@0<40l092HS01LH5P0H61H06AXE01`L5`0H5a<06APC01`M6@0Y;RX05AXF01<H500N8al0
41DA01lT800M8Qh06b0L01dR7P0201PM6@0<01`Q7@0H7QX05Q`J01LM7@0D6A`05AXN01LL800D6Ad0
8BHY024W9`0F71X05adI0`0J81h01P0K8Al07R@R01lX9`0L9B@07RLV01hX:@806bLW00L07BPZ030l
?00S;bd0930]01dY9@0K:2408RlX00809c@]02<09c<_02Lc<`0V<S809C8c02Li>@0U>CP09c/j02/o
?P0]@D00:Shm02Tm?00Z?S`0;40n02m3@@0aAT40=4Q603A:B00lDE80>4e>03I;CP0jCe<0=T]@049F
G@18G6D0Cf=^03eAG015FFD0>4]J04aNLP1>H7D0B5]Z04EHIP16FV40AU]N04=HF@0204QMGP0@04YO
HP1@IFX0CfAY04eUJ@1CJFh0Efaa05U^L`1HK780EfY`059UJ`1EIfh0Cf5U059TJ01MKg80FF]]061b
LP80GW1`00X0HWAd06IfMP1VMWH0JWYj06]iNP1cPH80Tj6R08ZEU`1iQ8H0PHbB0`27TYP0302<UI`0
SiRO092IX02CVZ80UIbT09^OZ02NXZ/0Wj>/0:2T[@2]/;T0ZJbe0:j^^P80^KO401P0_;S70<>lcP35
_]00bL3C0<k5f03@amX0dL[L0=O>h@3Kcn<0gm7U0>GCj@3[end0k]S_0>oLlP3dhOX0mnGm0?WWo`3k
jol0oNon0?g_o`3olol0ooCo0?oeo`3omol20?oho`030?oko`3ooOl0oogo0080oogo0680ooco0?ok
o`3on_l0ooWo0?oho`3omol0ooGo0?odo`3olol0oo7n0?o`o`3nkOl0oN[n0?kXo`3ni_l0o>;o0?WO
o03ggOX0l][f0?3Jl@3/fNd0imKX0>?Ah@3Rd=h0f/[G0=?6d03Dam40c/;;0<RnaP35_<40_[Rk0;Ja
]@2`[:d0Y:BR0:6RVP2QY9T0V9^@08b?Q028Rh00PhUo07b4N@1jPWL0KGEZ07V3NP1nR7l0NH=k07N2
O01mR8@0OXV5071lN01kQh<0NhN507>2O`1_OW/0K7ak06emO01YNGT0HWAd065cM@1MLG80Gg=b059T
I01=Ge`0CEeJ04QID`19FE80@E5703Y:?`0_?c@0;3T_02/b:P0Z;BH0:RlX020U7`0_=2l0:S0/02H/
:P0W;B/08R/X02H_;01PJFH0BEA@05EQG`22T900=dE503]:A`0fAD808S4^02Xi=00^?CP0:STb02Lf
;`0U=2d07R/T02H`;@0P:BH08R/X01hW90809c0]01`0;CHc02</:@0P:BH07RLT01/T8@0G81d07B<Q
024W9@0T:RP0;S@b01TO7@0Z<2h09B/Y028X9P0P9R@07bDS024W9@0Q:RT0:38e02D`<P0J92D07BPU
024Z9`0S;2L08BLS024W9@0S:BL08BDV0P0K7b80300M92<08R/X04aCD@0R:2H03aDC020U900N8R40
8R@S02<U900c=C@0>3Xi01lP7P805aLE00L05ADC01/K6@0N7Q`06QXH01TI5`0J6QP06ATG00805aLE
00<05QHD01PH5P0G5aD00P0>3P`03@0I6AL061PF01LG5@0G5aD0820N01DE4`0J6QP0RXV70:f/ZP0]
;2X05QDC01@C4@0G5Q@00P0A40h0400B4@l04a8@01<B400@3`d0100001/G5P0B3Ph061@C07UeM01B
CTd03PX9024M700C3`h03@T8010<2`0G4a8201DA3P0601PD4@0C3``030P500`81@0400002PH30P0?
2`P0400F4Pl0510=02/W9P0300005a<B014=300F4Q404`l>010<2`0D40l04@d<010<2`0A3@`030P7
010<2`0>2PT2014=300800l;2P0B3Pd040`;01<@3`0G4a803PX9010<2`0:1PD2014=2P0700<0000_
:bP02`L501LC400B3P/071PE02l[:00201HB3`803@T600D03`/8018>2`0D40d04`l<014=2P0300`8
1@0400l;200@30T04@d:00`710803PT600@03@P500h91P0?2PL040/81@0?2PL03@0>20X030H600`7
100?2PH050l901HA2`0A30H03PT5014<200=1`L04@/=010:300@2PX00P0=1`L02@0?2@T03PP800d7
1`0?2@T03PP801<=3@0J51@040X:018<300201<=3@0A00l92@0400003@L701`F5P0:10@03@L7010:
2P0J51@071HF00d71`0G4A406Q@D00`61P0?2@T040X:00d71`0@2PX00`0>20P01@0@2PX040P90106
1`0@1PL04@L800804PP900@04@L801061`0@1PL04@L80P0@1PL01P0=10D02`D5010:2P080P804`d=
018<30<03`T90P0@2PX00`0?2@T040H70147200201882@804@L800D050X;01T?400Y7b008QPI0106
1`0700l51P060147200900004`T:00l51P0<0P<05P`=0P0?1@H201061`804@L800P01`0000h41@0J
41406@l@01061`0=0`@03P@300l5108040H500P03`D400h40`0>10<05P`;01<9200J40l08ALF00h4
0aCooooo000Kooooo`0F010>3`0B414040h?018@4@0@3Pl05Q@E01XH6@0=2``04@l@02PV9`0Q7b00
40h?014?400>30d020L701/I6P0<2P/03`d>010>3`0?3@h03P`=00l=3P804@l@00<03P`=018@4@0?
3@h00P0A3a00200>30d03@/<01DC500;2@X03`d>00d;300>30d04Ph=0`0A3@`2018>3@0801DA400>
2PT03PX9010<2`0C3`h04Ph=00h=2`0F5A<3014@3P0=00D40P0?3P`04Q4?00l>300G5Q@08B0N018A
3`0;2PP06aXH01@C4@0?3P`040l=014@3P02018A3`0L01DD4P0<2`T0>STg055@CP0D4a403Pd;01<B
400B4@l03Pd;01<B400@3`d05aHD01DD4P0<2`T03`h<014@3P0?3P`051<A018A3`0?3P`03@`:01HE
4`0C4Q004Q4?014@3P0:2@L08B0N02PW90804Q4=00D04A0<010?2`0@3`/05A@@014@300200h=2@0;
00l>2P0D4`l04a8>01HE4@0H5a<06APD01XI5@0E510040l;00h=2@0C4Ph00P0A40`0200>3@T040l;
00d<200D4`l040l;00l>2P0C4Ph04A0<0P0@3`/00`0B4@d04a8>014@300201<B3P<051<?02404a8>
00h=2@0E51004Q4=01DD400D4`l09BHQ01<F3`0;40X051TC00`@3`0D61P041@E03Di>P1DF5P02@h:
00hC3`0>4`d03Q<<018B400F5Q@05ADC018B400A4@l030`:010@3P0A4@l04a<A00h>300C4a40410>
01@@3`0E4a400`0B4@l03P0<30X04a<A00h@3@0>40d04aDB00lD400B5a<051@D00h>3P0@410051@D
00/;2@0I6AL04Q8@0P0A4Pd00`0C50l04a@>01<D3P0201<D3`0601@E400H6A@06a`G01`M600B4`h0
4a@?0P0D5A0201<D3`0501DG500M7a`061XG03Pj=`0I6aP00P0C5A805`0B514061XG01LI5P0C5A80
61/I00lD4`0D6AL04AHD01PL6`0G6aL07B0M01TJ600G6A@05QLB01hN6P0Y:B@09bPT0497@`0]<Rh0
4aPD01dR7P0<4@d05Q/G00805a`H02/06QlK01TN6P0G71P05a`H01DK5`0E6aT05a`M01PM800L8BD0
8RL[01hS9`0G71l06AlO01@J600M8al07bDS01/Q7`0P9R@06b8P01LP7@0L9B@06b@S01`V9@0M:2P0
72PX01dY:@0P:bd0>4A602/h>00M:RX09C8`02<a;00X=S009C</02@b:`0W=3009c@d02Db<P0V<c@0
:cdm02Tm?00Z?Sh0;4100080:clo06<0:Shn02i2@P0`A4<0;d=30355A@0eBDT0>4e>03A9BP0kD540
?U=F03Y?D`0jCe@0?E5H045EGP11EF00?e=N045DH@1>HG00BEa^04ePL@16FFP0B5]Y04UMI@1:Gf@0
AU]O04MLG`17G600BEiS04eQI`1@IF/0CVEZ05E[L@1IKG<0FVme05IZL01IK740GG1e05Q[K`1LKW40
FVa_06=eN022U9H0HgEe061bLP1OLG40IGMg06emO@1_Ogl0NHV908BBT`2>W9d0SI^L08B?T@22SHl0
SYVM08RCV029U9T0S9JK08nGW@2BVZ00Ti^R09RNY@2JX:L0Wj>[0::V[P2SZ:l0[:nh0:b^]`2a/k`0
]KC00;Nd`P2l^LL0`kc<0<NodP3;`M@0clGH0=C8g03EbMd0e/_O0=[>hP3NdND0iMCZ0>[Gk@3_f_00
lmgc0?CQmP3ii_/0o>[o0?c[o`3mkol0o_?n0?odo`3omol0ooSo0?oio`3on_l0oo_o0?olo`3ooOl0
1@3oo_l01@3ooOl0ooco0?olo`3on_l0ooSo0080ooKo0140ooCo0?kcoP3olOl0onko0?k/o`3njOl0
o^Ko0?gSo`3lh_l0nMol0?CMmP3_fNh0j]O[0>CCi03Pc]h0g/cJ0=S8e@020=C7d@0D0<ZoaP37_/<0
`kZm0;Ze]02c[jd0[ZZX0:FUX02RXiX0VYj?08J9O@1/Kf<0JFeP08F;P02U[J80Ph^007InL`1lQWd0
MX1g07V3NP1lQh4207R3O`80LWij05H0M81n06akN01/NgP0K7ak06YjN@1/O7`0HG5a069dMP1QLgD0
Gg9d05=TI01:FeP0C5eG05=SG@12DTX0<T8g03Q7>P0T<bH0;3P/028W800V:280<S@^02db;00]<Rd0
;c@_02dc<00]<c40>Clm02H_;00d?C/0=Cln030l>P19F5H0=4=103e<B@0_?S/0<D0k03E4?`0b@C/0
9SD^01`/8`0V=Rd0934Z028/:@0`>CH0;SLd02D^:`0_>3D09Bh[024Z9`0P:BH05QlL01hW900O:2D0
5AhK02T_;@0J81h08BLU02D[:@0W;B/061hL01lU8`0W;B/07bDS02<Y9`0V;2X08RXY01dV:@0O:2X0
9Bh]024Z:00J8Ad08BPT01/Q7@0M8R407R<R01dQ8`0L7b@07b@X01/S8@0[=3406R4O01LM6`0L8R00
6AhL01HJ6@806Q`K00D08B<R028T8`0I6QP06QXH01`L6P0201XJ600501PH5P0G5aD061PF01TI5`0H
61H00`0F5Q@01`0I6AL0:2PV01PH5P0H61H051@B01<C4@0T92800P0B4Q002@0L71X03@d;020P7P0_
;R`04Q4?01TH5P0C4Q004A0>01@C4@0201<B40805QDC00L04Q4?01/G5P0:1PD061@C01DA400T81l0
?CTh00805A4@00H0510?01dI600A3@`05a<B010<2@0A3@X201<?3003010<2@0B3P/05Q8?00804Ph;
02L0510=01<?300B3P/040`;02`X9`0A3@`06QHE00`81`0@30/04@d<01DA400F4Q40510?014=300@
30/0510?010<2`0C3`h04Ph=00h:2@0A3@`030P701@@3`0?2`X04@d<018>3@0D40l040`9018?2`0D
4@d02`L400l<2@0G4`l02PH201LC3`0S7a/040`800h:1P0<2@H00P0F4@h08`0C3P/040/800l;200B
3P/040`900l;200B3@X040`900d91P0?2`P04@/8018<2@0A2`P040T7014:200B30T050h;01<<2P0A
2PP03`T6018;2@0C30X03`T;010:2P0810805Q4=04]6@01HDdd06aH@00X50`0E40`040X:01@>400=
1`T04@/;008040X:0P0?2@T01@0@2PX03`T900h8200>20P04P`<00803@L700L02P@400d71`0A2`/0
2@<302dW9`0m=cL03`T9008030H60P0C3@d01`0?2@T0:R@T02lY:@0A2`/03PP8018<300=1`L00P0k
=CD07@0@2PX03PP800h8200C2`/030<401@:2`0B20T04@L801L=3P0?1PL040H700l51P0C2@X05@/<
01@:2`0A20T02P@4014;2`0=1`L040X:014;2`0?2@T040X:018<300A2`/03`T900d71`0@1PL04@L8
00@04PP900X050X;00l51P0A1`P050X;01061`0B20T04@L801882@0@1PL03`D60P0@1PL00`0C2@X0
3P@501882@0201<92P0>01882@0D2P/03P@501/A4P0<0`@04PP900d3100D2P/03PD500h41@0@1PL0
4@L801882@0>10<401061@0700h40`0D2PT04@P700/20P0B20L06Q0?01471P0Dooooo`006oooool0
1P0L6Q/04@l@01HD5@0D4Q<03@/<00/92P803`d>00P03@/<00h<3@0@3Pl04Q0A01@B4`0@3Pl03@/<
00l=3P804Q0A00H040h?00h<3@0=2``03P`=014?400B414200l=3P0500d;300B41404a4B00h<3@0@
3Pl00P0?3@h200h<3@0300d;300C3`h04`l>00@04`l>01P030P802l[:P1fLW408alN00H20@0E4A00
51<A00L610020@003@`:01<B400A40h02@P702<R800L6aT0J6MU0<g<bP0C4Q008R4O00l>300@3`h0
1`H4055@CP05108300/:200=00X91`0@3`d06APF010?3@0?3P`040l=018A3`0C4Q005A@B010?3@0?
3P`02PT700`;2@0201@C4@0<014@3P0B4@l04Q4?00l>300>3@/051<A00l>300>3@/04a8@00P71@0J
6AL09RDR0P0A40`3010?2`804Q4=01<04A0<00h=2@0?3PX04a8>00d<200>3@T03@`8014@300G5Q80
4Q4=02<R7P0E51003`h:00`;1`0D4`l061LC010?2`0A40`04Q4=008040l;00@04a8>014@300@3`/0
3`h:0P0@3`/200h=2@0N00l>2P0@3`/04Q4=01<B3P0D4`l071/G01<B3P0510003@`8014@300I6QD0
3a8;00lD3@0?50h03a<B010D500A5AH00@D6020T900E6QH041DA00lD3@0:3@H05QHD00l?3@0J6QP0
5ADC01@D4P0E5A<04A4?0P0@40h01@0C4a404Q8@00h>300E4A00514@00804A0>0P0A4@l03@0@40h0
2@/8018D4@0E5a@01@X600H;1`051@D08B4Q01DE5@0;2`/0410>00h>300C4a400P0A4Pd0100C50l0
4Q<=014B300B4`h2014B3@0501@E400H6A@06AXE01LH4`0C50l00P0B4`h0800C50l051D@01<E4P0@
4Pl030h;03@f<`0>40d04A<@02@V8`0?4@h030h;018D4@0D5Q<04QDC00/?3P0B5QD061`K01TM700F
6aL051LD01HH5@0G6A@05QPC01LI500K7QL06alI02H[9`0J7a/04QLC01lT800G71P05Q/G0P0E6QH0
5@0H7AT06b0L01/P700F71P06AlK01`R800H7Ah061dP01`Q9@0C61`04AHJ01dR9@0H7Qh0728P03@j
=P0O9B<07R@R01`R800?61D07RLT01hX9`02020Z:@807b/[02h08Bd]028^<00Q;c807B/^01PV:00R
<30052<P01XY900L:b@07B`U024`:`0Y=cL0;C/k02`k>`0Z?3`0:Cdl02e1@P0^@T<0:Sho02a0@@0X
?3d0;T930396A`0bADT0>Da@03iAE@0`ADH0?U=D045FE`0kD5<0?55E04IKH010E5/0A5QQ04AHH`12
EV40AUYV04iQK`12EF@0@EAS049EH`1;GV`0BemY05M[LP1;GfH0B5aR0P19GF@05P1<H6L0EVYa06Ak
P`1OM7d0Ef]d05eaN01MLGL0HWEi05U/L01EJ6T0EfU[05AVJ01LKW00Nhf?065cL`1RM7@0HgEe06Uk
N`1aPH40M8B407F5Q@1nS8d208:@T@80PXf?01H0S9NK08B?T`29U9P0TibQ09:IW`2>UI/0UIbR09^P
YP2LXJL0WjBZ0:BY[`2XZk80[:bf0;2`^P2c/kd0^;K30;nkb@35_ld0a[k?0<c0e03?`mL0e<OK0P3G
b]h03`3Ic>00gM3T0>7Bi`3Yend0l=[a0?CNm03ghOH0mnCh0?_Yo@3mk?l0oNko0?gboP3nm?`0ooKo
0?oho`020?oko`<0oogo1`3oo_l20?omo`140?oko`3onOl0ooSo0?ogo`3omOh0o_Cm0?obo`3okol0
ongo0?oYo`3miOd0oN?n0?gSo`3lh_d0m]of0>oIkP3XeNP0h]7R0=g;f@3Jb=H0e/KB0=74cP3>`LX0
b;g20<>j_@2n]KH0]:n[0;2]Z02`[JH0Z:RQ09^MT028S7d0KW9S06mcI@1mPG<0Ri650:J^X`1lQ7T0
Mgmd07n9P01mQgh0NhEm07V4OP1mR8@0MX5m071lN01ePGd0Kg]i06akN01]O7T0L81o06YjN@1dQ8@0
IgMg05i`L01JK6`0Cf5Q04YJF@17Ee@0B5UC051OF014Dd/0;3`a02dj<00U<bH06RHJ02H[9@0o@C`2
02/`:P0L030e;`0V;BH0<SPd03<i=P0S;2T0<CXg03Ho?@0c?C`0>TI403Y9AP0kBTL0>TU603=2?@0_
?ST0;3/d02Lf;`0T<b`062PN02@d:P0T<BP082XW02hg=00_>3D0;CHc03Y3@00Z<c005QlL028[:080
72DR00<08R/X02</:@0R:2H00`0R:2H2020V900:02X`;P1>E580>3hl024W9@0F71X0:S0`020X:P0N
9bH07BHU01dV8`808BLS00d06b4M02<W:00O8b@08B@X01PK8P0K82@04a/I014J5`0F7Q/08BLU01hT
8P0F6aX061`K00806adL00T06Q`K01/M700J6aT061PF01XJ600K6aT06ATG01LG5@0F5Q@01@0E5A<3
01HF500?01LG5@0H61H061PF01PH5P0E5A<0410>00l?3@0=3@/03Ph<014@3P0E518040l=01PG5@0[
:RP071/I00803`h<00T04A0>01<B400B4@l03`h<01XF5@0E4A005Q8A014=300:1PD00P0F4Q403`0A
3@`04`l>01LC4P0E4A004`l>010<2@0B3P/04`l<014=2P0?2`P040`900<0000F4Pl04`l<00h:1`02
018>2`0<01lK6P0c;bh0510?01PD4`0>2PT03@T801HB4@0?2`X040`;014=300?2`X04@d<1P0@30/0
600A3@`040`;00h:2@0>2PT040`;014=2P0;1`@02PL200/80`0=2PD03``700h;1P0<2@@03``7010=
200?30L04Pl:01HC3P0F4@h04`h;00l:1`0>2@H040/8014<2@804Pd:00@06A@A01LB3`0B3@X050l<
1P0A2@L201<;2@10018:200@20H04PX801<;2@0=1`T07QPH014<2@0K5Q<0fmK@0?onn00S7QP050l;
01HA3@0C3@d0100000l92`0@2PX04P`<014;2`0=1`L03PP8010:2P0=1`L04@/;00T30`0X8R80=S0`
01/E5@0;1@D0208200l92@090`<03`T901PB4P0?2@T030H6010:2P0C3@d040X:00h8200K5AD07ALG
00d71`0?2@T04@/;00L20P0^:2P0:B<S00/51@0F41003`T900`4100P5QL02`4201892P0N51D0UH^<
01`B4`0?1@H03@<401<92P0H3Pl05P`=01892P8040X:0P0?2@T01`0>20P0208200`61P0B30`05Q0@
014;2`070@400P0@1PL2014720804PP90P0A1`P00`0B20T04@L80147200201061`0301<92P0@1PL0
3P@500<04@L800/03@<401<92P0L4Q<060h?0147200=0`@02P0104To@00Y7b003PD601@:2`060106
1`H03`D400H03@<201<9200?1@@0308101061@0B20LDooooo`006oooool01P0I61H020L500l>300;
2PP040l=018A3`803`h<0P0>3@/0200@3`d04A0>01LE5P0?3@h02`T:00l=3P0C4A804@l@0P0>30d2
00l=3P8040h?0P0B3Pd01@0A3@`05Q8A01LC4P0D40l04`l>00804Ph=0P0A3@`01`0@30/04Ph=01@@
3`0F4Q405A4@018>3@0A3@`00P0J5QD0201TH5l05a<B014=300I5A@04A0>00T81P0A40h09B@R0P0@
3`d04P0<2`T081lM02PW9@0c<S00HV5O01PG5@0<2`T020L5014@3P0I61H0T8n=01<B400F5A<04A0>
00l>300@3`d02PT700h=2`803`h<00X040l=014@3P0C4Q003@`:00/:200>3@/06aXH01`K6@0@3`d0
3``;0`0C3`h02@0A3@`040`;00h:2@0B3Pd05Q8A018>3@0?2`X04Ph=01@A3`02010?2`<03`h:00D0
3@`8010?2`0E51004a8>014@300200l>2P0=014@300>3@T03@`8014@300B4@d0;2/W01XI5@0?3PX0
3Pd901PG4`0K6QH040`9018>2`0201DA3P0301@@3@0F4Pl0510=0080510=0P0C3``00`0G4a003Pd9
00h=2@0200l>2P8040l;0180@T4m02`[9`0A40`04a8>00l>2P0?40/041<<010C3@0@4Pd04A<B014C
4`0A4Q@02``>00P92@0G6AH03@l<01@F400C5Pl201LG5@0<01`L6P0=3@/02PX801PH5P0B4Q004A4?
018B400C4a404Q8@010@3P0C3`h04Pl>0P0@3`d2014A3`0=01PH5P0A4a003a4>01DG500730P06QlK
00h>3P0h>3P0:b/[01LG5`0@40h06QXH01<C4@02014B3@0401<D3`0B4`d04A8<01<D3`D04Q<>00<0
6AXE01HG4P0C50l00P0B4`h0200C50l05QPF00/=300@4Q4061XI00`>3@0F61L02@X90P0G6AP00`0A
4a8030h=01<F5@0301@H5`0401<G5P0C61@04QLC01@I5@805Q/E02004QLA010E3P0F6aD06AhJ018G
4`0D6AD0724M01PM6@0E6QH05Q/G01@I5@0G71P06QlK01/P700G7AT06b4M020V900J82005a`O01PM
8@0J7b<07b@X02X_<P0J8200:2h/028X900L9B804Q/H030i=P0]=S<07RLT01XT8`806bLU03d072PX
01/Y:@0L:RX07R`]02@b=@0L:bh07Rd_02@d<`0O;b`0;Sli02@e;`0W>380:3Tc03=3@P0oCdh0>4U8
02Pl>`0W?3d0;45202i3A00[@440;dA702i3AP0`ADP0;dA70356B`0gC540=T]@03A9C00jCe00=4U:
03I;CP10EET0?55F045EG016FV<0Ae]V04IJI@18G6P0CF1^04ePK`1?HW40@eIT04QKJ@1;GfX0Cf=/
04]OJ019GFD0BemX04aPJ@1@I6`0FVig05=YM01MLWd0Ffmh05AXK`1CIf`0FVea05Y^K`1GJVX0G6i^
0080Ffe_03H0IWQj069dM01SMGD0IGMg06]mO@1cPh<0MHF507N7Q`1kRHX0OH^<07j<S@23SY00QI2B
08VBU`28TIH0RY>H09BMXP2GWZ@0TIRN09ZOY@2NXjT0WjBZ0:>V[@2XZk80Zjje0:f/]P2b/;/0]K>n
0;^ga@34_/`0b<;@0<Vod03>`]H0d/GI0=O9g@3Ib]l0f/_P0=c=i03RdnP0i]CZ0>WGk@3afo00mmoe
0?SRm`3ii_T0o>[m0?k]o`3mkol0o_?m0?ggn`3on?l0oo_o0?omoP3oo?l40?ono`H0oooo0P3oo_l0
103oo?l0oo[o0?ojo`3on?l20?gfoP050?oco`3okol0ongo0?oYo`3miOd00`3mhoh0C@3gh?P0l=[_
0>WFj@3Sd^<0g<[H0=W7e@3C`lh0cL3:0<^na`36^l00`KRi0;ng]@2c[Z/0[JZS0:j[XP2IVY40S8j0
07QlJ`1WJeX0NGe^08N;O021QgT0Ph]n07EmL01nQW/0OhV007j8O`1nR800NhJ007j9Q@1gPWh0L7ah
07B0O01]NGL0K7]h06]jM`1]OG`0IgMf06moOP1RLW80Ffe]05EWI@1>GUd0BUYG04EDD@10CdX0:CPa
034o=`0W=2X0:3D[02Tf:@0Q:b00;3</04E:A@0V:bD09BXS038i<@0S:R80<STb02li<P0J9B40<Sdi
03I0@00d?Sl0>DE303M6@P0d@ch0<T4l02ln>@0[>S<093</02Dd;00V=R`07blU02Lg;@0T<BP08B/W
0080:C8_00X09c0]02Xc<00K924082TV01XS800T;BX0:C8_02</:@0O:2D092XZ0P0S:BT3028X:00J
01dS8`0a=cL0;38b02H/;00K8B40;38b02@Y;00Q9bL07bDU01lU8P0P9R808BLS01`Q7@0W:b`07b<T
024U:@0C5Qd07B8X028Y:P0L9B@05QdM014G5`0K8B408BHV01PL7@0I6Q`201XK7@0701TJ700I6QP0
71/G01`K5`0M71P06QTE01PG4`0601LF4P<061LC0P0I61@03`0J6AD061LC01PG4`0=30P04Q4=01<B
3P0];2P061LD01HE4`0@3`d05A@B02<R800D4a403@`:00l>300201<B40804Q4?01d0510?01<?3P0A
3@`03`/:010<2`0C3`h0510?010<2`0B3Pd05A4@01<?3P0B3Pd040`9018>2`0D40d04@d:010<2@0A
3@X08AdJ01`H5@060`4081`I01HB3`0E4@h040`;014=30081@@0510?00l;2P0201PD4`0500l;2P0A
3@`0510?014=300>2PT01`0@30/03@0?2`X03PX900h:2@0?2`X040`900T50P0=2PD040d800l<1`0>
2`H03``700h;1P0B3`X00P0D4@`00`0E4Pd05a@?00l:1`02014<2@03010;200>2@H030L400803`X7
00@05A0=01@?300@2`P04@`91P0A2@L05@0B2PP04`/9018:200A2@L04`/901D=2`0D3Q002`D500@0
000H4`l0HEaF06aWH@0H4`d02`H200h91@0B30`0618D01@>400>20P03`T900h8200200`61P0D00h8
200A2`/03@L700@0000@2PX05@l?00d8200<1PH02082010:2P0?2@T02@<300/51@0>20P030H600l9
2@0B30`03`T900h8200?2@T200d71`0F014;2`0@2PX03PP800/51@0500003PP801@>3P0<1PH03@D6
00X00@0R61T03`D601T?400Q5aP03PD501061`0>10D04PP901D;300C2@X040L800h820803@L70P0<
1PH01P0H4Q804P`<00H10@0500002P@4014;2`8040H70`0A1`P01@0B20T03P@500l51P0@1PL04@L8
008040H700@03`D601882@0@1PL03P@50P0B20T0300@1PL03P@501D;300L4Q<05P`=00h41@0H3Pl0
4`T:01H<3@0700003P@501D;30H03`D61P0?1@@01P0;0@003`D400X0000:00004@L601@:2ACooooo
000Kooooo`0600`;2@0R8Al020L501<B400A40h061LE1P0?3P`0100>30d04@l@014?400?3@h200h<
3@0900d;300?3@h04@l@014?400?3@h03P`=018>3@0@30/04Ph=00805Q8A00<05A4@01<?3P0C3`h0
0P0B3Pd8014=300D00h:2@0H51<06QHE01TE500K5aH040`<00l>300=30X05aHD02TX9P081`D04a8@
01@C4@0<2`T01@@301<B400B4@l03`h<00/:2@0E518200l>300700h=300F5A<081lM01LF500=30X0
51<A010?3@0300l>300:010?3@0A40h04A0>010?3@0F5A<051<A02HU8`0Z:BL05A@B014?3@<04`l>
00H04@d<018>3@0D40l05Q8A01@@3`0B3Pd2014=3004014>300@3`/03`h:00l>2P803Pd900D030/7
010?2`0E510051<?014@3002010?2`0901<B3P0E510040l;00h=2@0@3`/05aHB010?2`0D4`l04A0<
008051<?00@04@d:01<?300F4Pl0510=0P0C3``01P0B3P/0510=01HB3`0E4@h05a<@020L6@<04Q4=
0`0A40`06@0E510051<?00`;1`0C4Ph040l;018A3@0C4`h04A8<010B3@0C4Q804Q8C010@4P0L6ad0
40l@00`=2P0E51804A8=01<D3P0<30X0>3Pf010@3`0E5A<06QXH00h>300B4Q00100C4a403P0B4Q00
510?018@3P0A40h04Q4?01<C4@0D51804a<A00T;200D5Q<0418?014F4P0;40`04A4A0P0D51@0100B
4Q803@d<01dM6`0C4a42014B3@0501<D3`0B4`d04A8<01DF4@0F5a800P0G61<0100D5A004a@?01LH
4`0F5a8401DF4@0A01<E500G6AP06A/J01DG5P0I6aX0418A02@V9@0H6QT05ALF01/M700C5A@04aHE
014E500@51<05ATH01<G5P0B5a<00P0E6QH05@0C6A<04QPB01@J4`0F71D06b4K01@I5@0F6aL06AhJ
01HK5`0J7a/06AhJ01LL600E6QH05Q/G01XO6`0K81`06R0L01TO6`0I7ad061dN01/P8`0201TN8P0;
01`Q9@0B5aX06R0P04eCD@0M8al04a`I01dV8`0i@Sl08R`Y020[9`0G8R400P0L:2H05P0L:BT072XZ
01h/;00P;S007Rdc02@c>@0N;C406BTY01d];00]?CT0834[02Pi<`0T=Bl08c<`02hn?00X>SP0:Sho
02Pm?P0/@D80;45302Tn@00^@dL20356BP0<0315B`0iCU@0@UIN03mCFP0gC4l0CF9S04=HF@0jCe80
@eQL04AIGP10E5/0AEUR0P18G6L0C@18FfP0BEaZ05AWM@1NLGl0Bei/04iQK`1@I740B5aX04]OJ`1:
GVP0Cf=]051TK@1DJ700GW9l069hQP1NLX00F6ag051TK@1JKW<0FFe^05IZJ@1LKfd0H79a061bL`1Q
Lg@0HWAf069dM01TMWH0J7Yj06eoO`1cPh<0MHF507V9R@1nS8d0Ohf>082>S`25T980R9>E08fFVP2B
W9l0SiRL096IW@2IWj@0VZ2U09fRY`2PY:X0XZJ/0:JY[`2[[[@0/;2h0;Bb_@2h]L00^[S30;njb036
_ld0b/;A0<k3e03BaMT0e/SM0=_<h@3Nc^<0glkT0>7Aj03[fNl0k=[`0>kIl03egO<0nnCi0?_Vn@3m
j?/0ongn0?o`o`3ol_l0ooGn0?ojnP3onoh0oogn00<0ookn1P3oool00`3oooh0oooo0?ooo`020?oo
o`0Q0?ono`3oo?l0oo[o0?oio`3nn?l0oOOn0?odoP3okol0ongo0?oYoP3miOd0oN?n0?cRo@3khO`0
mMke0>kIk03We>L0hM3P0=c:f03IamD0dL7<0<bob03:_L@0a[bo0<6i]`32^[L0][:[0:bYX02SX9H0
Nga`06e`GP1aMF<0N7eZ0080NGe]04L0NH1a07MoLP1mQGP0PXYo086;PP22S8<0NhEm07Z5P@1lQh<0
Mh9n07=oN`1dP7`0KGUg0760O@1]O7T0KGel06EeM01WMgL0Ff]Z05Y[J@1CI600Cf1I04mOF`18F540
?Te704=ABP0U<b/06RLN02<_9P0O:b807BLO028Y9@0T:bH09RlW02de;@0U;BD0;cX`02dh;`0/>300
E61J03@o?P0kAdH0?DY:03U8A@0iB4<0<3lj02`k=P0^?CL0:STb02Lf;P0W=bh08S8X02<c:@0T=2X0
82dT02H`:`0V;b`09Bh[02H_;00O:2D05QlL020Y9P0E7Q/082TV03Ho?00b>cP072DR02@Z:P0S:BT0
8RPX024W9`02028X:00O02H/;00O9BD09R`/01`R8P0b>3P09B/[02DZ;00S9BL07b@R01hT800P9B40
8BHR01lT8P0R9RL061`O01hR9`0G6R<092T_03Ho?`0F7ah07B@T01XP800E6a/061dN01HJ6`0E5QP0
6AXL01`M7`0K71h06QXI01/J5P0301`K5`806aXF1@0J6AD00`0I61@05aHB01LF4P0301LF4P0301@C
3`0I61@030/7008061LC00H0@D0l01DD4@0F5A<05aHD014@3P0@3`d2018A3`8051<A00L04A0>018A
3`0J6AL04@d<01XF5@0H51<040`;00805A4@01d0510?018>3@0D40l05Q8A018>3@0C3`h04@d:01<?
300E4@h04Ph;014=2P0B3P/0510=01TF500f<Rl0XIfJ05]GE00@30T04`l>010<2`0B3Pd05A4@024M
700X92<03`/:010<2`0D40l04Ph=00d9200<010<2`0>010<2@0?30L04Pl9010=1`0<2@<03@X4014>
200D4@/05A8<01HC3@0E4P`04Pl9010=200?2PL2014;2009014:200@2@L03PP500h71@0?2@H04P/9
018<2@0@2PL040T700L04PT70P0C2PP01@0B2@L050/901H>300?2@/03PP800803@P700P05a8<01<>
200U81X02PD100d8100B30`0C4I801H@4PH03PP800`030H600h8200G4A4030H6010:2P0I4a<04@/;
018<300:10@02`D5010:2P0A2`/200d71`0W00h8200@2PX03`T900l92@0<1PH02`D5014;2`0?2@T0
3PP801@>3P060@403PP801<=3@080P8040X:01@<3@0700004@P801<92P0B20T03@@501H=3@0A1`P0
40H70147200B20T04@L800l61`0>20P03`T9014;2`0B30`04`d=00X51@0A2`/04`d=00h92@0<1`L0
3`T900H04@L800X03`D601061`0B20T04PP901<92P0B20T040H701<92P0B20T040H70`0E2``02`0A
1`P04`T:01H<3@0B20T03`D601882@0D2P/040L8018:2P0B2@T07Q@E00H040H71P0?1@@01P0@1PD0
4@L700l61@0B20L05@/:00h40aCooooo000Kooooo`0700X91`0d<c402@P601PG5@0<2`T04A0>00l>
3003010?3@0E00l>300=30X02@L801LE5P0K6AX04a4B00d;300@3Pl03P`=010>3`0A3a0040h?00h<
3@0=2``04@d<00h:2@0B3Pd04`l>014=300B3Pd04`l>00804Ph=0P0A3@`0800@30/04@d<00h:2@0<
20L03@T8010<2`0A3@`06QHE00d9200:1PD040`;018>3@13?ch040l=00X91`071P@03`h<00T81P0H
5aD03@`;01<B400W9R@01PD400h=2`0;2PP07QdK018A3`0J6AP06QTG00/:200E51804a8@0`0B4@l0
0`0=30X03`h<00l>3003010?3@0;00l>300E518061LE00h=2`0@3`d05aHD01DD4P0E4a404`l>018>
3@0A3@`00P0B3Pd01`0E4A0040`;010<2`0I5A@04@d<00h:2@0B40d00P0@3`/300l>2P03010?2`0A
40`04Q4=008040l;0P0B4@d00`0C4Ph06APD01HE4@02010?2`0<00h=2@0<2`L051<?00/:1P0=30P0
5QDA018>2`0D40d05A4>014=2P0?2`P040`90P0D40d0100C3``04@d:014=2P0D40d6010?2`0S01TH
500K6QH04A0<014@300=30P051<?01DD3`0A40/040l;01<A4P0C4A<03P`?00400P0A3a400P4001dL
6P0?3PX040l:01<C4@25QH<0=cLe00l?3@061P@06a/I010@3P0B4Q004a<A018B400A4@l04Q8@01DA
400D4Q004Q4?01<B400C4a400P0D5180300D5Q<06A/H00T;2@0D6AD041DA01HF5P0B4Q806a/K01LG
5`1LG5X07AdK01<C4@804A8=00D04a@?018C3@0A4P`04Q<>01@E400201DF4@0301@E400C50l04a@?
008051D@0P0E5Q40:P0F5a803a4@01LI600;3@`05ALF01lQ800=3`h04A<B01HH5`0D5QD03a4@01DG
5P0U:2L061`K01DI600K7ah05ATH018G4`0D6AD051XF01DL5@0H7aP05ahG01<J4P0A5a4051TE01HK
5`0H7AT05AXF01LL600K81`05a`H01DJ5P0G71P06AhJ01XO6`0I7a/061hJ01DK6@0F6a`07B8U01`Q
9@806AhR00X092T/01LM7@0L8R0051XF01hW900M9R<05QlL00dH500Y=30072PV0P0M:BL05P0M:b/0
7R`/020^;P0S<C<07Rdd02Dc?00M;380<D1302Hf=@0T=3809SLa02ho>@0/?CL09cLd02dm>P0^@3h0
<4A502e2@`0_A4D0;dA702a1A00aAT/20397C01103=7CP0mDEX0Ae]T04IJHP0hCE00CfAU04YOH00n
DeH0?U=G049GG010E5/0@eMP04EII016FVD0AUYV04EHIP12EF<0D6=a04III`1;GV`0C5m]04AGI@1?
HW00Cf=_05AXL`1EJG@0F6ae065eP01IKgd0L8BD07:6T@1@I6d0E6Q/05EYJ01HK6/0H7Ab05e`KP1M
Kfl0I7Ig065cM@1TMWH0IgUi06]mO@1`PX80MHF507J6QP1hR8P0OXb=082>S`21Si00QI2B08JAT`28
TY@0TifO09VSY@2FWZ40UIZN09RMX@2OY:P0XjJ[0:FX[@2XZk00[K2e0;:c^02k^<<00P2n^lH05`32
_<X0ako>0<[2d@3Ba]L0elSM0=[;h03Ncn@0h]3V0>?Ai`3WeNd0k]_a0?3Ml`3cgO@0nN7g0?kVn`3o
j?`0on_l0?o_o`3ol_l0oo?o0?oho@3oo?/0oogl0080ookm00<0ooom0?oooP3oool00P3oool20?ko
o`030?kooP3nood0o_oo00<0oooo00@0ooko0?klo`3onol0oo[o0P3mn?h06`3om?l0onoo0?o]o`3o
jOh0oNGk0?gSo03jh?/0mmgf0?7Jl03ZeNP0hm3S0=g<g03Lb]P0fLOE0=?3cP3=`<T0bkk50<Jl_P33
^kT0^kB^0:bWX02RX9@0VIN:08>5MP1VJEH0KG9L07f2KP0208B8M`0l0827M`1iPG@0PXYm07^3N022
S8<0QY2707j8P01iQ800N8=o07N2OP1ePGd0M81l06ijN01[NWL0IGAa06QhM`1SLg80I7Ac05][JP1H
JF<0DV=J04mPF01?GUL0AeI?03a;A00S<2T0EfAL049?AP0R;BD07bXS024/9P0M9R<09c0/02H`:00]
=bl0:CDZ02Hd9`0_?380<Sle07>2N`0eA440=TA303U7A`0fAD80=dI102/j=@0X=c80;3/e02Lf;`0]
?C<0:SX`01h^900U=BX08S8W01l/8`0Y<bl09c0]02</:@0U;R/06B8O0P0K92401`0[=3407bPU020Y
9P0Y<Rl07BHS02@Z:P0Q9bL00P0P9RH0100Q9bL08RPX028X:00F71`202H/;00505EKF`0e>c/092DW
028T8`0Q8b800`0N8al04P0P92<0:2`_028V:@0I7R@07b</02<X;P1jPh<09Bh]014I600H7Qh0728R
01`Q8P0E6AX05QLI01PI6`0L7Al07AhP01/K6P806APD00@06aXF01`K5`0L6aL06QTE1P0G5Q8201HE
4@805A@@0P0D4`l02P0I61@040l;01<B3P0=30P08B0L00h=2P0@3`d02`X8018A3`0J6AL201@C4@0Y
018A3`0>3@/030/900l>300G5Q@04`l>01dI600J5QD03@T800h:2@0A3@`04`l>018>3@0F4Q405A4@
014=300D40l04Ph;01<?300E4@h04Ph;014=2P0B3P/02@D201DA3P0;1`@0?3Pe02XV8`0D40d02`L6
018>3@0<20L00`0000l;2P0A3Pd04Ph=014=300?2`X02PH501@@3`0/:2L01`0@30/4018>3@0?010<
2@0?30L03``500h;100?30D05A8;01/H4@0F4``04a09018?200A3PL03``500X7000D30X04`/90080
40P600P04PX801@<2P0@20H050`:018:200D30X05@d;018:20H04PP701h04`T801@:2@0C2@P04PP7
01@:2@0E3@/04``>00T30`0;1P<03`X700/6000?2P@03@P200l:1P0=20@02P@400l92`090`D040X:
00h8200?2@T04P`<014;2`0?2@T05a4A014;2`070@402P@400/51@080`<200`61P05014;2`0E3`l0
40X:00`61P0@2PX00P0?2@T400h82006010:2P0?2@T02P@400/51@0?2@T01@000P0=1`L02@0A2`/0
6Q@D0108200K4A805P`=00/10P0Q5aP040H700l51P0301882@804@L800@04@P9010:2P0?2@T03`T9
0`0>20P01@0@2PX020<300`61P0^:2P0O7If00804PP90`0A1`P00`0@1PL04@L80147200301<92P05
01882@0A1`P050X;01882@0A1`P00P0D2P/0300G3@h04PP90147200@1PL03P@501882@0E2``04PP9
00P0000;0@802P0101/A4PH04@L81P0?1@@01P0>10<09adL02<I600@1PD02P4101@:2ACooooo000K
ooooo`0400d<200I61@03@`800d<20<03`h:00/040l;014@300@3`/03Pd900`;2@0=2``05Q@E01TG
600C4A803P`=00l=3P03010>3`0:00l=3P0>30d03@/<01<?3@0?2PL050l<01<>2`0@2`P04Pd:01<>
2`804Pd:0P0A30T00`0@2`P03`/:00l;2P0500l;2P0800@0000F4Q405Q8A00T5100O6aX030/9014@
3P0?3P`2014@3P0=010?3@0A40h030/900<2000I61H030/900l>300B4@l03Pd;00d<2P081`D06APF
00H51002014@3P0801XI5`0G5Q@03Pd;014@3P0?3P`040l=014@3P0@3`d200h=2`0700`;2@0A40h0
40l=00d<2P0?3P`03`d;01<=3@02018<300901<=3@0D3Ph050h>014;2`0B30`05a4A018<300@2PX0
4@l<00804A0<100@3`/2018A3@0@010?2`0?3PX04Q4=01LF4P0D4`l061LC01LF4P0B4@d04a8>010?
2`0<2`L04Q4=00`;1`0>3@T051<?01<?30805A0=0P0B3@X0100D3``061<@01HA3P0D3``201<>2`03
010;200?3PX03`h:00@040l;01D020L300X91@061@403`h:014@300G5Q805a@?018>2P0A3@X05A4B
01D@4`0?2Ph04`hB01LB5@0>2PT05Q8A01<@300J6A@02`/902HV90092@L00P0E5A<010061P@03Ph<
018B400C4a42010@3P0=014A3`0F4Q40514@018A3`0A40h04Q4?014A3`0:2PP0418?00T;200J71T0
1@X601LL600200l?3`0501PH600@4100Bd]901@D4P0C4a400P0A4Pd0100C50l04Q<=014B300B4`h3
01<D3`03018C3P0A4Pd051D@00<051D@00l04a@?018C3P0C5A@05ALF00d?3P0G6AP06A/J01<E500D
5QD06A/J010B4@0<3Pd0<38a04a?CP0R9RD00P0E6AP02P0B5QD051TE01PN6P0F71P061lH01`U7@0J
91`051hE018H4P0N8al201HK5`0J01PM6@0?51005a`H01LL600F6aL061dI01XO6`0I7QX05a`H01/Q
7@0N92806R0P01/P8`0K82@05a`P01@I7@0N8bH06R0P00`B400Q9b<092dZ00lJ5P0I92008B`X01lZ
9P0J9R@201`X9P0^01/Y:@0M:b/07bd]024`<P0/>d80Gfef03M6C00V=CP08S8a02@d<P0R<bd08C8/
028c;@0U=C80:3Pe02Xk>P0_A4D0:d=302e5A@0^ATP0;4A6039:CP0cBU00=4]A03=:DP0fC5L0?59M
03Y@FP0nDeH0>4e>03Y?D010EEP0?U=G0356B`12EUd0@eMP04AHH`16FVD0AUYV04EHIP14F6<0BemZ
04=GHP17FVP0AEQW049EI080CV5_04<0DfMb05AXL`1EJG<0GW9m05=XN@1mTJ40R9bW05Y^M`1KKg@0
GW9a05mcLP1SMW@0GG1^06=eM@1^P840HWAf06MiN@1ZO7`0Kh6107B6QP1hR8P0NHV907^;R`20SXl0
PY2A08>ATP28TiD0RYFG09NPXP2>UYT0VZ:U09^SYP2FVil0VYnS0::WZ`2VZJh0Z:^`0:Z]/P2a/[L0
];Fj0;^h``31^lL0`[c80<Bnc03:`]40clCD0=C7f@3HbMh0g<gR0>;@iP3Td^P0iM?Y0>_Il@3^f_<0
lMgf0?OPn03khoT0o^Ol0?oZoP3okOh0oo7o0?oco`3om?l0ooWn0?omnP3oo_/0oool00@0ooom103n
ool09`3nooh0o_om0?koo@3nooh0o_oo0?ooo`3oo_l0oogo0?klo`3nn_l0o_Wo0?ghoP3om?l0onoo
0?o]o`3ojOh0oNGk0?gSo03jh?T0m]ce0?3Ik`3Ye>L0h/oR0=g<f`3Jb=H0elGC0=?3cP3>`LX0bkk5
0<Fj_@33^kT0]:fW0:JQVP2KVHd0SXao08>5MP1aM640LgQR07b1K00208>7MP1507V0L01fOW40OhMj
07InL`20RX40PXb407n9P@1kQX80NHB007R3O`1fPWh0LWij06ahMP1VMG80Gfi[06=cLP1NKVd0GVi^
05MWIP1EIUh0Cf5F04YKD@17Edd0?Ti403A4>P0iASl0OXZ406E`JP0a?3H07RTT01dX900O:RH0;STd
02@_9`0/=bl0;c`a02Dc9P0/>Rd0<d<h04EDC@0mC4T0<40n0351@00^?CX0<D0k02@c;P0R<BX09cH_
020_:00Y>Bl0:SX`01l_9@0[>c00:3P]02@a:00Y<bl09Rl/01lX9@0P:BH04Q/H01`U8P0T;BX0;CHc
020Y9P0K92407BHS01XS800U:b`08RLZ00808BHY01`08bP[02@Y;00[<3<06AhQ01hS9P0T:B`0;34d
018H600P8B80828Q024S8P0Q8b007B8N01`Q7@0M8B00>cm203Xn@@0H7B<08RH_01`P:@0S:bh07RHX
01hT9`0G71l05Q/N01TN8@0H71l06Q/O0P0I6Qh00`0L7B407AdL01/H4`0201/H4`8071TD00<06QLB
01PE400H5A000`0H5A0301TF4@0601PE400G50l05a@?01PE400G50l0514<0P0G50l03P0I5Q4061DC
01<B400<2`T04A0>01DD4P0?3P`04a8@014@3P0>3@/03`h<014@3P0B4@l03`/:0P0B3Pd00`0?2`X0
4@d<01@@3`02014=300L01DA400D40l03`/:01<?3P0B3P/0510=01DA3P0C3``04@d:018>2`0J5Q<0
6ADB01<?300;1`@05a<@018>2`0@30/061@C01<?3P0>2PT04`l>01PD4`0F4Q404`l>014=300?2`X0
61@C02/W9PH040`;00l03`/:014=300B3Pd04Ph=014=300?2`P040d800l<1@0A3PL05A8;01XG400L
6A80514:014>1`0>2`@00P0@3@H00`0=2P<04PX8018:200201491`08018:200C2`T03@D3018:200>
1P@04@T701<;2@0?1`D601881`8050X901D04`T801471P0C2@P04`/901<=3P0F41001P4001<>2P0K
5Q00IF1J00d81@0I51006aHB01H@400<1PP05a4C00l92@0=1`L03PP8018<300A2`/00`0?2@T01007
0@404`d=01LA4@0=1`L200X4100401H@400J51@04`d=010:2P804P`<00@040X:00d71`0=1`L03PP8
0P0A2`/200d71`0?00h8200@2PX03@L700l92@0>20P04P`<01D?3`0d;2`0Rh6200`20`0N51D01`00
01H<3@0D2P/04PP900804`T:00<04PP901<92P0A20T00`0=1`L200`61P0600L10@0A2`/04@/;00P2
0P0A2`/0>38b0`0B20T00`0A1`P040H701061`02014720804PP900T04@L801061`0A1`P04`T:0147
200>10D04PP90147200D2P/00`0A1`P0200>10D04PP900h41@0C2@X03P@501@:2`0L4Q<01`001P0@
1PL600l5100600/1000Q5aH07A<B00`20@0:0@404`T85?ooool001_ooooo00d05Q@D00/:2@0B4@h0
30/:010?3@0@3``04@l?014@3P0>3@X03P`<00l>300=30X04Q0>00@04@h>00<03``<01<@400C4100
0P0A3Ph03`0@3@d04@d<018>3@0?2`T04`l=018=2`0?2PP04Pd;01<>300@30X04Pd;01<?3@0?2`T0
510>010<2`0201<?3P0U01@@3`0B3Pd03`/:00l;2P0D40l040`;00h:2@0F4Q403`/:00d<2@0>2`T0
40d;01@?3`0L5QL030L701D?400H4a@01P8201TF5@0920H0518A00l<2`0=2PT030T801HC4P0?3@/0
40h<01<@3`081P@0518@00h<2P0C40l0514@01@B400C40l04Q0>014>3@02014?3@0U00h<2P0D4A00
4a4?010>300E4Q405A4@010>300B3@`0510?014>3@0C3Pd05Q8A014?3@0C3Pd03``;00h;2P0C3Ph0
5A4?01DC3`0B3``040d:014>2`0A3`/04Pl<018@300E4Pl04Q0<00l=2@0C40d040h:014>2`0E4Pl0
4Q0<00l=2@0F4a0040d:00h<200201@B3P0:01<A3@0@30T0510=01D@3@0E4@h050l<01<?300E4@h0
61<@01LB3`805a<@01h05Q4>01<>2`0@3`X04a<<00l>2@0@3`/04Q4<014A2P0E50l051<>018A2`0F
5A404A0;00d<1`0D4@h04@l<00l=2`0C40l05A<B010=3@0B3Q4040h=01TF5@0B3`h040h;018A3P0C
4Q003`h<018A3`0C4a42018A3`1;00l?3@0B4@l04Q8@014@3P0A4@l04a8@01<A4@0D4a803Ph=00l>
3@0B4a403Pl=010B400I71X05APF07MkN@0E6QL03a@A02TY:00@40l03Ph=014@3`0E518061LE01<C
4@0E5A404a<?01<C400D51404a<@01<D400F5a<04a<@018C3`0D51404a@@01LH500H61D04a@@01@E
4@0A4Ph04Q<>01DG4`0E5Q805QLC01LH5`0B4a4051DD01XK6P0=3Ph06AXI010A4@0D5AD07R0M01<G
4@0@50l05a/E018F4@0@5A005A/F01PN6P0M8b0072<P01HO6`0D7AT04aXF01/O7@0E6AL06QhL020U
8P0G6aT061`J01DI5`0G6aT06QlL00805AXG04<061dJ01`T7`0/=3408BPX01TO8P0E71l07bDZ01DK
800H7R<0728T01LN7P0M9B@06b@R01/U8P0N9bD0620M01PR7P0N:2H09S0^02@_;@0P;2d08Rd^02Db
=00[>3`0LH270<gLi01aPHP072``02Tj>`0W>3P0:3Th02Df=00U=SD0:S/i02`m?@0_@D00<DA302a1
?`0[@3l0;D5302m3A`0gBe00<dI>03U<E@0iC5H0>4]D03iBFP0oDU/0@5EG03Y?C`0nDe<0@5EG03iC
E`0oE5T0?e=J04AHHP14F6<0AeYW04ULJP10Df40Ae]U04AHH@1<H6X0B5aV04MKI@1@I6l0CF5[0080
Cf=]01<0D6A^05EYL@1HK7@0GWAm05M/L`1EJFl0CV9V05a`LP1FJFP0Gg9b061bL@1NL6l0IWMg06io
P01VMgP0JWal06eoO`1bQ8@0NHZ:0080OHb=02`0P8n@08>@T@24TI80Qi>E08^FV02>VI/0XJV/092H
V`2FWZ40WZJZ09RMXP2RYj`0YJV_0:JY/@2[[[H0/kBm0;Jf_`2g]l40_;W60<2kbP32_L`0b<7@0<g4
eP3Aa]P0e/WL0=_<h@3Ncn@0i=;X0>OEj`3Yend0l=[d0??Km03fgoH0nnCk0?gVn`3njod0ongn0?o`
o`3om?l0ooKo0?ogo`3oo?l0oool0?onoPD0ooon103oool01@3oooh0oool0?ooo03oood0ooon0080
oooo0600ooko0?omo`3oo?l0o_[o0?gio`3nmOl0onko0?o/o`3oj_l0o^Kn0?gSo@3jgoT0m=[c0?;J
k`3/e^H0i=7N0>3=f@3B`L`0e/O@0=?5b`38_<00ak^k0<:i]P2o^;80ZZJM0::OU02ASh<0OGa`07Ef
J027RGH0MGUT0823KP1dN6D0JVeK06ebHP1jOg00O8=e07ElL@1lPgX0NhAj07j7OP1nRHH0N8F407J3
PP1cP7l0KGaj06]iM`1XMg@0Hg=`06AdLP1PL6h0Ff]Y05=SG`1CHe/0BUYA04IFC@0gASd0=D<k03E1
>P10C4H0;cTd02D/:00U;BT0:2l/01`T7P0Q:B<0:c@]024/900c@3L0;S/c02Ph<00Z>c80=DI002Hg
<P0nCT/0=4=103M4@`0b?CP0>TDo02Te;@0U<2T0;SXb02D`:@0Q;B@0930W024/900S;bH0<Sdd02<^
9P0P:bH0:38^01lY9P0R:bP072DR02H_;00P9bD2028Y9`0W02<Z9`0/<Bl09bd[02D[:@0T:RT08RPW
01lU900S:BP09R`[01hT9@0T:R/08RLY020U9`0K82<082HV01hR8@0]<2l0=3Lf01lR800R9B<0720M
020S8P0g>SX0=cXl01hP8`0Q8bL061/O028V9`0E6A/05AXJ01LL6`0H6Qd06QdN01PK6`0M7R4061XK
01TK6`0M7R40>cXh00806ALC02@071XE01/I500M6aH06ALB01/I5@0H5Q8061HA01/I500H5Q806aLC
01XF4P0I5A<05Q@@01DE400T92409RHR01@D3`0C4a005a@A01XF4P0D3`d05A4>01<@3P0F51405A<@
010>2`0G51805Q@A01@B3`0=2`T0514?01LE4P0B40d0510>014=2`0B3P`201DA3`804Ph<01/04@d;
018>300B3P`040`:018>300@30T04`l<01DA3P0B3P/040`9018>2`0E4@h030P501HB3`0=2@H04@d:
010<2@0E4@l050l=014<2P0D40h03`/9014<2P0D40h040`:01<?3@0A3@/00P0C3`d0200A30X040`:
00l;2@0@2`T04@d;018=2`0A3@/04@`:0P0@30X01@0A30X04@d:00l;1`0A3@P04`l90080510<00H0
4`l:01<?2`0@30P03`/5010<200A3@T2014<2@0A00h71P0A2PT04P/:01<<2`0B2`X04@X9010:2@0@
2@P03PL600`61@0E3Pd04``;0148200>1`H050`;03`c<`0M5QD00P0C2PX0600A2PT040P80188200A
2@X04`d>010:2P0B30`04@/900/60`0@2`P06aHC00l:1`0?2PP030L701@>3`0;1@H040X:00`61P0=
1`L06Q@D00d71`0?2@T03@L7014;2`805@l?03L03`T9014:2P0?20P04@L801482@0<10D03@@501D=
3@0D3@d04PT:01082@0:10@03`D601492@0D30d07A@E00l61`0F3`l040L8018:2P0@20T04PT:0108
200=1PH04PP901hD5@0S6AX03PH60148200J414040H701071`0B20T05@/<01882@0H3Pl04`T:01<:
2`0A2`/04P`<014;2`0B30`04`d=010:2P0=20P05@l?00h820070P804Pd=01<92P0?1@H04@L801hD
5@0>10D03PD600@04@L80P0@1PL02P0>10D04@L80147200=0`@04@L801P>3`0B20T03`D60147200C
2@X201882@0601471`0;0`805@/;00`30`0?1PD060h>0P0@1PH0100>10@03@<300l51@0A1`L20106
1@803`D40P0A1`H01P0?1@D03@@301D;2P0>10<04@L600`20ACooooo000Kooooo`804Q0A00D03P`=
014?400<2P/03P`=00X82@02018@4@<03P`=00H04Ph=00l;2P0>2PT03`/:014=300@30/301<?3P<0
4Ph=00l04@d<00l;2P0B3Pd04@d<00l;2P0B3Pd040`;00`81`0:1PD03`/:00`81`0E4A004@d<01<?
3P0B3Pd00P0G4a807`0B3Pd04@d<018>3@0A3@`040`;018>3@0C3`h04A0<010<2@0A3@X05Ph?024F
6P0N4aL05`d@01@;3P0P6Q`030T901DD4P0<2PP0100000`81`0U8B0040`;00H20@0@30/04`l>00d9
200B3Pd03PX901DA400C3`h00P0D40l401<?3P0H01@@3`0E4A005A4@01<?3P0D40l04a4?00d<2P0>
3@/04Q4?014@3P0B4@l051<A01dL6P0920H03@`:028Q7`0A40h04@h<00/7100D40d071PE014=2P0=
2@H05Q8?0`0C3``03P0A3@X061@A01LC400J5Q<06ADB010<2@0>2PL05Q8?010<2@0A3@X0510=01DA
3P0C3``04@d:0P0C3``01`0B3P/040`9010<2@0?2`P04@d:018>2`0D40d00P0C3``0100D40`03`h9
01LG3`0?3`L201@D3003014A2@0B4PX04Q8:00804A4900P04108010?2P0B4@d03Pd;00d<2P0@3`d0
4a8@01@C4@@04Q4?00P04A0>010?3@0?3P`04A0>00l>300A40h05QDC018A3`804A0>0P0B4@l201<B
4004010@400B4Q804Q8B014C4P80418A00l05QXI00dA400g>cX0T9JD00hD4P0@51<04Q8A014@3P0Z
:BL09B@R00h=2`0<2`T051<A01PG5@0D4a400P0B4@l03@0A40h05ADC01TI5`0D51804Q8@01@D4P0B
4Q003Ph<01HF500J6QP05ADC01@D4P0S91l00P0D5A0201<D3`804Q8@00l05QHD01TI6@0?3`l07AdM
01@D500E5a804aH=01LJ4`0L7aP05aXC01<H4P0D6QD061hJ01hT8P0H81l00P0?61L01P0D6QT051PG
01DI600I7A`06alN01PL6`805a/J01l061`K01TM700E6AP05QXI01`R7`0>5a805QlL00hF5P0E7Al0
6b8X01hU;00H7bL08RT_01XQ9P0N9RT041PJ020U:00L8B@07B<S01lU8`0M8b407RLT024Z9`0R:bP0
8R`]02@]<P0W<3D09c<i02hmA01IJW40>DYA008093Hj06L08S@h02Dg>@0W>C/09cTk02Li>@0Y>c/0
;T0o051SH@18FeL0>Te<0353A@0`@TH0;d1803U:E00fAe40<45;03A5C@0lCED0?DmF03Q<C@0aAdD0
>4i<041EEP15FUh0AeaQ041DG@13Ef40AEUT04=FI018FfX0EFQf04QLI@18G6<0Cf=Z045EG019GF@0
DVI]051TJ`1CIfh0Cf=Z051TJ`1GJg80EFY_05U^K`1EJVT0E6QW05IZJ@1KKVd0G6i^05maL@1QLW80
Hg=c06EeM@1YN7T0K7Yk06emO@1^P800LXB407J6QP1iQhP0NXR908:@T@25T980Qi:D08ZEU`2=V9X0
SYRJ09RPX`2GWj80U9bO09ROY@2JWjD0XJJ/0:b_^02Y[;D0[[6j0;Ng``2e]L40/k>o0<2lc@32_/l0
a<3A0<_4eP3?a]T0d/KJ0=W<h03Ncn@0hM;W0>OEj`3[fNl0kmcb0?GLm`3igoP0nn?k0?kWo03mj_d0
o^gn0?gao`3nl_h0o_Ko0?oho`3onol0oogo00/0oooo00D0ooom0?oon`3ooo/0oool0?ooo@020?oo
o`1B0?kno`3ooOl0o__o0?gjo`3lnOl0o_Go0?o^o`3njol0o^Wo0?kVo`3lh_l0nMkh0??Jl03afN`0
jmGR0>3<e@3Kb=00c[o60=S9cP3CalT0aKVi0<Bk]P2m]Zd0ZZJJ09jJSP2GUHP0QhMk07moL`24Q7T0
RHYh06i`F`1mOfX0JVeJ061SD01cMVD0NWi_07YnL01hOW80NGmc07Z0M01jPWT0NHF30761P@1]OGd0
JWYi06EeM01WMgH0IgMd06AdL@1PL6d0FfaV05IWH@1AHU`0AeI?04=BB`10CdP09c@]03E1>`0oBT@0
?dQ302Ta;00N920092TU02/`;00P9Al0:2hT02`e:`0R;BD0;STc02hm>@0b@Sl0:3/i02e0?P0dAdD0
>DU603Q8A@0f@Sh0<c`g038i<P0W;RL09B`U02L^9`8082LP02809RdV020W800a>340HVUR03<m=@0G
8Ah05b8N020[9`0W<2d0;SLd02</:@0Q9bD082@S02<W9P0X;2/09b/Z01TN6P0S:B@08bTU020V8P0N
92007bDS028X9P0O9B<07B<S01hT900P9RH07b@W01dS8`0L8R40N7ak07f1P00R9RD05aTH0P0T9RD0
1`0V9RH092@T024Q8@0P82007alO02<U900I6aX00P0L7Qd201/M700>018D4`0H6QT05ALF01LI600H
6QT0O7aj02XY9@0<2`L051<?018A3@0S8Qh051<?01LF4P0E510201TH500I014@300E4Q004@/;010<
2`0B4@l07alM03m1?P0j?3T04A<@018B400E4a805a<B01H@400F4A00510=01<?300D40d04`l<01PD
4@0N6QL01@40014=2P0M6AH04Ph;00h:1`0200X60`0800d91P0B3P/05A4>01PD4@0E4@h04`l<018>
2`0C3``201@@3@0H018>2`0C3``05A4>01<?300A3@X04Ph;01HB3`0?2`P03@T6014=2P0C3``06QHC
018=2P0?2PL04@`901D@3@0B3@X04`h;01@?300@2`P04Pd:00`7100D3``04`h;0P0A30T01P0?2PL0
40/8018=2P0C3P/05A0=018=2P803`X700X04Pd:01D@3@0J5A805a8?01<>2`0B3@X03`X700X50P0C
3P/04Pd:0`0@2`P01`0A30T01@0001D?3`0;1@D050h>00P20P0=1`L00P0@2PX02@0I4a<07ALG00/5
1@0@2PX02P@401XD500F410040X:030Z:P0700l92@0K00X4100B30`03`T900T30`0D3Ph07QPH01`F
5P0@2PX03@L7014;2`0@2PX030H601@>3P0=1`L0618B03Tc<`0D3Ph02`D5014;2`0B30`03PP801<=
3@0A2`/04@T901H<3@0J41405P`=00803`D600<050X;00h41@0=0`@00P0D2P/0200M4a@081HG01X@
4@0R61T03P@500l51P0;0@803`D60P0B20T08P0A1`P040H701061`0@1PL06@l@01P>3`090@401`00
00P0000M4a@0308300d3100B20T01`0000P0000<0`@03`T900d71`0;1@D03PP800`61P0?2@T0618B
08EoO`0C3@d06aDE01<=3@0I3a004PP901T?4011=cP0;R@U01061`0C2@X201882@0=0147200@1PL0
40H701882@0C2@X04@L800`20`0>10D060h?01061`0?1@H040H70147200201882@0<01<9200>10<0
2@4000l5100=0`802P0001061@0C2@P05P`;01D;2P0C2@P04@L60P0@1PD02P0>10<03`D401471P0B
20L01`0001<9200700002P0001071`0K4A0Dooooo`006oooool03@0A3a004Q0A010>3`0A3a004Q0A
01<A4P0B41403P`=00d;300>30d040h?014?400A3@`00P0>2PT00`0?2`X040`;00l;2P03014=30<0
4Ph=01<04@d<00l;2P0B3Pd04@d<00l;2P0B3Pd04`l>01HB4@0A3@`05A4@018>3@0H51<04`l>018>
3@0@30/0510?01HB4@0B3Pd04@d<00804`l>01d04@d<010<2`0A3@`02`/6018A3`0I5A@08A/K01L>
4@0F3A004`X=01T@4`0N61X02`P9028P8@0F4a<02`L601TE500l>3L07ATH00d9200C3`h03@T801HB
4@0A3@`04Ph=00/71P0@30/04@d<018>3@0201@@3`0801<?3P0A3@`04`l>01@@3`0A3@`03PX9010<
2`0@3@`2010?3@0M00l>300C4Q0051<A00l>300G5Q@020L501PG5@0T8b402PT701DC400=2@H04@d:
01LC400A3@X09B4N01dI5P0F4Pl040`9018>2`0C3``06ADB01lK600N6QL05a<@00l;200>2PL04`l<
00l;200@30T00P0B3P/02@0A3@X040`901DA3P0C3``04@d:00l;200@30T04@d:01<?3003018>2`08
01<?300D4@d030/601@D300?3`L051@<014A2@0>3PH2018B2P804A4900P04108010?2P0C4Ph03Pd;
01LF500I61H04a8@01@C4@@04a8@100B4@l0100>3@/040l=01HE4`0C4Q02014@3P804Q4?0P0C4Q00
6P0B4Q80410@01@D500A4A403@h=01@F5@0=4A003a<B01dQ801>E5802Q0>00`@3`0C4a404Q4?028Q
7`0J6AL04Q4?01LF500I61H071/I01PG5@0D4a404a8@010?3@0F5Q@05aLE0P0E5A<02@0D51804A4?
01/K6@0A4@l0410>01DE4`0G5aD05aPC01HG4@0301LH4`0J01@D4P0C4a405ADC01hN7P0C4a<08B4Q
00h>3P0G61D051L@01LI500L7QT061XE01<H500D6QH05A/G01HL6P0B6QL03aPE014J5`0E71X05QXI
01DI600G6aX06AdL01LK6P0F6QT201TM700H01HJ6@0I7A`06AdL01`R7`0<5A004a`I028Z:P0W;c40
4QTO01PO9P0S:S806B0V01hU:P0L92L08BT[020U:00M8RD07R<U020V900N92807bPU020[9`0Q;2P0
92h_0P0V<CD01@0V<ST05B@[01h_=P0S=3/0;3i2008093Hj02H09cTk02Tk?@0[?Cl0:S`l02/m?@0^
@3l0B5]I049ED@0hBTT0<dE703=5B@0dADd0>4UC03E6D014EEl0Ffad05MXL00lCUD0@eMH03Q=C@0k
D540@eQK04EJGP13F5d0BUiW04IJI015FF@0?4mM049EH`1VNHL0AUYQ04aQIP17G640?eAI04iRJ01>
HVT0Cf=Z05=WK`80DVI_03h0EFUb059VK@1HKFh0EFYX05AXI`1FJVT0Ffi]05a^KP1OLG40HG9b06=c
L`1UMGD0JWUi06ajN`1^OWh0LX:207F5Q@1gQhL0NXR907^9RP24TY<0R9>E08ZEU`2=V9X0T9ZL096K
W@2FWZ40VZ:U09NOXP2PYJ/0][_10;Bi_`2/[kP0[[6j0;6d_@2j^/H0_;c80;ZjaP32_/l0a[oA0<W2
e03?a]T0e<SL0=G9g@3Kc^80hM;W0>CEjP3Zf>h0kmgc0??PmP3hgoX0nn7j0?gUo@3ojOl0onco0?o^
o`3mlOl0o_;n0?ofo`3onOl0oo_o0?ono`/0oooo00D0ooom0?oon`3ooo/0oool0?ooo@020?ono`1F
0?omo`3nnol0o__o0?cio`3mmol0ooCo0?o^o`3njol0o^Wo0?kVo`3lh_d0n=kh0??Jl03_enX0im7N
0=_7d03C`LP0cl370=G6b`3?`lD0a;Zi0<:i]02e[ZD0XIfA09jJSP2EThH0R8Ql08J6NP2:S800OWm]
071bG@1iO6L0I6MD06=VD`1fNVT0NGe^07YnL01jP7@0Nh5g07Z0MP1gOgH0MX:006inOP1[Ng/0IgMf
069bL@1SLg80JGUf06EeLP1MKVP0EfQR05AUG`1@HE/0@e9;03]9@P0gA3d09c@]03i:@`0h@cd0=d0k
02P`:`0J81`08RPT02`a;@0Q9R00:2lW02Pa9`0`>c<09C0Z02/j=P0c@d80?U5?03E8AP0cAT@0>TY7
03Q8A00_>cL0>D8m030g<00_=Rl0<CPa02`c;00X;bP09RdV01dT7@0P9b0202L^9`0>01/U7@0[=C80
5R4M01`W8`0K9240C5EB01LP7@0Y;bd09RXY020T8`0T:2L07R8Q01dR7P0U;2H3028X900V020V900N
92807bDS01lU9@0Q9bL08RPX020U:00M8b<09R`[034e=00`=3<07R8Q01LI600K7A`07b4P02@T900S
8b<0820P024Q8@0T92@06adL01XL6`0P8R407b4P020R8@0T9RD07AlN01lQ800P8R408R@S01lQ8020
P7h0<C0/01HE4@0P7a/08R4M03@c;`0F5A4201PG4`0F02<R7P0L6aL04Q4=01/H5P0M5aL07a/J01`K
6@0B4Q0061XG01/M6P0A4a004a<A01<A400D40l05Q0@01LB4@0B3P/04@d:01DA3P0C3``04Ph;014=
2P806QHC00<04@d:00l;200D40d00P0D40d0200E4@h061@A01dI5P0W8b005Q8?01@@3@0C3``0510=
0P0E4@h00`0C3``04Ph;018>2`02018>2`0700l;200B3P/03`/8010<2@0B3P/03@T600T50P0200l:
1`0401<>2`0B3@X03PT601<>2`804Pd:00@05A0=00d81@0C3P/05A0=0P0A30T2010;2004018=2P0C
3P/050l<018=2P803`X700D04Pd:01@?300E40d040/800l:1`0201<>2`0300d81@0B3@X04Pd:00@0
40/80P0?2@T04004000050h>01<=3@0D3Ph03`T9018<300H4Q809R0P018<300;1@D04P`<00L10@0A
2`/0<R`/02@N7P06000600l92@07018<300G4A4050h>014;2`0Q6a/0;bTY014;2`0200l92@0E010:
2P0>20P02`D500X51@090`<02P@401TC4`0:10@04@/;010:2P0E3`l02`D500`61P0?2@T040P801P>
3`0O5AH060h?00l51P0A1`P050X;00803@<400H04PP901061`0F30d060h?01<92P0D2P/201061`03
020F5`0@1PL04@L800804@L801P040H700l51P0?1@H0308301P>3`0G3@h0:AlP0147200G3@h02P01
00`20`0F30d0200002`R8`0C2P/040X:00h8200A2`/05Q0@018<30090`<0100006]UI@0;1@D200T3
0`0600L0000G3@h07Q@E01L=3P0=0`@040L80P0D2P/03@0C2@X040H700l51P0>10D050X;01882@0@
1PL03@<400h41@0@1PL03P@500l51P0A1`P00P0?1@H03P0A1`P0718A01/A400@20L0718A01071`0A
1`H0308100d30P0>10<040H500h40`09000040H50`0?1@@0200A1`H04PP701<9200?1@@04PP700T0
000H3Pd01`005?ooool001_ooooo00l03`d>00h<3@0?3@h02`T:01DC500A3a004a4B00d;300B4140
4@l@00/92P0A3a004`l>014=300@30/00P0B3Pd0100@30/03`/:010<2`0A3@`4018>3@0@010<2`0C
3`h04Ph=010<2`0C3`h03PX901@@3`0?2`X04Ph=00h:2@0B3Pd05A4@018>3@0=2@P04@d<01@@3`80
4@d<01T0510?01DA400B3Pd04@d<00l>300A4Q403@d<01DD4`0W8b<04Pd>01D@4@0B30h071LH00/8
2@0E51@04Q8C00h>3@0D40l05A4@01@@3`0H51<0510?00l;2P0C3`h0:bLV00806ADD00D03@T801XF
5@0D40l0510?01<?3P03018>3@0301<?3P0B3Pd04@d<00805A4@00@04a4?01/J600H5aD03@`:0P0B
4@l0500@3`d030/901`K6@0e=3805aHD00d<2P0D4Q00510=01hJ600B3P/05A4>03hj>00P71T061@A
018>2`0C3``04@d:018>2`0H51405A4>100B3P/401<?300:018>2`0A3@X061@A01HB3`0C3``04Ph;
01<?300F4Pl06aLD01PD4@80510=00P05A4>01@@3@0B4@`05QD?00l?200F5@l04Q4;01<C30804Q8;
0P0A4@X01P0@40T040l:018A3@0?3P`08B0N02<R80804Q4?0P0C4Q02014@3P04018A3`0C4Q006APF
01HE4`803`h<00@04a8@010?3@0A40h04A0>0P0B4@l201<B400D00h=3@0C4Q804A4A018B4P0D5AD0
3a4@018D4`0H71/03a<B00lD4P0D6AL05APG00l?3@0M71X06QTG01<B400J6AL04A0>01DD4P0G5Q@2
01DD4P0301@C4@0?3P`04a<A008051@B0`0E5A<0500D51805ADC01DE4`0D51806a/I018C3P0E5Q00
5aPC01TJ5@0H6A@05ADC01@D4P0J6QP03`l?01XJ6P0A4A407alO01`M700K7AT06A/I0P0I6aP201HK
5`0801HL600E6aL05AdH01HO6@0E7QX061hL01/O7P0I7A`201PL6`806AdL01h07b<R024U900M8B00
8bLV024U900K8Ah0624L01dV8`0b>cX0BE5C02H]<`0M92/05A`T02@[<@1AFEd07BDX01`T9P0Q9RT0
7R<V020U:00Q:2P07bHU020Y9P0S;R/082XY028/;@0S;S808bhd02Hb>P0V=C`202Df?@1301la=@0Z
?400:3Xn02Xl?P0/?T00;d5302i0@00]?cl0;d5002m2@00]@3`0;Cln0394AP0hBTh0?DiF03U:E00f
Ae40CEiX06AeO@1GJ700>TaC04]NH@0mDU<0?eAE04IKGP15FUh0@UML045EG016FV<0AEUS04EHI@1J
KG/0M8RC04YNI016Feh0BEiR04mTJ01AIV/0BemU04iRJ@1AIFd0EFUb05EYL`1DJ780DFE/05M/K@1E
JVP0EFUX05Q/J`1LKfl0GFm_061bLP1RLg<0IGEe06MgM`1/Ng`0Kgen07F5Q@1cPh<0N8R808>BT`25
Ti@0PHn@08NDU@29U9H0RiJH08nIV`0209:LWP0T09JNX@2PYZX0WJBW0:>X[P30a</0/kNn0:^^]`2`
/[/0[[2i0;Via@2n_LX0^;K30<>od037`=80blCF0=78f`3Fb]h0f<cP0=c?h`3RdnP0i]K[0>_Ik`3a
goD0m^7h0?WPn`3mho`0o^Kn0?oZo`3okOl0onoo0?kbo`3olol0ooOo0?ojo`3oo?l0ooko2`3oool0
1@3oood0oook0?ooo03oood0ooon0080ooko02<0ooco0?oko`3nnOl0oOKo0?ceo`3nlol0onko0?k[
o`3njOl0oNGn0?[PnP3efo@0lMS^0>_Di@3Rc]X0fLSB0=71b03?`<H0c/750<Rl_@2o]K<0^[6/0:RQ
V02FTXH0V9B809:BQ02OWi80Wj2C09>ER01hNVL0LgIQ079eH@1[KU`0MGQV07UmKP0207f2M00]07^1
M@1jPGH0NH1f07R0N01dPh00KWin06]kNP1XN7L0Hg=b06EeL`1VMW<0Hg=`05a]I`1FIf40CUmI04MH
D@16EDh0=T@m038o>00^>S<0@dm902D`:P0]=S40:30/01`T7`0[<Bd0:2dY01hT7@0[<RX0:34X04QC
B`0b?cP0<T8o02/k>P10De40=4M502dn?@0`@3d0<d4m038n=`0/=C00=C`e02/b:`0W;RL0:C0Y0080
8bXS00H09B`U01lV7`0/<b`0;SD^01hX800Q:bP201hY9@0>02@]:P1mQX<0?4E202dc<@0]<C007B4P
01hR8@0P92<0<cPd028Y8`0N92008BLS02L]:@0T:RP201lU8`0h020V9P0S:BT09B/[028W:P0O9BD0
7B<R02@X9`0Q9B@092PW01DG5P0R92<07b4P01/K6`0O7al0820P01lO7`0Q8B406adL01dO7P0N81l0
6Q`K01dO7P0R92<06A/J01HH5`0J71/07AlN01HH5`0h>CH071/G01PG4`0E510061LC01hM6@0E5140
61LC01@C3`0R8Ad061LC00l>2P0H5A<05Q0@01LC4P0H5aD04Q8@014C400C5A804Q@A01<C4@0A3`h0
4@d<01LA4@0G4Q405Q8?01`H5@0N6QL201@@3@0600l;200H51404`l=01<?300@30T061@A0P0D40d0
0`0B3P/03`/8010<2@0201DA3P0301<?300B3P/04`l<0080510=01405A4>01<?300D40d061@A01XF
4`0F4Pl04`l<014=2P0@30T04Ph;01XF4`0h=3406QDB01D@3@0D3``05A0=01<>2`02018=2P0601TD
4@0O6QL050l<01<>2`0@2`P03`X70`0@2`P2014<2@0;01<>2`0A30T03`X700l:1`0A30T04`h;010;
200A30T040/800l:1`0@2`P00P0B3@X00`0A30T040/800l:1`02010;2003010:2P0D3Ph0BdE50080
3PP800H03@L7010:2P0?2@T03`T901@>3P0;1@D4014;2`0300l92@0B30`04@/;00L03`T900H02`D5
00`61P0@2PX040X:00h8200=1`L2010:2P0300h8200=1`L03PP8008040X:01003PP8018<300;1@D0
3`T900d71`0B30`040X:014;2`0@2PX03@D60147200B20T04@L801061`0B20T04`T:0P0@1PL0800A
1`P03@<400h41@0C2@X03`D600/10P0E2``04PP9034W:00F30d050X;01882@0@1PL04@L801<92P0F
30d02`8301T?400N51D0AS`m01L=3P0@1PL05@/<01L=3P0D2P/060h?0557B00C2P/03`T900d71`0C
3@d06Q@D0P0E3`l02`0X8R804@/;01LA4@0K5AD03@L701061`0E2``05P`=01D;300Q5aP050X;00H0
4@L800h040H700h41@0>10D04`T:01@:2`0@1PL03P@50147200C2@X03P@500d3100A1`P030820106
1@804PP700T050/:00d30P0F30/04@L600d30P0>10<04@L601881`0?1@@00P0@1PD301471P0600d3
0`0>1@D06Q0?03P`;`10=SD0BCln5?ooool001_ooooo00l040h?00l=3P0F51D03@/<02@R8`0M6a`0
30X;014?400B4140108301hL7@1WIFH04`l>018>3@0C3`h00P0D40l4014=30@04Ph=018040`;01<?
3P0B3Pd040`;01<?3P0I5A@04@d<010<2`0E4A00510?01lK6P0C3`h04Ph=010<2`0G4a8071PG01XF
5@0A3@`201@@3`804`l>00h04Q0A00/=3`0=3Q00410@00`;300>2P/07a/L01TF5`0<2P/03@d=01lP
7`2k_l00?3`l01TE50805Q8A0P0H51<201@@3`09028N7@0E4A0040`;010<2`0L61L061@C01@@3`0A
3@`040`;00804Ph=01<04`l>014=300>2PT05Q8A01@@3`0E4a407QdK01TH5P0@3`d03`h<00h=2`07
1PD04Q4?00P71@0<2`T04Q4?00D40P0:20H040`9008061@A00T081`I01TE4P0D40d040`901<?300F
4Pl04`l<018>2`0C3``00P0B3P/00`0C3``04Ph;010<2@0201HB3`0F01DA3P0D40d04`l<01<?300D
40d04`l<018>2`0A3@X04Ph;01@@3@0E4@h04Ph;010<2@0D40d05Q8?01<?300A40/04a8=00l>2@0F
5A003`h901<B3@804Q4<0P0A40/2010?2P0<01PG5@0>3@/04A0>01<B400@3`d05QDC018A3`0A40h0
3`h<010?3@0B4@l051<A0P0B4@l0100>3@/040l=01HE4`0C4Q02014@3P804Q4?0P0C4Q008@0I5aP0
5A@E01HF5P0P82007QhN00L9200?4A0000@301HJ6@093@`03A4@00d?3P0E5A<04Q4?02LV900F5A<0
5aHD02HU8`0D4a405A@B01<B400I61H06aXH01LF500G5aD05QHD01DE4`0@40h04a<A01XJ601:BTP0
1`L501`L6P0201DE4`0301`M600E5Q005QLB008061TD0P0F5Q@04P0J6QP04A4A01PH600R8R80E5AD
01LH5`0C5A@05QPG01/M700P8R406QlK01<H500C6Q<05A`E01LO600E7aH04adE01@K5@805a/J01/0
5QXI01DI600H71/05a/J01XN7@0O8b807B4P01lS8P0Q9B@07R@Q01dV8@0I8Ql06B8Q038j?00N9B/0
8BP_01lV;P0F7B<082P/01PP8`0T;2h08BHZ01hS9`0Q9RT08R/Z01lX9`0O:BH00P0R;2/03@0^>C/0
=3m502/f?00T;cP082lf01//<`0U=Sd08cDi02Hh?00[?D40:cdo02`n@00^@4800P0^@400H@0aA4<0
=DQ60395@@0`@d80<TA603A6BP0dADd0>DYD03M8DP0iBU@0>daD03Q9D@0iBe80?U5E03M<C@0kD540
@EII04=HG015FUl0A5QO04]OI`15FF80CV9]06=fP`1NLW/0CfAW04YOH01CJ6T0GgAg055VJP1>HfP0
CF5X04iRJP1DJ740EVYe05=WLP1DJ6l0Efa_05I[J@1GJfX0Ffm^05iaL@1NL700HWAd06AeM@1XN7P0
JWYj071oO`1cPH80Nh^;07F5Q@1hR8P0Q9:C08:@T@1lRX/0R9>E08VDUP2;UYP0SiVK096KW@2BW9h0
V:2S0:6VZP2NXjL0WZ>Y0:R[/P2PXjX0[:nh0;Bd_P2b/[`0b<SD0=;@g@35`m00a[oA0<W2e03<aML0
dl[M0=S<h03Jc^80g]3T0>GCj@3WeN/0j]S^0?3Ml`3dg_D0nN3k0?cRn`3miOd0onSn0?k[oP3nk_l0
o_;o0?oco`3omol0oo[o0?olo`3oo_l02`3oool0103oooh0oook0?ooo@3oooh20?ono`0W0?omo`3o
nol0ooWo0?kgo`3lm?l0o?;m0?g`o`3mk?l0o>Wm0?_Vo03ihOT0mmgf0?7HkP3^enT0i]7O0=_:e03I
bM<0eLO>0<o3a`3<`<@0aKZk0;fc/@2d[JD0Y9jC09jJSP2GUHP0Rhan0:b^X02VZ9X0TI>507IiIP1e
N6<0L7=P07UlJ`21QG@0N7a]07^1L`1jP780N7ib0080MGeb0480MWif06mnN`1YNGP0IgMf06EeM01R
LW40I7Aa06=cL01QLV`0G6eW05AUG`18FE80?Te603U6?`0kB440>TM002@_:@0a?3H0:C@^02lh<`0V
;bX07BHQ038h=00R:2@09bdY02dd;@0W<BT0=d@m03I2?P0iBDL0=4A30313@@0eAdD0=TI303=2?@0]
>SH0:SD_034k<`17CTL0<3L`02<Z8`0/<b`08bXS02T`:@0^=Bh082LP024X8@0[<R/04Q`D01XT8@0M
:2@0=T4m020Y9P0]=S<06B8O020V900O8b80720O02DY:00O8b80724M01XQ6`0F71P06R0L028X900R
:2H201lU8`0e01lU9@0Q9bL092XZ028W:P0P9RH08BLV01/O7P0B5QD07b<R01PJ6@0Q8b80:B/Z020P
800S8b<0820P01/K6`0N7Qh07b4P01hP7`0L7Qd05ALF01PJ6@0J71/04aDD00`>3@0D5QD05QPG014C
4P0H61D04a8>00h=2@0U92005QDA00H50@0L6aL06APD01<B3P0I61@05A@@010?2`0L6AL071HF01TE
500D4a404A4?010B3`0C5A8051HC01@D4P0C4@l04`l>01LA4@0I51<00P0G4a002P0E4@h040`901TE
4P0K5a@0:BDR05YFD`0I5A804`l<014=2P0G4a0201HB3`805a<@0P0D40d02P0B3P/040`9018>2`0C
3``04Ph;014=2P0@30T04Ph;01DA3P0F4Pl201DA3P0:01@@3@0?2`P030P501TE4P14@3d08QdJ01PC
400C3P/061<@01HA3P804@`900L05Q4>01dH5@0C3P/03`X700P3000>2@H040/800<04@`900<040/8
014<2@0A30T00P0@2`P2014<2@0600/60`0C3P/04Pd:00/60`0=20D061<@0P0A30T04P0?2PL03PT6
00l:1`0?2PL06Q@D024K6`1kMGD04P`<01@>3P0C3@d02`D5014;2`0E3`l03@L700@0000A2`/03`T9
00D000805Q0@00<07QPH00D0000?2@T01@0?2@T03P0A2`/07aTI01hH600B30`03`T901<=3@0A2`/0
40X:00l92@0=1`L03PP8010:2P0:10@02`D50`0=1`L03P0;1@D03`T900D0000=1`L03PP800l92@0F
3Ph04`T:00h41@0?1@H04PP901061`0?1@H04PP90P0C2@X00`0A1`P04`T:01D;300200h41@0T0188
2@0?1@H07A<D01@:2`0F30d04`T:01061`0B20T05@/<01P>3`0C2@X06@l@00`30`0L4Q<02P0101T?
400>10D03@<401882@0700008aTJ00d41@0?2@T02`D500`61P0?2@T02@<300`61P0N61P04`d=00h8
200C3@d030H601@:2`0B20T06@l@0P070000200A1`P03P@500h41@0@1PL04PP901<92P0D2P/04`T:
0P0A1`P201@:2`0400h41@0A1`P04PP901<92P8040H700l04@L801D;2P0=0`804`T801lE500b:2L0
4@L600T0000A1`H05@/:01<9200<0P80200000h40`0@1PD00`0A1`H01`0@1PD07Q@C01L=300<0P40
=2XY06iTH`3Vg=/05?ooool001_ooooo00L04Q0A010>3`0H5QL03@/<02TW:00O7Ah05A<D00803`d>
00T01P@5028P8@1]Jf`04Ph=014=300C3`h0510?01<?3P0@30/00`0C3`h4018>3@0B010<2`0C3`h0
4Ph=010<2`0C3`h03PX900L30P0C3`h05a<B00L30P0@30/04`l>018>3@0@30/05Q8A01XF5@0G4a80
40`;0P0B3Pd06@0C3`h05A4@01HD5@0B5QT0310C01@E5`0;2`/03@`:010?3@0B4@l06QTG01DE4`0T
9bH0cm?D04=4A00?2`X03@T801<?3P0>2PT03@T8014=300E4A003@T8010<2`0<20L00P0E4A00700D
40l04`l>014=300A3@`04Ph=010<2`0I5A@06aLF00h:2@0?2`X04@d<01DB4@0F5A<04a8@018A3`0>
3@/040l=014@3P0N7A/03`h<00d<2P0N7A/051<A01TG500E4@h03@T601<?300J5Q<2018>2`05014=
2P0E4@h05Q8?018>2`0E4@h00P0D40d0100C3``04Ph;018>2`0E4@h201LC400301HB3`0D40d04`l<
00L04`l<00X0510=014=2P0@30T05Q8?01LC400B3P/03@`7010?2P0A40/06aXE0P0?3PT2018A3080
4A0;0P0@3`X01@0G5Q@04A0>00h=2`0@3`d04a8@008051<A00/04Q4?010?3@0A40h051<A01HE4`0?
3P`04A0>00l>300A40h05QDC018A3`02014@3P804Q4?0P0C4Q001`1>C4d071XK01HD5@0Q7b005aLG
010@400F61L00P0G6AP0400=4A008BDT01HH5`0@40h06APF040o?@0V9B<02PT700l>300H5aD05QDC
01@C4@0K6QP07ahL01/J600D518201HF5009014A3`0J6QP0:2PV05]KF@061P@051@B01DE4`0H61H0
414<008061TD01P06AXE01XK5P0J6QP06QXH01TI5`0E5AD06QXJ028R8P1:BTX07QhO01lP8P0J6ad0
5QLI01`N7@0G71P04QPB01DL5@0F7AH05QhF01<M4P0B71<04aXD01HJ6@0H71/201HJ6@8061`K0240
5QXI01TM700H71/05QXI020T8`0T:RL07BHQ01dV8`0O9bL06b<U00T@5P0V;C@06B0X01TP9P0M92T0
9Rha01`T9P0O9bX07BDX020X:`0S;2/07bPW01lY:00U;bh0930^03@o@@0iAT`0;CY002Hc>`0S<ST0
93Dl02Xk@P0/?T800P0Z?4003`0[?Cl0;3i002do@@0]?cl0;T1003A6A@0aA480<4<o0354@`0eAdT0
=dU=03Q9D@0cA4h0>T]E03m@FP0203]<E00403Y<D`0oDUH0>e1C03eBE@80?U=H04l0@eQM05IZL@1<
H6P0AEUR04YNJ@1?Hfh0B5aU04]PH@1HKV`0DFMU05I[K01=HV@0CF9W04eQJ01<H6P0E6Qa05EYM01C
Ig80Ef]b05M/K`1GK6X0FFe/05eaL01PLg80H79b06=eM@1VMgL0JWYj06emO@1bPH80MH>407N5QP1h
QXL0NhV:082>S`23SY00PXf?08VDUP2;UIL0SINI092JW02CVih0U9bO09RMX@2MXZH0WjBX0:NZ/@2V
ZK00[:nf0:j^^02d];h0/k>m0=?AgP3OgNX0cL_H0<S1d`3<`mH0clKI0=O;g`3Lcn<0g]7U0>7Bi`3W
eN/0j=K/0>_HkP3_g?80m=ke0?[Qo03mho`0o^Kn0?oYo`3njoh0o^ko0?kbo`3om?l0ooSo0?ojo`3o
o?l0ooko00/0oooo02d0ooon0?ooo@3oood0ooon0?ono`3ooOl0ooco0?ojo`3on?l0ooGo0?gbo`3m
lOl0o>oo0?c[oP3jio/0nNCi0?OOm@3cfo40k]O[0>gFj03QcM/0e/K@0=K9dP3Eb<l0cl?70<c0a034
^[X0^[2^0:nXX02TWY<0ZJFI09VGR01oP700W9j@08j@PP21QGH0LWET07EhI@1cN6@0Oh=b0824L`1e
NV/0LGMY079hK01bNVl00P1aN700>01_Mfl0KGUg06MeM@1VM7@0IWEb06=bK`1UM740IWE`069aK01J
JF<0DF1I04IECP0mC4D0=44j034l=P0d?cT07BPR02Td;P0/=c40;CHa02Tb;@0`>C@0Ae1;02@]:00/
=C00:cD]02lj<`0W=2d0=D4m03E4@P0eB4H0>4]903Q:A`0eAD80;chi02Pc;P0Q;2H09S0X034h<@0R
:B806R4J024X8@0N9Ah09bhW020W800f?CH08RTR01hU7P0b?3@0;CLd018M6@0Z=C409Bh[01LP7@0F
7a`07R@R0P0X;2/0600Q9B@082@S01LL600K8A`05adI01TO6`0O9B408BLU020V900O9B<07R@T01lU
9@0S:BT08bP[024W9`0F71/0;S8a02P/:`0P92<07AlN02LY:00U9bH092@T02LW9`807AdM01d0:BTY
01hP7@0N81d0828O01XL6@0I6aP071hK01hP7@0F61D07R0M020R7`0N81d07AdJ01HE4@0O7QX0>CPd
02PW8`0K6QH07QdI01lN6P0H5a<06APD01XI5@0D4`l04Ph<010:2P0F4Q406APF01TI5`0201LI5P08
01HH5@0D51805A<A01HB4@0G4A405a8A018>2`0@30T201HB3`0501DA3P0D40d0?c/h065MFP0>2PL0
0P0C3``0700?2`P02`L400/7100C3``05Q8?014=2P0E4@h04`l<014=2P0C3``0510=01<?300?2`P0
40`9018>2`0@30T03`/8010<2@0A3@X04Ph;01@@3@0>2PL02@D2014=2P0K5Q<050l<014<2@0C3P/2
018=2P0<01@?300B3@X05Q4>00l:1`0B3@X030L4010;200B3@X04`h;01@?300C3P/04Pd:1P0@2`P0
2P080`003`X700l:1`0=20D04`h;01dH5@0A30T040/800l:1`0>2@H200l:1`0B01@>3P050000:bDU
00@0000@2PX03@L700`61P0B30`04@/;01@>3P0;1@D03`T901LB4P0>20P04P`<00P20P0E3`l06Q@D
1P0?2@T01P0;1@D05Q0@01<=3@080P802P@4014;2`803`T90`0@2PX04`0?2@T050h>01PB4P0B30`0
1`4101H@400O6AT04@/;00L10@0F410030H600X4100G3`l050X;01<92P0D2P/04`T:01061`0A1`P0
0P0D2P/02`0@1PL03P@500h41@0@1PL02P0101882@0@1PL050X;01061`0E2``050X;00804`T:0`0B
20T07`0@1PL03P@501H<3@0I3a003`D601D;300;0@803@<401D;3009000040H701892P0A2`/03`T9
00d71`0?2@T03@L701@>3P0400004@/;018<30080P80618B04Y0@@0H3Pl0200001<92P0E2``040L8
00l51P0@1PL00P0A1`P00`0B20T04`T:01<92P0301882@050147200>10D05@/<01<92P0B20T00P0C
2@X06@0A1`P03P@300`20@090@0050X901lE500900004@L601lE500V71/081HE01H<2`0D2PT03P@3
01061@0A1`H04PP701471P0@1PD01`0000P0000L4Q404`T801L=300Y7ah05?ooool001_ooooo00l0
4@l@01DC500;2@X02@L8018@4@0E4a@0GeeN01<A4P0G5AH03`d>010>3`0J61T03`/:01<?3P0D40l0
100B3Pd00`0D40l04`l>014=3002010<2`0301<?3P0B3Pd04Ph=008040`;0P0B3Pd0200D40l0>cLf
048n?@0=2@P0510?018>3@0A3@`03`/:0P0@30/08@0=2@P040`;00d9200A3@`04`l>020L6`1>C4d0
L7Ah01@H6`0F6Q/04Q8A01PG500B4@`03@`902HW8@0R92004aHC020V900F5aH06ADD014=300?2`X0
5A4@01<?3P0a;B`07QXI01<?3P0A3@d05a<B01`H5`0B3Pd05Q8A01@@3`0201<?3P04014=300H51<0
:bLV02/W9P805A4@00@05a<B018@3P0@3`d03Pd;0P0@3`d00`0C4Q005QDC00D40`02010?3@0N018A
3`0F5A<04@h<01`H5@0A3@X05Q8?010<2@0E4@h05Q8?01DA3P0G4a005A4>01<?300F4Pl04@d:01TE
4P0M6AH04`l<014=2P0H51405a<@010<2@0E4@h040`901XF4`0C3``04@d:010<2@0E4@h04`l<0P0F
4Pl201DA3P805a<@01@05Q8?01<?300C4Pd04a8=01dL5`0K6QD051<?01LF4@0F5A406QTE01@C3P0@
3`/04Q4=014@300D4a4061LE018A3`0E51806APF00d<2P<04Q4?00T04a8@01@C4@0E518051<A018A
3`0@3`d04a8@01DD4P0A40h0100C4Q0201@C4@0I04i;C00M6Q/04@h?01HD5@0B41406a/K01@D500J
71/0J6YY03Pk>P0Z;B`030h=01@C4@0>3@/061LE01DD4P0G5Q@061LE01DD4P0C4Q004Q4?01<B400G
5Q@06QTG01HF500201TI5`0Q01HF500M7A/09bLU01`L6P0c<c407AdK01DE4`0J6QP051D@01@E3`0H
6A@05AHA01XK5P0H61H05QHD01@D4P0D51@071`L00d=3@0M7Ad0=SHh04I7B`0Y:R`05QLI01HH5`0I
7A`04QPC01LN5`0I81P05QhE018L4@0G8AH05A`F00805a/J02P06QhM01/O7P0J7Qd06QhM01TM700O
8b80720O01@H5`0Q9B@09R`Y01LP6`0I8Ql07RLV01LO8@0W;S@0H6M^01lV;P0P9bd07BDY01`T9`0L
92H08BT/01lW:`0P:B`08BX/020Z:P0R;B/09S8a024];@0W<cH0;CY002/h@00R;cP08S4h02/l@`0W
>3l09cTm02m1A@0Z?400:cdo0P0^@4805P0^@400<D=303A6A@0bAD<0<dI203M9B00hBT`0?e5E06am
Q@0hBE<0>T]E03Q9D`0`@DT0@U=K03a>EP0lCeD0?eAH045FFP10EEX0@5EK04QLHP1@I6/204MKH`80
BEeW01P0CF5X04IKG01CJFL0BV1N04QMGP17G5h0Bf1S05=XK@1<H6L0E6Q`05Q/M01DJ780F6ac05U^
K`1JKfd0G71_05ibL@1OLW80Gg5a06EgM`1XNGT0KGem0720P01cPX8207J4Q@0;07^9RP1nS8d0Ohb=
08JAT`29U9H0RiJH08fFV02>UiT0T9VK09BLW`2FWZ400P2JWZ<08P2LX:D0YJR_0:FW[P2^/;L0/[:l
0;Fd_`2c/[`0`l3>0<[7e02n^/P0b/?E0<o6f@3BbM`0f/kR0=kAi@3PdnL0iMGZ0>WFk03Zf>h0kMW_
0?7Ml`3egoH0nn;m0?kTo@3oiol0onWn0?o/o`3ol?l0oo?o0?odo`3on?l0oo[o0?omo`3oo_l;0?oo
o`1E0?oooP3oood0ookn0?ono`3ooOl0ooco0?oko`3on?l0ooKo0?oco`3ol?l0o^oo0?g]o`3kjOh0
n^Gj0?WRm`3fgo<0l]_^0>cFi`3Xe>40fl[F0=74c@3Cb=00d/S>0<^o``35^[`0`;Je0;J_Z@2XXIT0
XIfA0:FSU028RGP0Kg5O0823L`1mP740OX9c07AgIP1bMV@0MW]X07^1L01jOfl0M7]/06Q_H`1[LVH0
KgM/06efK@1[Lf/0J75Y06QdL@1WM7<0JGIe06MeLP1TLFl0IWA`06=aK01MJfD0EfEN04eKD`13DDT0
KGYb041;A@0T;RP09S0[02<]9`0U;bX0:C<^02La:`0^>380=d4l04QBC00/=S00;SPb034k=00jACl0
;c/g03M6@`0`@Cl0<4=103a?C@0/?C/08c8_02Te<@0Q;2H0:c@^02/b:`0302H]9P0`02D/9@0X;bP0
<CPa02H]9P0Y<2T07RDN02@[900T;RH0BUAA02Lb;P0b?CT09Rl/01TR7`0P:BH082HT030d<`0[;bh0
6QhM02<W9P0R9b<07RDO01dS7`0L8Qh07B<O020V900Q9bD08bTW01/Q8@0M8b<08RPX01lT9`0c>CT0
9R`[028V9@0P92<0720O01`N7@0N81l08B<R01hN7P0Q8B407AdM020P800Z:RX092HS01/M6P0Q8b00
7AlL0P0J71T0?@0I6aP05ALD01/M6P0J71T06A/H01TJ5P0I61@081lK01`K5`0I61@07A`H01HE4@0L
6aL06aXF01PG4`0I61@05QDA01PD4P0H4Q8061@C01PG5@0?3`d092HS05aNF`0U9b@06a/I01HD4P0J
5QD05@l?01TD4`0C3``05A4>02DQ7P0V8Ql04`l<01@@3@0K5a@061@A01DA3P0@30T04Ph;01HB3`0D
40d04`l<01LC400I5A805a<@01DA3P0C3``040`901DA3P0I5A805Q8?01@@3@0G4a005Q8?010<2@0?
2`P0510=018>2`0A3@X00`0@30T06@0B3P/03PT6010;200B3@X03`X700d81@0D3``04`h;014<2@0C
3P/04Pd:01D@3@0C3P/050l<018=2P0E40d06aHC01XE4P0C3P/061<@010;200B3@X04`h;010;200?
2PL00P0A30T2010;2003014<2@0B3@X05Q4>008040/801D04@`900l:1`0A30T04P`<00l92@0A2`/0
3`T901@>3P0@2PX04`d=018<300<1PH05@l?018<300@2PX0=S4a01`F5P0;1@D0:bDU01<=3@0=1`L0
0`0@2PX02@0?2@T03PP800h8200B30`03`T900h8200@2PX04@/;018<300200d71`0C014;2`0D3Ph0
3PP800h8200B30`02`D501<=3@0B30`030H600X51@0?2@T05a4A02<M7@0D3Ph02@@400l71`0A1`P0
5@/<01H<3@030147200`01D;300C2@X04PP90147200@1PL050X;01061`0F30d04PP901D;300<0`@0
60h?02/Q8P0J41404`T:01882@0C2@X04@L801D;300?1@H050X;00l61P0B20T04`T:01@:2`0F30d0
4@L801@:2`0?1@H03`H700d71`0E3`l02P@401<=3@0@2PX030H6014;2`0@2PX02P@400h8200A2`/0
81HG00d41@0@1PL060h?00l51P0C2@X03`D60P0B20T0700A1`P04`T:0147200?1@H040H701@:2`0A
1`P03@<401061`0E2``04`T:0147200B20T04`T:0147200<0P8060h=01<9200@1PD05@/;01@:2@0<
0P4050X901D;2P0@1PD03@<301471P0?1@@201061@804@L600L040H501881`0C2@P030<301D;2P0?
1PD04@L601Cooooo000Kooooo`0@00H41@0J61T06aTJ01`J6`091`P05aDF03Hd=@0<2P/04a4B00/9
2P0C4A804@l@02<O7P0L61L04Ph=014=30<04Ph=01403@T800`81`0C3`h05A4@01@@3`0F4Q405A4@
01<?3P0A3@`04Ph=01@@3`0E4A00100000d9200M6AP020@300l;2P06014=300O01LC4P0>2PT02`L6
00X61@0F4Q40BTQ905MJG`0@51L05AHH014B3P0H5a8051@<01/K4P0D50`020T3014E3P093PX03@l<
014=300>2PT06QHE014=300D40l0PWim03`h=`0A3@`061@C018>3@0810<061@C01TE500201PD4`0F
01LC4P0@30/0510?01dI600K5aH03@T801<?3P0E4A003``;01<B400D4a404A0>018A3`0A40h03`h<
00`;2@0F5A<04A0>01DD4P0F5A<04a0>02dY9P804`l<00<02@D201HB3`0A3@X01@0A3@X0100>2PL0
61@A01hJ5`0E4@h2018>2`0:01HB3`0;1`@04`l<00h:1`0300004@d:018>2`0@30T05A4>00l;2080
510=0P0C3``01`0@30T03`/8010<2@0F4Pl09B@P01PG4`020@000P0H5a<03`0F5A404a8>01XI5@0F
5A4040l;014@300B4@d04Q4?01PG5@0C4Q004Q4?01<B400I61H03`h<014@3P0301<B4007014@3P05
10805A@B01XI5`0C4Q003@`:010?3@0601@C4@0=01LC500E4A80510A018@4@0D4Q<05aDF01<C4`0I
6AT0ATQ703Tk>P19BdX0418A01DD4P0201<B400F01@C4@0E51805QDC01DD4P0C4Q0051<A01LF500U
9280<S4_01LG5@0I6AL061PF01@D4P0C4a4051@B01PH5P0g=cD05aLE01TI5`0@40h05aPC01LH4P80
61TD03`05QLB01LG5@0[:bT07AdK01TI6@0H61P07alO014A4@0I6AX08B8T01PI6`0N7b406A/J01/P
700A5a404aXC01@K500I8AT05AlD01hX7`0N9Al061`K01DI600K7ah0720O01XN7@0N8R406QhM00`@
3`0F6QT08BDT01lS8P0O9B804Q/F01DN6`0M9RD04a/M01TP9P0U;3<09bhf020W;@0N9RX0<c/n01/S
9@0S:S008RT_020Y;@0O:B/08B//02<_;P0[=cL0:C@f02Tg>P0R;cL07b`d02Pf?`0V=ch0:CY102Pi
@00W>Cd202/m@@0P02Xl?P0^@480;T1202i0@00cADD0<TA302i1?`0X>cL0=TU803a>D00cADT0G6ee
03M8DP0cA4h0=4E?03I7C`18FF40>TaD03]>E013F5d0AU]P04EJG`17Ff40C61W041DF`12EUd0AEUP
04MKI01:GVL0BemV04UNH@15FUX204IKG00D04QMG`1AIVT0FFic051UJP1JKg@0GW9i05EYL01DJFh0
F6e^05]`K`1OLg80H7Ac069eM01RM7@0IWQh06MhN01^OWh0LX:207B3Q01kRHX207f;S00A07b:R`22
SHl0QY6C08RCU@2=UiT0SiNJ08jFV@2?UiX0U9bO09ZOX`2JWJ80VijS09fPY@2TYjh0[:bd0:n_]`2_
[kT00P2h]/406`2n^/P0a<3>0<C0cP3<`mH0d<OJ0=?:g@3Jc^80g]7U0>3AiP3Ve>X0jMK/0>[Gk@3^
f>l0lmgd0?SPn03khO`0o^Cm0?kVoP3niod0o^_n0?o`o`3olol0ooCo0?ogo`3on_l0ooco0?ono`0;
0?ooo`0Z0?oooP3no_`0oogn0?omo`3onol0oo[o0?oio`3om_l0oo;o0?oao`3okol0ongo0?gZo`3j
iod0nN?h0?OQm@3dgNl0l=WY0>[Eh@3RdM/0elSB0<o4c03?aLd0c<;90<Jm`02l/[<0]JbZ0:jWX@2S
Wi@0ZJJH09RIQ`1lOF/0L7=P07YnK@22QWD0Oh=d07UmK01]LF00LGET06ieI@1`MfL0LGMY0P1]MFP0
1P1/M6T0JG=Z06UcJP1YLf`0IG5]06EaK`80Ig=a00l0IW9^069^JP1TLFX0EfAM04AABP17E4/0<d0g
04]FCP0c?3L07bPS02@]:00X<B`082TT02@]:00R;BL00P0X<bd05P0`>cD0;3La030k=@0Z=Bl0:SHa
02<b;@0P<2d09cTf0395@`0gBTP0;chl02@c;P0[=S00>dHn01DO5`0L8a`0:C0Y010G400M91d0?4<l
02`c;00W;RL202H]9P0D028Y8P0Q:2409c4Y024[9`0_>SH0DEaH02Xc<00P:BH07bPU01dS8@0V:RT0
92PW028V9@0Q9B@07B8N01lU800Q9b<082HR01hT800N9282020V900M02<Y:@0P9RH08RPX02db=@1M
Hf<0Be5@024U900H71/06QhM024S8P0W:BP09BLV01XJ6P0K6a/07QhN01lO7`0Q8B408bDR01DG500M
7a`06A/H01HH5@0K7AX061XG01LI5P0I6aP05ALD01HH5@0I6AH00P0H5a<0700I61@061LC01LF4P0I
61@05QDA01XI5@0I61@04A0<01HE4@0K5aD071HF01hJ6@0@3`d061PF06U[J03Zk>T0D59?01LG5@0@
3Pd061@C00H0000E40h05A4>01@@3@0F4Pl061@A01HB3`0E4@h201`H5@0601@@3@0C3``05A4>010<
2@0A3@X04Ph;0P0?2`P0500A3@X05A4>01HB3`0B3P/05Q8?01dI5P0I5A803PX700l;200B3P/061@A
01XF4`0D40d040`9014=2P0F4Pl0510=00d91P0@30T04`h;0P0D3``01@0A30T040/8014<2@0?2PL0
4@`9008050l<00l04`h;014<2@0B3@X030L4010;200G4Pl050l<00P3000=20D030L400l:1`0@2`P0
3`X7018=2P0@2`P00`0A30T06P0@2`P03PT601PC400?2PL04@`901<>2`0A30T050l<01<=3@0P6QX0
8adM00d71`0:1@D06aDE010:2P0C3@d04P`<00/51@0:10@03@L7010:2P0/9RH0618B02XT900D3Ph0
5@l?0`0?2@T3010:2P0400h8200?2@T03`T900l92@<040X:00T04`d=00h8200>20P03`T900d71`0B
30`030H600X4100=1`L00P0@2PX03@0>20P04`d=018<300>20P03@L7018:2P0?1@H02P0100l51P0E
2``050X;01882@0E2``00P0?1@H04P0@1PL03`D601D;300A1`P040H701882@0C2@X04PP901T?400b
:2T05P`=0147200@1PL05P`=01<92P0A1`P03`D601882@8050X;0P0B20T02P0C2@X04@L801061`0B
20T05@`=00l92@1_JFT0RhF501<=3@0E3`l200l92@0>00h8200=1`L03@L700h8200A1`P05`d>0106
1`0C2@X050X;01L=3P0?1@H04PP90147200?1@H201D;300601L=3P0;0@803`D601X@4@0E2``04PP9
100@1PL02`0B20T04`T:00h40`0B20L04@L600h40`0B20L04`T800l5100B20L04@L600803`D40P0A
1`H01@0@1PD03`D400l5100@1PD04@L600H040H55?ooool001_ooooo02@04Q0A00l=3P0J61T07A/L
00h<3@0:20T00`42014?400<2P/02`T:014?400?3@h0<2`[01`H5`0>2PT040`;01<?3P0?2`X0:RHU
01PD4`0>2PT05Q8A01DA400?2`X05Q8A01DA400D40l04Ph=01@@3`0G4a8061@C010<2`0<20L04Ph=
01<?3P0H51<3014=30<04Ph=01P040`;01<?3P0C3`h081`K03<_;P0o?Ch05aTN014B5P0<30`03`l:
01DB2@0B40@03@`1014A1`0J71403Q0900T>1`0@40d040`;00d9200E4A0030P700l;2P0e<C0200L3
0P09014=300E4A001@40014=300F4Q404`l>01HB4@0E4A0040`;00<0510?01D040`;018>3@0E4A00
4@h=014@3P0C4Q004Q4?01<B400A40h030/901TH5P0A40h03`h=00l>300B4@l04@l<020L6@0D40d0
6ADB00`81@0=2@H01P0C3``0=P0A3@X05A4>01@@3@0D40d05Q8?014=2P060P006aLD01DA3P0N6QL0
6ADB010<2@0E4@h04Ph;01DA3P0>2PL0510=01DA3P0D40d04Ph;010<2@0B3P/04`l<01@@3@010000
5A@B01@C4@0R8Al02PT701PG5@0>3@/04a8@01TH5P0E518040l=01<B400J6AL0@T4o018A3`030P00
71/I00<2000A40h04Q4?01<B400D4a404a8@018A3`0N7A/05QDC010?3@0A40h04Q4?00l>30H051<A
0P0F4Q<03@0E4A80510A01<@4@0B414061LG010@400I6AT02PX:01DG5P0H6QT061LE01DD4P0D4a40
0`0B4@l01`0H5aD051<A01@C4@0C4Q0071/I02LV900D51800P0H61H03P0D51804A4?014A3`0C4a40
7AdK01LG5@0N7Q`0410>01LH4`0F5a404Q<>01`M600G61<08b<Q0P1>CT`0500E5AD05QHF00T92@0M
7Ad05QLF01LI600C5A@05aTH01<E500M8Qh06b4M018I4P0@5a0051`E00/E300:50`061lI01PL6`0G
6aX0720O0P0K7ah0FP0M8B007b<R01HJ6@0^<S40=CTh01hR8@0P9R<06B8M01PQ7P0R:RX0620R01@K
8@0O9Rd08RTa01XQ9`0h@4@06B4T024Y:`0S;3408R/`024Z;P0O:R`082`/02<_;`0J:2T06BLX02@b
=@0Z>D009cHm045?F00X>D00:S]202Lh?`0U=c/0:C/o02Xl@00Z?3h0;Cm102i0@P0^@400<TA40395
A00^@Cl0;T4m03U;BP0lCU00>D]?0393B`0dADl0AeQR059SK@0lCED0=TM?03i@E`0jCE@0@5AK04EI
H014F5l0AUYQ04YNI@12EUd0@5AK04AHG`19GF@0BemV04QLH`19GV40AEYL04EJG@16Feh0Bf1S05I[
KP1IKW40E6U/05ebM@1PMGX0EV]^05=XJ@1EJV/0FFi]05ibL@1QMG@0I7Mg06IhN01[OGd0JGYj06in
OP1aPH40MHB407f;S0<0OhZ<00@0PXf?08NAT`29TiD0SiNJ0P2@V9/02P2CV9`0V9fQ09^PY02LWj@0
WZ6V0:2SZ02XZ;00[Zjf0;6a^@2c/K`20;^h``0K0<2lbP36`]00a/;@0<c3eP3Ba]X0e/[N0=_>hP3O
d>D0h=7V0>GCj@3Ye^`0jmS^0>oIl03egOD0n>3h0?_Qo03ni?d0o^Kn0?kWo@3njoh0onoo0?oco`3o
m?l0ooOo0?oio`3onol0ooko00/0oooo00D0ooko0?omoP3ooOh0oocn0?ojoP020?oho`1V0?oco`3o
l?l0onoo0?o]o`3ojoh0o>Sm0?WVo03hh_L0mMkc0?7Jk03]e^H0i]7M0=o>eP3Ealh0c<790<c2bP36
_lD0aKbo0;Za/P2bZjL0[:FM0:>OU02WY9H0QhQf07EfI01eN6D0OX9a08B8M`1jPFl0M7]Y06U`GP1]
M6@0KWEU06mfIP1_MfT0LGU^06eeJP1VL6L0J79Z06afKP1[MVl0Ig=_06A`KP1RKVX0I71/069^JP1H
IEl0D5eF05MTG@18ED`0A558034n=@0[=Rh092dX020V8P0W;BT0:S<^02L`:`0R:bH08bhX02Ha:`0^
>C<0=T<l02hk=00gA3d0=D4m03A0?00Z>C@08S8_02Hh=P0bAD<0;Cdl02Lf=013DTd0>D@n02D`:00[
<RX0<cXc03Dl=@0P9b00>D0i05mVG`0f?CH082LP02<Z8`0X;bP09B`U024X8@0U;bL09Bl[02Lb;P0i
A4008R/X02D^:`0S;2T08BLU02T];00W:bX09BTX024U900N8al08BPR0P0T:RH04@0P9R807bDS01lU
8`0e>cT09bd]01dS8`0Q9bL06QlR02dc<`0P9RD06AdL02<W9P0W:bX07R0O01XL6`0O8B006QXJ0080
71`L00l07AdM028R8P0J71P05QPC01hP6`0H6QD05QPC01/M600H6QD05QPC01LI500E5a805aTD01TI
5@0G5Q801@0H5a<04P0@3`/05QDA01PG4`0<2`L04A0<01PE4`0I4a<07QXI01TH5P0D5180;S0]0863
P00W:BH03@d;018@3`0M6AP050h>01/F5@805Q8?00H040`900h:1`0G4a005A4>01XF4`0K5a@601@@
3@804Ph;01H05Q8?014=2P0C3``04Ph;014=2P0E4@h0510=01LC400D40d04@d:01<?300F4Pl061@A
00h:1`0=2@H05Q8?01DA3P0<20D04Ph;01D@3@0C3P/040/80P0B3@X200l:1`04018=2P0D3``050l<
01<>2`804@`900P040/8018=2P0F4@h04`h;00`7100?2PL06A@A01D@3@803PT60P0A30T2018=2P06
014<2@0@2`P03PT601D@3@0?2PL040/80P0B3@X01@0D3``02@<3010:2P0G4A407ALG00<04@/;00@0
30H600d71`0F41004P`<0P0<1PH01@0O6AT05Q0@01<=3@0;1@D04P`<00<03PP800@04@/;01@>3P0F
410040X:0`0?2@T200h8200C00/51@0A2`/030H600T4100F41003PP800d71`0G4A4040X:01<=3@0D
3Ph02@<300h8200<1PH02`D500`61P0>20P04PX:01<92P0201@:2`<04`T:00H060h?01882@0A1`P0
4PP900l51P0C2@X201882@080147200B20T050X;01H<3@0M4a@03@<401882@0@1PL201@:2`050147
200@1PL04@L801@:2`0C2@X00`0B20T0300A1`P040H701882@0B2@X0208205E?C`1/IVH0100000l9
2@0A2`/040X:00l92@<03@L700L0308301P>3`0>1@D03@<401061`0D2P/03`D600804@L800X05@/<
01hD5@0V71d0;bDV01/A4P0D2P/05P`=00`20`0A1`P04PP90P0A1`P02@0@1PL04@L801882@0@1PD0
3`D401471P0@1PD03`D401D;2P0201881`0301061@0=0`803P@300804@L600D040H500l5100?1@@0
40H501471P0601061ACooooo000Kooooo`07010>3`0B41403`d>00H51@0B4140518C00h<3@0200l=
3P0?01LE5P0A3a003@/<01`H5`0B3Pd04@d<01DA400B3Pd040`;02LS8P0J5QD04@d<018>3@0@30/0
30P700804Ph=00X040`;00l;2P0B3Pd05A4@010<2`0A3@`05Q8A00l;2P0:1PD04Ph=0P0?2`X0:00@
30/04@d<014=300A3@`04Ph=01<?3P0F4Q403PX901XF5@0>30d03@dB01PH6@0=30T05Q<<010=0@0J
60T0;R/J01lL3@0R8A@04a@:01LJ400?3`T06QHE01HB4@0=2@P071PG01/G5P0<20P05Q8A01hJ6@0=
2@P061@C01DA400K5aH04`l>00h:2@0C3`h0510?014=300H51<301@@3`0300h:2@0@30/04a4?0080
4a8@00@03`h<018A3`0C4Q004A0>0P0D4a40100E51802@P601HE4`0H5Q<2014=2P0301/G500G4a00
5Q8?00H04Ph;01h061@A01XF4`0F4Pl04Ph;01DA3P0C3``06aLD00<0000k=c@03@T601TE4P0C3`d0
5A4>014=2P0D40d03@T601@@3@0F4Pl04@d:018>2`0G4a007ATF01/G500A3@X05A@B00l>300H5aD0
4Q4?01@C4@0G5Q@2010?3@0:01`K6@0K6QP040l=01<B400I61H04A0?01LF500I61H03Pd;01LF5080
51<A00X04a8@01@C4@0C4Q004a8@020O7@0W9R@08b8P01PG5@0B4@l05QDC1P0D4a40400E4A805a8D
01TD5@0H51D05Q<D01@A4P0L6Q/0GUiN010@400E5AD02P/:018B4P0G5Q@05QDC01DD4P0D4a43018A
3`0Y01DD4P0I61H05A@B014@3P0D4a405QHD01/K6@0L71X06ATG01DE4`0D51805ADC010@3P0M7A/0
7alM018B400L7AP05aPC018C3P0H6A@051D@01XJ600i>CL0:2PV01HF5P0K6a/03`l?01dM7@0F5aH0
8bDQ01TK6@0F61D0418?01/P700F6aL04ALC01LM6@0I81`07RLQ00dF4P0J81h00P0E6AP09`0O8b80
6alN01XN7@0N8R408BDT02``;`0b=SD09RXY01lS8P0R:2D07RLR01XS800L9B@07BDW01lV;00S:S40
6B0X04mFG02@V9`0:30c024Y;00P:Bh082T`024[<00R;Bl092la02Hc<`0[>CX08Bl`02Le>@0eA4/0
:3Ho02/i@`0W>400:CY102Hg?P0V>3`0:ce102i0A00202i0@P0C0312A00a@d<0<dE503I8A`0_@T00
>4]703Q;BP0/?T00AEMK03]<E00gB580AeQR05Y[M@16Eel0?e1H04AFGP10DeX0@UIM04AHG`0204=G
GP1904AHG`1@I6/0BEeT04YNI01?HfT0C65W049GG019GV@0Bf1V04aQI@1=HVH0DFIZ05I[KP1JKg40
EV]/05Q^K@1IKfh0EFYY05AZJ01FK6X0F6e[05a`K`1OLg80HgIe06EgM`1aPh<0KGin06moO`1aPH40
LX6207V7R020Rhd0PHb>08:=S`25Si40R9:D08VCU@2>UYT0TIRK09:IW02EVYh0VIjR09^PY02PXjP0
XjFZ0:JX[@2][KD0/[:j0;Bd_02k^L@0`;g80;jkaP32_L/0b<?A0<W3d@3?aMP0e<SL0=O;g`3Lcn<0
gm3U0>3AiP3Ud^P0j]K/0>gHk`3`fO40mMge0?OOm`3khO`0o^Cm0?kVoP3niod0o^_n0?o_o`020?oc
o`040?ogo`3onOl0oo_o0?omo`D0o_kn1P3oool0J@3oo_l0oogn0?kloP3onol0ooSo0?ogo`3om?l0
oo7n0?o^oP3ok?h0onWm0?gUnP3liO/0n>Gk0?KPm@3bg>l0kMKV0>OBgP3Mb]<0eLK<0<g1a`38_/H0
al370<6l`P30^[/0_;Bb0;F^Z@2YYI`0W9R<08n=O`1fMfD0Kg9N07b0J`20QG80PXQe07QoK@1aN6L0
J6mN07=jJP1gOVl0N7m`07InL@1[M6T0Ig1U06A^I@1[MFd0KWUa06]fL01VLFd0IG5^06=^JP1LIf<0
EV5M04mKE@1;Ee00D5aE04IBB@11CT@0=40g034l=00/<Rh0;C<_02X`;00]=300<CTd02Tb;@0T;bT0
9S4[02hj<`0f@c`0;CXc03E3?00d@Sd0<d8n0392?`0b@T40:chl02@g=@0Z>ST0<d8o07f:P`0g@SX0
;cP_03]2>P0U;2D09bhW04Q?B00Z<BX0:C0Y01lV7`0P9b008RTR02L^9`0U;2D092/T02Tc:`0Z=340
92l[028]:@0L9B8092dZ020Y9P0S:BL08RHU024U9002020T8`05020U8@0R:B<09R`X02D[9`0R:2@0
0`0N9280500P9RH07B<S02@Z:P0L8B@06R0P01XP7`0O8b808BDT01dQ800O8B009RPW01/M700Q8B40
92@T01dM7@0H61P06a/I01XL600K7AP07AlJ0P0G6A@02@0K7AP05aTD01PJ5@0K7AP05aTD01HH4`0G
61<05QDA01LF4P0401PG4`0301@C3`0G5Q805QDA00806QTE01405A8@01D?3`0E4A0051<A01LG5@0<
3P/07R0M018D4@0N7Q`0518@01XF5@0C3@d04@`;01HB3`0I5A8061@A01@@3@02018>2`805Q8?00<0
4@d:018>2`0A3@X00P0D40d01@0C3``04@d:01<?300I5A804@d:0080510=00<040`900l;200C3``0
0P0A3@X0400D40d04`l<00h:1`0B3P/03`/8018>2`0?2`P03PX701<?300D40d03`X7014<2@0B3@X0
4@`9010;200C3P/2018=2P<04`h;00@04@`900h91P0@2`P04`h;0P0E40d02`0D3``04@`901XE4P0B
3@X040/801@?300=20D03`X7010;200B3@X04`h;00804Pd:02004@`9010;200@2`P04@`901<>2`0D
3``03`T9010:2P0K5AD0=S0`02<M7@0A2`/020<301@>3P0B30`030L700h8200?2@T04@/;00P20P0@
2PX03`T9010:2P0=1`L04@/;00l92@0>20P04@/;01@>3P0G4A404@/;010:2P803`T900d03PP800d7
1`0B30`03`T901D?3`0?2@T040X:00`61P0?2@T03PP800/51@0=1`L040X:00803PP801403@L700l9
2@0B30`04@/;00d51@0L4Q<0;28S024G600;0@80308301061`0E2``04`T:01882@0E2``04@L80188
2@0201<92P0:01061`0A1`P05P`=01`B4`0@1PL0308301882@0@1PL04PP901H<3@<04PP90P0C2@X2
01D;300:01@:2`0A1`P03@<400h41@0D2``02@<300l92@0=1`L06aDE018<30804@/;00`03`T900d7
1`0<1PH030H600h51@0M4a@05@/<01061`0A1`P03P@501D;300D2P/201<92P0L01D;300G3@h05@/<
01061`0E2``03@<400P0000e:b`05P`=01D;300B20T03`D600h41@0=0`@04@L600`20@0B20L05@/:
01881`0L4Q405P`;01881`0>10<03@<200l5100@1PD04@L601061@803`D400<040H501471P0@1PD0
1@0@1PDDooooo`006oooool0400=2``04Q0A00d;300A3a0040h?004000040P<06ALH01LE5P0?3@h0
2@L801DC500>2PT04@d<01hJ6@0M6AP2010<2`0600l;2P0B3Pd04Ph=00l;2P0A3@`0510?0P0C3`h0
2`0A3@`040`;018>3@0D40l040`;018>3@0>2PT05A4@01hJ6@0<20L04@d<00804Ph=0P0D40l0?00E
4A0030P7010<2`0L61L040`;01/G5P0L61T03@/@00l=3P0B3P/06aH=01<=000X8a00N7=O07mjIP0d
<Ah09RDG0041000I5a4040`;01TE500C3`h030P701DA400C3`h030P700d9200O6aX061@C00d9200C
3`h04Ph=01<?3P0R7Qd07ATH014=300C3`h04@d<018>3@0C3`h03`/:010<2`0J5aH07ahL01XI5`0@
3`d04A0>018A3`0A40h06QTG04e<BP0Y:2H04A0>01TH5P0>30T040`902/W900A3@X02@D200`81@H0
4Ph;01006ADB01hJ5`0K5a@040`9014=2P0E4@h03`/802@P7@0A3@X0<2`Y00l;200I5A805a<@01@@
3@0F4Pl03PX70P0C3``0100E4@h04`l<014=2P0C3``201DA3P0B014@3P0I61H0FeYH02@S8@0J6AL0
5QDC00l>300@3`d05A@B01@C4@0?3P`03Pd;0040000J6AL01PD301TH5P0l>cT05QDC0P0D4a402P0B
4@l04A0>018A3`0C4Q0020L501dL6P0R8Al05QDC00l>300G5Q@601@C4@0301D?4@0G4A<06Q@F0080
6ADF00P05a<D01PF5`1@D50010@402DU9@0L71`051@D01@C4@<05A@B0`0C4Q002@0A40h05A@B01HE
4`0H5aD071/I01@D4P0H61H06ATG01HF500201@D4P0T01DE4`0B4Q006QXH01HF500B4Q005aPC01XK
5P0I6QD05AHA01PI500A4@l05ADC01`L6P0O7al071`L01PH600W9bL06a`H01/N5`0D5Q406Q`G01TK
5P0M8Qh051TE01DK5`0O9B<04APF01HO700:4a00;C@b01PL6`0D61L07b<R01/O7P0H71/08bLV0P0G
6aX0900I7A`06alN02@X9`0J81d06B8M01`U8P0I8R406B4S01/R:00K8RT092/c01XQ9`0`>3`09blb
020X:`0O:2d082T`024/<00T;c409S4c02Hd=00O;Bh082h_02Dd>@0X=Sl09C<l030nB00U=Sh0:3U0
02Lh?`0Y>cl0;d550394B00a@dD0;d530353A@80=4I600h0>Da;03Y=B`0bAD40?U1?0312A00cADT0
?e1H03Q9D`0gB580AUMQ03i?E`15EUh0@59I045DF`80?e=J0140@5AK04AHG`16FV40CF5X04QLHP1:
Gf@0D6EZ04eRI`13Eeh0CV9[05EYLP1EJG00E6Q_05I[K`1DJF`0Efa]05AZJ002055XHP0B05=ZHP1F
KFL0Fg5^05aaL01NLW40H7Ac06AgMP1VN7P0JG]k06]lO01dQ8@0MhN707N6Q`1kRHX0P8^=08:=S`23
SY00Qi6C0P29TiD0402<U9L0TYNK09BIW@2EVYh0VIjR09^PY02SY:T0YZN/0:Z[/02_[kL0];>k0;Je
_@2n_<L0`[o:0;nla`33_L/20<W3d@0H0=75f@3Db=`0el_O0=c?h`3Od>D0hLoU0>CAi`3[eN`0k]S_
0?;JlP3egOD0mmog0?_Qo03ni?d0o^Kn0?kWo@3njoh0onoo0?kbo`3olol0ooKo0?oho`3on_l0o_co
1@3moOd00`3no_h0oooo0?ooo`030?ooo`0Z0?ono`3no?d0oO_n0?khoP3mm_d0oo?m0?obo@3okO/0
on_l0?oXo03niOX0n^7g0?OPn03ch?H0lM_b0>cFj03Ucm`0g/[E0=?1b03=_/<0b;g10<:k`P32_L<0
^KFl0;F_[`2`Z:H0Y9fI09RDR`2?SH00PH5`06iaG01aM5l0OhA^07^3KP20R7<0OXEc07ElK01[LV80
LgYZ07AlK@1cNf`0L7Q[0P1VL6D01@1YLfX0KGQ`06ehL01VLF/0GfYV0080HfiZ02P0F6=O055LF01?
FU@0Ae9:045<A00g@SX0;CT_024]8`0b?3<0;cDa02hc;`0X;RX0:Bl[02`d;`0X<B`0:SD_030l=@0^
>c@0=T<l03=1>P0fACh0?di90351?@0]?CX0<TE30354@P0V>CL0:SXi02`j=P0[>3407bTQ03<l<P0@
60d0;3<[02T`:@1;DT/08RTR02he;P0N9Ah09RdV0P0T:b@04`0Q:2408bXS02/e;@0Y<c0092l[01TT
800N9b@09Bh[02L`;@0N92806AdL01XN7@0M8B007b<R028W8`0P9b408bTU028X900O9B400P0N9280
7P0X;R`08RPX01`R8P0J82006AhQ01DK6`0i?ch082@S01/O7P0R9RD08B<R01XL6`0O8B009bLW02XZ
:P0R8R806ATI01/K6@0K7AP06Q`G01LI500E5a805aTD01PJ5@0F61<06A/F01hP6`0H6QD051HA01HF
4P<05aHB01/05QDA01DD400H5a<04a8>010?2`0=30P06QTE01hM6@0>2`T04P`<028N7@0D4a40410>
00L91P0E5a@030h;00P81P0F51<05A4@01D?3`0L5aD04`l<010<2@0C3``05a<@018>2`0C3``00P0F
4Pl00`0C3``05A4>018>2`0301<?30804@d:00X05A4>01<?300B3P/0510=014=2P0>2PL0510=04M3
@00Z9R<04@d:0P0I5A80300?2`P03PX701DA3P0E4@h04`l<01LC400?2`P050l<01TD4@0K5Q<04@`9
00h91P<04`h;0P0B3@X3014<2@<040/800`03`X700d81@0G4Pl040/800/60`0@2`P04Pd:00P3000>
2@H040/8018=2P0C3P/201@?300O00d81@0B3@X040/800l:1`0B3@X04@`900/51@0?2@T03PP800l9
2@0:10@050h>014;2`0@2PX03PP801dG5`0J51@02`D5010:2P0?2@T050h>00d71`0B30`05@l?018<
300@2PX03`T9010:2P0A2`/04P`<010:2P0300l92@803PP801<02`D500L10@0>20P05Q0@00L10@0A
2`/03PP800/51@0G4A407aTI018<300:10@04P`<00`61P090`<02`D5014;2`0D30`04`T:008050X;
0P0C2@X04`0O5AH0;bDV020F5`0?1@H04`T:01882@0D2P/04`T:0147200@1PL04@L801D;300N51D0
3`D601D;300A1`P04`T:01882@0D2P/00`0B20T01P0A1`P04`T:01P>3`0J41406@l@01@:2`8040H7
00T02`@400d71`0=1`L06aDE00@0000C3@d04@/;010:2P0?2@T00`0=1`L0200I3a006a4B00l51P0?
1@H03@<400l51P0@1PL03P@50P0B20T01`0=0`@02`4201P>3`0E2``05`d>01882@0900000P0B20T2
0147200A01061`0A1`P04PP901471P0?1@@040H500l5100=0`804PP701@:2@0A1`H03P@300l5100@
1PD03`D401471P0@1PD00P0?1@@00`0@1PD04@L601061@0501061ACooooo000Kooooo`0<01<A4P09
1`P02@L801/I6P0B41407Q`M01LE5P1>C4d05A<D00L51P0?3@h05aDF0P0B3Pd02@0N6QT07ATH010<
2`0A3@`05A4@01LC4P0D40l04@d<018>3@0301DA400>018>3@0@30/04Ph=01@@3`0@30/01`<201<?
3P0B3Pd06QHE00D1000A3@`04Ph=01<?3P0D40l201DA400C00l;2P0A3@`05A4@00/71P0>2PT03PX;
00l=400C3`h04a0;01PC1`0Q6PX0>S<P0=?@^`3lmn40NGMR02d]700;30005aD>00/71P02018>3@05
01DA400J5QD04@d<01XF5@0D40l00P0:1PD02P0B3Pd04@d<01<?3P0B3Pd08QhM01`H5`0@30/0510?
01HB4@0G4a8301@@3`0401TF5@0N7A/06APF014@3P804Q4?00`04A0>03Lf=02:RHL09RDS014@3P0E
518040d;01XF4`0o>cP081`I01dI5P0E4@h701HB3`0[01XF4`0G4a0040`9014=2P0C3``03`/801dI
5P0W8b80[ZZW02PT8@0@3@/04`l<018>2`0H51404`l<01PD4@0I5A805A4>01@@3@0B3P/040`9018>
2`0H514081lM00X91`0K6QP030/9018A3`0510803`h<014@3P0?3P`040l=01<B400?3P`06QTG010?
3@0E51806QTG010?3P0@3`d051<A01<B4002010?3@08014@3P0B4@l05QDC00l>300<2`T040l=01@C
4@0B4@l601@C4@0I01LA4`0H4Q@0618D01LC500F4Q<05A4B01LE5P0?3@h07Q`M00l?3`0000006QXJ
01@C4@0E51805QDC01DD4P0B4@l04A0>01DD4P0B4@l05QDC01DD4P0C4Q005A@B01<C4@0201HF5080
51@B0P0E5A<01@0G5aD04Q8@01@D4P0G5aD04A8=00805QLB03005aPC01dN6@0G5aD07QhL02PX9P0[
:b/0AdM701PH600M7Ad061TE02DX7`0G6Q<05QTB01@G400O91h05AXE00`B3P0P9R@06b8R02L`;`0o
B4L0KWEd02<W9P0D61L07B4P01TM700G6aX07R8Q01PL6`0E6AP07b<R028V9@0L81l061hK01dV8@0P
:BH07BDU01lW:@0O9R`08BP_02<Z<P0K8RP08RX^02Ta=00N9RT08R/`028]<`0T;c<202D`<P0I02<a
<P0/>S/0<Cm00350A@0[?4@0;d1802Tj@`0V=cl0:S]202/l@`0/?T80<4960353A`0bA4H0;Cm10312
A00dATH0<dE503Y<B`0lCdd0>Da8045CDP0hBT`0>4Y>03e>EP02041AF`0Q04YKI@0hBE40?4eE041B
F@15Ef40?e=L03]?F00lD5L0@EEL04AHG`18G6<0AU]Q04YOI01?I6T0CV=X04IJH@1FJWD0G71k05M[
M01EJG00F6ea05EZK@1CJ6T0E6YX059YH`1BJF40E6]Q05E/I01KLFh0G75_05ibL@1PM7<0I7Mg0080
J7Yj00T0KGin07Z:RP1nSXh0NhZ;07b:R`20Rhd0Phf?08F?T@28TY@00P2:TYD0402=UIP0U9VM09JK
W`2HWJ40VYnS09fRYP2SY:T0YjR]0:^//@2a/;P0]KBl0;Je_@2m^/D0`;g80;jkaP34_/`20<c6e00H
0=;6fP3FbMd0f<_O0=c?h`3Od>D0hLoU0>?@iP3[eN`0k]S_0?;JlP3egOD0mmog0?_Qo03ni?d0o^Kn
0?kWo@3njoh0onoo0?gao`3nl_h0ooKo0?oho`3on_l0o_co1@3moOd00`3no_h0oooo0?ooo`030?oo
o`0`0?ono`3no?l0oo[n0?khoP3lmO`0o_;l0?o`o03nk?X0on[k0?oWo03lhoP0n]ke0?GLm03afo80
k=K]0>K@hP3ObMH0f<C?0=2ma@3=_/40a[bo0;nh_`2m^;h0/[2f0:RRXP2VWY`0W9NB09NCRP2?SH00
Ogi^07MjI@1kOVT0PhQb07InJ@1jPVd0OXEc07QoK`1[LV80KGAT06]cI01]MFH0KWU[06egK01^N6l0
KWUa06ehLP1YM6h0I6mY0P1PJfL06@1LIf<0DUeG04]FD014CdT0<Sde03M2>P0e@3P0:3@Z028^900b
?3<0:2hZ02X_:`0`=C40<3Hb02`c;`0Y<Rd0;CPb03M3?@0]>S<0=4<l03]:@`0jBD80BeYE03]:A`0`
@3d00P0bAD<0>P0[?S`0?De:02lm>P0L:B80<cde02H_9@0[<BL0<cXb024X8@0a>340;3</03U0>@0L
8a`09bhW02D/9@0T:b@082LP01lV7`0W<BT0:38_024/:00B7AT0624N01hW900Y<Rl06R0N01LK6P0N
8R408RHU024U900S:2@082LQ028X900Q9b<07bDQ01lU8`0Q9bD08bTW01<I6@0H7Qh08BLW02<X:`0I
7al0Ife/030d<`0I7A`06alN01lQ800J71/07b4P020P800S8b<07alO01XJ6P0M7A/06ahH01XM5P0I
71D201XM5P0701TL5@0F6A8061/D01`O600G6Q<05APA01LH4`0201PG4`0701LF4P0E51004a8>01HE
4@0=30P05QDA024P700201HE4@0501XG5@0C3@d061@C00l>300L71X00P0K7AX06@0A4a003@d;01TG
5@070`80208201LB4@0B3P/03`/8014=2P0F4Pl0510=018>2`0E4@h0510=01<?300E4@h04Ph;01@@
3@0E4@h05Q8?01@@3@0C3``05A4>018>2`0?2`P00P0A3@X03`0>2PL04Ph;059>B`0`;2T03PX7014=
2P0D40d05A4>014=2P0?2`P05a<@01HB3`0@30T081`I01LB3`0201PC4006018=2P0@2`P04@`901@?
300C3P/04Pd:0`0A30T03P0F4@h04`h;018=2P0C3P/04Pd:00l:1`0U81d05Q4>014<2@0C3P/03`X7
00/60`0A30T04Pd:0P0C3P/05`0B3@X04@`900d81@0D3``040/800d81@0A30T03`X701LA4@0<1PH0
4@/;010:2P0F41005a4A01PB4P0910@02@<302dW9`0U7al02@<300d71`0D3Ph03`T9008030H600<0
3`T9010:2P0@2PX00P0?2@T2010:2P0400h8200?2@T03`T900l92@8040X:01d04`h>01PB4P070@40
5@l?00L10@0E3`l02`D5018<300P6QX0=Bl_020J6P04000040X:00l92@0<1PH02@<300h8200D30`0
3`D600X00@0?1@H05@/<01@:2`0P5QL0=2X[02DK700B20T04`T:00l51P0201882@0@00l51P0@1PL0
4PP901<92P0I3a002P0101T?400@1PL05`d>01<92P0A1`P04PP901<92P0A1`P040H701<92P<05`d>
00T050X;0147200B20T03PD601XD500=1`L04@/;00@0000J51@00P0?2@T02@0>20P03@L700d71`0>
20P05P`=01882@0?1@H06a4B01<92P0200h41@0;00`20`0D2P/060h?01D;300F30d02`4200X00@0=
0`@05@/<01P>3`0B20T0100@1PL01P0B20T04`T:00h40`0B20L040H500`20@803`D400<04PP700l5
100?1@@00P0A1`H00`0>10<04@L601061@0200l5100301061@0A1`H040H500D040H55?ooool001_o
oooo00`040d=014>3P0F4a<0514A018?3`1<BDT07a`L04E2@P0J5aL0514A01XG5`0B3`l201@@3`0J
014=300G4a805A4@01DA400@30/04@d<00l;2P0B3Pd05Q8A01HB400C40X04Pl901<@2P0?2`H040`8
01DB3P0V8Ql030P701TE500<20L04`l?010<300A3@`05A4@010<2`0B3Pd201<?3P0Z010<2`0B3Pd0
4@d<018>3@0D40l04Ph>01D@4`0D3`d05A0;01PD200a;A/0A40]0;FaW03=bKL0C4Pi024N4`0g<b`0
5Q8>01@@3`0@30/06aLF07McLP1LF5L04`l>010<2`0A3@`05a<B01@@3`0F4Q40510@01D@4`0@30h0
6A@F01XF5@0F4`h06AH=02<Q5@0N70h04@l601PD3`0C3`h03``;0P0E4a404@0D4A00518@01<A3`0E
4Q40=C8a06ERH@0G5A<040h<01<A3`0C410030L901PD500H5AD0@3`j01@@3P0@30T04`l<0080510<
01005A4=01@@300B3P/05a<A01<?3@0F4Q004`l=018>300A3@/0510>018?3@0/:2H02`L501HB400<
20H040`:0P0F4Q00100G4a407ATG018>300B3P`201LC4@0I01DA3`0G4a4040h;01@B3`0F4a4040d;
01@A3`0F4a4030X701PE4`0;2@H0514?01PE4`0A3P`05A0=01HB3@0E40d05A0>01@?3P0F51<05Q4A
01HD4`0A3`d05A8A01@A3`0200l>2`805aHC00L04a8?014?300A3`/040h;01DC3P0=2`P061@@0080
6A@A01/05Q8@01PE5@0D4A406ALF018@3`0B3`l05QDD01DC4`0G5QD04Q4@01LF5@0H61L051<A01PH
5P0H5aD04a<A018A3`0D4a405A@B018A3`0I61H071/I01PH5P0G5Q@05QHD01TI5`0H61H00P0E5A<2
01PH5P2Y01LG5@0@40h05QHD01XJ600B4Q0051DA01<D400G61@04aDA01<D4P0K71X07QlM01<D4P0O
81l06a`J01@E500K7AT07R8M01TM5`0H71D05ATB01TN600J7aT06AhJ01TN700I7Qh05A`N05IJGP1Y
Kg006R8P01hS8P0Q9bH07BDS01PM700G7Q`08BTW01PM7@0K8B007BDS01DJ6@0N92@07B@T01dT9@0K
8R@092/`02D/<P0P9bh06b<Y02hf?00P:2d08bha02H`<`0T;c<09C0d02Hc=@0U<C<08c8b02Dd=00V
=cL09CHf02hoA01FJ700X[>g04=FH@0/?TD0;T1702m1B@0Z>d@0>4UB049CG00bADX0;d970313A`0c
ATH0=4M603U<C011E5H0B5]N03e?D`0eB4d0@eEL04=EG@18FF<0@UAN041AF`0oD5X0AUQQ04AFH@1>
H6d0B5]X04AGH@13EUh0@eMM04=GG019GF00BEiQ04YNHP1<H6D0CF5V04QKHP1FJW@0Ffmi05AXL01B
IVd0Efa`05I[K01DJVP0E6YW05I]I`1EK6@0E6]Q05Q^I@1JKVX0G6m]065dL@1TMG@0IGIe06QjM`1/
OGd0LH6007R8QP1jRXX0NHV807V7R02;UiP0R9BE08F@T@27TI80RI:E08^DUP2AVId0UYbQ09BJW`2J
Wj@0WjB[09jRZP2TYZh0Z:Ra0:b/]@2b/KX0][C00;Ne`@2l^LD0`;c90<2mb@36`Ll0cLOE0<o9e`3B
amP0e<OI0=S;g03Lcn40h<kS0=k=h@3Sd>D0jmG/0>oIl03cfo<0m]kf0?SPn03kh_`0oNCl0?gUo@3n
j?d0o^_n0?o^o`3nl?l0o_7o0?oeo`020?ogo`090?ojo`3mo?l0ooco0?omo`3noOl0ooco0?omo`3o
o_l0oogo0080ooko0P3oo?l0O`3on_l0ooOn0?kdo`3nl_h0o_7o0?o^oP3njod0o^Sl0?gVnP3ihOH0
mMga0?7Jk03/fNP0hLkL0=c9d`3B`<P0dl780<no``3<`<40a;Rj0;bd]02j/k@0/:ZY09nKU02MVI00
VYV<09VHRP2ATh80P89^08F8L`24RG80Q8Yc06mgG`1dO6D0OXE`07MoK`1XKf80IVeQ065YG@1fOW80
OHQl07EoMP1gPGP0LWie06]gKP1XLfX0HViW069^IP1MJF40Ef=K04iIDP12CDH0<Sdg03<m=`0_>C80
;SPa02/e;P0b>cD07RPR02L_;00[<c40=3`j03Do?@0b>cT0<3/f02Td<@0e@C`0:SHa034n>@0iAd40
>TU403U8@`0_?c/0:SXf03I7@P0`@3`0;Cdi02Ph=00W=2h0<Che02Lb:P0V<2H08R/Q02T_:P0X;BP0
:S0[02P]:P0T:RH09bdX02<Z9`0U;BP092lX024[9P0M9b407bTU02@/:@0Y<2h092/Y024X9P0F6aT0
7B8Q01TN7@0K7ah082@S028V9@0P92<08RLS02@[8`0R:R8082PR01lU8@0P9R@08BLV02<X:@0V:bd0
:2d_01hQ8P0L7b407b8S02DX9P0N8Al082<Q020Q800O81h061TG01hO7@0K6aX00P0L71/04@0M7A`0
7alM01/L5`0P81/07AhI01XL5P0K6aH07QlJ01`N600H61<06AXD01TK5@0H61<05QHA01PG4`0I61@0
5aHB008051<?01l06APD00`;1`0X9b<0C4]7024P700E51006ALD01<@3P0K61H05A@A01<C400A40d0
4a@@01/K600C4a004Q4>01TF500H5Q<0510=01@?300F40d05a8?01HA3P0E40d050d;018>2`0D3``0
5@l<018>2`0A30T04@d:00804`l<00L04Ph;014=2P0@30T09b<P01HB3`0B3P/061@A00<05A4>01X0
40`9018>2`0B3P/03`/8018>2`0H51402`L4010<2P0F4Pl0510=02<O7@0A30T05@l:01L@3@0@2`P0
3PT5018=2P0>2PL050l=01HC4@0<20H04@d;00l:200D3``03PT6014<2@805A0=00L04Pd:01LB3`0B
3@X04Pd:01@?300C3P/050l<00<04Pd:03X04@`9010;200?2PL03`X7018=2P0?2PL040/8018=2P0;
1P<050h>00l92@0A2`/040X:00/51@0<1PH03@L7018<300@2PX04P`<014;2`0<1PH04P`;01D?3P0<
1PD04Pd<00l:200A2`X03`T8010:2@0A30X03`T8010;2@0=1`H03`/:00h9200B3@d03`X900h8200B
30`091`M02LP800B2@X05Pd>00d51@0B20T05@h>00/51@060@40?3Hf04Do?`0>20P03@L701D?3`0K
5AD05@l?00`61P0?1`P04@L80P0C2@X05P0B20T04@L800l51P0D2P/04`T:0147200E2``04PP901@:
300B1`X03P<601472@0=1@D05P/>01462@0<0`D05P/>01472@0G3@l050X<01482@0@20T201892P0@
01082@0>1@D04`/<018;2`0?1@H04@P900X30`0B20T040L800l82@0@2@T06a4B00h8200=1@H040L8
00l7208040L800L040P901882@0?1@H04PP901hD5@0X7Ql07A<D00804PP900h04`T:0148200g;Bh0
GeEF01882@0D2PT04`T800l5100?1P@04PT701481`0B2@P040T800l81`<03`L800`03PD301471P0C
2@P040H501H<2`0Q5aH05P`;01471P0?1@@04@L601881`0?1@@501061@0401471P0@1PD03`D40106
1@804@L600<040H5ooooooooool04_ooool001_ooooo00D061@C014=300E4A00510?00h:2@0201HB
4@0S01TE500M6AP03@T801<?3P0;1`H040`;00T51@0A3@`05a<B014=300400004@d<01<?3P0@30/0
4Ph=01@@3`0A3@X0514901DB2@0C40L04a0801HC300H5A003@X6018>3@0A3@`04Ph=01`H6@0B3Pl0
40`;00h:2@0G4a804@d<00X61@0I5A@01P0@30/0500D3Q004`h;01<>200@30806AH501hK200W91D0
?SX^03@`9@0;1PD081XL01PC4`0:1PD03PX901DA400[9bH05Q8A018>3@0A3@`04Ph=0P0C3`h03@0B
3Pd0510@01@@4@0B3A405A4C01XF4`0H5@`06AP603lo9@14A2P08B4<01/I3@0K5a@00P0E4A0201HB
4@0301DA400D40l0510?00<0510?01404`l>018>3@0A3@l050lE018=4@0W8b@0BTI701HB4@0C3``0
5a<@01HC3P0D4@`05Q<>01@A2`0L61D06aLF00T51002014=300>01<?3P0@30/040`;020L6`1ACD`0
5A4@014=300W8b80:2@S010<2`0E4A007a/J00h:2@0B3Pd201<?3P0401@@3`0E4A005A4@014=2P80
5Q8?02L04Ph;01<?300A3@X03`/801LC400;1`@0920M00h:2@0C40/040/501`E4@0I510081PF028L
7@0?2@/030H801hI6`0B3Pd03@T8010=2@0P7aX05aPC00l@2`0?3PX04A0<01@B3P0G50l07a`G01HB
3@0N6A<05a8<01PC3@0G4P`06aLD010?3@010000<2l]00h=2`0I61H01@0F5A<06@0E51805QHD02<S
8@0T92806QXH01@D4P0E5A<04a<A02/[:@0O7ad03`l=010@3P0=3@/06QXH01`L6P0I6AL051@B01<C
4@0E5A<04Q8@01<C4@0F5Q@06ATG01DE4`0A4@l00P0F61D0100C5A808B<P03Pj=`0];b`201@F4`07
01DG500F61D05QPE01LJ600H71/05a`H01HK5P0201LL5P0F01@I4`0M8Q`06QhM02/_<00A5AP0:B`c
01dR9P0H8B00=Sln02D^;@0H8B008b`[038k>P0>5aH08BXY01/T8`0U;Rd0>45001TP8`0N8bT07b@Z
01dS:@808RT_00T07BD[02@]<P0K92T07BL/02Xe>@0Q;30092lc02Ha=@0V=3D00P0S<c805@0U=SD0
7c4a024e=00Z?D80?E5H096U[P0dBE<0;d5;03A7CP0bA4h0:Sa803I8E016F6@0;d5;02m2B@0`@dP0
<TI703E9B00hC4X0CV5W04ULH`0203a?EP0R04EHG`16F680@59L045CG@0nD5X0@E=O04aNJP1FJ7D0
B5UY04AEI012E600A5IP04QKH019GEh0AUYK04]OG`19GEh0BeiT059UK01DIfh0BUiW05=WK`1CIfh0
DfQ]05=XJ`1=HV<0DVQV059XI@1GKVP0FG1X05I]I01EJV<0GW5]069bK`80J7Qe00l0IgMd06alN@1_
Og`0L81m0761OP1dQ840MhN407V9QP24T900Phn?08:>SP27TI80S9JH08jHVP2<TiT00P2CVZ009`2H
W:D0W:2Y09bPZ@2UYk<0ZZZf0:f]^@2b/[h0]kG20;Rf``2l^/L0_k_90<:nc037`m40cLOE0<k8eP3B
amD0e<SF0=K:f03JcMh0g<kO0=g<gP3TdND0jmG/0>kHk`3bf_80m]kf0?SPn03jh_X0nn?k0?cTo03m
io`0o>Wm0?k/o`3ok_l0o_3o0?obo`3om?l0ooGo0?oho`020?ojo`80oo_o0P3oo?l30?oko`80oo[o
02d0ooSo0?oeo`3nl_h0o_7n0?g_o`3nk?l0oN_o0?cYo`3kiOX0n>7f0?CMl@3`fN/0k]SU0>SGg@3D
`lT0d/;80<Zk_P3=_/40a;Jh0<Fj^02o];80^:j/0;N^Z@2`Z:00XIn@09BEP`20PFl0MGQU07MjI`1m
P6/0Q8Uc08V>M`1oQfl0JW9K071hH01iPFX0Mgmb06=ZHP1YL6P0HFQP071gK`1eOgH0LWac07=mM01Z
MV`00P1SKfD03`1PKF<0I75W05]XGP1DHEP0CUUA04=>AP0g@S`0@DY504=<A`1:De00;C<a038h=P0a
>ST0<S`m030k?002030l?01202di>00X=380=40n03a8A@0c?c/0>4A003Y6@P10C4P07bhY03Q9@`0Q
<R`0:3Lb02hm=`0a@3T0:3D^02Db:P0Y=2`0:3<[024]900Q:b<0;34]02`^;@0X:RT09BTX02H[:P0W
;B/09Rl/02Pb;`0X<bl09C4]02<_:`0T;b/09BXX02DY:00R9RD082@S01@H5`0B5QD06AdL01hR8@0P
92<08bLV02HZ:@0X;RX08R/P01hX7`0M9al07R@Q01hT900O9BD07B4T024R9P0R8bL08R<U02HW:@0X
:RT09RHT01dM6`0Q8Al07AdK028R800M7A/071`J01/K6@0J6QP06a/I0P0L71X201XI5@0F01TH500G
5Q805aHB020O6`0R8Ad06QTE01lN6P0Y:2@08R4M01DD400G5Q8061LC01HE4@0D4`l05A@@024P700=
30P030/701LF4`0<2`L05A@@01/J5P8061LC00L05aHB01HE4@0F5A404a8>01LF4P0H5a<04Q4=0080
61LC00@05A0=01P@3P0H40h05`l=0P0F3P`02@0N5Q@06A4?01P@3P0H40h050`:018<2@0C3P/04Ph;
01<?3002018>2`07014=2P0P71T04Ph;00P40`0300004Ph;01HB3`02018>2`<04@d:01H040`900<0
000R7Q/03PX700P40@0=2@H05A4=01D=2P0G40X0614;014<200?2PH04Pd901XF4`0>2`T051<A00h=
2`0C4Q005QDC02<N6`0F4@h04Pd:0P0D3``01`0F4@h040/801<>2`0?2PL03PT6014<2@0=20D01P0?
2PL400d81@0:010;200E40d0100001H@40090`<01@0001XD500?2@T03PP800l92@8040X:01D03`T9
00h8200<1`@04Pd:02<N6`0L5a@02PD200/60`0?2PL04@`901@?300@2`P05A0=00h:1`0<2PT01`H4
014@3P0710<01`4101D?3`0A20T00P0C2@X01@0D20X04`L901882@0>1`L05Q0@00803`T900X06aDE
00h8200;1@D03@L701LA4@0C3@d02`D5018:2P0B20T04@L80P0B20T00`0A1`P040H7014720040147
200600`4100?10P03`@800l5200@1@T05@X>1@0A1PX0200@1@T02`<501H@400D3Ph01P4101H@400=
1`L01`820P0B30`02@0P6QX040X:018<300B2P/05`d>00l51P0>10D040H704Y0@@0201061`804@L8
0P0B20T03@0A1`P0308300/10P0C2@X06@l@01P>3`0C2@X06a4B01@:2`1:@440OWAe01D;2`0@1P@0
0P0B2@@01P0?208030D000/30@0?2PL03PT600d91P803@T800`03@P8018:200?1@@04`T801061@0>
10<07aDD01D;2P0B20L040H501881`0A1`H200h40`0;00d30P0@1PD04`T801D;2P0B20L040H500h4
0`0A1`H04`T801881`0@1PD05?ooool001_ooooo00<04Ph=00l;2P0?2`X00P0B3Pd0900?2`X030P7
014=300<20L00`0000l;2P0<20L020@301DA400/:2L04@d<00T61@0J5QD04`l>01HB4@0A3@`040`;
014=300=2@H0514;01<@2@0>2`@040d701@A300A3@X06ADB01`H5`0F4Q403PX9010<2`0300004Ph=
014=300810<02`L601@@3`L040`;018050h@01dG5`0J5A405Q8901XG200L6@P07Q/<00H2000h=2/0
:B@R01<=3`0?2P/01`<2014=300>2PT040`;00d9200D40l2014=30804Ph=01004`l>01DA3`0C3``0
4@d<018>300E4P/05Q@7024P2@1eMUL0YJJ706m^EP0b<2408QlH01LC400F4Q405A4@0`0D40l0500C
3`h04Ph=01<?3P0C3`h04Ph=014=300B3A0061<G00d8300J5QL081`M00l;2P0I5A806aLD01PD4@0C
40/05A8=01@A300400004@d<0P0D40l01P0A3@`05Q8A01HB4@0@30/05a<B04A0?`80510?00@07QXI
03Te=00P71/020@30P0F4Q401P0E4A006QHE01LC4P0C3`h061@C01DA40804`l<03d061@A01LC400B
3P/04`l<014=2P0D40d030P501TE4P0=2@L05a<@01@A300C3`/03`/:01H@400L61T04`hB00d8300K
5aT06ADD01/G5P0=2PH00`8001XJ600<3P/04Q8@01HF500E5A006APD00`;1`0I5a808AhI01<@2`0H
5A002`P300X91@0O7Q`0;2/Y07elNP0S8R002PT701<B400G5Q@06QTG01TH5P0D4a404Q4?00h>300H
61H06ATG018B400>3P`03`l=01XJ600>3P`02PX801LG5@0N7Q`07AdK01/K6@0H61H05QHD008051@B
00d05ADC01LG5@0F5Q@05aLE01PH5P0D51804Q8@01LI5P0K7AX04Q@A02h`;@17BDH0:bdZ00805aTF
0P0H6QL06P0I6aP061/I01LK6P0H7AT061dH01PM5`0G71H0724K01/P6P0F6QT09RX[024U:00F6B00
5Q/O01TR8@0R:bX072DT01dV9@0Q:RT0:34`02</:`0H8B004a`K02</:`0M9RD082LZ0P0R9b/0300N
9BP082P[024Y;00M9RT0<C/m020Z;00M9bT0=D1202Td=P0T<SD09C<f02Dc=08093@c03X08SDc02<e
=@0W>CT0;3m402@h?`0mDEX0:Ce702doB@0gBU40<TA>02i0C00/?TX0=DMC0312C00bAD`0=DQ>03U=
CP0jCTd0?51?04IIG`10DeX0>4]B03mBF@17FV40@UAN04=EG`12E5h0?4iH03mAF`1;GFL0F6Yg05=T
M01;G6/0@UAP049DGP16FEh0B5aM04MKG01=HF80BemP04]NI01DIfh0FFac04iQJ01BIF`0DfI]05EX
KP1FJFd0CV9S05AXI`1FJVP0EV]V05U^I`1JKfP0DVMP061cK`1SLg00J7Qe0P1YNGH02`1_Og`0L81m
0761OP1bPWl0M8B107R8Q@1jRXL0P8b<08:>SP24T900R9:C0080R9:D0P2CVZ004@2EW:80UYZS09^O
Z02RYZl0YjVe0:^[]`2^[[X0];C00;Rf``2i]l@0^kW60;nkb@32_/`0al?A0<g7e@3>b=H0e<WG0080
eL[H00T0el[K0=c>g`3Qd>80i]?W0>gGkP3_fO00l][b0?CLm03fg_H00P3jh_X02P3li?`0oNOl0?cY
o@3mjoh0o^go0?g_o`3olOl0oo?o0?odo`3omol20?oho`80ooWo0P3on_l30?oio`0k0?oho`3nmol0
ooKo0?oco@3nl?d0onon0?k]o`3ljOl0o>On0?[Tn`3hh?H0mMgb0?3Ik@3/dnH0im7O0=k=e@39^/40
d<760<joa03?`lD0`KFf0;nd/P2f[:T0[jJQ0:nVW`2[YI`0UI>408R9M`1bMF80JfiK079eHP22Qg<0
KG9N07f2K01dO6H0IfmJ06YbF`1RJED0NX9g06M^I`1dNg@0KWE^06]bJ`1[MFd0KgYb06iiL@1SKVH0
FfQO05i[HP1OK6<0GfaR055NE012CdH0?TU103Q3>`0`>cD0=3dh03<l=`0oB4D00P0/<S001P0b>cX0
>TA503<o@00a?Cd0<clo02hj>@808bl]02@0;c/h02`h=00b?SX0<3`h034m>@0eA3l0:STd03a;AP1J
IV80Hg1Z02<`:@0X<bd08bhW02D_9`0T;RH08R`S02P_:00[<2`0:bd/02X/:`0X;2/0:Rl]02/a;`0Y
<Rl0:S@`02Pc;`0V<Bd09S8^02Td<00P9B<07b<R01XN7@0P92<07b<R01LK6P0L81l2020T8`0F01lS
8P0P92<082HR01hW7@0L9Qd072HN01lU8P0P9RH082DX020T9`0M7R8071dQ020Q8`0W:BP09RPW02<S
8@0L71X08B4O01dM6`0Q8Al06a/I01dM6`<071`J0P0M7A/0300Q81`05aHB01/J5P0P7a/07QdI01dL
600H5a<04a8>01hM6@0[:RH081lK01DD40806APD00X05aHB01DD400F5A408R4M01`K5`0D4`l040l;
01PG4`0Q81`06aXF0P0H5a<02P0G5Q805A@@01@C3`0A40`051<?01LF4P0D4`l06APD01PG4`0E40d2
01P@3P0:01L?3@0F3P`05Ph<024I5`0J4Q005`l=01TA3`0G3`d05@h<018=2PD04Ph;00H04@d:00h:
1`0N6QL04`l<01DA3P0B3P/2010<2@<04@d:01004Ph;02LS801NFUL0:RHS01DA3P0>2PL05a<?01P@
3@0D3@L04P/501@?2`0F4@d04@`800L3000?30X06APF0P0^;B/00`0B4@l0:RDR01XE4P02014<2@04
01@?300I51404@`901<>2`803PT600<04`h;014<2@0?2PL01@0?2PL02`0A30T040/8018=2P0=20D0
4@`902LR7`17@D4040X:01D?3`0P6QX0208200803PP800X03`T9010:2P0@2PX03`T900h8200E40d0
6A@A03Pc<00]:2D04@`90P0>2@H0300B3@X05Q4>01<>2`0I51404`l<010>300:2@L04A0>01@@3`0:
10@03@L7010720<04PP900l04PH80147200?1`P03`T901@>3P060@402P@4010:2P0<1PH02P@4010:
2P0>20P02`D501<;2`0C2@X00P0@1PL3014720<04PP90P0A1`P07P0E2Pd081DI02<H700A20X04PL;
00/0100@1@T04PL;01462P0@1@T03`@800h31`0@1`T05@l?010:2P0D3Ph05@l?01<=3@0@2PX030H6
00L10@0A2`/01P0000l92@0=1@H02@0001H<3@0>10D04@L801D=3@8040H70P0A1`P201882@0?00l5
1P0B20T05P`=01H<3@0C2@X03@<400L0000900003P@501H<3@0T6Q/03P@400l50`0E30L04PT40080
30@100d05`l=00l:1`0?2PL03PX700d9200<20L03@P701<;2@0?1@@04PP701471P0;0@004PP70080
40H500L04@L601<9200A1`H03@<201471P0?1@@040H5008050X90P0A1`H01@0@1PD04@L601<9200D
2PT040H501Cooooo000Kooooo`0D018>3@0K5aH04Ph=00l;2P0C3`h030P701DA400C3`h0<2`[04U5
A00F4Q4040`;01DA400D41003@T800h:2@0A3@`030P7010<2`0D40l3014=300900d9200B3Pd03@T8
01<?3P0@30X03PX801HB400L61H02@D40080510?0P0D40h01P0D40l03`/:01DA400@30/05Q8A01<?
3PD04@d<01@04@d>018<400J51H04`d<010;1@0A3@<03`/101HB2@0I5@h06QD@04i9B@0C3Q405Q4D
01@@3`0J5QD05A4@01PD4`0F4Q4040`;018>3@8040`;01404Ph=01@@3`0D40/04Q0601DB2`0D4@X0
4a0501dL2`1:BRl0alRW0?oohP2`/ID0<S4N01hL3`0F4`h05Q8A01@@3`0201<?3P80510?00<04`l>
01@@3`0D40l00P0C3`h0C@0D41002PH801@?4P0D41405A4B01LC4P0H51806QHD01HB3`0B3PX05A4=
01@A300H51<04Ph=010<2`0O6aX0:RHU01<?3P0=2@P06ADD00h:2P0K5aH03PX9018>3@0N6aX0>SHe
02XV9@0=2@P03PX901DA400G4a8081`K01XF5@0B3Pd06QHE01@@3`0G4a004Ph;01LC400J5Q<05Q8?
024M6P0H51404Ph<014=2P0J5Q<05a<@01XG5@0D4a80410@01@C5@0C4QH040hB01PE6@0=2Ph0510B
01<?3P0K5QD05a8>01LE4@0B4a405APH01LJ600D5aL04Q<B01DF4P0I61D0K6]X04E3?`0N71L04a4=
01DB3`0F5A<04A0>014@3`0S8R005QDC008051<A00L05QDC01PG5@0G5Q@051<A01<B400D51805QHD
008051@B00`071`J024Q7`0n?Sd04A4?01dM6`0L71X02`/901HF500H61H051@B01<C4@0F5Q@201PH
5P0<02@T8P0K6aT05ADC01<C4@0G5aD06ATG01LI5P0P8Ql06adJ02<U8P0X:RL03a4>1@0H6QL0>P0G
6QP05QXI01PM6@0J7aX06QlI01TN600J7aT051TC02HZ:@0A5AH09RX]01`O9P0I7R408BXY01LP7`0H
8B006B8Q00hG5P0M9RD041TH01XS8P0R:bX06R<R01lX9`0L8b<08BHX024V:@0O9RP082PY02<[;P0S
;2d0;3Hf02/e=`0S;Bh07b/Z028^;`0S<C@0938e02Dd=P0V=SH09cLf02Hi=`0[?Cd0:S`l02Hi?@0^
@DP09SU002m3C00]@4L0>DaC02m2B`0eAe<0;3i:0394D00^@4/0<49<03M:D00kCU8203a@D@0R03mB
F010DU/0?e9J04EGH01;GFH0AeUS045CG@12E5h0?U1J03mAF`19FfD0DF=_05AVM01>H6h0B5YV04UK
I@1:GF<0BUeQ04YNH01?HVD0BUeQ04MJH01=H6L0D6=Z05AWK@1CIVd0E6M]05MZL01HJfh0EVY[05EY
J01IKF/0E6UT05=XH`80FVmX03h0Gfm/069bK`1[NgP0K7ai06YjM`1]OGX0L81m0761OP1bPWl0Lh>0
07J6P`1hR8D0Oh^;082<S022SXh0Qi6B08ZDUP2<UYP0Yjjd09BKX@2EW:80VYjW0:2T[@2Z[[L0Z:^e
0:f]^02`/;/0]KG00;Vg``2k^LD0_;[60;nkb032_//0al?@0<c6d`3=am@0dLWF0=C9e`3BamD0e<OH
0=c>g`3Re>D0imGX0>cHkP3^fO00l=Wa0??Kl`3dg?@0nN7j0?WRnP3jho/0o>Kl0?_Xo03mj_h0oNcn
0?k]o`3okol0oo3o0?oao`3om?l0o_Ko0?ofo`80ooOo0P3on?l0;`3omol0ooKo0?kfo`3nmOl0oOGn
0?oco@3ol?/0onkl0?o^o`3ojoh0o>Ol0?[TnP3hhOH0m=cb0?7IkP3[dnH0i/kO0=k:eP3Gb=00b;W1
0<bna@36^[h0bko10<6f]@2i/:/0YinG0:6IT@2SVi40V9:608B4LP1lOV/0MGQU07UlJP1mP6h0NWm]
07UoKP1mPg80I6YJ05aSE01]M6D0KgIX07AkL`1aN740NH1i079kL`1aNG80JgE]0080J7=[02@0HFeT
05YWGP1LJF00FfQO069_I@1BGeD0@e1704A?A`12CDD0>TDo03e6@@0a>SD0>44n03m5@`0m@d40>dA3
03e7B00`?3d0;3Ph034m?@0b?Sd0;3Pf02hj>00hA440<clk03Q4@00b?SX0;CTe02Te<@0Z=c80;STe
05QTH00`?3L0:C<]028/9`0P:282020Y8@0402D/9@0`=Rl0;34]02`_;P80:Rh]00l0:Rl^02X`;P0Q
:RL092h[02H`;00T;b/08bhZ02@^:P0S:2L092PW01dQ800K7ah09RXY01/O7P0O8b800P0S9bH2024U
9005028X900P:B007bTP01hX800P9R<00P0P9BP03`0g>ch0:2T]024R9P0O82408R@S01`N7@0P81h0
6a/I024Q7`0M7A/08B4O01/K6@0L71X06a/I01XJ600201/K6@0F01`L6P0L6aL061LC01`K5`0N7AT0
7A`H01PG4`0E510051<?01LF4P0O7QX06QTE01LF4P0J6AD06APD01LF4P0F5A405A@@01HE4@0E5100
6QTE01PG4`8051<?00D04a8>01DD400E510051<?018A3@02014@308051<?00@04A0<01@C3`0D4`l0
5A0=0P0G4@h0100F40d05@l<01D?300I4a0201<=2P0601PB3`0F40d050h;01<?300B3P/04@d:0P0B
3P/02@0C3``05Q8?014=2P0/:2D08alL00h:1`0A3@X03`/8010<2@02014=2P0E018>2`0C3``04Ph;
01hJ5`0<20D04Ph;014=2P0D40d05Ph;01<<1P0B2`D050l;01D@300B3@T061@A00`91`0W9R@0Ti:@
0::QW`0>3@/061<@00804@`900T04Pd:014<2@0D3``040/8018=2P0?2PL040/801PC400I51401P0@
2`P03P0E40d03@P501@?300@2`P03PT602@O700`:RX05Q0@014<300A2`/050h>010:2P0>20P03`T9
0P0@2PX05P0?2@T03PP800h91P0?2PL04`h;014<2P0=20D03`X7010;200B3@X05Q4>018=2P0G4Pl0
4@`905UFE@0S8Al02`T701hI600G4A4040X:0107200A1`P201882@0:0187200@1PL04`/<010:2P0;
1@D04@`<01`F5P0<1PH03`T900d71`8040X:00P03`T901<;300B20T03`D60147200E2``05`d>01@:
2`804@L80`0C2@X01`0G30l02@0201L<400B20/0304501@93@0C20`01@0A1PX03@0B2@/0;BLW01lI
6@0=1`L03@P801D?3`0>20P05a4A018<300H4Q803PP801D?3`0?1`P00P0B20T00`0D2P/05P`=01<9
2P0201061`804@L80P0B20T04P0=0`@06a4B02DK700C2@X0308301`B4`0h;Rl03@<401@:2`0<0`@0
50X;01<92@0@1P@060l:01071@090@004`/8030X9P8040/800/03PX800d9200<20L03@P801081P0>
10<04`T801L=300C2@P04@L600l5100200h40`0?00l5100A1`H04@L601<9200G3@`05@/:01471P0?
1@@04@L600l5100A1`H03`D401471P0D2PT03`D401Cooooo000Kooooo`0401@@3`0O6aX05Q8A00l;
2P804Ph=00l03PX900T5100b;Rd0GUYI014=300<20L01`<203lk>P0R7Qd02`L600X61@0S7ah030P7
014=300@30/00P0B3Pd04`0?2``03PT>00d83P0F4AD04@`@018>3`0P71d0=30`00d9200H51<040`;
00P40@0<20D04Ph=01<?3P0W8b806aLF01TE500<20L01@0B3Pd0500B3Pl05Q0E014;3`0@2P`05a8>
01TD3P0D3`T040/601/F4P0;1P<04@`>00h73P0<20T08alN01<?3P0D40l030P7014=300G4a804Ph=
0P0@30/04@0B3Pd0510?01DB300D4PH05Q<:01LD2`0D4PH081l=03Lg7@1hNET0/;6?06QYC00@3`00
5aD801PD3`0E4A00510?00<04`l>00<04@d<010<2`0A3@`00P0B3Pd0D`0A3@`05Q8B00@00@0H51D0
3PX;01HB4`0@30/04@d<01@@3`0B3P/04@d:01@@3@0D40`01`<200d9200H51<0510?028N7@0G4a80
4@d<01@@3`0H51<06ADD00L30P0C3`h06ADD01HB4@0@30/07QXI01XF5@0>2PT04Ph=01LC4P0C3`h0
3PX9018>3@0?2`X04Ph;00l;200@30T04Ph;01LC400R7Q/0510=01TE501:AT<0PGej01lK600920H0
1@T<01@I7@082a0010L<01<D6P0=318071/Q01LD600D40l07aXG01XE400J5a803a4@01@H6@0=4A80
8bLX03`o@00F61L08R@S010A3`0G5aD061PF024P700=30P04a8@01HE4`0N7A/00@0001PG5@0@3`d0
5A@B01@C4@0C4Q0051<A00805A@B00@03@d;01<C4@0D51804Q8@0P0?3`d0100J6QP08b<Q020P7P0K
6aT201PH5P0501TI5`0F5Q@051@B01<C4@0D51800P0E5A<201TI5`0701LG5@0F5Q@05aLE01PJ5`0J
71T07AlL01@F4`0401TK608061XG00D05aTF01LJ600G6aX061dI01XO6P0201XO6@0I01PM5`0`=Bl0
HfMV02L[;00D61/06QdT01/P900_>3L09Bh]01XS8P0B6aX072DT01DN7@0Z<c806b@S03m8A`0a>ST0
1Pl>02D];00M8b<07bDU024X:00R:bX0:S<b03@m?00202@^;@0602hi>00/>3H0;3Pg02<a=00U=3T0
:CPl0P0V=SH04@0Y?3X08S@d02`n?P0[?T40:Ca202@g?P0/?dP0=4M>03U<D`0bAD`0>4YF03U;E`0l
CUX0;d5=0353C`0gBE80>diD0080>diB02/0>diE03mAF`11Ded0@E=M04EGH@17FF<0B5YT04]MI`1:
G6H0BE]U04eOJ@1<GVP0BE]W04QJIP18FV@0BEaS04QKHP15F5`0B5]O04]NHP19G600BeiT055TJ`1?
HVT0BEaR055TJP1ML7H0G6mc05AWJP1AIFH0CV9Q059VI01IKF/0F6eX05I[IP1LKfT0GFeZ065aKP1[
NgP0K7ai06YjM`1^OW/0Kgml0080L81m03L0LX9o07B4P@1fQX<0Oh^;07b8R01kQhL0PH^<08RBU02<
UYP0VJ2V09:IW`2HWjD0XZJ_0:2T[@2OXj`0Z:^d0:b/]P2_[kT0]KFo0;Vg`P2j^<<0_K_60;nla`31
_/T0a<7<0<W3c`3:a=00c<CA0<k3d@3?a=80dlKG0=c>g`3Pd^<0i=?V0>WFk03[f>h0k]S_0?7Il@3b
f_80mmoi0?OQn03hh_T0n^Ck0?WVnP3kj?`0o>Wm0?cYo03nkOl0onko0?o_o`3olOl0oO?n0?oco`3o
m?l0ooGo0080ooCo03P0o_Co0?kboP3ml_h0o?;m0?gao@3nl?d0o^cj0?kYnP3njO/0o>Oj0?[Tn@3h
hOH0mMgc0?7JkP3/e>H0i/kN0>38eP3C_l`0c;o90<:e_`37^/80_K:f0<Bj^`2j/:h0/:VQ0:FOU02Q
Vhl0VI>507ahJ01mOfX0N7]V07MjI`1oPW40PHEd07]oL01lPW@0MG]_07EkL01OIe`0IfiV06YaJ@1f
OGH0Nh9k07ElM@1_NG40LWad06QcJ`1OJV80HFaT05i[HP1HIE`0EfAK055NE@16DdT0?4To03M4>`80
?DQ000@0>D@n03Dn>@0f?cX0>44n0P0d>SP0;00mATD0>dE602lk?00X=3@0:cLg02lk>P0]>CL0F6AR
04eIEP0b?SX0<Cdi02lk=`0`?3P09c8^02Td<00N:BD0;cXf02lh=00Q:RD09bdY02@[9@0S:R<082DO
020U7P0Y;RP0;34]02/_;P0Y;B`09bd[02D[:@0T:RP07bPU02D^:`0Y<Rl09S4]028]:@0P:BH07R<R
028V9@0X;2/07R8Q02HZ:@0I7A`08RHU0P0U:BP202<W9P0D02<Y9@0S;2@08R`T024Z9@0Q9bH07R<V
01dR9@0]<C@08R<W01lP8P0P8R408B<R01`N7@0O7ad06ATG01lO7@0M7A/08b<Q01dM6`0K6aT301XJ
60806a/I00H05QDA01`K5`0K6QH05aHB01HE4@0H5a<201`K5`0401DD400F5A4061LC01LF4P8051<?
00/05A@@01@C3`0B4@d05aHB01DD400I61@061LC00/:1P0D4`l06QTE01DD400201@C3`804a8>0P0D
4`l01@0A40`03Pd900l>2P0@3`/0514=00805Q4>01D05A0=01@?300D3``05A0=018=2P0C3P/050l<
010;200B3@X05A4>01@@3@0B3P/040`9014=2P0C3``030P502DQ7P0@30X02`L401DA3P0B3P/00P0@
30T3014=2P0K018>2`0O6aP01@4001LC40070`002PH300`91@0C2`P050d701D>200A30P040/7018=
2@091@804a0>018A3`0J6AL06APF00/:200?2PL040/801HA3P0E40d03`X700h91P0@2`P04Pd:0080
3@P500<04Pd:010;200A30T01@0A30T03P0D3``03@P5018=2P0D3``03PT6014<2@0F410030H605I@
D00L5QH05Q0@01LA4@0>20P03`T90P0@2PX01P0?2@T03PP801<>2`0L5a@02`H300l:1`8061<@00d0
4@`901<>2`0D3``03`X7014<2@0;1P<03@T900/71P0810<03PT9014;2`0K5AD040L800804@P900/0
4PP90147200@1`P03`T900h8200B30`02@<300d71`0>20P030H600h82002010:2P0800h8200@20T0
40H700l51P0B20T05`d>01T?400E2``20147200<01<92P0D2P/050X;01@:300>0`L02`0401X?4`0;
00@06@hB00l4200@1@T04@H:0P0C20`04`0D2@d03@D702LQ8@0G4A404@/;00L10@0B30`020<301H@
400?2@T04@/;00P20P0>20P040T901D;300c:BX0BT1101T?400?1PL00P0@1PL2014720804PP900l0
308300d3100?1@H04`T:01L=3P0L4Q<081HG00L0000@1PL01`0001@:2`0<0P803`D301D<1`0B20H0
0P0<10400`0G3`d03PT600h91P0300d9200I00h92@0A20T04@L601881`0C2@P04@L600h40`0@1PD0
3`D400`20@0;0@003`D401D;2P0<0P4050X901D;2P0@1PD03`D401D;2P0=0`804PP700d30P0?1@@0
5@/:00d30P0Dooooo`006oooool04`0@30/0510?018>3@0A3@`05A4@01PD4`0B3Pd05A4A00d9200O
6aX03PX9018>3@0D40l07a/J010<2`0<20L03``;00T5100;1`H00P0A3@`2018>3@0C00h:2`0E41H0
71LN01<>500=20h050lC01HB4`0I5AH02PH5018>3@0D40d06ADB01HB3`0<2@P05Q8A07mkNP18A4<0
0`0001LC4P05018>3@0D018>3`0H4aP01@0500`62P0H4Q405A0=00`70`0E40d020<000d71`0C3A80
9b0W020K7`1=BDP07QXI00h:2@0J5QD040`;00/71`0B3Pd2014=300?018>3@0C3`h071PB01HD200A
3PD05a@=01DB2@0H5PT061L6024Q1@1;C2d0>3PO014?000K60l0510<00<0510?00H04`l>018>3@0@
30/040`;014=300C3`h2018>3@0N01DA400@30/0510?014=300I5A@05a<B010<2`0D40l04`l>018>
2`0D40d04Ph;02@P7`0>2PT0510?03di>01IEE@06QHE01LC4P0D40l040`;00h:2@091@@06QHE00@0
000:1PD03@T801LC4P0D40l05A4@0`0A3@`2010<2`0U00l;2P0?2`P04Ph;014=2P0?2`P05a<@01XF
4`0O6aP030P5010<2@0e<Bh030P701LG5`0:3a<03A@J01/R:00P9B/05QTQ014A6@2DTiT0BDI:00`8
1`0B3@X04`d8018?2P0?4a804AHI01`Q901WK6l0UY^K02/_<00I7Ah04A@C01`N7@082PT01`L601/K
6@0201HE4`0401LF50071P@051<A01DD4PH051<A00l05QHD01/K6@0M7A/06a/I01HF500D5180:b/Y
01XJ600<30X04a<A01DE4`061P@05QHD01TI5`0G5aD00P0C4a40100F5Q@04A4?01PH5P0J6QP301PH
5P0501LI5P0I6aP071hK01@F4`0K7AX00`0L7Q/0600K7AX06Q`I01XL6@0I71X05a/J01LL600I7QT0
6QlI01/P6P0G71H08bPR03a0?`0L82402`lB01DH7`0O92P092d/01DN7@0G81l07BHU02`e=00F7ah0
4a`K01`U9080;SLf03<092d/01dU8`0O9B<082HT02@[:@0U;R/0;cPe04YDD@1@FeL0?4M302hi=@0/
>3@09c<a02Dc=P0[>Sl0;Ci102@f=P0Q<c<0:C`j02Dg=`0]?cl0<dE802Hg?P0[?T@0<TE<03E8C`0d
Add0<TE<03=5D@0nD5`0>D]I03E7D`0gBED0>diF03iAE`0oDUH0?e9G03e?F@0mCe/0>TaH03a>F013
EEl0@UAN04]MI`1>H6X0BUeT04IIH018Ff80AUQQ04]MI`18FV@00P17FV406P14Eed0?e9H04EHGP17
FV00BEaR04mRJ@1EJ6l0CV5X04]LH`1CIFT0GFmc05U[K`1CIFP0FF]]06]mO@1GJVT0FVe[05e`KP1F
JFD0GG1/069bL@1SLg80JGUh06YjN@1/O7/0Lh>20`1aPH00301cPh80MHF407N7QP22SXh0Oh^;07f9
R@21Rh`0QHnA08RBU02AV9h0VZ6W09bSZ@80XjN`00/0Wj>/0:NZ/`2/[;H0[jni0;Bd_P2h]/40^[S3
0;jla`30_LP0`[o:0<C1c0020<O1c@0<0<W1cP37_l`0b/;?0=C9f@3Kc]l0g]3Q0>;Ai03We>X0jMK/
0>gGkP3_fO00lM_b0P3fgoT03P3hhO/0n^Ck0?_Uo03li_`0nnSl0?cYo@3njoh0onco0?o]o`3okol0
oO7o0?oao`3ol_l0oo?o0P3ol_l0Q03mlOl0o_3o0?g`o`3ll?h0oNon0?k/nP3mj?L0nnCf0?[SmP3i
h_H0n>3f0?KNm03bf_00kMKZ0>S@h@3QbML0g<CB0=:oc03<_//0`KBn0<Nl``31][X0aK^l0;:ZYP2[
Y9`0Y9jC09REQ02?S7T0NGMT07AfH@1fNF@0Nh1/07n3LP21QG@0Q8Uj07j4N01mPgT0Z[6X08B;Q01g
OWL0LgYc07R1O01eOWT0KGIa07=lM`1_N7<0IG1Z061[I@1QKVL0GV]T05ETG@1DHe`0CUeE04QEB`10
CD<0?DY1049=A@11C4@0@Da603M0>`0mAT40>D8o03Dk>@0l@T00@T]:03U3A00c?d00<3`l034m?@0b
?Sd0<Cdk04QDDP0oBdP0:3@`02Te<@0W<bl09S8^01DP700Q:RL0>T=001HO700c>CH0;38^02L/:00X
;BP09b`V02@V8@0O8Q`09BXT02T^:P0X;R`09R`Z02D[:@0S:BL08BLU02H/:P0Y<2h0:C8_02L`;@0T
;BX08b`Y02T^;@0H71/08bLV01hR8@0/<2l082@S02HZ:@0W:bX092PW01lS8P0L81l06b4M024Z8P0Q
:RD082TT020V9@0M8RD0724T01dQ900J6ad06a`N01hP7`0M7a`06adJ020P7P0I6AL07alM01dM6`0U
9B<0820N01lO7@<07AdK00D07QhL01lO7@0K6QH07A`H01/J5P0201PG4`0901XI5@0L6aL06aXF01DD
400G5Q8061LC01HE4@0E51005QDA00806QTE00P05QDA018A3@0=30P04Q4=01<B3P0=30P040l;014@
30804a8>100D4`l01P0C4Ph04Q4=018A3@0A40`04Q4=01DB3P805Q4>00H05A0=01@?300D3``050l<
01<>2`0D3``2018=2P0401lJ5`0G4a005A4>018>2`803`/800L04@d:03Pd<@1EDDh0510=00h:1`0L
61D030P500804Ph;0`0A3@X02`0@30T04`l<00H2000F4Pl02`L402/W900c<2`05@d:01D>200D3@L0
4@`8008040/700h05Q8?00`91`0E51804A0>01TH5P0R8Al050l<014<2@0D3``04`h;010;200C3P/0
3`X7014<2@803@P500<03`X700`7100A30T01@0A30T03P0B3@X04`h;01@?300D3``04Pd:010;200@
2PX04`d=03D_;`0G4A40@cdm00`61P0>20P03`T90P0@2PX04P0?2@T03PP800`7100?2PL02`H300`7
100=20D030L4014<2@0C3P/050l<00l:1`0A30T02`H300d8200N61P091hN010:2P80100000@03`T9
01892P0B2@X04PT:0P0A20T00`0?2@T01P0001D?3`0301<=3@0300d71`0>20P03@L700803`T900@0
40P801061`0?1@H04PP91@0D2P/02P0C2@X04PP901882@0<10@0<bP/00L0000;00@03P<701L<400D
2@d401462P0C01872`0A20X03PP800@0000f<3003PP8014;2`0H4Q807aTI018<300=1`L030H601XD
500E3@d01`0001lE5P0Y7b0050X;0147200201061`804@L80P0B20T03@0?1@H03P@50147200H3Pl0
5P`=00/20`0D2P/0;R@U01P>3`0700003`D601T?3`0@1P@00P0B20H00`0?1`D030@200/30P0200`6
1P0900d9200=2@X03PX;010;2`0B2@X04`T801471P0?1@@040H500803`D400P04@L600l5100=0`80
3`D401<9200?1@@040H501471P804PP700L04@L600h40`0D2PT03P@301061@0G3@`03@<201Cooooo
000Kooooo`0f01<?3P0A3@`05A4@01DA400@30/04@d<02/W9P0e<C004Ph=00T51@0E4A003PX901/G
5P0B3Pd04`l>00d9200@30/04Ph=00/71P0B3Pd040`;014=300B3Pd040`=04M2BP1oNX407APO014<
4`0F4AL02`H:00d92P0H51<03`/:01@@3@0?2`P02`L4018>3@0@30/071PG01PD4`0C3`h03@T801<?
3P0B3Pd03@T8014=300J5QD04Ph?02LP:00I4QT071DK01hH6P0G4A803`X80P0C3@h08P0F41<04P`B
01D>5P0B31009B4P00h:2@0?2`X05Q8A00/71P0D40l04Ph=014=300?2`X0510?02DQ800Y9R408QlH
00h:1`0E4A404`l?010<200H5@T04a8401`K200M6`/05A<:01PE4P0D40l02`P701DA400F4Q403`/:
01LC4P0@30/2018>3@0<01@@3`0E4A004`l>00l;2P0J5Q@03PX801dI601>BTT0CDU8018>3@0D40l0
4`l>0P0B3P`02@0A3@/040`;01`H5`0@30/061@C01`H5`0A3@`03PX901DA4002014=300601TE500H
51<0510?01PD4`0C3`h04@d<0`0C3`h0<@0A3@`04`l>01@@3`0B3Pd04`l>00l;200D40d05A4>01@@
3@0G4a00510=014=2P0H51405A4>010<2@0F4Pl04A4A00`A5@0I8RT0VJ:Y0:nc^`0O8R/05APO02TX
<00J5a`05A4@01XE4P0F40/06AHA00lC500B61/0:2d`08jCUP35b//0=CTj01LK700A51@03Q0?01/M
700E5Q@04A4?01TH5P0D4a402PT701hM6`0@3`d05aHD01TH5P0C4Q000P0D4a4201<B400A01@D4P0A
4@l0410>01LG5@0L71X06a/I024Q7`0G5aD06QXH01LG5@0F5Q@04a<A01@D4P0G5aD05ADC01<C4@0E
5A<00P0G5aD0300H61H05QHD01DE4`0I6AL07AdK01DG500N81d06A/H02T[:00F61D03a4>01XL6@80
6A/H0P0H6QL03P0J7A/051PG038g<`0E6QD07b@N01LL5P0M8Q`05a`F00X<2`0P92D07R8U01XM900L
8BD0624P0P0G81l0A`0M9RD0:C8a01DN7@0N9bH07BHU01lX9`0R:bX0:c@c028Z:00V;2X092XX02Xb
;`0V;b`0>D8o09ZTX@3Fgmd0[;Nc04eHE00hA400:SLe02ho@`0cA4/0>4Y?02Xl?P0Q<c<09cTi02/n
?@0Z?C`0;d5202Xl@00b@dT0=4E=03=6C00^@DL0=4M>02m1C@0gBED0=DME03I8E@0gBED0>deH03e@
F00nDEL0?U5H04EGHP10DUl0@E=O04AFHP0mCeX0AUQR04IIH@0jC5D0?e9I04AGGP15F5h0AeYP04AG
GP15F5l0@eIM04EHG`18Ff80AUUP04AGGP16FF00BeiT051SJP1CIVd0DFAZ05EWJ`1EIfX0EfU/0080
E6IY03`0GFma07B6QP1MKfl0DfIU05Q[J@1LKfd0GW5^06QhM`1WMgL0J7Qh06YjN@1]OGd0M8B30761
P@1cPh80Lh>307B4P`1fQXH0NHV907b8R01nRXX0P8b<08RBT`2>V9X0TI^M09NNY02TZk40WjJ/0:2T
[@2UZK80XjN`0:JY/@2/[;D0[jnh0;>c_02h]/00^KS10;fla@32_lT0`l3:0<:ob@32_<L0`kg80<Fn
bP37_l`0c<CA0=G:fP3JcMh0g<oP0=o?hP3UdnT0imG[0>_Gk@3]fNl0km[a0?GNn@3fgoX0mn3j0?[S
o@3li_d20?cVo0090?gWo03njOd0o^[n0?o[o`3okOl0o^ko0?o]o`3okol0oo3o0080onoo06H0o^ko
0?o]oP3nkOh0nncl0?cZn`3mjOT0nnCd0?OPlP3fgo80mMkb0?CLlP3`fNh0kMOZ0>WCi03QbmX0f/G@
0=K0b`3Ea<l0dlSC0<RmaP38_/H0_kJi0;J][P2WXI`0Xj2D09RFR02<RWP0QHIa07n1J`1eN6<0OH5/
08:7M01iOfh0Mga]07QnL@1lPgP0KgI/08jESP1hP7/0L7Qc07MoN`1cO7L0JG9]06A^J@1]Mg80IW5[
065]IP1RKfP0IG9[05aZH`1FIEh0E6=L055PF01:Edh0@Di403M4>`0kASh0=T4i03Q3?@0oB4<0<3Td
02lh=@11AdD0>3hl03@m?00jA4D0<cm003I2@P0hA4@0=D50038n?00_>cT0=40m02lk=`0`?3P0;3Pd
02Te<@0lAD807RLT02H_;00_=C<0<3Hc02`b;P0Q9R809R/V02<X8P0W:B@092LQ02@Y8`0U:bL09Rh[
02D]:P0S:RP08BPV024W9@0Y;bd0:S4^02Xb;`0W;R`08RTW02<Y9`0`=3<201`P7`0@01dQ800T:2L0
8BDT024U900S9bH09RXY02DY:00S9bH08bTW024Y900O:2@07RLT020V9P0R9bX07B8U01hR9@807b0R
00d0828P01dO700Z;2P07alM01TI5`0K6aT07AdK024Q7`0N7Q`0820N01lO7@0K6aT06ATG00806QXH
00X06aXF01TH500H5a<061LC01LF4P0I61@06aXF01XI5@0I61@06aXF0P0I61@0100K6QH061LC01hM
6@0M71P201HE4@805A@@00D051<?01PG4`0I61@04a8>014@3002018A3@8051<?0`0C4Ph0:P0F5A40
51<?018A3@0E4Pl05Q8?01<?300G4Pl040/801HA3P0D40d040/801@?300I5A805A0=02HQ7P0J5Q<0
4`l<01@@3@0=2@H04`l<01@@3@1>BTL0EU9?018>2`0A3@X04Ph;00`81@0B3P/04@d:010<2@0B3P/0
5Q8?01<?300I5A807QXG018>2`0D40d0;BTV03@`;00G3``05@h801@=1`804Pd900l03`X600h:1`0@
3P/06APF00h=2`0C4Q002`X801D@3@0@2`P03PT6010;200E40d07APE00h91P0A30T00P0@2`P0=P0B
3@X040/802/V8`0M61D02`H501@?300A30T050l<00`7100C3P/04@`900h91P0@2`P04@`902HP800A
2`/050h>018<300E3`l02`D500h8200@2PX04`d=014;2`0?2@T04@/;01<>2`0:1@804Pd:00l:200@
2`P03`X7010;200A30T04Pd:00l:1`0A30T03PT6014:2P0<10D03@D601092@0A2`/03PP802DO7`0P
61T08ATJ01@=3@0@2@T030D500`61P0?2@T040X:00d71`8040X:00X03`T9010:2P0=1`L03`T9010:
2P0@20T04@L801061`0B20T04`T:0P0D2P/201D;300;01882@0A1`P04`T:030U:028OH40:1dQ01D:
3P0>1@L04@H:01<8300B1`/00P0A1PX201052@0D01482P0=1`L0100002XT900?2PX03@L700h92@0?
2@T03@L7014;2`0<1PH040X:00`41@0E2``09Q`M00d51@0A1`P04PP900l51P0A1`P201882@0301@:
2`0B20T04PP9008050X;0P0>10D02P0D2P/0:AlP03T_<00?1PH040H701@:2`0B20T050X901471P0@
1PD201081P0@018:2@0J51@02`D500h:2P0@2`h04Ph@014<3P0A20T04`T801471P0?1@@04@L601<9
200;0P404PP700l510804@L600@040H501471P0=0`803P@30P0B20L01`0=10@03`D401@:2@0;0`80
5`d<02/Q800A1`H05?ooool001_ooooo01003@T801`H5`0U8B007ATH01TE500Y9B@05Q8A01`H5`0<
20L040`;014=300?2`X03PX900T5100?2`X04Ph=0P0@30/06@0<20L04`l>010<2`0?2`X04Ph=014=
3P13?TD0FEAK00T42P0B3A<03@P<024M7P0G4a@06aLF01@@3`070`406QHC01@@3@17@d801P8101<?
3P0<20L08QhM020L6`0@30/00P0?2`X01`0K5aH0:BDT01TE5P0C31<04P/B018<400C3A400P0D3Q00
1P0@2P`03`T=00l93@0B2a805PlF01LB5P802`L601L040`;024M700@30/04@d<01<?3P0D40l06ADD
02<O7P12?Sd09B4O010<2@0810D05A0F01<>5@0B3A<05Q<A01DB2@0F4`X05Q<<01DA400D3aD05Q8E
00d92003010<2`0401PD4`0C3`h04Ph=010<2`804@d<00P040`;01PD4P0?2`P04Ph;00d9200D40l0
9b<R01<?3P804Ph=0P0A3@`02`0B3Pd02`L6010<2`0B3Pd0510?00<0000D40l04`l>018>3@0A3@`0
4`l>00805A4@0`0C3`h00`0O6aX06ADD00l;2P0301DA400:01@@3`0C3`h04`l>01<?300E4@h061@A
01TE4P0G4a005A4>01<?30804Ph;02X0510=01DA3P0@41008RL[00lF701bNGl0OX>901`O9`082100
4Q4G010=4@0E4A005A0=01@>2@0H5A001@T801XO8P0=4QD08BHY0497A`0F6Q/04ADF010C4P0A4a80
4aDD01DE4`0B4Q004A0>018A3`0O7Q`0:RTW01<B400D4a407A`J01@C4@0E518051<A018A3`0A40h0
5QHD01TI5`0E5A<201HF50804Q8@00/05ADC01PH5P0C4a405QHD010@3P0D51804A4?01@D4P0K6aT0
5QHD00h>300201LG5@0=01DE4`0D51805aLE01/K6@0B51408B<P020R7`10@Sl071hK01/M6P0H6QL0
5aTF01HH5@0201LI5P0Z01/N700n@T40Y:VU02<X8`0@5@l0:2dW01DJ500M8Q`0;30_01hR8`0C5aX0
;2lf01`Q9@0P:BP0624P01dV9@0I8R405QlN024Z:@1kQ8<0[kRg07R1P00b>cX0;cPg02P_;P0/<S00
728P02T`;P0d?CX0C5EB0;6k]`3`noL0/;^g03U5@@0/>3@0:cPf01//<`0gBU40AEIM02m1A@0R=3H0
;Clo0P0[?S`01`0]?cl0;T1202m1A@0b@DP0=DI=02i1A`0gBU400P0cAE403@0iBeT0>TaJ03]=F`0n
D5d0?e5M03i@FP0kCEL0@UAR03]=F`13EF<0CV1/049DH019FfD00P0kCUD0200oDUP0BUeS045DFP0m
D5H0?e9H04AGG@13EU`0A5MN0P1;GVD01`17FV40EFQ_05EXK`1EJ6l0F6]b051SJ@1FJ6`00`1FJ6X0
3`1EIfT0E6IX055SH`1GJFT0EFMW05a_K@1XNgT0H7=a06QhN01YNGT0JWYj06alO01^OWh0Kgmo0761
P@0307>3P`0T07N7Q`1kRh/0PHf=08>?S`26TY80SINH096KW@2CWIl0Vj:X0:B[/@2QZ:h0XJF^0:>W
/02QYJh0YZV`0:f]]@2`/;P0/k>k0;Nf_P2j^L40^k[20<6na`32_lP0_kc50<2ja031^lD0`kg90<[2
c`3>a]<0dlSH0=S;g03Kc]l0gm3S0>?Ai`3UdnT0j]O]0P3[f>h01`3`fOD0lmch0?GNnP3gh?X0n>7k
0?WSnP3kiO`00P3ni_`01@3miO/0onOm0?oZoP3mj_d0o^_n00@0onco0P3njoh06`3mj_d0n^Oj0?WV
n@3jiOL0nN;b0?GNl03cg>l0lM[^0>oGk@3ZeNP0i]7R0>7<f`3Ia]80d/790<jm``3:_<D0akg60<Bj
``2n]K/0][2b0;6/Z@2VXid0Ti6508Z:N`2BTh40U9J108>5L00207n4L01[07b0K`1`MfL0Jg9R06Q^
H@1]MFX0JW9W07AkL`1WLFT0HfaW06YcKP1aNWD0JW=^069]I`1SKVP0IG1Z065^I`1PKFH0JGI_06=b
J`1OKVL0EFAM04mNE`0f@cX0?T]103m<@`0/=bl0:C@/03<n>00j@ch0:34/03M0?@1DFUP0>Clm03<l
>`0a>c`0;STj03A0@00hA4@0=40o02lk>@0hA480<3`i02lk=`0d@3`0<clk02Pd<00[=S80:C8_02df
<`0W<2d0;38_028X900V:bL09b`W01dR700W:B@0:2/U02@Y8`0Z<2`0:c@a02Pa;P0T;BX08RXW02@Z
:00Q9bD0:2h/02`b<00T:RP06R0N020V900Q9B@092PW01TM700H71/05QXI01lS8P0R9RD08BDT02DY
:00T:2L08BDT028X9P0T:bL06R<P02H_;00[<C40=3Tl01PM800R9RT08B8T01lQ800O8Ad0D59=09fO
VP0S8b407QhL01dM6`0O7ad07AdK01/K6@0O7ad0820N01XJ600H61H06QXH01TI5`0H5a<00P0I61@2
01LF4P805QDA00/061LC01TH500H5a<05QDA014@300C4Ph04A0<018A3@0D4`l040l;01DD400201@C
3`0401DD400F5A405QDA01@C3`804a8>00<04Q4=01HE4@0F5A400`0A40`2018A3@07014@300@3@X0
40`901XF4`0Y9B8071PE00`81@0201@@3@0B020L6@0T81d05A4>01<?300>2PL02`L401TE4P0A3@X0
:2@Q01DA3P0F4Pl03PX701TE4P0@30T03PX701HB3`0?2`P04Ph;0P0?2`P02@0E4@h0510=00P40@0I
5A803PX7018>2`0>2PL04`l;01D=2P0201@=1`804Pd900d04@`800P40@0B3`d03Pd;00`;2@0I61H0
30/901@?300A30T03`X7010;200E40d06A@A00H040/800D02`H3014<2@0[9R<04Pd:00T50`0200h9
1P0G01@?300C3P/03`X700l:1`0D3``04`d=00l92@0:10@02`D5010:2P0A2`/03`T900/51@0>20P0
40X:00l92@0A2`/0?cXg02@O7004000040/800l:1`0A30T01P0>2@H401482@803`T900X04`d=059<
C01;ADD02`H600L10@0Q6a/040X:00l92@0>20P03`T90P0@2PX03P0>20P040X:00h8200@2PX04@/;
01492P0B20T04@L801061`0A1`P04`T:01882@0A1`P04PP90P0@1PL01`0D2P/05@/=03P]<@0B1`/0
4@P:00h31`0C20`01P0A1PX03`0H3a406A<C00l92@0>20P0>38b018<30040000208205I@D01`JVX0
40X:00T30`0?1`L040H701882@0201<92P0601882@0A1`P05@/<01D;300B20T04`T:0P0@1PL01P0C
2@X05P`=01061`0>10D04@L801<92P804PP90`0@1PL201881`0;01471P0=1@<03PH401892P050000
6aDE03<_<00d;c<06aHJ00X51`0?1PL00P0@1PD02@0A1`H04`T801@:2@0F30/05@/:00l5100>10<0
40H500d30P0300l510<040H500H04PP700h40`07000040H501T?3P07000Dooooo`006oooool03P0B
3Pd04@d<018>3@0@30/03@T800l;2P0=2@P04@d<010<2`0F4Q403`/:01<?3P0D40l04`l>0P0E4A00
100A3@`03`/:00l;2P0D40l2010<2`0N018>3@0@30`0?STl01`H6`0B3Q004`h@00T51@0G4a<0K6QW
05IBD@0:1PH05Q8A014=2P0=2@H0AD5000/81`0I5A@0:2@S00l;2P0A3Pd04Ph=00l;2P0C3`h05Q8A
01@@3`0>2PX04P`?014;3`0A2`h04`d?0P0E3a408`0I4aD050h@010:300?2@`04@/?010;300?2`X0
8QhM00l;2P0E4A004`l>018>3@0=2@P03`/:018>3@0?2`X07ATH014=2`0B3P`0510B01<>5P0B31P0
4`dG01D@4`0D40`04a0;01@@3P0E41@05a4J01@?4`0J5QD04@d<01@@3`0K5aH04@d<00<04`l>00`0
3`/:00h:2@0A3@`03`/801XG4P0F4Pl03PX701DA3P0P71/04`l>018>3@0B3Pl201<?400C01DA4P0H
51<03`/:01TE500B3Pd04`l>018>3@0E4A004`l>014=300C3`h0510?01<?3P0<20L06QHE01@@3`0B
3Pd03PX:044m?002014=3004018>3@0C3`h04`l>01@@3`805Q8?00D05a<@01HB3`0D40d04Ph;01@@
3@02018>2`1701@@3@0E4@h04A0>00l?4@0?4QD03a4D01lP9@0E5AX04Q4F01DD6@0C41<0510?01H@
3`0G4Pd06AHA01<E500@51D03Q8B00lC500C5AH05aTG01LH5P0B4a40410=018A3P0D4`l04a8>01PG
5@0J6AL020L601@C4@0C4Q005aHD01HE4`0@3`d051<A01HE4`0E51804a8@01DE4`0I6AL05ADC014A
3`0D51805QHD01LG5@0L71X05aLE01TI5`0U9B<06ATG01DE4`0G5aD061PF01DE4`0F5Q@06QXH01TI
5`0H61H05QHD01DE4`0F5Q@061PF01XL6@0I6aP071hK02DW900B51407AlL01XL6@0I6aP00P0H6QL0
E`0I6aP071lM00hB4@0X;BT05Q/F028W8@0C6180724K01dR700G6aX08bLX014E600L7bH0>Sm3045:
B@0K92<0<3Th02Tb<@0=5QD08BXY06mhM`1IHV40:S<b01hW9P0I8R409Bd/020V9P0T:R/0:2l_02hg
=P0i@D80CEIF07=mO01PJVX0<Sdl02`h=P0Z=cL0@5=J0;;6cP2HZk80:Ca102@h>@0/?Sl0:chl02`o
?@0`@400<T5403=2A@0e@dT0=TQ<02m2A`0hBe80=4IA03A6DP0jC5X0>T]K03a=G00oDEl0@E=P041B
G@0nD5/0<D9A03Q9F@0nD5l0@59P03i@G@0nD5/0>4]B069eO014Eed0A5ML03iAE@12EEP0?U9D04QK
GP18Ff00AeYP04ePJ01@HV`0BUaW05AVL@1>H6X0CV1Y05IYL01@HfT0Ff]^05UYJ@0205IVIP0?05QX
J01IJFT0EFEU05a/K01NKVh0IGEe06]kN`1QLG40IgMg06QhN01[Ng/0KGem0720P01aPH40LX:200<0
Lh>300H0N8R807j>SP1nRXX0PXj>08NCT`2<UYL208jHVP0;09JMX`2LXjT0VZ6W09bPZ@2NXZ/0X:B]
0:JY/02^[[H0/K6i0;>c^`2h]kl00P2k^/830;fj``1<0<6ka@33_LL0a;k:0<W3c`3<a]80dLWH0=K;
f`3HcMd0gLoR0>7@iP3Td^P0imG[0>[Gk@3Ze^h0kMWd0??Ln03fgo/0n>7l0?SPnP3ggoP0n^;j0?cR
n`3lhoX0o>?i0?kUn`3oio`0oNOl0?kWo03niod0o^Sm0?oXo@3oj?h0onWn0?oXo@3mio`0n^Ci0?WR
m`3gh_D0m=o`0?;MkP3`fnd0k=S[0>WEj03SdN<0fl[H0=K5d@3Ca<`0cL330<Rj_P33^Kd0`;Vo0;bf
^`2e[k40[j^Y0;2/Z02TXi/0U9B808j?P029RgX0PhIb07UmJ@1oQG80M7]Y07MnKP1nQGD0Mgi^07R0
L@1eOG00MGea06miK`1JI5X0G6IM061/I01XLfd0IG1/065/J080H6aX01D0Gf]W05]ZI@1OKVT0E6=N
055RG01CI5h0HW=/0:NdZ`1BGeD0=44h03Q3>`0Y=2`0;STc03Ho>P0/=C00;SLd03a2@00b>3H0:S<b
02Pb<`0]>CX00P0[=cL0600b?Sd0=40n03<o?@0^>SL0;CTe02lk=`0c?c/0>4A003U4@00a?3P0<3/g
02Pc;`0Z=2l09RlZ02P`:`0U;2H072<L02P^9`0Z;bT0:2lX02La;00V<Bd08bhZ024Z9`807RLT00l0
7B<Q02D[:@0X;R`082@S01PL6`0O8b8061`K024U900L81l07b<R01/O7P0U:BP08bLV024U900R9RD0
0P0Q9B@03P0T:RP07RHS01hW900P:BL07R<U02<X:`0O92L07b<V01`M7`0K7A/092HQ028T7P0V:280
7AdJ0P0K6aT02@0M7A/07QhL01hN700J6QP071`J01PH5P0I6AL071`J01XJ600301PG4`0;01LF4P0F
5A405A@@01HE4@0H5a<06QTE01PG4`0F5A406APD02/Z9P0U92000P0F5A40100B4@d04a8>01@C3`0D
4`l301DD400401@C3`0C4Ph04a8>018A3@805QDA0P0C4Ph0:@0B4@d04A0<010?2`0A40`05QDA01PG
4`0C4Ph0;B`X09BCS`0j>CD05aHB01HE4@0@3`/020L4010?2`0A40`03``:01XF4`0B3``07a/H06aX
I@0/:2D04@h<010<2@0?2`P0=C4^018>2`0A3@/03PX7014=2P0C3``04Ph;01<?300B3P/05a<@02/W
900F4Pl04`l<014=2P0C3`/04`/800804``60P0B3@T02@0C3PX05Q8?00`:1`0A40h05aHD03ln?00>
3@`04Pd:014<2@0200l:1`P040/800L04Pd:01D@3@12?CX05A0>014=2P0?2PT03`X700804`h;0P0@
2`P00`0C3P/03PP801<=3@0200/51@0401<=3@0?2@T06Q@D014;2`8040X:00P03@L700h8200W8Ql0
3`X903Lb;`0P6aP040/8014<2@D03PT600@03`T601882@0B20T04PP90`0A20T02P0?2PX05@l?00h9
2@0C3`h02PH500h:2@0A2`/040X:00l92@0@2PX2014;2`0>00l92@0@2PX030H600h8200?2@T04PX:
01H<3@0C2@X04PP901061`0A1`P04PP901<92P0B20T201061`070147200B2@X040D901D:3P0B1`/0
5@X>00`11@0601462P0=01482P0<1`L04`d=00h82014?Sh05Q4A010;2`0<1PH0=c4a051:BP0H4Q80
3@L700h71`020147200A01882@0E2``05`d>01L=3P0I3a005@/<0147200B20T040H701882@0D2P/0
5P`=0147200>10D040H700l51P0@1PL00`0A1`P0100B20T04PP701881`0B20L200h51P0801892P0<
1PP03@L903@_<`2:QHT0:RDY00l9300@1`P201471P0:01881`0D2PT05@/:01P>3@0?1`H04@L600X0
000@1PD050X901881`@04@L600L040H500h40`0;0@404`T801471P0;0P405P`;01Cooooo000Koooo
o`0b018>3@0<20L03`/:01TE500K5aH040`;01HB4@0D40l03`/:01@@3`0<20L04`l>00X61@0?2`X0
4@d<018>3@0D40l04`l>00h:2@0A3@`03`/:018>3@0E4A004Ph=01DA3P0R7Q/0510=018>2`0H5140
2PH301dI5P0D40l04Ph=00`81`0L61L06QHE01@@3`0B3Pd01`<201dI600300003PX9010<2`0A3@`0
510?014=300>2PT05Q8A01@>3P0B30h5014;3@0>018<3P0C3@l050h?01D?4@0B3@d07ATH03`h=`0E
4A002`L601@@3`0H51<03@T801<?3P0G4a8201@@3`0>01<@2`0C40T04Ph=00d83P0D3aH061<J01@@
4@0B3`X04@h7018?2`0E4A805a8I01D@500B3Pd201<?3P0301DA400B3Pd03`/:00804`l>00T03`/:
00d9200A3@`05Q8?01PE400@3@P06QHC01HB3`0>2PL00P0B3Pd01`0B3Pl04`hB01@?4`0F4A@03PX9
01@@3`0>2PT00P0I5A@03@0A3@`0510?018>3@0@30/04Ph=01<?3P0B3Pd061@C01XF5@0@30/04Ph=
00L30P0K5aH00`0B3Pd301<?3P<0510=00H04Ph;010<2@0?2`P0510=01<?300B3P/201@@3@0S018>
2`0C4Q005A<C01HD5@071@P0QhF802<N8P0D3a<04`hA018>3@0E4A005a<?014@300;2`T04A<B01PJ
5`0D5QD04A4?01HG4P0H5a<04a8>018?2P0C40/05A8=01DA3P0G5Q@08R4O018A3`0g=S@05aHD00h=
2`0H5aD03Pd;014@3P0D4a400P0G5Q@04`0D51804Q8@01<C4@0D51804a<A01@D4P0E5A<06ATG014A
3`0E5A<092@R01LG5@0E5A<03@d;01HF500O7ad071`J01/K6@0J6QP00`0G5aD201HF500e01TK600D
5Q<06Q`I01TK600K7AX0:R`Y01lQ7P0L7Q/06Q`I01PJ5`0G6AH05aXH018F5@0Y;RX04aPC00@90`0G
71H04aPB02L/9P0J7Qd05ATJ01@H6`0J7B@06AhR01@M700I8R4072DT01XS8P0Q:RT06b@S01XS8P0O
:2L0:34`01`U900U;Rd08bX[02@Y;00X;C40728U02`d=P0nATT0;CHh03@n?`0b?3h0:C<e02Pd=00^
>cd093Ln04iRJ`14FEl0=TU?02Di>P0a@d@00P0`@d40:P0b@T40=49303A2@`0d@TD0=TQ<02i1A@0h
Be40=4I@03A6DP0jC5/0>daN03a=G@11DV40@eES049DH011Del0=dQH03m@H00nCel0>deK04EGI@0o
DE`0M8N>0:Bg_P1TMgd0B5]O03]>DP0lD540?U9A04QLG019G600BEaR04iQJ@1?HFd0DF=a04aNJP1H
JW@0EfUc04aOI`1GJW00FVU/05MWI`80Df=S00d0EfMW05YZJP1OKW40Gfia05i]L01RLG@0IWEh061_
LP1VMGP0J7Mj06]jO@1]O7l0L7n20080LX640P1dPhH01`1eQ8L0NXV<07n?S`21SHd0QI6A08ZFUP2?
VIX00P2@VY`03@2CVZ00V9nU09ZQY`2LX:T0XJF^0:JZ/`2VZJl0[Jjc0;2a]P2b/kP0][Fk0;Rg_@2i
^;h00P2h]K`05P2l^L00`Kc30<>ma`33`</0b/C@0<c6dP3?amH0e<WI0=K;f`3JcMl0g/oT0>3AiP3U
dnT0i]CZ0>OEk@3/f?<0lMgi0?CPo03hhOd0mmoi0?KMn03ggOP30?_On00?0?cPn@3mh_/0nn?k0?cR
n`3lho/0nn?k0?_QnP3lho/0o>Cl0?gSo03jhOX0m]kf0?KLm@3af^l0jmWY0080j]OZ01D0imKX0>CC
i@3Lc]h0cl??0<^ob@3=`/L0aKbm0<6i]`30^[T0^[Je0;B`[`2a[JX0[JZU0:BSWP2HV8l0TI>608f@
P022QG@0OH5`07n3LP24RgT00P1dNf/0A@1lQ7D0M7a]07=kK021S7`0O8Mg06mjK01FHU@0FFEG05EQ
E01KIV00GfYV06=_J`1RKVX0GVYV05QWHP1GIV40H6mZ05UZI01BHed0B5UC04AECP1HIE`0>DHl03E2
>@0b?CD0@di603i9@`0f?cX0<CXe02Tb;`0]<c40<SPf02`e=00/=SL0;c/l02`h>00[=cL0=40o03U5
@`0nBTP0<cll02Xf<P0W<bl0;3Pd03i:AP1JIV809S<_02Hb;P0X=3009C4/02/f<00T;bT08b`V01lY
8@0Y<b/09RhV02@^9P0Y=2h09C4]028]:@0P:bL07bTV01hW900Q9bD082DT02<W9P0S9B@07AlN01`N
7@0201@H5`0G01PL6`0U:BP06alN01lS8P0Q9B@082@S028V9@0Q9B@09BTX02/a;`0P9bD04Q/J00PA
4013B4/04aPK02T^<@0O8bD08R<U01HH5@0R91h0;c8[024T7@0L7AT00P0M7A/01P0O7ad08R8P02<S
8@0J6QP06a/I01LG5@806ATG00H05ADC01TH500J6AD06QTE01PG4`0G5Q8201PG4`0;01HE4@0E5100
5QDA01PG4`0I61@08b8N01/J5P0B4@d07A`H01PG4`0C4Ph01@0D4`l301<B3P0a018A3@0F5A405QDA
018A3@0D4`l05A@@01<B3P0B4@d05A@@01PG4`0A40`02`X605ACC`3hmo<0Cdi:010?2`0C4Ph04Q4=
01<B3P0O7QX03@`800l;20060P003`/900l;200L61D05Q8?01hJ5`0J5Q<04Ph;08R4P@1NFUL05Q8?
014=2P0?2`P04@d:01DA3P0B3P/02`L4014=2P0T81d040`900h:1`0@30T05Q8>01491P0A2P@04P/5
014<2002018=2@0600l;200C4@h030/900/:200;2PT02@P60P0>2@H300l:1`0300h91P0@2`P040/8
00@040/80P0B3@X01@04000040/801<>2`0H4a003PT6008040/80P0?2PL04P0@2`P0208201<=3@0?
2@T03PP8018<300>20P0618B01XD500K5AD03`T900/51@0@2PX03`/900T40@1QG5T0?CPe01HA3PH0
3PT600<040P601<82@0B20T00P0B20T201482@0:00l92@0G4a802`L600l=2`061@<04Ph=00l92@0>
20P03@L700h820803`T900H03PP800l92@0<1PH03`T9018<300B2P/201<92P0301882@0C2@X04`T:
008050X;00/04`T:01882@0B20T04@L801P=4007000060dA00h31`0G31003`@801H;3`0501462P0=
01<:300C3@d07QPH01dG5`090`<04`d=018<300M5aL04P`<010;2`0D3Ph04P`<01@<3@0201472007
01882@0E2``060h?01<92P0F30d04`T:01061`0201<92P0500l51P0@1PL04PP90147200@1PL00P0A
1`P02`0B20T04`T:01<92P0B20T04@L801061`0A1`P04PP900l61`0>1@H04@P;008050h@00L02`L:
05IAE`0M61h030L<01892P0B20L04@L600803`D400/040H501T?3P0F30/060h=01471P0?1PD04PP7
00l5100@1PD04@L601881`0201<9200301061@0B20L040H500803@<200<03P@3ooooooooool04_oo
ool001_ooooo00H02@D4018>3@0A3@`03@T800h:2@0?2`X201<?3P0[00X61@0?2`X03PX901<?3P0@
30/05A4@018>3@0A3@`0510?01<?3P0>2PT040`;00l;2P0D40l05Q8A018>2`081@804@h7010=1P0C
40X06QLB00l;200C3``040`;01TE500H51<06ADD01LC4P0@30/05a<B014=30060P805A4@01LC4P0A
3@`04`l>014=300@30/02`L6014=300D3Ph04P`<014;2`03010:300b018<3P0C3@l050h>01D?3`0D
3Ph04`h=01DA400V8R404Ph=01@@3`0A3@`04Ph=00T5100@30/03`/:01<?3P0<20L04Pl8014?0`0C
40/050lA01HA5`0C3Q804@d;018?200B3`H04a0901DA400F4AD061@F00X61@0@30/03PX900X61@0E
4A004@d<01<?3P0B3Pd040`;00l;2P0A3@`04Ph:00d:1@0D4@`06aLD01HB3`0K5a@04`l>018>3@0B
3Pl2018=4@0?01@?4`0E4A806QHE01@@3`0G4a801P81018>3@0C3`h04@d<010<2`0A3@`04`l>018>
3@0D40l05A4@00<06QHE00P05a<B01TE500I5A@05a<B01DA400C3`h04Ph=01HB3`805A4>00H04`l<
018>2`0A3@X05A4>01<?300B3P/201@@3@0P014=2P0U8Qd01000028N7@0=1`L0;b//00<00P0G4QH0
510B010<2`0B3Pd05A8>00d<200=3@/04A<@00l?3@0=3@/0410<00l>2P0F5A404a4<018?2P0D4@`0
5A8=01@A300J6AD04a8@024P7P1:BDL04Q4?01LF500P7ad301@C4@805QDC00P04a<A01@D4P0I6AL0
5QHD00d=2`0<30X051@B01HF50804Q8@00T07QhL01DE4`0D51804Q8@010@3P0E5A<0@D4o06EUH`0I
6AL00P0G5aD01P0I6AL05aLE01HF500F61D07AlL024S80806Q`I00@07R0M01dO700J71T061XG0P0F
61D07`0E61H051PG010E4@0V:bH07B8L020U7`0N8ad051TC01PL6`0V:R/04QHI024T:`0M8RD04a`K
01LP7`0E7Qd072DT01lX9`0@6AP05b0O02D^;@0H8B003QLF030i>00Q:2/07B8V01hS9`0T:Rh0@DU<
04Q@D`0]=ST00P0^>3X02@0Y<cD09C0b02`h?00Y>dD0;D5<02PlA00eB4h093Pi02`n?`020395@`0i
03A4@`0e@d@0=D=403E3AP0gBDd0<4=703U<D`0eAe40=DMC03]<G010DF<0@E9T04AEI@13E6@0@E=Q
03i@GP12Df<0?DiP03Q9F@14EV@0E6Id049DG`0lCUP0HGAk04MJG`11E5P0@5=G04IJFP0mDDl0A5QG
04QLG@1=H6H0E6I_055SK`1IJgT0DfEb06eoR`1ZO8H0Cf5Z05QYL01GIVT0E6AT059RHP1CHf<0F6QX
05][J`1QL7<0GFa_05i]L01SLWD0J7Mj06MfN@1XMgX0JWUl06akOP1^OH00L7n20080LH2301/0M8>6
07J5R01gQXT0NhZ=07n?S`21S8h0Q92@08NCT`2<UYL0SYRJ08nIV`2@Uid0UYfS09^RZ02LX:T0Wj>/
0:FZ/02WZ[00[Jjc0:n`]@2`/KH0/k:h0;Fd^P2g][`0][>j0;Nd^`2l^L000P31_<<04`34`L`0b/C@
0<c6dP3?amH0dlSH0=C9f@3Ic=h0gLkS0=o@i@3Td^P0iM?Y0>KDk03Xe?00k=Sd0>oKm`3cg?P0lm_e
0??Jm@3fg?L00`3igOH00`3lg_P0o>3i0?[Pn@020?[Pn@80nMoh0`3jh?T0>@3ggOH0m=[c0?;Hl@3]
e^/0i]CT0>GBi@3TdnD0h=;S0=g?h03EbML0bKo80<RnaP3:`LD0_KRe0;bg]02n^[H0][:_0;2/Z@2]
ZZD0Z:FN09^KT`2DUH`0RXb107eoLP1oPg@0Oh=b07=gIP27SWh0O8=c07V0L01nQWL0NX9c07V1LP1Y
M6@0K7MW071kJ`1KJ5L0F6EC05UUE@1FHET0GFQT06A`K01QKFT0GFUU05QWHP1PKfX0Hg9]05EVH01<
GEL0@U==03Y;A00gAcd0=D8h041=A00c?SH0=D0h034l=P0202lh<`0N02df<`0`=S@0;S@b02H_;P0_
>CX0:SHg030l?00c?cl0<Cdl034m>`1JIV@0=d=002/g<`0b?SX0<clk034m>@1PKfX0:cXe02Xi=00^
>SH0:SHa02/h<@0V<B/09C0Y02@^9P0Z=2`08B/R028]9@0W=2d08bhZ0P0O:RH09P0O:BH07RLT02<Y
9`0N8b408BDT02@V9@0N81l06adL02@X9`0D61L05ATH02DY:00P92<09b/Z024U900R9RD092PW02<W
9P0X;2/0;cDc01`S8@0b>cX0EEiM0;>h^`0Z;c803Q<F01<G6@0O8B00:bdZ01/M5`0D5`h04QD>01hN
6`0N7Q`07AdK01XJ600K6aT07AdK0P0K6aT0100H61H06QXH01PH5P0C4a4301XI5@0?01TH500H5a<0
6APD01PG4`0F5A4051<?01HE4@0H5a<05A@@01LF4P0@3`/03`h:01XI5@0D4`l04a8>00<051<?1@0C
4Ph01@0B4@d05QDA01HE4@0@3`/04Q4=00805A@@00P05QDA01XI5@0O7QX08B0L01XI5@0F5A40Cdi:
02<R7P805QDA0P0A40`0400I61@030/7010<2@050@0071PE01DA3P0300003PX700P40@0300005A4>
02@P7@0<20D040`901@@3@0A3@X2010<2@803PX700L01@4001HB3`0>2PL04`l<00`81@0>2`L04PX7
00804P/50`0A30P01P0T81d06aTF0040000U92801`H401hM6`803PT600@03`X7010;200A30T04@`9
1P0@2`P01P0400005a8?00@0000A30T03@P501D@3@H03PT6018030H600h8200<1PH02P@400h8200E
3`l03PP801H@400J51@03PP800`61P0D3Ph04`h;01D@3@0P6aP0>3<`01@?300?2PL500h91P030108
1P0C20T04PP900804PP90P0A20T01`0=1`L0100000<0000A40h02@P600D40P0?2@T00`0=1`L0200>
20P03`T900`61P0>20P03@L701@>3P0K5AD05@d=0P0?1@H20147200401882@0D2P/050X;01<92P80
50X;00P04PP901@93007000060dA01462P0I3Q803`@801@93@D04@H:01<02`@500@0000;1@D03PT9
00@0000M5aL02P@400d71`0:10@02@<300H0000400003@D601061`0A1`P04PP901@:2`0F30d03`D6
00804PP900D04@L801@:2`0C2@X03P@500l51P04014720806Q0A00L06@l@01H<3@0C2@X03`D60106
1`0A1`P04PP900803`H700X04@P;01D?4@0K5AL05A0D01hI7`0300@02`D:01<:2`0C2@P04@L60`0>
10<04P0800005P`;00l5100D2PT040H501@:2@0=0`803`D401061@0A1`H04`T801@:2@0>10<04PP7
00X0000;0@004@L600L001Cooooo000Kooooo`0E01`H5`0M6AP04Ph=00d9200A3@`03`/:00h:2@0G
4a802@D400l;2P0D40l04@d<01HB4@0J5QD04Ph=00h:2@0C3`h0510?018>3@0C3`h03`/:0080510?
01003`/801HC2`0:1`0071T@010=1`091P803P/6010<2@0?2`X03`/;018>3@0M6AX03PX;010<2`0E
4A004Ph=0P0D40l01`0>2PT04`l>01@@3`0A3@`081`K01@@3`0<20L00P0A30T0<`0@2`P04P`<018<
300C3@d05@l?018<300A2`/04`h<01HA3P0F4Q0040`;018>3@0A3@`061@C00X61@0D40l04Ph=01XF
5@0>2PT06aLF00`81`0E4`X04Q0201@A200E4@h03PX:00l;2@0C40/04@l401<A1@0E4`P0514<01@@
3P0D410020@301PD4`0S7ah03PX901<?3P0D40l04Ph=010<2`0B3Pd04`l>010<2`0C3``02PL301DB
3@0<20H03``801<?300201<?3P0>018>3`0A30l04@`@014<4@0B3Pl05A4@014=300:1PD0=S8a03Lc
<P0A3@`040`;00l;2P0A3@`201@@3`0601TE500=2@P05a<B01LC4P0c;bh05A4@0P0B3Pd301<?3P05
01@@3`0E4Pl0518>01<A3@0B3``00P0C3``06`0F4Pl04`l<018>2`0D40h04`l=014=2@0A2`H07AHA
00l:200L51805Q0@01H@4@0_:B/091hP018>3@0B3P`06ADA01<A300C4`l03`l;018A3@0F5A405Q<@
01<@2`0D4@d04a0;01@@2`0201LB3@0]01D@2`0J5Q@05QDC01LF500T8R007adL01HE4`0I5aD04Pl>
01@C4@0F51805A<A01@C4@0B4Q004a<A01HF500G5aD092@R03<c<@0I6AL061PF01XJ600E5A<06ATG
01HF500E5A<04a<A01HF500D5180:BTW0451?`0H61H05QHD01LG5@0K6aT06QXH01HG5@0E5a@08R@Q
01XL6@0G6AH07AlL01HH5@0J71T06A/H00806Q`I01d06adJ01hR7`12AT@082DQ01XO6P0C61806QlI
01/P6`0G71L0720O04Y>D00R9RT05QTO01LK7`0T;2/07bHV01`T8`0N9bD06B8P01lX9P0P:BL05b0N
028[:P0L9B@092d/01hU:00Q9R/092T^02H/<@0203<j@01602H^<`0U;S<0:c@j02/f>`0Y=3T0:SHl
02Dg@00P=3l0:Ca302m1AP0X>cd0=4I60353@@0c@d80=4A403I5A`0hATP0>DI;03]=DP0dB4`0?E1H
03Y<E`0iBeP0@55P041AHP11DV<0A5EV04EFIP13E6<0@59P03a=G@0oD640AUMW049DHP17FFH0@59M
041BG00oDUT0@UEJ04=FFP13EeT0AEUJ04EIF@17Fe/0BUiP059UJ`1GJG80CV1[05AVLP1BI700Gg5k
05e`N01AI6/0FF]^05EUI@1EHf<0EVAT05QVI`1LJV/0Gfe^06AbM@1QKg80I79e06UgNP1/NWd0JgUl
06YiO01/Ngh0KGao06imP080L7n203T0Kgj107F4Q`1jR8/0NhV<07f;SP1nSHh0PHb>08:>S`24Si00
RI>D08fGV@2>V9/0UYfS09bSZ@2RZJl0Wj>/09fQZP2SZ:h0YjZ`0:f^/`2^[k@0[Jjc0:n^]02`[kD0
];>i0;Ba^02f/kX0_[_20<2la02o^l<0a<7=0<S5d@3:am<0cLOE0=38e`3BbMP0f<cM0=_=h@3Ncn<0
h];V0>?Ci`3UdnX0i]?]0>SDk`3Ze_00k]Sb0?3Hl`3afO@0lm[e0?OKm`3gfoH0n=_d0?WLmP3kgoT0
n=oj0?SNn@3gg_T00P3fgOP20?ONn0220?KMm`3cf_@0l=O`0>gDk@3XdnL0hM3P0=o>g`3Lc=d0e/SH
0<o2dP39_//0`kW20<Bk``33_L00];2^0;Jb[`2i][40[jjW0:bYX`2RXIX0UYN?092AQ`2;SH80PXEj
07]oLP1nPGD0Nh1c071dIP1aMfT0L7IX06meI`1bNV/0N81a07R3LP23SWd0KGQW069_G@1LJEL0FFIC
05=QC`1GI5`0G6UU065^JP1LJFD0FFIR05a[IP1KJVD0FFQR04QHDP15Ee00@E=<03a>AP0jBT00>DHl
03Y7?`0lAd00<chg03E0>`0kAD00=T0k038k>@0^=S@0:S4`02/c=01IHf@0<cm0030l?00e@D40;3Pg
030l>P1DH5h0=D4n038n>P0jAT80=D4m034m>@0^?CP0<d<n03E5?`0^?CP0<D0j02<a:P0Q;RL0934Y
02@_:00X<b`09C0X03<n=P0X=2h08bhZ01l[9`0R;2T09Bh[02@[:P0N92<07R<R024U900P8R406Q`K
01hP7P0_<c407B8O01XN700N8b0051PG01hR8@0O8b808BDT02<W9P0O8b808BDT02T^;@0L8b807RDU
020W9`15Bd`08BHX02DZ;00K7b0071hL02@V8`0L7QP08bHM01/N5P0K71P07AdK01XJ600H61H06ATG
01`L6P806a/I00@06ATG01dM6`0J6QP051@B0`0I61@0100H5a<05aHB01LF4P0H5a<301LF4P0801PG
4`0E510061LC01DD400G5Q804a8>00h=2@0E510201@C3`0401<B3P0B4@d04Q4=018A3@804a8>00h0
4Q4=01HE4@0F5A404A0<01DD400I61@05QDA018A3@0C4Ph051<?01<B3P0?3PX051<?01HE4@8051<?
0P0H5a<01`0D4`l030/6010?2`0E4@h03PX701dI5P0C3``00P0D40d01@0D4@l061@A014=2P0@30X0
3`/800804@d:00`04Ph;01<?300>2PL04Ph;034]:P0@30T05a<@010<2@0H51402@D2018?2`0C30T2
01<<1P<040/700`04`l<00l;2@0G5Q<08QlN010>300=2`T04`h;018=2P0A30T040/8018=2P0C3P/6
010;2006018=2P0@2`T07QTF00X5100D3``05A0=0P0@2`P0100?2PL040/8014<2@0?2PL200l92@04
01/E5@0H4Q803PP801TC4`804P`<00X04`d=00h8200>20P050h>010;2@0E3P`03`X901@>300?20H0
40/80P0?2@H0100>2@H03`T600l91P0@20H301<82@0?01882@0A20T04@P9014;2`0@30/05A4@00T7
1P0D4Q006AHE014;2`0@2@T03`T901092@0A2@X04@/;00803`P800D02`D5014:2P0F3`l04`X;0147
200501882@0:0147200@1PL04`T:01@:2`0B20T040D801D:3P0F2`l04PL;01H;3`L04@H:00l0718D
00d8200I4Q8030H601<=3@0<1PH04``<01H@400@20T040X:018<300<1@D040L801061`0B20T00P0C
2@X0200B20T0308301061`0B20T04@L801<92P0@1PL04PP9100A1`P00`0>10D04`T:01@:2`0201H<
3@0@01@:2`0A1`P03`D60147200C2@X040L:00l62@0A20/040T<00P31@0C3A40100403`g?00P6al0
4PT:01881`804@L60P0B20L01P0@20L0:b4P00T0000I3`h03PD401471P<03`D40`0@1PD301471P03
01881`0C2@P04@L601Cooooo000Kooooo`0401D?3`0D3Ph04P`<014;2`8040X:00@06A<C014;2`0D
3Ph03@L70P0?2@T0700@2PX04@/;00T30`0@2PX04@/;01XD500A2`/040X:00l92@0A2`/04`d=01@>
3P0W8b0040`901DA3P0B3P/04`l<014=2P0>2PP04`l>010<2`0?2`X02PH501HB4@0;1`H04@d<01<?
3P0B3Pd2014=300401<?3P0A3@`04@d<00l;2P803@T800@03PX901@@3`0E4A004@d<0P0=2@P01P0B
3Pd04`l>01@@3`0D40l04Ph=014=30<040`;00<04@d<01<?3P0C3`h00P0C3`h01`0B3Pd040`;00l;
2P0@30P04@h9014=2P0A3@/00P0A3@`0300G4a0040`900d:1@0Y9R800`0001<?3P0J5aL03@/<00`:
2`0Q7b003`d>00H41@804@l@0P0;2@X01@0>30d030X;018@3P0@30T04@d:00804`l>010040`;01@@
3`0@30/03@T8010<2`0B3Pl04@d>00P71@0I61H030/:01/J600;2PP07A`J01@C4@0B4@l04A0>0P0C
4Q00100?3P`04`l>01TE500J5QD201DA400P01@@3`0@30/04Ph=01DA400D40l04Ph=018?3P0@4@`0
2`h701TJ5@0;30L03@`9018A3`0B3Pd04Pd<018<300B30h050h?01L>3`0=1@<05`l<01P@3P0E3@/0
:20N04Dm>`0J4A806Q4A01TD4@0H40h0FeEB024L6@0D4`h301<B3P0Q01DD400F5A40;bh/02HU8`0K
6QP06aLF01<?3P0E4A008alP00l:300E4A806A<E01TD5@0G4a@04@`=01H@4P0T82404Pd>01`F600B
3Pl04A0A01PH600J6QX051@D07IfMP3Jf]X071`L00/;2`0E5AD04a<C01DE5@0F5QH05aHD008061LE
04X05aHD01TI5`0K6aT061PF01<E4P0G6AH06A/H01LI5P0I6aP05aTD014C3P0K7AP06A/F01lQ700K
7AP05ALB01`N6@0M7aX06A/F01LI500G6QD061dG01TN600J7aX06b0L01`Q7@0L81h06alN01dQ8P0O
8bD07R8U01dP9@0K7b<08BDX02@X:@0_=3@0IfeY02D[9`0M8al08RPT01dV8@0J8b408BXY028Z;00O
:2P08BXY024Y:`0S:bd09Rha02L`=@0S;380:c@k02dg@00/=T00:SM002Da?00T<CT08Rlg02/h?P0a
@4<0;Shn0310@00dA4@0;Cdm0350A00a@4L0>dYA03Y:DP1BIVl0@eUT03U?FP0nDEl0?e9P041CH@80
@eIT00/0?e1O03i@GP14EV@0@U9Q04AFI00nD5h0?U1M04=EH@10DUh0@eEP04EGH@0204EHG`0C04=F
G014Eed0CF1V059SK@1AHV`0C5eW04UJI01HJG40CUmV04IGGP19Feh0@eEE055THP1HJfP0E6MS04mO
GP1CHf<0EfMW05YZJP0205][J`80I7Ad0P1UMGD206IfMP080720P01/O7`0KWin06moO`1`Oh00MXB5
07F3Q01jQhP207n:S00K086<SP24Si40QI2D08:=T@2BWJ40UIjS08jGW02AVZ40V9nW09jU[@2W[[H0
Yj^d09nS[02PYJ/0YJZ^0:b`/`2]/K@0ZZfb0:f]]@2_[kL0/;2h0;:a^@2e];`0/k:k0;Fc_P2l^L@0
`ko>0080a/;A0280bL;B0<g7e@3?amH0e<[J0=O<g03FbMX0g]7R0>;EiP3Md>40g<kO0>CCiP3Ue>L0
jMOZ0>cIk@3]f>d0kmW`0>oGk`3^e^h0kmO_0?3Hl03bf_80lmgd0?GMm@3dgOH0l]_e0?7JmP3ag?L0
l=cg0>kJl`3[f?00imKY0>?Bi@3Qd>00elWF0P3A`m005`3:_/X0ak_50<Bi`P37_LD0][2d0;bf^@2i
/kD0/Zb/0:j/YP2b]:T0ZZZP08R:O`2:SH80SI2508J9O`1cNFl0L7M]07b2N01]MFX0OhIk08F=P021
RGX0N81a0080LGU/0P1dOg408P1XLfD0GFUM05]WF`1FHUH0CU]@05IWH@1FIV<0G6aY05a]I`1GIV40
EFAM05QWH01BHUP0CUiD04QHCP0oCdD0?De2045>A`0gA3d0>TI103I2?P0d@3`0>4A202lk>`0oBd/0
<S`n02Tb=`0b>d0092h`03Y6AP0b?S`0<3`j03]7A@0/>3H203<o?@04038n?00[=cD0:cLe02`h=P80
9C4]03T0;C/d038o>00_?3D0:SHa02Xe<@0h@cl08bdY02lh=@0Z<c00:S8_05mUH@0k@S/08bPS02P/
:`0n@T406alQ038f>@0Z;S40:b`_03@f=@0J71/08B<O01PJ5@0K81X0724K01hS7@0Q9R008bPT02@Y
9@0O9200:BhZ01hS7`0W:bX0;S8a02@X9`0U:BL09BTX02<W9P0P92<08R@S02@V9@0N81h05aTF01`N
6`0L7QX061XE01TK5P0J6QP05aLE01PH5P0K6aT06ATG01LG5@0M7A/06a/I01TI5`0H61H00P0F5Q@2
01HE4`0A01@C4@0C4Q008R4O02HU8`0E51805QDC01LF500E51806aXH02h[:P0@30/081`K01DA400I
5A@05Q8A01@@3`0G4a800P0F4Q40100G4a806ADD01PD4P0D40d201<?300J01DA3P0H51405Q8?01DA
3P0G4a005Q8?01<?300B3P/0510>01<?3P0I5A@040`;01PD4`0E4@h04a0;018?2P0C40/0514<01DB
2`0C40/09b8O01PC400B3@X04`h;00d81@0C3P/3014<2@08010;200?2PL03PT600T50P070`004a0>
01DA3P0@30T2018>2`0700h:1`0A3@X05A4>014=2P0@30T03`X6010;1`02014<200;018=2@0C3PX0
3`X6014<200B3`X06A@A010<200E40`04`h:018=2@0A30P00P0?2PH01@0=20@030L3010;1`0A30P0
40/700803PT500l04Ph;00X60`0:1P<03`/8014=2P0<20D06QHC00`81@0B3P/0510=00`81@081040
5A0=018=2P0@2`P00P0A30T0500?2PL05Q4>00T40P0=20D040/8014<2@0I51404`/901@:2@0D30X0
50/:01@:2@0B2PP03@@301061@0@20H04PT801<9200B2PP03@@50P0B2@X01`0A2@X030H600P20P0<
1PH03@L700h8200>2@T00P0@2PX01P0Y82404PP900H0000P5QL09adN00L000804PP90P0@1`P01@0@
1PL04@L901H;3`0E2Ph040D900804`P<00<03`@801052@0A1PX00P0B1`/0700@1@T03@8601052@0I
3Q803`D800l4200H3A4040D901dB5P0A1PX04@P:01@93@0700004@H900/20`0@1PL04@P900X10P0<
0P<04@L801482@0C2@X040H700h51P0D2P/05P`=01<92P0A1`P301061`804@L80P0@1PL00`0A1`P0
4PP901881`0201881`0301471P0@1PD040H500H04@L602@03P@500l51P0A1`P04PP901<92P0D2P/0
3P@501@;300?1PT04@P;05]BE@0j<C<03@<400h41@0@1PL03`D60147200D2P/0DDM801lE5P0e:b`0
2`4200`4100?1@H03`D401@:2@0@1PD03`D401881`0@1PD03`D400T1000E2`X01`0001881`0<0P4D
ooooo`006oooool02@0E3`l050h>018<300A2`/040X:014;2`0=1`L050h>01H@400201PB4P0701D?
3`0=1`L04P`<01LA4@0R71`0618B00h82002018<3007014;2`0B30`050h>01D?3`0X92<05A4@01TE
5002014=300800l;2P0>2PT04`l>00d9200A3@`02`L6010<2`0>2PT2014=3004010<2`0?2`X040`;
00T510804@d<0`0?2`X0200B3Pd040`;014=300C3`h04@d<00h:2@0?2`X04@d<0P0B3Pd00`0?2`X0
40`;010<2`02010<2`03014=300B3Pd04`l>00804`l>00@04Ph=010<2`0?2`X040`;1@0A3@`03P0<
20L03`/:02@P7`1;AdH06aLF01<?3P0;20P03@/<01hL7@0B41402`T:01/I6P0=2``0518C0P0C4A80
0`0G5AH03@/<00d:2P02014=30804`l>00`040`;01@@3`0A3@`03`/:014=300C3`h04Ph=01/J600C
4Q004Q4?00D40P0A40h201<B4009014@3P0@3`d04Q4?018A3`0?3P`03`/:01DA400G4a804`l>0080
510?00h04Ph=01@@3`0E4A004Ph=010<2`0@3@/03@l:00`A2P0;3@P04Q<>01DE4@0?3P`04`l>01<>
3`804`d?00l05PhA01L>3`0I41406Q8@01D=2`0B2PP0610>02@L6P0A2@L05Ph<01/C4@0;0`40:b<Q
00/60`0E4Pd00`0B4@d07P0D4a005A@B01LF500J61P040h?01DC500B41405Q@E01<?400G4A<050h@
01LA4`0P6Q`030H801@>400f<380AT1201lI6`0L5QP05Q8C014@400G5aL06QXJ01HF5P0d=3@0EUIF
01TI6@0C4a<06ATI01<C4`805QHF00P06ADD01TH5P0H5aD05aHD01LG5@0H61H05aLE01DG50806Q`I
014051TE01HK5`0J71L061XE01DG4P0G6A@07AlJ01PJ5@0M7aX08B<N028T7`0N81/07AlJ01/N6@0I
7QL06AhH01XO6P0201/P701Z01`P7`0L82407B4R01hR900N8RD07R4V02d_=00J6al051PI024U900X
;BT00`X302@[900Q:2407RLR01`U8P0R:bX08RX/01lX:00Q:RL08R/Z02@/;@0V;S009c0e02Tb>00U
;SD09S0j02Td?`0U<Cd0;SY7030j@`0]>3h0<3/o03=1@P0b@440>4I603M7A`0b@T80=dI;02m0B00f
Adl0=DMA04QNJ`10EV<0?59O041FH`0nE640?U5O049EH`0oDV00AEMU049DHP17EfH0Be]Z049DH00m
Ce/0@59N04QJIP19FfL0CV1Z055SK@10DU`0?U5H04=FG@0oDUT0CV5X06EeQ01AHG00G6ai04iOJ@1;
G6@0C5iR04mQI@1HJVX0Cf9N059UH@1?He/0CV5K051PG`1CHf<0EfMW05UYJ@1LK6`0GFe]06=cL`1T
M7@0IGEe06IfMP1WMgL0J7Qh06alO01YNGT0KGem06inOP1^OGh0Lh6207J1P`1kQXP0OXV;07n9R`21
Rhd0Q8j@08JAU`28TiT0W:N]09jW[P80TY^R00L0V9nW09ZQZ@2PYjl0XJF^09jRZ`2QYZ`0YZ^^0080
ZJf`00D0Z:^`0:^[/`2/[;@0[Zjf0;6_^P020;Jd_`060;Rf`@2m^lP0`Kg=0<K2d@37`m80b/?C0P3;
aM<02@3AbMP0elcJ0=C9e`3Gc=X0fLkL0=G:f03Mcmh0j]c[0>WKjP020>SGj@030>WGjP3[f>`0kMO^
00<0kMO^07P0k]S^0>oIkP3_fO00kmWa0>kJl`3^f_D0k]_f0>_Il@3Yenl0i]GZ0>;Di@3Nd>40g<kK
0=C7d@3>`L/0cL3:0<Fj`P32]kl0_kJk0<6h_@2c[K40]k6c0;6[[@2YXjD0YZBN0:RZW@2TYYT0Rhj2
08J9OP21Qg/0M7Y_06meJ`1gOg@0N7mg075hL01cNg40OXIi07R0L@1bNV/0Lg]^07InL@1dOg40K7I[
06I`I@1QKF<0Gf]Q05aXGP1MJf40FVYW05EXIP1HJfL0FV]U05IWH@1JJF80CemE04UIC`18ED/0@e16
03Y7?@0gA3T0:CH_03<o>`0mBDD09S8`02/g=@0`?3`0>4=503I1@`0b?D4082/a03a7C@0g@TH0@dm?
03]7A@0/>3H0:cLe03E1?`0/>3H0<Cdk030l>P0[=cD0;3Pf02hj>00W<bl08BdY02Db:`0[>340;STc
02/f<@0W<Rh0<CXg02Pa;`0Y<S409bd]02<Y:@0a=cD0:R`W034c;`0K7AX0:2T[024R9@0720d08b@Y
01dN8@0U9bH07AlN02HX900M81T06b0I020U7P0S:24092TS02<X8P0R9b408BHR020U8@0B5a<05QXI
02L[:P0T:2L2020R7`0601lQ7P0N81d0828O028T8@0N81d061XG0P0K7AX0300L7Q/0828O01/K6@0H
61H06ATG01`L6P0K6aT06ATG01dM6`0J6QP06ATG01LG5@805QHD00L061LE01HE4`0G5Q@05A@B01`K
6@0Q81h05aHD00804a8@00X05QDC020O7@1^K6X0<Bd/00<0000F4Q406QHE010<2`0I5A@05a<B0P0F
4Q401@0H51<06ADD01HB400B3P/04`l<0080510=0P0C3``201@@3@09018>2`0A3@X04Ph;01@@3P09
1@@03PX901<?3P0Q7A`0>CDb00803``700@04@h901<@2@0D4@X0514:0P0A30T0100@2`P04`h;01LB
3`0E40d200l:1`804Pd:0P0C3P/0300I5A8030P500l;200C3``05A4>010<2@0D40d04@d:01<?300G
4a00510=018>2`8040/70`0A30P01`0B3@T050l;01<>2P0B3@T03`X600d8100910000P0C3PX2014<
2005010;1`0?2PH03@P4010;1`0A30P00P0?2PH03P0@2`L030P500d91P0?2`P040`9014=2P0?2`P0
0`0002PT8@0e<Bh07ATF01@@3P0C3``03PT60P0=20D02@0>2@H03`X700l:1`09104040/801HA3P0>
2@H02@@100h91P0201@:2@805@/:00<050X901<9200A1`H00`0B20L0200A1`H03`L501H>3`0A2`/0
3PP8010:2P0E3`l05Q0@1P0>20P01P0A1`P03P@501L=3P0S6AX0DTQ901lE5P804PP90P0A1`P01@0@
1PL04@H901D:3P0E2Ph04@H:00805@X>0P0B1`/01`0C20`050T=01@93@0D2@d05``@01D:3P0F2`l0
0P0C20`03`0D2@d0304501<8300A1PX05P/?00L0000:00<0=2X/01D;300C2@X05@/<01061`0>10D0
40H70147200201<92P050147200B20T04`T:01882@0A1`P00P0@1PL0100A1`P04PP901882@0A1`P2
01061`050147200B20L04PP701881`0A1`H00P0@1PD601471P803`D601`040H70147200B20T04PP9
01D;300B20T030<300/10P0M4a@05@/<00h41@0@1PL04@L801061`0B20T05@/<0;F[[00e:b`060h?
01D;300K4A801`0000h40`0A1`H03P@300l5100B20L03`D40P0C2@P0100F30/03P@301061@0I3`hD
ooooo`006oooool00`0E3`l050h>018<3003014;2`0600`61P0D3Ph030H601XD500=1`L05@l?0P0A
2`/0100E3`l09AlO01/E5@0:10@201<=3@08018<300C3@d050h>01@>3P0A3@`03PX901DA400@30/2
01DA4006018>3@0M6AP04@d<01HB4@0B3Pd03`/:0P0B3Pd05`0@30/03PX9014=300B3Pd0510?01TE
500B3Pd040`;018>3@0@30/05A4@00d9200>2PT05A4@01@@3`0A3@`04Ph=01HB4@0H51<05a<B01<?
3P0B3Pd04@d<008040`;00<04@d<018>3@0C3`h00`0B3Pd00`0A3@`040`;010<2`05014=300J018>
3@0?2`X04@d<01PD4`0;1`H0510?010=3@0>30d0518C018@4@0;2@X03`d>014?400E4a@03@/<014?
400F51D03P`=010=3@0A3@`04Ph=01<?3P0D40l04@d<01@@3`0C3`h2018>3@0301@@3`0C3`h040l=
008051<A00<04Q4?010?3@0@3`h00`0@3`d01`0A40h040l=00h=2`0=2@P04Ph=01<?3P0A3@`00P0D
40l201HB4@0A01@@3`0A3@`040`;018?3@0>3`X0;c8[00h@300B4`h03@d9010?3@0D40l04`l?014=
3P0B30h04`d?01<=3@0F3@h00P0C2`T01@0G3`d06A4?01H>300C2`T050`:00808ATG00@06Q8@01<>
2`0E4Pd04a8=0P0B4@d08@0D4a005A@B00h=2`0O7Qd040h?01LE5P0C4A805A<D01DB4`0F4a@061DF
01DA4P0F4Q<061DF01LD5@0G4a@07Q/L01@A4P0K5aP05A8C01DD5@0H61P04A4A01@D500H61P04Q8B
01DE5@0J6QX06a/K01@D500J6QX05ADE01PD4`0201XI5`0E01LF500D518051@B01DE4`0G6AH06adJ
01PJ5`0C61@05a`H01PJ5`0J71T06A/H01XL6@0D5Q<07AlL01/M6P0M7a`071hK01XL6@0K7AX071lJ
00806QlI02d06QlJ01XO6`0J7Qd0720O01dQ800L8240720R01dQ900O8bH07R8U02P/;`0n@T<07B4P
02ld<00T:b@07RDN020X8@0O:2<082TV028/:`0P:R/082TY02</:`0T;B`09Bl_02La<P0Y<SL09S0f
02hi?`0Y<c`09c8m030lB00a?TP0>49;03@oA@0a?400<3ho0390@@0jB4P0<T9202hn?P0eAd/0<dA<
03Y;D`0fB5800P0mD5h0:014EfD0AEQV041BH010DV00@55O03E6E@18EfH0?diM04=@H01:F6L0@U=O
03i@G010DUh0AeUU04YLJ01>H6X0A5IP03a>F018Ff80AEQO04ULH`2<WjD0enOc06AdPP1MKGT0FFYd
05AUK@1?HFD0CV1S05a^KP1EJ6@0DFAP04YMEP1AI5h0Df=R05ATI01FIVH0F6QX05e]K@1PL70206Ad
M080IGEe0P1VMWH0701[Ng/0JWYj0720P01bPX80L7n007>1PP1eP880NXF707f8RP1nR8X0P8Z<08:<
SP25T9D0Q8nE08jIW`2BVj80T9VP09>LX`2HWjL0UijV09VPZ02MXJX0Wj>/0::W[@2RYj/0X:BW0:6U
Z02XZk020:j_]0060:b/]02b/KT0^KS00;Zh``2k^L@0_kg90P31_L`01`32_/d0aKk>0<W3d@3>b=H0
c/KD0=O?g03Fc]/00`3Db]D0<03Kc]d0jM_Z0>OIj03Pd^<0hM3R0>CCi@3We^T0jMK/0>_HkP3Ye^`0
j]C[0>[Dj@3ZeNP0j=GX0>SEjP3Ye^`0jMK]0>OEk03RdNH0gm3T0=k?h03KcM/0f<[H0=C7d@3<`LP0
b;g40<Nl`@2o]KT0^k:f0;bc]@2aZj`0[:JW0:nZZ02`[:X0YZ:P09fNUP2=TH<0QXYl07]oLP1bMFX0
KG=W06abI`1cNFl0O8Ai07ElM01gOWH0LG]b06ifJP80K7AW01d0MGe`07V1M01dOW<0Kg]a06]gK@1W
LfT0HFiU05i[HP1RL6P0IgMa061`K@1JJVL0EfQR05=TGP1FIEh0Be]A04UIC`1:Edh0A55703e:@00h
A3/0=d@m03U5@@0e@Cl0>TI406McL@0hA4@0>dI802Td=P0203M2AP0^05QSJ00^>Cd0D5aL04UED`0a
?C/0:SHd04EAC`0^>SP0:cLe02Xf=00X=380:cLe02di=`0S;b`08bl[028_:00U<R/0:SDa02Pc;`0Q
;2P0:S<`02Tb;`0O:2D09B/[02hd=00S:BL0:B/X02PZ9P0V:2D07b0R01lP8`0S92P06Q/O028S9P0T
9RD08bDT01hP700R91l0724J020U7P0R9b008RLQ01lT7P0M8Q`082DQ02HZ:@807b<R00T08BDT01lS
8P0T9R<092HS028T8@0O8Ah07R0M020R7`0M7a`00P0K7AX0100J71T07R0M02@V8`0L71X201/K6@06
01dM6`0L71X06a/I01`L6P0J6QP061PF0`0G5aD01P0J6AL05aHD01TH5P0G5Q@05A@B01LF50805A@B
00/05aHD01@C4@0G5Q@07a`K01@@3`0N6QT0510?01TE500K5aH05A4@01LC4P0201HB4@805a<B00T0
5Q8@01DA3P0F4Pl05a<@01@@3@0B3P/0510=01LC400H51400P0F4Pl0200I5A806ADC00d9200D40l0
71PG00l;2P0C3``04@h90P0B3`X0200A3PL040d6018?200D3``06A@A01<>2`0>2@H05A0=0P0A30T0
4P0B3@X04`h;01<>2`0C3P/04Pd:01TE4P0<20D04@d:018>2`0E4@h03@T601<?300?2`P04Ph;01HB
3`0B3P/040`901<>2P804Pd90P0A30P2010;1`06018=2@0G4Ph030L302@O6`0H4`l04@`8100B3@T0
500A30P040/7014<200?2PH03PT500l:1P0B3@T02PH300l;200A3@X040`900h:1`0?2`P0;RXW0:NS
X00M6AH05a<@00h:200?30X03`X70P0@2`P00`0A30T050l<01HA3P02018=2P0500`71@0D3``061<@
018=2P0C2@P00`0D2PT201<9208040H500`04@L601<9200D2PT050`:01082@0>20P040X:014;2`0B
30`050h>010:2P0?2@T200h820803@L700L06a4B01D;300?1`L05@/<02HL7@0>1@D04PP900@04@L8
01004@L901<8300D2@d04`P<01D:3P0F2`l050T=01872`0@1@T03`@801052@0B1`/04`T<01062@0A
1PX050T=0P0?10P201<8300800l4200@1PT03@@602/Q9013>3/04`T:00h41@0A1`P201882@0301@:
2`0B20T04PP9008050X;0P0A1`P01@0B20T04@L801061`0@1PL04PP9008050X;00@04PP901061`0@
1PL040H70`0B20L00`0A1`H040H501061@0601471PL040H700H03`D601<:2`0L4Q<03`D600h41@0=
0`@200l51P0?00h41@0@1PL04`T:01T?400@1`P04`T:01061`0=10@04@L800l5100>10<030810106
1@0E2`X03P@3008040H500@03`D4034W9P0H3Pd03P@35?ooool001_ooooo00@050h>01<=3@0A2`/0
4@/;0P0B30`03@0E3`l04`d=024K6`0f<3006A<C03H`<00E3`l04P`<00X4100D3Ph04`d=01H@400A
2`/00`0B30`2014;2`0>01DA400H51<06aLF014=300B3Pd03`/:018>3@0W8b805A4@01@@3`0C3`h0
510?01<?3P0B3Pd2014=300501HB4@0I5A@03PX900h:2@0?2`X00P0B3Pd01@0>2PT03`/:014=300B
3Pd04@d<008040`;00P03PX9014=300C3`h04Ph=00h:2@0@30/04Ph=014=308040`;00<04@d<018>
3@0A3@`00P0B3Pd00`0A3@`040`;010<2`05014=3003010<2`0>2PT06ADD00805Q8A00h05A4@01DB
4P0@3Pl01@<401@B4`0B41402PP9010>3`0:20T04@l@03@b<`0Q7b002@L8014>3P804Ph=0P0D40l3
014=30804Ph=00/04@d<018>3@040`403@`:00L61@0<2`T03`h<01TH5P0=30X03Pd;010?3@0300l>
300701<?3P0E4A004Ph=014=300C3`h04Ph=01@@3`0201DA400;01<?3P0D40l05aDB0=GFd@2d]Jl0
5QLB0042000B4Pl06QTG018A3`0B40l00P0B3Pl03`0C3Q0050h>01PB4P0G4Pl05A0=01@?300F4@h0
5a8?01PC400K5Q<06A@A02<N6`0H4a005A0=01LD3`0301@C3`0401HE4P0G5Q@061LE02LU9@806QPI
00l0518C018@4@0:20T05QDE01XJ6P0=2``02@P801PH600A414081hO020P800A41005Q@E01`L700A
4A400P0M7Ad201<C4`0301TI6@0E5AD05QHF00805ADE00H071`L018B4P0I5A@06QTG01/J600G5Q@2
01<C4@0<01HF500D5Q<05QPE01@F4`0C61@061dI01dO700N81d04aDB01LI5P0I6aP061XG0P0M7a`0
1@0L7Q/06adJ01dO700M8A`06QlI00<06QlK05D06QhM01`P7`0M8B00720Q01/O800M8B807b<V028V
:@0N8RD0;C4b01TN700P9R809bhW01`U7@0N:2007bPS028]:@0R;2/07bTZ024[:`0T;B`092h_02H`
<P0Y<cD0:C@h02Pc>00[=S`0;CY202llA00U<S/0;CU4030mA@0`?D<0;S`o02hl?@0`?Sl0<D5003M7
A`0_?cl0=dU=041AF@1;G6@0@59L03Y<FP0kCE/0@UAR045CH@0nCUd0A5AS04EBHP0oC5`0BEIV04EA
H@1:EVH0B5EU049BG`0oDEd0?U1L03mAG@13EF40@eEO05QZM017FF<0?E1G04EHG`1DIfh0HGAj09:S
[@1JJWL0H75k05EVL01?H6P0BeeQ04eOH@1@HV40BUeI04iQG@1;GUP0EFQT05EUI01EIFD0EVIV05UY
J@1NKVh0HG5a0080KWin01X0K7al06YjNP1YNGT0J7Qh06YjNP1[Ng/0LH6107>3P`1bPH40M8:307F0
PP1iQ8H0NhJ807b6R01nR8X0P8Z<08NBUP24Si<0QI2D08ZCV02AVYl0Uj2U09ROY@2JXJL0Vj:X0:2U
Z`80XZN]00@0Y:V/09jRY@2OXjH0YZZ]0P2/[K80LP2^[k@0];>k0;Zi`@2i^<00^;K10;bja@2o_L/0
a/;A0<g9f03;amD0bL?A0<c6e03>b=@0eloL0=O?fP3?am80c/C?0=77dP3Hc=X0f/kL0=W=f`3Md>40
gm7R0=k?h@3Sd^D0iM?Y0>ODjP3VdnT0i=7W0>?Ah`3Udn<0imGU0>OEj03RdN@0g/gP0=c<g`3Jc=d0
f<[I0=K:e@3Cb=00d<G=0<Zoa033^[d0`[Vl0<:i^P2k/[<0^[6b0;fh]@2]Z:D0ZjNT09VFT@2RWiX0
TY6<096BR@25RG/0OX9d07b1M01dNVh0LWQ/06ieJP1RJUl0IfmT06egKP1RK6<0IW1W06A/H@1YLFH0
LWY_075kL01`NVl0LWac06ahKP1ULFL0HVmV06UfK@1ZMfh0JGM`06UhL`1QLV`0FfaV05QWHP1AH5/0
C5]D04EBB`16Dd`0AE99045<A00lAcl0=40g041;A@0oBTH0<3Xi03@n?@1ZM7<0<S`m09bVY`17DE80
:38d03e7B@0Y<cH0?DM9030l?00_>cT0930^02lk>@0[=cD08Rh/02lk>@0]>CL0;3Pf030l>P0_>cT0
8Bd[024]:@809C4]01H08RdY020[9`0Q;2P0<CXg02Pa;P0O:2D07bDS020V900Q9bD0;2h[020R7P0Q
8b008R<U028S9P0:2`l09bP/024R9@0J71/07R0O01/M6@0W:B@07B8L0`0L8A/0500M8Qh07R<O01lT
800P92<05a/J02X^;@0P92D092PW02LY9P0V:2D08bDR01hP7@0M7a`07R0M01XL6@0N81d071hK01PJ
5`0I6aP06Q`I0`0K6aT201XJ600301/K6@0J6QP061PF00@05aLE00h061LE01/J600F5A<04a8@01HE
4`0G5Q@051<A01HE4`0J6AL04a8@00l>300J61H06aLF01@@3`806QHE00<061@C014=300D40l0100D
40l0100F4Q0061@A01HB3`0D40d201<?30804@d:0P0D40d201<?300901HB400H51<04`l>01DA400K
5aH06ADB014>2@0B3`X04a0;00804@h700D05Q<<01<>2`0@2`P05Q4>01PC4002018=2P0C014<2@0B
3@X04Pd:014<2@0@2`P03PT600d91P0H5140;2PU020L6@0A3@X0510=014=2P0=2@H040`901@@3@0@
30T03PX701<>2P02018=2@09014<200@2`L040/7014<200@2`L04`h:00@0000K5Q802PD100@03`X6
0P0@2`L2014<200N00l:1P0>2@D040/701<>2P0K5Q<04`h;00l:1`0B3@X04`h;00l:1`0;1P<0;RTV
00l:1`0400003PT600`7100=20D040/800h91P0<1`@03@P5014<2@0910403PT600X50P0D3``05a8?
00h91P0B20L04`T80P0D2PT201881`803`D400X040H501<9200F30/05`l=01@=3@0:10@02`D500d7
1`0C3@d071HF0P0=1`L02P0>20P03`T900l92@0?2@T05Pd=01<92P08000050X;00l51P0G3@h50147
200401882P0B1`/04@H:01872`8040D900<05``@01/@500F2`l00P0B1`/0400D2@d05P/?01872`07
00004PP;01T>4P0<0@D02P4301<8300B1`/05@X>028G6`0F2`l03`H701<92P0B20T201<92P0701X@
4@0M4a@04`T:01061`0A1`P04`T:01882@020147208040H700H04@L801882@0D2P/050X;01882@0@
1PL200l51P<04PP700<04@L601061@0@1PD01P0A1`H2014720@040H700L06@l@00h41@0B2@X02`42
00d3100B20T03P@5008040H701D03P@500l51P0B20T02P0100/30`0700004@L801<92P0E2``04@L6
00l5100>10<04`T801P>3@0@1PD050X901061@0A1`H0@3He01`B4@0?1@@05?ooool001_ooooo0P0C
3@d2014;2`0?018<300C3@d04`d=014;2`0Z92@0>38b01H@400Y8b<04@/;01D?3`0?2@T050h>014;
2`0G4A404@/;00<04P`<00h040X:00l92@0B3Pd05Q8A01TE500A3@`04Ph=00d9200@30/08AdL01<?
3P0?2`X03PX901<?3P804Ph=00@04@d<018>3@0G4a806QHE0P0B3Pd01@0I5A@05A4@00d9200?2`X0
40`;00804`l>00D03`/:00h:2@0?2`X040`;014=3002018>3@04010<2`0A3@`04Ph=014=308040`;
100A3@`00`0B3Pd04@d<010<2`06014=300E01@@3`0:1PD03`/:00D10@0?2`X04Ph=01HC4`071@H0
3`d>00P61`0:20T06ALH00`:2`081PL03P`=02l];P0L6Q/02@L801@A4@0B3Pd04`l>0080510?01P0
4Ph=00l;2P0A3@`04`l>018>3@0@30/04Ph=01`K6@0:2@L05A@B014@3P1>CD/0FeYH00d<2P0?3P`0
4A0>010?3@0?3P`04A0>01HB4@0G4a804Ph=014=300D40l2014=300=01<?3P0D40l0510?01DA400I
5A<0MWEa06AUG`0@4@`04Q<>01PH5@0?3P`051<A01@B4@0201DA4P0?01LB500I4a<05@l?01LB3`0D
3``04@`901@?300J5A8030L401`G500E40d04@`900l:1`0I5A8061D@00<05A@@00D05aHC01PG5@0F
5A<06ALG01/I6P0201DC500801@B4`0I6AT07AdM010@400X:2P0@D51014A4@0@410201HF5P0@010@
400;2`/03@d=01DE5@0C4a<061PH01<C4`0B4Q806a/K01PH600E5AD061PH01HF5P0J6QX04a<C01TE
50806aXH01H061LE01HF500F5Q@06ATG01<E4P0G6AH061XG01DJ5P0G71P09RPU02DW900Q8b007AlL
028T8@0>40d07AlL01hP7@0L7Q/06adJ01`N6`0L81`06QlI0`0J7a/0100J7Qd0720O01`P7`0L8242
01dQ8P1?01hR9@0T:2/05QXM01XN7`0K81l06b4M028Y8P0N9al07RPP01dX8P0R;BT08B/Z020Z:`0S
;Bd09Rl^02D_<00W<C<0:S@f02/f>P0_>Sl08bhd04QEG@1WM7d0;S]402hjA@0^>d<0<Ci4034o@P0`
?Sl0<d520351@00hB4P0;Clo03E7B`0mCUH0AUMO03]=E`0lCU`0>deK03m@GP0oCeh0?DeL04QEI@14
DF40Cea/04]GI`16DV80CEUY04QDI011DEh0@59N03i@G010DUh0AEMS04EGH@1<GVP0AeUS04AGGP1;
GVD0DfI]04IIG`1NKgT0EVMa05e^MP1KK7@0F6U_04mQH`1EIfL0D69Q04QKF@1>HEd0BUeG059UH@1E
IF@0EVIV05QXJ01KJf/0Gfm_065aL@0206]kN`0P06QhN01WMgL0IGEe06AdM01YNGT0J7Qh06inOP1`
P800Kgio07B2P`1fPH<0NXF707b7R@1mQhT0OXR:082:S020Rhl0QI2D08ZEV@2=UY/0SiRM096JW`2G
WZ@0Vj:X09bSZ@2RYjd0XjR^0:2UZ@2X[K00XjNZ0:2TY`2RYZT20:JW[00:0;2a]P2d/k/0^KS00;Nf
_P2e/kh0^KO20;^iaP3<b=L0f]KU0=GAg`80a/3>00L0cLOC0=79e03AbM@0b/;=0<Jla`39_lX0f<cJ
0080eLWG05L0gm;S0>;Di@3Ncn40hM3S0>;@iP3SdNL0hm3V0>;?i@3Rcn40i=;P0>GCh`3Sd^<0g/gO
0=W8fP3Fb=T0e/[H0=?7d`3AaLh0cL;80<Zoa@33^[`0_[Jd0;je]P2n][@0]:n[0;>^Z`2e/:`0ZZNP
0;Re[P2CT8T0WYjD09>CR`2=T8@0QHUk08:6N026Rgh0OhEi07IlL01^MFT0IViS06ifJ`1hPWT0Ig5X
06I`I`1SJf00Jg=X07EmLP1_NFh0K7I[06iiL01bOW@0JWE]06IcJP1]NW40JgQa06AbJ`1QL6/0FV]U
05MXHP1IJ6<0DV5L04]JD`11CTL0@e19045>A@0lAcl0>TDm03<n=@1ZMG40DeiJ03U3@P19De80LWak
03<m?P0X<S<0:C<d02hh>P0a>cd072HX02li>`0^>SX0;c/i038n?00oBdT0;3Pf02di=`0/>3H00P0Z
=S@0100^>SP0;3Pf01/W9@0L:2@2024]:@0`01lZ9P0P:bL09C0/02/d<@0U;R/0:34^02H/:P0K8Al0
82HR02H[9`0L7QX09bTX02<U900S92L0D55E05AEF@0V9bT05ALF01`N7@0Q8b00828M01lT7P0M8Q`0
6b0J01`Q6`0P9B408BHR01XO6`0_<c80<SHe04I:B@0O8b@0720O01hP7P0N81d07AlL01/M6P0L7Q/0
7R0M01TK600N81d071hK01TK600G6AH051HC01XJ600L71X06a/I0P0J6QP01@0L71X06ATG01PH5P0G
5aD05QHD00805aLE00P05aHD01/J600D4a4051<A01PG5@0K6QP05QDC01<B40805QDC00T05aHD018?
3P0>2PT03`/:020L6`0<20L0510?01PD4`0D40l00P0E4A00200D40l04`l>01DA3`0F4Pl04`l<014=
2P0@30T04Ph;0P0A3@X06@0D40d05A4>018>2`0A3@X04Ph<01PD4`0@30/03@T800l;2P070`0030T4
00l<1`0B3`X04@h701@A2P0L6A8061<@01HA3P0V8Ah0:B@Q01PC400B3@X03@P500h91P0@2`P00`0A
30T0300;1`@06QHC02l[:00O6aP02`L4014=2P0C3``03`/8018>2`0E4@h04Ph;010<2@804Pd90`0A
30P01`0@2`L04@`8010;1`0@2`L01@00018=2@070P000P0?2PH400h91@0O010;1`0B3@T04@`800l:
1P0@2`L04Pd9028M6P0F4@h040/801@?300G4Pl04`h;01@?300?2`T04@`900d81@0F4@h02@@1010;
200C3P/04@`900d81@0<1`@040/800d81@0E40d03PT601<>2`0b;BX0@chk01881`0301<920804PP7
01005@/:01881`0A1`H04@L601881`0B2PP02@4200h8200I4a<05@l?00X4100;1@D030H600d71`0>
20P03`T90P0@2PX01`0<10@050X;01T?400<0`@081HG01<92P0@1PL00`0A1`P08@0B20T04`T;0146
2P0@1@T04PL;00h31`0=0PH05P/?01T>4P0E2Ph04@H:01052@0A1PX03P@7024F6P0P5AT05@X>00h3
1`0=0PH07a@H01<8300:00<01`0000/0100?10P04@L901882@0C2@X04PP900h41@0D2P/06Q0A01<9
2P0201061`0401882@0C2@X04PP90147208040H700D04@L801<92P0D2P/04`T:01882@0301061`<0
4PP700<04@L601061@0@1PD01P0A1`H50147200801882@0<0P<01`0001D;300F30d01`0001L=3P0B
20T201<92P090147200B20T05@/<00T0000P5QL07aDF01P>3`0:0P803@<400804PP700X040H501<9
200G3@`04@L600`20@0=0`802P0001L=300700006a4@5?ooool001_ooooo00@04`d=018<300A2`/0
4@/;0`0C3@d0300A2`/05a4A01D?3`0A2`/040X:014;2`0D3Ph03PP801@>3P0A2`/05@l?01<=3@<0
50h>00d04@/;010:2P0>2PT04@d<01@@3`0A3@`0510?00/71P0C3`h05A4@010<2`0C3`h02`L60080
4@d<01D04Ph=014=300?2`X04@d<01@@3`0C3`h02`L601<?3P0;20L071PG03hj>@0H51<040`;00l;
2P0A3@`040`;00h:2@0D40l04`l>018>3@0C3`h00P0D40l00`0C3`h04@d<010<2`02010<2`<04@d<
0P0B3Pd7014=300E01<?3P050P405a<B018>3@0H51<03PX9018?3`071@H06aTJ02h/;@0B41403P`=
00d;300B41403`d>018@4@0D4Q<03P`=01<@400B3Pd04`l>00805A4@01<04Ph=010<2`0D40l05Q8A
01@@3`0B3Pd0510?01@C4@0=30X03`h<00T81`0P7ad07A`J00d<2P0@3`d04a8@014@3P0@3`d04a8@
0080510?01P040`;014=300F4Q40510?00l;2P0A3@`0510?01<?3P0B3Pd04`l=01/J5P0F5A005A@@
00h=2@0A40d04Q4?00l>300?3Pd040h?01@@4@0G4a@061@C01H@400F4@h301D@3@0801@?300M61D0
50l<01`G500H4a004`h;01XF4`0F50l301@C3`0Q01HE4P0G5Q@092<Q014?3`0T8R<040h?018@4@0?
3Pl04A4A018D4`0D5QD0@TA305iPG`0A4a805aTH018D4`0>40l051HE014C4P0E5aH051@B01LG5@0F
5Q@051@B01PH5P0M7A/061PF01dM6`0W9bD061PF01HF500I6AL06aLF00806QTG01806APF01XJ600L
71X06a/I01LI5P0O8Ah09BLT01PM6@0C61@07B4P01hR8@21QH@0Ce=B01LK6P0K7ah05QXI01TM700H
71/201HJ6@0301PL6P0I7A/06AdL00806alN0`0L81l0:`0M8B007b<R01hR8@0N8R80720R01lT9`0N
92@0728P01`S7`0Q:b<07RPP01lY8@0M:2808RdY020/:P0P;2`09C0`02H`<@0V<380:38d02Xe=`0/
=c/0:cLl02hk@@0nBe<0C5YR0350A`0/>d<0<3e403=0AP0a?d80;Shn03A4A00cA4<0<TA40312@P0i
C500=4M>03]>E@0jC5H0?dmN03a<F`0nC5`00P11CUh02@18E6@0Ce][07^7U`1NIgP0BeAU04aEIP16
Cf00A5AQ04EGH`02041BGP0H04MII@15Ef40AUQR049DGP16FF00BUeT04ULH`1@HfT0CEiV05]/M01;
G6<0DF9Y04mPI@1SMGL0BUaL04YLF`1:GE/0DFAP04aOFP1GJVH0E6AS05MWI`1KJf/0GVi^0P1PL702
06EeM@@0IWIf03@0K7al06UiN@1^OWh0L8200760P@1gQHH0Mh:407^6R01mR8X0OXR:07n9R`20RX`0
PHb@08JAU@27TYH0RY>H096JW`2DWJ80U9^Q09NNY02EW:80WJ:X0:6V[02NXjL0XJJX0::VY`2PY:D0
WZ:U0:BUZ@2WZ:`0/K:g0;:a]`2e];X0];>k0;Je_@2k^L<0^KO30;nmbP3;bMH0alCA0<2mb035`/d0
a;k:0<:laP38`/`0bL;:0<O0b03;`ld0d/OE0=O<fP3FbmT0fLkN0P3Kc]l0<03Mcn80gLkS0=g>h`3N
c^<0glkT0>3@h03Mc]T0flcI0=O9e`3Eb=L0eLSF0=C8e@3Aa]00cL;;0<W0a@34^kd0`;Rg0;Zc/02f
/Jd0]k:^0;>^Z@2WXid0YZ:L0:FSV`2c/jP0f][?09>DR@2EUhX0SY2408^?P@24RW`0OXAf07b2M@1n
Q7P0Lg]^06]cI`1eOW<0M7ic06afK@1^N6l0JWI/06A^I@1WLFP0KWQ_06miL01/MVh0JWE]06ijLP80
JgQa01/0IgI`05i]J01IJ6<0GfiW05MVG`1CHU/0E6=L04mNE`1:Ee00?da5049?B00nBD<0=d8j03U4
?00d?SL0=d8n034k>P0e?ch0<3Xi03<m?00]=cH0;3Hg038l?@0W<C80:cDf030j>P0Z=3@00P0^>SP0
100d@3h0;SXh02Xf=00Z=S@202Te<`0=02/g=@0b?S`0<3`j01hZ:00V<S008Rh/020/:P0R;2/08bh[
028]:@0S;2T08R/W02</9`0202L]:@0=02@Z9P0V:bL07B8P02<W9P0[;bh07B4P05QLG014B4T08RHV
02@X9`0H71/08BDS020U8@0201/P6P0I01`Q6`0N8al07R<O01hS7`0R9RD07B4R01PL7@0Y;Bh05QXK
02DY:@0P8R00828O01lQ7P0L7Q/07AlL01lQ7P0K7AX06Q`I01LI5P0M7a`07R0M01PJ5`0L71X07alM
01hN700201`L6P0301hN700I6AL05aLE00805QHD0P0G5aD201PG5@0?01LF500M71X06QTG01LF500F
5A<051<A01TH5P0H5aD05QDC01HD4P0S7ah04@d<01PD4`0A3@`071PG00805a<B0P0H51<01`0F4Q40
5A4@01DA3`0E4@h05Q8?01DA3P0D40d00P0C3``201DA3P0E01<?300A3@X04Ph;014=2`0C3`h03`/:
01PD4`0D40l0;2PU00h;1P0A3PT04Pl:00h;100?30D05a@=014<2@0I514071LD01LB3`0F4@h04`h;
00804@`90`0B3@X0100A30T04Ph;00`81@0E4@h2010<2@804@d:00D03PX7014=2P0D40d04@d:00l;
2002010;1`804@`800/04Pd901<>2P0?2PH040/701<>2P0E40`04@`801@?2`0B3@T04@`8010;1`02
00l:1P0900d8100?2PH04Pd901<>2P0B3@T040/7014<200C3P/04@`9008040/800/04Pd:01<>2`0A
30T040/801@@3P0<1`@04`l<01<>2`0@2`P050l<018=2P0200h91P0701<>2`0L5a@040/8014<2@0H
4a008ahK02`W900201881`804`T800@04PP701471P0F30/04`T80P0A1`H0200C2@P04`/900l8200E
3`l08Q`L01`F5P0=1`L03PP80P0?2@T200h820803@L700H04`X;01D;300D2P/04@P900d51@0D2P/2
01061`040147200B20T04PP901<82`803`@801H050T=01052@0@1@T050T=01872`0@1@T03`@80105
2@0A1PX05``@03`a=@0b9b/060hA01D:3P0:0@<04PP;01052@0I3Q805P/?00l4200C20`04PL:0P0>
10D0200C2@X040H700h41@0?1@H04@L801@:2`0C2@X04@L80P0C2@X301061`080147200C2@X04PP9
01882@0A1`P040H70147200B20T301881`0301471P0@1PD040H500H04@L60P0A1`P02`0C2@X050X;
01@:2`0E2``0N6i_071VI`0@1`P060h?00/20`0M4a@040H700804@L800L03P@500l51P0A1`P05@/<
00d41@0?1`L03`D600804PP900`040H501@:2@0@1PD040H501<9200A1`H050X901061@0K4A002P40
01H<2`0h;RdDooooo`006oooool601<=3@0800/51@0D3Ph030H602@N7P0E3`l05Q0@01@>3P0B30`2
010:2P03018<300D3Ph04P`<00@04@/;014040X:01<?3P0J5QD00`00010<2`0>2PT03@T801@@3`04
00004Ph=014=300G4a802@D4010<2`0A3@`04Ph=01<?3P0201@@3`0@00/71P0E4A003PX901DA400U
8B00[JVX02DQ800>2PT04@d<018>3@0A3@`05Q8A00h:2@0A3@`04Ph=01<?3P<04Ph=00`040`;00l;
2P0@30/04Ph=01DA40050@008AdL048n?@0A3@`02PH501PD4`0C3`h2010<2`804Ph=00d04`l>01@@
3`0C3`h04Ph=00l;2P0>2PT04a0@00<10P0c<C80LFm`01XH6@030@805A<D00803@/<00X040h?01@B
4`0E4a@04a0@014=300B3Pd05A4@01PD4`0K5aH04Ph=0P0D40l0;P0A3@`040`;014=300D4a404Q4?
00l>300=30X03Pd;014@3P0@3`d03`h<00d<2P0<2`T03@`:00l>300>2PT03@T8018>3@0E4A004Ph=
01@@3`0A3@`05A4@018>3@0A3@`05a<B01PD4P0A3@X04a0;01HB3`0B4@d040l<010?3@0D4a403`h=
00P61`0<2P/0518C00d<2P0B3Pd04@d:010<2@0G4a007QXG018>2`0C3``301DA3P0?01PD4@0L61D0
5A@?01DD400N7AT04a8>00h=2P0O7Q`0:BPV014@3`0B41405Q@E00h<3@0@410051@D008051HE01T0
5ALF01LI600H6QT03a4@01HH5`0D5QD0418A01DG5P0L7Qd051@B01<C4@0E5A<06QXH01PH5P0E5A<0
5aLE01XJ600H61H05ADC01HF500H61H05a<B01HE4`0G5Q@06APF00806ATG00/05ADC01DG500E5a@0
5QPE00`A3@0D6AD041HD02T_;@0H7Q`08RPV01DK6@0201HL6P0;01PN700J81h06AlM01TO7@0H7A`0
61`K01LK6P0I7A`06alN01hR8@0M8B000P0K7ah201`P7`0?01dQ800O92@0724T024W9`0R:BL07bPS
01lY8@0K9Qh07RTQ01hY8`0S<2/08Bd[01l[:`0N:BX08B`^00809C0d03h092lc02Le>00X=SX0:cPn
02/j?`0Z>Ch0=DA902`mA00eA4T0=4=803=2A@0b@T80=4A403A7A@0nD500<4A303I9C@0gBe80<TI=
04=FH00nCUd0?4aK045>GP1<FFT0=T=C04]GI`1AGFd0UJ6a05aUMP1;E6D0@daM04aDIP15EF80A5IR
03U;E`0kCET0B5YV04MIH`15Ef40@UAN04EHG`1>HFP0DFA[04aOI@1:Ff80FV]b059TJ01:G600CEmR
04UKG@19Fe/0CF1O04iQG`19G5P0AeYE05EXI01AHF00EFEU05][J`1MKFd0GVi^05e]K@80I7Ad00h0
IWIf06UiN@1[Ng/0JGUi06YjNP1[Ng/0K7al06inOP1cPX80MH>407Z5Q`1kQXP0O8N907n9R`80PH^=
02/0Q8nA08F@TP24Si40QHnA08ZDUP2=UiT0TYZM09JNX@2KXjH0VYnS09VNXP2NXjH0WJ>R09JJV`2O
Xj@0WJ6R09fNXP2WZ:`0/;6e0:n^]02`[kD0];>i0;^j`02n_LD0^;S30;^ka`2l_<P0_K_60<6nb@34
`LX0`;g60;Vc_@30^l80`kk50<[5c036`LP0clSE0=;:e`3Fc]/0dLWH0=35e@3Fbm/0e/_L0080fLcP
00`0e/WM0=?6fP3EamP0e<SD0=G9e@3Hc=T0c/;@0<c0cP3?aM40bl7:0<Voa`2o^K/20:nZY`0a0;6^
Z@2]ZZ<0clc50:bYX02=SH<0YjNM09RHS02FV8/0T9:508Z<OP28S7d0RXio08Z?P01nQ7H0NX1b07Mn
L01XL6<0IViQ07=lL01jQ7T0NHAi07J2N01bOW@0JWI/06miL@1/MVh0JWE]06QcJ`1UL6X0J7A]061/
J01SKf/0GVeX05]ZI`1MK6T0FfYV05e/I@1=GE<0Df=I04MDC@1GI5d0EF9K041;A@0jACl0A4e803Dn
>@0f?cX0?dQ302lh=@0203Dn?@030419B00lAD@0;SLf00<0;cPg01d09Bh]03Q1?`0mAdH0;3Pf030l
>P0X=380930^02Xf=00^>SP0=D4o02Te<`0^>SP0@Ti<04EAC`0U<Bl07BTY02Pd=00^>SX09c4`01lZ
9`0X<bl08b`Y024Z9P0S;2L08bXS020W800T:RH06AlM024W9@0201lU8`0J02@Z:00T:RH0<SPf01`R
800M8b406R0N02<Y9`0F71X06QlK010E4@0[<2`07b@P024U900M8B007R8S028V9`0G6a`092P[01/O
8P0K7b00828P02<U8P0[;BX07R0M014C400L7Q/601/M6P1701TI5`0M7A/071`J01dM6`0W9bD07alM
01LG5@0T928051@B01<C4@0Q8Al06ATG01PG5@0D4a4040l=014@3P0L6aT06QTG0081000F5A<05A@B
018A3`0920H05A8A01@@3`0F4Q4061@C01LC4P0F4Q405a<B01XF5@0C3`h05a<B01TE500B3Pd04Ph<
018>2`0D40d05A4>01@@3@0B3P/05a<@01<?300:1P<05a<@02<O700j=S<02`L501@@3`0A3@`03@T8
01HB4@0A3@X02`P301XG4P071080514:018?200C40T05Q4>00L2000B3@X0?STf018=2P0D3``03PT6
010;200E40d0<2/X01HA3P0C3P/00`0C3``01P0B3P/04@d:014=2P0D40d04Ph;014=2P804Ph;00P0
40`900T4000D3`/05A0<018=2@0:1@404Pd901<>2P803`X60P0A30P00`0=20@040/7010;1`0200h9
1@803`X600d04`h:01D@300F4@d05Q4=01D@300C3PX04@T7018:200A2@L03`L501081P0B2PP04@T7
00804`/900D04@T700l71@0@20H03@P500l:1`02014<2@0300l:1`0=20D03@P5008040/801P03PT6
010;200B3@X04@L601<9200D2PT03P@301061@0H3Pd040H501D;2P0G3@`05@/:00l5100;0`403PH7
00/51@0?2@T03@L700/51@0>20P03`T9010:2P0A2`/3018<30H04@L800/04PP901061`0>10D05`d>
01P>3`0@1@P05@X>01T>4P0E2Ph03`@801052@0201462P0801<8300E2Ph04`P<01462P0?10P04PL;
01H;3`0E2Ph201462P0>01872`0F2`l0GE9F01052@0K41@0304501472@0>10D05P`=02<I6P0=0`@0
200001@:2`0A1`P201061`0D0147200B20T04PP901/A4P0=0`@05`d>01D;300D2P/01`0001hD5@0B
20T060h?01061`0?1@H0308101D;2P0?1PH040H501D;2P0?1PH601471P0<00h41@0A1`P04`T:0147
200@1PL04@L803/a<P0Z82404PP900h41@0B20T04@L8300@1PL301061@0901471P0B20L04`T80106
1@0B20L04`T801471P0B20L050X901Cooooo000Kooooo`H04P`<00P0618B00h8200F4100Ad5103<]
;@0<1PH04`d=018<30804@/;00<04P`<01<=3@0A2`/01@0A2`/0300;1`H05a<B00X61@0D40l05a<B
01@@3`0F4Q403@T8014=300@30/04Ph=00d920D04Ph=00T04@d<02PT8`0A3@`00`0001HB4@030000
;b/Z01TE500<20L00P0A3@`01P0=2@P04`l>010<2`0A3@`04Ph=01<?3P804@d<1@0B3Pd0200?2`X0
5Q8A04I2@@1NFUT06ADD00H20@0@30/04Ph=0P0D40l0100A3@`03`/:010<2`0A3@`2018>3@804@d<
01h04a0@00`:2`0A3a008b4R018@4@091`P0518C01HD5@0B414030X;00T7200;2@X03``<014=300B
3Pd04`l>01@@3`0G4a8040`;018>3@0C3`h040`;00l;2P0A3@`04Q4?014@3P0?3P`03@`:00h=2`0A
40h2010?3@803`h<00<040l=014@3P0E4A000P0?2`X0700E4A00510?01@@3`0B3Pd05A4@01<?3P0B
3Pd05a<B01PD4P0>2PL04@h901@@3@0A40`04A0=018A3`030P004Q4@01@B4`0H5QL03@/<01DD4P0B
3Pd04`l<014=2P0E4@h06ADB010<2@0A3@X301<?300?01HB3`0J5Q<03@`7010?2`0A40`030/703Pg
=00A40h02`X801<A4@0M6a`081hO01/I6P0C4A8051@D00<05ALF00/051HE018D4`0@4Q4051HE01<E
500A4a805QPG01XL6`0J6QP05ADC01@D4P0201LG5@805ADC0P0H61H01`0F5Q@061PF01XJ600M6AP0
6QTG01TH5P0H5aD00P0F5Q@01`0Q8Al04Q@A01lQ7P0J71T041DA01@I5@0K8Al00P0D6QP0100J81h0
5Q`J018H5P0I7ad201PN700301XP7P0K8Al06QlO00806AdN02406QhM01dQ800O8b807R8Q01/O7P0M
8B007b<R01lT800N8al07B8Q02ld=`19Cdl0=Sdk01HO6P0N:B409C0X01lZ8P0O;2D09C8]02@`;P0R
;Rh08bh_02@_<@0V<CD0:3<g02Td>00Y=cX0:SLl02/j?`0Z>Ch0;ci3041?E00eATd00P0a@4D0<P0b
@D@0<d=30394A00dAdD0;D5003iBD@0nDED0=DU@049FG@0jCUL0;d5?04YJJ@14Df80?daL05MTM00m
BET0E61`07J2TP1>EfP0Dea]04QAHP17DV80@U9O04AFHP12E600BeeY05a^NP1OLG/0AeUS04IHHP18
Ff80CV5X04mRJ@1<GfD0A5EL05=UJ@1;GF40A5IJ04MIF`14EUH0B5YJ04EHE`1<Ged0CV5M05IYI01B
IF40EFET05QXJ01LK6`0GVi^0P1OKfl00`1RLW80I7Ad06IfMP0206MgM`0P06QhN01[Ng/0K7al06em
O@1_Ogl0M8>307J4Q@1iQ8H0NXF707b7R@1nR8X0PH^=08:<SP24Si40QI2B08B?T@26T980RYBF08jH
VP2;TiH0RI6D096IW02KX:@0W:6U09jSYP2KXJ00VinP09ZNW`2LX:40XjBX0:FVZP2a/[H20;2_]@07
0;:a]`2e];X0]kJn0;Jf`@2i^LD0_Kg90<;0b`020<:ob0090;Re_P2j]K`0`Kc30<6l``39a</0b<?:
0<[4c`3;aM40dLWF0080c/KE01P0e/_K0=G:f`3Gb]h0f<_O0=G8g03Ca]X0cl?C0<c0c03AaM40el_I
0<g2d038_L/0bl3=0<O0b036_lH0`;Zk0:n[Z02YYZ40[JZT0::OV02QWYD0UYJ<09NGS@2NWY8208nA
Q00h092BQ02>TX<0R8am08F9N01oQGD0NX1b07QnL01_MVP0I6aO06M_HP1dOW80NH=h07F1M@1bOW@0
KWY`06YfK01ZM6`0J79Z06YeK@1ZMFl0IG1Z06EbJ`1NJVH0HFeY05i]J@1KJVL0G6]X05YYI@0nCDH0
C5aB04UIC`1<FE80SIZC07b9PP1BGEL0AU5;03e6@@0g@3/0>T<n02lh=00/=C@0=Chm03@m?00g@3l0
<c`k030i>013C4/0<c`k038k>@0a>SL0>D8o041;A`0Z=3<0:cLe02Da;`0T<2h202Te<`0?02hj>00/
>3H0;SXh03E1?`0`?3X062@R024];@0W<c<0<Cdm038l?@0V<2l082/W02H_;00R:bH08B/S00808RTR
0200:c4]03<i=`0Q9bL09R`Z02X`;P0S:BD09R`X024W8`0N92408RPV02le<`0N92<06R0P02/`;@0A
5Q805a`H01XO6`0T:2L07B4P01hR8`0S9bP05ATJ01XN8@0S9bX051PI01lQ7`0R92404A<@020R7`0U
9b@03a4>01`N6`<06adJ0P0J71T0600P81h07alM01/K6@0F5Q@071`J01<C4@0B4Q003Ph<00T91`0I
6AL06a/I018B400E51807QdK01/J600S8R005aHD00h=2`0C4Q008R4O01HE4`0M71X04Q4?01PE5080
6ADD00H061@C01HB4@0E4A004`l>01PD4`0D40l201DA4003018>3@0F4Q00510=00@0510=01P03`/8
01<?300P71T071PE00l;200C3``0<2`Z00`81`0A3@`06aLF020L6`0A3@X03P/601DB3@0@3@P071TB
00h;100e<R/08A`I01@?300J5A80;2LT01PC400B3@X2014<2@0400`71@0O6QL03`X7014<2@<04`l<
00D04Ph;014=2P0A3@X04Ph;010<2@0200l;200500h:1`0<20D05a8>01D@300F4@d00P0<1`<0100A
30P04`h:010;1`0?2PH2014<200500d8100A30P040/700l:1P0@2`L00`0A30P01P0B3@T04`h:01<>
2P0B3@T04@`801491`804`/90`0B2PP0200@20H04`/901<;2@0A2@L040P601491`0>2@H03`X70P0@
2`P03`0?2PL03PT600X50P0<1`@03`X7010;200A30T04Pd:01471P0<0P402`4000l5100Q5aH0<2HU
01H<2`0201L=300?01H<2`0D2PT04@T701092@0=1`L03`T900h8200=1`L04@/;01@>3P0?2@T030H6
00X4100;1@D030H600804@L80P0B20T20147200601882@0@1PL03`D601H<3@0G3@h04@H90P0A1PX0
3P0B1`/040D900l4200?10P04@H:01<8300E2Ph04`P<01462P0>0`L040D901<8300B1`/03P<70P0?
10P030070000=BX^00`21@0C20`0200101882P0H3Pl040H701892P0K4A804`T:00l51P<040H700T0
4@L801882@0A1`P06Q0A01882@0J41405@/<01061`0Q5aP00P0800002@0?1@H04`T:00l61`0B20L0
8QPG02HL6`0E2`X060h=00h40`0601471P0;01D;300H3Pl05@/<01882@0E2``04@L802LM7P0M4a@0
40H700l51P0B20T03@0@1PL0100B20L04@L600h40`0>10<200l5100600d30P0@1PD04@L601061@0B
20L050X95?ooool001_ooooo1P0B30`01@0?2@T04`d=00d71`0J51@04P`<00804`d=100B30`04`0C
3@d03`T9010:2P0A2`/04P`<01<=3@0D3Ph04Ph=01<?3P0D40l02`L601DA400B3Pd04`l>01PD4`0?
2`X05A4@00l;2P0D40l00P0C3`h02P0B3Pd04@d<010<2`0@30/03@T801XF5@0:1PH05A4@00d9200B
3Pd200l;2P0401@@3`0A3@`03PX901<?3P@04Ph=00l040`;00l;2P0A3@`04Ph=01<?3P0B3Pd04@d<
01<?3P0:1PD03@T901PD4`0?2`X040`;018>3@0E4A000P0L61L01P0B3Pd03`/:00h:2@0?2`X04@d<
01<?3P80510?00h03``<01HD5@0@3Pl03@/<01<A4P0>30d04@l@018@4@0E4a@04Q0A00h<3@0@3Pl0
4@h>010<2`<04Ph=00@04@d<00h:2@0@30/04@d<0P0@30/00`0B3Pd03`h<00l>300200h=2`0500l>
300A40h03Pd;010?3@0B4@l00P0D4a402@0C4Q0061@C014=300?2`X05A4@01@@3`0A3@`04Ph=01<?
3P02014=300E01@@3`0F4Q004@`901@?2`0F4Pl05A4>01DC400F5A<040l=01@C4P0;2`/051@D010@
400F5Q@03`h<01<B3P0B4@d040l;018A3@0@3`/03@`800<040l;02L04Q4=01DD400D4`h05QDA01/J
5P0@3`/0?chk01HE4`0E51804Q4@00l=3P0D4Q<06QPI01<A4P0F5AD06APH01XJ6P0J6AX05QDE014A
4@0D4a@04a8B01<C4`0G5QH061LH01LG5P0J6QL051D@01<D3`0E5Q4061TD01XK5P0E5Q405aPC01PI
500I6QD06Q/F01/L5`0K5aH00P0I61H0300J6AL06ATG01TI5`0S8b40:R`Y04a>B`0K7AX04QLC01dR
7P0F71/04aTI01TO7`8061hN0P0K8B4201TO7`0N01XP800K8B40724S01/O8@0K7b007B4R01hR8`0O
8b807R8Q01`P7`0N8al082DQ024V8P0Q9R4082HT01`T9P0T;B`09Bh[024[9P0R;BD07b/R01l/8`0O
;2D0938]028a;P0Q;bl0934b02Ha=@0X<cL0:SLj0P0[>C`02@0/>Sh0;3]002Ph?@0]?d<0?4iB03A6
BP0^?D80;ci30312A00203=5A@0_03=6A00nDU40;d=203U>D@1bQXd0CF5X03eAFP15EfD0?U1N04AF
I014EF@0@E5P04UGI`1:EfL0EV=c05UVMP1?Ff/0>TIF04eIJ@16EV<0B5YV04MII@1;GFT0E6Ib05=U
K`1:G6H0BeeW04ePI`1;GVD0BUeT04ULH@1:G5l0DfEW04eOH@18FU/0BeeM04YLG01?HF00B5]I05=V
I01DIf<0Kh9n05U/J01MKF`0GFe]05i^KP1OKfl00P1RLW800`1SLg<0JGUi06YjNP0206MgM`0>06]k
N`1/O7`0KGem06inOP1`P800MHB407N5QP1hPhD0NHB607^6R01oRH/0PXb>08>=S`24Si4208JAT`04
08RBU02<UYP0SiVK0:R`/`80UYjQ0380Vj2T09FJWP2AUYT0WjFT0:BXY`2IWI`0VinN0:NXZP2TYJL0
Zjb`0:j]/P2`[k@0/[6g0;>b^02c/[T0];Bn0;Rh`P2k^lD0^k_40;Zi`@2i^<00/:fd0;Ba^02m^/40
_[Vo0<S3b@38a</0blSB0<W6d@3;a]80blGC0<g7e@3AbMT0d<OH0=?7f`3Db=`0dlOK0=;6fP3DbMX0
e<WH0=35e03>`m@0b/7@0<[0d039`Lh0`kk50<6l`P2o_;`0/K2/0:JUX080WYjF0700UiN=09^LTP2C
UHX0RH]o08N:O@1mPG<0Nh1a079iJ@1ZLF40JW5O06mfIP1fOVl0Lg]/065YF`1PJ5/0I6mQ06mjK@1b
OW80K7Q/06IcJ@1ULVP0J7E[06IaJP1TKfT0JGA^06YfLP1VLVh0I71/05e/J@1QL6d0Gfe/05UYJ01J
JVT0EFES04mNE00kB3h0@Tm604=@A`17E4/0B5==04E>B@16CdX0=Sll03Dk>@0l@T00=3Xh03]4A014
C4h0?4A6038k>P0[=3<0<3Tg04I?C00]=S<0;CHa034j=@0_>3<0<C/g02dh=@0]>CL0:SHd02di=`0a
?C/0;3Pf02Da;`0]>CL0;c/i02`h=P0Y=C<09C4`06agN014Ce40:C@e02Pb<`0X<S409c8^02hg=00W
<B/09BlW02L^9P0[<RX0=chg069XJ00T:R/06R0N028X9P0M91l0<3L`020W800S:B@05A/H024W9P0I
7R008bTY01lT8@0O8b807B4P02L[:P0R9RL082@U01`P8@0Q9BP0H6AW03/o@P0Q9BP082@U01hP7P0R
9240@D=001hP7@0G6AH05QPE0`0K7AX301XL6@0L01TI5`0L71X07AdK01PH5P0K6aT04a<A01TI5`0D
51808R8P01DE4`0l?3X0VIVG02h]:`0F5A<05aHD02HU8`0>3@/06APF01@C4@0I61H04A0?014@3P0@
3`d071XH01dI600K5aH05a<B01DA4080510?00h06aLF01TE500G4a80510?014=300H5180510=018>
2`0A3@X04Ph;01<?300E4@h05a<@01@@3@804@d:018081`I09B@SP0R7Qd020@301LC4P0C3`h05A4>
01@A300K61<04Pl:01LD3@0A3PL07a`E01hI5P0F4@h07QTF010;200K5Q<2018=2P0501LB3`0@30T0
5A0=01<>2`0B3@X00`0B3P/3014=2P0B00l;200>2PL03PX7010<2@0A3@X040`900d8100B3@T03PT5
01HA3@1KEU807QTE018=2@0A30P040/7014<200@2`L03`X60`0@2`L01@0A30P04`h:01@?2`0A30P0
40/700803`X600@040/7014<200?1`D040P60P0C2`T01@0B2PP03`L500l71@0B2PP04`/900804PX8
00<04`/9014<2@0@2`P00P0>2@H0400@2`P04@`900l:1`0>2@H03`X7010;200;1P<02@@100l5100A
1`H050X901471P0C2@P06@l>01H<2`0E2`X201@:2@0E01D;2P0D30X040P900d71`0@2PX03`T900d7
1`0@2PX0;RPX028L700H4Q8040X:00h8200?2@T04@L801<92P0D2P/04`T:0147200@1PL04PP90080
40H70P0E2``02`0D2@`04@H:00h31`0A1PX050T=01462P0?10P04@H:01<8300E2Ph04`P<00804@H:
0P0B1`/01P0A1PX040D901462P0D2@d03@@600`31@804`P<00P03@8601H;3P0E2``03@<401H<3@0A
2@T050X;024G60<03`D601@040H70147200A1`P04@L800d3100B20T050X;01`B4`0I3a005P`=02TO
800b:2T03`H701@:2`0J4A402P4001471P0<0`80718A01@:2@H04@L600H03P@501@:2`0@1PL050X;
028H6@0N51D201882@040147200@1PL040H700l51P`040H700L04`T801471P0?1@@040H501@:2@0G
3@`03P@300804@L600<040H501471P0B20L05?ooool001_ooooo1`0A2`/201@>3P0301PB4P0C3@d0
4@/;00H04P`<01003PP8010:2P0@2PX04P`<01<=3@0D3Ph04@d<00/71P0I5A@03@T801DA400A3@`0
40`;01XF5@0B3Pd08alN0P0G4a82010<2`804@d<0P0B3Pd02@0D40l05a<B010<2`0=2@P03`/:00D1
000A3@`04`l>01@@3`0200l;2P0601DA400D40l04`l>014=300@30/03`/:0P0@30/03P0?2`X03PX9
00l;2P0@30/03@T8018>3@0L61L06ADD00l;2P0@30/04@d<01DA400J5QD05a<B0P0?2`X00`0A3@`0
4Ph=018>3@0201<?3P0@018>3@0A3Ph030X;00/92P0>30d02PP900h<3@0@3Pl02PP900P61`0<2P/0
8AlP03Tg>00/:BT03PX9014=3080510?00@04`l>00l;2P0A3@`04Ph=0P0A3@`02P0D40l03Pd;00h=
2`0>3@/03`h<010?3@0A40h030/900h=2`0A40h201<B4009018A3`0C3`h05A4@01`H5`0J5QD04`l>
018>3@0D40l04Ph=00804@d<03<04Ph=01@@3P0E40d05Q4=01LB3`0D40d0510>01HB4@0?3P`0410?
01hN7P11@d80CDm>014A3`0>3@/04a8>01DD400C4Ph04Q4=01LF4P0>3@T04A0<018A3@0A40`04Q4=
01@C3`0=30L051<?01<B3P0F5A403@`901HE4`0K6QP040l>01@B4`0>30d03@/<02/Y:P0D4Q<05a@E
01TG600K5aP05a@E01<A4P0G51D0510A01<A4P0J5aP06aLH01HE4`0C51000P0D5A00100E5Q4061TD
01XK5P0I6QD201PI500d01TJ5@0H6A@061TD01`H5`0L6aT07ahL02<R800U9B<09RHT01PH5P0];b`0
E5IC01HH5@0@5A407R<O01DL700O:2L04Q/J028[:P0?61L05b0O01DN7@0H8B006B8Q01LP7`0E7Qd0
5a`N01XN8@0K7b80720R01dQ8P0M8B007R8Q01dQ800K81`06b0K01hS7@0Q9R009R`Z028Z;00T;B`0
6R@P01HQ6`0P:b<0934X028_9P0N;BH08S4/01l^:`0N;2`08Bla02Db>0<09c@j00<0:STn02hm@@0a
@4<00P0`@T@0400eAdT0=DU:0394B00cADT0=DM903E7A`0cADD0<DE303Q>C00N=380?U=F092W[@18
GfD0=TeE04III`0lCed2041CH@0P04YLJP0nD5h0D61_04IFI@1AGfl0C5UY04YGI`17E6@0@e=P04EG
H`17FFD0BE]W04aNJP1:G6H0BeeW04aNJ01>HFP0BUeT04MJH@15F5d0BUaN04iPH019Fe/0AUQH04UL
F`1;GU`0C5mM051SH@1CIV@0@eIB069eL@1JKFT4061`L005069bLP1SLg<0I7Ad06]kN`1/O7`00P1X
N7P0501/O7`0JWYj06]kN`1/O7`0Kgmo07>2PP1ePh@0MX6307V4QP1lQhT0P8Z<08>=S`25Si40Phn?
08JBTP28U9@0RYBE08fGV02@VY/0WZJX0P2CVid0302EVYd0V9fP09bRXP2GWIX0V9bK09VMW02KWih0
YZNY0:j_/@2XZJ/0[Jba0;2_]080/[6f01H0/[6g0;6c^`2g^/<0]KS10;6a^@2i^<00`L360;Bc^@2^
[;40];:g0;Vg_034`/L0`[o60<_8dP37a<l0a<7<0<K2d03<a]@0c<KE0<_4e03=a=L0c/GH0P3=a=L0
8@3Cb]`0d/WJ0<W0d@32^L/0a;_<0<JmcP36`<d0`[c60;^h_`2j^;X0]kJb0:f^Z02TYIh0VIZB09nP
V02c]:`0XZFJ08R;P01_LfH0IVaN069XFP1LHe@0GfQG06QaH01]MFD0Jg=T06A/G@1GHE80GfYL069]
G`1VLF@0K7Q/06EcIP0205i[H@0/06EbJ@1[MW00IG1/06EaK@1YMG<0Ig=a06EdL@1RL700IG=c05m_
KP1HJ6P0EfMW051PG`0lBD00>dPn04MDBP18Dd/0AE1804MBBP0kA3l0@DY503]1?`0c>CT0>T1003Lm
?@0_=3L0=3Tl02db=@0`=SH0;C<c02`b<00a=cD0;cDa03@j=P0]=2d0<CPa02L`:`0/=c<0:cLe02Te
<`0/>3H0<3`j02Xf=00/>3H302/g=@13030l>P0iADD0<3/m02@_<P0T;c40:S@e02Tc<`0X<bl08R/X
01lY8P0Q:b<08RTQ028Z800Z<BX09c0_01TQ8P0R:bP0:c@a02@^9`0O:B405R0H01lY8P0N9b8031DD
03@m?@0Y;bl07b<R01DI600U:BP0B4a;028V9`0Y;Bh08bLZ010D5`0c=cX07B0U01/N8`0B5QT07b4O
02`^:`1YJfP08B<P010B3`0U9b@05aTF01PJ5`0I6aP06adJ01`N6`0M7a`06a/I024Q7`0V9R@071`J
01LG5@0>3P`06a/I00D50`0C4a402@T701lO7@1eMG<09bHT01/J600P7ad0<S4_00d<2P0201@C4@0B
01dL6P0L6aT051<A01TH5P0D4Q006ADD01LC4P0E4A00510?01DA400G4a806QHE01@@3`0G4a806ADD
01<?3P0F4Q00510=0P0E4@h08@0D40d04Ph;014=2P0E4@h02PH3020L6@0810402`L401hJ600B3Pd0
71PG00X61P0@30/040`9010=200D4@`03P/601LD3@0M6Q<02`P4010;20080`006QDB010;200B3@X0
4`h;00l:1`0E40d05Q4>010;200I514050l<010<2@05014=2P0<010<2@0?2`P03`/8014=2P0B3P/0
4@d:00h91@0H4`l04@`802DP7025P7`0;2LS0P0A30P2010;1`803`X60P0=20@01P0>2@D03`X6014<
200C3PX04Pd9014<20803`X600L04@`8018=2@0?1`D04@L601@:2@0G3@`05@/:008040H500L04`T8
01D;2P0D2PT050X901@<2P0A30T03`X700803@P500D03`X7014<2@080`002PD200h91P03018=2P08
01H<2`0>10<03P@301061@0J40l091XI01061@0B20L201<9200601061@0>1P@03@H6014;2`0F4100
50h>0P0<1PH01`0>20P030H600/51@0<1PH03@L700h8200C2@X00P0D2P/02@0C2@X04@L800l51P0B
20T040H701882@0C2@X04PP901872P0601872`0501462P0C20`04`P<01<8300A1PX00P0B1`/20146
2P0@01872`0C20`040D901T>4P0700004`P<01@93@0@1@T02`4301X@4@0=0`@050X;05E;C019?d00
6@l@01061`803`D601@040H70147200?1@H0200001<92P0F30d03`D600X10@0;0@803`D605U?D021
MgP04PP901@:2`1?AD@07A<B01P>3@0E2`X06@l>01<920H04@L600`04`T:01L=3P0@1PL040H701X@
4@0A1`P040H701882@0D2P/04PP901<92P0G3@h<01061`0<01471P0@1PD040H501881`0G3@`06Q0?
01@:2@0E2`X04`T801061@0?1@@040H55?ooool001_ooooo1P0B30`0200H4Q805a4A014;2`0:10@0
30H601<=3@0A2`/04P`<0P0C3@d01@0B30`04@/;00l92@0@2PX04@/;00804P`<00d04`d=01<?3P07
0`80510?00l;2P0:1PD00`0000`81`0B3Pd03@T801XF5@0E4A003@T800803`/:00H040`;018>3@0B
3Pd04`l>00T51@0:1PD201@@3`0P01<?3P0?2`X040`;018>3@0@30/03@T800h:2@0B3Pd0510?018>
3@0A3@`040`;00l;2P0A3@`040`;00h:2@0=2@P03PX9010<2`0C3`h04@d<00l;2P0:1PD03@T8018>
3@0@30/04@d<018>3@0@30/030P700h:2@0B3Pd301@@3`0A018>3@0A3@`040d=00/92P091`P030X;
01XH6@0D4Q<03@`<01TG600F51D040h?00l=3P0D4Q<0514A00l;2P0B3Pd00P0D40l0200E4A0040`;
018>3@0C3`h04Ph=014=300C3`h03`h<0`0@3`d2014@3P0300d<2P0>3@/040l=00<040l=00@04@d<
01LC4P0S7ah07QXI0P0E4A006`0G4a80510?01@@3`0D40l04`l>01HB400D3``05A0<01@?300@30T0
4@d;01<?3P0P7ad03Ph=01LG5`1?DE00F5YI00/=2P0>3P`04Q4=01HE4@0D4`l04Q4=01PG4`0?3PX0
4a8>01@C3`0201<B3P0=01@C3`0?3PT06aXF00`;1`0Q81`05A@A01LF500D4a403`h=01XH6@0E4a@0
=cDf092>S`0501DA4P0401HB4`0I5AH05A4B01HB4`806QHG00P06ADD01HF4@0F5a805QLB01DF4@0G
61<06AXE01XK5P8061TD02006AXE01PI500F5a806aLF01XI5`0K6QP07QdK01hN700O7ad06ATG01DG
500^<2d05QPE01@I5@0F71X05AdL00PA400<5A@08b`[014J6@0C71/051dL01PQ800J8b805b0O01<L
6`0E71d06QhQ01/O8P0M8B<0720Q01`P7`807R8Q01`0724M01XO6P0M8Q`07b@N01lW900O9bT09c0_
01hX9@0G8Q`082dT02Ld:`0U<RT08C0Y02@c;P0R<Bh08Bl_02Le=`0Y=S`0:3Dk02Hc>@0X=C/0:STn
02`k?`0^?D00;T1202m1@`0a@dD0=TY;0P0eAd/0700eAdT0=4I603=5A@0aAD<0<dU703E;B@0Z?d80
=4]A0358CP0jDET0@EMT051SL@1ZOH/0@UES04]NK012E680@E=Q03i@GP19FFP0?DeL04ICH`17EFD0
A5IR04IHI019FfL0BUaX04]MJ@1:G6H204aNJ00;04ePI`1<GfH0BUeT04MJG`1<GV00C5iN04QJFP16
F5P0BEaK04ePGP1>HEl00P1FJFL01P13EU80EfYV05]^JP1NKVh0Gfm_061`L080HG5a0P1RLW80101W
MgL0J7Qh06IfMP1VMWH206UiN@0f06YjNP1/O7`0KWin07:1PP1ePh@0Mh:407V4QP1mR8X0PH^=08F?
T@28TY@0Phn?08NCT`29UID0RiFF08jHV@2@VY/0SiNI08fEU`2?UiT0TYNJ09fRY@2W[Jd0W::O09JJ
V@2GViX0V9bK09jOX@2TYJL0[:f_0:j]/P2_[[<0/:nd0:j]/P2/[K80[[2h0;Bg`02c][l0/k>k0;nn
a038ald0^;Nm0:bZ[`2a[k@0][Bi0<2n``2l^L00_Kc50;bia02j]l80`[k<0<_5d`3:a=<0b/?C1P3;
`]D05039`=<0b;oB0<_2e@36_m40`[c;0;nla@2j]kh0][Bf0;Je/@2_/:/0XjBM09BES@2TYId0Z:ZQ
09BGSP2;SX<0LgQ/071fJ01]LfD0JW5R0P1WL5l02@1UKEd0GVIG05YRD`1JHeD0HfiP06A_H@1WLVD0
K7Q/06MeJ00205m/HP0:06IcJP1^NG<0Ig9^06A`K01XM780Ig=a06EdL@1RL700I79b05e]K080EFEU
05<0D61P04ADBP16DdT0@4e304A?A`13CTH0;cXb03Ho>P0Z<bh0;C<a034g=`0k@D40;S@d04=8B`12
AdX0<cPk03<i>@0/<S808BLU02H/:00]<bl0=C`f02T`:@0`=c009c0[02lj=P0_>cT0:cLe02di=`0a
?C/0;CTg03A0?P0[=cD0:3@b02Te<`0[=cD0;c/k02hi>`0`>ch0=3m1038l?@0T;Rh07RTU020Y9P0O
:B808R`T024X800N9A`08RTR01<L6`0L92D08BXW02</:@0P:R<05AlG01XT700G8AX07bPS018K6P1]
MWH0Mgn101lS8`0N8R407b<R02<W9P052@X0<CDf01dQ900F6Qd09RX]020S:00H6b0061`O01LI5`0W
:BH0<38_01hP7@0O8Ah05ALD01LI5P0H6QL06A/H01/M6P0201`N6`0J01LG5@0N7Q`09bLU01lO7@0K
6aT051@B010@3P0O7ad08R8P02<S8@0A4@l05aLE00d<2P0K6QP061LE03ln?00X9bD05QDC01/J600E
518020L600h=2`0Q81h04Pl>01LC4P0F4Q4201DA400[01HB4@0E4A005Q8A00l;2P0F4Q406aLF01DA
400G4a405a<@01TE4P0J5Q<05a<@01@@3@0F4Pl06aLD00T50P0C3``030P502/W900U8Al04`l>01@@
3`0P71/06QHE018>2`0D4@`030T401<@2`0E4P/03@X301DB2`0@2`P02`H301LB3`0I51403PT6018=
2P0A30T040/8018=2P0400004Pd:01@?3003010<2@<04@d:00<04`l<014=2P0?2`P00P0?2`P02P0<
20D04`h:00h91@0;1P803PT503`g<`0E40`040/7018=2@0A30P200l:1P03010;1`0>2@D03PT50080
3PT500@040/7014<200B3@T04@`80P0@2`L01@0A30P04Pd901D;2P0C2@P05P`;00806@l>00@050X9
01471P0D2PT05@/:0P0D2PT00`0D30X04PX800l:1`0200h91P0500l:1`0@2`P04Pd:01<>2`0B3@X0
0P0?2PL02@0A30T04`T800l5100A1`H04PP701H<2`0L4Q4040H501<9200201D;2P0801881`0@20H0
40P901<=3@0J51@05a4A00l92@0>20P200l92@8040X:0P0>20P0100E2``050X;01<92P0B20T20147
200901882@0@1PL04`T:01882@0@1PL04@H901052@0B1`/04`P<00<04@H:0P0B1`/0600C20`04PL;
01872`0A1PX040D900l4200@1@T04@H:01052@0;0P@060dA00d21P0A1PX05``@01<8300>0`H05P`=
01882@0D2P/0?cDf03D[;00?1@H04@L801061`804@L801<04PP901hD5@0D2P/04PP90147200C2@X0
5`d>020F5`0700003PH601T?400C2@X05@/<02LM700:00004@L600`20@0700003PD500H04@L600H0
4@L801882@0@1PL04@L801@:2`0>10D20147200401882@0C2@X05P`=01dC50`040H70P0A1`H30106
1@0701471P0E2`X05P`;01@:2@0A1`H03`D401061@0Dooooo`006oooool00`0D30h04`d>01<=3@03
01<=3@0802@N7P0E3`l04Pd<018=300G4Q803PT8014;2`0B30`201@>3P03018<300A2`/04P`<00@0
4@`:00d04@/:03lk>P0A3@d02@D401@@3`0B3Pd04`l>01dI600J5QD05A4@00`81`0G4a803@T80080
4@d<0P0@30/0100?2`X040`;018>3@0=2@P201@@3`03014=300C3`h03PX900804@d<00D04Ph=014=
300?2`X0510?014=3002010<2`03014=300B3Pd04Ph=00<04`l>00D04Ph=01<?3P0<20L030P701<?
3P0201@@3`8040`;00<03`/:010<2`0B3Pd00`0C3`h301@@3`0701<?3P0@3@d04@l@00d;300A3a00
4a4B00`:2`0200h<3@0A00l=3P0B41404@l@00l=3P0A3Ph04Ph=014=300@30/04@d<01<?3P0A3@`0
4Ph=01<?3P0@30/03`/:010<2`0B4@l00`0C4Q00100B4@l04A0>014@3P0@3`d300l>3008014@3P0A
3@`04Ph=01TE500J5QD0510?018>3@0F4Q42014=300A018>3@0?2`X04`l=01D@3@0G4@d05Q4>01@@
3@0F4Q006QHD00X91`0F5A<02`/:03Hg=@0D5QD06Q`I01<C4@0A40`00P0E51001@0?3PX04Q4=00l>
2P0C4Ph05A@@00<04a8>01404A0;014@300G5Q8051<?00d<2P0@3`d051<A01HE500P7Ql06QPI014?
400M6a`081`M01/F5`0C3Q004Pd?01HA4`0201XE5`0D01TD5@0H4a@06QDF01/F5P0K5aH05aPB01HG
4P0E5Q005aPB020Q6`0V9b4061TD01HG4@0H6A<071dG01/L5`0I6QD061HD01LG5@0H61H201TI5`0;
01TJ5`0J6aP05ALD01<E4P0H6QL061dI01HL6@19DE008RX[05mXJ00N9RP00P0E7Al0:@0H82806B4S
01XR8`0G82005QlO01TN800L82<07b4T01lS900O8b<07R8R01hR8@0P9B008BHR028W8P0P9Al07R<L
01lW8`0I8b@06bDT01lY9P0S;RT09C8Z028_9`0Q;bP07RdW02@b;`0T<c4093@c03I4B00fA4/0:3Dk
02Xh?@0b@4D0;Ca102dm@@0_@D<0;Cm102m2A00aADH0<DE50080<dE801T0<TA60355A00aAD@0<dM5
03I;B@0fBd/0>De@03U?E00mDUT0?59J03U?F`0hCUX0IGZ604QMJP11EF<0>TeK04MJJ00oDV00AEMU
03i@GP10DF00BeaZ04=EHP14EV80BE]W0080BeeY00@0CV1Z051RK01=H6P0CF1W0P1BIF`01P1<Gf@0
DF=S04ePGP1;GU`0BUeK04ePGP80DfIT00P0E6MU05Q[J@1FJFH0EFQU05MZI`1JJVT0GFe]061`L080
HG5a00D0H71`06=cL`1TM7@0IWIf06QhN00206UiN@0Q06]kO01/O7d0KWeo0720P01dPh<0MhF507R4
Q@1kQXL0OhZ<08B>T029TiD0RiFG08>?T027Ti@0RiJG08fGV@2?VI/0TI^L092HVP2<U9H0SIFG092E
U`2GW9h0WjFU09JLV@2FViL0TIJB0:N[ZP2i^kX0/;:b0:RYZ`2ZZZh0ZZZ_0080[:^`01L0[:fb0:ja
^02/[kH0[[6h0;Bd_02f]k`0]KJk0;:a]`2^[K80/[:e0;2^/P2h][T0^;Jj0;Bc^`2c/K/0/K2i0;^i
a@32_//0a<3>0<W4d`39`]<0b<7B0<Nod@020<NodP0h0<S0dP35_M00`kc>0<O1dP32_Ld0^[G40;^i
`P2h][d0/;2a0:j^Z`2WZ:@0WYnJ09NHTP2MX9X0T9>;08R;P@27SH80MWa_07=iK01]MFL0KGEV06]c
I01SKUl0H6UK05mWF@1PJe`0JWEV06QcI@1YMFL0KWY/06mkK`1_OG00J7E[06EbJ01[N6h0JGM`06=`
K01TLFl0JGId06EcL01OKFd0FfUY05aZJP1EIFD0Cf1P05=TI01DI6@0BUU?04QEB@13CdD0A4m603E0
=`0d?CH0?4E002H_:P0nA48202hd=01402L/;`0X;Bl0:Bh`024V:00Z<300:c4`02X`;P0^=3009B/W
030g<@0Z<BX0:2lX02dg<00b?CT0=D4o02hj>00[=cD0<3`j038n?00^>SP0:cLf038n?@0c?ch0:cLf
02/g=`0X<cD09S4e02Lb=00W<C409S0^02`g<P0X<R`09BlW02D^9P0R:B407B@K020W800M9R@07BDU
01/T8@0J8al072DN01hX7`0K9Ad06b<M02H]:P0I81l08BPY01hT9`0P92<08bLV01TM700]<C40;30a
06IZJ`0o@dD0A4Q:01@H6P0L7b<04QDI024U9`0K7A/05QPE01/M6P0M7a`05aTF01TK600K7AX201XL
6@0801TK600H6QL061XG01PH5P0G5aD07QhL01LG5@0J6QP301TI5`804Q8@00<061PF01LG5@0I61H0
0P0G5Q@201HE4`804a8@00H051<A04E4@P0E51803Pd;01LE4`0H51<201TE500<01LC4P0F4Q406ADD
028N7@0M6AP06aLF01PD4`0D3`h06ADC01LC400F4Pl0510=0P0C3``0200D40d05Q8?01PD4@0@30T0
6QHC010<2@0d<2h07QXI0P0@30/0500@30`0510>01<@2`0C40/061D@00d:100>2`L05A8<00h91P0E
40d03PT601LB3`0D3``04`h;01D@3@0?2PL07QTF00d81P0D3``04@`90P0?2`P2010<2@<04@d:0P0@
30T00`0C3``05A4>01@@3@0201<>2P0501<=2@0C3PX04Pd901@?2`0?2PH00P0B3@T00`0?2PH03PT5
014<2002014<208040/70P0A30P09@0?2PH04@`8018=2@0B3@T04@`800l:1P0D2`X040L501071P0F
30/060h=01<:200D2PT05P`;01H=2`0D2PT04`T801<;2@0@20H040X8014<2@0B2`T040X800h91P0F
3`d06aDB01HA3P0>2@H050d;01/D4P0G3@`04PP701@:2@0B20L03P@401071P0C2@P00P0A1`H02@0B
20L050X901@<2P0@20P03PP8018<300@2PX03@L7010:2P0200l92@0600h8200=1`L030H600/61P0G
3@h04`T:0P0A1`P0200B20T050X;0147200@1PL050X;0147200?1@H04`T<0P0@1PT0100H3Q406a4D
01@:3@0@1@T601872`0D01062@0@1@T050T=01D:3P0A1PX03`@800h41`0D2@d040D901D:3P0=0`H0
5@/=00/10P0J41404`T:00d3100J414040H701<92P0B20T201<92P0501@:2`0Y7b006a4B01<:2`0@
1`L00P0B20T02`0=10@05`d>01D<300R61T09A/L01<:2P0D2PT05`d<0188200A1`H060h=00L04@L6
00`04PP900l51P0F30d060h?01061`0?1@H04PP901061`0?1@H040H701882@0C2@X<01061`0500l5
100A1`H04PP701881`0A1`H00P0?1@@01@0B20L04@L601061@0A1`H04PP701Cooooo000Kooooo`0K
01<83P0D2`l05@`?01@;3P0B2Pd03`T;014=30091@D07A`H01DD400@3`/01@@000d71`0E30d04`X;
01<;2@0H40h050`:01TA3`0C2`P0610=01491P0D30T06A@@024M6`0L61L04`l>008040`;01D02`L6
01DA400F4Q403@T800X61@0D40l06ADD010:2P0C3@d04@/;00h8200B30`05Q0@018<300C3@d04P`<
014;2`0C3@d05@l?00l;2P0A3@`00P0B3Pd05`0?2`X03PX900h:2@0=2@P03`/:01<?3P0B3Pd05A4@
00/71P0E4A007a/J00T5100?2`X05A4@010<2`0J5QD04@d<00`81`0C3`h030P700h:2@0@30/04Ph=
00804`l>01@04@d<00l;2P0A3@`04`l>010<2`0>2PT03`/:01<?3P0F4Q404Ph=00h:2@0A3@`05a<B
00P40`0P71/02@D4020L6`0?2`X0510?01<?3P803`/:00L040`;014=300O6aX020@3014=300:1PD0
5a<B008040`;00D04`l>014=300>2PT04Ph=01DA400200d9200400l;2P0@30/04@d<01<?3PD04`l@
0P0C3`h02P0M6AP0510=01@@3@060P003PX7014@300C4Ph051<?00l>2@0A3PT201<@2`0I014@2`0?
40/0414<01<D400E5A<04A0>02<O7P0O6aX05a<B01DA400C3`h04Ph=01@@3`0F4Q405a<B01PD4`0F
5A405A@?010A2@0W:2003a0:018C3@0K71L05AHA01<D3`02010@3P0L01LG5@0M7A/0[J^/024O800C
4A805A<D01<B4@0E51804a8@01HE4`0J6AD05QDB01DD400I6QD061TD01TK600C5A004Q@@02d_;01V
J6<06Q`H018D4@0G6A@05aTE014C400C5A0071hI01PJ5@805aTD01`06A/F01TN600Q9Al04aPB018G
4@0I7QP06b0J01TN600I7a/06AlM020V900I7al0724T01XO8P0H7B0061hN01LM700F71X06AlK01`P
700L7QT07QlJ01lQ700Q8ah082DO01dR700E6Q<08BPQ0P0P9al0600U;2@05alK02<];P0Q:b`072LV
02di=`1aOGd0934a02<a<P0M:b`0;3/m01TX:`0O;S40?diD03A5C00S<ST09cLm02Li?@0U=c/0:S`o
02i0@P0`@T@0<49302m1@@80<D=30100=DM703a?CP0aA480=4M50394A00cADL0@UIG04AFF@0lCe<0
>4]A03mBF00eB4l0<TA>03Y<EP11Del0?DmK0`0nD5`09@11E680AUUW04YMJ`1>HG00AeYY04MJJ015
F6L0BUe[055UL01HJW@0DVE/04ePI`1CI6/0FFYa059TJ01=Gf<0CEmO04]MG@1=Gel0DVAT05IXJ01E
IfL0CEmO05=UI@19Fe/0DfEU05U/J`1JKF/0Hg=b05m_KP1[NgX0GFe/05a/J`1XN7L0Hg=b06IfM@1Y
NGP00P1XN7L0>@1YNGT0IgIm06imQ01cPXL0Lh:507>2PP1dPh00NhN5075mN`20S8`0SiVK08>=T02B
Vj80R9>I08B>U`29U9X0RiBJ096JW`2KYJL0U9bN08VBT@2:Ti80UYbK09BJV02?UI<0TiNF09FIV02J
WYd0a/[;0?_oo`35bL`0X:BW0:BW[02WZZl0Zjfb0:b]/P2Z[K80ZZfe0:ja^P2a];d0/[Fl0;6b]`2_
/;D0/:nd0:f][`2][Jd0ZZRZ0:ZXZ@2_[Jh0/K2d0;2_]@2/Zk40/k:h0;bk``2l^l@0_K_60;nkb@02
0<2lbP060<6mc031_/X0^k[20;Vg`P2l^l@0]kJn0P2e];`01@2a/[L0/;6e0:n`/`2WZ:X0WIjP0080
U9BF01l0Ti>A096CS024R7X0MWe]075hIP1UK5X0I6eJ06E^GP1WKf80J71U06A/I01NJ600IFmV07Eo
M@1]N6X0JGEW06ikJP1ULF<0GfeP06MgK01]OG<0JWUb06QiL`1VMg40HgA^065aKP1NKV/0FFUV05IV
H`1IJFH0DV1P0080D5iN0240CU]J04E@BP1;EDd0?TQ003Dn>@0Y<Rd0=3di02H_;00b>cP0;CHe01hW
9P0_>3L09Bh^02D^:`0T;BP0:34^02df<`0/=C809Bh[02Xc<00V;b`09c0]02`e<P0^=cD0=Cln03Q4
@P0/>cP0BEQE030o?00V=C<0<3hn02Xh>00^?3`00P0b@440800_?Ch0;CPj01hY;@0Z=3D082XY02Xc
;P0I8aT0>D@f0459>P0f?S00:2hT024V7`0N8ah082HR01LP6`0J91l06B8M01LQ6@0K91`08RTR01LM
6@0Q9R807B4P01`N7@0O8B407R0O028T8P0S9B8092HS028T8@0N81l071hM0P0O8B001@0M7ah06adL
01`N7@0N81l06a/I008061PF02L07QhL01dM6`0I6AL05QHD02@T8P0F5Q@07QhL01@D4P0J6QP07A`J
01`K6@0:2@L07QdK01<B400I61H071/I00d<2P0@3`d06aXH01XI5`0F5A<061LC01DD400D4`l05A@@
01LF4P0E51003`h:01HE4@0d<bl08b8N00l>2P0E51406APF00/:200J6AL05A@B01LC4P0H4a800`0I
4a<01`0G4A4060l@01@?3P0B3P/0JFER024M6P0L61D00P0F4Pl2018>2`0K01LC400H5140510=018>
2`0D40d04@d:00`81@0>2PL04@d:018>2`0C3``04@d:00l;200@3@P040`901<>2`080P804`d=01TC
4`0B30`05A0=01<>2P0D3`/05A0<01@?2`0C3PP04@`800<04`h:00d04Pd9014<200A30P040/701<>
2P0?2PH040/701@?2`0=20@04`/901H>300D2`X07aLE00804PX800`03@P5018>2`0U8Ah08QhK00d9
200<20D06A@@00L2000@2`L050l;00`70`0C3PX6010;1`0F010;200A2`P040/8018:200A2`P040/8
01L?3@0F3`d04Pd:018:200@2@L050`:01H>300C2PP04@T701@:2@0C2PP03PH401D;2P0D2`X04PX8
01<:208050X900h06Q0?01@:2@0@1PD040H501@:2@0F30/050X901881`0>10<04@L601D;2P0B2PP0
4`d:014<2@8040/800D03`T900h8200?2@T03PP:00d72@0200h82P0R00l92`0B1`/04@H:01462P0B
1`/04`P<01@93@0?10P04@H:02HK7`0H3A40304500l72P0E4A8020@5081kO@28PX@06aDG01482`0>
1@P03`@801@8300A1@T040@800d41P0I4a<03PD601D<3@0V7Ah01P000107200B20T040H701051P80
40@601<04@H801<9200A1`H04PP701`B4@0I3`h04PP701<9200D2PT04`T801061@0=0`803P@300l5
100E2`X050X900d30P0>10<04PP700804`T80P0@1PD01`0C2@P04PP600d40009000040H401H<2P0A
1`D00P0A1`H02P0A1`P050X;01T?400A20P01`0001T?3P0]8b807A<B00l5100@1PD200l510050147
1P0@1PD03`D400d30P0A1`H00P0@1PD05@0?1@@040H501471P07000060h=00/1001;@D0040H601<9
200H3Pd030<201L=300A1`H030@300X0000F30/01`0001T?3P0A1`H06a4@00L0000Dooooo`006ooo
ool0800C20h050X@01D<3`0D2`h04P/=010:2P0;1`H06QPD00d<20041@002@X7020O6`0<1PH050/<
01482@0B2PP05Ph<01491`0E3@X040T401<<1P0G40X03`P200@0000G4Q005A4@00l;2P0@30/04Ph=
00l;2P0A3@`05A4@0`0C3`h0100@30/050h>014;2`0@2PX3014;2`8030H600@03@L700l92@0?2@T0
3`T90P0@30/2014=300C010<2`0?2`X04Ph=01<?3P0D40l04`l>010<2`0=2@P061@C01@@3`0e<C00
;2PW00L30P0B3Pd030P7010<2`0B3Pd01`<200`81`04018>3@0I014=300@30/04@d<010<2`0?2`X0
510?01DA400B3Pd040`;018>3@0D40l04Ph=00l;2P0A3@`030P802<O7P1RGUd0:bLV00/71P0810<0
8alN01`H5`0C3`h03`/:010<2`02014=300<00D1000E4A004Ph=01XF5@0>2PT040`;01@@3`0C3`h0
40`;01<?3P0E4A003`/:0P0@30/2014=3003018>3@0B3Pl04Ph?00<04Ph?01H04Ph=010<2`0A3@`0
4@d:00D1000L61D061D@00l>2P0@4@`04Q<>010?2P0A3`T05A8;01<@2@0B40X040l:014@300C50l0
5QDA00l;2P0G4a805Q8A0P0E4A00:`0=2@P04`l>01DA400E4A005Q8A01DA400C4Ph051<>01<D300T
9Ad051D=01<D3@0C50h03a0;01/L5`0H6A@05ADC01LG5@0B4Q00=3@d010@400Q8B407AdM01DE500?
3`d05aLE01LH4`0I6QD05QLB01HG4@0L7AL0418?00X<2@0A4a006Q`I014C400S9B804aDB01HH5@0E
5a@07AlL01hP7@0E5a@00P0D6A<0:`0E6Q@061dG01`Q6`0M8Q`05a`F01HK5@0D6A<04aPB01DJ500F
6aD05ahG00<91@0H7QX06AlO01TN8@0G71l061dP01PN7P0G7A/05adI01TP6@0M8A/07b0J020Q6`0Q
8ad08bHO028W800W;2D06AhG01/R6P0O9Qh06b8J02<Z8P0M9b<06bDV014K700W<S808bl_03Y5A`0O
;2h09S@g02Th>`0V=CT00P0d@dP0J@0iBDl0<T=:02Df?@0[?480;3i202/m@@0]?d80;Cm102m1@`0^
@440;Clo0312@P0kCT`0=DQ602m2@00bAD<0<4=103Y<C00a@dD0@UAF03mAD`0jC500?DmC03mAE@13
E5`0A5EM03e>F00kC5H0A5EO04MII@13EF40@UAP041CH@12EF<0AEQV04MMJ`12F6H0@EMU04QKJP1?
HW00DFE`05EWLP1CIVd0Cf9Y05=TJ`1HJVh0DVAX04eOHP19Fed0B5YJ04YLG01>H600DVAT055SH`1I
Jf/0G6i^059TI01HJVX0EfUY05U[J`1JJVT0IgMf08BDT`1gQhH0IGEd05i^K@1UMG@0Hg=b069bL@1Y
NGP0LH6006alO01XMgh0KGb40760Q@1aPH40LH5o07>2O`1dP7`0NXJ407N3P`21Rhd0PhbB08N@V@28
TY/0QY2J08^EWP2;U9X0SIJK09BNX02@VIT0RiBC08jGU02FW9T0TINC08bBSP2HW9/0TiNF09FIV02`
];D0dMGH0:Z^/@2RYZT0Y:N/0:NZ[`020:V//@0F0:V//`2XZk@0[:nh0:nb^`2`/kX0[k2e0:f^/`2W
YjX0YZJX0:RXZ02VY:D0Z:NU0:f/ZP2_[k40[jjc0:^Z[`2a/;D0^KRn0;Vh_`2j^L40^kW40;bjaP80
_;[700D0_[g70;Vj_`2e][/0]kRm0;>d^@020;:c^00N0:n`]@2][[80ZZ^_0::SY`2KW:00Ti>H0:2O
Y027QhL0Rhf608N;O@24RgT0JW9L06M_F01TKEX0JG5Q06mgK01_MVh0JG5[061YI01UKVT0LWac06Uc
J01ULF<0IG9Q05aXFP1MJeh0IWI/06]kL@1XN7<0GVmY0P1KKVP205a_J`1505][J01FIV<0EVIS059P
H01AGel0C5YJ049>C@0mAT40<cde03Y3?P0g@3/0;3D`02H_;00nAd@0@4U601PQ800V;bh0>T=202lg
>00[=2l0;3H^02hg<P0`>C@0;cPc02/d<@0b>cP0;SLd030i>00b>cX0<SXk03Do@00[=cD0;chk04YI
EP0eA440;3/i02<a<@0Z>3T0;3Xk02dk?00/>Sd0:SPk02Pf>@0_>3d0:38c020[9`0b?3<0:3<T04MB
@@2LYI80NH5a03m5>@0a=Rl07b<Q01HL6P0J91`06bHM01/U7@0J91`07BDO020V8P0N8al09BPV024S
8P0P82008R8R01hN7P0P8Ql07b4N00807R0M0P0M7a`00`0O8Ah0828O01lQ7P0201dO700W01hP7@0M
7A/06QXH01`L6P0P81h07QhL01XJ600R8R00I6AR05MGE@0G5aD07alM00T91`0N7A/081lM02<R800J
6AL081lM010?3@0J6AL05aHD04m>C00l>cT06APF018A3`0H5a<05A@@01@C3`0E51005aHB01PG4`0B
4@d040l;020O6`0H5a<040l;04i=BP1PGed08B0N008040l=02H05Q8A01<>3@0D3Ph05@l?01L@400G
3Pl05Pd>01<=300n>SL0W9RE01hK6@060P005A4>01XF4`0C3``05Q8?01LC400D40d04`l<010<2@0=
2@H03`/801LC400L61D05a<@01/G500G4a0040`900`81@0A3@X061@A00l92@0i<c<0A3hn010:2P0;
1@D03`X701<>2P8050l;00<04`h8018=1`0B3@L00P0B3@T2014<208040/701@04@`8018=2@0@2`L0
40/701@?2`0>2@D08aTH00L0000E2`X0>30^00H0000B2PP06A@A018>3@2FTXl0THf:00d:200U8Ah0
9b8N01D@30804`h:00<03@P4010;1`0@2`L01@0@2`L6010;200700X50P0A30T03@P501<>2`0H4a00
5a8?01D;2P0201881`8050X900@04@L601881`0B20L04PP70`0C2@P00`0G3@`050X901<920030188
1`0701`B4@0I3`h04`T801881`0C2@P03`L500l91@0300h91P803PP800<03`T900h82P0=1`T00P0>
20X02P0?2@/04PL;01462P0A1PX04PL;01<8300D2@d05@X>00/0100E2Ph201052@0:01D?4@0=2``0
2PP904E2@`10?3d04@/=018;3@0@1`X04@H:01@8308040@800H06a4C00@0000B30`03@H600H0000F
3@h201@:2`0=01<92P0C20T04`L901@82P0D2@T04`T801471P0B20L06Q0?01L=300@1PD04@L60188
1`0301<9200401471P0@1PD04@L601<9208050X901X03@<200h40`0?1@@03@<200h40`0A1`H03`D3
01<:1@0E30L03`D300d30@0?1@<06@l>01881`0A20T02@0000L0000o=CH03`D401H<2`0K4A004PP7
00d30P0B20L040H501471P804`T800<04@L600h40`0A1`H00P0@1PD02@0?1@@040H501471P0R61L0
3PD501471P0j<2l060h=01@:2@0201881`0:01471P0=0`806Q0?01061@0B20L0DTQ700`20@0@1PD0
1`0001/A41Cooooo000Kooooo`0K01@93@0D2Ph050/=01@;3@0C30`04P`;018>300>2`P07QdH01@E
3`0<3@L04A0;014;2`0D2``04`X;01@<2P0E3@/04PX801@<2@0H40d04PX701<<1P0G40X06QDA01<>
300C3`h04@d<00804Ph=00P040`;018>3@0B3Pd040`;01<?3P0B3Pd030P701LA4@804@/;01<050h>
018<300?2@T04@/;010:2P0C3@d06A<C01H@400B30`04Ph=010<2`0?2`X040`;014=300B3Pd05A4@
01XF5@0I5A@04Ph=00803`/:00`05a<B00d9200I5AD081`K00l;2P0C3`h05A4@01PD4`0T81l05A4@
00`81`0E4A03014=30<04Ph=00P040`;00d9200@30/0510?01<?3P0A3@`04Ph=014=30<04Ph=00l0
4`l>00`81`0P71/03`/:01TE500?2`X061@C01XF5@0A3@`03PX9010<2`0B3Pd0510?014=300C3`h0
0`0D40l0100?2`X0510?01HB4@0C3`h201DA40804Ph=0`0C3`h00`0D40l04@d>014=3P03014=3P0=
014=300G4a8040`;01@@3@0T81d03`/801@A3@0@3@X040l;018@300C40/0514<01HC3P0201<@2`07
018@2`0C40d0518?01HC400E4A00510?01LC4P0201dI6003018>3@0D40l05A4@00805A4@00`0510?
014@300@3`X07QlG010A2@0A4P`06Q/E01`M5`0E5Q405QLB01<D3`0A4@l201<C4@0<00X:2P0J6QX0
4A4A014A4@0I6AP051@B01DE4`0D5A005aPC01HG4P0F5a406a`F0P0D5Q<03P0I6aP05QPE010B3`0K
7AX04Q@A01XL6@0F61D08B<P02@V8`0E5a@05AXD01HK5@0G71H06AhH0P0J7aT00`0H7AL08RLQ024V
800201PM5`0=01dR700J8AX05adI01`R7P0F71`07B8U01@I700I7R406R0P01TO7@0I7a/06R4J01lS
7@02024S7P0:02<U800T9R408bPR02H[9@0I7QP06B0I028Y8P0K8Q/07RPP01hX9@809Bl`00d08Rd^
02Pd=00O:R`0@4a?01/Y;00Y>3/08S4e02Lf>`0N;C80:SY002Lh?`0U=Sd0;3e30080:Sa000H0;d54
0312A00a@dD0<49302m1@@0a@d<203=6A00803iAC`1WNWP0@eID03I8B00eAdT0@59D03a>D00kCE42
03i@E00W045BFP1;G6@0A5EO03e>F018FF<0A5IR04YLJ017FFD0AEQV04MJJ018FfT0@eUW041FI00n
E680CF1_05IYM`1@I6l0E6Ia05AWKP1AI6/0DfA[05=UJ@1?HFD0BUaO04QJG019Fe/0BeeM04mQH@1A
Hf<0D69R059TI01DIVH0EFMW05]]K@1DIVH0Ffe]05e]K01LK6/0JGUh0080GVi]02T0HW9a05m_KP1W
MgH0Gfm^06MgMP1kRhX0M8B406akO`1_OX<0Kgj006inO@1`P7h0M8>007R4PP23Shl0QI2C092IW`2;
U9`0QHjG08RBV`29U9/0S9NL08^DV@2;U9P0SYRI08bEU02?V9H0TY^G09>JU@2?UI00S9:>09BHV02>
TY<0UYZK09jRX`2VZZd0X:BW0:BXZ`2UZ:d0YZV^0:NZ[`020:JY/0080:JY/P2Y[;D0Zjjg0:b_]P2/
[K80Zjba0::SYP2SXjD20:JVYP0:0:VXYP2_[Zd0/[:d0;6`]@2_[[<0/[6f0;Je^`2f]K`0][Fm0;Jd
_`80]kG002P0]kG20;Nf`02a/[L0[Jjc0:j_]02[[;40ZZ^`0:b]/P2/[K40Z:V]09jOX`2EUYX0TiBH
0:2QY@3?d=80ZJ^Z0863O01^LV@0OHAb06A/E`1QJE<0HfaI06]cI01aNFh0LG]b07EoN@1aNWH0KWMb
06]fK@1NJUh0FVII05]XFP1KJE/0H6eQ065aI`1QLFP0H71Z05e^J01JKFL0FVeY0P1KKVX00`1JJVL0
FFUV05=SH002051NGP0P04aJFP11CD`0<CXe03Do=`0kA3l0?TM20419A00V;b`08R/X02Tb;`0c?3/0
8BXY02Xc<P0f?cl0<S/f03<m=@0c?3L0;SLb02df<@0`>CH0;CHc02`e<P0b>cX0=Sln03<l?00d?Sl0
=40n02ln>`0a@3d09SDb030n?@0Z>3P202hl?@0M02dk?00/>Sd0:3Hi02Lc=`0[=3T0:cDf02Pc;`0Z
=2`0<ch`07f8M`3cn^/0]Kb]03Pn=00[<2T07R8O01lU8@0M9al06bHM01dW7`0O:B407bLQ01`R7P0S
:2@08bLT024S8P0S8b<08R8R01`L700T9R<00`0R92400`0S9B8092HS01lQ7P02024S800O01hP7@0M
7a`07R0M01`L6P0I6AL07AdK01hN700I6AL05ADC028R8027QhD0LG5_01/K6@0C4a406QXH024P7P0V
9B<09B@R04U8AP1gMW@05aHD020O7@0D4a40?C`j02TX9P0N7A/061LE01PG4`0E510051<?01DD4002
01LF4P0K01TH500D4`l04a8>01<B3P0A40`0=3<`040o?@0H5aD05A@B014@3P0E4A004Pd<01<=3@0E
3`l06A8B01T@4@0G3Pl05a8@00H20@0X9240510=01PD4@0B3P/04`l<01DA3P0H51405Q8?00804Ph;
00D05A4>01@@3@0D40d03`/800X71@02014=2P0;010<2@0B3P/04`l<018>2`0C3``071HF02TS8`0S
7Ad02P@401LA4@0F4@h00P0D3`/0100C3PX04@`6018=1`0C3PP3014<208040/701T03`X6018=2@0B
3@T04@`8010;1`0B3@T040/701L=300:0@409ahM04e5@`0H40l04@T800h91P0C3P`09b<P028N6`0B
3P`08QhK01/F4P0E40`030L300d8100D3`/04Pd900H040/71P0@2`P01`0<1`@04`h;00d81@0C3P/0
40/800d81P0C2@P00P0B20L01@0D2PT05@/:01@:2@0A1`H050X900805`d<00<05P`;01D;2P0C2@P0
0P0E2`X01@0D2PT040H500h40`0J40l060h=00804PP700H04`T800l71@0>20@03PT600l:1`0A30T2
018<300300l92@0>20X03@L900803PP:00H03`T;01872`0A1PX04@H:01872`0C20`201@93@0G01<8
300D2@d04@H:01872`0I4Q@02@L800h<3@0?3@d02`L801H@4P0D30l04`X=01872`0C20`040D90145
2@0@1PP05a4A00h92@0B2``040L800l7200C2@X00P0?1@H02@0@1@L04PH80186200C20T04`T80106
1@0A1`H05@/:01<9200401061@0901471P0B20L04PP701P>3@0C2@P03@<201@:2@0B20L03`D40080
40H500H03`D400h40`0B20H04`T701480`0@1`<200l50`0801881P0C2@P03@@401882@0E30d05`d>
0557B00C2@P201881`804`T80P0@1PD01P0B20L05P`;01H<2`0D2PT040H501471P8040H501D03`D4
01061@0A1`H01`0001T?3P0C2@P040H501D;2P0K4A002P4101H<2`0?1@@04@L602hT8`0M4a8081HE
08b2P@0F30/02@000188200;0@405?ooool001_ooooo0P0C2P/06P0D2``04P`<01<>2`0D3`/03``7
030^:@2n_[H0EeM?01@D300C4Pd03`T900h82@0>20P03@L700h91`0B3@X050l<00X6100G4Ph081/G
00h90`0D3`/0510>01<?3P0D40l04Ph=0P0>2PT0100G4a806aLF01DA400?2`X2010<2`0E018<300E
3`l05@l?018<300C3@d05@l?010:2P0>20P04P`<01TC4`0D3Ph03`T9018>3@0?2`X03PX900l;2P0A
3@`04Ph=014=300H51<05a<B008040`;00L03`/:00T5100K5aH04Ph=00h:2@0J5QD02`L600807QXI
00@06QHE01PD4`0<20L03PX90P0?2`X0100@30/04Ph=01@@3`0D40l201LC4P08014=300C3`h0510?
018>3@0A3@`03`/:014=300B3Pd2014=300;010<2`0O6aX04`l>01<?3P0D40l04Ph=00h:2@0?2`X0
4@d<018>3@0A3@`00P0C3`h02P0:1`H061@C00L30P0@30/03`/:01@@3`0F4Q40510?01HB4@0E4A02
010<2`04018>3@0D40l05A4@01LC4PD04`l@00T04`l>00<0000k=cH020@202hZ9`0300003@X501DA
3P0D40d00`0D3``00`0B3@X050l<01D@3@0201D@3@0;01DA3P0D40d04`l>01@@3`0G4a8061@C01HB
4@0D40l04`l>01@@3`0F4Q400P0G4a808`0E51004A0;00/<1@0L7AL08b@N01lP702l_KP0@44l01XJ
5`0I6AL06QXH00`<2`0F5QH051@D01PH600>3Ph061PH01/K6P0?3`d051@B01DF4@0K71L071dH01TJ
500K71H061XG00P:1`0F61D05aTF01/M6P0L7Q/061XG01@F4`0H6QL071hK00806A/H00L06QlI01TN
600I7QP05Q/E01<H4P0B5a405a`F00806QlI0P0G71H03@0I7QP06R4J01HL600G7AT082HV020U:00G
71l06AhQ01/Q8@0K8Al06R0L01/R6`0N8ad00P0P8Qd0<`0Q91l082DO024V800L8Q`092/T02L^9`0N
9Ql07bTQ024[8`0R:bP08B//06afM`1_NW/06BDU024/;P2GY:H0=D=601d/;`0X=c/0<3m401/Z;`0Y
>Cl0:3U002dnA@0a@TP0;3i202do@`0`@TD0<D=50394AP0a@d@0;d510353@`0jCD/0<dI40395@`1O
LW00>Da:03A6AP0kCDl0=TQ:03a>D00kCE40=TQ<03U;C`0lCED0?e1H04QIH`19FV@0A5EO045CG`02
03mAG@0:04EHIP1>HFl0CV5_04=II`15FfT0@eUW04mRL@1DIgD0Cf=^05EWLP80DFA[00P0D65X04]M
H@19Fel0AeUL04]MG`1>H600DF=S059TI080DfEU00H0D69R05IXJ01GJFT0G6i^05AVIP1KKFd205a/
J`0X06MgMP1NKVd0HW9a06=cLP1XN7L0PI6@0720O`1PL6l0IgMf06IfM@1`P800LH6106moOP1^OWd0
LX9o07N6P`20S8`0P8^<0;k9c@3FgnH0W:B^08bDW`28TiT0RIBH08NBU02:U9D0T9ZK09>MW02>UiD0
T9VF08nHT`2?UI00T9N@09:ITP2AUID0Si>D09^OX02KWj80W:2S0:>WZP<0XjJ[0140XjJ]0:BW[P2T
Yjh0YJVb0:N[]02X[;D0ZJbc0:R[/02WZZl0Z:V/0:RXZP2YZJT0YjNW0:VYY`2_[jl0/K2d0;2_]002
0;:a]P030;:a]`2d/kT0/k:h00<0/k:j00L0/k6l0;2_^@2ZZ[80Zjba0:n`]@2YZZl0Y:FY0080XZ>W
0240XZ>U09jOX@2LWIl0XJ:T0:^/[P2NWj40Si6@075eKP1mPgD0IFaL05iVE01SK5T0LW]X07EoL01b
O740MGmf07Z3OP1`NGH0Ig9/061[H`1MJEl0H6eS06=`I@1PKF<0GFeS05QXGP1GIUl0F6QR061`K@1L
Kf/0FVeY05U/J01GJVH00P1EIF80@`1AHEh0CeiK04aKF016EE80?d]803i7@P17DDT0=Chi051IE00V
;bX0<c`i02Xc<00a>SL0CeQG03M0?`0c?3/0:c<d03Dn>@0e?cL0<S/f02/d;`0Z<bh0<3Tf02df<`0/
=C80<c`k03Q1@00f?cl0>493030l>P0Y=C<0=T90034m>`0Y=C@0:SHf030k?@0c?T00=3m1038m@@0Z
=CT092lc02Pb=00P:R/0<C`h03M1>@0V<B@0=d8b06]cI01TJed082HL02P]9P0O8b007B<O01hX800K
9Ad072HN020W800N9Al061hJ028W8`0O8b008B<R02@V9@0R92<07R0O01`N6`0P8Ql00P0R92400`0N
81d071hK01`N6`0201hP7@806adJ00D071hK01hN700H61H071`J01/K6@0201DE4`0b02<S8@0I6AL0
3Ph<01TI5`0F5Q@09bLU01`K6@0M71X06QTG01/J600Y:2H05QDC01LF500S8R004a8@01PG5@0B4@l0
4a8@01PG4`0E510051<?01DD400G5Q8051<?01`K5`0J6AD051<?01HE4@0B4@d03`h;01LF500?3P`0
5A@B00L6100@30/05a8A01PB4P0I4a<06a@D01XA4P0H3a004`d<01dI5P0V8Ql04Ph;01TE4P0J5Q<0
4`l<01DA3P0C3``201DA3P0I01<?300F4Pl03`/800X60`0I5A8071PE00/71@0;1`@02PH3014=2P0E
4@h03`/800d91P0<1PH01@0001LA4@0E3`l04@/;010;2@0C3PX04Pd9014<200@2`D04@`601@?2@02
01<>2P05018=2@0A30P04@`8014<200B3@T00P0A30P2010;1`0C01<>2P0:0000718A01H<2`0E3@/0
6a<A01@<2P0B3@X03@P501`H5@0M6AH03`/801HB3`0<1`<04`h:00h91@0B3@T07APD01LB3P06010;
1`H040/800L04Pd:00h91P0D3``03@P500/71@080`004@L600<04`T800X050X901D;2P0A1`H05@/:
01P>3@0I3`h05`d<01H<2`0C2@P04PP70`0A1`H02`0B20L04@L601881`0?1@@04@L601@:2@0@20H0
40T6010;200A30T04`h;008050h>00<03`T900h82P0=1`T00P0>20X07`0?2@/04PL;01462P0A1PX0
4PL;01<8300D2@d04PL;01D:3P0=0PH03`@801T>4P0F3a403@T:00`82@0?2P/05@lA018<3P0@20/0
40L:00l62@0B20/04@H:01@93@0@1`T071HF020J6P0N5aL040L801L>3`0<10D00P0B20T01P0C20T0
50P:01D92`0D2@X04@L601061@804@L602`040H501881`0C2@P04@L601061@0A1`H04PP701@:2@0T
6QT08QPG01881`0D2PT04`T801D;2P0F30/05@/:01471P0@1PD04PP601H<2P0A20<04PT401D;2@0A
1`D04`T700d30P0;0@0040H701L=3P0T6Q/05Ph>00d30P0?1@@05@/:01L=300E2`X040H500h40`0@
1PD050X901D;2P0C2@P040H501471P8040H500T03`D401061@0A1`H04@L600L0000_9B@0L6IU018:
2@0K4A000P0B20L02P0C2@P03@<201061@0700002`4000h61@0K4A005@/:01L=300K4A0Dooooo`00
6oooool0<`0D2``04`X;01<;2@0B3@X050l<01D@300>2`H0AdDo0?3`j01jNW806QXB00l<1`0D3Ph0
5@l@01<=3@0?2@T04Pd;020K600N6AH04`h;01D@300O6QH04@`601`G4`0@30X03`/:014=300@30/0
3`/:014=300F4Q408QhM01hJ6@0D40l03`/:00h:2@0@2PX05Q0@01D?3`0A2`/04P`<01H@400A2`/0
3`T9014;2`0E3`l04P`<00l92@0A3@`040`;00l;2P02010<2`05014=300@30/0510?01<?3P0@30/0
0P0A3@`00`0?2`X05A4@01DA400201HB4@0400l;2P0O6aX06aLF00T61@804Ph=00h04@d<018>3@0A
3@`03`/:010<2`0A3@`040`;01@@3`0E4A003`/:018>3@0C3`h03`/:010<2`804@d<0P0@30/05P0C
3`h02@D400X61@0A3@`05Q8A018>3@0;1`H040`;018>3@0E4A00510?00l;2P0E4A00510?00d9200]
:BP02`L601LC4P0?2`X0510?01DA400B3Pd201@@3`8040`;00@04Ph=01@@3`0E4A005Q8A1@0C3a00
2@0C3`h09R8Q085mO00S7a`07ATF01lK600C40/05a8?01HA3P0201@?300401<>2`0A30T050h>01D@
3@805Q4>01X05A0=01@?300B3Pd05A4@01PD4`0E4A004@d<01DA400B3Pd0510?01HB4@0H51<06ADD
01LF4P0K6QD0414:01lP6P19BT@0824K06m`J`0d=C004a<@01`L6P0R8R004A4@01PH60804a<C0P0H
61P02`0G5aH05ADC018B400A4Pd05QLB01LH4`0D5@l05AH@01hP7@0M7a`0<C<`00805aTF00/07b4N
01LI5P0@4Pl05aTF01XL6@0G6AH06adJ01TN600H7AL05a`F01HK5@0201DJ500301LL5P0E6Q@05AXD
00<061dG00l07B@M01dS7`0N92006R0P00`A500S:2/06AhQ01`R8P0M8b406b4M01/R6`0M8ad07b4L
020R7@0P8ah00P0O91h05P0Q9b40=Sdf030g<00J8a/08B/S02<]9@0]=S<02aDF03<m?P1=F5T09S8b
01TT9P15DU@07R`_01l^<@0S<SH0:3Ll01d/<@0U=C/0:CY102hoAP0_@DH202`n@P0H02m1A00a@dD0
<TA60312@`0^@400<49203a?C@0dAdD0;D0n04MJF00aA480=4I603]=C`0bA4H0>de?03Y<D00mCe<0
=TQ<04AEG@11DUX0AeQR04QIH`12Ded0BUaX0P11Del03@19G6X0EFQf05IYM`1:H6h0Aee[04]QK`1B
IG@0DFAb055UL01GJG@0Cf9Y059UK01?H6L00P18FUh06P18FUd0BUaN04mQH@1BI6@0DF=S059TI01C
IFD0CEmO05Y/K01EIfL0F6YZ05MYJ@1KKFd0FVYY05][JP1VMWD0Gfm^06AdL`1QLG00K7ak08RHU`1m
SH`0JWYi06emO01dQ8<0L81m0P1aPGh0701`P7d0Lh>007R6QP26TY80QY6D0=ORj03eo_l0Z[:n08nG
XP25T9@0R9>D08B@T029Ti<0TYbK09BOV`2?V9@0SIJA08^ES@2=U8d0T9N?09>JT`2GVi/0UIVJ09^O
X02FVYd0W:2S09>GVP2QY:T20:2SZ0030:6TZ`2RYJ`0XjJ]0080YJVb0140YZZc0:NZ/@2VZJh0YZV^
0:RY[02WYjT0Z:RX0:FUY@2VYZ@0Zj^[0:b[[`2/Zk00/:nd0:n^/`2][;80/K2f0;:a]`020;:a^@80
/K2h00X0[jng0:b/]02^[k@0];Fj0:b]/P2UYZX0XjBX0::SY@2OX:80VIZL0P2DUYD06@2=Shh0LG=b
08:4P@1dN700OhEi05MNCP1PJ5L0IVmN07EnK@1gP7<0LG]b07AnMP1jQ7h0Lgai06MbK01KIV00F6=K
05]XG`1NJf80GFYQ05][H@1HIf00EfIO05UYI01HJfL00P1FJFD0601GJVH0EVUU05EUHP1?Ge`0DF5N
051OG017EU<0@E1=04A@C@14CDP0OHMo04I?BP18DD`0<c`g03a5@P0f?c`05QlL09fVY@14CD`0B55@
04]CE00h@C`0=T0h038k=P80;CHa00h0<CXg030i=P0]=S<0;cPg038k>P0a>CX0<cdn03Q2@@0/>3H0
<Cdk02lk>@0V<S40<Cdm02dh>P80<3/m01T0;CPl02Lb=P0P:bl0;3Hh02@^;`0/=c<0:S@/02<]8`0_
>R`09BdP03Dl<00J7aP09BXT01hS7`0P9B4082LP01dW7P0L9Qh07RDN01`S7@0I7a/092TU024U8P0V
:2L09bTX008092HU00H07AlL028T8@0U9b@08bDR01dO700J71T201dO700P01/M6P0I6aP06Q`I01`N
6`0V9R@06QXH01dM6`0L71X05aLE01/K6@0D51803`l=024Q7`0K6aT08B4O00`<2P0F5A<061LE014@
3P0G5Q@06aXH02<R800D4a408b8P01HE4`0K6QP01`H401TH5P0H5a<05A@@01@C3`0E510201LF4P0<
01/J5P0D4`l04A0<01@C3`0A40`05QDB01hM6`0A40h071/I01@C4@0I5A@06A@D0P0H4Q803P0H4140
5`h?01H=3P0A2`X05A4>00T50P0D40d06QHC01TE4P0D40d05A4>014=2P0D40d05a<@0P0C3``04@0D
40d04`l<00`81@070`0081`I01DA3P0?2`P04`l<01HB3`0@30T04`l<00l92@0A2`/0618B00X4100F
41004@`900<04@`800<04@`6018=1`0C3PP00`0C3PX2018=2@03014<200C3PX04@`800804@`80100
3`X601@?2`0=0`806Q0?01<9200<10804`/9018:200<1`@050l<00D1000810405a<@00T50P0?2PH0
5A0<0P0@2`L00`0E40`03PT5010;1`05010;1`H040/800L061<@00h91P0G4Pl02@@1024L6@060@00
4@L6008050X900D04PP701<9200E2`X040H501881`0201D;2P8050X900H05@/:01881`0@1PD04@L6
01<9200E2`X201@:2@0501471P0B20L04`T800l71@0@2PH00P0?2PL01P0@2`P040X:010:2P0?2@T0
3PP:00d72@803PP:01<03`T;01872`0A1PX04@H:01872`0C20`050T=00d21P0D2@d05@X>01X?4`0F
2`l03@D801@@4@0A3@h040/=010:300;1@L04PX=00803PD800X04PP<01872`0D2@d05@d?018<300<
1PH09b0P01T@4@0Q61T030@50P0A1`P0100A1PP04PH801<72@0C20T200l5100301881`0@1PD040H5
00<04`T800H05@/:01H<2`0G3@`04PP701X@3`0M4a8301881`0601@:2@0E2`X04`T801061@0>10<0
40H50P0700002`0C2PD04`T700/1000E2`T03P@300`20@0A1`P03`D600d3100;0P<03`D4008040H5
0P0?1@@0200A1`H03P@300l5100A1`H04PP701471P0@1PD04@L60P0@1PD04@0?1@@040H501471P0F
30/05@/:04Pn?@2RV9L09adL01471P0@1PD02`4101dC4P0L4Q406Q0?01P>3@0<0P405`d<00801`00
00<03PD500L00?ooool04oooool001_ooooo0P0B3@X06@0A30T04Pd:01DA300F4`h06QLA01XG400h
=Bh0:BHM00h;0`0@3@H05Q0@01TC5@0F41803PP901@>3P0_:BT0;RTV01LB3`0V8Ah0Pgij05mJEP0V
8Ad0510>00l;2P0B3Pd00P0A3@`00`0F4Q404@d<01@@3`02014=3003010<2`0=2@P04`d=00804P`<
00<04`d=00l92@0=1`L00P0D3Ph01P0C3@d04P`<018<300B30`040`;014=30804Ph=00/040`;00l;
2P0D40l04@d<010<2`0A3@`04Ph=01@@3`0=2@P03`/:01@@3`02014=308040`;00T05a<B010<2`0=
2@P05A4@018>3@0A3@`040`;00l;2P0A3@`00P0C3`h03@0B3Pd03`/:01@@3`0T81l07ATH00d9200A
3@`0510?014=300=2@P040`;018>3@0A3@`00P0D40l00`0;1`H05Q8A01<?3P02014=30804`l>00`0
4@d<018?3P0B3Pd06QHE051<B`0A3@`03PX9010<2`0D40l04Ph=00l;2P0C3`h201DA4080510?00<0
4Ph=014=300A3@`01@0B3Pl05@0B3Pd05a<B01hJ6P0@30X04`l=01HB3`0@30L05`l<01H=2P0E3@/0
5Q0@01DA4@0A3Ph04`lA01DA4@0G4A406A4?01L?300E3@/05Q0@01@@3`0201TE500401@@3`0I5A@0
510?01DA40805Q8A00`05A4@018A3P0F5A407QlI08R9P`3`l>`0HF9M01`M600H61H05QHD01<C4@0C
4a<201HF5P0802DU9@0C4a<05QHF00X:2P0H61L04a<A01lO7@0D5A0201<D3`07018C3@0D5@l05ALD
028T8@19BdP06adJ00d?300201PJ5`0=01TK600F61D071hK01XL6@0?4@h06b0J01PM5`0F6aD05AXD
01LL5P0H7AL06AhH01/P6P0401`Q6`0=01HM5P0M8al05adI06=YJ@0f>ch041DH01XO8P0N92@07R@R
01`R7P0L8a`07R@N01hS7`0301lT800O01hT800U:bL0<CTd02D^:@0V;bX0:34/01/V800R;BX08bd^
01lY:P0R;Bh0:cLg02@_<@0P;2l09cDh02Lf>@0V=CT09cHk02Xi?P0Y>Cl0:S]202`mA00]?T@0;T14
0312AP0dATT0=dU;03Q:C00eAdP0<dE503E7A`0203A7A@0U03M:B00dAdD0=4M503M9B@0mCe40>Ta>
03]=C`0mCe<0I7Ij03mAE@0kC5@0A5EM045BG00jBeD0@55K04EGH`19FfL0AUQT04MJJ01@Hg40DfId
04UOK@17GF/0EF]i05Q[NP1@Hg40Ef]f05EWLP1@HfX0EFQ_055RJ@18FUh0BeeQ04eOHP1;GEl0DF=S
05EWI`0205=UI@0b05AVIP1NL700L8:205Y/K01GJFT0FF][05=UI@1KJfX0G6a[06AdL`1NKVd0IgMf
06=cLP1RLW40IgMf06IfM@1TM7<0JGUh06moO01/OGL0Kh1i0761O@1`P7d0M8>107R6QP1lQhX0OXV?
09:LY@2[/kd0VJ6]07n8T@1oRX`0QY:@08>?S@27TXl0SIRD08bGT`2;U900R96;08NAR@2;TX/0S9>;
08bCS02CVIX0V9fP09bQY02PYJP0^[o309NLX02MXZH209bQY`0309jSZ@2PY:d0XJF^00<0XZJ_00l0
XZN]0:>VZ`2RYJX0XZJX0::SY@2TYZD0XZBS0:BTXP2ZZZX0Z:V/0:VZ[P2_/;@0[Znc0:^//02_/;@0
0P2_/;D0:02^[k@0[Jjc0:f^/`2][[D0ZZfd0:^^]@2_/[P0ZJba0:>WZP2TZ:X0XZJV09bPX02DVIH0
RXn;0866PP1dNGD0M7Ud07j3OP1jOgL0M7Y_06=[G@1YLV80JgAV06mjJ`1dOW<0MGmf07=nMP1eP7X0
Lgij06agL`1RKVT0GfaU05m/IP1OKFH0GfiW069aJ`1TMFl0HW=]05i^J@1GJVL205MZJ080FFaZ00d0
F6QU051PG@1EIF80BEQD041?BP1BHE`0QY:>04E?B026T8P0DU]F03Y3?P0`>C@0:S<`00809Rl/00H0
>D9103a5A00f?ch0<c/l03M0>`0d?SH202lh<`0B030i=00a>SL0<CXg02`e<P0Z<c80;3Dd030i>@0h
@D<0=d5003Y6A00/>3H0:CDc02di>00b?Sh0<3/m02`g>@0W<S@09C0d0P0T;c<0:P0W<C<0:38c02Td
<00Q:RD0;3H]03Q2=`0U;B80:C0V02DZ8`0W;2H08bPT028W8`0S:R<092/S020W800M91d07B<M020U
8@0U:RH08bPU02L[:P0T:2L07B4P028V9@0P8Ql08B<P028T8@0P8Ql071hK01/M6P0P8Ql07AlL01XL
6@0I6aP07AlL020R7`0[:bT061PF01TI5`0H61H06ATG024Q7`806QXH00@06a/I01HF500L71X06QXH
0P0F5A<03P0K6QP04a8@01dL6P0B4@l061LE01HE4`0E518061LE01@C4@0I61H061LC01DD400D4`l0
5A@@0P0G5Q80<`0F5A404A0<01XI5@0I61@040l;018A3P0J6AL03`h<01/J600D4a407ATH01dH600F
41005@l?01D>3P0G3Pl06A0A01/E500g<c007ATF01/G500;1`H04`l<01DA3P0G4a005Q8?01@@3@0A
3@X04Ph;01<?300B3P/05Q8?01@@3@0?2`P0<BdZ03<_;00Q7AX03`/800d91P0@30T0:2@Q01@>3P0A
2`/04P`<00X51@0N61P04Pd:00l:1P0@2`L04Pd901<>2002018=1`<04Pd901/04@`8010;1`0@2`L0
4`h:010;1`0B3@T04@`800h91@0F4@d04PP701L=300D2PX06Q8@01<;2@0@20H05A0=00d81@0B3P/0
40`900`81@0K5a@04`h:018=2@0@2`L03`X6014<200D3`/01P0@2`L6010;2009014<2@0>2@H050l<
00h9201XHf005Q4@01<9200F30/05@/:00804PP70`0D2PT201<9208050X900T05@/:01@:2@0C2@P0
50X901D;2P0F30/050X901D;2P0B20L00P0C2@P01@0>1P@05Pl<01<>2`0B3@X040/800803PP800<0
3`T900h82P0=1`T00P0>20X05P0?2@/04PL;01462P0A1PX04PL;01<8300D2@d0=b``01462P0>1@L0
6@hB01<8300B2@`030H8010:300?2@/02`D7014;3@0@2P`030H800l62@0B2@`200l62@0:018:300A
30`02@<305UADP0Q61T04@T:01<:2`0B20T04@L801461`804@D700P04@H700h40`0?1@@050X90106
1@0B20L05@/:01<9208050X900D04`T801471P0B20L03`D401061@0201@:2@0I01<9200?1@@04@L6
01881`0@1PD04@L601D;2@1<@T00;2<N00l60P0C2@L04PP601071@0B20L0308101882@0?1@H03P@5
01<:2P0C2@P040H500h40`0A1`H04PP700l5100401061@0301471P0C2@P04@L6008040H501D03`D4
01061@0A1`H02P8101<9200@20L08ALF00l5100B20L050X900h40`0E2`X040H501071P0<0`<05P`;
01481`0A1`H040P701071P0H3Pd05?ooool001_ooooo01/040`;01@@3`0F4Pl020@1018>2`030000
3P/6014=1`0D3`T05A0:01<>200A30P0510A00l:3P0C3a003`/<018>3P0=2@P03PX901XF501<B4D0
l>gZ0:6MVP0^:RL0510?00l;2P0@30/00P0C3`h01@0A3@`03PX900l;2P0@30/04@d<00804Ph=00L0
4@/;00d71`0@2PX0618B01H@400B30`04@/;008040X:01h04P`<01@>3P0E3`l030P701<?3P0:1PD0
5A4@00L30P0H51<0B4A301DA400D40l04Ph=00L30P0@30/04Ph=010<2`0<20L04Ph=01DA400>2PT0
4@d<018>3@0C3`h02`L600T5100B3Pd05Q8A01PD4`0C3`h201@@3`07014=300B3Pd040`;00l;2P0@
30/04Ph=01<?3P03018>3@07010<2`0?2`X05A4@01DA400A3@`04`l>018>3@0201@@3`0C01DA400?
2`X030P700L30P0K61L04Ph=00l;2P0@30/04Ph=010<2`0C3`h03`/:00d9200B3Pd040`;00d9200B
3Pd04`l>010<2`0201<?3P0;00d9200A3@`05a<D00h:2`0G4a@08alP01/G600F4Q404@d<018>3@0C
3``00P0D40d03P0E4@`06A4>00l50`0K4a40>C<c01/H6P0@41804@lD010=3`0B30`0610>01D<2P0:
0P0050h>0`0E4A00;`0D40l04Ph=01dI600>2PT07QXI00l;2P0E4A004a8@01`K5`0E5Q40>c`g05mP
F`0d=C405QHD01/K6@0@40l07QhN00H6200H61X03Ph@01TI6@0E5AD04A4A01`L700<30/08R8P01/K
6@0E5Q404a@?01@E400I6Q@06a`F010B3`0F61D06Q`I014C400G6AH0:R`Y01PJ5`0F61D061XG01XL
6@0F61D04Q@A01LL5P0H7AL06QlI00806AhH02P02Pl901XO6@0M8Q`08bPR01dR700G71H06QlI01PO
600G7AT0:Bl[03Y0@00d>C`041DH01/P8`0O9BD0728P028X900Q:240728L02ld<00D6AD06AhJ01hT
800V;2P082PS02</9`0R:bH08B`V01lZ900N:B<08R`Z02@^;`0S;Bh08bh_02@`<00V<C<09C8d02Hd
=`0Y>3/0:cXn0P0[>Sl03P0_?dD0;Sm602hoAP0bA4T0<49603A6BP0iBdh0?U1B03e?D@0_@D80=4I6
03I8B00dAdD0>4]90P0fBDL06P0lCdd0?4i>03i@DP12E5H0?DmA03mAE@0jC500?4iB04]LI00mCUH0
AUMQ049CG@0oD5X0DF=_04iPK01CIG40@UES04aOK@1:GF/0Bf5_04UOK@1=Hg40DfIe055TLP1AIG00
EVQc0P1AI6/02`19FV40AeUM051RIP1DIVT0Cf5S04mQH@1@HV80DF=S05=UI@1EIfL0EVQX0080EFMW
00<0EVQX05U[J`1KKFd00P1MKF`04`1NKVd0H71_06AdL`1VMWD0H71_06MgMP1^OWd0M8B306UiN01_
Og`0KWmg06amM01cQ7h0LX9o06mnO01kRHX0PhjB07b7SP1oRI800P24S9L01`26SiH0PXj>07n;Q`22
SXX0R9>?09:MU`2KYZ000P21RXD07`1mQgl0S9><08R?R026S8P0TIZJ09:JW029TI<0Xj^^0:jf^@2G
Wj80UijT09JMY@2KXZX0VZ6Y09fT[02TZk<0WZF]0::Y/@2X[kL0WjBZ09fRYP2Z[k<0WJ6S09nSY02V
ZZT0XJ>R0::TX@2^/:l0Y:FX0:RY[@2[[;000P2^[k<07`2g^;`0/;6e0:BUZ@2ZZjl0Z:V[0:Z[[`2[
[K80Y:V_0:FZ/02W[;40YZ^_0::WZP2OY:H0WJ>Q09NMV`2;THd0QXf608>:P`1mPgd0MGYd07QmM`1m
PgX0LGU^07=kKP1mQWT0OhUn06miKP2:UX`0SIR@06ehLP1_NWD00P1`O7P04@1YMG40IG5]06QgM01Z
NGD0I7=^065bK@1RLfd0H75[05IYI01GJVP0E6IV05U[J`1GJVP0Cf9P05EUI01BHUl0B5QE0080AUE@
05/0BeYC04=@B@0f@3P0>D<k03a5@00nAd80;cPc02Pa;P0[=340:S<`02`e=00U;Rd0:34`02/c=00/
=C00;3H^02Xc;P0`>C@0=Slj02`e<P0Z<c00;CHc02`e=00[=3<0<S/k038j?00T;Rd0<3Xi03M1@00b
?3/0:cDe02Tc=00V<380;SPj02/e=`0Z<cP082T^02/d>@0P:R`08R`/02@_:`0V;bX092hV024[8P0U
;2@09R`U020U7`0N8ad092TT02P]:@0O91h08RLQ02<X8P0G71H07B8M024V8P0R9b<09BXW024W9@0J
81h0728P01HJ6@0H6QL0:2XW01LI5P0P8Ql0Gf5N01@F4`0K7AX09RPU01<E4P0N81d04aDB02PZ9`0L
71X07AdK01PH5P0C4a405aLE01dM6`0J6QP05QHD01LG5@0J6QP061PF01DE4`0G5Q@061LE01LF500F
5A<05aHD008061LE03d051<A01DD4P0J6AL061LE01DD4P0F5A4061LC01DD400F5A405A@@01HE4@0J
6AD06APD01HE4@0C4Ph04Q4=01<B3`0V9B<040l=01PG5@0S8R00L6a[01D@3`0D3Ph04`d=01/C500G
3Pl05@`=01LA400:1P<05Q8?01TE4P0>2PL061@A014=2P0M6AH04Ph;01@@3@0>2PL0510=01<?300B
3P/04`l<01TE4P0D40d040`901DA3P0<20D05A4>01@@3@0A3@X03`/801H@400E3`l02PD501PB4P0@
2PX05Q4>01<>2P0B3@T04`h:00805A0:00T04Pd7018=2@0C3PX04@`800h91@0@2`L03PT500l:1P0@
2`L00P0B3@T05P0@2`L03@P401dC4P0U6aX05P`;01491`0D30X05Ph<014<2@0@2`P01`<001<?300L
61D0al?0055<B00C3PX05A0<00d8100<1`@050l;014<200>2@H200d81008014<200E40`04`h;00`7
1P0N6AH0100001<>2`0k=S<600l:1`0601471P0B20L04`T801<9200B20L04@L60P0C2@P201881`80
4@L600H04`T801881`0A1`H04`T801D;2P0F30/201<920804PP701H04@L601081P0G4@d03PT600d8
1@0A30T03PP800X4100>20P03PP:00T31@0=20T06aDG00`6200=0PH03`@801872`0G310060dA01L<
400C20`04@H:0`0@1@T04`0?1@T050/>01<:3@0?1PT06Q4D01LA4`0A2`d03@L900`6200D3Q004@/=
00d72@0<1PL05@l?01@>3P0C2``040L800T00@0A20T00P0B20T0100A1PP050P:00/00@0E2PX20106
1@0901471P0B20L04PP700l5100@1PD04PP701061@0A1`H04PP700H040H500`06a4@00L0000C2@P0
5P`;01061@0W7A`0e/c:06]RG@0;0`4050X800l50`0;0P4201471P@04@L801@06a4@01@:2@0<0P40
4@L601D;2P0B20L040H500l5100>10<03`D401881`0F30/03@<201H<2`0C2@P05P`;00l5100A1`H0
4`T801881`804@L600@04PP701<9200>10<040H50P0B20L0100@1PD03P@300l5100A1`H201<92003
01471P0?1@Cooooo01?ooooo000Kooooo`0P018>3@0A3@`04Ph=00/71P0D40d06QHC00l;200C3`X0
5A0:01HA3@0D3`T04Pd9010<3@0F4AD03`X>00h:2`0A3@h04@d<00T5100J5Q@08QhK08=oO01KEe@0
3@T6014=300@30/04@d<01@@3`0A3@`03PX9018>3@0A3@`2010<2`803PX900@04`d=014;2`0A2`/0
4`d=0P0D3Ph301LA4@0N01H@400C3@d04P`<01<?3P0H51<03PX901<?3P060P404`l>01HB4@030000
2@D401DA400B3Pd061@C01<?3P0B3Pd03@T8018>3@0D40l04Ph=01<?3P0A3@`09R8Q02LS8P0C3`h0
3@T8018>3@0C3`h040`;0P0C3`h00`0A3@`04Ph=010<2`02010<2`03018>3@0C3`h04`l>0080510?
00L04`l>018>3@0D40l03`/:00`81`0?2`X03PX9008040`;03403`/:014=300K5aH081`K03lk>P0B
3Pd03`/:010<2`0B3Pd040`;01<?3P0D40l03@T801LC4P0D40l04@d<018>3@0E4A003`/:010<2`0D
40l04@d<01<?3P0H51D040`=01HB4`0O6a`061@E01<?3P0D40l04`l>018>2`0A3@X04`l<01HB3P0A
2@H04`T7014:2@0J5QL04a8F01TJ7P0?41@04a8F01dI6P0E3`l040L502<K600F4@h05A4@00804`l>
04`0510?01DA400B3Pd0510?01/G5P0:1PD061@C01<B400I61@03@h901hO6P0`<B`071`I010@3P0?
3`d0410?01@D500@41805aLI02@T9P1@D5004a<C020P800G5aL09bLV0041000I6AL05QLB01DF4@0F
5a8061TC01TJ500I6aP05QPE01TK600J71T0;Bl/04=5@P0H6QL05QPE01LI5P0I6aP05QPE01<E4P0H
7AL07b@N02DZ900Y;RP0:c0Z01dR700K81X07R<M02<X8P0P9Al07B8L024V800mA3d01`d902@Z9P0K
8B4041DH028W:P0D6A`051XJ01hT8P0E6aL07bHO07=iL`13B4@07R<O01hT800I7a/0BU1<01dV8@0P
:B@07bXT0P0N:B<03P0M:2808R`Z02H`<@0U;c009C0a02Hb<P0X<cD09S8e02Dc=P0W=ST0:CPl02Xi
?P0[>Sl0;Si40P0/?D@01`0`@TL0;T140394B00dATT0=TQ:03M9B`0a@d@00P0iBd/02@0aA480=TU7
03A7A@0aA480=4M503=5A@0eAdT0?DmA03U;C@0203i@E003049DF01WN800C5eU0080@55K00h0AeQR
059TL00oDEd0C5iZ04MJJ01;GV`0DVEc04AJJ019Gfd0Bf5_051SLP1@Hg40D6A_05=UL080D6=Z0140
B5UP04IHG01>H6@0D69U051RI01@HV80DF=S059TI01EIfL0EVQX05AVIP1EIfL0EfUY05U[J`1LKVh0
GW1`065aL003069bL@1f061`K`1NKVd0I7Ac06UiN01[NgX0L81o06QhM`1`P7d0KWmg06n0M`1bPgd0
LH5n07:1P@1iQhX0OXV?07b7SP23SIH0Qi2I086:T`1mQXd0Oh^;07n;Q`22SXX0Q8n;08RCS@2>VI<0
SIJA08><Q`20RH@0PhZ408:8Q02AUi<0SYNG09RPXP2CVid0Ti^N09FMX02@V9/0UIbR09FLY02IX:P0
V9nW09ZQZ@2QZ;00WjJ^09jU[@2RZK40WjBZ0:N//02g_<00_<3209jRX`2OXj80YjVX0:BVX`2VZ:L0
YZNZ0:NX[02YZZh0[:fa0:j_/`2h^Kd0/K:f0:BUZ@2RXjD0VibN09bMW`2TZJ`0YZ^a0:N//P2W[;40
XjR/0:2UZ02FW9/0SiFA08bBSP24Rh@0QHb408J=Q@1jP7P0L7E^092ESP2MXiX0LGU^06ifJ`1dOW<0
K7I]07V5N`3CgmH0]/6i07AoN@1^NWD0L7ah075mN@1]NGH0JGEc06UhM@1YMgH0Hg=`061`K@1MKFX0
FV]U05=VH@1GJVP0DfEU05EWI`1DIVH0CF1N059RH@1>GU/0CemL049AC00a@3T0<3lh03M4?@12C4@0
=T0h030i=080=d0k01T09c0]01lX9@0Y<Rl0>dA303M0?`0`>CP09Rh_02hg<P0^>300;CHa03@m>00k
A3l0=3dj02Xc<00]=S<0;3Dd02/d<`0a>CX0;cLi02@^;@0Z=3<0;SPg02dg=P0Z=3@0:S@e0080:38d
03H092h`02Pa=P0Q:Rl0:38d01lY:`0T;Rh09S0_02@]:P0P:B@07bTQ02D/9@0X;RP09b`V02DZ900R
9b807R<M02H[900T:B<0724K018G4@0N8ah06QlK01`Q7@0F6aP08bTW014G5@0P9R@06b4O02HZ9P0G
6AH05ALD01hP7@12A4409RPU01TK600W:BH05ALD01hP7@0E5a@051HC01HF500J6QP06a/I01PH5P0G
5aD061PF01HF500B4Q004a<A01DE4`0C4a404A4?01PG5@0G5Q@201DD4P0>01PG5@0K6QP05aHD01DD
4P0F5A<05aHD01HE4`0E51805A@@01LF4P0D4`l05QDA01DD400D4`l501DD400702@S801/JfT04a8@
00h=2`0A40h09R8Q018=300201H@400T01PA4@0F3@h060l@01H@3`0@30T04Ph;00h:1`0D40d061@A
01DA3P0;1`@08alL00/7100Q7AX01@4001`H5@0C3``040`9018>2`0C3``05a<@01dI5P0?2`P02@D2
00/7100B3P/05a<@00@0000V82007QPH010:2P0400004@`900/60P0=20@040/70P0A30H01P0@2`D0
3@P400h91@0B3@T04@`800l:1P804Pd900<04@`8010;1`0?2PH00P0?2PH00`0>10<06Q0?01H<2`02
01H>300=018:200E40d03`X801TE4P0D40d0920M0:fYYP0l=c<040/701D@300?2PH03@P4010;1`02
01@?2`8040/70P0C3PX01P0@2`P04@`900`7100g<Rl0Ddi;06eXI@H040/800H04@L601881`0C2@P0
4`T801881`0A1`H201<920804PP70P0A1`H301881`0401<9200D2PT05@/:01<920804PP70P0A1`H0
4P0@20H050d:00h91P0>2@H040/800l92@0>20P040X:00`6200:10H03PP:01XD5P0@2P`04@H:0105
2@0B1`/05P/?01D:3P804`P<00D04@H:01052@0@1@T040D901062@0201482`0@01P?4P0/8bH0:R@V
01LA4`0?2@/030H800/51`0>20X03@L9014;300=1`L0100002DN7P0i<3407aHG00h51P804PP900@0
5@X;01451`0A1@L03P<40P0@1PD0100A1`H04PP701881`0@1PD201471P0400h40`0@1PD03`D400l5
10D04PP700X0308101@:2@0F30/0308100l5100>10<081HD0189100F3@P07Q@B0P0A1`D201471P@0
4@L800H05`d<01881`0=0`8040H501881`0@1PD200h40`0:01061@0C2@P05P`;01X@3`0C2@P060h=
01H<2`0H3Pd050X901D;2P804@L60P0@1PD201471PL040H500D04@L601881`0B20L04@L601061@0D
ooooo`006oooool07P0A3a403P`>00P61`0C4A<040d=01HB4@0>20T04@/:018=2P0D30/050`9014<
2@0<20T09R@W00`:3@0?3A003P`>01LE5P0=30X04A0>00X91`0J6AH05QDC01DD400>2PT040`;018>
3@0C3`h03`/:00`81`H040`;00<04@/;01<=3@0B30`00P0@2PX04`0A2`/050h>01LA4@0I4a<0618B
01D?3`0C3@d0510?01HB4@0A3@`04Ph=014=300B3Pd07a/J02/W9P0I5A@03`/:00d9200?2`X00P0B
3Pd00`0A3@`04Ph=014=300200h:2@0400d9200M6AP07QXI014=3080510?00@03`/:010<2`0E4A00
510?1`0A3@`00`0@30/04Ph=01<?3P02018>3@8061@C00D04`l>01@@3`0A3@`04@d<01@@3`03018>
3@0A00T5100G4a804`l>010<2`0A3@`04Ph=010<2`0C3`h07ATH00`81`0D40l02`L600h:2@0C3`h0
5A4@014=300@30/00P0C3`h02@0E4A005a<D010<3@0B3Pl05a<D018>3`0@30/05A4@01@@3`02014=
2P0@01<?300G4`h05Pl901`D400D3Pd05A@E00lB5@0>51P02@dB00d?4P0>3@d04@`<01H>300F3P/0
5Q4>01@@3`804Ph=01`05A4@01LC4P091@@06aLF01HB4@0O6aX06aLF01@C4@0F5A404A8=01LH4`0>
3P`05aLE01HF500G5aL04a<D014A4`0];Bl06ATK01LG6@0E5AD061PH01LG5`0A4A404a<B018B400F
5Q@05aPC0P0H6A@02`0H6A<05aPB018D4@0D5Q<06Q`I01HH5@0C5A806A/H01XL6@0G6AH05QPE00<0
61XG00H051TC01XO6@0P9Al08bPR02P]9`0L8A/301dR700E01XO6@0K81X07R<M01`S700U:bL07R@P
01XP800I7R406QlR01/P8`0I7al08BLU020V8P0O9Ql0>D0k020V900Z<2h07bDS02D[:@1BFeP08R`Y
00807bXV0P0P;2P0500Q;BT08bh/02@^;`0T;Rl09C0`02Hb<P0W<S@09S8e02Dc=P0V=CP0:3Lk02Xi
?P0]?440;Si402/l@`0/?D@0;T1502i0A00a@dL0<dE80P0dATP0100dATL0?4i>03M9B@0fBDL203Y=
B`0K03E8AP0fBDL0>de=04=EE`1?HF<0@UAF03e?D`0nD5@0>deA04=DG00oD5P0AeQR04IGH@1;G6H0
B5YV055SK`17FFD0Bei/04AGI@18FfT0CfEc04aRL01;HFl0CF1_051SL@1AIG00Cf5/0080B5]R00D0
AeQO04UKG`1=Gf<0CV1S055SI@02059TI00705=UI@1FJ6P0F6YZ05=UI@1FJ6P0FVa/05a^KP0205i`
L00705i^K@1QLG00Hg=b06=cLP1PL6l0GFe/065aL00206EeM02206]kNP1YNGP0LX9o06enN01cQ7h0
Kh1k06moO@1gQXH0MH>7082:TP24SYL0SYRP08jGW`20RHl0Mh2307V5P`1nRXH0R9B@08JAS@22S8X0
Q8n;08ZCT02AVYP0VZ>Q096GU@1mPh80S9:A08fEU`2?UiX0TYZM08nGVP2>UI/0U9^Q09NNYP2HWjL0
VJ2X09NNZ02IX:X0WJB^09ZSZP2LXj/0X:N_09^RZ02QYZX0ZZnc0:Z`/@2FVY/0UYZI09^OWP2NXil0
XjNV0:6UZ@2OXZL0XJBY0:FY[02VZZd0YZZ[09fQXP2EVIX0TYJF08jBT@2DV9L0X:FX0:>W/02SZ:h0
WZ>X09JKW`2BUiX0T9JD08jDT028SXT0O8=j07Z2M`1kPgP0NH5f06eeJP2:TXL0WZFL07V0N01cOG@0
M7ie06mjLP1hPg/0ZKF]08fJT`1WM6d0KGUd06ijMP1]NGL0K7Ui06YhN@1YMgL0IgIg06EeM@1OLG00
EfYW05AWH`1EJ6<0G6i^05QZK01CIFL0DVAT055SH`1@H5l0BEUF04]KE`0oCTP0BUUB03m?AP1EHUT0
GFMO041:@P0lAD00;CHa02/d;`0V;b`0;cPe02`e<P0Z<c809c0_02Tb<@0^=cL0;SLb02`f;P0X<B`0
;3D`030i=00]=S<0:S<`02df<`80;CHe00<0<CTj02hf>00Y<c800P0V<2l09P0Z=3<0;3Hf02Xd=@0Q
:bd09S0b02Xd=P0a>Sl08b`a020Z;00L9RP08B/[02@^;@0T;B`08BXX01lX900Z<2d092TU024V8P0P
9B407b@O01hS7@0Z;BH07R4K01hP6`0M7aX082<O014F4P0N9200728O01TO7@1AFUL0<3Tf02hd<P0M
81d04A<@01lQ7P0K7AX07b4N0P0H6QL0200U9b@06A/H01`N6`0S9B805QPE028R800J6QP061PF0P0K
6aT201TI5`<05aLE00T05QHD01DE4`0I61H05aHD01DD4P0D4a4061LE01`K6@0E51800P0H5aD201DD
4P0401HE4`0C4Ph05QDA01@C3`805aHB0P0D4`l05`0C4Ph051<?01@C3`0E51009bHS06e/JP0J6AL0
6APF01DD4P0C3`h061<B01PB4P0I4a<05@h>01P?400I414061<A01dI5P0E4@h061@A01<?300=2@H0
5a<@008030T700`06ADB00P40P0X92403P/800h:1`0?2`P05Q8?01@@3@0B3P/03@T601<?300D40d2
014=2P0801@@3@0C3@d0<B/[01PB4P0B30`050h>014<2@0A30P201<>2P0B00d80P0<1`404Pd701@?
2`0>2@D04Pd901@?2`0=20@04Pd901<>2P0B3@T040/700h91@0?2PH04@`800`30`0F30/04PP70`0E
3@/0600C3P/03@P500l;200=2@L04`l<01@@3`0H4`l03`X601<>2P0@2`L04Pd900`70`0B3@T05A0<
00d8100<1`<04`h:00h91@0@2`P04@d:00l:200?2`T0D4]801LB3`H04@`900H04@L601881`0C2@P0
4`T801881`0A1`H201<920804PP70P0A1`H01@0B20L04`T801@:2@0D2PT04`T800<04PP70P0A1`H0
5P0@1PD03`L500l81@0@2`P03`X700`7100>20P04@/;010:2P0;1@L03`T;010:300K5AL081XL01@9
3@0B1`/04`P<01@93@0B1`/040D901<8300A1PX201052@0J01462P0D2@d050T=01052@0C2@d081LJ
01/B5@0B2`d08A/M01XD5P0?2``0510A010<3@0A30d04@/;00h8200F3Pl040L800/20`0C2@X05P`=
00d3100D2@X04@D7034U9`0A1PH201061@0301471P0B20L04PP700804PP700@040H501<9200I3`h0
5P`;1@0A1`H03@0B20L040L701@:2@0B2@P05Ph=018:2@0B20H050X801H=200>1@803@@30189200?
1P@00P0A1`H40147200:00l5100A1`H04PP701061@0?1@@040H500h40`0?1@@04@L601<9208050X9
00L04`T801061@0@1PD03P@301<9200B20L040H500@04@L600<040H501881`0@1PD00P0?1@@0100@
1PD04PP701471P0A1`H201881`804@L65?ooool001_ooooo01P04a8G02<R9`0<30h040hC010<400I
5AH03@L;00l72P0A20T04@P;01882@0A20T07aXN03/i?P0G5AX05A<F00X82P0@3Pl02`T:018@400C
4Q0020L6014@3P0C4Q0200l;2P803PX900H03`/:010<2`0>2PT03`/:010<2`0A3@`2018>3@0600l9
2@0A2`/05Q0@01/E5@0D3Ph03PP80`0A2`/0300C3@d050h>01@>3P0E4A004`l>014=300:1PD0510?
00P40`0@30/05a<B00d920803`/:00@04Ph=00h:2@0?2`X04@d<0P0@30/0200?2`X04`l>010<2`0=
2@P02`L6018>3@0S7ah061@C0P0@30/00`0B3Pd04@d<010<2`05014=300300l;2P0>2PT03`/:00<0
4@d<00D0510?018>3@0?2`X04@d<00h:2@0200d9200>00`81`0C3`h05Q8A014=300E4A00510?010<
2`0A3@`04Ph=00l;2P0B3Pd06aLF00l;2P0G4a82014=300401@@3`0B3Pd0510?01@@3`803PX900d0
4`l>010<3@0=2@X03`/<018>3`0A3@h04`l>010<2`0A3@`0510=01DA3P0D40d04a0;00803PT302T0
40h;018C5@052`l07bP]0499D@0O9BX05AHH01LF500E4@`061<?010<2@0C3`h05Q8A01LC4P0E4A00
4`l>01DA400G4a80510?04M3@P0J5QD05A@B00l>300B4Q006QXH00l?3@0M7A`05ADE01PH600L71d0
5QHH09nNX`1?CU<0410B01/K6`0@41004Q8B0000000G5aH051@B01PH5P0201DF4@0;01HG4P0I6Q@0
6Q/E01XL6@0C5A8051HC01HH5@0K7AX07b4N01TK600H6QL00P0G6AH0GP0I6aP06adJ01PM5`0H7AL0
5a`F01DJ500K81X04QLA01PM5`0K81X0724K028W8@0[<2X0;c@^01lV7`0F71P04QPD01XP800@5AP0
6b0S01DJ7@0R:2P06R0N01XP700M91d07bHQ028X9P0I7ad09Rd[01lX9@0<5A8082XV01lZ9P0O:bL0
8RhZ02@`;00U<Bd092l]028/;@0S;Bh09C0a02Hb<P0W<S@09c@f02Pf>@0Y>3/0:STm02`k@00`?d@0
;cm502dnA@0_@4L0;d560353A`0cADT0>4Y=03U;C@0eAdT0=4I703U;B`0gBDT0>di<03U<BP0eB4H0
<DA203A7A@0oDE40=TQ:045CE@0gBD/0=TQ<03]=D@0lCU80>4UA03]<E017F680@U=M04YKI@1AHfl0
Cf5]04QJIP1EJ7H0A5MU04EHIP1>I780D6Id04eSL@1>HG00D6=a051TK`1<GVT0BeiU04ULH`1=GVD2
059TJ00k059TI`1@HV@0D69R055SH`1BI6@0EFMW05IXJ01EIfL0EfUY05Y/K01KKFd0FVa/05QZJP1K
JfX0G6a[05e]K01NKVd0HG5`06=cLP1UMG@0KWim06alN`1bPX40Kgmn07:2P@1/O7T0LX9o06emO01_
Ogl0NHN<07B1R@1nR940P8ZB08F@UP22Ri00MX22079lN`1iQH<0P8b:08^GU@29Ti80PH^<086;RP2>
UYL0SYJH08VAT`2>TiH0RHjA08fBU@2;U9H0T9ZL08jHVP2=UY/0SYNL08bEVP2AVZ40TibU09:KY02A
VZ<00P2BVj@0H02FWjH0VZ>Z09^TZ`2FWJ<0TYZM09FMX02IWj00W::R09VOW@2@U9<0U9VE09jRX@2M
X:@0W9nT0:2SZ02UZJ`0X:BU09^OX02FVYT0T9BC08^?SP27S8P0Ri2<09ZNXP2QZ;00XJR^09ZQYP2@
V9X0S9BF08VBS`25SXT0OXR0079lLP1bOFl0Lgi`07AnL01eOG00MGeb071iK`1_NG00LG]c06UcK01d
OgT0MhAm06QeK`1WLfl0JGEa06]hM01VMG00I7=`06AbLP1ULgH0IGAg069aM@1QL7<0Ffe^05AWI@1C
IV80EfaV05MYJ`1GJFd0D69T04eOG`1@HV80Be]J04IFD`1:FeD0AEA=03i>A00b@SP0/l2g0>_ek@1o
RH40=Slj02hg<P0a>SD0<c`i02lh=@0Z<c00:34`03@m?00f?ch0;CDf038k=P0]=bl0:S<^02`e<00]
=S40;3Db02Tb;`0/=C80;CHe02hg=P0d?3d0<SXl02df=@809c0_03<0;3Dd02/c=00R:R`07RHY02Ta
=00]=CP0;SDk020W;@0T;2l08bd^01hX9`0O:BP09Bh]02</:`0J8b00:S0^024V900Q9B@08bPT02L/
9`0`=Bl0FEaE02HW8@0P8A`071hI01TL600S:2@07B<O02<Z9`16Cd`0bmCA06]eLP0E7Q/07R8N02@V
8`0l?S/05ALD02X/:@0M7a`0<C<`02T[:00N81d07AlL01/M6P0N81d0:BTW01TI5`0E5A<06QXH01`L
6P0J6QP00`0G5aD0100F5Q@05ADC01DE4`0F5A<201TH5P0401LF500F5A<05aHD01HE4`806aXH0P0G
5Q@01P0H5aD04Q4=01DD400C4Ph05aHB01HE4@H04a8>00h04A0=014@3P0>3@/06aXH01HE4`0^:RT0
71LG01H@400D3Ph05Ph?01XA4P0F3@h02@@401<?30804Ph;01/03`/800`81@0I5A805a<@01TE4P0@
3@/04Ph;00<0000A3@X04`l<01TE4P0S7a`06aLD00l;200H51405Q8?00L30@0C3``04Ph;00`81@04
00002@<301<=3@0I4a<03`T900h91`0>2@D00P0@2`L02`0?2P@05A0:02HQ6`0Q71P04`h:00`70`0B
3@T04@`8018=2@0>2@D03`X600<04@`801L040/701D;2P0I3`h04@L6018:200@20H050`:010;200D
40d06QHC01hJ5`060P40;2PU00T4000C3PX03PT5010;1`0B3@T03PT5010;1`0A30P03PT500l:1P02
01<>2P0601XE4P0;1P<07QTF01D@3@0<20H01P401P0A30T01P0A1`H04PP701<9200C2@P04PP70147
1P804`T80P0B20L301471P0501<9200D2PT04`T801471P0@1PD00P0B20L201471P0E01061@0?1`D0
4P/801HA3P0D3``03@P500h8200B30`03PP800l92`0B30h02P@600d72@0M5aT04PL;01462P0B1`/0
50T=01872`0@1@T04PL;008040D901/04@H:01872`0B1PX04`L;01872`0A1PX050T=01<:3@0>1PT0
71HH01<?400?2``02`T:00H41@0H4a@0208200D0000U7Ah07QDF00l61`0C2P/060h?00X00@0B1`P0
4@D703``<P0C20T00P0@1PD02`0A1`H04PP701881`0B20L04@L601061@0D2PT07A<B01X@3`0A1`H0
3`D4008040H50P0A1`H0300D2PT03P@301061@0E2`X03@<201L=2`07000030<00189100B20H04@L5
01881P804@L6100A1`P02@0=0`804@L601H<2`0B20L03`D401881`0?1@@040H501471P0201061@09
00l5100C2@P0308101<:2@0800004PP700l5100A1`H04PP700804`T800@04PP701471P0?1@@040H5
0P0A1`H00`0@1PD03`D401471P0501471QCooooo000Kooooo`0800001@0O7R@07QdR01<A5P0810X0
3PT=010:3P0A2Ph201<:3@0>01D;3P0D2`h040/?02@R9`0@3Q<040hA00`:300@3Pl03`d>00`:2P0P
7ad051<A02@S8@0F5A<2010<2`0300h:2@0=2@P03`/:00804Ph=00<04@d<010<2`0@30/00P0>2PT0
300B30`04`d=01TC4`0P6QX0618B010:2P0F41004`d=014;2`0@2PX04@/;018<30802`L600X04@d<
00/71P0T81l040`;01@@3`050@002@D401@@3`0:1PD04`l>0P0?2`X02`0A3@`03`/:00l;2P0B3Pd0
4`l>00`81`0A3@`04`l>014=300L61L05A4@00803`/:00<03PX900d9200?2`X00P0A3@`01@0B3Pd0
4@d<014=300@30/04@d<00@04Ph=00<040`;00X61@0:1PD00`0@30/201<?3P0500h:2@0810<030P7
00l;2P0D40l00P0A3@`02P0B3Pd03`/:014=300<20L03`/:01HB4@0I5A@04Ph=014=300@30/201DA
4003010<2`0A3@`04Ph=00803PX;03/040`=018>3`0C3a00510?00l;2P0A3@`05A4>01LC400E4@h0
4Pl:01<>200E4P/05QHC00X>3`0>5QX0D5]Q0>7Zl@18D5@03a<D01TI5`0<2PD07aXF00h:1`0C3`h0
61@C01TE500F4Q404Ph=01/G5P0C3`h05a<B04Q4@`0H51<05A@B01<B400A4@l04Q8@00h>300F5QD0
4Q8B00410@0H61T08R8T030_=00T8bP03Ph@00/;3@0F5QH03@d=02DU9@0E5A@06QXH01LG5@0E5Q40
51D@01HG4P0J6aD06a`F014C4002018D4@0901<E4P0D5Q<05QPE01PJ5`0I6aP061XG01LI5P0I6aP0
6adJ00806AhH00@05a`F01@I4`0L8A/051TC0P0N8ad0=P0K81X07B8L02@Y8`0V:bD04aXC02<Y9@0O
9B407bDU02`a=01CF5/0;C8e00dC4`0N928082HR01/R6`0M91l06b4O01hT8P0@61D08R/X01lX9@0N
:2D07BPT01hZ9P0P;2P08bl[02@`;00T;bh09Bl`02La<P0Z=CD0:SHf02/f>00Z=cT0:cTl02/j?@0/
>cl0;Ca1030oA00^?T@0;d170352B@0`@TL0<dE903E7B`0gBD`0=dU;03A6B00dATL0>D];03e?C`12
EE<0>di<03A7A@80<TE302H0>Ta<03A6B00jC4h0=DM903U;C`0kCE40@E=G03m@F00jBe<0BU]U05=T
KP1BHfd0?U1L04]MJ@1EIg<0DFAb045DHP1@Hg40DFMe051VM01>I780Cf9a04mRL01>HVd0BeeX04aO
IP19G6<0C5eT051RIP1?HFD0CV1S051RI01@HV80DF=S059TI01EIfL0EVQX05QZJP@0FF][00/0F6YZ
05m_KP1NKVd0G6a[05e]K01OKfh0HG5`06IfM@1`P7l0JWYi06inO@0206UiN00P06inN`1_Ogd0Kgmo
07>2Q@1jR8l0NHJ>086;U01nRI00OXV=07^5Q`1eOgl0N8:107j:R021SH/0R9BB08>=SP1lQXL0OXR9
08ZBU02<U9H0Ph^>08^@U027S900Q8b?08><S`2BW9h0SiVK08^DV@2?V9d0T9VN09BMY02HXJX209FN
Y`1<09JOZ02EWZL0VJ:Y09JOYP2DWJ@0U9^Q09NOXP2JXZD0VInP096GU`2?UI<0U9RG09ZOV`2MXJ00
WJ2T09fPY@2RYJX0Yj^^09jRX`2EVIT0Si>B08fAT02<THd0SI:>08nDT02CVY/0VJ2X09ZQY`2CVil0
RI6C08J>T025SXX0PXb407^5O01/MVX0J7=U06IaH@1QJe`0MGe`07b4N@1WL6H0H6YQ06=]I@1XLf`0
JWE_06]hL@1]NG@0J7A`06A`K01RKf/0HW5/069`L01QKg40HFmb065`M@1NKG80FVU^05EWJ01AHf<0
D6=O05=XH`1EIfT0G6ib05EWJ@1?HF<0EFMW04iNG012DTl0?Di804=BB`13DdT0?De30;W6_03Dg]H0
Lgee02df<@80:c@_00@0<c`i02Pa;P0U;R/0:34`0P0j@d802@0/=3D0;CHa02Tc:`0[=2l0<3Td02lh
<`0a>SL0:S<`02df<`0202`e=00k03<k?00c>cd0:C8a02H_;P0W<2l0:S<b02H_;`0M9BL092`_02L_
<P0Q:B`082L]01XQ9`0Z<SD0:C<d024[:P0N:2L08b`[028[:P0J8b807B<S01`Q800V:RT09R/W02DZ
9@0_=2h0@T<m01dN6@0Y:RD09RPS01XM6@0P9B40>Clk01@K600@6AH0<S/h02Xd<00H8Ah051LD02la
;P1OHEh08bDR01dO700B51407AlL018D4@0=3``0=CLd01HH5@0D5Q<06a/I01LG5@0I6AL07QhL01XJ
600E5A<06ATG01XJ600I6AL00P0G5aD01@0H61H05A@B01TH5P0J6AL061LE00805QDC03/05aHD01/J
600L6aT06QTG01PG5@0G5Q@04Q4=01DD400C4Ph05QDA01DD400A40`040l;014@300C4Ph05A@@01HE
4@0F5A806aXH01@C4@0A40h02@P600T5100E410050h>018<300H41406A0A01P?400O6AP0<Rh[02PT
8@0>2PL06ADB01PD4@0D40d00`0001TE4P0F4Pl06ADB051<B@0L61D04Ph;01<?300H51404`l<00l;
20091@8061@A01<?300F4Pl06ADB05=?C00o>CT05a4A018<300H4Q804@/;014<2@0201@?2`08010;
1`0=20804Pd701lJ500N6AD05Q4=00`70`0@2`L201D@300E00d8100>2@D04Pd901<>2P0A30P03`X6
01471P0F30/050X901H>300@20H03`L500@0000I51401`<001HB3`0=2@L040`900/60P0E40`02`H2
00<04@`80P0;1P802P0E40`05Q4=00h91@0@2`L020<001PC400400003`X701@?30091046010;2006
01471P0B20L04`T801<9200B20L04@L60P0C2@P201881`804@L6100B20L201061@804`T80P0B20L0
4`0A1`H040P601H?300J5A8061<@014<2@0A2`/050h>00l92@0A2`d040X<00/51`0400003PP:0105
2@0?10P04@H:01@93@0C20`00P0A1PX201052@0K01462P0B1`/04PL;01@8300E2Ph04`P<01462P0B
2@`03@H8018<3P0:1PL03@X;00H41@0H5QL0FEEE03H`<00D3Ph081TI01<:2`0800004PP901@:2`0?
1@H05@X<01041P0U6A/03P<3008040H500<04@L601881`0B20L00P0B20L01P0@1PD04@L601D;2P0B
20L03P@301471P804PP700h04`T801@:2@0@1PD02`4001L=300F30/04@L600X10@0H3P`04PT400d4
000800001`0000l510804@L6100A1`P0500>10<04@L601D;2P0C2@P04@L601<9200?1@@040H50147
1P0B20L04`T801@:2@0@1PD02P0001X@3`07000040H500`20@0A1`H04`T80P0D2PT0100C2@P04@L6
00h40`0@1PD201881`0401061@0>10<04PP701471P8040H500<04@L601881oooool04oooool001_o
oooo00P0MWAm02<Q:@0E4aT05Q<I018>5@0D3a@04@X@014:3`804PT>00l050/@01D<4@0A31803``A
00d;3`0;20/03``?00d;3P0<2@X0518C00X82@1=BdX04@h=00`:200?2`X00P0C3`h00`0@30/03`/:
010<2`06010<2`0701<=3@0D3Ph050h>01D?3`0C3@d04P`<010:2P02018<300D01<=3@0@2PX03`T9
014<2`0@2`/06A@D014=300c;Rh05Q8A02@P7`1<B4L04`l>00l;2P0L61L0510?01LC4P0D40l04`l>
00d9200>2PT2014=300@00d9200A3@`03PX900P40`0C3`h04Ph=014=300C3`h03PX900l;2P0C3`h0
40`;018>3@0C3`h04Ph=010<2`@04@d<010040`;00l;2P0A3@`040`;00l;2P0D40l04Ph=014=300@
30/05a<A018>3@0:1PD06QHD01@@3`0E4A004@d;0P0A3@`02@0>2PP04@d<01HB4@0T81l03`/:01PD
4`0D40l09b<R01<?3P02018>3@0;01`H5`0S7ah05Q8A010<3@0C3a005A4B01@@4@0C3a004`l>014=
300B3Pd00`0D40d0=00D4@`04a0:01dJ500I6AH041@D010H6`0Z=SX0OXN<02P`<`0730/04Q<A010>
2@0C40/040`:01<?3P0E4A005Q8A01LB4@0F4A0050l?01<?3P0N6QT06aLF01HC4`0F51@04Q4?01@D
4P0A4@l05aLG00h>3P0H61P071`M01@D5@0E5AL03`hB03Dd>00=3@l04a<D01hN7P0F5QH0OGem030`
;`0D51805ADC01LH4`0H6A@06AXE01TJ500H6A@05aTF01`N6`0J71T301DG500301LI5P0K7AX06adJ
00806A/H00L06adJ01HJ500L8A/07B8L01PM5`0K81X04QLA00807b@N0P0H7AL08`0L8A/06b0J02he
;P0O9B00;C<_01XP7`0L8B<0HFIX03<h>P0H7Qh06AlM01lU8@0O9B008RPT03@j>@1EGU`06b@R02H_
;@0`>SP07bTW01l[:00P;2T08bl/02@`;@0U<Bh09C0_02H`<@0X<S<0:cHg02`g>00/=cT0:SLj02/i
?00]?3l0;Ca00080;3]00340;3a102m1AP0b@dX0;d5603A6BP0fB4`0<dE803=5A`0fB4X0>4Y;03M9
B@0kCDd0@eIE03U<B`0gBDP0?E1>03]>C00jC4/0@59C03a>C`0iBdd0@E=G03U;C`13EEX0BeaT03a=
EP13Del0@eAO041@G014EV80BeeZ04QJI`1XNhT0Sj:`06j1S`1:Gfd0CF9`04mTLP1@Hg80Bei[04QK
IP19FfD0Cf9Y04]NI@1CI6/0G6ic05a^LP1PLWH0DVAV0080DfEU00<0E6IV05MYJ@1IJf/00`1IJf/0
1@1JK6`0G6i^05iaL01OKfh0HG5`0080Hg=b05L0HW9a061`K`1TM7<0KGem06AdM01YNGT0KGel0720
O`1cPh<0KWen07J5Q`1lRXl0OX^B08B?V021Ri@0OHN>07^5R01gPH80Mh5o07n:QP22SH/0PHb<08>>
SP21Rh`0P8Z<08F?T@26SY40R92C08ZAUP2:Si@0Ri2F09fUZ@2f_/80Q8fB08F>T`2?V9d0S9FL096J
X@2CW:<0VJ:[09FNY`2GX:T0V:6Z09FNY`2FWjH0V:2X09JOY@2FWj<0UYjQ09FMX02:Ti<0Ri6@08^A
SP2BUi@0VYnK09bQWP2JWj80UIZN09VNX@2OY:L0V9jN096GUP2=Ti40Ri6>08fCS`2AV980SiF@08N>
S`29T9L0S9BH08R?T`1oQhT0OhN80829Q@1nR800Mh5h06QbIP1QK5h0GVUJ069/G`1YLVH0KWU_06Yd
J`1UKfL0KWUb06iiM01VLFd00P1VLVh0:`1SKf/0HFeZ05IUH@1NKFT0IWAd06IdM@1OKG00G6]`05a/
LP1GJFd0DfEV055TH`1@I640CF5N04]MG`1JK700EfU/04eMH01DI6H0CE]K04]IE`0mBdH0>DI003E3
>`0b@3L0AE5805=LEP0nAd40:C8^02lh=00^=c<0:c@a02</:P0X<Bl0;CHe03U2@@0g@3l0=Sho02/d
<00W<BX0;3Da034j=P0]=S800`0_>3H01@0Y<S409Bh^02`d=@0]=CL0:C8a00809c0_03H0:34`02Pa
<@0U;Bl0:C4c02L_<@0Q:B`092``01/S9`0R:Rd082XZ028/:`0P:RT07bLX02@/;@0]=C@09B/[02<X
9`0X;2/08bPT024V8@0f>CD08b<O01lP700U9B80824M028U8@0J7Q`05a`I01hU8P0W<2d05b0M01dV
8`0I8Qh06QhJ01lQ7P0U9b@06adJ01dO700S9B8071hK020R7`0Y:bP0[:j[055CD00Q8b006QXH01LG
5@0H61H06ATG01PH5P0G5aD06ATG01/K6@0J6QP201LG5@0C01TI5`0G5Q@06APF01PG5@0F5A<05aHD
01TH5P0F5A<05aHD01XI5`0L6aT05aHD01<B400D4`l05QDA01<B3P0E510051<?018A3@0501@C3`1R
01<B3P0E514040h<01<A3`0R81d03@T801`G5P0C3P`04`d=01PA4@0B2@T08QTJ069LFP16@Sl06ADB
01HB3`0E4@h0510=018>2`0B3P`05A4?00l;2@0K5a@0M71]02TV8P0>2`P030T7010=2`0?3@T04Ph;
00`81@0F4Pl03PT6018>2`0G4Pl0OWUf05mIF@0F41004P/<00d51P0E3`l04@`9018<200A30P04P`9
01<=200C3PP04`d801D?2`0O6QH06A<?00d60`0B3@T04@/7014:1`0@2`L040X6014:1`0A30P050d:
01D;2P0F30/04@L601L?3@0D30X07ADC05I?C@0F4@h03@T801D@3@0Q7AX03@T700d8100E3`/02PD1
01L@3@0?2@D050l;01@>2P0D3P/0<bhZ03@]:P0C3@T04Pd900l91P0B3@/050l<01/D4P0I4a405a8?
014:200A2`P040/8014:200A2`P04@X801471P0B20L201<9200401881`0A1`H04`T801<920804PP7
0P0A1`H00`0D2PT04PP701471P0201061@0301471P0E2`X05@/:008050X900L04`T80189200?20H0
4`d:01<>2`0A2`X04@X:00804@/;00`040T;018<3P0T7R005@d@00d5200A1`/040D901462P0C20`0
4@H:00l5200A1PX201062@0E01472P0B20`04`T<0104200?10L04@H:01472P0?1PT03`P:01D?4@0;
1`P0514B010>3`1HEEH0j>KV09>=S@0_9bP07A@E01L>3`0:0`<050X;00804PP900@04`P:01<72@0>
0`@04PL80P0@1PD01`0A1`H04PP701881`0@1PD04@L601881`0?1@@00P0A1`H200l5100@01471P0B
20L04PP701<9200E2`X0>2h]0516A@0@20L04`T901@;2P0?1@<04PP601891@0D2PP05`d;01471@80
4@P6100A1`P00`0?1@@040H501471P0201471P0?01881`0C2@P04PP700l5100>10<03`D401881`0D
2PT04@L602`R8@0>1@@05@/;01061P0?1@@04@L600804`T800@04@L600l5100A1`H04@L60P0?1@@2
01471P0601<9200A1`H040H501061@0A1`H04`T85?ooool001_ooooo01L0BdI=01`G7@0A3100510A
014;300P6aP03@P5018<300<1PP06A<G018<4@0@2A0040X>014<3`0C3a005@lA018=3`0=2@X05a4C
03<^<00P71d04@`=01H@4P02010:300;00l92`0;1@L03`T;01@>400C3@l03PP:018<3P0A2`d040X<
01@>400H4Q@00P0?2@/05P0@2P`04@/=014;3@0A2`d05@lA018<3P0C3@l050h@01<=3`0A2`d050/>
0189300C2Pd04``>0189300>20X04`d?02LS900>2P/05A4B00<0000B3@h2010:2P05014;2`0B30`0
4P`<014;2`0B30`00P0D3Ph0100A2`/040X:010:2`0A2`d301<=3`03014;3@0@2P`04P`>008050h@
01h04P`>010:300@2P`050h@00l92`0D3Q003@L9024K7@0l=SP04P`>00d72@0D3Q007QPJ03La<`0I
518040d800h:1P0B3P/05Q<>01DA3@0@30T04a0;01HC3`0E4@h04Pl:014=2P0E4A004Ph=010<2`0A
3@`201<?3P0<02HR8@060P403@T802DQ800^:RT04Ph=01H@400C3@d0618B00@0000?2@T06A<C0P0F
41009@0E3`l050h>01<=3@0B3@/040/801@?300B3P/04@d<01HD500A4A404a4B010>3P0@3`d05A4>
01LC400E40d040`;014<3@0B30`050l<01TA3`0J4Q005@d;01PC4@0E4A006ALH01DE600>3Q005A<D
01TH5P0A40h03`h<01@C4@0A40h05aHD01DC4`0I5aP00P0O7Ah04`0G5AH05aHD01/J600M71X06aXH
01LG5@0F5Q@0820N03do?00B51405ALD02T[:00I6aP0ATM500d=2`0D51806QXH014A3`0J6QP00P0M
7A/301`L6P0301XL6@0H6QL05QPE00806adJ00h06Q`I020R7`0F61D08bDR01lQ7P0K7AX07b4N02hc
;@2j_kP0=c`e02T^:00K81/07R<O01DJ5P80720O01808bLV01lS8P0N8R408BLW01PP8P0M9BL0<3Tj
02La<P0K9BH072LW02Da<@0H92@0938b01l];@0S<C409S<e02Pc=`0Y=3P202Tg>P0A02Xh>`0/>d00
<3m403A3B00fB4`0;d5502do@`0`@TH0<dE703E7B`0bA4H0<49403A6B00gBD/0<dE70394AP0eAdT0
0P0iBdd0;01KJVl0AEAI03Y9C@11DE40AUIE03M7AP11DE00=TI503]:C00jBDh0?4]B03m?EP1>GV/0
A5IT04IHIP17FFL0?U1N04IHIP1EIWH0AUMW07N8V03Nkol0T:6a04MHI`1=Gf/0C5iX04QJI017F680
B5US04iOI`1AHVX0DfA/05Y[L`1;G6@0BeaS05Y[LP1JJF`0FFQ[05YYK01LJfh0Ff]/05MWI`1MKFd0
GVi]0P1OKfh2065aL00V06=cLP1TM7@0Jg]k06EeM@1WMgP0Hg9e05a[KP1[NWd0IgIi07j=TP1TLgP0
NHR=06]hOP1lR8h0PhjD07j9S`1oRY00R96F07n8S@1nQhX0OhN906aeM01jPX00NH9o0829R026Si00
QHf?07n7R@22RX`0R92B08fEU`25SHl0QXj@08>;SP2j`/D0];bo0:je_01nQHd208fDW080TIRP06H0
TYVQ09>JXP2@Uil0UIbT09NNYP2AV:00UIbT09NLXP2AV9h0TYNL09>HW02DVI`0QXb;08B:QP2<Th`0
OhIn09>JTP2KXY/0U9RH08b@T`2IWIh0U9RI09>GV02OXj@0Rhn@08>7R02<T8l0Si>B08b@S`29T940
Q8b>0869R`1oR8L0O8F207V2O`1hPG/0Lgee071jL@1[MFX0IFmT06YdJ@1/N6d0IG9Y06IcJP1YMVh0
KGYc071lN01]NgL0IGAa06=bK`1SLW00HW5^05e[J`1LJVX0IGEd06QhN01LK6`0FFUY05i]L01OKW40
EfIY059RHP1HJ6P0FF][05MXI`1?HF<0BUaP04YKG@1CHF@0EUmT04aBE@11ATT0?D=303<g=`0/<2l0
;c@`03Tn>`0a>ST0<3Xi02li>00[=C@0:S@c02`f=@0X<S<0;SPi03Q2@`0i@d@0=T1103<m?P0^>3T0
;cTj02@^;`0_>CX09Bl`02La<P0[=CH0;cTj02hh>@0Y<cD09S0b01hV:00T;B`201dS8`0R01XP800W
;Bd0;cDe03i4A00/<C<082DX02<X:`0U:Rd08BLW01lU9@0W;B/08bTW028X9P0U:RT08BDT02DY:00T
:2L07b<R01/O7P0N8R409bTX01PF6`0L6Ql081lT024P9@0O82<06alP028V9`0P9R@06R0L01LM6@0C
71L06R<N01PM6@806QlK01805Q/G01dR7P0H7AT05Q/G01hS7`14BDD0>Chj02hc;`0A4a006a/K01@D
500E5AD061PH01hN7P0O7al04Q8B01TI6@0K6a/201@D500?01/K6`0L6aT071/I01@C4@0A40h05QDC
01LF500F5A<05A@B01<B400@3`d05A@B00/:200C3`h0510?00<05Q8A01@03@T803<_;P0B3Pd0510?
01PD4`0U8B004`l<01@A300G4Pl061@@01TD400H4a005A0=01D@300F4@h061<@01LB3P0F4@h07APE
01/E5@804P`<05005Q0@01@>3P0B30`040X:018<300G4A404`d=010:2P0D4Q000P@101`N7@0<3@`0
410>01HD4P0B3Pd05Q0@01PB3`0D30X04PX801L=2`0G3@`04`/901@;2P0F30/04PX801D<2`0B20L0
4`/901071P0@1PD05@d:01D<2P0F30/04PX801H=2`0F30/03`L50189200F30/05@d;01<:2@0C2@P0
4PX801<9200I3`h05P`;01@:2@0C2@P04@L601H<2`0]8b804@T701D=2`0K4a404`/901L?3@0E3@/0
4PT8024I5`0?1@@04PT700X2000D2PT03PD301D=2`0C2@P04`X900`40P0900005`h<01<;2@0I3`h0
5Pd<01L?3@0?1@@05Pd;018:200G3@`04@P601D;2PL04PP700X03@@401T?3P0@1PD06@l>00`20@0?
1@H0710B01T=3`0?1@H06`lA0P0C1`T0;P0I3@l08QHH01`@4P0@10H03`D600l71`0G3@h04PT:0108
2@0Q5QX03`H901H<400A1PX04@P;01H<3`0@1@T02@0300h51P0E30d06A0A01892P0E30l03`T;01<;
3P0?2@d030H:01H@500300803@L:01/B5@0A20/04`X=014;3@0?2@/03PP:010:300=1`T05@lA00h:
2`0f<380WYNI06AKGP0I3Q805P/?01P=4@0?10P201462P0@01872`0C20`04@H:01052@0B1`P03002
01T=3`0C1`T03@4301T=3`0C1`T06`lA00P0000@1@H05PX<0186208040@601h05@T;01@8200B1PH0
4PL500T0000A1P@05@T90104100?0`<04PH801X<300C0`@04@@401<9200A1`H04``9014<200D3`/0
40/800h8200B30`030D601@:2@0A1`H02@4000/1000G3@`081HE01D;2P0D2PT201881`0>01D;2P0D
2PT05`/=01<72@0A1@L04`L90186200=0@<03P840186200C1`T04@D701041P0A1@L<018621Cooooo
000Kooooo`0=020I8@0C318081XL02DO8@0D3Pd03@P401XE4@0D3`d0618B01PB5P0910P04@XA01<=
4@03018<3P0=01<=3`0A2`d02`D701hH6P0F41804P`>01H@4P0@2P`05@lA01@>400?2@/04@/=01@>
4002018<3P8040X<0P0B30h0100A2`d03`T;00l92`0@2P`3014;3@0:01@>400B30h04P`>01<=3`0B
30h040X<01@93@0E2Ph050T=01<:3@8050/>00`0618D014=3P0810D040`=01/G600D3`l040X:00h8
200L5QH05Q0@014;2`0C3@d2010:2P804@/;00H04P`<014;300A2`d04P`>01<=3`0B30h2014;3@04
018<3P0C3@l04`d?01<=3`8050h@02/05Q0B00h82P0A2`d02P@601<=3`0X8R@03PP:00/51`0D3Q00
6aDG02lY:`0B3@/03``7014>2@0?30L030T400T60@0@3@P04a0;01HC3P0E4Pd0514<01DA3@0C3`h0
4@d<018>3@0C3`h0510?018>3@1EDE00;BTX01HB4@0D40l071PG010<2`0?2@T050h>014;2`0@2PX0
30H6018<300E3`l050h>00804`d=00T050h>01D?3`0D3``05a8?01@?300@2`P05A0=018=2P0F4@h0
0P0C3P/04`0E40d05a8?01D@3@0D40l050l?01<=3@0E3@/05`h<01P>300O5aD05a8@00T81P0B41<0
3@hA01DF6P0?3@h05aHD01<B400@3`d00P0D4a405`0B4@l04A0>01@C4@0H5aD06APF01DD4P0G4a80
6ALE01TH5P0G5Q@05A@B01@D4P1:BTP0OX1m02/]:P0=3``05a`H00H;1`0L71X04A4?02HV900Z:RP0
61PF00806ATG00L06QXH01/K6@0M7A/07AdK01hN700I6aP05aTF00806adJ00h06Q`I01lQ7P0L7Q/0
7b4N01/M6P0L7Q/06adJ02DW8P1PIEh05a`E020U7P0K81X07b@N01XO6@80724M01808BHS01dQ800M
8B008BHX01XR9@0M9BP0;3Dh02La<`0P:R`07BLY028];`0M:b`082h_01HT9@0S<C80934d02Td>P0W
=3X202Pe>`0:02Lf>`0Y>3d0:CPm02Xl@00_@DD0;3i202i0A00cADP0<TA60353A@<0<TA600<0>D]=
03e?D@0kCDl00P0jC4h0;00iBdh0>dYA03i=E00mC540?4]>03e=C@13De80A5AC03i>C@15EEH0AEAK
04ABF`14Ded0AEET04AEI@16EfL0B5UY04]LK019FVX0C5e]05=TM01AHW80M8FE05a]O@1:FfX0C5eW
04aMI@19FV80A5EM04MHH01@HFT0BU]S04]LI01>GfL0EVM_05QYL@1EIVh0G6]`05a[KP1JJF`0F6MZ
05MWJ01GIfL0GFe]0P1NKVd05P1OKfh0HG5_065aL01RLW80Gfm_065aL@1NKG00I7=f06IeN01^OH80
JWUn08JEVP35e=/0VZV`06QgOP1^N840NhF>08B>U`25SYD0QHjD08J?U01mQHP207b4QP0L07EkN`2A
UiH0WjFS08^CU@28T980P8R:07^3Q@1oQhT0Q8b>0828RP24S8h0S9BF08::S02JXZ@0RY:E08J=U02A
V:00QXfE08N>UP2CVZ80QXfE096HX02?UYh0SIBL09JMY@2HWjL0TYVQ09RLY@80VIjT04H0UibP092E
V02;TI40R8j=08B:QP1oQWl0PXV108ZAR@20Qgl0T9BD09:FU`2?Ti@0T9BE096EUP2:SXl0OX:30824
Q@2?Ti@0TIFF08b@T@28SXh0Q8f<08:;RP21RXP0P8V607j7PP1hPW/0L7Yb06ihK`1ZM6X0I6iS06Qb
I`1ZMfd0IGA]06AcK01VMFl0IgIa06UhL`1WMW80IGAa06YhN01^O7`0JGMg065_K`1MK6`0HG5a05m_
K`1HJ6P0FFUY05YZJP1IJFT0F6QX05MWI`1FIVH0EFEU059RHP1@HVH0BeeQ04aJG@1BGF40DEQN04A8
C015ATX0?d1403Lg>@0b=3<0=CLf03`o?P0T;2h09Bl`0P0Y<c@0>@0[=CH0;SPi02Pb<`0[=CH0=3ho
03Y4A@0h@T<0;SPi02dg>@0c?Cl0:C<e02hh>P0kADL0<C/m02li>`0b?3h0;cTk02Tc=@0U;c407BLX
02T_;`0T:RX0:S0`02le=@0T:RX07R@T02D[:`0R:2P07bDU020V9P0U:b/09bd]01lS8P0V:RT08bLV
028V9@0T:2L08BDT02P/:`0U:BP07b<R01`P7`0O8b809BHX02DR:@0U8BT08b0W024P9P0Q8BD0824U
02<W:0093Ph0:c4]01LM6@0P9b<06R0L01PM6@0202<X900O01HK5`0H7AT05Q/G020U8@0M8Qh0Ada8
02@Y9@0G71P07b4N01TI6@0K6a/07AdM03lo?`0c<c<04a<C01XJ6P0D51@05QHF01LG5`0I6AT07AdM
01PG5@0=30X04A0>02@S8@0N7A/03Pd;01PG5@0M71X05aHD00l>300201TH5P0=01@@3`0E4A005a<B
01LC4P0F4Q40=C4`08=oOP0^:RT03PX900X61@0810<071LE01LB3P0201PC3`0501LB3P0F4@d04`h:
018=2@0C3PX00`0D3`/0700<1`H07ALG03D_;`0V8200208200d71`0G4A4050h>01H@400E3`l04P`<
01XD500O7Qd061`K00L;2P0F6AP00`<3010?3P0S7Ad05@l?01D=2`0J40l04`T801P=2`0G3@`05@/:
01P>3@0J40l201H<2`0?01471P0E2`X050X901881`0D2PT03`D401D;2P0C2@P05@/:01P>3@0F30/0
7Q@C01H<2`0E2`X050X900804`T801L050X901<9200B20L05`d<01P>3@0A1`H03P@301dC4P0A1`H0
5P`;01P>3@0C2@P05P`;00l5100C2@P060h=00l5100K4A005P`;01@:2@0B20L05`d<01061@0201D;
2P0<01@:2@0K4A0040H501881`0>10<040H501881`0@1PD02P0001881`0A1`H04`T81P0B20L04P0I
3`h03`D401D;2P0B20L07Q@C01H<2`0B1`P050P:01<72@0=0@<06Ph@01@82P0B1PP05@T;01/?4@0H
30h04PH801@82P8040D902X05P/?01482P0@1@T03`@801052@0>0`L03`@801@93@0G310060h?01H=
3@0;0P<01`0001@;300D3Q0030H801<=3`0300802@@800H21@0I5a`04@/?00H00P0B30h04`d?00h8
2P0<1PP03PT:00l92`0G4A<0618D00T31@0B30h0=bha02LL800B1`/04`P<01462P0<0@D03`@80105
2@0A1PX201872`0@01462P0D2@`04`L900P0000E2@/05`/=00P0000A1@L02@0001/?4@0L41802000
01dA4`0B1PT04@D901<72@805`/;0P0B1`D05`0E2PP05@T90104100@10@050L901T9300I2@X060/;
01@:2@0@20H040/701DB3@1?C4L0?3Pe00<0000@2PX040X;00P0000L4Q406Q0?01`B4@0900003`L6
00<04PP700D04`T801@:2@0A1`H05PX<01@82P0201<72@080186200?0`D04PH801<72@0B1PP040@6
01451`0D20X60186200601<72@0B1PP04@D701451`0B1PP04`L95?ooool001_ooooo00h04@XA010:
3`0B30h05@lA01D?3P0B3@X04@`9010;2@0=1`L06Q@H03H`=@0G4AH04`dA01<=3`8040X<00l04P`>
01D?4@0<1PP03PP:010:300D3Q004`d?014;3@0G4A<05@lA010:300A2`d04P`>00l92`0E3a400P0@
2P`00`0B30h040X<00d72@06014;3@0O01<=3`0@2P`040X<018<3P0@2P`03`T;01D:3P0G31005@X>
0189300G3Q4071<F01D?4@0?2``040`=01PD5@1mNGX0B4=300l92@0=1`L07aTI01D?3`0=1`L06Q@D
01/E5@0C3@d04@/;01<=3@0B30`04@/<018<3P0301<=3`04018<3P0C3@l04`d?018<3P<04@/=0180
4P`>01H@4P0A2`d040X<014;3@0>20X05Q0B01<=3`0?2@/04`d?010:300M5aT02PD4010<2@0C3``0
510=01TE4P0U8Ah201@@3@0401<?300@30T040`901<?30804Ph=00L04`l>01DA400D40l040`;01PD
4`0<20L03`/:0080510?00T040`;018<300L5QH04P`<01dG5`0?2@T04`d=01D?3`0D3Ph00P0B30`0
1P0D3Ph0618B01<>2`0D3``04Pd:014<2@805A0=01@05Q4>01@?300C3P/05A0=01HA3P0E40d05a<B
01LB4@0E3`h05@d;01H=2P0F30X050`901LB400A40h06QPK01XJ7P0J6al0518C01HE4`804a8@0P0G
5Q@02`0C4Q005A@B01DD4P0E51805aHD01TH5P0I5A@06ALE01LF500E518051@B00805QHD00/06adJ
00d?300L7Q/03Q<?01TN6P0I6AL06a/I01`L6P0J6QP06ATG01dM6`0201/K6@@06QXH00D071hK01XL
6@0K7AX06adJ01XL6@0201`N6`0R01LI5P0F61D07b4N01XL6@0N81`07b@N01LL5@0S:2406b0J01XO
6@0N8ad07B8N01dQ800O8b807R8Q01dQ800N8bD06R8U01`T9`0S;2h07bT[024[;@0T;S007BPZ01d[
;00Y=cP0=TA504ABD`0U<SH0:3<i02Hc>@0W=3X0:3Dk02Lf>`80:STn00`0:C/o02`n@P0[?D40;T14
03A6B@0a@dD0<49403A6B00fB4X0<dE703I8BP0kCDl203U;C@0@03Y<CP0iBdh0?DaB04iMI013DUL0
AeII03m>D00oCe00?4]=03m>DP16EE`0BEMR049@G00oCUd0?dmN04MII`80AUQV00T0Cf5_04QJJ015
EfD0Cf5_04]MJ`16F6H0BE]Y04YLJ@1:FfD00`19FV802@1<GFD0DV=[059SJ`1GJ700CUmW06enQP1/
OHD0DfA/05IUJ`0205a[L00305UXJ`1JJF`0Gfm_0080GFe]02l0GVi]05m_KP1PL6l0HG5`05i^KP1O
Kfl0H71`06AcMP1UM7L0IgIi05m^L`1/Nh00RiZO0;O6c@2DXjX0LH2707R2R`1jQ8d0OXRA08:;TP23
S980PX^@07n7RP1iPH@0MGeo07IlO02;TI00TINE07b4QP1mQHL0NH6307j6R02=UIL0UYjP08fEU`25
SHl0R92B08::S02:TY@0Ph^>092GWP2=U9`0PXVA08ZAV@28SiL0S9>K08jEW@02092GW`0H096HX02B
VJ40T9NO092DW@2>TiT0TIJL09>HW02AUYT0TINH08fCTP25RhP0QXb708>:P`29T8P0Z[6Z09ZNWP29
SHh0SI6B08nCU02:SXl0Q8R907f1PP21QHH0RHf>0P2:SXl05P2:T900Qi2?08B=S022RhT0OXN407Z3
OP1cO7H0JgE]06YdK01ZM6/0IFmV06E_I@1YMF`0IgI_06IeL01UM6l0I7=^06AcL01UM740J7Md06Ug
M`1VM7@2065_K`0L069aL@1NKVh0EfMW05IVIP1LK6`0FFUY05EUI@1IJFT0FVYZ05ATI01?Gel0Be]K
04eOHP1=GV80D5iQ059LH01<DeT0?T9703Hg>`0`<CD0:R/]02`^;@0`<S40;S<b02L_<@0Y<c@0;3Hg
02Xd=@80:38c00<0;cTj02hh>@0d?Sl00P0mAdP03@0a>c`0:cDf028/;@0`>S/09S0a038l?@0e?d00
;cTj034k?00]=cP0:C<d02/e=P0W<3400P0V;2`01@0P9RH0;C<c02hd=01HGUh082HV0080:2h^00H0
8bTY028X:00W;Bd092PW02L[:P0R9RD201lS8P0F01hR8@0Y;B`08bLV01lS8P0P92<08RHU02@U9P0X
9b/09B<X020N8P0O7R<08R8V02DV:00J7Ql0JVi^02T];02?UI@09R`Z01/Q7P0O8Ah061XG01TK6080
7R0M01407b4N024S800M7a`07b4N01LI5P0O8Ah04Q@A01PH600F5QH05ADE03dm?@12@T80ATI6030`
<00I6AT05QHF01PH600201@D5006020O7@0g=S@0;Rd[01HE4`0C4Q006APF0P0E51801P0D4a407QdK
02HU8`0V9B<05Q8A01LC4P8061@C00P05a<B01@@3`0R7Qd04`l>01PD4`0@30/06QHE01@@3P<061<@
00@05Q4>01D@3@0F4@h05Q4>0P0E40d00`0G4Pl061<@01TC4P0201/E5@0N01D?3`0@2PX04`d=01D?
3`0D3Ph05a4A018<300?2@T07QPH05eLF`2e^KP0>S`k00d>3@0`<3004a4@03D_;`0K5AD04`/901/A
400B20L04`P601D;2P0C2@P060h=01X@3`0E2`X050X900h40`0C2@P060h=0P0I3`h201H<2`0801D;
2P0F30/05P`;01H<2`0M4a805P`;01D;2P0D2PT201<9200801D;2P0?1@@05`d<02@J6@0M4a804@L6
01061@0<0P4301<9200J01D;2P0A1`H04`T801L=300?1@@04PP701H<2`0G3@`04PP701<9200F30/0
40H501X@3`0L4Q407A<B01lE500@1PD04PP701471P0E2`X0@CLf02XP7`0=10<040H501@:2@0K4A06
01881`0f01471P0?1@@050X901<9200G3@`050X901D92`0B1PP06@d?0187200E2@/040@60186200A
1@L04PH801<72@0D20X05`/=01872`0D2@d03@@601@:3@0D2@d05@X>01`A5@0F2`l04@H:00`11@0?
10P04PP901<92@0A1`P060h?0107200b:bd0Qh6303La<`0@2`l061<G00l:3P0D3aD040X>00`7200<
1PP0618D02LQ8`0@2P`03PP:00l92`0C3@l02`H7018<3P0I4aD03PH80P0G3100100;0@@040D901H;
3`0B1`/201052@0@01462P0B1`/050T=01<72P0>0P@05@T;01051`0>0`@060`>01L;3@0:00405`/=
00h41@0V6Q`04`T:01L<3P804PH800H060`<01T=3@0C1`L050T70146100@1@<20146100L01@81`0D
1`L05`X901461@0:0@003PH3010;1`0?2`T04@d<01D@3@0A2PX03P@50107200B20L05@/:01071`0Q
5aH05`h=01@;2P0@1PD03`D401471P0D2PT04PP700l5100C1`T05@T;01H:30804PH800L04`L90186
200B1PP040@600h2100@10H050P:00H04PH800H050P:0186200@10H040@60186200D20XDooooo`00
6oooool04@0@2A005PlE018<3P0@2P`04Pd;00`7100A30T061<A00T30`0C3A40?CHl00d72`0?2@d0
4P`>01<=3`0A2`d04P`>00805@lA00D050h@01LA4`0B30h03`T;01D?4@02018<3P0;00l92`0A2`d0
4P`>010:300A2`d04`d?014;3@0?2@/04@/=01<=3`0B30h01P0A2`d200l92`0?010:300?2@/03@L9
01D:3P0H3A405@X>01482`0H3a807QDH014;3@0?2``01`<400d92P0c;c0040/<008050h>0`0?2@T0
1`0J51@07aTI01D?3`0B30`050h>018<300B30d01@0D3Q000`0B30h040X<018<3P0201H@4P0:018<
3P0@2P`050h@01LA4`0B30h05Q0B01TC5@0A2`d04`d?00d72@804`d?00l08A/M01PC4P0D40d03@T6
010<2@0G4a007QXG01@@3@0C3``04@d:00l;200@30T05Q8?01HB4@0C3`h00P0A3@`2018>3@0H01DA
400G4a805a<B01<?3P0=2@P04`l>014;2`0>20P04P`<00X4100F41007QPH01TC4`0F41004P`<010:
2P0B30`05@l?014<2@0@2`P04Pd:01@?300E40d05a8?0P0D3``201<>2`0F01@?300E40d05A4@01DA
3`0D3``05Ph;01P?2`0I40/05`l<01<>300:2@L071XM07enP@2HVI/0:bTZ01PG5@0@3`d05A@B01LF
500C4Q0040l=018A3`804A0>01P04a8@01HE4`0J5QD06QLF01LF500E51805ADC01LG5@0E5A<05ALD
01PJ5`0Q8b006b0L01TN6P0F5Q@07AdK01PH5P0I6AL06a/I01LG5@0L71X06a/I01XJ600I6AL201PH
5P8071hK03@06Q`I01/M6P0L7Q/06adJ01XL6@0I6aP05aTF01dO700J71T0828O01XO6@0Q9R007R<M
01`Q6`0M8Qh09BXV020U8@0P92<07b<R024U900Q9BH07R<U01/R:00O9R`07RH/01TR9`0L9BX09S0d
01lZ;P0M:bh0;ce004ABE@1?GF00930e02D`=P0T<CL09c@j02Xg?@0Z>Ch0;3]002dl@@0^@4@0<TA8
02i0A00_@DD0<D=70394B00fB4`0=dU=03I8C00gBDd0>D]?0P0gBDd0;P0kCE40?e5E041BEP0lBe00
BEQM03Y9CP1=G640AeIK03a;D010CeH0AeEN04ECG`1=FV/0AeAU04ECI`17EfL0AeUW04YLJP18FVP0
AeUW04iPKP1<GV`0?U1N04EGI@14EV@0AUQV04YLJ@1:FfD0AUMO04UJHP1FIfl0FFYb051QJ@1>GfL0
GFif051QJ@1RLg/0FV]c051QJ01AH6L0G6]`069aMP1PKg@0GVe`065`L`1LK6`205e]K@0905i^K@1P
L6l0H71_06inOP1/O7`0HW9b06YiO01TLgH0IWEh0080J7Ml0140IGAi07B3RP1`OhH0MHB;07AnQ`1h
PX/0O8J?08><T`2FWjD0Z;6f08^CUP1mQHP0KgMi07UoO`1kPH00KWAb07=kO@020828RP0F07Z2Q025
SHl0TIVK08ZBU024S8h0PXZ<0828RP1lQ8H0QhnB0:bc^@39d=H0W:>Y09:IW`2@Uid0R8nE09FLXP2S
Z[00XJR^096HWP2>UI/0U9^Q09JKX@80UIZP0140SI:F08bAU02BUiX0Ri6@08>9Q`2:T8`0QH^608jE
SP35blL0VinO07j2P`2<T940TIFF08F9RP27Rh`0R8b=08Z>S`0208R<S@0>08V=SP2;TI40R96@08F>
R`21RXL0NX>007AmN01^Mg80JG=[06QbJP1[MFd0Ig5Y06I`J01XM6`306IeL00<06EdK`1TLg00I79a
06=aL@1PKVh0GVa]06IdM@1bP840K7]k05e]K@1KJf/0EVIV0P1IJFT00`1GIfL0EFEU055QH@0205=S
H`0@04aLG018EeX0BUUL04mLG`1;EEL0@TY=03Hj?P0a<SH0;2da02PY:`0];S00;S8c02/`<00S:bd0
9bla02hf>080<3Pj00D0<SXl02/c=@0]=CL0<3Pj034i>`02030h>P0C02/c=@0^=SP0:C4c04Q@DP2^
][P0MWj002de=`0^=SP0:c<e02P`<P0]=CL0;3@f01HL700S:BT08RPX02le=@0R:2P0A4Y:020V9P02
024W9`06028X:00U:b/0:2h^02DY:00S9bH082@S0P0M8B008@0Q9B@092PW01lS8P0N8R408RHU02DY
:00V:2L08B4Q024Q8P0O7al07alQ020Q8`0Q8R@09BHX05aOH00k?d00:Rha02`a<`0T:RX07AlM01/M
6P0G6AH051HC00`>2`0K7AX06Q`I014C400L7Q/06Q`I01LI5P0I6aP051@D01DE5@0201lO7`0E01HF
5P0K6a/06QXJ010@400A4A404a<C01@D500G5aL04a8@024P7P0L6aT04Q4?014@3P0B4@l06aXH01@C
4@061@<03@`:01PG5@0X9bD05a<B008061@C0P0G4a801`0F4Q40:2@S014=300G4a806ADD01XF5@0S
7Q`00P0E40d201HA3P0301LB3`0F4@h04`h;00804Pd:00L04`h;01D@3@0E3`h05Q0@01TC4`0H4Q80
50h>00<04`d=01H05@l?01H@400@2PX04`d=02@R8P1BE5<051@D00X92P0>30d06aLF01@>3P0C3@d0
40P601H<2`0M4a807A8@01L=300C2@P04PP701<9200A1`H05@/:0P0G3@`0300E2`X040H500d30P0@
1PD04`T801H<2`0H3Pd050X901<9200B20L05@/:01@:2@804`T802H050X901D;2P0;0@004@L601@:
2@080000308103<Y:00D2PT05`d<00h40`0A1`H06@l>00h40`0H3Pd040H501D;2P0M4a804`T801X@
3`0G3@`04`T801881`0?1@@05@/:00L0000>10<050X900/1000B20L04`T801@:2@0E2`X07A<B01X@
3`0L4Q403`D500`20@H04PP700h0308101D;2P0E2`X04PP701061@0E2`X04PH801451`0I3@l04PH8
00d10`0C1`T05@T;01@82P<04`L900D04PH801<:300K41@02P0301@93@0201052@0N01H;3`0A1PX0
4PL;01L<400F2`l04`T:01@:2P0?1@H06Q0A00l61`1EC4l0gMCG04m9B`0G4AD04@/?00P41`0Q7280
4@/?01`C5P0<0`H06A0C01H=400O5QT050/>00T00`0C2Pd050/>01072P0E30l03@<70P0?10P0100D
2@d05@X>01052@0>0`L200l4200B01052@0B1`/050T=01H;3P0M4A<04@D701T=3`0B1PP020000146
1`0N4Q@060`>01/?4@3IcLl0>2`^00d3100B1PP04`L90P0B1PP03@0B1PH05P/90146100E2PP06@h:
01D:1P0D2@D05@X801<:1@0?1P4040P5018=2@0>2@D00P0@2`P04`0B20T050P:01D92`0C10L04`L7
01471P0g;B`0Q7Yi0<[0_`0Z81l04`T800h40`0?1@@04`T800l5100@1PD04@D701@82P0F2P`00P0A
1@L01`0E2@/03P8401<72@0E2@/050P:01451`0@10H01P0A1@L01P0C1`T04PH801451`0A1@L04PH8
01<72ACooooo000Kooooo`0?0109400B31003`T;00l92`0A2`/03PT600/60`0>20L03PP:00T31@0?
20h02`D900d72@0C3@l050h@00804P`>01<05@lA014;3@0E3a405Q0B010:300A2`d05a4C010:300B
30h040X<01<=3`0E3a404`d?00l92`0C3@l04P`>00h82P0B30h05Q0B00<04P`>0`0A2`d05P0B30h0
3`T;00l92`0A2`d03`T;00h82P0D2@d05P/?01D:3P0B2@`05Pd@01XA500=20T061@E00d92P0C3a00
71PI00`71`0H4Q806Q@D00`61P0@2PX201@>3P0301D?3`0@2PX040X:00804`d=00<050h?01@>400C
3@l00P0C3@l03`0D3Q004@/=00h82P0B30h06aDG01hH6P0I4aD050h@014;3@0G4A<04P`>014;3@0H
4Q@050h@01hH6P0201<=3`0300l92`0K5AL050l?00803PX70P0C3``00`0<20D04@d:018>2`0201<?
300401HB3`0M6AH061@C01@@3`8040`;01d04@d<018>3@091@@04@d<00h:2@0@30/02`L601HB4@0I
4a<04P`<01dG5`0@2PX09b4Q034[:`0H4Q805a4A01<=3@0A2`/04P`<01@>3P0D3``04`h;01HA3P0G
4Pl04Pd:01<>2`0D3``05A0=01@?3002018=2P0D01D@3@0D40l0510>01@?300G3``06A4=01/B3@0G
3``050l<01DD4P0Z:2T0YZJY0<c=c`0_;Bh06APF014@3P0F5A<05aHD018A3`0C4Q0201@C4@0K01DD
4P0F5A<05QDC01LC4P0H5Q@05aHD01DD4P0C4a4051@B01LG5@0B5140:R`Y01HH5@0K81`03a4>01PH
5P0I6AL05QHD01`L6P0N7Q`06ATG01PH5P0I6AL06QXH01`L6P0M7A/07QhL008071hK00@06A/H01`N
6`0N81d071hK0P0O8Ah0800K7AX071hK01PJ5`0P8Ql05Q/E02<X8P0I7QP082DO01dR7P0Q9R8082DQ
020T8`0O8b808bLV02@X:@0P9BT07bH/024X;P0P:2h07BH[01hW;00R;3009C0d02Dc=P0W=CP09C<f
03=1A00Q;S809S4g02Db>00X=C/0:cPn0P0[>Sl03`0Z>Ch0;3i20394B00_@DD0<D=70394B00dATX0
>4Y>03M9C@0eAd/0>D]?03]=D@0gBDd0=TQ<03Q:CP0203]=D@0?03U8C@18Ee`0@e9G04QGG012DEH0
@e9I03a:D`14DUd0>dQI04]HJ`15DFL0@e1W04aLK019FfT0C5i/0080CV1^01d0EfUg04IHIP18FVP0
B5YX03]=F`13EF<0BE]X04YKI@16Eel0BEYR05QYL@1KK7@0Cf1X04QIH@1GJ700DF9Z05AUK@1?H6P0
E6E]05MVK@1OKW<0Hg9g061_M01MK700G6]^05][J`1LK6`0GFe]05i^K@0205m_KP1D08FEU@1kRh/0
Hg=c06imP01WMWT0Kgj106QgO01_OX<0K7^006mnQ@1]O8<0MhB<07J0R@1jQ8d0O8J?0829T02@VIl0
XZ^`0:2XZ`2?UiX0MGeo07f3P`1gOG`0KG=a06mgN@20R8X0Q8b>07^3Q@21RH/0RY:D08F=S`20R8X0
NX:408F=S`2DW9h0^l?50:2W[@2RZJl0RY6G08>:T024Ri40PhZ@08nFW02MY:X0W:>Y08ZAU`29T9H0
U9^Q08fBV02@UI/0UIZP08nDV029SY40SiBG08N=S@1oQHD0OH>108N=RP2<TXh0U9ZF08Z>SP24R8T0
QXZ;08jBT`26RX/0Oh>408Z>S`2?Ti@0T9BE08jBT`2:SXl0QXf=08F>S@23S8T0PHZ707^4P@1eOWT0
KgQc06QaK01WL6/0JgE]06UcJ`1XLVX0J7=^0P1UM6l0101VMG00IGA_06EdL@1SLW02069`L00N065_
L01SLG80IgEf061_L01KJf/0GFe]05EUI@1BHV80DF5Q059RHP1?Gel0C5aL059RHP1CHf<0C5aL04iM
H01AH6<0E65T04]EE`0oAdX0=3Ll02l`=00/;C40:BX/02X^;`0/<340:c0`02L_<@0Z<S@0;SHh0P0]
=CL0500^=SP0:c<e02hf>00a>C/0;cLi02hf>00a>C/0;cLi02/c=@0U;Bl0@4Q:09NOX@1TK6h0;SHh
02lg>@0Z<S@09Rh`02Ta<`0V;S00;C<c0P0[<C402P0m@d<0;cDe02`b<P0/<S809R`/028X:00T:RX0
9R`/02@Z:P0Q9BH301lS8P06028V9@0Z;Rd08BDT01lS8P0N8R4082@S0P0T:2L0400R92<08b<S02<S
8`0R8R807b0Q01dN800D5AL07b8T01LK7P0T:2/05QXN01/O8P0Q8b402`d:01HH5@0c=C8201TK6003
01hP7@0];b`07b4N00805QPE00L05aTF024Q8@0M7Ad06ATI014A4@0R8R805aLG00805ADE00@061PH
01HF5P0E5AD06QXJ0P0I61H02P0H5aD07A`J01`K6@0G5Q@04a8@00/:200E5180>CPf01XI5`0<2`T3
01LC4P0901HB4@0E4A005a<B01/G5P0N6QT061@C00l;2P0>2PT03`X8008050l<00@05A0=01HA3P0H
4a005Q4>0`0D3``0100E40d05Q4>014<2P0B30`201LA4@0F014;2`0@2PX050h>01@>3P0E3`l06Q@D
01@>3P0?2@T04Q0?01TI6@0:2PX061LG00<10P0B3Pd03@L701D?3`0D30X04@L601X@3`0G30X06Q0?
01D;2P8050X900<04`T801P>3@0F30/00P0D2PT201<9200401lE500@1PD05P`;01X@3`805`d<0`0D
2PT201<9200@01@:2@0F30/0718A01T?3P0@1PD03P@302LM701]Hf806a4@01P>3@0?1@@04PP701T?
3P0@1PD06@l>00d30P805@/:00d03`H600T0000C2@P04@L601H<2`0J40l09A/J01881`0>10<050X9
00d30P0E2`X04`T800804@L600D04PP700T0000>10<04@L601hD4`0601881`0>00h40`0A1`H02`40
01471P0>10<05P`;01<72@0;004040@60186200;004060`>01H:300G2`d201@82P0N01<72@0@10H0
40H900l4200F2`l060dA00T00P0I3Q804@H:00h31`0C20`0714E01P=4@0C2@X04@L701882@0E2``0
4PP901482`0d:bh06A<E00H0100C3A40:RDY0:nZ/01?Ad`05Pd@01D<3`0?1PT01P000P0A20/0300;
0PD040L:01D<3`0:0@@030<601062@0<0@D040D901H;3`0=0PH03`@801@93@8040D903404@H:0187
2`0C20`05``?00X0000f:R`0FTi@01L;3@0<00805`/=00T0000<00804@D7024E5`0G2`d06`lA01<7
2@0D20X040@600l31@0B1PH05@T901050`0E2PL05P/700h3000=0P004@P100h5000B2P@04`h800d8
10060@00100000h6100@1@H03`0301X:3@0I2@`05@T900`20@0M51<0OWAc0?kdl`0i;bh05@/:00h4
0`0B20L05P`;00804@L600<04@D70186200C1`T00P0A1@L01`0C1`T040@601H:300J3Q0060`>01@8
2P0B1PP01P0@10H6018621Cooooo000Kooooo`0:01LA5@0?2@`040X<01<=3`0C3@h05Q0@01H@4@0B
30h04@/=01/E5`8040X=01D040X<01<=3`0A2`d03PP:018<3P0K5AL03PP:01<=3`0?2@/040X<01<=
3`0B30h03@L9010:300>20X04@/=018<3P0?2@/04P`>010:300?2@/00`0B30h201<=3`804P`>0P0A
2`d01`0C3@l040X<014;3@0B30h040X<00l92`0E2Ph00P0D2@d0100D2`h04`X=0189300C3@l2010<
3@0I00h:2`0@30d04Pd>014;2`0C3@d05a4A01@>3P0A2`/040X:00l92@0A2`/04P`<01<=3@0D3Ph0
4`d>014;3@0@2P`03`T;010:300A2`d04`d?014;3@0@2P`05a4C01TC5@0201D?4@0I00X41P0B30h0
5Q0B014;3@0H4Q@04@/=024K7@0E3a404`d?00`6200D3Q0040/;00h:2@0C3`h04Ph=010<2`0>2PT0
4@d<018>3@0C3`h04@d<018>3@0F4Q405A4@01@@3`0301<?3P0=00l;2P0C3`h071PG018>3@0E4A00
30P7010<2`0A2`/050h>00l92@0I4a<05Q0@01TC4`0501@>3P0:01H@400B3@X04@`901XE4P0M61D0
5A0=01@?300C3P/05Q4>01@?30804@`900l050l<01HB3`0F4@h05A0=01L@2`0I4@`06a8=01dF400G
4Ph06QTF01@B4`0c<cD0?Sm101`J6`0E51800P0G5Q@0600E51806QTG01PG5@0F5A<061LE01`K6@0K
6QP051<A01PD4`0K61L06aXH01TH5P0F5Q@05ADC01PH5P0N81d02`d:02HX9@2;T8`09BLT01dM6`0I
61H05aHD01XI5`806aXH02/06QTG01/J600M71X07ahL020O7@0O7ad06adJ01`N6`0I6aP071hK024S
800M7a`0828O01hP7@0L7Q/08R@Q01hP7@0T9R<061dG02T^:00C618082DQ01`Q7@0N8al07B4P01lS
900L824092PY02HZ:`0Q9RX07RD[01dT:P0L92X07bP]02</<@0S;C40:C@h01l]<00V=3L07R`_02Hd
=`0Y=CX0;3Lm00<0:SLm00T0:CPm02hm@P0`?d@0;T1402m1A@0]?d<0<D=703Q:CP0gBDd00P0eAd/2
03I8C080=dU=01H0=TQ<03Q:CP0kCE40>Ta@049AE013DUD0AUEJ04=BF@14DUX0AeEP04=AG`1<FFT0
?daQ05YVO`1EHG/0BeUb04eMK@1@HVh0BUaX051RKP1NL7`0D69^0P18FVH02P15Ef<0CEm[04aNJP12
E600AeQR04MHH019FV80CEiV051QJ@1AHVX2051QJ@0>05=TK01?H6P0DF9Z05MXL01KJW40FVU`05UX
K`1JJFh0GFa`05e/K`1KJVd0G6]]05e]K@1NKVh205m_K`0L06QfM`1[NGX0G6Y[071nP@1TLWD0JGMj
06UfO01cP8H0M867075nQP1cP8P0N8F=07f7T01nR940P8ZC086:T@1kQ8X0LGYo07b4Q`28T9<0N822
07f3P`1aMgH0LWQf06eeM`1fOX00P8R:08B<SP80QHf?0P29TI<0;01kPhD0Q8b>09RPXP3EgMl0VZ:W
08B;T@2:TIL0QHbB08^BV02<TiT0QHbB08J=T`29T9H0QhjD092GW@2MY:X0Yjbb08^@UP2<TIL0SY>G
08^@T`2?U9L0R8f?07n5Q@23RHP0QH^9096GUP2;TI00PXR808N=S@2:T900P8J608N=S@2BV9P0SiFE
08fCT`28SXh0S9:B08V?S`22RXP0OhR507f6P`1iPWl0LGYg0P1YLVl01`1WL6`0I6eY06UbK@1YLVd0
JG9^06McKP1TLfh00P1UM7401@1RLFh0HFm_065_K`1QKfl0Gfe^0080H6i_01X0GVa]05]ZJP1NKVh0
Gfm_05IVIP1>GUh0AeMG04ADE019FET0CEeM04iNGP1<G5`0B5QH04YHF@1>G5d0DEaN04E>D@0k@DD0
<SHi02//<00Z:bl09bT/02<W:P0T:2/09b`_02hf>080;cLi0P0/=3H0:00^=SP0;CDg02hf>00c>cd0
>41203Lo@@0^=SP0<CXi020Y:00X<C0082TX02Tb<@0Z<c80:34`02/d<`0X<C0092d/02L`;`0S;2/0
8bP[02T^<@0U:Rd092T/02`a=00W;2l0;34d02T^<@0V:bh09BX]02@Y;00R9bT09b//024U9P0P92D0
7b<T020T9@0[;c0082@U028V9`0P92D201dQ8P0I024U900O8Ah07b4N01lQ7P0P8Ql08B8R024R900X
:Bd071dQ01LH7@0U:2h07R4W02LZ;P0J6aX06ATG02/[:@12@T006ATG01/K6@0P81h0;Rh/010@3P0H
61H07AdK01HF500201PF5`0?01`J6`0Z:2T06ALH01HD5@0I5aP05aDF01/I6P0J61T05aDF01PF5`0E
51807QdK01PG5@0B4@l05A@B00805aHD00H04A0>01XI5`11@3h07A`J014@3P0F4Q4201LC4P0;01DA
400D40l05a<B00h:2@0O6aX040`;01<?3P0P71/04`h>01H@400E3`l00P0D3Ph201D?3`0401@>3P0F
41005a4A01LA4@805Q0@00<04P`<00l92@0A2`/00P0D3Ph0100E3`l04`d=018<300E3`l2018<300D
00l;2`0H5QL04@h?00l<3@0K5aP04`d=01LA4@0B30`04`/901H<2`0E2`X04`T701L=300C2@P050X9
01D;2P0C2@P05@/:01@:2@0B20L201D;2P0301@:2@0R61L04PP7008060h=00@050X901P>3@0H3Pd0
50X90`0C2@P0200D2PT05P`;01071`0@1PD05@/:01@:2@0A1`H060h=0P0E2`X0700D2PT04@L60147
1P0E2`X040H501881`0E2`X03`D4034X9`0D30/04`T801D;2P0D2PT04`T8028H5`0F30/050X901L=
300>10<05P`;01D;2P0B20L04`T801H<2`0D2PT0718A01@:2@0?1@@601881`0<01471P0B20L05`d<
034W9P0G3@`040H50186200?0`D06@d?02`P8P0?0`D04`L90P0E2@/02P0@10H04`L901L;3@0D20X0
CD=6028G6`0<0PD050T=01072@0A1PX201872`804`P<01H04PL;0147200D20T04PH801882@0D2P/0
5P`@01072P0C2Pd05@hB00`62P0[9BT0`[_205A=D@0F3A003`H901L?4@2GSY40>C0c01482`0F3A00
3`H90P0A20/01P0=10L050X=01<8300D2@d04`P<01462P804PL;02/04@H:01872`0C20`04PL;0146
2P0@1@P04`T:02dQ8`0j;S004PH80147200E2@/0308302PL7P0P5AH060d>01/A4P0f:R/05@T90186
200D20X05@T;0186200C1`L040D301L<200G3@D04@L101/A2@0L4`P04@/201<<0`0>2@8020<002@O
700C2`/04`T:01D92`0H20/060D801H41P0>0`<04`T8008050X901@0;R@T01@;2P0B20L03P@301T?
3P0P5QD05P`;00l5100B1PP040@600l31@0A1@L04PH800l31@0@10H050P:01D92`0C1`T04PH801<7
2@L040@600D04PH801D92`0E2@/04PH801041P0Dooooo`006oooool0300K5AL01P0202LQ8`0;1@L0
4@/=00l92`0C3A4030H8010:300D3Q0040X<00d72@H04P`>01l03`T;018<3P0E3a4050h@014;3@0?
2@/05a4C00h82P0600806Q@F00`6200F41804P`>00d72@0F418040X<01D?4@0X8R@0Ad5301D?4@0>
20X04@/=00P2100D3Q003`T;010:300A2`d050h@01D?4@0F418060dA00803P<700`050/>0189300>
1@P050h@00l;301DD5405Q8C00<0000H4a<03PP800l92@0C3@d2010:2P0>01<=3@0B30`04P`<01<=
3@0D3Ph05@l?01@>3`0;1@L05a4C00/51`0M5aT03@L9010:300A2`d3010:300B00l92`0I4aD01000
00`6200=1`T07ALI02TS9@0C3@l04@/=00P2100?2@/05@lA01@>400C3Pl03@T800`81`0K5aH02@D4
0P0E4A000`0D40l03`/:00h:2@02014=300601TE500?2`X05Q8A01@@3`0A3@`040`;0P0B3Pd0400J
5QD01`<200h:2@0F4Q404`d=00h8200B30`06aDE01TC4`0C3@d040X:01@>3P0G4A404P`<010:2P0C
3@d200l:1`05018=2P0E40d050l<010;200D3``00P0C3P/05`0E40d05Q4>01@?300H51405a8?01D@
300I4P`07aL@02<J4`0M5Q004Pd8018A3@0M6a`07b0Q01@E5`0C4A806aXH01@C4@0Q81h04A0>01DD
4P0D4a405A@B00805QDC02L05aHD01PG5@0G4a806ALE01/J600J6AL061LE01HF500H61H05ALD00h@
3@0M7a`0OhB00<C6``0S8b406QTG01LF500H5aD071/I01dL6P0L6aT06aXH01`K6@0N7A/081lM01lO
7@0L7AX04Q@A020R7`0I6aP05aTF01XL6@0T9R<05aTF03@f<`10@Sl08bDR01XL6@0O92000P0L8Ad0
4@0M8Qh0720O01/O7P0M8B807b<T01dQ8`0N8RD08RHY024V:P0M92`07RD]01dU;00N9bh082T`028/
<`0N:Bl0:3Dk0080;3To01408c0f02`h?P0/=cd0:SLm02`i?`0_?480<3m403A3B00fADX0;3i20353
A`0dATX0<4960394B@0lCE@0?e1G03U:D@0203Q9D00U03U:D@0cA4/0=TM>03a=E00gB4l0?U1E041?
DP11D5<0@4mD03e<D`0mBe@0@U1N04UFI`14DF@0BUI]059NN01=FG<0AU=/04EEI@10DUh0AeUU04QJ
IP0nD5`0AUQT04UKI`12E600@E=O04EGH`14EV80A5IQ04AEG`1>GfL0CEiV041AF@1<GFD0Cf1X059S
J`02055RJP0305=TK01EIVh0EVM_0080F6M^03@0GVed061_MP1MK740Gfic05IUJP1VMGP0IgIi05a/
K01OKfl0HW9b071nO`1^NG/0KgYl07=nPP1_NWh0IW5e07=nQ01dOhD0SIRN08B>U`1gPHX0NhF>07b6
S`27TIX0R9:K07j7SP1`NGl0JgAi06M_LP1iPH@0NX:407^1P@1mPh80LGMe071hNP1iPH<0P8R:08::
S024S8h0QhnA08F=S`22RX`0P8R:0869R`24S8h0QXj@08::S@27Si80R92C0869S027Si80Q8b?0P1o
QhX01P27Si80PHV<09VQY02maLP0bm3F08V>TP80SI:F01@0T9FI08N<T024RH`0PXN:07n4Q`29SY00
YJZ]0;Fk^`24SH`0QXn>08F>S@21RXT0OXN608><R`27T8l0QXn>08><R`1nQhH0NhB307b5P`80Mh1m
0100JgAa069[J01WL6d0J75^06M`K@1TKFX0IVm]06=/J@1QJVT0HFaZ06EdL@1XMg@0I79a06EcL`1T
LW80H6i^0P1NK6d02P1RL780HW1c05i/K`1LJfd0GVi^05e]K@1DI6@0B5QH049BDP13De<204QHF00?
04IFEP19FET0AUIF04aJFP18E5@0@D]<03i6B00k@4<0<CDh02h_<`0Z:bl0:2/`03Lj?`0_=3P0<3Hj
0080;c@g00X0:Rlb02H[;P0]<SD0>Sm203Dj?@0oA4L0@4E803@i?00a=ST0;S<f0`0Z<3003P0Y;bl0
:2h^02P^;P0`=SH0:S0`02@Z:P0V;2`09bd]02<Y:@0O92L0<SLk02T^<P0I7R80:Bhb0P0X;C401`0T
:Bd0<cPl02@Y;@0T:Bd07B8U02L[;00T:2T00P0P92D0800S9bP09RX[01`P8@0P92D09b//01hR8`0R
9RL08bLV01hS7`0O91l08RLS02PZ9`0N7al0:2T[02<T:00L7B807QlT020P:00N7RH07QlT01dM700K
6aT061PF01dM6`0L71X05aLE01<C4@0D51808b<Q01HF500M7A/030`:0`0E4a@0100L6Q/0:2HW02l]
;P0F51D201PF5`0601DC500D4Q<05A<D01PG5@0M71X061LE0P0F5A<0800B4@l05A@B01<B400E5180
4a8@01HE4`0L6aT06aLF01LC4P0@30/05a<B01HB4@0D40l061@C01LC4P0F4Q405a<B01PD4`0F4A40
6Q@D01dG5`0E3`l03PP801<=3@0B30`09R0P00X4100G4A403@L7020J6P0A2`/04`d=0P0D3Ph200h8
20804P`<0140618B01XD500<1PH05@l?024K700D41404`d?01LA4`0I4aD04P`<01P?400C2P/09AdK
01D;2P0L4Q404@L501D;2P0201@:2@0301<9200D2PT05@/:00H050X900H0308102HL6`10=SD02@00
02lU900C2@P201D;2P0501@:2@0@1PD04@L601L=300A1`H00P0D2PT02@0A1`H04`T801471P0F30/0
4`T801D;2P0>10<04@L600`20@0201H<2`8050X900@04`T801881`0B20L05P`;0P0I3`h0100E2`X0
4@L601471P0C2@P301@:2@804`T8020040H500l5100A1`H04PP701471P0;0@0050X901`B4@0B20L0
4`T900l5100K4A0030@3028H5`0<0P406Q0?01dC4P0D20X05PX<01T=3`0D20X04@D701D92`0I3@l0
50P:01451`0@10H04@D70186200O51P06a0D01H;3`804@H:1P0C20`0500C2@X04@D601451`0F2P`0
4`P901872`0G310060hA01893P0C2Pl050hB01@=500@2@d04`P<01@93@0I3Q80:AhR02DJ7P0E2Ph0
40D90P0>0`L00`0?10P04PL;01<8300201872`0H01462P0@1@T040D900`31@0K41@050T=01062@0G
31003`@801@9300F2P`03P8401D:2`0C1`T06Ph@0186200@10H060`>0147200B1PP0710B01451P0@
1@<04PH60P0C1`T07@0C1`X040@401`A3`0A1P807aD;0106000P5`P06141018;000D3P@01@4001D@
2P0=20@040L801462P0C1PP05@D601L41P0H1@H04`L701<9200<0`<05@/:00l5100K4A005@/:0106
1@0A1`H050X900804@L601P05@T;00X0000I3@l06Ph@00`20`0B1PP05@T;00h2100G2`d03P8401<7
2@0T61X05PX<01D92`0C1`T04@D700l31@0>0P@06@d?00h3100=0@<04@D70147200I3@lDooooo`00
6oooool0300E3`l0:bDV05UCE@0P6Q`03@L:06mYK@0E3a<05Q0D01LA4`0A2`d03`T901TC4`8040X<
0P0A2`d2018<3P0:00h82P0B30h050h@01@>400@2P`03PP:01TD5@0<1PP0;bT[01D?4@803@L902D0
4@/=00`6200?2@/03PP:01LA4`0V82809AlQ01<=3`0:10H071HH014;3@0B30h03`T;010:300A2`d0
4`d?01@>400E3a408QLK01T>4P0G31005`hA01@;3P0A20/02`H7010<3@0`;2d06QHG01<?400B3@d0
4@/;010:2P0C3@d040X:014;2`0D3Ph04`d=00804P`<00X04`d=01@>3P0E3a0030H801PB500J51H0
;2HX01/E5`0H4Q@04P`>0`0?2@/05`0>20X020<401/E5`0O6A/06A<E01`F600<1PP081XL01dG6@0D
3Q005@lA01@>400A2`d040/;010<2`0E4A004@d<00`81`0C3`h06ADD01LC4P0C3`h040`;00804@d<
01<05A4@00`81`0=2@P03`/:01HB4@0L61L02`L600l;2P0>2PT07QXI01lK6P0F4Q4071HF01D?3`0D
3Ph05a4A01@>3P0@2PX05Q0@00805@l?00<05Q0@01D?3`0C3@d00P0B3@X01@0D3``05a8?01HA3P0B
3@X050l<00804`h;01H05A0=01HA3P0D3``0510=01<?2P0B3@L05@h801XB300O5Pl0614;01<>2@0A
40`05A@B01DF5`0A4a801`H401PG5@0L6aT061LE01hM6`0>3@/05A@B100F5A<03P0G5Q@06QHE01DC
4@0D4a406APF01`K6@0I6AL05aLE01LI5P0C5A805QPE04U>BP1]Kf`06aXH0P0G5Q@00`0J6AL06aXH
01/J600301`K6@0;01hM6`0P7ad08B0N01TJ5`0Z;2T06A/H01/M6P0M7a`07b4N02DW900F61D00P0M
7a`0100I6aP08B<P01lT800O920201hS7`807B4P00d07b<T024U9P0O8bD0720S01dQ900Q9R/092/c
02D/=00U;C@08b`c020Y<00X<ST0=T5700807BX`03T07R/a02`i?`0U<CL0:cHl02Xg?@0/>Cl0;CY0
02`k@00Y>3d0;3]002/m@@0hBTh0>Ta@02m1A@0iBU00VJZa0:6b^@0jBe80?4eD045BF@0b@dX0=TM>
03U:D@0mCUD0>DYA03m@E`10Ce@0AEAG04MFG013DEX0AUAO05ERL@1DHG@0AeAW04eIL01ULHT0HVj8
04ABJ@1IJGP0F6Yf04IHI00mCe/0B5YV04EGH`12E600?e5M04=EH@17FFD0AEMS04EGHP1<GFD0D65Y
04aMI@16Eel0DV=[04iOI`1CI6`00P1BHf/0:@1EIVh0F6Ua05QYL@1JJG00FFQ_05i]M01OKWD0GFab
061_M01QL7D0G6]_05UXJ`1RLW80F6QX05m_K`1XLgD0IW5c06MbM01[MWX0KWUm06agN`1_NX00LGb2
086<TP1hPX/0LWb507J0R@1nR940P8ZC086;U01nQhh0LW^106M`M@1`N7/0Nh>507R0PP1jP800OH>2
075gM@1hP880OhN90080Q8b>02`0QHf?08J>T025SHl0PXZ<0869R`22RX`0Q8b>08F=S`25SI00QXjA
08B<S`2@V9/0Vj>V08ZBU@1nQXT0PHV<08ZBU@24S8l0R92C09VQY02OY:X0OX>708R=T@2:Si<0SiBH
08R=T@27S8l0RXnB08R=T026Rhh0SI:E09BIW023S8/0Q8f<08><R`1oR8L0OHJ5086:R@24SH`0Phb;
0829R01mQXD0NhB307^4PP80MGik00d0JgAa06E^J`1ZLg00JW=`06M`K@1SK6/0HV]Z05iWIP1LIF@0
GfYY06EdL@1VMG80H6m]0080H6i^00L0GF]/061^K`1QKg00H6i`05]YK01JJ6/0EVEW0080DV9R02@0
CemO04YJFP16EUH0@e=C04EEE@13De<0@E5A04ADE013DU80AE5A041<C00j@dD0>Sm203Hk?P0]<C@0
8b@X024R9P0U:Bh0<cPl02`d=`0^=ST0?454038g>P0R9bX08bP[030e>00oA4L0?4540456B@0k@4<0
;34d02X_<P0[<3<0:c4a02X`<00Y;bl202P^;P0>02T_;`0W;Bd09bd]02D[:`0R:2P092XZ02P^;P0c
>3/092T]02<X;00P9BT0:c0d02ld>00c>3`201hS9`0P02P]<@0W;3007B8V02da=00Y;Bh08RHW01hR
8`0L82406QhO028V9`0K7b00720Q02L[;00U:BX04QHG01dR7P0Q9R806AhJ01HH5@0J71`09BHX01`M
8@0K72407QlT01`M8P0I6B007QlS01dM700K6aT061PF01/K6@0J6QP201DE4`807QhL00@04a<A01hN
700E5A<05Q@E0`0G5AH02P0K6AX07Q`M01LE5P0I5aP061HG01HD5@0E4a@05Q@E01DD4P0K6QP201LF
500?01PG5@0E51805A@B01DD4P0G5Q@04a8@010?3@0D4a403@T801hJ6@0K5aH02PH501DA400J5QD0
5a<B00<05Q8A00l05a<B01D@400G4A406Q@D01H@400A2`/05Q0@01`F5P080P805@l?018<300Y8b<0
1@0001D?3`0G4A400`0F4100500C3@d0;bTY01dG5`070@406Q@D00X4100Z92@0@3Xk01D?4@0A2`d0
4`d?01LA4`0D3Ph03PD600X10P0I4@l05@/:01T?3P0E2`T05P`;0P0E2`X00`0D2PT05@/:01H<2`06
01@:2@0:02@J6@0;0@004PP802HL6`1AAdH05`d<01H<2`0D2PT04PP701@:2@805@/:00X04@L601D;
2P0D2PT04PP701@:2@0B20L03P@301881`0E2`X060h=0P0G3@`01P0A1`H04PP701881`0C2@P050X9
01D;2P804@L60P0@1PD01@0?1@@03P@301@:2@0D2PT04`T800<04PP700H04`T801471P0@1PD04@L6
01881`0@1PD201H<2`0J04To?P0n=3<04@L601881`0;0@0050X901P>3@0A1`H06a4@00/1000@10H0
3P840186200D20X05@T;01T=3`0A1@L040@601451`0C1`T05`/=01P<3P0B1`/03`@800d21P0>0`L2
01052@D04@H:01H04@L801861`0A1@L05@T;01<72@0A1PX05P/?01D:3P0C2Pl050/@01D?4`0B2a80
40H<01<8300A1PX03`@801T>4P0G31005@X>01/@500H3A4050T=0`0C20`201872`0W01462P0@1@T0
40D901052@0A1PX03P<701@93@0C20`03`@801051`0F2P`02P0000l51P0C1`T0200001@82P0<0080
710B01X>400:00004PH801861P0@1@<04`L701@82P0C1`T04@D801451`0W71X05@X501T?0`0R6@X0
6a<601TA000R6`T0>C8S01H?1@0=20803PL400804@H:00h04`H801D51P0G10H060D501hB4P070000
4PP701lE502l/[407A<B00d30P0>10<04@L601881`804`T80P0B1PP0200;0@80200002DI6`0<0080
4@D700l31@0A1@L030020P0G2`d201@82P804PH800P04@D701041P0C1`T03`@50186200M4A<05@T;
00`00QCooooo000Kooooo`0<028M6P0C3P`04@/<00X41`0H4QL04@XA024J8@0C3A803`T;01<=3`0H
4Q4071LE100@2P`2014;3@0:00h82P0A2`d04`d?01<=3`0?2@/03PP:028L7P0?2@/05Q0B00`72080
50h@00`04`d?01D?4@0@2P`03`T;01@>400E3a4050h@03Xd=P0F41803@L9010:300Q6ad3014;3@<0
4P`>01@06@hB01L<400E2Ph04PT<01<:3@0D2`h06A@E01<?400=2@X04a0@014=3P0E41404`d=014;
2`0C3@d04P`<01D?3`0G4A405@l?01<=3@<04P`<00T08A/L01LA4`0=1`T04P`>01XD5P0@2P`05@lA
01LA4`0C3@l00`0A2`d02P0D3Q003`T;014;3@0H4Q@02PD6010:300F41804P`>010:300B30h2010:
300901@?4@0=2@X05A4B018>3`0c;c00510A00l;300>2P/040`=00804@d>02005A4B00h:2@0A3@`0
40`;01@@3`0F4Q404@d=01<?3P0@30/03@T801PD4`0;1`H0<2`[01hH600H4Q805@l?01H@400C3@d0
4P`<01@>3P0A2`/040X:01<=3@0D3Ph03`T901<>2`0B3@X04`h;01HA3P0E40d04@`901@?30804`h;
01D05A0=01HA3P0D3``04a0;01<?2P0B3@L05@h701TA2P0M50d05@h601TD3P0D4`l040l=00d>3@0B
51<08b8P01HE4`0B4@l04a8@018A3`0?3P`00P0G5Q@05P0F5A<05A@B01DD4P0E5180<2`[02<P7`0H
5aD06APF01TI5`0F5Q@05aLE01@F4`0F61D05ALD01`Q7@0H6QL06aTG01`H5`0O6aX081`K01`H5`0H
51<301hJ6@0D01lK6P0P71/07ahL01TJ5`0O8Ah071hK030b;`0O8Ah0828O01LI5P0M7a`092HS02LY
9P0M7a`05QPE01XO6`0Q9B@082@S01/O7P0J7Ql201`P8@0j01lS9P0P92L07R8U01hR9@0Y;S@0:S4i
020W;`0O9bh092dd02L`=`0`>T00AU5G024^=00W=3X0:SLm049?E@0Y=C/0:SDk02Tf?00Z=cd0:cPn
02/j?`0c@TL0>dY?02i0A00]?d<0=DM;03A6BP0lCU<0RY^S09FV[P0oD5P0=TM?041AF@0jBe<0=dQ@
03U:DP0kC5@0>4UA03Y;D`0kBTl0?Da?03a;D@0mBe@0C5YU06ejR@1IIWP0EF9e055NLP1AGG80DEib
05ARM01PL7d0BeeW049DGP1;GFL0AUQR04AFH080@UAN0P18FV@02@14EV00AeUS04mPJ01<GFD0BEYR
04iOI`1FIfl0D65Y05AUK@0205=TK00^05QYL@1KK7@0G6ee05i/M@1KJG80GF]d05e/L`1LJg80H6mf
05QWK01SLWH0EfIY06UhN`1QL7<0GVa_06MbM01[MWP0KgYl06ehO01XLgL0I6mc06A_M@1_NX00Mh:8
071jP`1jQ8d0O8J?0;:la@2FX:T0OXRA07n8S`23S980PX^@0828R`1mQHL0M7an07UoO`1oQH@0Mgek
07MoP@1mQHL0PXZ<08F=S`26SY00QhnA08>;S@<0Q8b>0P23Rhd05@25SI00Q8b?08::S@2BVYd0Vj>V
08>;SP22RXd0Ph^>08F=T026SY40PXZ=0828R`2:Si<0QHZ>08B9S@22Qh/0RXnC08R=T@25RXh0R8fA
08N<T00208B9S@0V08F:SP22RXX0PX^:0829R01mQXD0O8F407n8Q`1nQhH0OHJ507^4P`1hPH00MGim
07=lN@1WL6/0IVm/06=/J@1TKFX0J75`06I_KP1TKF`0HFU[06=[K@1QJF/0H6QZ069]K@1RL700HFm_
05]YJ@1JJ6P0FfUZ05m]KP1TLW<0HW1c05]YK01DHVD0E65W05ETIP1AHF4204eMG@0B04]KF`14E5@0
A5AD04]KF`17EeL0A5AD04MGE`17EUH0?d]:03e7AP0h@D00=cdm03@i>@0^<3@0?d1503<e>P0_<cL0
;cDk0P0Z<SL02@0^<cL0;C4d02``<`0/<3<0;S8e03Pl?`0b=ST0=SXm03<g>P0202T]<00G030d=P0]
<C80:bl^02T];00X;2/0:Rh]02hb<@0U:BP0:Rh]02/_;P0S9bH09RXY034e=P1IGV409R/_02P]<@0[
<3@0:Bhb02`a=@0P9BT0<3Di01/P900d>Cd00P0W;300200Q9BP08RHY028V:@0R9RT08BDX020T9`0L
82<0;S8e0P0U:B`04@0N8RD0720R028X9`0M8R407b<R01PL700P8b@07b0R01/L7P0M7B008B4T01lN
8`0K6Qh081lS01lM7@0N7A/06aXH00807A`J00P061LE01/J600I61H04a8@01XI5`0L6aT061LE01PD
5@8071PI00/06QHG01LC500G4a@06QHG01/G600J5QL061@E01TE5P0J5QL051<A01PG5@0201LF5080
6APF00`05QDC01XI5`0N7A/06QTG01HE4`0H5aD0Ddm>01<?3P0Q7A`040`;01PD4`0D40l201DA4005
01@@3`0E4A005A4@01D@4@0D3Q000P0E3a408P0F4180618D01TC5@0>20X05@lA01HA4P0500406A<E
01<=3P0C3@d04@/;01D?3`0R71`071HF01TC4`0G4A404@/;01D?3`0>20P040X:01XB500F3A004@P;
0189300F3A005Pd>01L>3`0E30d05@d;01L?3@0=1@<04@T601L=300F30/301D;2P0301L=300D2PT0
50X900@050X900T04`T801061@0E2`X04`T801<:2@0C2@P05@/:01<9200D2PT00P0G3@`03P0C2@P0
4@L601@:2@0C2@P04PP701D;2P0D2PT03@<201H<2`0<0P406@l>01071P0J40l04@L61@0B20L03@0D
2PT04PP701471P0B20L05`d<01/A400G3@`05@/:01471P0@1PD04@L601881`0C2@P00P0A1`H201<9
200701061@0H3Pd03`D402/Q800R61L03P@301H<2`0201881`0:01061P0K4A005@/:01<9200I3@l0
4PH801H:300J3Q0050P:018620<050P:00@04`L90186200B1PP05P/?0P0@1@T00`0D2@d04`P<0105
2@0501872`0=01882@0G2@X05@H901P9300F2P`05@T=01H:3P0B1`/04`T?01@;400E31404@L?0147
3@0201P=4@0701052@0C20`050T=01@93@0F2`l050T=01872`0201052@0301462P0B1`/04@H:00<0
4@H:02@04`P<00l5200D2@d05P/?00/1100>0`L05`/>01@:2`0?1@H050T:01L;3@0L41803`@50186
200D20X040@601@82P0H30h04PP701<81P0D20P04`L:01862P0@10L050P:01<81`0F2`D040H002@L
2`28P6T0MVaG04U0:P0d:QX07aH=01P@2P0A2@L201462P0;01<62@0E1@L05PD601L51@0D20P04@L6
01481`0H3Pd0;B@T01<9200<0P800P0H3Pd02P0A1`H05P`;01D;2P0B20T04@D70147200K3a4040H7
01@82P0A1@L201D92`0301451`0K3a403@4300L04PH800D07a<E01@:2`0H30h03`<501041P0Doooo
o`006oooool04@0I5140100001@>3P0@2Ph0@C]00109400j<cX07QPM018<3P0F41804Pd;00X50P0E
3a4050h@018<3P0A2`d040X<00803`T;00<040X<014;3@0A2`d00P0?2@/04`21Ngd0E4i@00D00@0L
5QP0100000X41P0<1PP03@L900`6200`:R`0GeUK06YTIP0=1`T06A<E00@0000?2@/030H800l92`0B
30h00`0A2`d2010:300E01052@0E2Ph05@X>01<:3@0G3Q406a8E06aVJ00J5QL00`00018>3`0:1PL0
50l?014;2`0?2@T04P`<01<=3@0G4A406Q@D01D?3`0C3@d04@/;008040X:00<0:B<T02TS9@0@2P`0
0`0C3@l00`0E3a405Q0B01<=3`03014;3@0400X51P0S7Al02@<5014<3@805a4C02<03`T;01<=3`0D
3Q005@lA00d72@0>20X05A0A00X61`0@30d04Ph?03lk?00C3a00510A014=3P0B3Pl03`/<00X61`0?
2``020@3018>3@0A3@`05a<B00h:2@091@@06QHE01@@3`0C3`h00`0002LS8P0K5aH050h>018<300F
41006A<C01H@400201@>3P0601H@400H4Q805@l?01<=3@0E3`l04`h;0P0B3@X201<>2`0I010;200D
3``04`h;01<>2`0E40d05Q4>01@?300E4Pd05A4;01D@2P0G40P06Q8:01`C2P0G40P05a8<01@C3P0C
4Q004Q<B01<E500C4Q0051<A01LF500I61H05A@B01@C4@0201HE4`0901DD4P0D4a4051<A01<B400I
5A@06QLF01HE4`0C4Q005A@B00806QXH00H04aDB01LI5P0F61D06b0L01<E4P0N6aX201dI600401hJ
6@0L61L06QHE01`H5`806aLF010071PG01dI600L6aT071dK01PJ5`0P8Ql0=CLd01/M6P0L7Q/09BLT
024S800M7a`07b4N01XL6@0?4@h07B4P0P0U:BP0@00O8b807R8S024U9P0M8B@06alR01dP900P8bP0
8B@Y03Pm@`0l@dd0:S4k028Z<`0P:C808R/d02D_>00S;CH09S<k02dj@P0^>d<0:SLo02`h?`0[=S`0
9c@j02Pe>`0]>T00<D1502hm@P0`?d@0;3i203=5B@0nD5@0>D]?03e?E@0]?TH0<dA<041AF@0cA4`0
>T]C03m@F00nCeL0?4eE03Y;D`0kC5@0>T]B0350A@0hAdX0AUEK04aJH`19Ef80@TmO04eJJ`19EVL0
BeQY05ISL`1EHW80@4mL03a=E`1EIg40BE]U049DGP1NL7X0BUaV04MIH`16F68204QJI00704MIH`1@
HV`0CUmW04iOI`1AHVX0DV=[04mPJ002059SJ`07055RJP1BHf/0EfQ`05Y[L`1KK7@0Gfef05]YLP02
05aZL`0T05]ZLP1PKgH0FVU`06imPP1bPHH0Gfia05UXJ`1cPH@0G6MY06=]K`1XLW@0JG9g06QaMP1Y
LWL0G6E/079kPP1jPhX0Lgb5086:T`1nQi00QY2I08F?V026T9T0R96H08F>U01nQh`0PXZ=07MoPP1]
MGL0LgUi07b2P@1kPGl0Lg]m07R0PP1oQhT0Q8b>0P25SHl08@23Rhd0QHf?08J>T026SY00Ph^=08::
S01oQhT0R92B08nGV@22RX`0PHV;07j6R01oQhT0Q8b>0869R`23Rhd0R92B08J>T023R8`0PHJ:07Yo
P`22Qh/0RXnC08bAU@2<TIL0QHZ@0866S020QH/0OhB:07n4R01nQhP0OhV807j8Q`0307^5Q01I07V3
PP1hPX40M7im06miN01/MWD0Ig5^05YSGP1IHUd0FV=O05iWI01RJfX0H6QY061XJP1QJF`0J71c06I^
L@1SJfh0HVe^05e[J`1LJVX0FFMX05QVI`1KJFX0I79d069`L`1KJF`0FFI[05MTJP1BGfD0CE]N04UI
F@16EUH0C5aL051PH01=GEd0BEUI04]KF`18F5P0A5AD04IFEP14De<0=d=103I1?@0b>cP0;cDe02``
<@0X:Bd0<SDj028U:P0Z;cD0<CPn03M0A@0f?dD0<SLk02HZ;@0R9RT0;C4d02lc=P0[;c80<3@g03Di
?00i?D00;c<f02@X:`0P92H0;C4b02/_;P0Y;B`0:2`[02/_;P0_<c80;30_02/_;P0X;2/09RXY02P/
:`0[;c00=CXn02<X;P0W;3809BX`02T^=00W;380<SLm02<X;P1MHVP0T9FK02hc>@0P9BT00P0X;2l0
9@0V:Rd08bLZ01hR9@0I7B007b<V02@X:`0Q9BP04aLJ02@X:`0e>C`061dP01XP8@0V;2`07b<V03<g
>01ZKVl07b0R01LH6P0K6a/081hQ01`J700H5QL06QTG01`K6@0J6AL071/I01hM6`0L6aT061LE01DD
4P0J6AL08R4O01/J600R8Al061@E01/G600L61T00P0K5aP0200M6AX06ADF01XF5`0I5AH05a<D01TE
5P0L61T05QDC0P0G5Q@201DD4P0>01PG5@0A40h04a8@01HE4`0D4a404a8@01PG5@1SGeh07a/J02DQ
800B3Pd0<Rh]02/W9P0D40l301<?3P0501@@3`0F4A405@lA01<=3`0D3Q000`0F41804P0E3a406A<E
01<>3`0`:R`0100001`F5`0E3`l04`d=01PB4P0U7al081XJ01D?3`0>20P03@L701@>3P0@2PX05Q0@
01/D5@8050T=0P0F2`l00`0E2``04`T:01L=3P0201@<2P0300h6100E3@X050X900804`T800<04PP7
01<9200D2PT01P0D2PT0400F30/060h=00h4100K4A006Q0?01<92@0>10<050X901T?3P0E2`X04@L6
01<9200A1`H04`T801471P0?1@@301<9200500d5100J40l0CdE403H/:`0700000P0D2PT0300C2@P0
4PP701471P0A1`H03`D401061@0A1`H04`T801D;2P0F30/050X901881`803`D400d04PP701@:2@0B
20L04@L601<9200D2PT04`T801061@0?1@@060h=01<9200=0`806a4@00803P@300l04PP702DK6P0/
8R4040H501471P0>0P@040@601T=3`0M4A<050P:01451`0>0P@040@601<72@0F2P`00P0G2`d01P0H
3A4040D901052@0C20`03`@800X00`D04`P<01<04`T:01831@0@0@@0404401<41`0A1@T03P8601<7
2`0B1`d04@H<0107300A1`l03P@:01<72`0G2`l050P<01862P0C1`/04PH:00804@D900@04`L;01@8
300E2@d050P<1@0A1PX02@0>0`L06@hB00`11@0;00@06PlC00`11@0f;2d0/JFW02`P8P0201/?4@05
00P0000B1PP03@4300d10`0E2@/00P0D20X07@0J3`h060d;01<71`0@10P04@D901@73@0=0@<05PX:
01/A2@0]91D0Lf]F0>gXcP3oo^H0YYN003d_7@0C1P003@8001<92@0A1PX04@H<01862@0D1@P05@D6
01D51@0=0@404@L601@:2@0:00009Q`K00803`D400/07A<B01`B4@0@1PD05P`;01D;2P0900003`<5
024E5`080000710B00P0000201@82P03020D5P0F2P`04@D700<050P:0P0B1PP0200A1@L040@60186
200O4aD03P8401T=3`0=0P<050P:5?ooool001_ooooo00h03`/9018=2`0E3`l03PP<02hX;@0>1`l0
4``D01@=4`0D3Q003`T;00d81P0F4@h04`d=01<=3`804P`>00<04@/=010:300A2`d00`0B30h2014;
3@0B01D?4@0D3Q003PP:018<3P0:10H04@/=01PB500D3Q003PT:00l:2`0B30h04@/=00d72@0G4A<0
3PP:01<=3`0L5QP030H80P0A2`d2010:30804@/=00<04`P<01D:3P0E2Ph00P0C2Pd0400D2`h04@/=
01DA4P0@30d03@T:01DA4P0B3@d03`T900h8200B30`04@/;01<=3@0F410050h>018<300A2`/2010:
2P06014;300D3Q001`83014;3@0?2@/05a4C0`0?2@/2014;3@803PP:01004P`>010:300n>3X04P`>
01@>400?2@/030H800d72@0B30h04@/=01<=3`0D3a003`/<01DA4P0=2@X0510A0P0?2``0800;1`P0
4@d>01@@4@0B3Pl081`M01XF5@0K5aH03@T801HB4@0=2@P0;b`[04a8A`0F4a8071PG014=300E4A00
5Q8A01<=3@0B30`05Q0@01LA4@0B30`04@/;018<300D3Ph05Q0@018<300A2`/04`d=01LB3`0E40d0
4`h;0P0E40d06P0B3@X050l<01<>2`0C3P/05A0=01HA3P0D3``04Pl:01<?2@0C3PP05@h601L?1P0H
3`H05Pl701@@200B4@`04a8>018C4@0A4a804A0>01LF500920H06APF01HE4`0E518051<A0P0E5180
5P0D4a405A@B01DD4P0I5A@07A/I01XI5`0E518051<A01PH5P0V9R@0828O02`^:`0I6aP05AXF01HH
5@0H5A@061<B01TD500M61P07QTH01dH600N6AP201dH5`0601dH600N6AP07AXI01/L6@0b=34061XG
0P0M7a`0100K7AX071hK02DW900S9B8201XL6@0D01hP7@0I7A`0720O01dQ800L8200720Q01dQ8P0S
9bX07R8U01lR9P0Q92T082<X02<X;`0O9S0082La02Ta>`0S;3D08BXc02Pa>P0V<3T202Hc>`1002Db
>P0Q;SH0:3@k02/f?00Y=S`0;3To034nA00c@TL0>4M<045@E@0eAd/0<D=703mAE@0nD5@0>TaB03I7
C`10DET0=TM?04AEG@1@HFT0?DiF041AF@0iBU80<dA<03M8D00fAdh0=dI;03]:C@15E5`0CUaW04mM
JP1;F6P0AeAT04eJJP1<FVP0@e5L04=BF`14E5`0AUMP04UKI011E5`0?U1I04AGG`14EUl0B5YS04AG
G`15Ef00BUaU04]NIP1DIVl0DV=[05AUK@1IJW80EVM_04UJHP1CI6`0DV=[055RJP1BHf/0EFI^05QY
L@1IJW80G6Yd05UWL@80GVae01@0GF]c061_MP1TLgX0GVec07Z9SP1]O800Gfib09^Y[01`Ngd0JG=e
069/KP1SK740JgAi071iOP1[M7/0OXN>08RAV01mQXl0PHZC0829TP<0P8ZC00l0P8V@08:;T@24SI80
Ph^>07R0P`1`N7X0LgUi07QnO@1lPX00NX:407b4QP21RH/0QXj@08F=S`22RX`00P25SHl208J>T005
08F=S`24S8h0P8R:08VAT`2BVY`00P23Rhd03P26SY00Nh>508J>T028T980Q8b>0869R`22RX`0Qhb@
08F:SP23R8`0Ri2D0825RP26Ri00Q8V?0P1oQ8X01020QH`0NWn607=jO`1hPH8207f7QP0Y07Z4P`1g
PH00MX1o07AnO@1cOG`0LG]j06egMP1[MG@0J79_061YI01QJVD0GfQT061YIP1WL6l0IFe^069ZK01Q
JF`0IVib06A/L01RJFl0HFa^05]YJ@1JJ6P0FfUZ05MUIP1IIfT0Gfe`05UWJP1DHFH0EVAY05QUJ`1B
GfD0C5]N04YJFP18F5P0AUIF04EEE@12DU80A5AD04YJFP18F5P00P14E5@0M00oCTh0=D0o03I0?00g
?C/0=3Pi034e=P0`<CD0=STn02X]<P0g?D<0:C0f02hg?00d?T<0OhB805IJG@0W:bh0:2`_02``<`0Y
;C00:2`_02da=00f>Sd0<CDh02HZ;@0R9RP0;C4b02da<00[;bh0:Rh]02/_;P0^<S40;30_02HZ:@0Q
9B@09BTX02P/:`0T:2T09BX^02T^=00/<CL092T_02T^=00S:2h092T_02H[<@0U:S00<SLm02P]<`0P
9B/09RT^02DY;@0U:2`08bL[024T:00N8RH061`P03/o@`1lP8@0;C4e020S9`0I7B408BHY01dS9`0I
7R80<SHj02DZ;@0R9RP0;Bh`01lP8@0O7ah09B<S028P800N71X06ALE01dJ6@0I5aD06AHE01/I5`0J
5aH07Q`J02LU8`0O7A/05Q@B01lL6`0F4a806QDG01/F5`0J5AL061<E01TD5P0J5AL061<E01PC500G
4Q<05Q4C01TD5P0L61T05A@B01@C4@0G5Q@051<A01DD4P0J6AL05A@B01HE4`0I61H051<A014@3P0D
4a405A4@00h:2@0H51<03`/:028N7@0P71/05A4@0`0D40l03P0E4A005A0A01@>400C3@l050h@01D?
4@0F41806A<E018=3P0^:2X0EU1B01lI6`1@BT`0618C0P0A2`/01`0E3`l04P`<01<=3@0C3@d05Q0@
01D?3`0?2@T00P0H4Q803@0B2@/05@X>01H:3P0G2`l05P/?01H<3@0G3@h050X;01<;2@0>1P@08ATG
00d50P0D2PT00P0C2@P00`0B20L04`T801@:2@0601@:2@0@01071`0F30/05@/:01@:2@0H3Pd050X9
00h40`0D2PT06Q0?01<9200@1PD05@/:01H<2`0G3@`04`T800l510804`T800X04PP701@:2@0B20L0
7A@D01P?3P0E2`X040H501471P0B20L04`T80`0D2PT201D;2P0301@:2@0B20L03`D400804PP70P0A
1`H05@0B20L04`T801881`0B20L050X901H<2`0D2PT040H501`B4@0A1`L04PP700/20P0@1PD04PP7
01L=300B20P04PP701071`0D2PT03`D401451`0201<72@0601041P0G2`d08QHH01H:300D20X04`L9
0P0B1PP01`0C1`T04`P<01462P0B1`/04`P<01872`0@1@T01@0A1PX03P0B1PP05`P901D62@0D1@P0
70d@01/?4`0E2@d04`L;01<83P0B1`d040H;01473`0B1Pd04`L;0P0F2Ph00`0B1PX04@D901<72`03
01<72`804PH:00@04@D901052@0A1PX04@H:0P0B1`/0900I3Q809Q/O01472P0H3Q40=2T]01hC5`0?
1PL0@SHh00`20`0@1@L07A4C01@82P0C20T03P8401hB500m<C<04`P900/10P0R5QD05P/701861P0@
10P04@D901<6300C1`/060`<01lE3@0b:AP0DTXd0<S3Y`3XglD0PW5I02PH2@0L3PD070l900l41080
4@H<01/04@L90186200C1`D04`L401@9200?1@@04@P701@;2`0L4Q404PP801061@0C2@P04PP700l5
100B20L050X901061`0K3a4050T;08=gN@0O5AH05PX<01<72@0@1@H06`lA01041P0=0P@00`0C1`T3
0186200701451`0A1PL05PX<01/A4P0n<S@06`lA00h3100Dooooo`006oooool0;P0A2@L06Q<B00@0
000L4aH02P8801H?5P0B21003PH<01LA4`0N5AH06A8A018=2P0=1`T03PP;00l92`0A2`l04`d@01<=
3`0B31004P`?018<3P0B30l04P`@018<3P0@2P`04`X=02@N800=1PP07A@G01<=3`0[8bH06A0C00h8
2P0<1@L04PT<01H@4P0B2`d04PT<00P2100P61/0@cXm01D?4@0@2@/04@P;010:300B2Pd201<:3@0<
01@93@0E2Ph05P/?01D<3`0D2`h04`X=01L?4P0400004@/=00h82P0I4aD03`P80P0A20T01P0C2P/0
3PD600d41@0A2`/04P`>014;3@8040X<0P0A2`d0200P6Q`04@/=00d72@0600805Q0B00`6200@2P`0
4@/=0P0E3a40;P0B30h03@L901XD5P0800805@h@01LA4`0e;2l05`lB014;3@0?1PT04@T<00h82P0?
1PT04`d?010:300>20X06aDG00T31@0C3@l0618D018<3P0C3@l040X<00/51`0L5QP040`=01DA4P0C
3`l07ATJ00<0000T81l0>cLf02`X9`0G4a803PX901PD4`0?2`X04P`<00l92@0A2`/04P`<010:2P0E
3`l05Q0@01<=3@0B30`201H@4004014;2`0E3`l04`h;014<2@804Pd:00T040/801@?300C3P/04`h;
01D@3@0F4@h050l<014=2P0B3PX00P0C3PP201H?1`0>01L@2P0H50h05a@?018A3@0@40h051@D01XI
5`0C4Q4071/I08Z9Q`0G5Q@06aXH018A3`0C4Q0201@C4@0701DD4P0F5A<06aLF01LE4`0E51805QDC
01TH5P0201XJ600>014A3`0U9b@04Q<@018D4@0L71X06aPG01`H5`0M6AP07a/J01/G5P0H51<081`K
01lK6P0N6QT201lK6P0>020L6`0L71X07QhL01lQ7P0H6AH07AlL01`N6`0O8Ah05aTF01lQ7P0S9B80
6Q`I01LI5P0O8b8201dQ8003020T9@0Q9BH08BDV00807R8U00L08bL[02DZ;P0S9R/082H]01`S:`0Q
:300;3@l00809Bhe00<0:C<j03]6C00O;3@00P0^>d<01P11CUH08c0g02Tf?00/>Cl0<3e3034nA080
;Se20300>TU>03A6BP0bA4P0?DmC03I8C00bA4T0<D9:03Y;D`0fAdl0<45903a=E@16Eel0BU]U045B
G00gB580?TmI03e>F00jB540?deF04MEH@17EF80B5EU04iKJ`16E640BUQU04UGH@17EUd0BEQO03e<
DP0nCeH0?4mF03e?EP14EEd0B5YT04IGH@1>GfT0AeUS04MIH@1<GFD0BEaS04QIH018FF40B5UP055R
JP1FIfl0B5UP05=TK01DIFd205=TJ`0305EVKP1GJ6l0F6Ua0080F6I_02L0GVed061^M`1MK7<0Gfie
05]ZL@1UM7X0FfY_06akP01NKG80Gfe`06IaM@1SKFl0IW1b06efN`1_N7d0JW=h06UbN@1eOXD0PhbC
07IoR01gP8T0OXN@0869U01oR980PHZC08B=UP28TIP0R96F08bCV@26SY40OXJ807b2PP1lPX40PhV9
07InP01hP880OhN908R@TP27Si401`25SHl07P21RX/0OhN:07f7R024SHl0Ri>F07Z4Q@1oR8X0OhN:
08B>S`25SY00Q8b?08VAU025S980OXF;07f4RP24Ri40NX6708bCV@2DW:00PXZ=07Z2Q@1eOH00K7Ag
06I^L@1aO7T0N8=o07Z5P@1gPWh0LWei06mjMP80KWUe01<0KgUh06ihM`1]MgH0K7Md06IaJ`1YM700
HfiZ065/J01YLg80J79b069/K@1OJFX0Hfe_06MaL`1[MGL0J7Ae05]YJP1JJ6T0FfUZ0080Df5T02h0
E69U051NH@1AGV@0Df1V059OI@1?G680BeUL04QHF018EUL0AEAC04=AD@14DU80@Dm?041>CP11Cdl0
?D];03]9BP0d@D80;cXf034j=`0d>SP0<cTi03<g>P0d=c`0=3Ln02`a=`0m@T/09bhd03i7C01cO880
=c`o030d=@0/<3<092P[01dR9@0`=CP0;34d02/`<`0_=3L0:B`a01lR9`0T9b/0;S8c02`b<00]<C00
;30_0P0[;bh0500W:bX092PW028V9@0U:BP0:Bh]02T_;`0W;2l0724U02L/<00X;C40;34e02T^<P0c
>3`0724U030e>@0T:Bd08bP/02T^<P0P8bP082@W0P0Q9BP2028V:@0P03<d>00S92P0MGIj01<D600X
:Bd08b@X02d`=@1:CU<03a8G01`P8`0F61/071dO02TZ;00P81l06a/I01XI5`0J5aD07QXG024N7@0U
8B007A`J01XG5P0K5aH061LE01TG5@0O6aX05A@B03/i=`1RGUd0;BTX01LB500L5QP201dG6@0401`F
600M5aT05a4C01H@4P805@lA01806A<E01/G600C41404@l@01HE4`0E4a<05aHD01hM6`0=30X051<A
01XI5@0F5A4040l;018A3@0@30/06ADD00l;2P0B3Pd201PD4`805Q0@00D05@l?01H@400F41004`d>
014;3@0201<=3`0601@>400H4Q@05@lA01LA4`0Q6ad0H5YL0P0?2@/06@0H4Q<03`T901@>3P0L5QH0
3`T901PB4P0b;2`04Ph=00D1000K5aH02PH500D1000F3Q005`/?01H:3P0D20`05PX>01X@4@0N51D0
40H701D=2`0I4@l0Aclm01P@3P0E2`X00P0D2PT00`0C2@P050X901D;2P0601@:2@0901X?3@0B1`D0
6@l=01<9200D2PT050`:018:200C2`T050`900<04`/800@06a4@01`B4@0F30/04@L60P0D2PT01P0E
2`X04@L601H<2`0B20L04`T800/100804PP70P0@1PD0200?1@@03P@301061@0A1`H04PP701<9200F
30/05`d<0P0C2@P08`0B20L04@L600l5100=0`804PP701<9200E2`X05P`;01@:2@0?1@@04@L601<:
2@0E2`X04@L601P>3@0=0`80:R0O01P>3@0l<S405`d<00l5100C2@P04@D701<72@0?0`D050P:03da
<`1LD58050P:01451`0@10H04PH801D92`0F2P`040D900804PL;0P0?10P00`0@1@T04`P<01<83003
01<8300801@8300D1@P04P<601831P0L3A00710D01D93@0@10P201H;4@0301<83P0@1@/04@H;0080
3`<700H04PH:01<72`0D20`05@T=01862P0C1`/201@8300501<72`0B1PX040D901052@0A1PX00P0B
1`/0900@1@T04`P<01X?4`0D2@d02`0401872`0G30l0200001lC5@0?1@H04`L900P0000J3Q006@d?
00d10`0C1`T0710B01041P0@10<040D301861`0B1PP040@800h21P0;00408QHF01@:0`0K4@D05a00
03D/601KC3T09aH401L7000A0P003@0001H:2`804@H:00`04@L801861P0B1`D04PL400T0000B20L0
5P`;01881`0700004@L601/A400D2PT201061@0800h40`0A1`H07A4C01T=3`0>0P@0<RHX0186200I
3@l201@82P0600h2100:000060`>00`00P0@10H04@D70P0B1PP201@82P804PH800@0300202@H6P08
00007A4C5?ooool001_ooooo0P0C2@X01`0B2@X04`T:01<9300B2@`04`P<01<9300B2@X00P0C2@X0
8`0B2@X03`T=014<4@0>2@d03`X@018=4P0;1PX05A0F00`7300D3a<05A0E01<>500C3A403`H901@9
3@0F3A005`dA01D:3P0C2Pd040H901462P0@1`X05`d@01462P0E30l04PP901@:2`0G3Pl071<D01X@
4@0E30d050X;01D;300D2``05@`=00805P`=1P0C2@X0600H3Pl05@`=00X10P0D2``05Pd>0187200E
2@T050P801871`0D2PT05@/<00d51P0F3A803`T=01H@500?2Ph06QDK03dh>`0C3@d03@L701@>3P0B
30`050h>014;2`<040X:00l04@/;01<=3@0C2`d04`X=01<8300?1@T05@`?01T>4P0P5QT02`8501<8
300G3A005@`?01lD600?1PT0100D2`h0100C2Pd04PT<01<:3@0D2`h20189300E01@;3P0C3A404`dA
01@>4@0D3Q804`d?018<3P0@2P`050h@01LA4@0C3@d04@/;018<2`0;1@D05Q0B00l:2`0M5aT04P`>
014;3@0B30h04`d?00<05@lA00<04`d>01@>3P0D3Ph00`0D3Ph0800E3`l04@/;01D?3`0H4Q806A<C
01H@400C3@d05a<B00`81P0O6aP09b<P01hI5P0V8Ah07APE01TF500:1P<06aLF010?3@0A40h05Q8A
01DA400L61L07ATH01LC4P0D40l061@C01TE500F4Q404Ph=01<?3P0I5A@040l=0P0C4Q008`0M71X0
5QDC018A3`0K6QP06APF01PH5P0K6aT06ATG01PH5P0J6AL061LE01hM6`0O7Q`06APF01LF500J6AL0
5aHD014@3P0K6QP08R4O01/J600M71X0:BPV00T91`0M71X07alM01PH5P0T92803@l<028T8@0f>3D0
9BXV014F4P0O82406a`N00807b0R02007b<V02HZ;@0_=3P07R<W01`Q9P0K8RP09BX`01dT:@0Q:B`0
8RX]02@];`0V<380:34f02La=P16DED0>DI<02Ld>P0^>d408c0f02/h?P0Y>3d0:cXo02`k@00T<cP0
9cHk030oA01>GF80EVEZ03=2A`0eA4T0>dY?03E6BP80<dA;02d0>4U@03Q9D@0nCeT0AEIP03e=FP0j
BUL0A5AR03A4D`14E6<0=d=I04QDJP1BGW<0CEY]05ISM00oC5/0AeEP04aJH`1JJG00BeYO04ACF013
DUT0AUEL04=DF`15EEd0BUQS04YJI`1<FVX0CEYZ04MGIP15EF00BEMP04YKH`1=G680BeYQ04IEFP16
EE/0EfI]059QIP1IJ6h0Hg9i05QWK01GIV`0Gfie05YYKP1HIfh00P1]NX809P1IIV`0FfQ`05]XKP1L
JFl0GV]a05QUJ`1SL7H0GFY`05m/LP1RL7<0Ig9f06=^L@1LIf/0JGAh06UdN@1[MW`0JGAj07F0Q`1h
PX/0NhF>082:T`1lQ8l0MWj;08fDXP24RYP0PHNC0827T@2AV:00P8N=08N?TP21RH/0MWmn07f6Q@2B
ViX0MWj007b4QP23Rhd0QhnA0P26SY005P23Rhd0QXj@08B<SP1oQhT0P8R:08::S021S8h0PhbA08RC
U@20RXd0PX^@082;S@1oRH`0PX^@086<SP27TID0R96F08><T@23S9@0PX^B086:T@20RHl2086:S`0T
07b6R01hPX40N8:107R3P01XLfl0KWUe06ikM@1bOgP0Kgae079oMP1gQ7X0Hg1V06ikLP1OK6D0JWIc
06QdLP1ULG40I71^06IbKP1QKF/0GVYX06=_K@1ULFl0IW9`069^K01MJFL0GVYZ05m[J`1RKVh0HFma
065`L`1JJF`0EfIY05QWK01DHfP0EFAY0P1@Gf@0A@1CHVL0DV5V04]JG`17EEP0AE=D04eIF@17E580
@4a:04=?B`11CDT0@Ti:03e7AP0jA4<0>TA503Q0@`0c?3T0;CHa02Xc<@0lA4H0>d1603m3C00[;cX0
B4mI02/b?00j@DT0@dYB07^3Q`0_<c@0;C4`02X_;`0/<S80;SLf02/c=@1iPH@0CeMJ01dT9`0O92X0
:Rdd02`_=@0]<SD0:C8a02L];@0V:R/09b//02//;P0Q8R@08R<U024U9P0O9BD08RTY02@];00V;b`0
8b`Y028[:00Y<S40:c@c01/T8`0X<C009Rh_01/S9@0L92H09Rh`02H/;00R9RL07R0R02h_<@0b<cD0
92DW01lP8P04024Q8`05028Q900S8B@08R8R020P800M7Ad00P0L71`0=00M7Ad07alO01dL6P0G5Q@0
6APF01`K6@0E5180<2l_02/Y:P0A4A407ahN01hL7@0E5AD06QTI01`J6`0A4A40;2/[03dk?00M6a`0
5Q8A04I2@@1@C4/0920O051<B`1?BdX07a/J00X61@0N6QT06QHE01DA400?2``05a8F01TD600I5AH0
5a8E01HB4@0G4a804@d:01TE4P0H5A004Pl:01HC3P0L6A@051<@014@3P0C4@l05Q8A01LA4@0U7al0
;RDV020G600F3@h201`B4`0=01L>3`0E3`l06A<C01D?3`0A2`/050h>014;2`0I4a<071HF01TC4`0A
2`/02`D501@=3@0201H=3P0F01@=3@0B30`04@d<00l;2P0H5aD05A@B010?3@0E51807AdK00/61P0R
61T03P@501D<3@0O5AH060h?01D;300D2P/05@/<01P>3`0G3@h03`D501@:2@804`T800T05P`;01P>
3@0G3@`05@/:01`B4@0B20L06@l>01471P0E2`T00P0F20D02`0H3@`01`0000h60`0B3@X06AHA00d:
1@15@SX0:BDL01`H3@0F4PP04`T700804`L700L04PH601<71`0D20P03`<301H:2P0I3@d05`/;0080
5@T901404PH60104100=0@404`L701L;2`0900005@T901H:2P0D20P04PH601<71`0F2PX05@T;0104
1P0C1`T05@T;01<72@0201@82P804`L90P0D20X03@0B1PP04@D701H:300@10H03`<501L;3@0I3@l0
200001hB501<@480710B00T0000L41800`0A1@T00`0C1`/050P<01@8300601862P804@D900h04PH:
01@8300F2Ph05PX>01L=3`0A1@T05PX>00`2100R5QX03P8601862P0@10P07Q8F01882P803@4500`0
50P<01452@0@10P04@D901<72`0N4QH08aLK01`@500C1`/040@801862P0D20`20104200:01@8300@
10P040@801<72P0Q5AL04@D701061`0D20X02`0101H:308040@600@060d>02/O8@08000050P:1@0A
1@L00`0@10H04@D701lC5@0201<72@0300X0000A10D04`D500<04`@702D04@D700l51P0@1PL04PP7
01<91`0E3PP071<=01T<1P0H2`D05@L501<5100A1@D04PH601@8200B1PH050P701@91`0@1@4040D2
01<71`0B1PP04`L901@82P0C1`T040@60555A`1ODeD05P/<00T0000I3@l03@4301041P0E2@/03P<4
06eQH`0Z7R003@4300H03`<500D0:1`N01lC5@0B1PP05`/=01lC5@0301451`804PH80P0C1`TDoooo
o`006oooool;01<92P060189300>20`040/@00h93P0?2Pl04PdB0`0@2a001@0D3a@08alS01lJ7`0?
2Pd050X=00<050T=0P0C20`0300M4QH05``@01462P0E2Ph03`@801D:3P0D2P/05@/<01P>3`0K4A80
5`d>01D;30804PP90P0C2@X201@:2`H04`T:01L050X;00`20`0Q5aP040L801X@4@0E2@X050H70185
1P0D20T05PX;01D:3@0B2@/05@`@014;401?BDh071LL00d93@15@4<03PP800d71`0C3@d03`T9018<
3002014;2`8040X:00<04@/;018<300C2P`00P0D2@d02`0B1`/05``@01P=4@0E2Ph060dA01D:3P0a
9bX08AHJ00T00P0H3A405@X>00805P/?0P0G31000`0C20`050T=01D:3P0201<8300E01@:3P0J41P0
5PlF01@>4P0A2`l040X>010:300B30h050h@01H@400C3@d04@/;018=2P0M5aT0>C<e01<=3`0I4aD0
40X<014;3@0D3Q005@lA00805Q0B0P0E3a40200J51@05a4A01<=3@0@2PX04`d=01D?3`0B30`04`d=
0P0E3`l201@>3P80510?0P0?2`X0900G4a806QHE04M3@P0`;2/06ADD01<?3P0E4A0061@C01/G5P0E
4A005Q8A01PD4`0G4a806ADD01hJ6@0A3@`07QXI02@P7`0I5A@061@C01HE4`0G5Q@04A0>01PG5@0E
51805aHD01PG5@0F5A<05aHD01TH5P0H5aD05QDC01TI5`0H61H07AdK01hN70<061PF00l05QHD024Q
7`0K6aT06a/I02/[:@0O6aX05QDC01TH5P0O7Q`06QXH020P7P0J6QP071hK02DW900R92400P0M8Qh0
CP0S92H07AhP024R900T9BL08RHY02DY;010ADT06b0T02@Z;`0L8bT082L]024Y;00Q:B/08b/]02D^
<00W<C809c4c02<]<01OJVh0H6ia02@b=P0[>3h0;CY002`j?`0Y>3d0;3]002dl@@0X=c`0;3]00391
AP0hAd`0>dY?03M6B`0hAd`0>dY?03M8C00eAd/0>D]@03i?EP0hBE00=TM@03a<F00jBUL0=DED03i>
GP0iBET0FFUj05AON`18Dfl0CEUc082<X@1RKh00B5IR04ABF`12DEP0BUUN041?E011D5D0AEAK04ED
F@17EU/0BeUQ04iLI`1@GV/0D5e/051MKP1=FVT0BUQT04]IHP1<Ff80C5]O04]JG`1>GF80BeYO055P
I@1;FUl0EFAY05MVJ`80EVEZ0300FVU^05a[L01LJg00EV=Y05m/LP1HIF/0GV]a05aYK`1JIfd0IW=i
05m/LP1VLgT0H6ec06AaM`1VM7L0JWEi06E`LP27TYD0GVU]06]fNP1XLgP0KGQn07=mQ@1fP8T0NhF>
08>=UP21RiD0Vj6_0;[0c`23RIL0NX2<08jEX021R900PhZ@08:9SP1mQHL0Nh>507b5Q01oR8L0NX:4
07j6R023Rhd0QXj@08F=S`24S8h0QHf?08R@TP27Si4208::S00>08>=SP1oRHh0P8^?07j9S@2AW:00
P8^?07N2QP1mR8`0O8N;07f8S01kQXX0O8N;08:=T`1oRI<207n9TP0E07n:T01oRXh0OhZ<086=S02M
ZJL0QI6=06YgL01RKfL0KW]c06MdK@1/NG00L7ed06QeJ`1ULfH0GFYO05aYG`1LJF80GVYV05m[J@1`
O7`0FFMU00<0GVeZ00D0I7=`06=bK`1OKV/0FFQU05MVH`0205YYIP0^05]ZI`1LJf`0Gfic05YYKP1F
IFX0DV5V04aKH01BHFH0Df9W059QIP1:FEh0AeIK04aKH01MJVd0BeIH04A@D01>FUL0AU9>04YEC`15
CdX0>dE003Y3@00k@T80>3m103Dj?@0`>CD0=Chi02lh=P0`>3/0;C@j02he?P1<DUh0<CM303@kAP0`
=cl0>D16030f>`0^<S<0:bl^02P];00Y<S40:S<b02H`<@1NJ6X0AU1B02dd>P80;c@j0240:R/d02hd
=`0[=3<0:S0`02P/;@0W:b`0:R/]02DV:00W:2X09BTZ01lU9@0Q:BP09S0_024Z:00W<2d0:C8`028[
:@0N9bD09c0^02</:P0V;bl08b//028[:`0S;2`07RLV02DY:00P8b80;2h]02la<00U9RH08R8R020P
800Q82000P0Q7b00100R7b008alP024P7P0O7Q`201hM6`0>020O7@0Q81h07ahL01`K6@0N7A/07A`J
01PG5@0G5Q@071`L01LG5`0N7Qh061PH02DU9@0L71`301PH600I018B4P0K6a/061PH01PD4`0N6QT0
8alN01HB4@0Q7A`0510?018>3@0N6QT0510?01<?3`0N6QT0920P01XF600K5aT06ADG01DA4`0C3`h0
510?01HB3`0E4@h05Q8>01PD3`0201LD400A01@C4@0A40h04a4?01HB4@0F41006Q8C01/B4`0G3@h0
5P`=01dB500M4A<05@`=01PB4P0K5AD091hN01LA4@0>20P00P0D3Ph01@0B30`0618B01TC4`0@2PX0
50d=00805Pd>00h050d=01<=3@0B3@`05A4@00l>300<2`T07A`J06=SH@1kO7T09R4Q01P>3`0_9BH0
91XK00h41@805@/<0P0F30d01@0E2``050X;01882@0I3`h05`d<00<05@/:01@04`T801P>3@0H3Pd0
4`T801471P0E2`X050T801d?300:00005P/801TA3P0B3@X040`:014@301?CTT0f]SA04=0=P0A3P<0
4Pd301<91`804`L701404PH601<71`0D20P05@T901H:2P0C1`L04PH601D92@0J3Ph05@T901L;2`0B
1PH04@D501@8200B1PH05@T901<71`0201451@0801@8200E2@T050P:01H:300H30h050P:01041P0F
2P`201<72@060186200A1@L04PH80186200?0`D050P:0P0A1@L0300C1`T03P8404<g>@0L4A80710B
01D92`0@1@H040@601<72`0B1PX04@D901862P804`L;1P0B1PX04P0C1`/050P<01D93@0E2@d04PH:
01452@0G30l05P`>0104200?10L06`lC01452@1jKW808ADI00l51`0<0P@05`/?01@:30T04PH:00<0
4@D90104200B1PX00P0@10P0400C1`/040@80104200C20/04@D700/00@0E2@/02P0102`P8P1:?T00
4`L901041P0^8bD0B3`n01P<3P0A1PP501451`0701041P0P51H0;R8T00l51P0H30h04`L901851`04
01<41`0401451`0B20T04`T:01<92P8040L800@050/<01H:300E2@/04`L90P0A1@L02@0B1PH04PL5
00l40P0A1P@050T501870`0D2@H060`<01D92`0201041P804PH800`05@/<01@82P0C1`T06@d?00h4
1@0C20T02`4201H<3@0G30h0LFEW03<X:@0=0P<601451`0501L;3@0A1@L03P840186200D20X00`0A
1@L2018620804`L95?ooool001_ooooo2`0C2@X03P0B2@X07ALK018=4@0P6al07aXN014<400M61`0
50lC00h93@0?2Ph061<G01@?4`090`L04`T<0`0E2Ph03@0C20`04PL;01/@500F2`l04@H:01H;3`0B
1`/060dA01D;300F30d05`d>01P>3`0D2P/00P0C2@X201@:2`<05@/<1P0C2@X06@0A1`P03083028H
6@0K4A806@l@01H;3@0F1`X04PH:01L;3P0G2`l05@X>01/A5@0800805@lA01hH6`0F41806aHJ00/7
1`0:10@03`T9018<300<1PH04@/;018<300A2`/00P0@2PX05`0A2`/04P`<01882`0D2@d05@X>01@9
3@0G31005P/?01P=4@0=0PH040D9028G6`0E2Ph03`@801<8300D2@d05P/?01L<400H3A406@hB01<8
300D2@d05@X>00804`P<00L050X>01H<500C31<04@/?010:3P0A2`l05@lA00804`d?00X04`d=018<
300A2`/04@`905==C`1FD58050h@00P210090`D06Q@F0P0E3a4201H@4P805@lA00P0618B01H@400C
3@d04@/;01<=3@0E3`l050h>01<=3@804P`<00l050h>01H@400>2PT05A4@010<2`0>2PT061@C01dI
6024P7l0G5QG02LS8P0F4Q4061@C02@P7`0L61L00P0D40l02@0E4A005Q8A01XF5@0e<C00920O096=
S02FTY4081`K01DA4002028Q7`0S01PG5@0K6QP05A@B01TH5P0J6AL05aHD01PG5@0J6AL06APF01PG
5@0J6QP061PF01`L6P0K6aT061PF01XJ600L71X04Q8@01TI5`0F5Q@0;Rh/05=CD@0T81l0:BPV010?
3@0Q81h05QHD020P7P0N7Q`06adJ01lQ7P0S9B8082DQ01dR7P0U9RP00P0N7b401P0Q8R@0720S01XN
8@0C61`0:2da02<Y;P807bH/00l07BDX028Z;00U;Bl0:34c02Pb<`0W<C<09c8e01hY;@0F92L0;3Tn
028_=@0L:Bl0;3Y002Pg?00[>Sl00P0/>d008P0_?T<0=DA902hm@P0gAT/0DF1U03i=DP0c@TL0=TI;
03E7B`0fB4`0>4U?03Q9D00jBe<0?4eF03Y:E`0gAeH0?TiN03e=G@1PL840JWJ@04aGL`18E6d0IW>6
04UFIP0iAe80DEmX04IEG011D5D0>4M<03e<D@13DUP0AUEH04UHF`1=G68204iLI@0A04iLI`1=FfH0
C5YU04UGH@17EUd0AUEJ04IEF011D5D0CUeR04]JG`1?GV<0D5mT06MfN`1@Gf@0FFQ]05YYKP1GIV/0
0P1OKW<0FP1DHFL0GFY`05aYK`1RKgD0FVM]05QUJ`1SL7H0G6U_065^M01NJg40IG9h06AbM@1ZMGL0
JGAf096LWP1^NGd0JWEi06mjOP1^NGl0LWb407N1RP1lQXl0PXbE08:<UP1eNhT0QXbJ0826TP24RYH0
QHbE08N>UP29T9H0PhZ?0828R`21RH/0PHZ907b5Q01nQXP0PHV;08>;S@24S8h0PXZ<0869R`22RX`0
QXj@08F=S`20R8X0OhN9082:S025Si80SiZN07AoP`25T9@0Mh:608:=T@1kQXX0NXF908>>TP21S900
RYFI09bWZ`1kQXd0O8J?07b7S@1mR8d0OHR:07b7R@1mRHP0OHV506ijMP1ZMg00H6eV065^I`1SL6T0
FfQQ06IcJP1PKF<0GF]N05]XG@1@GE<0C5UB05]XH`1AGE/0Hfm_05aZJ01IJ6D0G6]X05m^J`1RLFh0
GVeZ05MVH`80Df9O00T0FFQU05QWI01FIF80FVUZ05e/L@1EI6T0DF1U04aKH01:FEh00P1CHVL0B01A
H6D0AeIK049AEP1:FEh0G6U/04]FF011CDd0AE5@03i:AP0oBT@0@D]503]4?`0]=S@0;34d03<h>`0n
@dL0>44n02Pa;P0T;B`0>d=603<j@00c>T<0<SU303DlAP0e?4D0SiJL0;c3b@0i@4<0:bl`02HZ:@0W
;2/0:c@c02Xc<P0W<C8072HX02H`<P0_=S`09R/a020U:`0];cL0:Rlb02Pa<00W;Bd09BTZ02DV:00T
92H0820R02@T9P0T9RP0728R01hV9@0W<2l0>T=2028[:`0U;Rd0:c<e02</;00U;Bl09Rh`02<[;@0M
9BL07bLY02Ta<`0e>Sd08BDV01dP7`0S9B@09BLV020Q800P82007alO01lN7`807adN00@081dN020L
7@0N7A/07A`J0P0K6QP04@0M71X07QdK03Th=P0O7Q`06QTG01/J600G5Q@08b8P01<C4`0?3`l06QXJ
01LG5`0N7Qh0820P01/K6`0D51@07AdM00806a/K02X05QHF01/G5P0K5aH06ADD01XF5@0K5aH081`K
01XF5@0A3@`08AdL028N7@0C3`h06aLF01DA400H51D061@C01LC4`0G4a8061@C01LC4P0D40l05A4>
01LC4@0E4A004`l>01<B400@3`d04a0?01DA400F41005Ph?01P?400H3Pl05`d>01/A4P0J3Q006Q4B
014;2`090`<040X:00H0000<1PH2020J6P0501D?3`0D3Ph05a4A018<300F3Pl00P0E30d0400D3@d0
4`d=01<=3@0@2`X06QHE00d<2P0Y:2H0i^KT0?Kfm00j=CD05P`=03X`<@0X7Ql02`4201D;300D2P/2
01H<3@0L0147200@1PL05@/<01T?3P0G3@`05@/:01@:2@0C2@P040H501X@3`0F30/07A<B01X@3`0_
9B@0;28Q01050`0H3@/060l=00d81@0810<03P/:00P71@0S8Qh0?cXg00d80P0F3`L04`/701@91`80
4`L701H04PH601<71`0D20P05`/;01D92@0A1@D040@401@8200I3@d03@4101451@0@10@03`<30145
1@0D20P05`/;01D92@0D20P05PX:01D92@0A1@D03P840P0B1PP00`0?0`D0710B03DY:`0201<72@08
0186200@10H04@D70186200G2`d04@D700d10`0@10H201H:300902TM7`0>0P@0200000/10P0D20X0
4PH801@8300C1`/04PH:00<04@D91P0B1PX601<72`0>01D;3@080000300401P<400<00@04`L;01`@
500900404`L;01H:3P0N4QH06`lC01452@0C1`/201@8300601452@0B1PX05@T=01H:3P0G2`l050P<
0P0B1PX201<72`0@01@8300C1`/04`L;01862@0B1PP0300201D92`0B1PP02@000186200K3a4060`>
01451`0@10H0300201H:30D04@D700L050P:00`00P0F2P`05PX<01D92`0:000050H900@04`@700P0
4@D70147200B20T04PP900h51P0=10D03`H701@82P804`L900d04PH801451`0A1@D05``:01<81P0B
1`D04PL300l4000A1P<05@T901<72@0@10H04@D700804`L900<09QXL028F600>10D00P0>0P@01`0F
2P`060`>01P<3P13=cT0300200`20`0Q5AL01P0A1@L01P0E2@/040@601P<3P0H30h04PH801T=3`80
4@D70P0B1PP201<72ACooooo000Kooooo`/04`T:00l04PT:00@00P0D3a80DD]?04m9C@0C3Q402`D9
04Y4B00I4aL02P@800P21P0600@03@L;00h41`0B1`/00P0E2Ph02@0A1PX03`@801@93@0C20`04PL;
01L<400A1PX05P/?01D;300201H<3@0301D;300C2@X04`T:00804`T:0P0D2P/201D;30L04`T:01H0
3`D602/Q8P0^92D03@<401T>400A1@T03`8901862`0>0`L03`@801D;3P0<0`H01P00014:2`0F4100
3@L901H?3`0=10D04`X;01@;300?1PL05@`=0P0D2``01@0C2P/04PT:01892P0C2P/04`T;00805@X>
018050T=01H;3`0F2`l060dA00d21P0C20`040L901052@0I3Q803`@801@93@0E2Ph05P/?01L<400I
3Q804`P<01@93@0E2Ph201<8300901@:3P0E2a<04P/B010:3P0?2@d04@/?01D?4@0D3Q004`d?00<0
4P`<00D04@`9030Z;00W8B<050h@01H@4P0201<=3`H05@lA0P0B30`401D?3`0A01H@400D3Ph04P`<
01<=3@0E3`l0618B01<?3P0D40l06QHE01LC4P0>2PT04@d<01TE500H51<01000014=300<20L00P0I
5A@00`0D40l05Q8A01PD4`0201HB4@0=01@@3`0J5QD0=S8a03Xf=@0O6aX03`/:01HE4`0I61H05A@B
01XI5`0C4Q004Q4?01XI5`0201PG5@0:01/J600I61H061LE01/K6@0I6AL06a/I01XJ600I6AL07AdK
01PH5P808R8P05T05aLE01`L6P0Y:BL07ATH02HU8`0H5aD081lM020P7P0T92806ATG02<U8P0N81d0
61XG01`Q7@0U:RH07QlQ01dN800P8B<0:BX/02X^<@0X;2l0:2da01DJ7P0[<CH08BP^01lV;00Y<C@0
9Bd_02L_<@0Z<cD0:S@e02Pb=00W<C@0<ci203A2A@0[>Cd0:3Dk02/h?P0/>T00:CPm02Xi?P0[>Sl0
;Se20350A@0eA4T0;Ca103Q7C01CHVL0>DQ=02hm@P0fAd/0=TQ<03Q:CP0gBDh0>DYA03]<E00gB540
=DI@03M7E013Df40A5AS05m_P01ULHT0Q92Z03a8G`1?G6l0AeAT04QFH@1DHV/0AeIM03m>D`0gATd0
?TeD04EDFP17EUT0BUUL04eLH01;FUl0BEQO04YHH@1?GFH0CUeT04eLHP1:FEh0BEQK04YIG01;FUl0
EfI[04eLH@0204]JG`0_065`M@1@Gf@0FFQ]05UXK@1FIFX0G6]`05YYKP1IIfX0GVa_05]YK01PKW40
F6IY05YXJ`1NK6l0FFMZ05i/K`1MJfh0IgEh069`L`1QK6h0I6ma06mjO01lQhT0HVe`079mP@1^NGl0
M7n507b7S@1nR940P8ZC08:<U@23RID0PHNC08bBWP2AUj<0Nh:;0868T024Ri40PHV=07j6R@1nQXP0
P8R908:;RP21RH/0Ph^>08B<S`23Rhh00P21RH`0:`22RXd0QhnB08J>T@21RH`0OhN:07n9R`26TI<0
TijP07N2Q027TY@0N8>508>>T01nRH/0NXF707n:S01hPhD0O8N908fHW01iQ8X0NXF;07^6S01kQX/0
NXF707V4QP1hQ8<0P8b807R4P01VLf`0JWM`08^HT@1iQX00GfaU06IcJP1PKF<0GFYP05aYG`1dPGL0
FfQQ05QUH01FHV00EV9R05]XI`1FIF800P1GIV<02`1JJFH0EVER059QGP1AH5d0Df9O05UXI@1GIV<0
E6=P05QWI`1DHfH0BEQK0080E6=V02P0AEAG04aKGP1BHF@0CeiQ04]JG@17EUT0AUEH04ICEP12CDl0
AE5A049=C013CTX0A4m903Y4?P0a>SD09R`[02P]<00e>Sd0AT]?03Hl?00g?C/0:S0`030e>@0d>Cd0
=SY203LkA00c=d00;c<l07b1Q`2Y[[@0;C8e02X^;`0T:2T0:2d^02hg=P0]=SD0:cDf02dg>@0Z=3H0
9Rha0P0[<3H07P0U9bd0:c0c02Tb<@0[<C40:2`]02LX:P0U9BL0820R02@T9P0V:BX08RPX02D];00/
=C@0GF9U02db=P0N8bH092T]02H[;P0]<SH07R<W02@Y;@0X;C409R/_024V:P0P9BP082@U01hQ800P
8R408B<R01hO7`807alO02`07ahO01lM7P0N71d07a`M01lK700Q81h07ahL01`K6@0K6QP071/I01dL
6P0j>CL06QTG01LF500M71X071/I02<R800L71`06QXJ00`<300M7Ad04A4A01lO7`0J6QX0;2`/02DU
9@0A4A405aLG01@D500J5QD06ADD018>3@0D40l03`/:01XF5@0H51<07a/J00`81`0E4A005a<B01HB
4@0E4@l061@C01PD4@805a<B00H06ADD01DA400F4Q405A4@01<?3`0D414201DA4008018>3@0D3`h0
5Q0@01D?3`0F3`l06Q4B01P?400E30d201T?400901@:2`0=1`L0:28R04@n?P0U7al04P`<00l92@0J
51@05@l?008050h>00D040X:01D>3P0E30d05@`=01@=3@0201<=3@0?018=3@0G4a804Ph=02<R801/
JfT0NGQf02<L700E2``07aDF01T?400>10D04@L801@:2`0F30d05@/<008040H700@05P`=01H<2`0E
2`X04`T80P0D2PT0500B20L04@L600`20@0?1@@01`0001P>3@0B2PT05`d<030X9P0T7A`0>cDg00l;
300A3Pl03`/<01<?3P0Q71X0610=01/B3@0?1P<050T70P0C1`L01`0B1PH04`L701@8200F2PX050P8
01861P0C1`L00P0D20P201861P0601D92@0G2`/050P801451@0D20P05@T90P0F2PX02@0B1PH03@41
01@82P0F2P`05@T;01041P0E2@/0:AdO01041P0200l31@0B01451`0@10H03P8401H:300B1PP04@D7
0186200D20X05@T;01X>400G2`d06@d?01P<3P0Q5AL07Q8D01@8300C1`/04PH:0`0A1@T601862P0D
01<72`0@10P03`<701862P0F2Ph060`@01/?4`0H31005@T=01<72`0=0@D05`/?00d31@0?0`L05@T=
00/10`0<00@03@4501452@0C1`/201@8300801452@0B1PX050P<01@8300C1`/040@800l31`0B1PX5
01D93@0400l51`0F2P`060`>00d10`8050P:00L03P<400d10`08000050P:01D92`0>0P@03@<400D0
4@D700L03`<502TM7`10=3H05@X;01<72@0A1@L04`H800@04`@700L04@D700h41@0?1@H04@L800h5
1P0=10D03`H700@04PH800<04@D701451@0F2`T00P0B1`D05@0C20@03`@001460`0?0`<03`<50104
1P0D20X05@T;01@82P090000710B01041P0d:2X07A4C00/10P080000710B02dQ8`0K3a4040H701T=
3`0601451`0601<72@0@10H060`>01D92`0=0@<05@T;0P0A1@L2018620804`L95?ooool001_ooooo
2`0C2@X03@0B2@X07A@G00/5200D3Q404P`?00d72P0Y8bH0M6ia020K7@080PD050hA00h82`0B30l0
0`0D2@d0300C20`040D900l4200D2@d04`P<01462P0E2Ph03`@801<8300C2@X05P`=01D;30804`T:
00@05@/<01061`0A1`P04@L80`0B20T601<92P805P`=018081HG01@;2`0J41404`L=01863P0C1`l0
5@T@00l42P0H3A<07Q@G01L?3`0F3@h04@X9018;2P0D3@`04`/;00l61`0C2P/201892P0401L>3`0D
2``050/<01<:2`804PT:00D04`X;01<9300F2`l05@X>01872`0201H;3`0301<8300L4AD06@hB0080
5@X>00<04PP;01H;3`0C20`00`0E2Ph0100F2`l04`P<01@93@0E2Ph201<8300401@:3P0F31@050dD
018<408040X>01H04@/=01D?4@0B30h040X:014;2`0B30`04@`901@>400>20X04@/=01@>400A2`d0
4P`>01D?4@0D3Q004`d?018<3P0C3@l05@lA010:2P0A2`/05@l?0P0F410301D?3`0S01<=3@0D3Ph0
5Q0@01LA4@0G4a404@d;01/G5@0T81h08AdK01PD4P0E4@l06QHD00h:200K5aD05a<A028N700G4a80
4`l>01PD4`0I5A@05A4@01@@3`0@30/061@C01`H5`0M6AP06QHE010<2`0G5Q@06APF01/J600X9bD0
8B0N01`K6@0J6AL00P0H5aD0300J6AL06APF01PG5@0K6aT06ATG01XJ600H61H06ATG01lO7@0M7A/0
92@R01hN70806a/I02D05aLE01hJ6@0B4@l08R4O038a;`2k^kT0;bl]02<S8@0J71T05ALD02@V8`0T
:BD07b@P028S9@0V9bT08R<U024R900Q9BP082@W024V:P0W;3007bDZ020W;@0S:S00:c<f02H^<00W
;c40:34c02Pb<`0X<S@0:C@g02Xe>@0Z>3/09cDi02Tf?00[>3h0:CLl0080;Ca10300;3]003=2A`0d
@dP0=4=802ln@`0b@DH0?TeB03A3B00b@DH0=dI;03Y;CP0oCe<0?TiC03e=D`0lC5<0?4]E049AG00o
CU/0AeIT04EDH`1BH740?DUP05]WO`17E6P0>TMH04eKJ@18EV00CUeT04EDF`16EEX0@e9I04YIH01D
HVT0AUIG04UIF@1:FU/0AUIG04IEF@1;FUh0AUEI04QGF`1:FE`0B5QI04QHF01:FUX0BeYM05=RI`1<
Ff0204mNH`0405MVJ`1FIFX0EVEZ05QWK080FVU^02D0EVEZ05YXJ`1IIfX0EVAW05aZK@1FI6L0GF]^
05i/K`1KJF`0H6ia05m]L01XMWT0GF]^065/KP1SKVl0GVUZ07R3Q@1WLWD0MH23071kP01iQ8X0PHbB
07n9T@23SYD0TijU08N=V022RI@0P8N@08ZAVP26SID0PXV?08B;T@26SY80QXjA08F=S`26SXl0RY:D
00<0Q8b?00@0Ph^>08::S@22RXd0Ph^>0P29TI@02023Rhh0PHV<086;S@1nRH/0QI2B08>>T02?VY`0
O8N90P1fPH<08`1eP880N8>507F0PP1gPX@0OHR:07R3R01iQ8T0NXF807R3QP1eP880M82006ijN01d
P7`0LWij06=`JP1ULV/0Q96:06ahM01KJ640H6eV05i[H@1PKF<0GFYQ09:OUP1dPGX0F6AQ06=_K`1N
JF/0GFUZ05]YJ01FIF<0Df5P05UWIP1KJVP0EfIT0080DV1O08<0F6IU05ARH@1AGeh0CEaL05=RI@1D
HVD0BEMJ045?DP1JJF`0LH2305UWJP1@GV40BeYM04QGFP13DUD0@DiA04MAD`1>FE/0A4m>041:B@11
BdL0=Slk03@k>@0`=SH0;c<f02hb=P0]<CD0<CLh05=IF00n@dH092T]03<h?00b=c`0=CXo030e>P1]
LWP0>d1502L/<@0_=3P0;c0d02DY:`0[<340<S/k02hf=`0/=SL09S0b02dg>@0^=ST092T^02DZ;`0/
;C<092T/02D/;00X;2d0:2T[02DV:00Q8B<071/N01hN800S92H09RX[02L];@0U;2h09R/`02DZ<00X
;C809R/b028W;00V:c0092T^028W;00S:2d08RL[02H[;`0c>3/08BDV028U900R92<08B<R020Q8@0P
82008B4Q024P8@0P7Ql07adN01lL7@0O6a`092<Q024P7P0N7A/07A`J01hM6`0O7Q`08B0N01HE4`0H
5aD07ahL01hM6`0K6QP09B@U02h];P0@3`l071/L00h=3@0M71`061LH024P800J6AX07QdM02HU9@0C
4A806ADD014=300B3Pd071PG01TE500G4a805A4@01/G5P0O6aX0?CTh01DA400G4a4061D@01XG4`0I
5Q805Q<?01DA3`0F4Q005A4@01HB4`0201HB500501LC5@0H4aH05A0@018=3@0D3Ph00P0E3`l02`0D
3@d05Pl?01L>3`0C2P/05`h?01P?400H4A403`T901D?3`0N6AT04P`<008050h>00T0618B01@>3P0E
3`l05@l?00l92@0D30d050/<01D<3@0D3@d00P0D3Ph0300A30/05a8A010;2P0J5AD05A<A01dH600D
3@h05P`=0147200D2P/060h?01H<3@805@/<00D050X;01<92P0D2P/05@/<01@:2@0201<9200501@:
2@0E2`X050X901<9200D2PT00P0C2@P03`0G3@`050X901@=300K5QL071PI07QcM`0D4AD03`dA01D@
5@03004091`N00h51@0<0P406`d;01@9200201<71`0401861P0C1`L050P801D92@8050P802/05@T9
01@8200@10@05@T901451@0C1`L050P801451@0D20P040@401@8200C1`L040@401861P0I3@d05@T;
01<72@0F2P`05`/=01<72@0D20X05PX<01<72@0H30h081@F01lC5@0B1PP03`<501<72@0H30h05@T;
01041P0F2P`08ADG01451`0>0`@04`P901H:300=0`@04`L;01862P0A1@T04PH:00804`L;1`0B1PX2
01452@0;01<72`0F2Ph05`/?01D;3@14>3`0Qg]o04Hj?P0900406`lC01D93@0=0PD00P0D20`00`0I
3A404PL:01862P0401862P804`L;00<04PH:01<72`0C1`/00P0D20`201L;3`0401<72`0G2`l05`/?
01@82`8040H700X04@D700h3100@10H050P:01P<3P0>10D050P:00h3100H30h04PL81@0A1@L01`0B
1`P040H701X?400D2@X04@D700T0000C1PP0100C10L01`0A1@L0308300l51P0B20T03`H700h51P0@
1`P00P0A1@L0700B1PP04`L90186200A1@D040D300h30@0C20H05P/701<8100C20D04@D501041P0A
1@L050P:01D92`0D20X04PH80147200F2``0:1`N00X00@0F2`d06@d?00X00@0E2P`02`0101P<3P0;
0@8601451`0301<72@0D20X04`L900804PH80`0A1@L2018620804`L95?ooool001_ooooo300C2@X0
7`0C2Pd06aDG00/51`0500404@/=00h82P0E3a403@P9010:300B30h040X<01L>4@0U6Qh07A8F01L<
400D2@d05P/?01P=4@0D2@d040D900d21P0C20`04PL;01X?4`0A1`P05@/<01@:2`0B20T04`T:01H<
3@0B20T00P0C2@X301@:2`H04`T:01X040L8024G602HSXl08ALH00l51P0B1`d03P8<01873`0D2A40
3P<;01lD6P0R61/05Pd>00T1000D3@`06A4?00d50P0F3@`03PD60107200?1PL04PT:01L>3`0B2@X0
5@`=01<:2`<04PT:00X050X<01L<400E2Ph040D901@93@0F2`l060dA01@93@0@1@T05``@0P0>0`L0
100H3A404`P<01<8300C20`201872`0301<8300D2@d05@X>00804`P<01l050X>01063P0?20l04@/?
018<400C3A404`d?01H@4P0B30h03`T9014;2`0B30`040/800@0000I4aD04@`=00/51`0:10H05@lA
01<=3`0B30h04@/=010:300A2`d04`d?01H@400E3`l050h>01<=3@0D3Ph05@l?00804P`<0P0C3@d2
01@>3P0U01dI5P0E4@h02@D201XF4`0/:2D04@d:00h:1`0A3@X06QHC01HB3`0H51404`l<01PD4`0C
3`h05A4@01LC4P0E4A005Q8A02PT8`0A3@`06aLF01hJ6@0D40l08AdL01LF500B4@l04A0>020O7@0J
6AL03`h<01dL6P0K6QP071/I01hM6`0M71X06aXH01`L6P0201XJ600I01HF500I6AL08B4O01dM6`0G
5aD05QHD01TI5`0G5aD051@B01lK6P0T8b4071/I024P7P0E5A<0:RXX01hN700O8Ah051HC01XL6@0P
9B4092TU02HW:@0_<3809bPZ01lP8P0201lS9P06028W:`0I7R808bT^01/R:00D6b409blb0P0T;2h0
1`0T;Bh092h_02H`<P0Z=CP09C0d02<a=00Y=c/00P0b?dD01`0[>Ch0<T560391AP0_?T<0=dI;03Q7
C00fADX00P0iB4d0:00mC540?TeB03M6B`0c@TH0?4]>03]:C@0gATX0@4mD04IEG013DUX0?TaG03M5
DP14DV00Cea/065^OP1<F6h0Ae=Y04AAH`19EVH0EF=^04]JHP0mC5<0>DQ?045@E@0oCUD0AEAK04iL
I014E5@0AeMF04QHF014E5@0AeMG055QH@13De<0AUIF04]KF`1:FUX0Be]K04mOGP1<Feh2059QIP0I
05YYKP1FIFX0C5]P05i]LP1EI6T0FVU^06EdN@1OKW<0G6]`05m]L01KJF`0F6IY05aZK@1CHF@0FfU/
05i/K`1MJfh0H6ia05i/K`1TLWD0Df5R069^KP1NJVX0KGUi05UTIP0206ehNP0B07=nPP1lQh`0PXfC
07f8SP29U9X0Z;>i08^BVP1mQ8`0Q8^C08nFWP22RHl0P8N=0869S023Rhh0QhnB08R@TP25SHl0OhN9
0P24S8l208>;SP80PXZ=00T0PHV<08N?TP27Si80PHV<07j6R@1nR8X0N8:4086<SP26TI<00P1dOh40
101fPH<0LWeo07F0PP1dOh4207V4QP0U07AoP@1hPhD0NHB607V4QP1fPX<0LGem06mkN`1`O7X0O8R4
079nNP1WLfl0FfQQ069_J01JIV80HViZ06EbJ`1HIEd0F6EL05MTFP1RKfP0G6QT06EaK`1JIVH0K7Mi
06QeMP1DHV80C5YJ04IDE01BH600FVQX05UWI`1AGel0D5iN05ARHP1@GUh0C5YJ04eKG00204mMH00c
055OHP14DUD0@e5D065_LP1RL7<0DV1S04ABE@11Ce80@e5D04MAEP0lADX0@4Y<049<C@0g@D00>dA3
03U0?P0d>SP0=3Xk03@g?00a=3T0:bhe02db=@0Z;c809b`_03Pm@@0d>Cd0;S<f03Hk?`0_=3L0;S<g
03Dj?P0`=CT0A4Q<03<d>00X;2l0;C4d038j?00Z<S@09c4b02D_<00Z=3D0:S8e02P]<@0Z;c<09BP/
02@X:@0U:b/0:Bd^02//;P0X:2X0928U00808AlR00H09RHX02``<@0Z;bl082DX02X_=@0Y;CH2028V
;`0F02T]=@0X;C<08RL]02DZ<00[<3@09b``024V:P0X;C007B4R024T8`0P8R407R0O01hO7`0M7Ad0
8R8R024P8@0Q7b0081hO020M7P0P71d071/I01/J60806APF01D071/I01dL6P0O7Q`08B0N01LF500B
4@l06APF01`K6@0T8R<0=S@e02@R8`0E4a@06ALH01dK700I5aP07adN01TG600A3a007A/L01PF5`0G
4a800P0L61L0600C3`h061@C01HB4@0D40l06ADD00L30P0S7ah05A4@01LC400D4@/05a@=01PE3P0G
50l061@A01XF4`0I5A@04PdA01HA5@0O6Qh07APN01LB5P0E3a004P`<01<=3@805@l?00T050h>01PB
4P0L4a@060l@01L>3`0F3@h04P/;01TC4`0E3`l00P0D3Ph0200A2`/0<R`/03`f=P0O6AT04@/;01D?
3`0C3@d05Ph?0P0D2``01P0D3@d050h>01@>3P0D3Ph06Q@D00T30`804`d=00H05a4A01@;300>10D0
6@l@01P>3`0C2@X201H<3@0N01<92P0B20T05P`=01L=3P0D2P/05@/:01@:2@0B20L04`T801@:2@0A
1`H03P@301L=300A1`H06Q0?01881`0A20P04@/=01DA4P0S7R80K6Y_02@R9`0V8bX020<901D@5P0@
1`/07a<E00l10@0C10@05PP80P0C1`L02@0B1PH04`L701@8200H30`04`L701451@0C1`L050P80145
1@0201861P0G01D92@0B1PH060`<02hR8P0C1`L05PX:01861P0>0P806`l?030T900]8B<05`/=00l3
1@0C1`T05@T;01<72@0D20X03@4301L;3@0U6A/08ADG00d10`0A1@L00P0@10H02@0=0@<06@d?03@X
:P0W6ad05@T;01451`0?0`D05@T;00l31@0301452@0301<72`0D20`050P<00H04PH:01H04@D901D9
3@0G2`l05PX>01452@0>0PH04`T;00X00P0H31004@H9028F6P0?0`L05`/?0104200D20`04PH:01P<
400@10P050P<01452@0@10P04@D90P0C1`/0100B1PX04`L;01@8300B1PX20104208050P<010040@8
01@8300D20`04PH901<72@0G2`d040@601451`0E2@/03@430186200:000050P:00h2100V6Q`05`/=
1P0A1@L01P0D20X06`lA00P0000E2@/04@D701851`@04`@700D04@D700h41@0@1PL04`T:01072002
00h51P0A00l31@0@10H04PH801<72@0B1PP04@D50146100@1@<05P/901L<200A1P803@8001P<300E
2@/040@600l31@0A1@L00P0B1PP02`0C1`T0Ed]=01X>400G2`d04`L900d10`0K3a403@8301L;3@0@
10H06Ph@00H04`L900H03@4301451`0:0000300201@82P0<008201451`804PH80P0C1`TDooooo`00
6oooool201<92P804PP90P0A1`P01P0B20T050X;01@:2`0B20T04`T:01@:2`H04`X=02/071<F00h5
200>1@P06A0C01<:3@0E30l0IeaP01/@500F2`l050T=01`A5@0@1@T03`@801D:3P0A1PX03@8601@9
3@0I3Q804PP900h41@0I3a0040H701D;300<0P<050X;0147200>10D03@<401882@0F30d04PP90147
200E2``050X;01882@0E2``06@l@01@:2`0F30d05@/<0147200A1`d04@L@00804PP@00d040H>0148
3@0A1`X04@L801<9200F30/05@/:01<91`0D2PT05@/<01@:2`0C2@X04PP900804@L801005@/<01H<
3@0D2P/06a4B01`B4`0G3@l05@X>01<8300B1`/04`P<01D:3P0D2@d04PL;01<8300D2@d05@X>0P0F
2`l01@0D2@d05P/?01L<400C20`040D900804`P<0P0D2@d03P0E2Ph05@/>01<94@0B2a804`dA018<
400A2`l03`T;01@>400E3a404@/;010:2P0B30`03PT60P0E3a40:`0A2`d05@lA01/E5`0=1`T05@lA
01@>400B30h04@/=018<3P0E3a407aTI07QbLP0N61P04P`<00/51@090`<05a4A00l92@0E3`l04P`<
01D?3`0?2@T04Ph;01LD3`0H5A005a@?01HC3P0G50l03``701<@2`0E4Pd0514<01<@2`0C3``0510?
01DA400L61L020@301XF5@0K5aH05a<B01HB4@0I5A@00P0M6AP0AP0H51<04A0>01@C4@0I61H05QDC
01LF500Q81h071/I01TH5P0H5aD06APF01XI5`0K6QP061PF01hN700P81h05aLE02d]:`0J6QP07QhL
01XJ600D51806a/I028R800J6QP0<Bd/02XY9`0P7ad071/I01hN700M7A/07alM01hP7@0L7Q/06adJ
01/P700M8Qh08B8T02@U9`0Q8R@09BHX02DY;00P92L092T]028W:`0S:Bh08BP^01dT:P0O9bX09Bd_
02@/;P0T;Bh09S0a02/e=`0]=cX0:SDi03=1A00W=3T0=D98038oA@0/>Sl0<T5603=2A`0b@DH0<d97
03Q7C00iB4d0<3m403A3B00mC54203I5BP0J03]:CP0kBd/0?Te@03U8C00iB4d0@e9I04ACF`19Ef00
AE=N04=AG@0nC5T0[K[;04QEJ00lBE`0Cea^03Q6D`16E5l0@U5I04IEG013DUL0@4mD04IEG01<Ff80
BeUQ04QGFP17EeL304EEE00Q04=CDP15EE@0AEED04MGEP1<G5/0CUiM04mOG`1<Feh0CEaQ051OI01C
HVL0EFAY05QWK01BHFH0Df9W05ASJ01JJFh0GVeb05IUJP1LJVd0E69S05ESI01FI6D0Df5R05MUIP1L
JV/0F6IW05UWJ01MJf`0Gfe^05e[K01QKFd0Hfm_0080J7Ad00/0JWIg07AoP@1fPH<0NHB707b7R`1o
RXh0PhjC08JAU`2<Ti/0QHbB08:9S`0208>:T0090828R`21RH`0PHV<09FMW`2SZjd0Ri>E08B<SP27
Si80PhZ@0080P8N=00T0OhJ<07f4RP24Ri40PhZ@0827S@22RHl0P8N=07Z4QP1lQhP00P1kQhL0;P1`
O7`0K7Qh07=oO`1dP800LGem07N3P`1cOgl0N8B4079nOP1iQHD0LGem07^7Q`1[MgH0Kg]i07B0OP1^
NWP0JgMc06YfLP1YMG40H6aX05UUH@1OJfP0Gf]W05YWH01IIUh0EfAK051ME@1GI5d0FVIR05]WI@1Z
MWH0KWUk05m[K@1=Fe`0AeEF04aJF`1FI6D0F6IW05UWJ01HIVL0EF=T059PH@1<FU/0AeEF04A@DP1;
EUP2059MG`80C5MI00@0CEQJ03e8BP0lAdT0BeIH0P11C4h0>018DUH0@DY?0459C00k@dH0<CXi03Dk
>`0i?cl0;S@d038f>@0]<3D0<SDj02X]=019C5409BP]02`_=00[;c806QhQ03Lk?@0m@D@0:bl`02lc
=P0W:bh0<3@g03m3AP0a<SL0;C0e02X^<P0V;S409blb02Tc=00/=SL0;SPi03Q0@P0X;C008RLZ02LZ
;@0W:b`0:2h^02P/;@0Y:R`0:BT[01lM800L6Qd07A/N02DU9`0V:R/092TZ02P]<00o@T/0;2hj02h`
?00]<3T07B0Y020S;00O8RT07b8X0P0S9R/02P0Q9BP09BT/01`P8@0M81l06A/J024S8P0O81l08B4Q
01XJ6P0L6a`201lM7P0:024N7`0Q7Ah05QDC01XI5`0K6QP06APF01XI5`0N7A/04a8@01lN70803@`:
00T07A`J014@3P0K6AX05Q@E01<A4P0N71d01083028P8@0H5QL00P0F51D00`0I5aP07Q`M020N7`02
01/G5P0W01PD4`0J5QD071PG01DA400H51<06aLF018>3@0I5A@05A4@01DA3P0B3`T061D>01lL5@0J
5a806QHC014=2P0=2@P04`hB00l:3P0E41@050lE01<>4P0G3a405Pd>01L>3`0H3a005@l?010:2P0N
61P06Q@D014;2`0B30`081XJ010:2P0H4Q8050h>018<300N61P06Q@D00<050h>00X04`d=014;2`0@
2PX04P`<01<=3@0B30`07ALG02/U9@0S6Q/05@`=1@0F3@h00`0D2``04PP901<92P0201<92P0801@:
2`0E2``04PP901L=3P0F30d04@L801P>3`0C2@P201@:2@804@L602L050X900h40`0=0`805@/:01X@
3`0G3@`050X:00l92`0I51P0K6M]0?olo`1PGF@0514H00T42`0A31804@L<020D5P0D1PH05PL801L9
2@0I3@d04PH601L;2`0E2@T04@D504<g=`0j;Rh04`L701T=3@0E2`/04`L701T=3@0E2@T07A4A01/?
3`0E2@T07a<C01@8200C1`L00P0B1PH01@0C1`L050P80186200@10H04@D700805@T;01P040@60186
200I3@l08ADG01X>400?0`D05@T;00h2100G2`d04@D700d10`0B1PP04`L901@82P0>0P@04@D700l3
1@0>0P@050P:01862P0A1@T02`030104200L41@201<72`0?01D93@0@10P04@D901@8300C1`/04@H9
00h21P0O4aL03@8500d11@0E2@d04PH:01<72`0E2@d05PX>00805@T=1P0B1PX01`0D20`04`L;01X>
4P0B1PX03P8601@8300K3a<00P0D20`01P0A1@T03@4501H:3P0F2Ph04`L;0104208050P<00<04@D8
01451`0C1`T00P0E2@/05@0D20X040@600`00P0N4Q@04PH804a0@P1PE5H06@d?01D92`0A1@L040H7
01hB500H30h03@<401D92`0A1@L04`L901@82P0>0P@04P@701831P0201@5200F01D62@0D20X03`D6
01T?400?1@H07A@E01@;300B2@X040@601D92`0L41803P8401041P0@10@03@8002<H5P0H3Pd0Q7Ue
01/@300>0`406Ph>00P0008050P:00T06Ph@01061`0=0@<05PX<01/?4@0H30h05PX<00`20`0B1PP0
0P0A1@L00`0@10H04@D70186200601451`0<00d10`0C1`T02`0101`@4P0?1@H0300201@82P0E2@/0
200001L;3@0@1PL0710B5?ooool001_ooooo0P0E2``301@:2`0701<92P0B20T050X;01@:2`0B20T0
4`T:01@:2`0601<:300;018;2`0E30h040L902lV:02BRH/0DTU;01P=4@0E2Ph02@0201P=4@0=0PH0
0`0D2@d02@0B1`/04@H:01<8300D2@d05@/<01`B4`0J414050/;01482@020147208050X;00P04PP9
0147200B20T04PP90147200E2``050X;01882@805@/<00d04PP901D;300E2``04`T:01H<4@0F3Q@0
610F01H=4`0A20d040L<01472P0B20T04`T:00805@X:00<050T:01<92P0B20T00P0C2@X201@:2`0<
01882@0D2P/05@/<01@:2`0H3Pl06@l@01H;3P0C20`04PL;01462P0B1`/04`P<100D2@d401D:3P80
5P/?00@05@X>01@93@0C20`04`P<0P0D2@d0500E2Ph05@/>01D;4`0A2Q403`T=00h8300?2@d04P`>
010:300A2`d04@/;01<=3@0G4A405Q4>01D?4@0O6A/03@P901TC5@0=1`T04`d?0P0D3Q004@0C3@l0
4P`>01<=3`0D3Q004P`<03`f=P0D3Ph05a4A01PB4P0`:RX0618B01<=3@0Z92@0:B<S01H@400D3``0
5A4>008061D@01805A8=01<@2`0B3`X04Pl:01DB3@0G50l05Q<>01DB3@0F4`h05A4@018>3@0H51<0
71PG01hJ6@0P71/05a<B01HB4@0H51<201/G5P0601PD4`0G5Q@07A`J02<R800P7ad061LE0`0K6QP0
4P0J6AL06aXH01XI5`0K6QP06a/I01TI5`0L71X06ATG01`L6P0D51805QHD01`L6P0J6QP07alM01hN
700L71X07a/J024P7P807QdK02407QhL01`L6P0P81h08B<P020R7`0O8Ah07B8N01lT800Q8R@0824S
01`M7`0P8B<08bLZ028V:@0V:bl082DY024W;00T:c409bhd02H^<@0V;S00:30b02Pa<P0Y<c@0;CLi
02H`<`0e@4@072X]02`j?P0/>Cl0:CHl03I4B@0a@4D00P0b@DH00`0c@TL0=dI;03U8C@0203Y9CP0Q
03I5BP0mC540?4]@03E4A`0eA4D0>4I803Y9C00kBDd0?4YA03m<E00lBU<0EF9]03a9EP0f@e40E65`
041=GP17E6D0>dUH03m=F013DEX0?diE04]JG`17EU/0AEAI04UHG`1;FV40AeEM04QGF`19F5X0B5QH
04ADD`13De80A5AB0080B5QF01X0BEUH04]KF`1<G5d0CEaO04eLH@1>GF80D5mT05=RI`1DHfP0EFAY
05MVJ`1IJ6d0FVU^05m^L`1TLgP0GVea05ITI`1BH640Df5R05ESI01KJFX0J7Ig05aZJ`1JJ6T0G6Y[
061^K`80I79c01T0HFe]06IbL@1_NgX0L7al06ahN@1`O7d0N8>507^6R01oRXd0PHb@08:=TP22SI40
QXfC08F=T@24S900Ph^?08>:SP22RXd0Q8b>08::S029TI<0Ti^M08B<SP25SHl0P8N=0080PhZ@0100
Q8^A08jEV`2EW:80P8N=0868SP1oQX`0PXV?0868SP1kQHL0M7mo07B0O`1cOgh0JgMf06QdL`1]NGP0
N8B30P1ePH00PP1dP7l0OHV807=oOP1bOW`0OHV809^WY01gPh00HFeZ06]gM01/N7D0J7A`06EaK@1P
K6P0GFUU05aXI01HI680FFEQ05MSG`1HIEh0F6EM05=PF@1IIUl0G6QT05UUI01RKFl0HVea05YVJ@1C
HF80CeeN05=QHP1HIVL0EfEV05ARH`1EHf@0EfEV059PH@19EeP0AE=D04EBD`19E5H0BeIH04IAD`10
Bdd0@Da>05UTIP1FHF<0A4mA04E@DP12CDl0AE1B04UCF011BE00?dI<03a4AP0d>Sd0<cTi03Dj>`0Y
;Rh0;30c034c>00h>T40:b`f02h`>00X:S00<38g038d>00^<3@0:B//02d`<00R9BD0:bh^02T[;P0]
<380=cTm02d^<`0/;cD0<3@i030h>`0a>C`0<S`m030j>`0[=CH0<CTj02T_<00Y;S00:b`_024U9P0X
;Bh0:bd_02@T9P0S8RD09B8U02LS9`0S8B@0:bX/03Df>00^<S<09b`_02HX<@0/;CT0:R/g02HX<@0W
:C809RP_02@V;00R92T09BLZ02@V:@0O8R<08B@T02X^;@0g>ST071hM01PJ6@0M7Qd06QXJ01lO7`0P
7al081hO01lM7P0O71d07QXK01`K6@0N7A/07A`J01/J600J6AL071/I01/J600L6aT202HU8`0901XI
5`0I61H06aPI03Pe=P0O71d061DF02<P8@0E4Q<06AHG00805a@E02/06AHG01`I6P0M6Q/05Q8A01`H
5`0N6QT05A4@02<O7P0C3`h061@C01hJ6@0I5A@05A4@01PD4`0F4Q005Q<>01/H500K5a<05Q<?01`H
5P0C3`d07ATH02XV9`0=2@/04`hA020K7P0C3A006@lA01L>3`0I41406a8C01TA4P0E3Pl05a4A01PB
4P0S7Qh04Pd=01/F5P0E40l0618B014;2`0G4A406aDE008040X:00D04P`<01<=3@0C3@d04`d=018<
300201@>3P05014;2`0C3@d06Q@D01H=3P0B2@X00P0F3@h01@0F30d05@/<01D:300F30d05@/<0080
50X;00T04`T:01882@0D2P/08aTJ04<i>P0C2@X060h?01892P0C2@P00P0D2PT201881`0L01@:2@0H
3Pd050X901<9200@1PD03@<201892@0;0`H06aHI02/U:P1NFEl07a/R00X73P0G4QP04PdC00l72`0J
3a004@@401P:2P0B1PH05`/;01861P0I3@d060`<01H:2P0;0@406@d=00d20P8050P800T04PH601H:
2P0B1PH06@d=01P<300B1PH06Ph>01@8200C1`L00P0B1PH00`0C1`L050P801D92`0201<72@0801D9
2`0F2P`050P:01041P0C1`T06@d?01L;3@0A1@L201@82P0301<72@0B1PP04PH800804@D700l05PX<
01<72@0E2@/04`L901041P0C1`T0710D04Tm@@0K3a<050P<00`2100F2Ph04PH:01<72`0B1PX00P0F
2Ph00`0@10P04`L;00X00P0201D93@030105200?0`L050P<008050P<00<04`L;01862P0A1@T01`0B
1PX0500F2Ph04`L;00/00`0U6Ad0;R8V00P0000O4aL03P<6020D600A1PT03P<601<72`0E2@d04@D9
01<72`0D20`04@D801451`0B1PP050P:0P0C1`T04`0H30h02@0001041P0D20X04@L801T=3`0A1@L0
5PX<01451`0E2@/05@/<00l51P0H30h04@D701L;3@0B20T03`<501H:300F20/00P0G20/08@0F1`X0
5@H901<72@0C2`/050X;0107200`:2P0J5mP06UPH@1DB4X081@F00d3100D20X0308301@92@0?10<0
2@0001T>300<0`404@P601L<2@1oLg<0;R8T01@92P0C2@X050P:03hc=@0E2@/0200002@H6P0d:2X0
4`P900l51P0201<72@0301451`0@10H04@D700L04@D700`0;B4S01882@0>10D050P:01@92P0E2@/0
4@H701872@0E2@/04`L901061`0C1`TDooooo`006oooool201D;300501@:2`0C2@X04`T:01<92P0B
20T00P0D2P/00`0B20T04`T:01@:2`0601892P0=0107200?1PL050/<00h61`11>3T03PD601482P0T
6Ad02`0401@93@0:00<05``@01<8300301052@0G01P=4@0O51P0>S0a00l51P0;0@806a4B00h41@0U
6a`04@L801H<3@0G3@h050X;01882@0A1`P04PP90147200E2``050X;01882@0E2``040H70147200E
2``00P0D2P/0100B2P`03PP:014;3`0B2Ph201482`070188300B1`/04PL;01<82P0D20X05@T=01D9
2`0201882@0501<92P0D2P/050X;01<92P0B20T00P0C2@X00`0D2P/05@/<01@9300501872`H050T=
00H04@H:01052@0?10P03`@801<8300D2@d201<8308050T=00@05@X>01D;3P0D2Q804@XA0P0@2Ph0
100A2`l05@lA01<=3`0D3Q02018<300801D?3`0B3@X0100003@^<00>20X0100001H@4P0J51H601<=
3`0>010:2P0>20P04P`<010:2P0B30`0:B<S00l92@0E3`l09AlO02TS8`0G4A4050l<00X70P0?30L2
018?2P0501<@2`0D4@`040d801<@2`0D4@`00P0C40/01`0E4Pd071PE01LC4P0?2`X061@C01dI600:
1PD00P0F4Q402@0G4a8061@C01PD4`0G4a804a8@01TH5P0Q81h081lM01PG5@0201TH5P0M01/J600L
6aT07A`J01/J600J6AL061PF01LG5@0J6QP06a/I018B400L71X07AdK01HF500G5aD07AdK01@D4P0U
9B<07QXI028Q7`0O7Q`07QdK01`L6P0I6AL07AdK01lQ7P0P8Ql07R0M01/P700L8Ad00P0O82805P0M
7R00824S024U:00Q9BP0724U01lT:00R:2d08bX`028Y;`0T;2l0:C4c02/c=@0[=3D0:38c02Pb=00Z
=CP0LGb002`j?@0/>Sh0=dA:02`i?`0`?T@202ln@`030350A@0c@TL0=TE:0080>DQ=0P0eA4T06`10
Ce@0?diC03E4AP0fA4D0>4I703Y8BP0iAdX0>4E;03a9D00hADd0C5UR03e9EP16DV00?TYH041=G@18
EFD0@DmK03=1BP0fAD`0AUEJ04UHG@16EEX0B5ML04]JH@18Eeh0@e5J04IEFP0204QGFP0903m?C`0m
CD`0@e=A04MGE018F5D0Be]J04]JG@1<Feh0CUeQ0080CUeR0100D5mT055PI@1BHFH0Df9W05]ZK`1L
Jg00FVU^05QWK01JJFh0E6=W051NG`1AGf00CUaM04]IFP1BH640Gfe^0P1NK6d0201PKVl0HW1a06Id
M@1WMGD0IG5_06UeL`1bOW`0M8200P1`O7`0@`1iQ8H0OHR:086<SP22SI40P8^?07f8S01oQhX0QHf?
08J>T@22RXd0PHV<08>;SP24S8h0QHf?0869R`26SY00OhN908>;SP1oQX`0PXV?0827S@1oQX`0QhjD
08fDVP20Qhd0OhJ<07f4RP1oQX`0OXF;07R2Q01dOgl0M81n07=oO@1^NWP0K7Qf06ijN01gPh40JgMe
07=oO@1`O7X0MX:007B0OP1`O7P0M81l08bHU01/N7@0GFUU06McK`1ZMW80JGEa06McK`1NJVH0G6QT
061/J01NJVP0H6aZ05eYI@1OJfH0GfaU05QUGP1JIV80GFUW05aXJ01QK6h0H6]_05YVJP1EHf@00P1C
HF80301EHf@0EVAU059PH@1DHV<0FFMX05=QHP18EUL0AE=D04QDEP1;EUP0BUEG04E@DP80?dY<00@0
Ae9D04=>D00mB4X0@4]=0P0oBT`0?P19DEH0@TUA03U0AP0g?D80<3Dh02X_<P0^<c@0:Rh_02X]<@0Y
:C40;Bde01lO:@0X:380;bli02X[<@0[;300;Bh`02h`;P0Y:bP092HS02T[:P0Y:R`0:2T[02`]<@0^
;SH0;c8i03<g?P0b>Sd0;cLj02Xd=P0/=SL09S0a02`e=00[<C40;cDe03Hg>@0^<S<09RX[020Q8`0/
:Rd0<c4d02LR9P0U82@08QdQ02DT9`0^;S00:2//02<W:P0Y:C<0<30l02h^>00Z:S@0:2P`02DV:`0S
92P07b0R02@V9@0U9bH08bDS02<U900N8R40;2l^0P0I6aX02`0P8B008B4Q01TI6@0K6Q/07A/L01hL
7@0O71d081`M01`K6@0M71X071/I00<06aXH00h071/I01LF500X9bD0:2LU01DD4P0J6AL07ATJ03Da
<P0O6a`040`=01`H6@0<20T06ADF01PD5@805a<D00/061@E01TE5P0F4Q40510?01DA400J5QD05A4@
01/G5P0H51<06aLF01hJ6@0201DA400@010<2`0E4@l06QHE01LC400D40l071PG018>3@0H51<07QXI
01XF5@0E4A404Ph?018<300G3Pl05P`=01T?40806Q4B00L05@h>020J6P0?2@T03`/;00X61@0A3@`0
5a8A0080618B00@0=Bl_034[:`0K5AD05a4A0`0B30`01@0C3@d050h>01<=3@0B30`04`d=00804P`<
00D050/<01@:2`0D2P/050X;01D:2`0201D92`0?01<82P0A1`P04PP901@:2`0E2``05`d>00L00008
0000:R0Q00d3100I3a005`d>01<9200D2PT05@/:00804PP702L05@/:01X@3`0D2PT050X901P>3@0E
2`X040H501@:2`0E30l030D900d63@0G4QP03PX@0<Boa@1KEUX03PT:01lG5@0O5A<04`P601@8200H
30`04@D501H:2P0D20P040@401H:2P0G2`/03@4100l30`0F2PX060`<01<71`0B1PH05@T901@8200@
10@05PX:01@8200C1`L00P0B1PH01P0C1`L050P801D92`0D20X04PH801<72@805@T;00h04`L90104
1P0A1@L04`L90186200@10H04PH800l31@0E2@/05PX<01<72@0H30h040@601451`805@T;01404`L9
01@82P0E2@d05PX>07Y^LP1REUX03@4501D93@0C1`/050P<01452@0C1`/050P<0104200B1PX0710D
01D93@0200l31`0301P<400B1PX04PH:00804PH:00<040@800l31`0B1PX01@0B1PX03`0D20`04@D9
01L;3`0E2@d03@4501@83008000050P<01D93@0I3A404@D901P<400K3a<07Q8F01H:3P0201452@03
0145200@10H04@D700<04@D701<03`<501<72@0B1PP04@D701@82P0E2@/04PH800P0000G2`d0=b/]
01@82P0=0@<050P:01041P0Z7R009ATK0186200I3@l03`<4008050D802@04`@701831P0@10H01`00
01L=3P0@1PL0ETe>0<Bk_00M51D05`/=0186200G2`d050P:01H:300A1@D02000020E4`0=10<05``8
00`1000A1P<0<bLW01D92`0C1`T04@D70186200F2P`04PH801451`0E2@/05`/=01D92`0C1`T050P:
01<72@0B1PP301041PH04@D700D03@4301P<3P0E2@/05`/=01H:300200P0000501L;3@0800002000
01<92P0H30h05?ooool001_ooooo0`0C2@X201882@070147200B20T050X;01@:2`0B20T04`T:01@:
2`0601<92P0K01H<3@0B20T05P`=01892P0D2P/07A<D01482P0H3A40304500d31P0F2`l05``@01D:
3P0G310060dA01052@0A1PX06@hB0148200T6Q/06@l@03T_<00L4Q<01`0001<92P0E2``050X;0080
4`T:01T050X;01882@0A1`P05@/<01@:2`0B20T05@/<00l51P0B20T05P`=01@:2`0C2@X04@X:00`8
1`0>20X03`T:00h82P0B2@`04`T=01872`0C1`/04`L<01@8300G20l05PX=00805@T;00@050P:01<7
2@0C1`T050P:0P0C1`T0100D20X04`L901@82P0D2@`;01@93@0601H;3`0L4AD060dA01@93@0G3100
5@X>0P0C20`201@93@0501D:3P0E2`h04`TA014:4@0C3A400P0D3Q8201@>400;01D?4@0B30`040X:
018<300>2@H0;RPZ08b6R00Y8bD05a4C01lI6`0500401P0C3@l04@0A2`/02`D501D?3`0>20P040X:
01D?3`0400005@l?00h8200G4A40618B01@?300F4`h06AH?01PE3P0E4P/04Pl800804@h70P0C40T0
2P0B3`P04a0901DB3@0F4Pl061@C01<?3P0D40l0=C4`018>3@0F4Q4201LC4P0301HB4@0H51<061@C
00805QDC00H071/I01/J600G5Q@06QTG01TH5P0K6QP201dL6P0301`K6@0K6QP061PF00807QhL05`0
6a/I01HF500R8R006a/I024Q7`0F5Q@08R8P01`L6P0H61H08QhM028Q7`0M71X071/I01dM6`0K6aT0
7AdK01lQ7P0P8Ql07b4N01`Q7@0M8Qh07b0R024R900S92H092DW020T9`0Q9BP08bP/02L/<00X;S<0
9bhd02H]<`0U;C009Rh`02Xb=00Z<cD0:38c02Pb=00e@4<0OHR<03I4A`0b?d@0=T=902Xg?@0]>d00
;Se202ln@`0a@4D0=4=803I5BP11D5D0@4mD03U8C@0mC540>4M<03A3B00eA4H0>dU903e;C00iAdT0
=D=603]8CP11CUD0@e1H03]8D@0nBUD0@TiJ03e9E`0nC5T0BUQU082>VP1DHV/0AEAK03m>D`14DeH0
@E1C04IEFP1;FV40AUAM04ABG014DeX0AUEJ04EDF00mCDd0>d]:049BD@14E5<0AeMF04]KF`1;FUd0
C5]P055PI@80CeiS0140DF1U059QIP1CHVL0E6=X05]ZK`1LJg00FFQ]05ETJ@1FIFX0DV5U04aJF`1A
Gel0CE]K04QFEP1<FUX0Df5Q065_K`03069`L00L06AbLP1VM7@0JWId06UeL`1`O7X0Lgmm079nO@1e
PH40NXJ607j9RP21S8h0PXf?07n:S@1lQhT0OXJ808B<S@25SHl0PXZ<0828RP22RX`0PHV;08N?T@21
RH/0QXjA0869S020R8/0PHR>0827S`80OhJ>00/0OXF=07f4S021R900P8N?07f4S01nQHd0O8>;07Io
Q01fPH40MX:007B0OP03079nO00;07=oO@1[MgD0QY:@07^7Q@1^NWP0LGek06eiM01TLFX0KGYc05m/
I@1QKFT00P1PK6P01`1SKf/0IG5]05aXI01GHf40G6QV05m[JP1PK6X00P1LJ6@07@1KJ640EfAN05]W
H`1LJ6H0GFQX05mZK01NJFd0GFY]05aZK@1GIFP0DV1S055OHP1DHVD0Df5T05ARI@1JJ6/0EF=V04YH
F`17EEP0B5AF04]EEP1<EUL0BUAE04I@D@14CTl0?DM803]5AP11Bd`0@Ta=0080?DM80380ATiC03i5
C@0e>T00<CHk02`a=00Y;C00:blb02P/;`0`<CH0:RXb030`>00];CP0=cM302TY<`0U9B`0=3Di02l`
<P0/;R`0:bdZ02T[9P0W:BH0:bd/02X/:`0_<3<0<C4i034d?@0d>3h0<3Lm02`c>@0V<380:C<d02H`
<@0/=C@09R`Z02P^;00d=SD0;C4b02@X:@0M7R00:RP[038`<`0U82@0:2<W02HQ9@0W9RT0:BT[02HY
:P0[;c80;blg02DU;`80;2`f01L07QlU01lP900S92P07b0Q02<U8P0U9b@08R@P024S800G6aX06A`K
01XL6`0S9B@07QlO02DU9@0G5aL06API01/I6P0L6Q/07AXK01hJ6`0J6AL06APF01XI5`0301/J600>
01XI5`0I61H06QTG01TH5P0G5Q@061LE03@`<@0[9bP0:RHW02@P8@0I5AH09B4R01TE5P0H51D401LC
500603Te=019AD@06ADD01`H5`0;1`H07ATH0P0G4a802@0M6AP061@C018>3@0C3`h05A4@01HB4`0G
4a805A4A01XF5@02018>3@0>00d9200F4Pl05a<A014=300D3Ph05``>01D;300G3@h06@l@01L>3`0E
3Ph06Q@D020L6`0`;2/200`;2@0>00`71`0=1`L05Q0@03hh>00f<3006Q@D01D?3`0D3Ph04`d=018<
300C3@d050h>014<300A3@`201H@400;014;2`0C2P/04`T:0147200C1`T05PP;01P9300I2Pd05@X;
01882@0C2@X00P0E2``0200F30d0F4i?02hT9@0>10D04`T:01L=3P0?1PL050X90P0E2`X0:@0C2@P0
4PP701D;2P0m<c80:1hM01061@0A1`H050X901D;2P0O4aD04PH801D;3P0;1@T04@`@01HA5`1XIV/0
6QPK01HA4@0I51401P0001@<2`0F2PX06Ph>01<71`0H30`05PX:01861P0C1`L04PP801D92@0J3Ph0
710@00h20P0C1`L050P801D92@0C1`L04PH601D92@0D20P04`L700804PH601H04`L701@8200C1`T0
4`L90186200A1@L04PH801<72@0G2`d04`L901041P0C1`T050P:00d10`0A1@L050P:01P<3P0F2P`0
50P:01T=3`0>0P@04@D70P0B1PP0600A1@L03`<501X@4P0>0PH060`@020E600K3a<0200001D93@0G
2`l040@800d11@0A1@T04PH:00d31@0B1PX0200001X>4P0E2@d04PH:00l31`0@10P04@D901862P80
4@D91P0B1PX02@0J3Q802P0200d11@0G2`l050P<00d21@0X7200300400d31@0200P0000401<72`0K
3a<07Q8F01H:3P804@D900<04@D801451`0A1@L00`0A1@L04`0?0`D06@d?0186200=0`@060`>0186
200C1`T04@D7038V:01<@4805PX<00P0000D20X03@4301dA4`0D2P/02@0001T=3`0A0`H00P0B0`H2
01<41`0R0186200700004@L801@:2`060000;RDV01<:2`0L41805PX<00`20`0800006@d?01H:2P0A
1P@05``:0146100I3PX0714=01L<2@0B1PH03P8400h3100A1@L06Ph@00/10P0A1@L060`>00d31008
000050P:0186200C1`T04PH801451`8040@61`0A1@L0300=0@<03P840186200W6ad05P`=0186200m
<C<0HeMI02@H6P0R5QP04PP900P001Cooooo000Kooooo`8050X;0P0C2@X301882@8050X;00<04PP9
01<92P0D2P/01P0B20P0200>1@H05`d=01492@0H3Ph02@4101P?3`0@1@T04@H:0`0E2Ph03@0?10P0
4`T<00h31`0E2Ph04PL;00`11@0A1PX040L701<92P0C2P/04PX:01L=3P0N51D00P0C2@X0600A1`P0
40H701<92P0E2``04PP90147200E2``050X;01882@0E2``04PP901L=3P0I3a0050X;0147200D3@`0
4@d;014<2P0?2PT04@/:01L>400F31004PL<01@73`805PP@00@05`L@01H83`0E2@/05@T;0P0D20X0
1@0C1`T05@T;01@82P0C1`T05PX<00804PH800<050T<01@93@0E2Ph00P0E2Ph00`0D2@d04`P<01@9
3@0201@93@805@X>00H06@hB024F6P0L4AD050T=01L<400@1PT201<8308050T=00D05@X>01D;3P0C
2A404@XA01<=4@02018<400?018<3P0A2`d04P`>010:2P0A2`/05@l?018=2P060@8081XL00h82P0>
2@X050h@01H@4P0B30h04`d?00<050h@00l04`d?00h8200A2`/04P`<01TC4`0D3Ph05@l?01`F5P0/
9RH030H601@>3P0B30`040/800h;1P0C40T00`0E4P/0600F4``0514:01HC300E4P/0514:01DB2`0I
5Q40510=01TE500G4a804`l>02hZ:@0D40l061@C01TE500H51<05Q8A01LC4P0K5aH07A`J01PG5@0J
6AL06APF01LF50806QTG00<06aXH01`K6@0M71X00P0N7A/0400L71X092@R020P7P0M7A/09bLU01hN
700K6aT08R8P02DU8`0F5Q@09BDS01XJ600N6QT07QdK01TH5P0J6AL201lO7@0N020P7P0Q8b008R@Q
024S800Q9R808RLS020Q8`0R8bD0:2T[02LX:P0Q9BP08bLZ02P]<@0W;3008bT^02@[<@0X;cD0:30c
02D];`0X<380:S<d02Xd=@0/=SP0;3Hi034l@00W=CP0>DI;02Tf?00^>d40=4970P0_?T<09P0d@dP0
=dI;03M6B`0iB4d0=DA903=2A`0hAd`0<d970350A@0gATP0?DY:03i:C00hA4H0=T=603i:D012CED0
@DaE03U5CP16DU`0CEQT04IBG`0hAU<0@DmL07^9T`1JJ740AeIM04mNHP13DUD0?diA04IEFP1:F640
A59K04IDG`15Ded0AEAL049AE`0oCU40@51@0P14E5<02P18F5L0CEaN04]JG`1<Ff80DV1X04mNI01?
GV<0DV5V05ASJ01EI6T205MVJ`0I05YYKP1HIf`0E6=X05MVJ`1EI6P0BUQI04mMG@1<FUX0CE]K05IT
I01IIfL0H6i^06=aL@1RL700H6i^065_K`1ULg<0KGUg06QdL@1]NGH0Lgmm07J2P@1kQhL0O8R807f9
RP02082;S@0>07n:S@1mR8X0Ph^=08><R`21RXT0PHV:0828R@1oQhT0OHF708N?T@20R8X0RY:E08VA
U01nQXT20827S`040868T022RI40PHR@07n6SP80P8N?00X0OHB<0827S`1oQXh0N86607AoO`1ePGl0
LGek07B0OP1ePGl0LWil0P1cOgd0:P2>VYP0Q92>071lNP1YMG40KGYc06AaJP1[N740HVmX06IcK@1R
KVT0H6aX05m[I`1VLVh0Hfm[05eYI`1QKF/0I71`06A`KP1OJfT0GVYV05]XH@1JIf40G6QT05]WI@1J
IVL0FVEY05]VK01KIf`0FFMZ05ESIP1:F5/0@e5D04MEF01?GF00Df5T05ITI`1DHVD0CE]N04YHF`18
E5H0Ae5B04QBD`80BE=D05@0Ae5B04E?D01:E5D0CEMH049<C@0mAdP0@4Y;04=;D00j@4X0<SHo034f
>`0/<CD0:Rha02/_<P0V:Rd0;Bhc02TX<00b<C/0=SE2051@G00];CL0?3a402d^<P0X:RT092HR02HX
8`0Y;2H09BLS034c<P0`<S40=cPk03@d?00b=Ch0<cLm02lf?00^=C/0;3Hh02Xd=@0U;c00:C8a024W
9@0R:2H0:B/Z024U9P0T:2T09BDW028P8`0U8bH09R4U02TT:00V8BD09B<V02DU9`0S9BL0:Bd`02/[
<P0P82T0:BTa02/[<`0R8bL09RLY02TZ:`0Q8b408bDP02DW8P0O8Q`071hH01`Q7@0K7Qd07AlN02@V
9@0I6QT0820P01`L700M71`07A/L01`J6`0L6AX06aLH01/J600I61H06QTG01`K6@0M71X201XI5`0<
01dL6P0D4a4051<A01/J600H5aD08ahP00l:2`0G4Q@06aHG01TD5P0Q71d06A@E100I51H0100I51D0
>3Dd05aHE`0K5aH201HB4@1201dI600G4a805Q8A01DA400H51<0510?03Te=@0S7b4040`>01XE600G
4aD05Q8A01DA400E4@h03`/801TF4P0M6QD06QLC01TD400I3Pl05``=01L<3P0G3@h05@`=01H>3`0>
20P0<Bd/05QFE00F5A<04Q4?020M700U7al040X:01D?3`0F41003PP801<=3@0B30`04@/;01<=3@0E
3`l0618B01HA400A3@`05@l?01LA4@0@2PX04@P901D;300D2P/05@T;01L9300H2@`06@T<01X<3`0H
3Pl05`d>01D;300C2@X04PP902@J6`0C2PX05@/<01@:2`0A20T060h?0P0E2`X01`0F30/04`T801<9
200F30/08ALF01D;2P0?1@@00P0F30/06P0A1PD05PL901H82@0G2`h040L;00X41`0^:Bd0UiFH02h/
;@0C4@l05A4=01<?2@0>2@@050X801X>3P0E2@T0710@01/?3`0I3@d09a/K01461P0@10@03P@401X>
3P0A1@D04`L70P0E2@T01@0C1`L04PH601<71`0D20P04`L700804PH600H04`L701@8200@10H05@T;
01H:300C1`T201451`0H01D92`0F2P`04PH801<72@0D20X03P8400d10`0B1PP03`<50186200H30h0
3@430186200E2@/04PH801@82P0E2@/04@D701882P0I3A402`4301L<3`09004060`@0P0E2@d03P0B
1PX050P<01@8300?0`L05@T=03HZ;P0E2@d04`L;00/00`0F2Ph040@801452@0B1PX04`L;200B1PX0
0`0A1PT050P<01@8300201452@0?01@9301?@dL09QXN01<82`0A1@T05PX>00h31P0C1`/05@T=0145
2@0C1`/050P<01<72P0D20X04`L900804@D701@04PH801H:300@10H02P0001@82P0A1@L03@830145
1`0C1`T04PH801<72@0;0@807Q8D02hR900?10D050P:01H:300D20X05PX<01441P8050D80P0E1PT0
2@0D20X04@P900`20`0@1PL04`X;00P10@0@1`P04@D700T0000202PL7P0D01451`0C1`L03@8100l4
0`0F2`T0XIJB0>;He00]8Ql04`L700l31@0B1`P05@T;00h2100@10H050P:01451`0A1`P050P:01D9
2`0@1@L401451`030186200C1`T04@D700D04@D700`050P:00l51P0m<C<0FdmA01`@4P0>0P@03@83
02`Q8P0D20X03P@501@92`0F2P`Dooooo`006oooool201D;308050X;0P0C2@X04`0B20T050X;01@:
2`0B20T04`T:01@:2`0B20T04PP801881`0B20T04PP801881`0K4A804PX:00d30P0D2P/060h?00`2
0`0B1`/00P0D2@d0400Q5QX04@H:01/@5017?40060dA01462P0C20`040D901<8300F30d040H701T?
400A1`P060h?00l51P0@1PL201882@8040H70P0B20T0100A1`P05@/<01@:2`0B20T201D;300601X@
4@0L4Q<04`P<00l4200A2PT03PT60P0=20D06@0F3P`07aHG01X@4`0A1P`050L>01L:4@0F2A005PH@
01<6300B1PP04`L901@82P0E2@/05PX<01P<3P0D20X050P<01P<400B1PX04@D901<82P0A1`P04`T:
01@:300C20`00P0A1PX09@0B1`/04`P<01@93@0E2Ph05P/?01872`0D2`h05@/>01<8300I41<050X=
01<8300B2@`04`T=01@93`0D2a005@/@01<<4`0A2Q403PP<00`62P0=1`/040X<01<=3`0D3Q004P`=
018<3P0F410050`=01D?4@0<1PP05a4C018<3P0C3@l04P`>014;3@0B30h00P0E3a40:`0D3Q004P`>
01@>3P0G4A402P@4024K6`0<1`L06A<C00`61P0K5AD030H601/E5@0@2PX071LD018?2P0F4`d05a@=
01DB3@0C40X04a09018?2P0C40X04Pl8014>2@0C40X05a@?018>2`0D40h06ADB01dI600F4Q406ADB
01TE500K5aD06ADB01HB4@0H518071PG01@C4@0B4@l05aHD01XI5`0I61H00P0K6QP201XI5`0c01`K
6@0O7Q`081lM01PH5P0M7A/06a/I028R800l?3X06a/I01XJ600[:bT0Rh^902l_;@0<30X07alM01dL
6P0P7ad071/I01/J6`0N7Qh071`L01hO7`0N81l07AlN01dP7`0O8b808RHU020T9@0P8B<08RHW028V
:00Q9BP09BX^01lU:`0W;3809bhd02@]<P0V;C<0:S8e02de=`0^=SP0:c@e02La<`0X<S@0;STl02Xe
>@1KIVX0AU=H02Xg?@0gA4X0;3Xo0080<3m400/0=DA903U8C@0hAd`0=DA903i=DP10Ce@0=TE:03Y9
CP0hAd`0=T=503Q4A00203M2A01003]6BP0nBDl0@diE03M1BP16D5T0@D]E05QRK01<F640?daE04=A
FP0nC5D0A5=J02hmA015E5T0AeIK045@E@17EU/0BUUP049AF017EEh0BEMP04ECG012DEL0@e9E04IE
F018F5P0AUIF04]KF`1>GF00BUUN04YIH01@GVH0CUeT04mNH`1BHFH0EFAY05MVJ`1JJFh0DV5V05ET
I`1@Gf80BUUL04]JG@1:FE`0CE]L04eKF`18EUH0CUaL05m]K@1QKfl0FfUY05m]K@1PKVh0GVa/065_
K`1VM7@0J7Md06EbKP1/NgP0MH5o07R4Q01jQHL0O8N907f8R`80OXV=00D0P8^?086;S@28T9<0PHV;
07f5Q`0207n7R@80O8B602T0Q8b>07^3Q@29TI@0SYJI07n7RP1nQH/0Ph^B0829T01lQ8/0PXVA08N@
U`1kPh/0OHB<07b5S022RY40Q8^C07j7S01cOgh0M81n071lNP1ePGl0Mh>1075mN`1fPX00JgMe06Yf
M01_NgT0Mh>106McK`1WLV/0GFQR06ehLP1HHed0FFAN06AaJP1NJVH0EV9N05m[I`1QKFT0Gf]Y06Ea
K`0206A`L00O061/JP1OJfT0GVYV05]WI01KIfD0FFEU05aWJ@1OJVh0Hfib05aYK01EHfH0EfEX051N
H@1:F5/0CUaO05=QI01AGf80D5iQ051NH01=Fe`0BUQK04UEE`19De@0AU1B04I@D@18E5@0BUAE04A?
C`14D500AE5A03a8B00203m;B`0K03m8C00mA4`0>cm803Ll@@0Z;c<08bH[02@W:`0P8BH09bL^034a
>`13@dd0BTYE03<c?@16ATh0YJJ[051AD`0c=C@07R0M02<U800[;BP092HS03<e=00_<380<S<f03Lg
?`0c=Sd0;S<i0080:S4g02L0:c@g02`d=P0R:R`09Rh_02P^;P0]<c<0:bd_02d^<00Y:R`092@V02/Y
;00_;C008R0S02TW:P0R82D08B0U02TZ;P0U:2/082@W01PK800S8b/07QlT01`M8P0S92L09BHX02DW
9P0N81d08B<N02DW8P0Q91h07R0K01LI5P0T9RD05QPG01LI600J6a/0820P01XJ6P0L6a`00P0O7Ah0
1`0Q7Ql08AdN020O7@0L6aT06aXH01dL6P0L6aT00P0H5aD03@0I61H071/I01`K6@0H5aD05QDC01LB
4`0P6Q`06A<E01`F6017@D<08A/M01TC5@0J51H00`0K5AL06P0J51H07ATH018>3@0O6aX061@C01DA
400@30/05A4@01TE500?2`X0510?01/G5P1VHV<0=C0d00d8300K5QX05Q8D01<?400J5QD04Ph<014=
2P0o>cP09b@O00H3000L5a<06a4B0P0H3Pl03P0G3Pl05@`=01082@0N61P040`;00d9200@3`d06QHE
01LB4@0C3@d02`D501D?3`0J51@040X:0`0=1`L0700B30`06A<C01dG5`0J51@03`T9010:2P0G4100
60l@01`C500N5AH060h?01P<3P0F2P`05PL:01D62@0G2@`05`d>01H<3@0E2``050X;01<92P0I3a00
1`0001P>3`0700007A<D01882@0E2`X201H<2`804`T800<05P`;01D;2P0B20L00P0A1`H07P0?1@@0
50X900h0000U5aL04P@701P=4@0@1`X03PP:02LS900300004@d;00D0000E40`03`T401@:2@0I3@d0
4PH601L;2`0E2@T04@D501H:2P0=0P806Ph>01451@0H30`03`<301861P0E2@T04PH6010410804@D5
00h050P801<71`0B1PH04PH601<71`0D20P03`<501L;3@0J3Q005`/=0186200@10H03@4301@82P80
4PH801T05@T;00l31@0D20X05`/=01451`0S5aT0=RX/01L;3@0?0`D050P:0186200K3a408aLI024E
5`0@10P060`@01862P0>10H05`/?01452@0B1PX03`<701D93@0T61`06PhB00802P0200D0;R8V00/0
0`0D20`02@010104200301<72`0301862P0@10P03`<700H04PH:00/04@D90104200?0`L04`L;01H:
3P0C1`/03P860104200E2@d040@800`0100201H:3P0301<72`0@10P050P<008050P<00l05@T=01<7
2`0B1PP04PH801<72@0E2@/04PH801@82P0@10D03`<301<71`0B1PL040@600d10`0B20T00P0E2@/0
1`0M4A<08QHH00l31@0=0`@05@T;0186200D1`T00P0C10L201421@0E00h2100C2@X060h?00h41@0G
3@h0200004@j>`13=cT05`/=0147200M4A<04PH801861P0C20H05``:01881`0e:RP0KF9N01/@3P0C
1`L05`/=00<03`<500L04`L900l31@0D20X050P:01P<3P0P51H05@T;00803`<500@040@601451`0C
1`T05@T;1P0A1@L0300;00405PX<01H:300>0P@03`@50186200F2P`050P:03da<`0?0`D04`L90186
21Cooooo000Kooooo`0F01P=4@0A1PX04`P<01<8300A1PX060dA01T>4P0D2@d02@0201872`0C2P`0
6PlC01872`0>1@L081HG01872`0A1`T04`T:01D:3P0D2@`04PP901882P804`P<00T050T=01052@0C
20`06a0D01X?4`0G3100>Rlc01D:3P0?10P00`0D2@d200h41@0400l51P0G3@h05@/<00d310804`T:
0P0D2P/06P0C2@X04PP901<9200E2``04`T:00l51P0A1PX04`P<01882`0F2`l06@hB01@93`0=0PP0
50X=01hE5P1gKVl05@`=01H<3@0H3Pl050X;00`11@0Q5QX030<500l4200G2`l05P/>0P0D2P/02P0C
2@/04PL;01872`0C20`03`@807mdNP12=cd050T?00T0100D2@`200l5100301471`0B20T04`T:0080
4@L801406@hB01@93@0I3Q804PL;01<93@0K5AL030@7038Y;00M5aT0;2DY05mFF`0=1`/03`P<01H<
500F3aH03@@<014:4@02010;3`<04@/?00/05@`A01T@5@0I41@0200401482`0F31001@0101`F600K
5AL06Q@F00H00P02014;3@03018<3P0C3@l04`d?00804P`>03D04`d?01XD5P0=1`T040X<01@>3`0<
1PH05@l?01LB400D3``040/800l:1`0B3@T07APE01@?2`0@2`L050l<01LB3P0C3PX061<@01HA3P0D
3`/050l<01HA3P0H4`l07a/H010<200O71L06aLD01@A3@0H5A0061@A01PD400G50l05a<@01PE4@0I
5A805A@B01@C4@0F5A<06QTG01/J600G5Q@061LE01dL6P0Q81h08R4O020O7@0O7Q`071`J01XJ600L
71X07alM01dM6`0201/K6@0_02LW9@0e=C<05aLE01LG5@0Q8Al061PH01/K6`0L71`06a/M01`L7P0M
7R007QlQ01`M8@0M8B@08RHY020S:00L8B@07bDT024U9P0R:2P092T]02H[<@0F7B<082P`02T`>00T
;C808bhb02Tc=@0Z<cD0<3Pk02de>00Z<SD0:C0f02Tb=`0/=C/0;3Lm04=>E00^>T40=T=;02llA00b
?dH0<Ci4038oA@0iAT`0?DY@03Q5B`0gA4X00P0jAdd0;P11CU@0A55G045>E00lBD/0=T9002`h>00g
@T@0BEAH049=D`0mAe00BE=L04]EGP1AG680DeiT04MDE`16E5L0@e9G045@E@11D5L0@U5H04ACFP0i
B4l0@E1G04]JH018Ee`0AEAI04]JG@1:G600@E=G03U;CP12E5H0AeUK04EGF00nD580AeUK04YLGP1<
GV00C5iR04QJGP1>GF80DV5V05IUJP1DHfH0Df9U05MVJ@1FIFP2051PH00L04QHF00oCdl0CUiN05MU
I@1>G5`0EVAT05UWI`1DHV80FfUY069`L01JJ6P0GVa/06=aL@1ULg<0IgEe06MfL`1TLg00J7Qg075o
O`1fQ8D0Lh6408>>TP1kQX/0NHB:07n8S`24SID0PhbC08N>UP80PXV?01L0O8B708::S@1mQHP0PHV<
0828R`1oQhT0P8R:08::S024S8l0OXN<09bV[02e`<H0PXbB08><T`1lQhd0NhF<07Z3RP1aO880OXR?
08RAV01nRHd0Mh>407N3P`0207J2PP80MX:004/0LWil075mN@1aOGT0L7ah06mkM`1`NgL0J79[06E_
I`1RK6@0GVMR05URG@1GHU`0GFMT05aWH`1QK6P0HF]Z061/JP1TL6h0I6i`069/KP1NJ6T0HVa]05MQ
HP1TKVl0GfUZ05USI@1MIfT0EEmQ04iHFP1=FUd0CEaQ04mNH`1=G600D5mR055PH`1=GEh0CUiN051P
H01<G5/0A5AC049BDP14DE80CeYL04mJGP13CU40AeEF04mJG015DU<0CE]L07F3P`18EUH0=D=303I4
A00mBDX0<3Tn04mFG00b=c/09bX_030a=P0Q8RP0;Rhf02XZ<P0h>480<cHo03m2BP0d=CT0;c0b03Xk
?@0o@D00;c4`024S8P0[;B`06adL02TZ;00a<S@00P0e=SX0800^<CH0<CHj03Hk?`0i?T80:c0d02hd
>00W;300;S<g024V:P0U:Rd06AhQ02HZ;@0L71h0:2HW02XX:@0S8bD07alQ02TX;@0O82@0;Bhc020S
:00V:Bh08BH[01lT:P0U:Rh082<X02``<`0I7B00;Blb024R900J6ad07QlO0P0R8R00400N7Q`061PF
00l?3`0R8R806ATI02h^;P0I61T09bDV01`J6`0K61T06aLH01dI6P0O6Q/07ATJ01XH6@0L6Q/201dK
700N01XH6@0H5QL05Q@E01XH6@0I5aP061HG01TG600D4Q<06QHG01LC500E4A805a<D01`H6@0N6Q/0
5a<D01PD5@0L61T061@E01HB4`0L61T06ADD01/G5P0M6AP06aLF01LC4P0D40l06ADD01/G5P0I5A@0
5A4@0P0D40l601LA4`0;01D?400I4a<0?SPh02DO7`0I4a<03`T901H=3P0B2@X04@P9010:2P0C3@d0
100E3`l02@0C3`h04`d=018<300O6AT071HF00`61P0L5QH08Q`L01D?3`02010:2P0M018<300C3@d0
5@l?01L@4@0F3A0030<601P>4@0A1PX0714E01052@0H3A405P/?01052@0C1`/04PH:01D:3@0B20T0
40H70147200C2@X05`d>01/A4P0E2``040H701@:2`0E2``03`D601H=3P0?1PL00P0A20T00`0:0@80
4`X;01482@0401482@0B01882@0@10H04PH801@82P0B1PP04@L801@:2`0C2@X040H701@:2`0I3`h0
5@/:01061@0>0P807A4A01<71`0=0@404PH60P0H30`06P0?10@04`L701861P0E2@T02`0000P0000M
4A<02`0101T=3`0B1PP03@4301@82P0=0P<03@430186200C1`T0300201041P0L4180=RX/01451`0H
3Pl0200001@82P0B1PP050P:0P0G2`d01P0B1PP02P0001/?4@0800009QXL05E9B`805PX<00L04@D7
01hB501MDE<06@d?00l31@0?0`L03@4500804`L;00@03@4500/00`0B1PX04PH:0P0C1`/03`0B1PX0
4@D901<72`0C1`/04PH:0104200B1PX050P<01X>4P08000050P<01472@0D20`06@dA00l52@0200h3
1`0:00l4200B1`/050T=01H:3P0>0PH03`<701`=4P0E1P/03@44010420804`L;0P0@10P601452@07
01L:400]82L07Q4H00d31@0G2`l040@601861`0201861P0S01461@0@1@<040D301461@0C1`T02`01
01D92`0A1@L06Ph@00l31@0=0@<04`L900d3100?0`D05@T;00l3100C1`L05PX:01@8200B1PH03`<3
00h20P0K3`l03`@400P0000?1@@08aLG01T=3@0F2PX040@400d10@0?0`<04`L700l30`0@10@00P0C
1`L04@0B1`D040@401T=3`08000050X;01451`0F2P`04PH801451`0@10H03`<501451`0B1PP040@6
01@82P0B1PP040@600804@D700<040@60186200B1PP0100B1PP0300D20X04PH801041P0@10H04PH8
01@82P0B1PP05@T;01/?4@0H30h040@601@82QCooooo000Kooooo`0C01D:3P0B1`/050T=01@93@0B
1`/05@X>02<H700O5AP06a0D01H;3`1:?d<040D900`21@11=SX0?34e01hC5`0A1PX040D901462P02
01872`0801D:3P0G310060dA01<8300?10P04@H:01L<400E2Ph201<8300601052@0C20`04`P<0146
2P0C20`05P`=0P0E2``0100K4A806@l@01882@0B20T301<92P804PP901P050X901@:2`0C2@X040H7
01462P0C20`05@X>01X?5@0:0@D06a4F02@I8@0F2a003@<402HL7@0A1`P0718C00h41@0B20T060h?
00X20P0J41404PP901061`0B20T201@:2`0;01<92`0C20/04PL;01P=4@080080<BH/01dB6@0J3aL0
50TA01472@0A1`D00P0A1`H0100B20L04`T:01@:2`0B20T201<830804PL;01h050/>01TC5@0?2@/0
5Q0B00`6200T7R80A3i201XD600D3A@03`T?0109400A2a403@H=00h8300A2Ph04``@01@=4@0E3a<0
6a<H01493P0@2@d07ADJ00d52P0F3A804Pd>01LA4`0D3Q009AlQ01H@4P0B30h2014;3@@04`d?01@0
40X<00h82P0E3a404`d?018<3@0D3Ph04@/;01@>3@0C3P/04Pd:01@?2`0H4`l04Pd:01XE4P0K5Q<0
5a8?01@?300F4@h061<@01HA3P8050l<00/05Q4>01PC400H51006ADA01XG4`0B3`/061@@018>2P0K
5a<06QLC01TF4P0201TE4@0401PD4@0I61H061LE01TH5P806aXH00D061LE01XI5`0K6QP071/I01dL
6P0201/J60<06QXH0P0K6aT201`L6P0701PH5P0K6aT06a/I01lO7@0J6QP06ATH01lO7P02024Q8P80
7b0S02007QlR01`O8`0L82@07R4U01lT9`0O92P08BLV02<Y:@0P9RH06b<V01XQ:@0Y<3P07bPa02</
<`0O:Bh07bX^02hi>`0V<3809blb02Xb=@0_=c/0<3Pn02lh?@0[=3X0?TQ>02Ha=`0e@DP0OX^C04QE
G@0_?4<0<Ci403A1A`80>4E;00@0=T=903M4BP0kB4h0?T]A0P0mBU00:00oC580@4e?03M4A00a?Sh0
>dM;03]7CP0g@T/0?TUB04MCG016DU/0Ae=J04MDE`0kB4/0?Ti>03m?C`10Ce<0@4mF03m>E@0oCEH0
@e5J04IDG@19F5l0A5=H045@D`13De<0?4i@03]=D016F5/0AEMJ04=EF018FUd0BE]N03mAE01:G5l0
AUQK051RI@1>H6<0D5mT055PI@1CHVL305ASIP0`059RHP19FET0BEUH04aLF`18F5L0D61O086?S`1L
JVX0CUaL05ARHP1HIVH0FVQX05QVIP1MJf/0IG=c06AbLP1RL700IWAd06EeM01ZNWT0KWin06moP01d
PhD0NHN;086<TP1lQXh0NhF>0869T`24S9H0P8VB07j5S`21R900QHbD0868SP22RHl0P8N=08::S@21
RH/0OhN90828RP21RH/0PH^=08F>T`2U/;H0[KRn07f8SP1hPhT0PXfC0P23SY@06P1oRY00O8N=07^6
S01gPXH0N8>607J2PP1dP800LGem06ijN01]NGL0KWYh06mkM`1^NWH0JgMc06QdL01WLV`0Hf]U065X
H@1OIUl0GVAP05aUH@1MIV80G6IR065/J@1NJ6H0GVUW0P1SKfd0<01QJfd0HVe_065[K@1ZMGL0H6]]
05eXJP1OJF/0F69T06=^L01JI6H0Ae5C045=D@16EEX0DF1U05=RIP1DHfH0DV5T04iNG`1>GUh0CUiM
04YJF@14E5<0@U9A049@D019E5L0B5=F03]7BP0lBT`0@4i?03i<C@0lBT/0A5=C03U8B013De<0=DE4
0390@@0_>S`0<3Pk02DZ;P0U:2d0<C4h04a;D`0c<SX0<30h03Hi@@0i?4@0?45702d^<08092HU02d0
:2XY028T8`0T9BL0:BX/02<T9P0/;C40>3Tm02h_<`0g>3d0<3@h03@i?00k@4<0@TI:03<h>`0]<SD0
<cLk03Pl@00Q9RT082@X02DY;@0m@4@0:BPZ024N7`0V92D0<30b02PX:P0U9RX0<cHk03e0A@0X;380
9b`b02<X<00S:Bl092T_01dR9@0^<SD06AdP028T9`0W:2X07QlQ02DV9`0W9bL08R8R01hN7P0L71`0
0P0Q8B400`0^;Rh06ATI020O800201lM7P0601dJ6`0M6AX07QXK01lJ6`0M6AX071PI0P0J61T02P0I
5aP061HG01PF5`0K6AX05Q@E01`J6`0P7Ql07A/L01XH6@0I5AH201PD5@0F01TE5P0J5QL06aLH01hJ
6`0K5aP030P903`h>@17@d@061@E01TE500G4a805A4@01LC4P0I5A@06QHE01@@3`0G4a805Q8A01DA
400F4Q405a<B01D?4@<05Q0B00d05@lA01@>400X8R@081XL01D?4@0B30h0;2HX01D?4@0E3`l04`d=
018<300C3@d050h>00@05@l?010050h>01<=3@0D3Ph04P`<01PB4P0X8R808A/K01H@400C3@d04P`<
014;2`0B30`04`d=01@>3P0C2P`06PlC0P0B1`/02`0M4QH04PL;01H;3`0F2`l06@hB01D:3P0A1PX0
5P/?01@:300F30d05@/<00805P`=00d060h?01D;300E2``05@/<01H<3@0E2``04PP901D;300@1PL0
6a4B02DK700K4Q<040L800H04PP90P0J3Q001@0I3@l04`L901451`0A1@L050P:00804PH801H040@6
00l31@0H30h081@D00l30`0F2`/06@d=01L;2`0B1`L04@D501<71`0G2`/03`D501D:2P0H3Ph04`L9
01451`0C20T06`lA01H:300P51H04@D70P0B1PP201451`060186200A1PL04`T:01D92`0D20X05P`=
0P0C1`T0100B1PP04`L901D92`0E2@/20186200A01<72@0D20X04`L901882@0A1@L03`<501D92`0;
0@807A4C00h2100D20X0:1`P01<72`0?0`L04PH:01<72`0D20`00P0B1PX201<72`0>01862P0A1@T0
4@D901862P0A1@T040@801452@0B1PX0>2``02PL800<0P@060`@01462@0=0@D201<8308050T=00h0
50P<01<8300B1`X04PL;01462P0B1PX03`@601H:3P0C1`/04PH:01@8300C1`/04@D9010420D04@D9
02@040@901T<500B1@`040@901@8300?0`D04`L801861P0B1`H04@H501050`0@1@804@D401<72@0I
3@l04@H8038V:01?@dD05@X<00d3100?0`D04`P90147200C2@X04@D601<71`0@10@03`<30104100D
20P05`/;0104100C1`L04PP800h20P0A1@D201<71`0401@8200B1PH04@D5010410H04@D501803P84
01X>400/82803`<50186200<0P<03`<501<72@0E2@/040@600h2100C1`T04PH801@82P0E2@/04PH8
01041P0A1@L60186200601@82P0B1PP040@601041P0B1PP050P:0P0A1@L201H:30804@D75?ooool0
01_ooooo0P0C20`201@93@804`P<00`081DI01`A5@0=0PH02`0401H;3`0J3a<0714E03DZ;P0B1`/0
40D901H;3`0H3A4201@93@0501D:3P0H3A406a0D01`A5@0B1`/00P0@1@T02@0C20`04PL;01052@0F
2`l05``@01D:3P0@1@T04@H:01D:3P0201882@0401061`0C2@X04@L800/10P804@L80P0B20T00`0A
1`P040H701<9200201882@0E0147200B1`/04`P<01lD600B1`d05@X@02/P9P0X7BD060dB01P>3`0C
2@X08aTJ01@:2`0=0`@050X;01X@4@0O5AH060h?00L0000E2``05P`=00@04`T:00T04`P<01462P0B
1`/04PL=01@9400B1`l060dE01872P0B20H00P0B20L05`0A1`H04@L801882@0H3Pl04@H:01@93@0B
1`/05``@01072P0<1PP03`T;018<3P0D3Q003`T=00X4200A2`l04P/B01D>5@0F3aH05a0G01<94@0C
2Pl050X?00804`X?01004P/?018<400H4QH05Q0D00@00P0400<09b4U02DO8@0@2P`05a4C00d72@0I
4aD030H800l92`0@2P`04P`>0`0C3@l0200K5AL04P`>01H@4P0=1`T04`d>00h8200D3Ph050l=0P0C
3P/01`0D3`/05A0<00d81@0J5A807APE01HA3P0B3@X00P0G4Pl02`0F4@h05A0=01D@3@0F4@h05a8?
01HB3`0C3``05a<@01DA3P0M6AH05A4>008071PE00@06aLD01XF4`0I5A8061@A100J6AL01@0I61H0
5aHD01`K6@0I61H061LE00805aHD00h061LE01PH5P0I6AL061PF01LG5@0J6QP071`J01/K6@0M7A/0
ADE301dM6`0D518092@R01hN70808B4O02P0820O01lQ800P8R408b@V028V9`0P92L07R8U028W:P0V
;2`07bDS01HL700U:b/0>d=601XQ:@0U;3@0:34j061YL00S;C<09C0d02/f>00X<C@0;SHi02/c=P0Y
<SH0;SLl03@m@P11Be4082/a030k@@1RKWD0EF9Z03m<E00^>d80=45703Y7C@0iAT`0=T=903Q5B`0j
Add0?4U?0P0oC5804@0nBe40@4eC03i<D00oCE00>dQ>03Y7CP0kB540?DUE04=?F`17Del0AE5M04MD
G01<FEl0AUAH03i=D010Ce80@U5F0080@E1G00@0@U1I04QFG`17EEh0AE=K0P13DUL01`14DeH0D69V
04=EF@11DeL0A5IJ04EGF`1<GV800P16F5`01`1>H6@0GFmc065cM`1AHfL0Df9W055PI@1@Gf@00P1E
I6L0101AH6<0CEeM04IFEP18F5L204iNG@0J059RH@1@GUh0E69R05e[J`1KJFT0EVAT05]YJ@1MJf/0
GVa/06=aL@1RL700Hg5a06]iN@1VMWH0K7am071oPP1_OX40Lh6507Z7S@1mR8h0O8N>07j8T@22RYD0
PHVD07j6T@1oQY0207b3R`0508>:T01nQH/0O8>90869S021RH/00P1oQhT08`1nQXP0OHN907f6R`1n
RHl0MX6707j9S`1oRY00TIbR08>>U01oRY00PhjD086<TP1kQX`0OHR<07N2Q01cOgl0LGem06ahN01X
M780Ig=a06ijN01_NgL0KWYf06UeL@1RKVX0H6]W05eUG`1KHU/0FF1I05YPG01LIF80GVMT05aWH`1_
NGP0Ig5`0080HFe[01d0F6AT05i[K01VLG<0G6Y[06=_L@1TKg40F6EV04aJF`2>VI/0Y[:d04mMGP12
CDl0;Se003Q7C018Ee`0CUeQ051OHP1AH6<0CUiO04]KF`1:FUT0AeMF04=CDP12DU40@4m>04A@D013
CU00>DI703U7B00203]9BP1?04ABD`0nC4d0?4Y=049AE00c@D@0<cm202Xe=`0/=3L0:c4e024T:@0V
9b`0BTYA02@S:`0[:c<0:Rdd038e?00j?d@09RLY028T8`0V:2L09bTX024S8P0O82808b@V02`];`0Y
:Rh0<34e028S9`10@DH0:Bd`02hb=@0b=ST0?413038f>@0X;2l0;S8e03Lk?P0X;2l07b<V02L[;P0a
<cL092@V01dK700W9BH09RHX03Xj?01aLWH0=3Ll03i1AP0V:C008RL]01hR:P0M8RP08bP/02DY;@0L
82<08BDX04E7BP0R8bD06AXL01/L7@0O7al08B4Q020P800M7Ad06ATI01hN7P0B4Q808B4Q01dL7@0X
9RL08AlP01lL7@0M6AX07QXK01hI6`0K5aP07ATJ01TG600201LE5P0:01PF5`0I5aP061HG014?400K
6AX07A/L01HD5@0J61T05a<D01TE5P806QHG00T061@E01LC500D4140510A00`82@0P71d0920Q00l;
300J5QD00P0H51<00`0M6AP0920O02LS8P0201PD4`0601HB4@0C3`h04`l>01DA400D3Q005Q0B0P0G
4A<0300D3Q004`d?010:300@2P`06Q@F01@>400I4aD04@/=01@>3P0E3`l05Q0@01D?3`8050h>0`0E
3`l02`0D3Ph04`d=01D?3`0<1PH03@L701lI6@0E3`l03`T901@>3P0C3@d04P`<00804@/;00P04P`<
01H>400M4QH04@H:00h41`0O51P02@0201dB5P801`0000@0714E028G6`0/8BD060d@0`0C2@X20188
2@0302<I6P0P5QL05`d>008040H70P0F30d01@0@1PL050X;01/A4P0G3@h04`T:00H04PP901404PH8
01@82P0E2@/04PH801451`0C1`T05@T;01<72@0G2`d05PX<01451`0B1PP050P802LK6`0_8b<02000
01lC4`0200l30`0=00d20P0A1@D05@T904<g=`1ZGUh0300200h3100M4A<060`>01<72@0L41804PH8
01@82P0401<72@0600P0000B1PP05PX<01dA4`1LD580D4A60P0A1@L0500B1PP04`L901<72@0B1PP0
3@4301041P0=0@<040@601P<3P0D20X04@D701<72@0M4A<05PX<01<72@0A1@L0RWj202`P90090040
3@<50P0E2@d201862P804`L;00D04PH:01452@0@10P04`L;01862P0201452@0901862P0>0`H02P02
01<72`0=0PD07A4E01D93@0C1`/04`@9008040@800h03`<70104200C1`/05``@01@93@0K4A@03`@8
01D93@0?0`L03@4501@8300I3A405`/?01862PD04@D900L04PD;01032P0A10/060`A0104200;0040
4PH700804PH600@04@H501050`0@1@<04PH60P0800009P0<0P<040@602@H6P0>10D03P8400X0000D
20X04PH801@82P0J3Pl040@401@8200F2PX04PH600d10@0@10@05@T901H:2P0K3`l05PX:01<8200@
10@04@D501@8200C1`L04@D500l30`0C1`L04PH60104100?0`<040@401<71`0I3@l060`>01T=3`0=
0@<06@d?0P0?0`D02`0B1PP05@T;01041P0>0P@04`L901041P0E2@/06Ph@01<72@0?0`D04@D700P0
4PH80P0@10H20186200601<72@0@10H050P:01P<3P0F2P`04@D75?ooool001_ooooo01804PL;01@9
3@0C20`04`P<01@93@0B1`/040D900`31@0<0@D08aPL00`21@0A1PX0714E01lD600>0`L06PlC0146
2P0<0@D201462P0501052@0B1`/04`P<01<8300D2@d00P0B1`/0300C20`04PL;01462P0A1PX03`@8
00h31`0B1`/05``@01P=4@0D2P/05@/<01882@804`T:00<03P@50147200A1`P00P0B20T00`0A1`P0
40H701<920020147200E01882@0C20`04`P<01`A5@0@1@/03@8801H;4@0R5al06Q0D01061`0>10D0
6Q0A00/10P0E2``040H701X@4@0m<c@050X;01`B4`0<0P<05P`<00804`T800`04`T901<92P0C2@X0
40D801dB5P0F2a405@X@00/01P0B1`d03`D601<91`0C2@P201881`804PP901D0718C00h31`0A1PX0
4@H:01dB5P0:0P@02`D701XD5P090`D02084018<400F41@07QPL00X42P0700L03`P?01XA6@0D2A40
50T?01D93`0D2@l00P0C2Pl02P0E3a<0100201/F6P0=20`05Q@G08f8S02ESi406A<E018<3P0@2P`2
018<3P03010:300A2`d04`d?00<04`d?00T02`D701LA4`0L5QP030H801@>3`0E3`l05Q0@01D?3P0C
3P/00P0D3``01`0D3`/04@`901D@3@0F4@h050l<01<>2`0E40d01P0F4@h03@0[9b@05A4>01hJ5`0N
6QL06aLD01LC400J5Q<06aLD01`H5@0K5a@06QHC01PD4@0I61H00P0J6AL02@0I61H05aHD01HE4`0M
71X06APF01PG5@0G5Q@061LE01TH5P0401dM6`1<01hN700O7ad06a/I02<S8@1;BdT07AdK014A3`0R
8R008R<N020Q700N7aX06a`H01dO700O8Ah092HU02<W9P0P92D07R8S028X:00V;2`092XX01TO7`0/
<S80ATiA01lV;P0T:c<0<CY30;o8c`0d?T<06bHZ02D`<P0`>C`0;3@g02H`<P0T;S40:34f02dh?00X
<cP0;3Lm02`i?`16DeX0@e1H030mA@0a?TH0>dQ@045>EP0oC5@0>dQ@03m<E00nBe<0>DI>03Y7C`0o
C5@0@4eE03e:DP0d@DP0@TmE04EBFP0oC5H0@4aH03U5D`0mBEL0BEES04A@GP13CeX0AeAL04=@E`0m
C4l0?4]>03a;D00oCUD0@DmH049@F`18EV40AUAM04=BFP80@E1E00X0@e9E03e?D`11DUT0@U=J04MH
G`0mCUD0AUMN04QIH01=GVD0CUmV0P2M[[D01`1@HFP0E6=X059QIP1AH6D0E6=V05ETI`1AH6<00P1:
FUX08P1=GE`0CUiM04eMG01DI6<0F6IV05UWI`1GIFD0DV1P05=QH@1OKFd0H6i^05i/K01VM7@0JgUi
06QfMP1WMGH0JGQk06]jOP1]O840L7n407B2R01ePXX0O8J?07f7T01oRI<0PHVD0828U01mQI00OHB>
07b3R`23RY80UYfS08J=T`1lPhT20828R`80OhN905d0OXJ807b6R020RHh0PXfA07j9S@25T9@0Lgj2
07Z5R@1nRHd0MX6507^6RP20Rhl0OHR<07b7R`1eP880LWin071lO01]NGT0JWId06UeL`1/N7H0KGUe
06ahM01VLVh0GVYV05aWH`1NIV40Ff5M05QNFP1GH5/0FV=P05aUHP1`NWT0NhN506ahMP1PK6`0G6QX
05APH01FIFH0GVa]059RHP1HIfL0EfEV05m^KP1=GEd0Df5R06YiNP1FIVH0BUQI049BE01;FUl0Df9W
051OH`1>GF00CEaO04aKG@19FET0AUIE04=CDP11DE00@51?03i=C@0nCDX0?Ta<03U7A`0kBDT0?4Y;
03e:C01;EUX0@TeA04A?E@0oC580=T57034l@@0_>S`0=Si1020U:@0f>Ch0<34f02/[<@0Y:2h0>3Tn
03Dh?@0m@4D0CeAH024R900R92<0:2XY02T[:P0S9B@07b0R028S9@0a<S@00P0W:2`00`0U9RX0BT]@
02@X:`0202P/;`0Y038f>@0/<3<09b/^02P/;`0^<SD0:Bd`01dQ900R9RT08bHY02LW:@0M7Al08R8T
01/K7@0];Bl0HF9V020Q9P0^;c@07R4V02<V;@0R9R`08BH/01dR9P0U:Bd061`O028V:@14AdT08R<U
02PY:`0Q8B80820P02<S8`0O7al05QHF02PX:00J6QX0:BTY038b<P0E51D0928S024O800N6a`00P0M
6AX0100M61X06aLH01hJ6`0J61T201PF5`0D01TG600J61T06ALH01LE5P0N71d071XK01DC500K6AX0
5a<D01TE5P0J5QL06ADF01LC500E4A807QXK024M7P0O6a`061@E01LC500I5AH201DA400401HB4@0H
51<06aLF01`H5`806ADD00H05a<B01@@3`0F4Q405a<B01H@4P0G4A<201PB500<01H@4P0E3a4071HH
010:300K5AL04P`>014;3@0J51H04`d=01D?3`0F41005@l?0P0C3@d301D?3`0401@>3P0C3@d04P`<
010:2P<03`T900@04@/;01@>3P0C3@d04P`<0P0A2`/03`0B30`05@`>01@93@0>0`L060dA01T>4P0=
0PH060dA02dR9P0Z7b<040L907Q]L@1gK7003`@70147200201882@090147200@1PL081HG01hD5@0H
3Pl04@L801061`0D2P/04`L900@04@D700<05@T;01<72@0C1`T0100C1`T00`0?0`D04@D701<72@02
01<72@0T01H:300E2@/03P8400l31@0F2P`05@T;0186200P51@0?C4a044e=@0@10@0=RXZ020D500G
2`/04PH601451@08000040H601451@0:00004`L901H:300<00803`D601<72@0F2P`04PH801451`0E
2@/05PX<01041P0J3Q0060h?01451`080000:1`N0P0A1@L20186200A01451`0C1`T050P:01041P0F
2P`02@0000d10`0I3@l02P0001041P0O4aD0?C4c01@82P0800004@D700h21P0?0`L00P0E2@d0100@
10P04@D901862P0B1PX201<72`0301862P0A1@T04@H:008050T=00/04PL;01462P0B1`/06Q4C01D:
3P0700006@hB00L0000@10P06@X?01H52`0201<42@0>01<72`0D20`04PL;01@93@0600006a@F0189
300A1`X03`<700d11@0C1`/06@dA01L;3`0C1`/501452@0T01@8300>0PH04PH:01X>4P0>0PH03002
01041P0B1PP04PH601451@0@10@040D301D92@0K3a40300201X>400800002@0000l31@0K3a404@D7
00d3100L41803P8400X0000800003@<301D92@0B1PH040@401H:2P08000050T9075UI@0Q5AD040@4
0P0B1PH04@0A1@D040@40104100A1@D04`L701861P0@10@03`<30104100C1`L0710B00h2100<0080
3`<501L;3@0B1PP04@D7008040@60P0A1@L01P0@10H03`<501D92`0I3@l04`L900l31@L04PH80P0A
1@L201041P804@D700H04PH801451`0B1PP05PX<01L;3@0@10HDooooo`006oooool03P0C20`05@X>
01462P0A1PX05@X>01<8300A20X060dA01872`0@1`T04PL;01L<400D2@d040D90P0E2Ph01P0G3100
9a`P01D:3P0D2@d04PL;01462P804PL;00<050T=01<8300C20`00P0C20`301@93@0401<8300G3100
5@X>00l4208050X;00D040H70147200C2@X040H701882@0301<92P804PP901`04PP701061`0@1PL0
50X;01@93@0C20`04@L:01X?5@0D2@l04`T>01873`0P5QX06Q0A00l51P0B20T050X;01L=3P0E2``0
3`D600l71`0O5AH0KF=T01hD5@0@1PH04PP701<9200C2@T050X:0P0D2P/0500C20/04@H;01D:400T
6Al09a`R01H;3@0B20H04PP701<9200D2PT050X;01H<3@0G3@h0308503@Y;@0E2Ph0714E01L>4@0=
1`T03@P90P0@2P`06P0C3A4040X>01LA5@0B2a8040T@01@=500J4aX04@@=01<5300D1`h05PT@01H;
4@0G3Q<04`dA00l;3P0F4aH06aTL01XI6`1/Jfh0GEUJ01dG6@0G4A<02P@600`6200D3Q004P`>0`0C
3@l04P0B30h04@/=01@>400I4aD02@@501`F600B30d07QPH01D?3`0C3@`04`h;01D@3@0G4Pl05Q4=
01@?300C3P/04Pd:01@?30805A0=0P0F4@h201LB3`805Q4>00P0;2PV01@@3P0I5A<05Q8@01LC4@0K
5aD05a<A01TE4`806aLE00<06QHD01PD4P0H5aD00P0K6QP0100I61H061LE01TH5P0I61H201PG5@09
01XI5`0K6QP071/I01/K6@0I6AL071`J020P7P0L71X061PF008071`J00/07alM01/K6@0K6aT05ADB
020Q6`0P8A`07b0J01`M600L7QX07R0L028T800201hS801;01hS8@0N92<07bDT02<Y9`0S:BT092XZ
02<[;P0L8b/09B`d030i@P2KY:/0<C]102<^<P0V<C<09c4c02Tb=00[=CL0<3Xm030j?`0_>Sh0;cXo
03I2B00[>3h0=45802Le?@0a?dL0<T1803E2BP0iATh0>4E=03I3B`0iATh0>dQ@03Q5C@0f@d/0>TM?
03a9D@0jAdl0>TM@041>F00lBED0AU=Q059NK`1AGFl0EF5c059OK`18E6D0@DiL04AAF`11CeL0@4mD
03a;CP0oCU@0CE]T055OJ01:F6<0A59M04IDG`15De`0?TeD03a;D010Ce<0GVmf06n0Q`14EEd0BeaU
04AEG01fQhl0DfA]05=TK01<GFD0KGj70721R01=GVH0DF1V0080DF1U01L0D5mR04mNH@1>GF00BEUI
04]KF`1>GUd0D61O059RH@1CHf80FfUY05ITI01CHF40EVAT05QVIP1EHf<0G6YZ061^KP1^O7`0LX20
06YhN01SLG80JgYn06imP`02071oQ@0507>1R01fPh`0O8J@07j8TP1oRI<00P1oQi802@1nQY40NX6;
08:9T@2=U9`0YZfc08fDVP27SY@0OHF807j6R00207n7R@0;07j6R01lQXL0NH:707b7R`1mR8`0NXF9
08B?T`2CWZ80OHR<07b7R`1gPXH00P1fPHD01P1bOH40Lgj0075mO@1_Ng/0K7Qh06YfM080JGEc0200
J7A`06IbKP1QKFT0FfMS05YUH@1NIV40G6=O05YRG@1IHUh0FV=Q05YTHP1SKF`0HVi]05]WIP1HIFD0
GV][05m]K@1IJFT0G6e]06=dM025UYH0EVMW05AUI@1[O7`0DV=S05Y[J`1_P800BU]K04YJG01?GF<0
CeeR04aKG`80D5iQ00@0BeYK04EDE010Cdh0?Da<0P0oCTd0800lBdT0>TU503Y9A@0kBDP0?4Y:03e:
B`0nBT`0@DaB03DoA`11BU@0>T=>03]4D00^>400>DA70459C00X;S80<cHk02//<@0/;380<C0e038c
=`0T:2`0720T02P]<@0X:B/0:R`[02`^;@0Z;2/0:bd/02h_<@0U9RP0;Rla0P0W:2`0=013A4P0@T=8
02@W:P0/;S40:2/]02/]<00X:Rd0:2/]02T/;P0T9RT0:B`^01lQ900P8bD08bDX02<T9`0I6Qd07AhQ
02LX:`0R8RD08B8V024R9`0_<3D08B<X02<V;00M82H061`R01XO8`0T:B`092P[01hR9@0N8B<09BHX
02<T9P0O82407alO020P800O7al06a/K01PH601KFe/0FEUI01@D500f=CD08b4R01hL7@0K61T06aLH
01dI6P0M61X06aLH01`H6@0J61T301TG600801PF5`0G5AH061HG01HD5@0I5aP06aTJ018@4@0H51D3
01TE5P0501HB4`0E4A806ADF01TE5P0E4A800P0K5aP01`0B3Pl06QHE01TE500H51<05Q8A01<?3P0B
3Pd00P0F4Q401@0E4A005Q8A01XF5@0M6AP0618C00<05Q0A00T05a4B01PB4`0B30d0618C018<3@0H
4Q<06Q@E01@>3`0C3@d00`0D3Ph201<=3@<05@l?00H050h>01<=3@0@2PX050h>01H@400A2`/201@>
3P07010:2P0B30`04@/;018<300C3@d050h>01D<3P0201@93@0:01P=4@070000:b0T01<8300B2@/0
5@`>01@93@0D2`d06@hB01@930<050X;01L05@/<01L=3P0E2``050X;01D;300G3@h05@/<01882@0A
10H04`H801L82`0H20/05PP;01P9300F1PT050L901D72@0F1PT050L901D72@0E2@/05PX<01L;3@02
01@82P0301H:300`92H08ADG00804PH801804`L90186200F2PX04PH601H;2`0C2@T06`l?00l51@0@
10@03`<301L;2`0C1`L05P/;0104100E2@/050P:01451`0I3@l201@82P0T01H:300A1@L04@D701D9
2`0F2P`040@600l51P0H3@h0308301T=3`0@1@H060`>0186200D20X04`L901451`0C1`T05`/=0104
1P0C1`T05`/=01<72@0>0P@05@T;01P<3P0E2@/0:AdO028F600E2@/050P:01@9300?10L050P<01H:
3P0@10P03P@60P0B1PX201<72`0301862P0A1@T04@H;00805@X?01L04`P=0187300B1``05@/?0105
2P0I3Q<04@H;01062P0D1`d05`D;01H42P0E10X05@D:01D62`0C1`/04@H:01<:3@0R71h0ZJFV089m
OP0N5AP050P<01452@0201862PL04@D901X04`L:00X00@0@10L04`L:00h21@0C1`T040@60186200B
1PL04@D60104100@1@@03P<401hB500>10D04`P900l31@0=0@<04@H701041P0>10D060`>00P0000I
3a00ACTj01/?3`804@D500h03P8201861P0B1PH03P@401<71`0k;bl05@T901451@0C1`L04PH600l3
0`0>0P803`<301861PH04@D500<04@D70186200E2@/00P0@10H0100@1@H04@D701041P0@10H30145
1`0301041P0B1PP050P:00T04PH80P0@10H201451`8040@600H03`<50186200?0`D040@60186200>
0P@Dooooo`006oooool04@0C20`05@X>00h31`0>0`L05@X>01<8300B1`/050T=01P=4@0T6Ad04`P<
00h31`0B1`/03@<601D:3P0:00<05@X>00804PL;00<04@H:01052@0@1@T00`0A1PX301872`0601<8
300D2@d05@X>01@93@0=0PH03P<70P0E2Ph01@0C2@X05@/<0147200B20T05@/<00<04`T:0P0D2P/0
400C2@X04PP901881`0>10D040H701@:2`0D2@d04PL;04@i?@0700804PL=02DJ800B1`l07a@I00d3
100;0@8201D;300800L0000C2@X04@L80147200?1@H08QPI01882@0B20P201881`0b01<9200D2PT0
50X;01L=3P0>10D07a@H01462`0M4QP05``B00d3100A1`D04PP701@:2@0E2`X05@/<01H<3@0;0@80
60dA07M/L00T6Ad050T=0189300?2@/05@lA01PB50090`D03PP<018<400?2@d04``C00P1200<1@`0
7QHN01L74@0H1`l05`P?01D83`0D2@l04`X?00h8300E41@0>cTl09NGV@0n?T006QXL01HB4`0I4aD0
2PD601hH6P090`D401@>400G018<3P0A2`d03`T;00P2100O6A/05a4C01TC5@0D3`l0ShV901/E5@0F
4@l050l<01D@3@0D3``040/7014<2@0E40d05a8?01HA3P0E40d05a8?01D@3@0F4@h00P0G4Pl03`0F
4@h05A0=014=300E4A005Q8A01<?3P0_:bX0>cLf018>3@0F4Q406QHE01/G5P0J5QD061@C01PG5@02
01dL6P0701/J600J6AL071/I01@C4@0F5A<05aHD01XI5`0201`K6@05024Q7`0M7A/08b<Q02/[:@0S
8b400P0J6QP0<@0E5A<09RHT01XJ600J6QP06a`G01TJ4`0Q8Q`092DO028S7@0N81/07AlJ02<U800N
8al07b@P02<X900O9B<06b4O02@Z:00Y;bl09B/[01lW:P0Y<3P092/c02@]=P0d?D@092hd01hY;@0a
?3h0;CLi02/e=`0Z=3H0:SDh02dh?00_>Sh0=415030m@`0S<3H0=TA;02`k@P0jBE00;Sa403A1B@0e
@TX0=T=;03M4C00hADd0?4UA03i;D`0mBU800P0gA4`0=`0nBe<0@e5L03Q5E@0oC5d0K7V;05MSN@0n
BV00Ae=Y04QEJ010CEh0?T]K04UGI01=Ff@0>dY?03M6B`10CeH0EfE^05]YLP17EF00?deH04ECGP1:
F680A5=J049AF01:FEh0/<790;31b`16Ef40DF9/03m@FP1EIW00CEiX03Y;E@1JJgD0A5EO051QJ`1C
I6d0BeYQ04iMHP1@Gf@0BUUL04QGFP19F5/0B5QH04EEE@17EeH0DV9Q05QXI`1BHV40EfEU05m]K@1G
IFD0CUaL05ESH`1VM7@00P1RL7003@1TLW80Hg5a06IdM01aOh00JGQm07B3RP1eQ8/0Kgj5075oQ`1l
RI80OHNA07j8TP1mQi400P1mQI009P1oR940PXVA08>:TP1iP8P0RY6G07V0QP2?UY`0NX:507b4Q`1n
QXP0OhN907j6R01lQXL0OhV;07AoP`1oRXh0OXV=08F@U01oRXh0OXV=08nJWP21S900MX6507N2QP1c
OX80Lgj0071lO01]NGT0JWIf06IbL01ULFl0JgMe06QdL01ULFd0HFeY05iZIP1MJFD0FfAO0P1LIF00
8@1MIf<0G6IU05aVI@1HI680FfMW065]K@1LJVX0EF=S05EUI01IJVX0EfUY07^=S@31dm<0FVa/05]]
K@0lCTh0BE]K055SH`17FET0Ffe]051NH@1@GF<0BUMM04UFF`1>G5l0BeUL04IDEP12D540?4Y:03Y8
B00lBTX0?D];03i=BP0203a;AP1O03i=B`0nC4`0?dY<03i9CP12C5D0?dMB03e5D@0V;S/0?TEE03Do
B02nbLd0b];E03Pm@@0f>Ch0<34f03<c>00j>Ch0<S<g02lc=P0Q9BH09R/]02DW9P0Z;2/0;S0_02T[
:P0W:BP092DW028S9@0S92H08b@X02d^<P1NGf<0:BX_02DV:P0`<C<0;2d_02PY:`0S92H092DW02LX
:P0L7Al0<34c02X[;@0P8B<071dO01/L800S92P08R<W01XK7`0G61`09BHZ01dN8P0[;3007b0U02<V
:`0Q92T07b8W024V:P0b=cX08RHY02<W:P0W:R`06Q/M02PY:`0];Rl0:2PX01hN7P0K6a/08R8R01XJ
6P0Q8B407AdM02<S8`0^;Bd06aTJ01XH6@0I5QL06ADF01/G600M61T06aLH01PD5@0H5QL06ALH01PF
5`0F51D0518C01`J6`0J61T04Q0A01lM7P0[:BX03`d>01TE5P0H51D00P0G4a@201HB4`0801PD5@0D
414071PI01TE5P0D41406QHG01TE500G4a8201HB4@<05a<B01405Q8A01<?3P0B3Pd05A4@01PD4`0G
4A4050h>018<300C3@d05Q0@01PB4P0G4A405Q0@00h8200C3@d050h>01H@4005018<300<01<=3@0E
3`l05@l?01D?3`0D3Ph04`d=01D?3`0B30`03PP801@>3P0G4A404`d=0`0@2PX02`0B30`04`d=01D?
3`0F3Q007Q<G01`A5@0G31007a@H08EjOP0[82@060dA008040D900@06a0D01@93@0C20/050X;0P0C
2@X03P0F30d06@l@02HL7@0M4a@03`D601061`0F30d06@h@01`=400G1`X04@4401H62@0M3A0070`?
1P0F1PT00`0C10L04`L901@82P020186200J01@82P0G2`d04@D701041P0A1@L040@601<72@0A1@D0
4PH601<71`0F2PX02P0001<71`0@10@04PH601X>3P0B1PH05@T901<71`0J3Q003@<4028F6014>3X0
7a<E01<72@0@10H201<72@804@D700d04`L901@82P1@A4H02P0001lC5@0H30h02@0001<72@0E2@/0
50P:01451`0D20X06@d?008040@600<03P8401@82P0F2P`00P0800002`0H30h03@4301041P0@10H0
3`<50104200D20`05@T=00l31`0D20`07A4E00804PH:0P0C1`/01P0B1PX04@D900l42P0C20h050T?
01873@8040D;0P0U6R005P0700805``B0146300?0PT060@:01h;4@0Q3Q@07`hD01T:3`0D20`04@L:
01/B5@0D3Q00[j^/08>1PP0@20/04PH:01452@0@10P03`<701452@0C1`/501452@0701D9300>0P@0
50P:00l51P0?0`D060`>00l31@020186200K01451P0@10@040@401<7200;0040200001<72@0<0080
6Ph@00/10P0K3a4040@601061`0C1`T02@0001dA4P0A1@D03P<301@8200?0`<04@D501H:2P080000
5@T900/0000B1PH05`d=00D040@400<04@D500l30`0@10@00P0C1`L03`0B1PH040@401451`0J3Q00
3@<400P0000J3Q0040@600h2100C1`T05PX<01041P0>0P@050P:01451`0200l31@0301451`0C1`T0
4`L900H04PH800D03`<501041P0A1@L04@D701041P0200l31@0501L;3@0B1PP03P840186200A1@L0
5?ooool001_ooooo0P0C20`201872`0401@93@0E2Ph05P/?01@93@804`P<00@04PL;01<8300A1PX0
4@H:0P0B1`/201<8300B01462P0F2`l04PL;01D:3P0G31004`P<01472P0E2Ph0304501@93@0?10P0
2P0301872`0H3A407Q<G01872`0O51P04@H:300C2@X0100B20L04PP901882@0B20T201872`0U01P?
4@0H3A<03P<902hS:@0O51`04PL<01T?400:00403P@501882@0K4A8040H701P>3`0B20T05`d>00L0
000Y7b003`H601881P0>10803P@301881`0D2PT04`T900d3100Y7b002P8201/@500800405@/;0188
1P0C2@P04PP701061@0B20T05@/<01H<3@0201D:3P804`P<01X040L:00l92`0C3@l04P`>014;3@0C
3A405@lC010:3P0C31<05a0G01@=502>QXh06PXD01T8400G20l05`XA01H;4@0@1``04@/?01<>4P0F
51L05ADG01<C5@0?41803PX;010:30<04P`>03@040X<01PB500B30h05Q0B00l92`0I4aD04P`>01/E
5`0?2@/06A<E00D00@0B30d05@l?01LA4@0I4a804`h;01D@3@0A30T07APD01@?300I51404Pd:01@?
300@2`P06QDB00h91P0H4a004`h;010;200F4@h05A0=014=300M6AP061@C014=300Q7A`05A4@00d9
200H51<05a<B01/G5P0F4Q407ATH01dL6P1MG5X051<A01TH5P0D4a408R4O01TH5P0E51805QDC0P0K
6QP0F@0I61H06QXH01/K6@0J6QP07QhL01dM6`0G5aD07alM01hN700I6AL08B4O020P7P0C50l08R<L
020Q6`0Q8Q`09BHP02DW8P0T9R407b4L02DZ9P0K81`08bPT024W9@0E6aT08RPV02T_;`0Z<30092`_
02@[<`0V;CD08BXc02@]=00V<3H0:SDi02lj?00R;Bl0<ci003e8BP0^>C`09S4e03M5B012Ce@0<d16
02He>P0eA4X0;ci502<d>`0c@DT0>4E>03a9DP0f@d`0=dA=03U6C`0kB540>TM@03Q5CP0jAe00@4eF
03i;E00nBUP0?DYK049?HP1GHgT0F6Al04YFKP14D6H0?T]N045>G`10CEd0?TaI05YXLP0nCE@0?TeB
03i=E010CUL0@DmJ04iLJ@19Ef@0A59M04=AF`12DEP0?diE045@EP1KK7@0BU]U04aMI`1:FfD0AUMQ
0080BEYT01H0BeaV04YKI@1=GVP0D65[04YKI017EUd0EfI[069aMP1HIfX0E6=V04iMH01?Gel0Be]K
04eMG01?Geh0C5aK05ATH`1KJFT0F6IV05ESH`1GIFD0G6YZ0P1QKfl0<P1VM7@0J7If06IdM01TLW80
IWAe06]jP@1/NX<0KWb5071oQP1ePh/0N8F=07f7T01kQHh0N8:;07Z3S01mQXl0P8VB08:9T@1oQXh0
O8>;0827S@24Ri40NX6707n7RP1jPXD0OHF707n7R@1mQHL0OXR907V3Q@1cOX00MH2207n:S024Si40
PXf?07R3Q@2?VY`0TYfO079mO`1fPH<0LWeo06iiN`1]NGT0KWYj06ahN01WLg40Hfm]06QdLP1QKFT0
GVYV0P1MJFD0201LJ6@0G6ER051KE`1QK6P0GFMV05QRH@1MJFL0E61P0P1JJ6P0601EHf@0EfEV05UY
J@1FIfL0DfEU05QZJP1PLW80HWAd05AVIP1>H600BUaL04eOG`1CIFD0DVAT059QI01@Ff40F6=Y09:M
XP19E5P0D5]O041;CP0mB4X0>dM703i:BP80@De=02T0?D]803i=B018Ee@0CU]J045=C@0nBD/0?TQ=
03HoB00oAE40@dUF03m5E@0m@e<0=Ce709RSY`2//kT0>Sm502@W;00e=SX0<c<h030_=00Z:bd08bLX
028V9@0R:2L092HU038d<`0a<c80:bd/038d<`0Y:R`08R<U02TZ;00[;300:2T]02//<00X:Bd0>CXn
04E6B00];S009RLY02DV:00202X[;@0C024R901QHV@0=cPj02l`<P0O82808bLZ01LJ7`0Z;C80<34f
02HW;00Z:bl0824U02<T:00M7R807QlS02//<00P92L08bP/02L[;`0201DI700I02<U:00J6ad061TK
028S900P82008B4Q02TY:@0R8R805aLG01/K6`0V9RH06a/K01`K6`0U8b@07Q`M01`I6P0M6AX07a/L
02@O800U8B8061@E01dK700>30d05Q@E01TG600201LE5P0B01HD5@0G5AH06ALH01PF5`0E4a@06ADF
01/G600O6a`05A4B01XF5`0Z9RL06ADF01DA4P0F4Q<04`l@01TE5P0D414061@C0P0I5A@0100J5QD0
Ee=B01DA400H51<201<?3P805a<B00d05A4@01LA4@0F41004`d=01PB4P0J51@05a4A01TC4`0<1PH0
3`T901LA4@0@2PX0618B00804`d=00@050h>01D?3`0E3`l05@l?0P0D3Ph02`0C3@d04P`<01D?3`0E
3`l01P0000h8201lMWH0618B010:2P0B30`06aDE00805@l?00@03@L7018<300E3@l05@X>0P0F2`l0
0`0G31006@hB01L<400200l4200401H;3`0C20`03P<701882PD05@/<02406Q0A01@:2`0B20T05P`=
01D;300C20X0404401D5200N3Q406PX=024A500H20/05@D801H62@0K2`h0400301D5200I2@`05PL:
00l31@0A1@L050P:01041P0D20X06Ph@02DI6`0G2`d07a<E01/?4@0=0@<05@T901861P0E2@T00P0N
4Q806@0C1`L05PX:0104100>0P804@D501861P0?0`<040@60186200G2`d06Ph@01L;3@0@10H04`L9
01L;3@0=0@<0300201H:300B1PP04`L901T=3`0J3Q0050P:0186200D20X01`0B1PP01`0E2@/04@D7
01hB500D2P/03P8401451`0C1`T00P0E2@/02`0B1PP04@D701<72`0B1PX091PL01D93@0?0`L050P<
01<72`0B1PX04@D900804PH:02804`L;01883P0C2Pl07QDJ00h52P0700<07A@I05M>D`0a:2d01P02
04PoA00B2@h06@`C01P42`0J1`d070T?01T83P0E1P/04PH:01872`0D2`h03PP:02@P8@0W9BH050`?
00/00`0?0`L03`@704Hj?P0H31003@4501452@0B1PX040@80P0C1`/01`0@10L03`<301@8200?0`@0
4`L901P<3P0?0`D00P0A1@L0400B1PP04@D701451`0?0`D06Ph@01D92`0>10D06Ph@00T0000>10D0
:alQ00l31@0>0P@040@600P0000G2``501451@0601L;2`0B1PH0304100l30`0H30`04PL71P0@10@6
01451@0>01P<3P0?0`D04PH800d10`0J3Q0040H701041P0A1@L040H701hB5009000050T:01<72@0B
1PP201041P0301<72@0F2P`03`<500804PH80P0@10H01`0C1`T06Ph@01451`0=0@<03P8401D92`0F
2P`00P0C1`T201451`0301041P0?0`Gooooo01?ooooo000Kooooo`0301H;3`0D2@d04PL;00<04@H:
00<05@X>01@93@0B1`/00P0B1`/00`0C20`04@H:01462P0201872`804`P<01804@H:01@93@0@1@T0
4PL;01H;3`0C20`050T=00h41`0A1PX040D901X?4`0i;S80F4eA02@I7@0>1@L050T=01P=4@0?1@P6
014720H04`T:02P04PP701<92P0D2P/050X;01872`0A1PX050X=01<:3P0@1@/05@X@00h32`0C2@d0
4@L801@:2`0e:b`06Q0A01<92P0>10D05P`=01L=3P0U6a`06@l@03H/;@0I3`h060h;01T?3@0G3@/0
4PP701471P0D2PT05@/;01061`0C20X05@`>01L<400D2PX050X801H<2`0D2PT04`T80P0D2P/00`0B
20T04PL;01@93@0201D:3P0301@;3P0C3@l04P`>00803PP:00<040X>01<=4@0A2`l00P0G41L0400;
10/0;bL_01D84@0F20l05`T@01X=500I3Q@050/@05A>DP0n>Cd061DH00X82`0=30h03@`?00h:2`0@
2P`2018<3P0H014;3@0@2P`0:28T0:ZTYP0S7Al06aDG00`7200@2``04@`=01hH6P0>20X06aDG01LA
4P0>20P03`T901LA400@2`P05Q4>01D@3@0D3`/06aHC020K600A30T050l<0P0G4Pl02P0D3``05Q4>
01@?300C3P/06aHC02HQ7P0K5aH05a<C01hJ6P0F4Q8301LC4`0A01TE5@0L61P0:2@T024M7@0I5AD0
61LE01dL6P0?3Pd06APF01`K6@0G5Q@07QdK01/J600L6aT07ahL01hM6`0L6aT00P0P81h00`0M7A/0
7alM01dM6`0201PH5P0901XJ600I6AL09BDS02PX9P0O81`07b0K01/L5`0L7AL07b0J00807b4M05<0
828N020U8P0M8Al09b`Z01/Q800Q9bH08RPV028X:00T:RX09blb02L^=P0U;3@092df02H_=P0W<CL0
9c8f02/f>00X<cD0;CPj02`g>@0]>3/0;CXm02dk?P0`?T80;Se2030oA00`@4H0;Ce402m0A`0eA4`0
=T==03E2C00e@D`0?T]E04EAG010CEL0B5AO04aIH`11CUP0?d]F03m<EP0mBET0?TaP04YHK@1ULhT0
IWB;05QUO@1:F6h0B5IY055OLP1:FFL0?dmI045@FP1:FF00B5MM04ABF`11CeX0?deH04]HIP15DV40
@e5N04ECGP16E5d0A5=J04IEG01cQ8`0EfQ_04MHH013E5d0AEIN04aMIP19FV<0BeaS04]LI01=GVL0
DV=Z04iOI`1AH6H0BeYO05QWK01QL7<0Df9U04UHF`0204eMG@0I051PG`1>GUd0Be]J05=SHP1KJFT0
FFMW05ITI01GIFD0G6YZ061^KP1SLG40IG=c06IdM01TLW80IG=c06QfM`1[NX00JWV106akPP1`OhH0
M8:807B1R01gPXT0NH>:07Z5RP0307^4RP0I07f4S021R900Q8^C07n6S01kPXP0PhZ@07Z2Q@1fOX00
NH6307b4QP1jPX@0NhF607j8RP1mR8X0NhJ807Z5Q`1lQhT0OXV;07J1P`1iQ8H0NXF706mjO01gPX@0
LGan06ehNP0306ahN00606McL@1TL6h0Hfm]05]WH`1HI600FVIR0P1LJ6@0>`1MJ6@0GfUW06=^J`1O
JVP0GFUX05aXI`1OK6`0GVa/05QVIP1LJf/0Gfi`05YYJ`1EIFD0DF9R05AUI@1CI6@0CUmO05=TI01=
GUh0BeaL04mPH01BHf<0Cf1P051OHP1=F5h0EV5W059MHP14Ce<0Ae9F03]6B@0oBT`0@De=03a8B00g
@d<0>TI603a9B@0jBDL0?Da:045>C`0lAdX0?4I;03m8D@0h@4T0?45=03i3D00l?dl0>Ca<02T`>P15
D5@0?dI<02L/<P0a=3T0;c0d038b=P0_;c40:R//02DY:00V:RP09bdZ0080:bd/00L0<38a034c<P0/
;Rd0:BX/02PY:`0^;c40;Rlc00809RL[03P09bP/024R900X:BX0:b//02HW:00Y:R/0;2`]02@T9@0S
92D0:b//01hO800/;Bh092DV01hQ9P0M8BL09BP^01/M8P0L7R<07QlS01XK7`0R8bL08R8U01dN8@0V
9RT092DY02@W;00M8RD07R8U020T9`0Q8bH092DW01lP8P0P8240820P01hN7P0K6a/06ATI020P800O
7al0:BTY01lO7`0J6AT05Q@E01XH6@0L6AX07QXK01dI6P0M61T06ADF01hJ6`0G5AH04a4B01PF5`0L
6Q/05A<D01PF5`805aDF02X06ALH01PF5`0E4a@06QHG01@@4@0G4a@05A4B01dI6P0[9bP06ADF01LC
500J5QL05a<D01`H6@0F4Q<05A4@01HB4@0I5A@05Q8A03Lc<P0?2`X05Q8A01@@3`0F4Q406ADD01HB
4@0B3Pd05Q4?01PB4@0F4@l06QDC01TD4P0D3Pd04`d<01D?3P0D3`d06A<B010;2@0E3`h04`d=01@>
3P0F410301D?3`0901LA4@0F410050h>018<300D3Ph04P`<01HA4@0G4A40;2HV00808A/K00T04@/;
00`61P0[9BD0PWal014;2`0G4A404`/=01@93@0C20`00P0E2Ph0200B1`/04`P<01H;3`0A1PX040D9
01<8300B1`/05@/=1@0D2P/0500B20T04@L801882@0D2P/05P`=01H;3@0L3a405`X<01`>4@0H20/0
408501L82`0O41<04@@601D72@0E1@P050H901<51`0E2@/050P:0P0C1`T02`0D20X05`/=01<72@0H
30h03`<5020D5P0T61X05PX<01<71`0B1PH04`L700805PX:00<04PH601@8200D20P00P0C1`L20186
1P080186200A1@L04`L901D92`0C1`T03`<50186200E2@/201P<3P0801L;3@0D20X04PH801D92`0D
20X040@600l31@0C1`T60186200501<72@0B1PP05`/=01@82P0]8B<00P0A1@L02P0C1`T05@T;01D9
2`0B1PP04@D704@h?00?1@L06PhB01/?4`0A1@T201<72`0901862P0A1@T04PH:01862P0B1`/050X@
01493P0D2a404PT?00804@P>02<081LM01D<4P0M4aX0>30e020G7@0C2@h05PD;01L52`0G1P`05PH<
01D62`0B1PX04@H:00d41`0<1PP04@`>00l:2`0>1PT03P<601P<400C2@/0<BDY01872P0?0`L04@D9
01<72`0B1PX04`L;01452@0@10D040D401861P0B1PL04@D601<72@0201451`0A0145200B1PT04@D8
0145200B1PP02`010147200g:bd06Q0A0187200D2@/0200001451`0E2@/04PP901051P0>0`@01@0A
1@D01P0C1`L04@D504Lk>`0H3Ph06@d=00l51@H040@41P0A1@D0300:000050P:01@82P0=0@<04@D7
0146200B1PP04@D70186200=0`@050P:00h41@804@D700L04PH801H:300L418081@F01<72@0@10H0
4@D700805@T;00P04PH801H:300@1@L05@T;00/10P0D20X04@H701041P<04@D70P0B1PPDooooo`00
6oooool00`0E2Ph050T=01462P0401052@0501872`0@1@T04@H:01D:3P0D2@d00P0A1PX201872`<0
4`P<01404PL;01052@0A1PX050T=01D:3P0P5AT050T=01X?4`0A1`X05``@03hc=`0F3@l06PlC028G
6`0<0`D05P/?00T00P0601<92PH04PP903804@L601<92P0D2P/050X;01462P0@1@T0Bd1401<83P0F
2a406PlE01873`0E2Pl03`D601H<3@0m<c@06Q0A00l51P0A1`P05P`=01061`0B20T02P01020F5`0C
2@P06A0;01hD4P0I3`d04@L501061@0D2PT0718A01L=3P0B20T05`d>01D:3P0=10<04PP601<9200B
20L040H501882@0D2P/04`T:01<8300B1`/04@H:01052@0?1PT03PP:010:30803`T;01<04P`@00l9
3@0>20`03`P?01<<4`0F3aH02`<;01463P0C20h05`/A01P=4`0F3A804`X?02LQ9@0H4QH01`8600h9
3@0E4aH05a8F00804@/=0`0B30h06P0A2`d03PP:08^5Q`1ECe408A/M010:300G4A<09b4S071ZK017
@D<05a4C018<3@0K5AD0:bDU02LR800=20D04@`901HA3@0B3@T02`H301lJ5`0=20D03PT601LB3`0C
3P/04@`90P0L5a@05P0C3P/09b8O05E@C@0V8R<04@d>01<?400E4A807ATJ01HB4`0H51D05A4B01LC
500V8R<081`M01@@4@0H5aD040l=01TH5P0G5Q@06aXH01dL6P0L6aT301/J600801TH5P0H5aD071`J
01/K6@0H61H06a/I01XJ600E5A<201hN700801/K6@0O7ad07alM01TI5`0R8ah07AhI01`M600O7a`2
020R7`07024S8P0D61L0;30a01`P8@0/<S80:2h^02P^;00202<Y:@0M02@/;`0R:C4082L_02Pa>P0X
<CP0:C<i02D`=00V<C<0:3<e02dh>P0`>cd0;S/m02/i?00]>ch0;Ca002Th?@0a@dL0;3i303A5C011
DUT0=TE>03I2CP0g@dl0?DUE049>FP0nBUH0>DEA04aHI01CGf/00P11CET07P15DEd0A59R04=BI`15
E6T0E6=i05QWOP1EI7/0CEab04QGJP19FFT0>daH03m@F014EE`0AUEL04EDF`16E5d0BEMR04]IIP1J
IgL0C5UY04QEI@16E600AE=L04=AFP17EUd0?DiE03=4B`13E5/0Cf1W051QJ080BU]R01L0CEiU04aM
I01:Ff80CEiU04]LH`1FIFX0BeYO055PI@1LJfh0E6=V04eLG`1>GUh0Df=S05MWIP1CHf80D61O05IV
I@1KJFT0F6IV05ITI01GIFD0FVQX05e[J`0206AbLP0Q069`L01SLG40IG=c06QfM`1[NWl0J7Mn06Yi
OP1_OX<0LX2506ilO`1dOh<0MH2207J1P`1gPH<0Mh6207N1P`2d^l40QHbD07MnQP1mQ8X0NX6707b3
R@1mQHP0NH6407j6R021RH/0OhN907n9RP2nb<X0SiZL075lOP1kQXP0NXF70080LGan00H0M7n107F0
PP1eP880LWeo06YeM`1[MWP206UeM@2706YfMP1VLW00I71^05eYI`1GHel0EF5M05UUH@1MJFD0GVYV
05aWH`1NJ6L0HF]Z05m[J@1NJVX0Gf][05aZJP1KJFX0Gfe^05a/K01EI6L0EVEX05MWI`1CHF80D61P
05QWJ01@GUl0D5mO04UIF@1<FU/0DF1P04mOG`1<FU/0Ae=G04mJH01:EE/0CeYO04E@E02Z]KT0DEaO
049=C`13Cdl0?TY:03Q4A00kAdL0@4e=03e<C`0lBTd0?da?041;D@10BE00?dM?034h@P0a=D40<CA0
034c@00`<T40:2lh030k?`0Q:2h0;S<i03<f>`0W:2`0<S8e02PX:00U9bD08bPT02DZ900W;RL0=3Hc
038d<`0e=cH0=SPg034c<P0];S007QlQ02TZ;00e=SX0<34e02LX;00P8BH0;Bd_028R8P0V9RH05aLG
01`L700V9RH08B4Q01`L700O7al0@D5103@d=00S92D0:B`a028W;@0U:2l082<X02DX;@0V9b`06AXN
020Q9@0R8R@07QhP028R900P8B<08BDX01dR9@0O8bH082@W01dO8P0L7Al09RLY01lP8@0S8b<08B4Q
01PH600M7Ad06a/K0451@@17AdL07alO01/J6`0j>3T071XK020M7P0P71d07QXK01`G600J5QL07ATJ
01/I6P0H5QL040h?01HD5@0K6AX061HG00805aDF00P061HG01LE5P0D4Q<06ADF01PD5@0M6AX06ADF
01<?4080510A02<05A4B01TE5P0G4a@06aLH01<?400K5aH04`l>01HB4@0B3Pd06QHE01TE500D40l0
5Q8A01/G5P0N6QT05Q8A014=300D3``05A0=01<>2`0G4Pl05Q4>014<2@0F4@h050l<00d81@0D3``0
4Pd:01@?300C3@d05@l?01H@400E3`l04`d=01D?3`0201PB4P0@01D?3`0B30`04`d=01XD500H4Q80
BD=301@>3P090`<08A/K00h8200O6AT05@l?02XT90090`<06aDE01072@804@H:00D06PlC020E6@0L
4AD04`P<01L<400301P=4@0301872`0C20/04`T:00@04`T:00@040H701@:2`0E2``05@/<0P0H3Pl0
6@0F2P`09a/M01P<3P0A1@L07A4C00l51P0;004050P:01/?4@0=0@<05PX<01D92`0<008050P:01L;
3@0F2P`060`>01451`0H30h06@d?0186200E2@/05PX<00/10P0B1PH00P0C1`L02`0?0`<03P820145
1@0?0`<05@T901H:2P0C1`L04@D501<71`0G2`d05@T;008050P:0`0C1`T02P0A1@L07A4C01hB500E
2@/060`>0186200C1`T040@600d10`0?0`D70186200801dA4`0:00006Ph@01`@4P0o<cD04`L90186
200C1`T201@82P0;01<72@0B1PP02@0101L;3`0B1PX02`4301L;3`0A1@T04`L;01862P0A1@T00P0B
1PX01@0B1`/02`<900H0100600@040H>00806@lG01L03@<;01L=5@0600@06@lG0516CP07008050D;
01@32@0B0`P04`@901452@0B1PX03`@801872`0?1PT03PH90189300B20`03P8601X>4P0D20`06`lC
00d11@0201862P0>01<72`0B1PX05@T=01D93@0B1PL040D300h20P0C1`L03`<300d10`0C1`T04@D7
01452@0B1PX201452@0=00l31P1SEeT06Ph@01@:2`0M4A<040@601L;3@0S5aT040@601@82P080000
7a<E01<7200501451@0600h20P0800007a<C00P0000900003082300A1@D0300C1`T05`/=00h2100D
20X0300200l51P0E2@/04PH801T=3`0A1@L02@0001H:30@03P8400D04@D70186200D20X04PH80145
1`020186200700l31@0@10H04PH801041P0H30h05@T;01@82P0201041P804@D70P0B1PPDooooo`00
6oooool0100C20`04PL;01462P0A1PX201<8300601872`0D2@d03@8600`11@0?10P02P030P0A1PX2
01872`804`P<018050T=01<8300C20`04`P<01D:3P0G31006PlC01@93@0E2Ph04@H:00X00`0K41@0
5@X>01dB5P0700004PP;00L0000A1PX601<92PH04PP900@04@L601<92P0C2@X04`T:0P0A1PX0:`1H
CE406PlE01T>500J3aD03@8:01@93P0D2P/02@0001H<3@0;0@805@/<01@:2`0A1`P0308300l51P0=
0`@06a4B01D;2P0F3@P06A0;01D;200@1P@04`T700l71P0P5QD0AS`k01<;2P0G3@h040H701P>3P0B
20H04`T801881`0@1PD04PP901@:2`0C2@X04`P<01872`0A1PX040D900h5200>20X00P0B30h03`0A
2`d04@/?00h8300?2@d03PL>0109400H4AP04``D01473`0B2@h05@/A01@;400B2@h03`L<01PB5P02
01H@500301LA5@0D3a<030H:00L04`d?01P0JVAV048m?P0I4aD03`T;014<3@0L5QP0@S`n02XT9P0C
3@l04@/<010:2P0/9RH09R0O00d81@0A30T05Q4=01@?2`0C3P/0;RTV01TD4@0B3@X04`h;00h91P0M
61D201@?300901TD4@0P6aP0:2<P00l;300I5AH05A4B00X61`0C3a002@D600805Q8C00/04`l@01dI
6P0J5QL061@E01TH5P0M71X05A@B01HE4`0G5Q@061LE01XI5`0201/J600:01TH5P0G5Q@05aHD01dM
6`0L71X06ATG01dM6`0N7Q`06QXH01LG5@806ATG00@0820N02<S8@0Q8Al08R8P0P0N7Q`0CP0Q8B00
8R@S024S8P0V9bT0:Rh_02da=00R9RT0;c@g02X`<00W;B/0:2h^02H/;00Q:B`08RTa02@[<`0Y<S/0
:34h02hh?@0Y=3P09C0b02Te=`0Z>3T0;3Xk02dk?@0_?D00<D1303=2AP0/>d00<TA80353B011DUT0
BUeS03Y9DP0f@Th0=D5=03i:EP0oBeL0>DEA03A0C00oBeL0@DeI03E1C@0lB5@0@DeI049@H010Cf@0
?TeR04ACJ@18Efh0BeYa04YIK`16EFP0BEUX041@G014EEd0@U=J04IEG017EUd0BUQQ04iLI`1@GV/0
Gfal04iKJ`18EFD0@e5M04=AFP14DU/0CEaS04QJGP11DeL0C5iR04eOH`1@HVH0EFM[04MIG@1;GF40
BUaP04UKG`80C5iR03d0BeYO04aKH01:FEh0BUUL04eLG`1<Feh0CemO05ATI01HJ6L0E6AS05=SHP1G
IfH0FFMW05QVIP1FI6@0EfEU05YXJ01MJf/0I79b069`L01QKfl0Hg5a06IdM01WMGH0JWUl06QgO01[
NWd0KWf0071nP@1/NW/0M7n1079nOP1`O7X0LWak07AnO@1gPH80bM3F08fDW01fOHD0OXF;07Z1Q`1d
Nh40OhN:07b4QP21RH/0Ph^=0869R`20RX/0cmWJ09ZVYP1cOgl0Mh>307B0P01/N7P0Lgmo07R4Q01c
Ogl0LWin06eiN@1[MgL0JGAf0080IW9b00L0Ig=c06A`KP1QKF/0G6QV05QTH01GHel0G6QT0080Gf]W
0200H6YY05YVI01PK6X0HFe]05i/K01ULg<0FfUZ061`L01bPX80HW5d051OHP1NKG00EVAU05]VJ01I
IfP0J7Af05eXJP1:EeP0BEMH04iIF`1AGEl0CUaM04]FF019E5P0BE9I049;DP1;E5X0>T=808ZCV012
Bdl0>dE703Y4A@<0>dE601T0?4Q;03e<D@0lBe00?d]A03m9DP0mATl0>d==034h@P0a=D00<34m038b
?P0c<T008BL`02<^=00O9R`0:c0e02ha=P0W:2`0;c0c02XZ:P0X:RP09b`X02X_:@0]=2d0:R`Y0080
<S@c02T0<cDd03do?P0f=cT092DW02DV:00V9b/08B8V020Q9@0W:2d08B4S01/K6`0_;bl0:2PX02LW
9`0U9BD07alO020P800S8b<0A4A403Ph>00S92D0@4=:02P/=@0V:c40:B`c02@W;P0Q92T07QlS01lP
900O7b408R0Q02<Q8P0L71h06alR02<W:`0L82<07B4T02@V:@0H6A/08R<U01`L7@02028R8P0o01`L
700S8b<04A4A01dM7@0P82003`l?01<B4`0K6AX07A/L01lL7@0N6Q/071PI01hI6`0Q7Ah04@d>01XH
6@0K6AX071XK01PF5`0;2@X06ALH01PF5`0G5AH061HG01LE5P0D4Q<04Ph?01@@4@0K5aP07ATJ01TE
5P0G4a@0510A01DA4P0I5AH05a<D01/G600C3a006aLF01HB4@0N6QT06ADD018>3@0N6QT05A4@01PD
4`0L61L081`K01TE500C3`h071LD01TD4@0E40d06A@A01`G500I514061<@01<>2`0?2PL06QDB01LB
3`0H4a0050h>00805@l?00H050h>01<=3@0D3Ph05a4A01PB4P0F4102018<300I01H@400k=CD0NWAd
01D?3`070@407QPH01D?3`0C3@d03`T9018=3@0B30`02@<301H=3`0E2Ph05P/?020E6@0X7B409AXN
01`A5@0G31004@H:00h31`0@1@T050T=01T?4@0501D;300C0147200E2``05@/<01@:2`0H3Pl05@/<
01H<3@0`9RL07Q@E00d3100D2P/060h?01lE5P0@1PL04PP90147200C2@X06@l@01041P0201<72@07
0186200D20X04@D701451`0D20X05PX<01041P0201<72@0A01861P0E2@T05@T900l30`0>0P804`L7
00d10@0C1`L05@T901861P0@10@04PH601L;3@0F2P`04`L90186200C1`T00P0D20X01@0?0`D060`>
01T=3`0C1`T06@d?00804`L900@040@600l31@0@10H04`L91P0B1PP0100:000040@601`@4P0?0`D2
01T=3`H04`L900T06@dA01/?4`0@10P040D801/?4`0;00<04`L;01862P0A1@T00P0B1PX03`0B1`/0
4`/B01PA600C31<03PL>01<<4`0X8BP0C4E<00@0100;10/03PL>00X32P0D2a004PD;018320020104
200:01452@0B1PX07a@H02@I7@0D2@d03P@801<8300A1PX02@0100d11@802P020140300401H:3P0B
1PX04PH:0104200H31006`lC01@82@0C20H03P<101871P0A1@D0300001<7200A1@L04@D901862`02
01442`0=0145200h;2h0200001H:300<00803@4300/10P0I3@l0200000h41@0e:B/02P0000d30`05
01451@0301T=3@0J3Ph03`D5008050P800<060`<01451@0A1@D02P0A1@D301451`0=01<72@0@10H0
6@d?00/00@0E2@/04PH8020D5P0>0P@05@T;01<72@0B1PP04@D701041P0200l31@0<01P<3P0L4180
6Ph@01@82P0B1PP05PX<00d10`0=0`@06@d?06EIF`10=3H02`010P0B1PP201451`8040@65?ooool0
01_ooooo00`05@X>01@93@0C20`04`P<01@93@0E2Ph03@8601D:3P0@1@T04`P<01hC5`0K41@20146
2P804PL;0`0C20`04@0B1`/05P/?01H;3`0C20`05@X>01<9300B1`/04`P<01P=4@0?10P04PL;01P=
4@0800406@hB01D;3P0D2@d04`T<00`04@L800@04`T801882@0A1`P04PP90P0C20`04P0F2`l05@X@
0146300B1`d03P<;0188300H3Pl04@L801H<3@0A1`P060h?01482@0C2@X050X;01L=3P0C2@X03@@4
01881`804`X50P0B2@D0300E2`T05P`;00l5100R61L040L702dS900C2@X04@P701@:200F30/050X9
01<9208050X;00<04PP901872`0D2@d00P0E2Ph0200E30l050h@01@>400@2P`03`T;014;3`0@2Ph0
4@/?0P0D3A@02P0:0`X05a0G0109400A2`l04`/@00l8300>1`/040X>00h72`0A2@h301@=4@0301H=
4P0C3@l04P`>00<04@/=02004`d?010;300F4A80618D00L20`0I4aD05A0A01<=3`0?2@/05@lA01XD
5P0L5aL03@L7018<300B30/04@`901PC400C3P/06aHB014<2@0R7AX061<@01HA3P0E40d05Q4>00l:
1`0T7a`09B0M01hI5P0L5a@050l<014=3P80=C4b0P0J5QL0900K5aP061@E01XF5`0F4Q<07ATJ01XF
5`0M6AX081lM028Q7`0F5A<08B0N01hM6`0E51806QTG01hM6`0O7Q`071/I01XI5`0K6QP071`J01XJ
600G5aD06a/I01dM6`0I6AL07AdK01`L6P0M7A/07alM020P7P0R8R007QhM01dM700O7b008R8S028S
9P80824T0200O824051DF00S9RX09b`_01TN8P0S:BP09bd]02P^;P0U;C00:2lg02Xa>@0X<CX09Bhe
03I0AP0d?d<0:3<e02lk?@0[>CX0:SPi030n@00d@TD0<3m202`l@00]?T80:ce102i0A@0iBe40>TeC
03U9DP0d@4`0<Ce903U5D@80>dMC0P0oBeL01`0mBED0>dMC03]7D`0mBED0?TaK03Y9G@0lBf000P12
DFL06P15E6X0EFAh04mOK`15EF@0>T]D03a=E015Ee/0AeIM04UHG`1:F680B5IS04ABG`1;F6P0AE9R
041=G@11Ce`0AUAO04UGH01DHfX0AeUM04EGFP1=Gf80B5YM04YLG`1=Gf80AeUL0P1<GV403`19Feh0
CEmR055SIP1<Ff00CeiS04eLH@1:FE`0CEaO05=RI@1?Gel0DV9R055QH01BHV40EfMV05QXI`0305IT
I00W05QVIP1LJVX0GVa/069`L01QKfl0HW1`06EcL`1WMGD0IG=d06MfN@1/Ngh0Kgj006elOP1]O7/0
KGaj071lN`1_NgP0K7Uc06iiM01aO7L0Lgik08>;S`1hOhL0MWf507V0QP1lPhT0OXF;07b4Q`1iPH<0
OXJ807n7R@1kPhD0N8:3082:R`1hQ8@0Kg]k06eiN@1bOWh0MX:20080OXZ:00T0Kg]k07=oO`1`O7`0
MX:206QcM@1SKfl0HVi^065]K@1NJVP00P1LJ6H0601KIf<0GFUU065]J@1PK6P0Gf]W05mZJ@1YMG<0
GVYX05aXJ01LJVX0FfUY05QVI`1MK6h0JWYk05]/KP1?H680G6]^05IPHP1RKFl0JWEg05IQH`1HHfD0
BeEG04eHFP80CUUK05H0C5MI04aFF01>F5`0?TM>04M@E`13C580FF9W03e6B`10BDd0?4I803]5AP0l
ATL0?dU:041:B`0oBdl0@e9J04ECF`10C5D0?TQA03a5CP0i@D/0<cM203<f@00/;SP0:BPd02l]>@0W
;3D092le02Xa=`0_=3T0<3<h02d^<P0V9bT0:2PX02LY9@0W;2H0:RlX02he;@0_<Bh0=CLf02h`;`0/
;Rd0<cDd02PY:`0S92H092DW02l`=00e=SX0;c0d02X[;`0[:bd09BDU02<S8`0R8R807alO028R8P0Q
8B40;2`/01dM7@0P8200;Bd]02@T9@0a=C`06b4Y020U:`0U:C008RH/02@W;00S92P0824U01lO8@0R
82408b0Q01lN800H71l08RHZ01dQ900Q9BP0:Rd_01lP8P0K71h06a`M01/K6`0L71`07QhN01lO7`80
7AdM00T07QhN01PH600Q82006aTJ01PF5`0L6AX071PI01TE5P0L5aP00P0R7Ql0:P0d<S<04@l@01TG
600K6AX05aDF01XH6@0H5QL05aDF01PF5`0G5AH04a4B01/G600H51D05Q8C01LC500I5AH06QHG01TE
5P0G4a@06QHG01LC500L61T05Q8C01DA400I5A@09b<R01hJ6@0?2`X05Q8A01LC4P0F4Q4061@C01dI
600J5QD05a<B01/F4`0F4@h04@`901HA3@0I51405a8>01XE4P805A0<00D04`h:00h91P0N6AH05Q0@
01@>3P0201<=3@0501@>3P0C3@d050h>01H@400E3`l00P0B30`00`0F410040X:01TD500201<=3@08
00T4100D3Ph030H601/E5@0?2@T07aTI018<300?1`T201<8300:01D:3P0G31005P/?01H;3`0A1PX0
6a0D02dR9P0J3a<04@H:01L<3`D05@/<02D04PP901D;300B20T05`d>01hD5@0D2P/030<301/A4P0G
3@h050X;00P0000d:b`0FDm@01lE5P0A2@X07A@E00`3100A1`P060`>01<72@0H30h06`lA01<72@0D
20X05PX<01D92`0L41803@4301451`0G2`d04PH601@8200E2@T04PH601451@0D20P040@400804@D5
0P0B1PH0100C1`L04@D701@82P0C1`T201451`0301@82P0B1PP04PH800804PH800<050P:01D92`0C
1`T00`0B1PP00`0C1`T04PH8018620050186200701<72@0B1PP04PH801451`0A1`P02`4201@82P04
01<72@0:01@82P0?1@L03@<501P<400@1@P03`@701452@0C1`/04PH:01452@804PH:00l04PL=00l8
3P0?21003PL?04Y4B`0U7bD04P/B02`U;028PHT050dD00l940080`T040L?01062P0A1PX00P0B1PX0
;00A1@T040D901/@4`0S5a/050T=01462P0F2@d03`@701472@0[7b<0@CDi01/A4`0A1PT04@D90186
2P0C1`/04PH:01L;3`0I3A4050P902<H5@0H3@/04PH601L<2`0<00004@D601451`0A1@T04PH;0144
2`0A10`050P=01P<3P0:00404`L901061`0H3Pl04@D700l51P0D20X0:AdO08]oP@0F2P`04PH71@0A
1@D01P0A1`L060`<00l4100J3Ph04`L701461PH04PH61P0A1@D03P0@10H04@D701D92`080000;20R
01051`0C1`T05PX<02<H6@0=0P<03P8401D92`0?0`D040@6100A1@L01P0C1`T06Ph@01L;3@0@10H0
3`<501D92`804@D700@04@L804@h>P0/8B804@D70P0B1PP301451`0301041_oooooooooo01;ooooo
000Kooooo`0401T>4P0G31005@X>01@93@804`P<00H040D901L<400>0`L03P<701L<400@1@T20146
2P804PL;0P0C20`04P0@1@T03`@801L<400E2Ph03`@801872`0@1@T02P0300h31`0D2@d04`P<02<H
700K4A@0;b@X00L0000B1`/06PlC01462PH04`T:1P0A1`P04`0D2PT04@L800l51P0@1PL04`P<01D:
3P0@1`T07Q<G00X00`0C20h03`@:01882@0G3@/0308001471P0:00005P`;01T?3P0G3@h00P0E2``0
5P0F30d03P@501P>3@0C2PD04`T701@;1`0E2`T050X801D;2P0D2PT03@<201L=3@0900004@L801@:
2@0B20L04`T80188200@1PL04PP901D;300F30d201D:3P804`P<08/05@/?01@>400@2@/03`H9010:
300K4aP04PT>00`62P0B2`l07aDM00P1200/8b/040X>014;3`0@2Ph03PP<00l93@0G3Q<06a8G01P?
500D2a0050T?01L<4P0K41H04PT<00l92`0?1`X03`H900h82P0A2@`07A@G00h82P0?20X07QDH01TC
5@0I4Q@030H801dG6@090`D06Q@F05aFE`0U7al071HF018=2`0C3P/05a8?00l:1`0X8b0071LD01HA
3P0>2@H05Q4>01<>2`0D3``04`h;024L6@0A30T03PT601TD4@090`<081`K01<?400H51D04`l@01PD
5@0L61T061@E01XF5`0I5AH08alP01`H6@0H51<06QHE01hM6P0U92006aXH01@C400L6aL05aHC01dL
6P0N7AT06aXG01/J600L6aT092@S020P800L71`07QhN01lO7`0K6a/08R8R020P800Q8B40820P024Q
8@0U9BD071`L01hN800R8R@09bLY02@U9`0R8bD0:b``03<g>P0V:Rd092P[08F:SP0U:Rd09R`[02D[
:`0Y;bl0:c<f02L^=00S:S009c0g024Z<@0lADX0?DQ<02`f>00^>C/0=dE604A?D@0gADL09S@g02Pf
>@0_?T80>D]?0394B00cA4X0<4=902dnA@0iBE80<Si:03I2CP10C5P0>dMC03M3C`12CUX0AE5M0080
AU9N0P0e@Dd05@10CE`0?DeM03a<G00mC5h0?4aL049AI01<G6/0?DeL03a<F@13E5d0?TmF03i@E01;
FV40CUeT059PJ@1BH6/0CE]V055OK010CU/0?TaI04ABG@0204YHH@0504mNI01EIf/0BeeO04MIF`14
EUP00P1;GEl00`1CIFL0EfU[05=UI`0204YLGP0704aNH01@Gf80AUEH04iMH@1EI6L0BeYM055PH`02
059RHP0=04iNG@1DI6<0GVi]05][JP1CHF40E69R05ITI01HIVH0GF][05m]K@1PKVh0Gfe^06=aLP02
06MeMP0S06=aLP1VM7L0L7j007:0P@1]Ng/0JWQh075mN`1ZMW@0K7Qe06ijMP1_NWH0KgYe06egMP1j
Q8H0Nh>907N0Q@1jPHL0O8B9079kP01iPH@0MWn107V3Q01kPhD0MGio079lO@1gPh<0L7am06ijNP1b
OWh0LGem06eiN@1_Ng/0Lgmo06UeM@1cOgl00P1TL700<`1WLg<0HVa]05iZJP1MJ6T0FVAS05MSH@1J
IF@0GVUU061/J01TKf/0HFaX05eYI`1XM7<0Si^K06QdM01PJfd0IgEf05ARH`1KJF`0EVEX04iMH01C
I6H0FVU/05=RI@1JI6L0Yk2e0=SRi022S8h0F69T04]EE`1?FE/0CUQJ04]EE`1:E5H0CEMI04aEF@1@
FEh0BE9G03a5BP0mAdT0<S]003Q2A00kADL0?TQ903Y4A@0g@D80>dE603i:C@11D5D0@U5H03I3C002
03<mA`0`03Q0B`0h?TX0>cm:02la>`0V9S00;2`d02/`=P0T;C80>41303<h>`0O8bH0:blb02T[:`0Z
;2/0:B`X02X_:@0]<R`0<SPa02`^:`0T9RD09bTX034c<P0^<2l0;2d_02LX:P0R8bD0:R/]03Df>P0_
<3@09bP/02LW9`0];Bd09bLW038b<P0W9bL08B4Q02XZ:P0U9BD0:RXZ02h^<00T92@0820R02@W;00S
:2h09RT_01XM900O8RL08bDZ0P0S92P04@0R8R@07Q`O01hL7P0V92L0824U01TM8@0P92L092DY01hO
8P0P8B<071dO024R8`0H61P05aLG01dM7@0G5aL07AdM00807QhN010061PH01dL7@0?3@h05A<D01hK
700P71d071PI01XF5`0M6AX0518C06m]KP10?Sl0:BLX00h<3@0M6a`06QPI0`0H5QL04@0F51D04a4B
018>3P0J5QL06aLF01`H600L61T071PG01TE5@0E4A805Q8A01<?3`0I5AH0510?01TE500A3@`06ADD
008040`;01X05A4@01HB4@0A3@`04Ph=01PD4`0I5A@061@C01XE4@0H4a005A0<01PC3`0H4a004`h:
014<2@0;1P<040/701<>2`0a;2T0HEaI01PB4`0C3@l04@/<018<300D3Ph04P`<014;2`8050h>0P0A
2`/03@0D3Ph03PP801lF5`0E3Ph02@<301dD5@0D3@d040X:00H0000H41402P@401P?400G3@l00P0G
31002P0D2@d04`P<01@93@0F2`l01`0001H;3`0d:Bd05@X>00T00P0C2@/501<92P0N01H<3@0G3@h0
50X;01lE5P0Z82406a4B0107200I41401`0001XA4P0D2``04@P901892P0<0`@040L800/20`0@1`P0
4PT:01451`0>0P@0;20R03P/;P0M4A<03@4301<72@0<00805@T;00X0000B1PP05PX<0P0@10@03@0B
1PH04`L701@8200C1`L05PX:01451@0?0`<04`L701H:2P0D20P040@601D92`0F2P`00P0D20X00`0G
2`d03`<501L;3@0201451`0801H:300>0P@040@601451`0B1PP04`L90186200?0`D60186200900d1
0`0F2P`040@600d10`0V6Q`05PX<01@82P0C1`T04PH800804`L900X050P:01862P0;00<0200000l5
1`0J3Q803P8601<72`0B1PX04@D90P0B1PX0800B1`/040L>044g?`0^92`0N6if03/a>@0B21004`/A
00d32`0D2Q803`H=01hD700600@03`H:01872`0D2@d04`P<01052@0?10P04@D901D93@0G2`l05@H;
0183200C1PX04`L;038V:P19?D403P8600`0100>0`H040@80`0D20`02`0A1@T04PH703DZ:00U6AT0
4`L701`@400<00003`<501451`0A1@T04PH;00804@@;01P04`L<00P0000A1@L03P@501<72@0D20X0
4@D701P<3P0;00404@L801P<3P0T61X04`L80146100A1PD04@D50146100A1PD05PX:00T0000C20L0
5@T901H;2@0E2@T601861PH04@D500d06Ph@01041P0=0P<05`/=08=gN@0N4Q@03`<500X0002CQhT0
?c<e01<72@0A1@L04PH800<04`L900<04PH801451`0A1@L00`0C1`T02P0D20X05@T;01L;3@0?1@H0
4`L900/00@0D20X040@600l31@0@10H201451`804`L95?ooool001_ooooo01<050T?01D:400C20h0
4@H<01873@0C20h02`0601H;4@0@1@/03@8801@93`0F2`l04@H:01061`0A1`P040H70147200E2``0
60h?00803@<400/03`D601<92P0J41404@L801882@0>10D06@l@01`B4`0@1PL04`T:01D;300201H<
3@0801<92P0B20T04`L901<72@0I3@l07Q8D01T=3`0C1`T201@82P804`L90P0B1PP201882@0501<9
2P0D2P/050X;01D;300C2@X00P0B20T0300C20`050T=01<91@0K4@P04PP001T>200D2@<04`P401<8
1@0E2@T05@T;01D930805@T=00@04`L801871@0C1`L050T80`0D20P201D92@0801@8200C1`L04`L7
01D:2`0@1PL05@/<01@9300A1PX201<8300b01/@500;00@040D901P=4@0900804@H:01482`0G3A00
60dA01<:3@0E2`h05P/?01D<3`0E2`l05@X@01@;400D2Pl03PD:00l62`0A20d04`X?01@;400E2Q00
6PlE01@93`0A1P`04`P>0146300k<3H04PL;0189300C2@d050T=01@;3P0E2`h03`@802TP8`0?1@P0
81DI01<:3@0F31003`T901H@400=1`L04@/;01PB4P0D3Ph0618B00h8200@2PX201<=3@0901TC4`0C
3@d05Q0@01TC4`0J51@0618B01H@400D3Ph05Q0@00<05a4A01805Q0@02XV9@0I5A@07QXI040l>`0T
81l040`;020L6`0I5A@081`K01LC4P0I5A@07a/J01HB3`0L6AD081dH01lK600K6AD201TH4`1702<T
7`0U9R0071dH010A300N7AT06aTK01PF6@0I5aX071XM01`L7P0K6ad07QhP028S9@0M7R009RLY02<T
9P0D5AL07AdM02PX:00Q8B4061PH024S8P0T9RD0824S020T9@0Y;Bh08RHW04aBDP0X;Rh08R/Z01dV
9@0a>ST0=3dm02@/;P0U;C00:c8h02`c>@0]=3X0;3Dj02dd>P0c?Cl0<Cdm02`f=`0a?3d0<Sdo02dh
?00/>Sh0;3]00350A`0^?DD0<T=;03Y8D@0gA4l0<cm=02hjB00iAE<0@DeK03i:F00mBEL0@dmM04QD
HP12CU`0@4aJ04UEH`1<FFD0B5IQ03e;EP17EF40;C]604=AGP13DE`00P12D5/01@13DEX0A59K04IE
G018Eeh0DV5V0080CUeT0380>dYA04IEG00jBE00?DaC05]ZL@1_OXD0BeYQ06]jO`1EI6T0C5]P04ED
F@1?GV<0EVEZ04iMHP1?GV<0C5]P04]JG`1?GV<0DV5V055PI01;FUd0C5aL051PH@1=GEd0AeMG04iN
GP1GIfL0Df=S059RHP1EIFD0EfMW05EUI01AHF00E6AQ05QXI@1KJfX0Gfm^061`L01NKVh0H6mb065`
L`1_OX<0I7=h06IcN@1kQXX0JWEg06mjO01fPH<0LGan07AnO`80JgEf0180L7Yk07J0P@1iPh@0MGn0
07Z4QP1fP8<0[[Vk07^5Q`1gPH<0KWUk07N1P`1gPX@0MX6307N1P`1dOh40Lgj007b7R@1cOX4206]f
N080KWUk05<0LWin06YfM01TL6h0JgMe065]J`1OJfT0Hfe/065ZJ@1QJfX0FF9Q05=LF`1FH5l0FF=R
05mXI`1SKF`0HV]Z05iWIP1MIfH0IG9b082>S`1^O7d0F6IY05YWK@1IIV`0EF9X05MTJP1FHfT0FfY]
05QVI`1@GV40I6mc0:bg_@3gool0P8^?04UDF01@Feh0CUUK04mKF`1>FUX0BUIF04IBDP1;EeP0B5=E
04MBE00e@480@Ti>034l?P0oBd/0>4A403]7A`0iADD0=T9203Y6AP0iADD0>TQ803A2@`0`?D@0>TIB
03a8EP0lB5P0?4ED03LoC00`=T40:Bhd02`_=00^<cH09Bh]02X`<00d>SX0:Bl_02L];@0/<2l0:Rh]
02hc<@0a=c<0<SPd03<h=00Q8b80:BTY034a<@0T92@09bLW02d];@0302XZ:P0902TY:`0W9bT09RHW
02h`;`0H6QL08bDR024S8P0R92<08B<R00807AhP02L09RLY01XK7`0L7Al09bP/02PY;@0W:2d092DY
02<T:@0U9RX0:RX^02HU:P0U92T081lT01TH7@0L71l09B@Y01XI7`0Q8RH092DY028Q9P0O7R807alQ
028R900P82407QhN01dM7@0O7al0820P01/I700P7R4071XM01XH6`0O7B009B<V01`J7@0P7R406QPK
01PF6@0K6A`00P0E4aH0@00P7R404@lB01/I700Q7b80518E01XH6`0M6ah0518E01<A500I5aX030X;
01XF500>2PT04@d:01PD4P0G4a805Q8?01DA3`0G4a8061@A01PD4P0E4A00510?01PD4`0J5QD05a<B
01`H5`0M6AP05Q8A01`H5`0K5aH05Q8A018>3@0F4Q4061@C01`F5@0G4A405A0=01@?3@0C3@d04`h;
01HA3`0I4a<08ahK014;2P15?cl0T8Z:01HA5@0H4aL03PT<01DA4P0C3a005a<D00<0000N6QT061@C
00T5100O6aP05a0?01T@4@0E2``04`T:01<:2`0D2P/201@;30805@/<00H050/<01D;300F30d05@/<
01882@0@1PL201L=3P0401D;300D2P/04`T:01@:2`804`T:00`050X;01D;300E2``03`D601882@0E
2``05`d>01`B4`0I3a004`T:01L=3P0F30d2014720804`T:00h050X;01D;300E2``04`T:00h41@0H
3Pl08aTJ01P>3`0G2`d04`L901041P0E2@/06@d?01@82PH04PH801@02`4001`B400B20H05@/900d3
0@0A1`D060h<00X20@0E2`T06Q0>01P>300I3`h05PX<00h2100D20X040@60186200@10H05@T;01<7
2@804PH800T04`L901D92`0E2@d060`@00X00P0800005@T=01H:3P0A1@T00P0C1`/0400A1@T04PH:
01<72`0:00804`L;01862P0G2`l07a<G01<72`0G2`l03`<70104200<0@@04`L;00d11@0A1@L20186
200301451`0C1`T05@T;00804`L901H03`<501<72@0L41803`<701D:3`2XWJ<0PWMm01P=4`0;00H0
714G01883@0700807Q<I00/11P0D2@l05``B01462P0>0PH05`/?01H:3P0>0PH04@D90P0B1PX02`0@
10P04`L;00l31`0H30l03@4301P<3P0A1@L040@601T=3`0>10D04`L9008050P:00T04@D700l31@0;
0@808QHH00h2100F2P`0300200h2100L41@00P0@10P0100A1@T04PH:01862P0B1PT201041P040145
1`0B1PP04PH8018620D04@D701P04@H501460P0A1P<04@H401460P0A1P<05P/900l4000?10807Q<A
028G4`0H3@/04@D500h20P0?1@D050P800h20P0B1PH02`0001L;2`0=0`<0300001861P0C1`L20104
1P803`<501@040@601451`0@10H060`>02DI6`0I3@l050P:00l51P0>0P@04@D701P<3P0@10H02`42
0186200<00805@T;01041P0800004PP901H:30H04@D700H050P:0186200=0@<050P:01H:300:000D
ooooo`006oooool0200A1P`04`P>01L<4P0I3Q@05@X@00h32@0B1`d04`P>0P0D2@l0100B1`d040D9
01872`0B20T201061`080147200C2@X03`D601H<3@0J414050X;01L=3P0P5QL201D;300401882@0J
41406a4B01882@H050X;00H04PH801041P0C1`T060`>01@82P0@10H201@82P804`L90P0B1PP00`0A
1`P04PP901882@0301<92P<04PP900`050X;01D;300Z81X091X?03dc:P0_9A/05@/301@90`0D2@L0
5@X801D92`0E2@`201D93@0301<72@0B1PH04`L700@050P80P0E2@T201@8200D01<71`0A1@L050T=
01D:3P0M4QH05P/?02XO8`0N4aL03@@601<8300P5AT06a0D01X?4`0F2`l04`P<01@93@0G31005P/?
01L<400F2`l201D:3P<050T=00d050T?01D:400F2a405P/A01D:400D2@l03`@:01P=4`0I3Q@060dC
01/@5P0C2@h050T=00805@X>0`0F2`l0300Z7b<0<bP/01/@500H3A404PL;01P>4@0U71d09R0P01D?
3`0B30`05@l?014;2`804P`<00H05@l?01@>3P0C3@d071HF01H@400G4A4201H@400301D?3`0D3Ph0
5a4A00806A<C0P0J51@0500I4a<06ADD01XF5@0L61L0510?01TE500f<S406aLF01HB4@0N6QT06QHE
02@P7`0]:BP06QDB01dI5@0N6aL07ATE01`I5@0K6QH07A`H0P0A4P`0200M7QT06Q/F01lO700P6al0
7adQ01dK7`0K6Ad06a/N0P0M72004P0I6Qd08b@W02//;`0Q9BL07b<T051@D00K6a/0:2PX01lO7`0c
=C@08bDT030b<@0T:2L07R8Q02@X9`0[<Bl082HT02D^;@8092d/00H0:c@c02/c=@0V;S00:c<f02`d
=`0]=CT202dd>P0B030i>`0_>CP0<3Xk03<m?`0`>cd0<Se103<oA00kB4h0<3m603I5C@0e@d`0?D]F
03E2CP10C5L0?TYG03m;F00nBUL0>DEC0P10C5X07@12CUd0A51O04A@G`15D640AE9O04]IHP18EUl0
?deF04=AFP15De`0@DmH03i<E@0oCEH0@e5J04IDG@19Eel0B5MN04eLH@15E5T0@e9G03M6B`10Ce@0
AEAI061_M01:FEh0CeiS04eLH@17EU/0C5]P0080CUeR00X0B5ML04MFF`1<Ff00CeiS051OI01?GV<0
BEQM04MFF`17EUX0BUUL0P1@H6000`1;Fe/0CUiN05=SH`02059RHP80Df=S02<0E6AT05EUI01EIF@0
EVIS05MWI01IJFP0GFe/05m_K`1OKW40G6]_061_M01RLGL0I7=i06]hOP2KYZX0Mh6306]eM`1bO7h0
L7Yl06egN@1YLgD0K7Ih06miN`1`NW`0KgUk06egN@1gPX@0LGan08>>T01`Ngd0N8>508:=S`1aO7h0
LWeo07=nP00207AoP@0907=nP01[MWX0KgYn075lP01_NW`0KGQj06agN@1ZMWH0JGEc0080I71^0240
HVi/065]J`1TKF`0I6e/06I_KP1PJFP0G6ET05iWIP1LIF@0HFYY061YJ01QJVT0HV]Z05eWIP1IIFL0
FFMZ05MUJ01JIfd0FfQ`05MTK01OK7@0FFI/05QUJ`1DHVD0D5iO05=QHP1DGfD0Hfid08jIW`1II6P0
AU5E04YEF018DeD00P19EED00`17De<0AE5A04MCD`02045=C@0W03]7A`0nBTX0;c/k03]7A`0d@400
?DU903m;B`0lB4P0>dM7038m?00e@Cl0>4A403Q7C00oCEP0@DiM03e:FP0lB5P0?DIE03<lAP0W;S@0
;34e03]0@00c>3L0:Rl^02db<@0V:bX08bPV02P];00]<S40<CHd02ld<`0/<C009b`[01lQ800/;2`0
;Rh^03dm?@13@d<0:RXZ00<09bLW01D09RHV02DU9@0U9BD05QPE02PZ9`0O8Al092HU01lQ800^;c00
:R/]020Q8`0S92P092DY02TZ;P0U9RX0:bX_02TX;@0U92T08B0U028Q9P0T8bP00P0Q82D201lN8`0:
024P9@0R8BH07A`R020O9@0R8BH08b8W020P8`0M7Al07alQ01hN7`807AdM010071`L01/K6`0H5QT0
6QPK01/I700I5aX061HI01LE600L6Qd07A/N01LE600F51L06ALJ01HD5`0E4aH06QPK0P0M6ah01@0D
4QD0;B/^06QVJ@0Q7b8071XM008061HI00H06aTJ01/G5@0J5Q@05A4?01TE4`0L61H201HB40<05a<A
00D05Q8@01DA3`0E4A006QHE01LC4P0201HB4@0401@@3`0B3Pd05a<B01PD4`805Q8A00<05a<B01TC
4`0F4100100E3`l04`0B30`03`T901@>3P0F41005@l?01PB500L5a`06QDI01<>4P0B3A404Ph?01XF
5`1:ATL04@d<01@@3`0=2@P06QHC014:2@0E2``00P0H3Pl301H<3@L05@/<0P0D2P/04P0L4Q<07A<D
01P>3`0E2``050X;01<92P0B20T04`T:01882@0E2``05`d>01@:2`0E2``050X;01H<3@0H3Pl050X;
01061`804`T:0`0D2P/201<92P0=01882@0=0`@06Q0A01<92P0?1@H081HG01P>3`0G2`d04@D701P<
3P0B1PP06Q0A01`@4P060186200@00/20P0I3`h03`D401<9200=0`804`T701881`0F30X040H401X@
3P0D2PP03`D401451`0@10H06@d?01451`8040@600P04PH801451`0@10H040@601451`0B1PP05PX>
01462@806`lC00<040D801862P0A1@T00P0C1`/00`0A1@T04PH:01<72`0201`@500:0104200?0`L0
5@T=00`0100@10P04@D901P<400A1@T050P<010620<050P:01804`L901D92`0G2`d08aLI00h41@0H
30h04@H701451`0D20X04@H901dB5@0D2P`04`P;01862P0@10P04@D901472@0@10P201D93@0D0104
200B1`X03`<701P<400T61`06PhB00l31`0C20/04PP:01D93@0D2@`02@0101862@0=0P<05@T;01<8
2@0:00403`<50186200C1`T201@82P0901451`0@10H04@D801452@0?1@L03P@602<G6`0l<3@050P<
008040@80P0A1@T01@0B1PX04@D801041P0@10H04@D700<04PH81@0A1@L00`0A1PD04@H201460P03
01460P0Z00l40@0A1P804PL301<8100D2@D05P/701@8200T61P081@D00d10@0=0P804`L700l4100D
20P040@401L;2`0E2@T04PH601041P0=0@<08aLI02dQ8`0I3@l03`D601<72@0A1@L060`>01D92`0<
0@804@H70186200G2`d07A4C01@82P0A1`P050P:01/?4@18?3h06Ph@01L=3P0A1`P03`D61P0A1@L0
1P0C1`T04PL801H:300;0@804`P901@82QCooooo000Kooooo`8050T?00H06@hD01lD6P0K41H040D;
0146300>0`T201<83P0>00l42P0D2@d04PL;01<92P0?1@H040H701882@0?1@H05`d>00l51P0B20T0
6@l@01472009000201<92P0;01061`0D2P/050X;00h41@0E2``04`T:01882@0C2@X050X;01D;300G
2`d00P0C1`T00`0F2P`050P:0186200601<72@P04@L800d04PP901@:2`0F30d060d:06]QE`3ooO<0
V8j501X?2@0K40`06@h;01@91`0D20X050P;008050P<00<04`L901861P0C1`L02@0D20P04P0C20X0
7a@H01D:3P0L4AD05``@03`a=@0Z7b<01`0000`11@0F3@l02P0301<8300E2Ph04@H:01/@500U6Qh0
7a@H01872`8050T=0P0C20`201872`0<01873@0C20h04`P>01<83P0B1`d04@H<01X?5@0@1@/03`D:
01X?5@0F2a40=R/a1P0F2`l0200@1@T04`P<01H;3`0<0@D03`@801L=4@0M51D081XJ0P0B30`0400E
3`l040X:014;2`0C3@d05@l?01<=3@0@2PX04@/;01LA4@0F41005@l?01@>3P0E3`l05Q0@01@>3P0E
3`l401H@401K01HB4@0H51<06QHE01HB4@0J5QD0;BTX01lK6P0I5A@06aLF01@@3`0I5A@061@C01`G
500M61D06aLD01XF4`0K6AD07QdI020O6`0S91l08B8M01<D3`0/;BP051@B01`G6P0P7R407adP01dK
7P0Q8B<09bLY02HV:00L7Al06AXL01dN800K7b008BDV01dM7@0B4Q80;Rh^020P800[;B`0;2h]02T[
:P0N8R40:Rh]02T];00J81h082HT02@];00V;bh082TX02@];00Z<S@0:C4c02`d=`0]=CP0;SDj02he
>`0]=3X0<CXl038l>`0b?3d0<cdo02hi>`0`>cl0=D5604iKH@0fAD`0>4I>02Xh@@0kBE@0=49<04=@
F00lBE80>4E>03m;E`10C5X0BeMU04A@GP16DV80BEAV04YEI`19E6P0C5UV04]IHP1CHFX0AUAM05IT
K@0oCEH0@e5J045?F003049@F@0N049AF@1:FF00B5ML041?E00oCU<0?DaA04=BE`19F5d0GVeb0;c;
d01QL7D0?diC04aKH019F5d0A5=H04MFF`1AH6D0Df9W04mNH`1;FUl0CEaQ04iMHP1;FUl0BEQM04UH
G01AH6<0GFe]05UYJ@1@H600EfMW0P1BHV80601EIFD0F6QX05IVIP1EIFD0FFUY05UYJ01GIf@0EFER
05IVI@1JJVT0GFe]06akOP1UM7P0JWUn05a[L01PKgD0IG9h061[K`1ZM7H0M7j0071jO01VL780JG=e
06YdMP80KgUk00/0JWAf06I`LP1VL780JgIh07J1P`1[MWP0N8>507=nP01hPhD0KgYl075lOP03079m
O`0/075lOP1eP8@0L7]o06ehO01_NW`0KWUk06ehNP1YMGD0JgMe06McL@1NJVP0Hfm]069^K01QJVT0
IFi]06I_KP1RJfX0GVMV05mXI`1KI6<0JgAc06=/J`1NIfH0HV]Z05mYJ01JIVP0JGMj06]iO01HIF/0
Gfad07>0R01FHf/0FVM]06EbN01HIVT0BeUJ05=QHP1?FV00?dY@04UDFP1CGV80C5MK04UDE`1:EEL2
04YFEP0/04MCD`16DU80A51@03e9B@0jATH0?TY:03A0@00Y=CD0>4A403U5A@12CTh0@dm?03]7A`0h
A4@0<Sdm03Q2@`0h@dD0=d=903]9E013DEh0?T]K034mB`0d?TX0<SU402X_=@0/;c@0>3`m03<g=P0Z
;Rd0:Bd/02L[:P0X;2/0;30_02hb<@0c=cH0<SHe02hb<@0V:RT0=CDe02@T900f=SH0clo?0>SXj013
@d<202LW9`<09RHV00X09bLW02la;P0K7AX0;c4`02HX9`0[;B`09bPZ030a<`0[;2h0:b``0P0J6al0
100R8bL0:RT^02TX;@0V9BX202@S:00L02HU:P0S8RL081lT01hM8P0Q82D08R4V01hM8P0P7bD07QdR
020O900S8RL08B4T01/K7@0P82808B4R024Q8@0O7al071`L01XJ6P0M6ah06ALJ01XH6`0L6Qd07Q`O
028P8`0K6A`071XM01XH6`806ALJ01005Q@G01LE600E4aH06aTL01`J7@0O7B00De5D0;Vg^P0V92L0
40hA00d;3P0L6Qd07Q`M018>3P0C3`h05Q8A0P0J5QD00`0G4a805Q8A01HB4@0401HB4@0301@@3`0G
4a8061@C00806ADD01l061@C01LC4P0D40l05A4@01@@3`0E4A0061@C01H@400G4A405Q0@01D?3`0F
41005a4A01XD500H4Q804P`<01LA4@0N61P06aDG09:=TP0X8bL06aHJ00T4200C3a006QHG06EQHP0B
3Pd05Q8A01@@3`0I5A805Pl>00806@l@00@050X;01L=3P0Q5aP081HG1@0E2``02P0D2P/05P`=01H<
3@0E2``0718C01hD5@0H3Pl05@/<01@:2`0A1`P201<92P050147200F30d060h?01@:2`0E2``00`0D
2P/201<92P0301@:2`0A1`P050X;008050X;00l04`T:01882@0B20T05P`=00d3100A1`P03`D600L0
000G3@h05`/=01041P0J3Q00200001041P0E2@/01P0B1PP01@0A1`H081HE01<9200G3@`040H500@0
4@L600H05P`;01@:2@0B20L05`/=0186200J3Q0201@82PL04`L900L04PH:020D602>PXH0TXJ:02<G
6`0900404@D900804`L;01T04@D901862P0C1`/07A4E01`@500A1@T03`<701D93@0B1PX07Q8F00h2
1P0;00<040D801hB5P0J3Q804`L901@82P0C1`T04@D701<72@0E2@/0Ge=E01@82P0@10H030830080
200000@060h@01@8300B1PX04@L90P0=0@D0600D20`0=b/_01862P0A1@T03`<701@8300A1@T060`@
0104200B1PX07Q8F01lC5`0H3100300400P0000L41@08ADI01H:3@0B1PP06@d?02LK7@0F2P`03002
01@82P<04`L90P0A1@L01`0C1`X02P0200l31`0C1`/0<bL[04m3A`0D20`00P0?0`L3010420040104
1`0@10H040@601451`<04PH81@0A1@L00`0A1PD04@H201460P0301460P0300l4000B1`<04`P40080
304000P04`P501861P0L41007Q8B00l30`0B1PH05PX:01@820804@D500d081@D01L;2`0@10@06Ph@
01<72@0L418081@F01<72@0A1@L050P:00h2100J3Q009ATK00804`L900P02`0101<72@0J3Q005@T;
01H:300H30h02P0005Q<CP804PH800<05P/<01041P0A1@L01@0A1@L01P0800008ADG00/00@0G2`d0
3P<400`00QCooooo000Kooooo`0601873@0>0`T040D;01H;4@0E2Q003P<90`0D2@l20146300=01T>
4P0>0`L040H700`20`0>10D04@L800X00@0?1@H05`d>01D;300?1@H040H701<92P0201882@0=0147
200C2@X04PP900h41@0D2P/04PP90147200B20T04`T:01@:2`0I3@l05@T;01@82P0201D92`0301@8
2P0C1`T04`L900@04`L9200A1`P02`0B20T050X;01D;300P5Q80IUaC0>gSfP20MVh06Pl901L<200B
1`@050T700<050P:00@050P<01<72@0B1PH04`L72@0D20P04P0E2P`05P/?00L0000?10P04@H:024F
6P0:0@<08QLK02TN8P1:?d<0;R<W00L0000G31003`@801T>4P0S61`07A8F01052@8050T=0P0C20`2
01872`0301@93`0E2Q005P/A00805``B00L05P/A01D:400A1P`091TO01`A5`0A1P`09AXP00H05P/?
00l09AXN01P=4@0E2Ph05P/?01lD600B20/040L801H@400?2@T04`d=01D?3`0>20P04`d=014;2`0C
3@d00P0H4Q802@0?2@T05@l?01D?3`0E3`l05Q0@01TC4`0J51@04P`<01@>3P0301D?3`0=01@>3P0E
4A0061@C014=300O6aX04`l>01LC4P0H51<05a<B01`H5`0H51<07QXI01XF5@0201dH5@0R01/G500I
5A806aPE01hM6@0Q81`0D55<02@U800O81/0824L01dM6`0M61/08AlR020N8@0N71l08R8T02LW:@0J
6Q`03a0B01DF600P8B<05ATJ024U9P0S8b<0<c<c03Lg=`0X:2P06A/J02`^;@1]Kfh05QXI02@X9`0X
;2/08RPV01DK6@808b`[00L09Rl^02</:`0T;2h0:c<e02`d=`0]=CP0;SHj0080;SDk03H0<S/m034k
>P0_>CX0<Sdn030k?@0`>cl0=415045>E00[>T40;3]302Xh@@0iAe80=D=;045>E00jAdl0>4E=049?
F011CET0A51N049>GP16DF<0Ae9U04MBIP1<Efd0C5UW03i<E@1GIFh0H6ig069`N@14DU/0@DmH03]9
DP0nC5D0A59K04MEGP19Eel0A5=J03i=DP0jBDh0?4]@049AEP13DUL0BeYO05i]LP3=g>40J7Ml03M6
B`1;FUl0CEaQ04MFF`19F5d0CUeR04]JG`19F5d204]JG`0504aKH01=G640CUeR04aKG`1?GV400P1L
K6`04P1EIFD0FVYZ04mOG`1>GUh0DV9R05IVIP1DI6@0Df=S05IVIP1IJFP0EfMV05EUI01EIFD0FFUY
05][J`1[NWd0IgIi06mnP@80Gfic01@0H6ec06UdN01/MgT0JgIh06A_L@1RKFl0KWUk06]fN01^NG/0
K7Mi06MbM01SKW00IG1b06IaL`1fPH<0JWEg07f8RP1aO7h0KgYl075lOP<0LWeo01P0LGan06mjO01f
PHD0KGQl06agN`1cOX00KWUk06MbM01YMGD0GVYX06mkN@1GHf40DemM061/JP1NJ6L0HVa[065[JP1M
IfH0FfET05YTH`1VL6l0NH>206ihM`1LIVD205YTH`0Q05IRI01AGf80BEMJ055NI02MZ[80fNK^061]
M@1QKW@0JGIl05QVJ@18EUL0CeeN05=NI015D5H0@diD05IQI@1>FEd0BUEH04eHFP1<F5P0BEEE04EA
D@13Cdl0@Da<049<C@0lATL0@D]<03Do@00`>S/0>D=403Do@00jA4D0>D=40080=3ho0300<cdn03U3
A00g@T@0<cm603<oB`0hAU<0?T]I03I2D00d?TX0=cm703@i?`0`<cP0<3@e02lc<P0]<C00:bl^02L[
:P0/<2l0<3@c02hb<@0a=C@0;c<b02X^;@0T:2L0@41002`/;00j>SX0clo?0>OWi`0o?cl092@T02<S
8`0R8R80820P024Q8@0R8R80828Q00d?3P0S9B@09BLV02h`;`0/;Bl0:b``02DV:P0X:Bd08b@Y02d^
<`0o@4D302@S:00G02DT:@0W9R/0:RT^02LV:`0S8RL07A`Q01hM8P0P7b@07QdR020O9@0N7B807ahS
028Q9P0Q82@06a/M01lO8@0P8240820P01lO7`0L71`06QXJ01HD5`0G5AP00P0N71l05P0I5aX06aTL
01XH6`0L6Qd07adP01hL7`0I5aX05Q@G01/I700J61/04a4D01DC5P0I5aX0=C<f04e;CP0?3A006QPK
00X82`0J61/07adN01XF5P0B3Pd201/G5P03014=300C3`h05Q8A00D05Q8A00H05a<B01<?3P0F4Q40
6QHE01LC4P0E4A0201<?3P0G01PD4`0F4Q404@d<01<?3P0E3`l0618B01LA4@0E3`l05Q0@01PB4P0C
3@d06aDE01lI6@0D3Ph03PP801@>400/9B/06Q@H00l93@0S7B405@lA00`6200S7Al00P0@2PX00`0B
30`061<@01H?3P0201T?400401@:2`0G3@h08ALH020F5`H05@/<0P0H3Pl00`0E2``060h?01T?4003
01D;300?01061`0E2``05@/<01D;300L4Q<06a4B01D;300G3@h06@l@01@:2`0C2@X05`d>01/A4P0H
3Pl04@L800804PP90P0C2@X201@:2`0<01H<3@0<0P<05@/<01T?400E2``0<RPY02TM7`0:000050T:
01dA4`0C1`T05@T;1P0B1PP04P0/8R40<BLV01881`0>10<02`4001H<2`0D2PT05P`;01dC4P0;0@00
2P4101dC4P0K3a4040@601D92`0C1`T05PX<018620H04`L900L07Q8F00d31@17>cl0Bcm30104200E
2@d04@D900804`L;00D04@D901862P0C1`/03`<701452@0200h21P804@D900H02`0301862P0I3A40
4PH:01hB5P0O4aL20186200601451`0?0`D04@D701<72@0B1PP03@430P0C1`T06P0N4Q@07a<E01<7
2`0>0PH02`0300h31P0C1`/03`<701@8300g:bl04PH:0104200?0`L04`L;01T=4@0?0`L02P0201X>
4P0P51P05@T=00h31P0C1`/05PX>01<72`08000050P;0P0?0`D01@0P51H05PX<00/00@0B1PP04`L9
00804PH800T04@D70186200A1@P040@800P0000?0`L05PX>01lC5`0<0P@01@0@10P0100@10L040@6
01041P0A1@L3018620D04@D700<04@H50146100A1P@00`0A1P@201<81P0J0146100?10803`@20187
1@0@10@020000188200B1PH03`<300h20P0<000040@401dA4@0_8b<07a<C00`0000A1@L040@600X0
0@0800003`<501H:300@10H02P0001<72@0O4aD201041P0<00P0000I3@l02`4200T0000P51H02000
01D92`0;0@802000020D5P0=0P<04`L91`0A1@L01@0F2P`06@d?00/00@0B20T03`<501Cooooo000K
ooooo`0G01D:400B1`d04@H<01<83P0D2@l04PL=01052`0C20h03P<90146300H3A<03@<601872`0F
30d04PP901H<3@0L4Q<04@L801P>3`0A1`P03`D601hD5@0M4a@00P0B20T201@:2`0501<92P0B20T0
4PP901<92P0B20T00`0C2@X01@0B20T050P:01@82P0C1`T04PH800804`L900<04PH801<72@0C1`T0
0`0D20X301<92P0@01882@0A1`P04@L801@:2`0C2@X04PP901<92P0D2P/05``90146000e:b<09Q/F
01<8100G30T050T701<71`<04`L900@04`L;0186200B1PH04`L70`0D20P201<71`8050P80P0E2@T0
4`0C20T07aDG03hc=P0N4aH03P@600`2100H3Q0030<500d31@0G3Pl040D801H;3P0E2Ph040D90146
2P0D2@d04`P<01@93@0F2`l00P0E2Ph301@93@0301873@0C20h050T?008050T?00L04`P>01L<4P0D
2@l0:b0V0146300K41H050T?00<05P/?0`0E2Ph02@0<0`D04@H:01H<3`0B1`/05``@01882`0@1`P0
5a4A018<300201D?3`0?00`61P0C3@d04P`<018<300J51@07aTI01D?3`0C3@d05@l?01LA4@0H4Q80
6Q@D01TC4`0F41005a4A00@0618B02h06ADD028N7@0D40l06aLF018>3@0N6QT06QHE01LC4P0I5A@0
5Q8A020L6`0I5A@071HE01dI5`0L61H06aLE01/I5P0N7AX05QDB01`L6@0O81`08B4N03/l>00T9280
8alP024O8@0P7R007Q`N01hN7`0P8240>3Pi07AfMP0];bl0828R02HZ:P0J7Qh08B4Q02<S8`0J6QX0
9RHV02<U900c=C@0GV1O02T];00X;2/092PW0P0Z<2h0;00U;Rd092d/02H_;P0U;Rd09Rh`02Ta<`0]
=CP0;SHi02lf>`0_=S`0;SDk030i>`0^>3L0;CLh034l?@0_>S`0<3/o02lk@011CU@0NHR?05UWK`0c
@DX0=49=03]9D00jB4`0?Ta@03e:D@19EUl0DEeY04]GI@1DH700Dei`04aGK015CfL0A4iV041=G00d
@d/0CUaT05m^MP1>GFD0AUEM03Q7C`11D5P0@e9J0P16EEd05015E5/0A5=H03a;D00oCU<0@e9G051O
I015E5T0?DaA04mNH`1IJ6d0CUeR04QGG017EU/0AEAI04YIGP1EI6T0D5mT04UHG@1LJg00D5mT0P1C
HVL0301=G640C5]P05=RIP1:FE`0D61P05ATI01EIFD0EVIV051PH01BHV80E6AT05QXJ080FVYZ01X0
FFUY05MWI`1GIfH0EfMV05MWI`1IJFT0FVYZ05i^K`1PKg40IgIi06UhO01SLWH0Hg9e06agN@1WLW@0
J7=e06agN@1]N7X0IW5c06agN@1ZMGL0IW5c06E`LP1WLW@0J7=e06YeM`80K7Mi00@0LGan079mO`1d
Oh40L7]m0P1aO7h04@1`Ngd0KgYl06ehNP1]N7`0LGb007V4R01lQhT0L7]m06MbM01VLW80KGUg05aX
IP1/N7H0R9BB05eYI`1LIVH0GfUY0080FfEU02L0GFMW05aVIP1JI6@0HF][06=]K@1KIFD0F69R05iZ
JP1JIfP0FVQ[05]YK01FHfT0GV]c06UfOP1DHFT0CeaR051MH`1>G5l0C5YK04mMGP1>FEl0B5=I04A?
E@1<Ee/0BUEI04QCEP18DeD0AU9B04=?C`0oBd/0?DU903a7A`19De@0>dE603Y4A@0b?3d0>49303Do
@00`>S/00P0b?3d06`0c?Ch0>D=403Y4A@0kADL0>dA903a8C`0e@T/0<d1;03a8E@0jA4l0<ca603Ln
A@0e>Sh0;c<f02`_;`0a=3<0<cHe02lb<@0Z;B`0;2l^02lb<@0]<2l0:B`[02@W9P0R9B@08B@S024Q
8@0202TY:@0603lo?`1:BTX0<C4a02PX:00V9RH08b<S0P0P82003@0R8R8061XI02la<00Q8R<0:b`]
02l`<@16AdX0@dA8030a=@0U9RX09BH[02`]<P0Y:Rl00P0R8BH202<R9`0902@S:00U92T092<X02<R
9`0P7b@07QdR01lN8`0P7b@07QdS00<07ahS00@07ahR01hN800K6ad071`M0`0K6a/02@0L71`07A/N
02LU:00f=3L0;bd`01/I700J61/071XM01/I700201hL7`0?01TG6P0J61/05Q@G01/I700F51L07A/N
01XH6`0I5aX07adP018@4`0L6Qd05Q@G01`J7@0=2`h05a<C00806ADE0P0G4a<01@0F4Q805a<C01HB
4P0E4A405Q8B00805a<C00l06ADD01DA400E4A004`l>01DA400J5QD05A4@01TE500U8B008alN01LC
4P0H51<05@l?01XD500I4a<00P0E3`l00`0H4Q805a4A00l92@0201PB4P0?018<300H4Q@0:bDZ02lY
;@0T7R8040/>01<=3`0H4Q@03@P902LQ8@0G4A405@l?018=2P0C2`X05@/<008060h?0`0F30d601D;
300601T?400J41405@/<01@:2`0E2``04PP90P0F30d0100A1`P06Q0A01/A4P0E2``201H<3@080106
1`0A1`P04PP901H<3@0A1`P05@/<01`B4`0H3Pl301882@804`T:0P0D2P/0300>10D05P`=00l61`0<
0`<06@l@024G600A1@L0BSi003DY:`0800005PX<01P=3`H04PH800T040H601dC4`0@1PH060h>0188
200A1`L05@/;01D<300:0P400P0D2PX0100A1`L050P:01451`0I3@l30186200801041P0A1@L04PH8
0186200A1@L040@601<72`0D2@`201862P0301<72`0>0PH04@D900804`L;01@04@D901862P0C1`/0
3`<701<72`0D20`04PH:01452@0C1`/03`D701@8300C2@/050T<04@h?01MDED04PH801<72@0A1@L0
3`<501041P804PH8018050P:01<72@0D20X05`/=00/10P0>10D06PhA01H:3@0@1@L03`D700l41P0C
1`X04PP:01041`0E2@`050P;00h21@0=0PD201H:3P0>00l41`0A1@T05PX>01452@0?0`L06`lC00l6
1`0V71h0@3@g0186200?0`D04@D701<72@0G2`d201<72@0;0186200A1@L04PH801<72@0A1PP05`/?
00`1100G2`l03P8601452@0B1PX00P0C1`/201862P0501452@0A1@P040@601041P0A1@L00`0B1PP5
01451`0301451@0A1P@04@H400<04@H401004`P601871@0B1`D04@H401871@0A1P@05`/;00l51@0R
5aL06Ph>0104100>0`<04@D501@8200=0P804PP80P0B1PH0600M4A<07a<E01D92`0=0`@04@D70146
1`0E2@/04`L900l41@0>0`@04@D701@82P0@10H03@<402@H6P0M4A<04@H7040d=P0K3a404PP900X0
000E2@/03`D6018620L04@D700D03P<501451`0<0P<0N6a^01lC5@0Dooooo`006oooool0800A1P`0
4`P>01873@0@1@/03`@:01052`0<0@L04`P>0146300S61h0<RL]00l4200=0PH04PP900h41@0D2P/0
718C00h41@0=0`@04@L801061`0E2``050X;00d3100>10D040H701882@0@1PL03`D601882@0A1`P0
4`T:0P0D2P/01@0A1`P040H70186200D20X05@T;00<04`L90P0B1PP01P0C1`T050P:01@82P0D20X0
5@/<01@:2`804`T:0P0B20T00`0F30d050X;01<92P0201882@0800d4100K40`05@X601870`0E2PH0
5``:0105100C1`L301<72@0401<72`0B1PL04PH601<71`<050P80`0C1`L0300D20P05@T901D92@0E
2P/01`0002PN7`0;0P<08QPI00P0000=0`@06a4B01@:2`805P`=00L0308301D;3@0B1`/05``@01P=
4@0D2@d05@X>00<05P/?0P0E2Ph03@0D2@d060dC01P=4`0G31805@X@01@93`0B1`d06PlE00L00P0D
2`l07A8H01873@0F2a400`0E2Ph07@0D2@d04`P<01<8300E2Ph04@H:01L<401?A4P0Fe1D01X@500D
2``06A<C010:2P0C3@d050h>00h8200C3@d05Q0@010:2P0A2`/05@l?00h8200B30`05@l?01LA4@0H
4Q805@l?01<=3@0F4100618B00<06A<C00T0618B01PD4`0I5A@06aLF01PD4`0L61L06ADD024M700K
5aH00P0I5A@06P0]:BP0:RHU01/E5@0M61L07ATH01`H5`0K6AL071/I024P7P0F5Q@0=SHd01HF500N
7Q`06QXH024M7P0L6Q/07A/L020N7`0P82007alO01hN7P0j?3/051HE01lQ800H71/09RXY0P0L71`0
2P0T92@07alO02PZ:@0S9B@09RPW02``;`0E6AP0:2`[01dS8@0Y;bd202Tb<@0701/T8`0V;bh0;cLi
02<[;@0]=CP0;SHi02lg>`0202lf?00R02lh>P0b?3/0=3ho02lj>`0U<380:C@h03A0A@0H9B/0EFA[
03I4C00mBe@0>4IA03Y8CP0/>S/0>4I903E3B01BGfL0MX:>05EQK`12CUh0A4mS04iHK`1BG7D0C5Ia
03m;G00c@TT0>TU@041?EP14DeX0KWf4049AF00oCUD0@U5H04QGGP80BUUP02H0@E1E03Q7C00oCU<0
@e9G05=RI`0nCE80CEaQ03]:C`19F5d0AeIK04IEFP18Ee`0CEaQ04IEFP1;FUl0CUeR04YIGP1DHfP0
DV5V05i]LP1RLGH0D5mT04eLH@1TLgL0E6=V04mOG`1@H600DV9R051PH01AHF40DV9R055QH@1DI6@0
Ff][05a/K01GIfL0E6AT05IVIP@0F6QX00L0GFe]05m^L01QL7<0LH2306UhN`1/Ngh0Gfe^0080JWEg
0180Ig9d06YeM`1_NW`0JgIh06=^L01OJV`0Hfi`06UdMP1ZMGL0K7Mi06A_L@1gPX@0JGAf06mjO01]
N7X0JWEg06agN@1]N7X306iiN`0I06MbMP1`Ngl0LGb006MbM01RKFl0Hfi`06=_K`1EHEl0FVIT061/
JP1^NWP0CEUG05aVI`1NJ6T0FF=T05eWJ01TKVl0Hfe^06E_L01BG5d0G6IW05eWJ01EGf00FVIV05=Q
HP0205=QI00B05ISJ@1BGfL0CEYR051MI@1?G680CEYP051NH@1:F5T0@Dm@04QCF@19E5X0DEaR04eH
G01<Ee/0Ae9E04A?D@13Cdl0@4a<0P0nBTX07015D500Hfe^04]EEP0mAdP0=Cm003i8B@0c?Ch0;CLh
02li>P0]=cP0;SPi03@n?`0g@480=3]102df?@0`>T80;S]3030mAP0f@T/0<Sa5030i@00d>Sl0=3Pk
03Df>00d=SH0<C<b030b<@0^<2l202la<00702d_;P0Z;2/092HU028T8`0T9RD0:R`[02HV9P0202DU
9@0601dM7@0S8b<09RHV02LW9`0U9BD0820P0P0L71`06P0M7Ad08R@S01dO7P0Y:R`06a`N03Lh>P1D
EET0:BX^02<T:00U9R/071dR020Q9P0W:2d0:bX_02XY;P0X9b`092<X028Q9P0P7b@06aXO01lN8`0S
8RL08B0U01lN8`0Q82D071/Q0P0P7b@03P0L6b0071`O020P8P0M7Al071`M01/K6`0L71`07alO024Q
8@0J61/07adP02LU:00M6ah04@lB0P0P7R40100G5AP061HI01LE600G5AP201hL7`0901LE600C4A@0
6aTL01HD5`0N71l05aDH01hL7`0L6Qd0518E008040hA00d0<Rh_04A0@@0S7b005Q8C01lK700B3Pl0
61@E01DA4P0D41405A4B01LC500H51D04`l>00806QHE00`04@d<01hJ6@0a;B`07QXI014=300F4Q40
5A4@018>3@0I5A@05@l?01/E5@0J51@201@>3P0301H@400C3@d05@l?00805a4A014050h>018<3P0F
41D07aTM01H@500E3a<08adO01dG6@0L5QP07ALG00l92@0E3`l030L401/B4P0J41405@/<01<92P02
01@:2`H05@/<00L050X;01T?400K4A805@/<01@:2`0E2``04@L800805P`=00l04PP901dC500O5AH0
5P`=01P>3`0J41405P`=01D;300B20T05`d>00h41@0=0`@050X;01882@0A1`P00P0E2``0400D2P/0
4`T:01882@0A1`P05`d>01061`0A1`P05P`=01<92P0@1PL04PH803L[;@0J3Q0060`>01D92`0?1@H6
0186200D038X:@0e:b`04`T:01061`0=0`@05P`=01061`1FC4d05P`=01T?400<10@06Q0A00`00P0J
3Q00:1`N01L;3@0A1@L060`>0186200C1`T201D92`0901<72@0B1PP060`@01862P0K3a<06@dA00l3
1`0H31004@D900804`L;00l04@D901862P0C1`/03`<70104200A1@T03`<70104200G2`l05@T=00P0
000@10P06PhB01`@500>0PH00P0D20X01@0B1PP040@601451`0C1`T03@4300805@T;02d02`0101@8
2P0D20X06@d?00P0000900005`/=01041P0C1`T05@T;00P0000O4aD02P010186200F2P`04`L;00/0
0`0A1@T04PH:01@8300L41@05PX>01@8300;00<04`L;01452@0C1`X03@4301T=3`0B1PP03`<501P<
3P0>10D04PH801451`0@10H04PH801<72@0D20/04`L;0104200B1PX03@4501dA5@0@1@P00P0D20`0
100C1`/04PH:01862P0A1@P201041P0401451`0B1PP04PH8018620D04@D700<04@D60146100A1P@0
0`0A1P@03`0<0@0040D301@91`0@1@<03P<101050`0;0000710@03HZ:P0A1@D02`0001451@080000
5@T901H:2P0201P<300I00h20P0F2P`03`<501451`0D20X03P840186200<00805PX<01D92`0;0040
5PX<00h2100C1`T05@T;01451`0:00004`L901H:300A1@L060`>00T0000E2@/03@4301D92`060145
1`0600P0000K3a4040@601H:300E2@/03P845?ooool001_ooooo100A1P`06`0C20h050T?01<83P0I
3Q@03P<902DJ800o=3X04`P<01H;3`0@1PL05P`=01<92P0>10D0718C01T?400@1PL06Q0A00l51P0A
1`P05@/<01061`0B20T04`T:01@:2`0B20T04@L801D;300201@:2`0A01D;300F30d05`d>00h2100A
1@L04`L901@82P0E2@/05PX<00h2100C1`T05`/=0186200@10H05@T;00h41@0A1`P00P0B20T00`0C
2@X050X;01061`020147200?01<92P0B20T040H401050`0?10804@H401D:200M4A407a<C01H:2P0D
20X05@T;01@82P0A1@L04PH7008050P800d04`L701@8200D20P060`<01T=3@0?0`<04@D501H:2P0B
1PH050T901H<3@0C2@X03P@500806a4B00/04`T:01`B4`0H3Pl05Ph>07meMP1hKVl04`P;00d21P0A
1PX060dA01462P0300l4200=01872`0@1@T0714E01T>4P0@1@/03047024F700D2@l01`0201/@5P0F
2a405@X@01@93`0201H;4@0>01D:400H3A405@X>01872`0D2@d05@X>01872`0F2`l06a0D00l6201i
KW80Uhb@03/a=00C2P/201<=3@03018<300E3`l050h>00804`d=0P0D3Ph201D?3`08018<300C3@d0
50h>01H@400J51@071HF014;2`0G4A4201/E5@806A<C0P0K5aH301XF5@0401TE500B3Pd07ATH01lK
6P808QhM02006QHE01/E5@0O6QT06ADD01XF5@0P7Q`071/I01dL6P0T92808R8P01/K6@0L71X051@B
020L7@0S8B807A/L01`J6`0N7Qh071`L02<S8`0O8B0071hM024S8P0J7Qd082@S01lO7`0T92@08b<S
01lO7`0S9B@0:2XY028T8`809BTX00D09b/Z02H/:P0Q9bD08R/Z02D^;@0202L`;`0_02P`<P0Z<S@0
:c<f02`d=`0a>Cd0<cY002lf?00Z<cD0=3hm02hh>@0S;Rl0<Sdo02`g>`0c?d@0;ca203m>E@0jB500
>DM@02lmB00gAD/0>DM803Q6B@0d@DL0?4UA041<F012CU`0?4QH049=H@1BGG<0EEmh059LM`1]NHX0
@4mD03a;D00mC540@U5F04=BE`12DEH0@e9G045@E@17EU/0?diC04QGG011D5D0?TeB03e<D@11D5D0
0P15E5T01P0oCU<0CUeR04QGG017EU/0AUEJ04]JG`80AeIK00/0C5]P04eLH@19F5d0BeYO05ETJ@2N
[K80]<?7051OI01<Ff00EFAX04mNH@0204mOG`06055QH@1DI6@0F6QX05EUI@1DI6@0EFEU0P1GIfL0
2`1DI6@0DV5T05MVJ@1CHVD0DV5T05QXJ@1JJVX0G6a/05e]K@1NKVh0H71`0080HW9b00@0IG=d06Qf
M`1ULg@0IWAe0P1/NW/03`1SLG80IWAe06AbL`1TLW<0J7Ig06IdM@1_NW`0Ig9d06ehNP1_NW`0JGAf
06iiN`1[MWP0JWEg06agN@0206mjO01?06YeM`1WLWH0JgIj06ehO01YM7H0IG1b06A_L@1MJFT0GFUW
05aXIP1KIfD0FFES05QTHP1KIVL0GVU[05YUI`1KIVP0HVe_06=^L01TKg40GFQZ05MRI01DGf40DeiP
05AOH@1FI6D0D5iQ05ESIP1>Ff40C5UQ05ISJ`1BGfL0CU]Q051MH`1>G5l0BUQI04]IFP1;EU`0CeYP
04aGG@1<Ee/0DUeQ04IAE012CDl0AU9B03i:BP0f@T80?DU904IAD@1BFU`0CEEG03e5A`0e?Cl0=3`n
03Dm?`0_=cT0:C4c02/c=@0]=CL0;cLi03Hm@P0k@TX0=d17038lA00i@d`0?4I?03]5CP0e@4H0<CY1
038h?@0/<3<0;c0b03Lh>@0e=cH0<38a02X/:`0Y:bX0:R`[02LY:00202HX9`0C01lQ800M7ah092HU
02PX:00S8b<09BDU02XZ:P0V9RH08R8R02HV9P0P82008B4Q01dM7@0V9RH0:2PX01dN800[;2h0824S
01/L8002038c=`08051AEP0T9BX0>CXo02HV;P0K6b<092@[02XY;P0X9b`202HU:P0F02DT:@0R8BH0
92<X02@S:00I61d08R4V024P9@0O7R<0:bX`01@C6@0N7B804A0E01HF6@0P828071`N01/K700J6QX0
6a/K01XJ6P0F5QH07A/N01`J7@806QPK0P0K6A`01P0J61/071XM01dK7P0M6ah071XM01XH6`805aDH
00@071XM01HD5`0K6A`02@L:0P0H5QT0400D4QD04@lB01HD5`0N71l07QXK01dI6P0E4A806QHG024M
7P0A3@h061@E01<?400O6a`0:bLX010<3@0/:2T201LC4P0501DA400F4Q4071PG020L6`0J5QD00P0G
4a802@0I5A@061@C01LC4P0V82005a4A01TC4`0G4A407ALG01@>3P0201LA4@0F01H@400D3Ph04`d=
01@>400J4AL0>2ld034X;@0O5Q/0;2<V0558B`0D2`h04`X;01@;300G3Pl06A4?01`C4`0J414050X;
01X@4@0=0`@060h?01D;30804PP901d05P`=00l51P0?1@H060h?01L=3P0D2P/03`D601061`0E2``0
5P`=01882@0@1PL04`T:01`B4`0H3Pl040H702dS9017?Ch07Q@E00`20`0J41406@l@01061`0I3a00
4@L801061`0K4A807A<D01T?400201@:2`0801<92P0?1@H03`D601882@0E2``04@L801061`0B20T2
01451`804`L901@050P:01D92`0?0`D04`L901D92`0A1@L04PH801D92`0F30d01`0001882@0=0`@0
2`420147200C2@X0DdU:024G600D2P/040H701@:2`H04PH80P0?0`D0200G2`d06@d?0186200>0P@0
5PX>01@8300B1PX04@D90P0@10P05P0F2Ph04`L;0104200D20`05PX>00X00P0<00@0GE5E01lC5`0D
20`040H801452@0G2`l040@800`0100E2@d03P8601@8300L41802000028F600?1@H201451`0701P<
3P0<00804`L900X00@0O4aD03`<501041P030186200401041P0?0`D04@D700h2108050P:00<04@D7
01<72@0C1`/01@0C1`/08`0?0`L03@4501@8300N4QH05`/?00l31P0C1`T040@600d20`0I3@l05PX<
00d10`0C1`T0300201P<3P0:00004`L90145200<00@03`<701T=4@0=0@D05PX>00h31P0D20`05PX>
01D93@0B1PX04@D901hB5@0H30h03@4301H:300D20X03P8400H040@600h03@8303@X:01<@4003000
00d10@0H30`04`L700P0000@10@04@D500l30`0>0P803`<3010410804@D50P0@10@04P0<00004`L7
00l30`0D20P0300000l51@0E2@/03P840186200C1`T0300201<72@0D20X04PH800l31@0@10H04@D7
018620804`L900L04PH801041P0A1@L050P:01041P0C1`T04PH800803`<500<04PH801451`0A1@L0
0P0B1PP201<72@0601H:300?0`D02`01024E5`0@10H06Ph@5?ooool001_ooooo0P0C20h01@0B1`d0
4`P>01D:400E2Q0050T?008040D;02T05@X@01@:3`0<0PD0714E01@:2`0G3@h05P`=0147200H3Pl0
?C<d01492@0<0`<050X;01L=3P0?1`L04@L801882@0C2@X050X;01<92P0B20T07aDF01/A4P0G3@h0
4`T:01061`0?1@H07Q8D02PL7P0H30h04PH801L;3@0?0`D04`L900l31@0C1`T050P:01451`0B1PP0
4PP901<92P0501@:2`0A01882@0A1`P04PP901<92P0C20T05`/:01451P0F2`/05@/<01T=3P0S5aP0
50P90186200C1`T05@T;01@82P0E2@X00P0E2@T0100D20P05@T901D92@0C1`L201L;2`0T020D500O
4a<04`L701@92@0@1PH03`D501H<300B20P040H601<92@0<0P<05P`<01@:2P0P5QL0:1hN01472@0J
3a<050T=01D:3P0S61`05P`?01@93@0B1`/04`P<01462P0O51P08AHJ01T>500L4AL04@H<01`A5`0I
3Q@0IeaR01H;4@0E2Q0050T?0P0F2a40400E2Q0060dA01H;3`0D2@d05@X>01H;3`0D2@d03@@601`A
5@0E2Ph0714E028G6`0F30l04`X;018<300C3@d201@>3P<04`d=0P0D3Ph201D?3`0:01<=3@0D3Ph0
50h>01H@400I4a<06aDE01TC4`0F410050h>01H@4080618B034061@C01XF5@0J5QD06aLF01XF5@0I
5A@0510?01PD4`0Q7A`06QHE01dI600K5aH06Q@E01hI6P0M6AT07QXJ020M7@0K6AT0:RPX01dM700G
5aH08B4P02h^;@1IFEP08AdM02<Q8@0O7Ad07QdL020P7`0N7Qd0820O01dO7@0K7A/08R@R01`P7P0R
9b@0;bl_02<S8`0P820092@T02<U900Q8b8092HU02DY:00S9bH09RXY02H/:P0S:BL09Rl^0080:C8a
00H0:34`02Xb=00[<cD0;CDh02/c=P0]=CT2030g?@0M03<l?P0oBDP0;cTj02hh>P0jADL0>4=7049>
D`0lBDl0B5MN03I4C00jB540<d5<03I3B`0fA4P0>4E:03]8C`10CEH0?DUE03]7E@1;EfL0EF1b04QC
J01JI7`0BUE/04ICH@0lBe00=dI;03Q7C00nCE800P0oCU<04010Ce@0?DaA04ACF013DUL0DV5V049A
EP10Ce@0@E1E04ACF015E5T0A5=H049AEP1=G640B5ML04IEFP18Ee`204]JG`0>04UHG@1:FEh0BEQM
04EDF@19F5d0E6=X065`M@1_OX<0DF1U05YYKP1@Gf<0E6=V05=SH`1BHV82055QH@0405ATI01AHF40
E6AT05IVIP80DF5Q01X0EfMW055PH`1GIVX0EfIZ05QWJP1HJ6X0DV5S05a/K01MKFd0GVi^05m_K`1Q
LG40HW9a061_K`1TLg@0HW5b06AcL`1YN7P0IWEf06]jN`1/Ng/0IWEe06EdM01YN7P0IgEf06]fN080
KGQj0P1[MWP03P1/MgT0JWEg06UdMP1ZMGL0K7Mi06]fN01WLW@0J7=g06UdN01XLgL0I6ma05mZK01N
JF/0Gf][0P1NJVP06@1MJFL0FfMU05YVI01OJV`0FFAV05YUI`1VLG<0I6ma05]VJ01OJV`0GFQZ05]V
J01FHF<0D5]M04iIF`1?GEh0CE]N04ABE@1JIfd0HVmg04eJHP1<FF40BUMM04eJH01<FUd00P16E5D0
3P16DEL0BUEK04YEF`16DED0B5=G03m:C@0mB4X0?TY:03U5A@12CTh0BeMG045;C00nATP0?DE70P0f
?T00700h@480=Cdo02/c=@0V;S00:30b02Ta<`0Z<S@0<CPm03U0B@0l@d`0<S]3030j@P0b?D@0=Cm5
038l?`0a>3d0<CHi02X];P0Y:B/0;2`/030a<00d=C@0<c@d02h_;P0[;2`0:BXZ02X[:P0Y:RX202<T
900602TZ:P0b<S80;Bd]02LW9`0Z:RX0:BTY0P0P82004P0M7Ad08B4Q01HF5P0L71`0;2`/02TZ;00Y
:Rd0;2d`024R9P0L7B40<S<g06AUJP0_<3D0:2P_020P:00X:3008b</02@S:@808b8W0P0T8bP00`0Q
82D071/P02HU:P02028Q9P0@02<R9`0P7b@07ahT02DT:P0H5a`05QDJ01`L7`0K6ad071`N01XJ6`0I
6AT06QXJ01/K6`0J6QX07Q`O01dK7P@06QPK00<05aDH01TG6P0I5aX00P0I5aX06@0G5AP06ALJ01/I
700P7R406ALJ01<A500F51L05aDH01HD5`0D4QD05A<F01LE600I5aX05a<E01HB500K5aT05a8E01DA
4`0E41<06aHI01D@4`0G4aD0920R01LC5@0[9bP00P0H51<01P0G4a805A4@01LC4P0I5A@05A4@01HB
4@8061@C02@0510?010<2`0F410071HF02PR8P0G4A4050h>01H@400G4A404P`<01D?3`0J51@06A<C
01D?4@0J41L05`hC01/B5`0G3Q<04PT<01L>4@0L4aH08QTJ01lF5`0F3@h04`/901D<2`0T6Q/05`d>
01X@4@0F30d06@l@01H<3@0K4A807Q@E01T?400D2P/201T?400<01@:2`0G3@h06@l@01D;300B20T0
40H701L=3P0M4a@060h?01@:2`0B20T03`H60P0D2P/05@0@1PL060h?01H<3@0D2P/03P@501882@0J
4140:b4R01X@4@0F30d050X;01882@0C2@X050X;01<92P0@1PL04PP901@:2`0B20T04@L801882@03
01@82P804`L901004PH801451`0C1`T050P:01451`0B1PP05@T;0106200@1@P04PT:01@:300>10H0
6@hA01/@4`0K4A<030840P0D2P`00`0B1`X04PH8018620040186200601T=3`0C1`T04`L901@82P0A
1@L04`L90P0C1`/08`0A1@T040@801452@0A1@T04`L;028F6P0J3Q80300400d21@0G2`l050T<04Pl
@00Q5aT03`<700h41P0F30h04@D901@8300J3Q807a<G00h21P0?0`L06@h?00h41@0E2@/06Ph@00h4
1@0L41806Pl@0147200I3@l050X;00d3100@10H04@D600<04`L80P0A1@H01P0@10D03`<401@82@0E
2@X040@501451`H04`L;0P0B1PX07@0E2@d06PhB01H:3P0C1`X05`/=01@82P0B1PP0710B01X>400H
30h05PX<01451`0?0`D03`D601041P0F2Pd04PH:00l51`0>0`H06`lC01<72`0B1PX050P<01D93@0C
1`/04@D901862P0Q5AP07Q8D00804PH80P0>0`@60186200901041P0S5aP0<bPY00h20`0>0`<04`P9
02DI6P0F2P/050P900803P<400<04`L80104100@10@00`0A1@D03@0@10@050P800T0000B1PH03@<3
01451@0E2PX03P@500h2100O4aD08aLI01H;300?10D00`0A1@L00`0B1PP04@D701451`0201041P80
4@D700T04`L901@82P0>0P@050P:01H:300D20X040@600l31@0@10H00P0A1@L30186200600h2100E
2@/0710B02hR900E2@/04PH85?ooool001_ooooo00@05@X@01@93`0C20h04`P>0P0E2Q004`0H3A<0
50T?01T>500E2Q003P<901`A5@0J3a<040H701882@0D2P/040H70147200900004`T:020F5`0=10@0
3`D601<92P0A1`P00P0B20T301<92P8040H700`04@L801@:2`0F30d05`d>01T=3`0Q5AL05@T;0186
200F2P`040@601H:300C1`T201L;3@0F0186200A1@L050X;01<92P0D2P/05@/<01<92P0A1`P04`T:
01882@0D2P/04@L801061`0B1`T07A4C01X>400K3a402P0000`00P0W6ad06@d?01D92`<04PH800d0
4PH701<71`0B1PH04@D501861P0C1`L060`<024E5@0K3`l0710@01/?3`0C1`L05P/:00804@L601h0
5P`;01881`0B20L05@/:00h40`0E2`X04@L601<9200I3`h03`D601D:3P0=0PH081DI03db=P0]8RH0
50T=01462P0D2@d04@H:01`A5@0Q5QX03P<901P=4`0G31806PlE00L00P0O51X05P/A01D:400D2@l2
01H;4@0301D:400H3A405``@00@05P/?00`0714E00l4200H3A4060dA01hC5`0I3a805@`=014;2`0D
3Ph05@l?018<300D3Ph201<=3@8050h>0P0E3`l201@>3P0A01D?3`0F4100618B01TC4`0L5QH06Q@D
01/E5@0N61P06A<C00h8200E4A0061@C01XF5@0K5aH06QHE01PD4`0Y9B@00P0O6aX02P0?2`X071PG
02LS8P0O6A/081/M020L7@0Q7Ah08QlP020N7`0W9BH201dM7@0401/K6`0N7Qh0:b/[024M708081lM
00X08B0N024Q7`0Q8Al0820N01dO700K7AX08R@Q01`Q7@0S:2@0:b/[0P0O7al02`0W9bL09RPW024S
8P0S9B@08RHU01lS8P0R9RD092XX024W9@0T;B`09Rl^00809c0_02/0:C4c02/c=@0/=3L0;3@g02de
>@0_=S`0<3Lm02hg>@0g@D009c4b03I0@P0_>S`0;CPl03A0A@0a?T@0>dYA02Xi@@0mBe@0=TA?038o
B00a?T@0;ca4030mA@0jAe00@dmK05UUL`1NJWX0GfYl05EPL`1AG700F6=i055MJ`0nCE80>DQ=03Y9
CP10Ce@0@E1E03m>D`0nCE80>dY?049AEP11D5D0D5mT0080AEAI01T0AeIK04UHG@18Ee`0AUEJ04MF
F`1>GF80B5ML04=BE`17EU/0AUEJ04eLH@1:FEh0B5ML04MFF`15E5T0BeYO051OI018Ee`0DV5V04]J
G`1GIV/0DV5U05IUJ01EIFD0DV9R0080D61P01@0DF5Q04mOG`1CHf<0EFEU051PH01?Gel0E6AU05IU
JP1GIV/0E6=X05MVJ@1LJfh0F6MZ05YZJP1LK6`0GFe/05i^K@1PL6l0HG5`05i^KP80I7Ad0100IWIf
06UiN@1UMGD0IgMg06YjNP1VMWH0IGEe06IfMP1QLG40KGQj07R3Q@1^NG/0Ig9d06]fN01XLgD0JWEg
101YM7H02@1WLW@0JWEi06MbMP1SKW80H6]]05]VJ01II6H0Gf][05eYI`0305aXIP0605aXJ01MJ6X0
HVe_05aWJ@1FHF<0FFAV0`1KIVP02`1JIFL0EF1R04iIF`1;EUP0AeEF05ESIP1RL7<0D5eS04]HH01N
Jg<0DEiV0080BUMM02L0AUAG045?D012D540@diD04A?E@15D5H0?4M;03m:CP0nBD`0?TU;041<C00h
A4@0?4Q8049>CP0kA4D0?DE703a4AP0g?d40>D5303Y2A00c>cd0:30b02H^<00W;c409Bd_02L_<@0`
=S`0>Ce803Y1B`0d?4D0;CHm02Xe>`0]=cX0;CLh02/c=@0Y;Rh09BHX02@T900Z:RX00P0b<S805`0/
;2`09RHV02LW9`0Z:RX0:BTY02PX:00T92@09BDU02/[:`0a<C40;Rh^02HV9P0S8b<09RHV02@T900L
71`06a/K02h^;P0X:2P07alO01hN7P0^;c<0;c0d0080:2T]02@0<S<g03dn@`0H6Ah06Q/P038b>P0K
6b<07alW02HV;`0S8RP08R4V024P9@0P7b@07ahS01XI7P0N7B807A`Q01hM8P0F5AX06aXO02LV:`0Q
82H07A`R02<R9`0/:c0051<G028R900L71h061PI01HF5P0I6AT071`L01dM7@0N71l07A/N01XH6`0I
5aX201PF6@0301HD5`0G5AP05aDH00805aDH00X05Q@G01<A500E4aH030X=01/I700G5AP04@lB01DC
5P0B41<04a4D0P0G5AP03P0B41<05A0D01lJ7P0?2Ph061<G014<400H4aL06aHJ01LB5P0>2@d04`hB
00d8300D4140510@0P0G4a800`0E4A00510?01DA400201LC4P0O01PD4`0I5A@05A4@01<?3P0J51@0
4@/;01D?3`0F410081XJ01XD500G4A404`d=01D?3`0I4a<0618B01H@4P0K4QP03PD:01dD6@0W7R<0
7A@G01P?4P0K4QD08aXK02HM7P0N5AH06Q8@01081`0S6AX0308300d51@0201@:2`0501`B4`0Y7b00
:AlP01L=3P0C2@X00P0D2P/05P0F30d05@/<01H<3@0F30d05@/<01882@0K4A808ALH01P>3`0A1`P0
4PP901L=3P0N51D050X;01D;300C2@X05@/<01T?400@1PL04PP901/A4P0Z824201882@070147200@
1PL04PP901<92P0D2P/04@L801882@0201<92P804PP90`0D20X0100C1`T04PH80186200C1`T20186
200?01<72@0A1@L050P:01L<400=0PH09a`P00h31`0@1@T081DI00d21P0?1PP08aPL01P=4@0@1@T0
4PL;00H04PH800<07A4C01@82P0B1PP00P0B1PP00`0F2P`04@D901452@020104200P01452@0B1PX0
3P8600/10`0:00804`L;01L;3`0:00804@D901H:3P0A1@T05@T=01/?4`0B1PX050P<01862P0A1@T0
5`/?00h21P0D20`03@<400d10`0A1@L02000030T9P3Fb/`0FdmA00d10`0K3a403P@501dA4`080006
0104100601<71`0D20P060`<01T=3@0E2@T04`L71P0B1PX00`0@10P04@D90104200200l31`0D00l3
1P0@10H03`<500h2100D20X04`L900`10P0:00006Ph@00l41@0<0080200001<72P0I3A403@4501dA
5@0800006@dA01862P0A1@T301862P0801@8300A1PP02P0000h2100G2`d050P:0186200C1`T50186
200301@82P0C1`T06@h?008050P:00L03`<501041P0<00805PX<01<72@0@10H03083008040@40P0B
1PH05@0A1@D040@400T0000C1`L07Q8B00h20P0K3`l040@401@82P0@10H03`<500h2100;00404`L9
00l31@0@10H04`L90186200A1@L040@60186200401451`0700h2100C1`T05PX<01T=3`0H30h050P:
01451`0401@82P805@T;00H05`/=00l41@0800004`L901041P0J3Q0Dooooo`006oooool201D:4080
4`P>00@050T?01D:400A1P`04`P>0P0A1P`02@0E2Q006@hB01D:3P0?1@H04@L801@:2`0B20T04@L8
02@J6`0201@:2`030147200E2``03`D600<04@L800@04PP901<92P0C2@X05`d>1@0E2``04@0B1PP0
40@601@82P0E2@/04PH801@82P0H30h07A4C028F600L41805@T;01L;3@0C2@X04@L801882@0D2P/0
4PP9008040H700h04PP901L=3P0A1`P03P@501<82`0E2@d04PH:01H:3@0800005PX<02lS9@0J3Q00
5PX<01<720@050P80`0C1`L03P0D20P05PX:01X>3P0B1PH04@D50104100;00005@X901dC4P0J40l0
4@L601D;2P0G3@`04PP70P0?1@@0600@1PD06a4@01`B4@0@1@L05``@01<8300:00<06@hB03`a=@0B
1`/03`@801H;3`0A1PX05``@01T>4P0B1`d03@8801H;4@0C20h04@H<01@93`0F2a405@X@01@93`80
5P/A01805@X@01H;3`0F2`l05P/?01D:3P0F2`l060dA01872`0700006PlC01052@0B1`/04PP;01D<
3@0?2@T040X:018<300>20P301<=3@8050h>1P0E3`l201PB4P0403`f=P0W8B405Q0@01D?3`806A<C
00<05A4@01LC4P0J5QD00P0K5aH01@0J5QD04Ph=01/G5P0Q7A`06ADD00806aLF05D08A/M01hI6`0N
6Q/07a/L020M7P0R82406aTJ01DE5@0N7Qh06QXJ034a<@071`L081`K01hM6`0P7ad08R4O024Q7`0R
8R0092@R020R7`0M7a`08R@Q01/P700Q9R808B4Q01lO7`0Q8B409BDU02@V9@0R92<09RPW02DY:00Q
9B@092PW02D[:@0S:BL0:34`02Tb<@0Z<c80:c@c02lg>@0b>S`0:c<f02lg>P0a>3d0<3Lm02lf?00[
=3H0=d50034k?012CDh0:C@f02Pc=`0/>3d0<d1603a;DP0c@DT0C5YS041>F@0gADl0>DI>03M4C@0d
@DX0>TIB04QDHP2DX:h0RiNU04]GI`1;EVP0Ef9d04aGJ`0lBED0@4mB03a;CP0nCE00@U5D04=BE@0o
CU40@4mB03e<C`12DE@0?4]>04IEF013DUL0AEAI0080B5ML00<0AeIK04IEFP16EEX00P1>GF801016
EEX0C5]P04YIGP1<Ff0204UHG@80B5ML00d0DF1U04aKH01?GV<0E6=X04QGG01GIV/0DF1T05ASIP1C
Hf<0DF5Q051PH01AHF40Df=S0080EFEU0140EfMW05QXJ01GIfL0E6AU059QIP1HIfd0FVU^05e/L@1P
Kg<0FVU/05UYJ@1KJfX0G6a[05e]K01OKf`0H71_05][J`02061`L004069bLP1UMGD0HG5a06EeM@80
KGem00/0K7al06]kN`1SLg<0Hfi`06mjO01WLW@0HFa^06E`LP1TKg40JGAf06YeM`0306UdMP0906Ye
M`1[MWX0IW5e069]L@1QK6h0GFQZ05YUI`1MJFT0FfMU0080FVIT02P0FfMU05aXJ01NK6h0HW1c05YX
J`1DHVD0FVQ[05i/K`1IIfX0EVAW05ARI@1@GV40C5YM04]IG016E5D0>4I904IDE`19EU`0OHZB0;g:
dP1?G6@0AE9H04=@EP11Ce80@Dm@04ABD`13CU@0BUEK059MH`14Ce<0?DQ<03]6B@0kATP0@De=03Y6
AP0d@400=d=303Ho@@0m@TD0>d130P0e>Sd0500c>3/0;S<f02X_<P0Z;c80;34d02T^<@0Z;c80=SY2
03/oB`0h?TX0>T9:03DnA@0^=c`0;cTk034k?00]=CL0:2d^02T[:P0/;2`0;Rh^0P0a<C403@0/;2`0
9bLW02PX:00Y:BT09RHV02<S8`0R8R8092@T02/[:`0V9RH0:2PX02`/;00[:b/00P0W9bL0;@0f=SH0
7AdM01PH600I6AT071`L02TY:@0[;3006Q/O02@U:@0Y:Rl08b@Y065RI`0`<3P0:2P`02LW;`0M7BL0
:b/e02HV;`0H5ad06APM01dL8@0R8BH092<X028Q9P0U92T06APM024P9@0H5a`06APM02<R9`0G5Q`0
6aXO00l>4`0C4QL06QXM01LG6@0L71h061PI01HF5P0I6AT071`L01dM7@0M6ah071XM01TG6P0401PF
6@@05aDH00X061HI01HD5`0I5aX0518E02HT9`0@3Q408R0S01XH6`0H5QT06QPK0P0M6ah04P0H5QT0
4`hB01TD600L5a/04PdA020K7`0H4aL05Q4E01/F6P0E41@061<G01LB5P0H51D04@d=01HB4@0G4a80
5Q8A01DA40805Q8A00<04Ph=014=300C3`h00P0C3`h0900Z92@09b4Q01`F5P0G4A407QPH00d71`0F
41006A<C01LA4@0C3@d050h>01H@4P0F31808AHL01`A5`1LDEL0;R<W01462P0D2@d05P`=01`B4`0M
4a@060h=02TO7`1DBT/0<RPY01dC500E2``03`D601@:2`0M4a@06a4B01@:2`0K4A806Q0A01<92P80
4@L800H04`T:01D;300C2@X04PP901T?400J414201D;300:01H<3@0B20T05P`=0147200F30d04PP9
01L=3P0H3Pl02`4201882@804`T:00@03P@501<92P0C2@X04PP90P0A1`P00`0C2@X04PP901882@03
01<92P0301882@0B1PP04PH800804`L90P0D20X04P0E2@/04@D701@82P0F2P`04PH801<72@0;00@0
6PlC08=hO00U6Qh02`0401D:3P07000060dA02/P900D2@d04@H:01052@H04PH800H060`>0186200C
1`T05@T;01@82P0F2P`201452@8040@80P0B1PX07P0A1@T09ATM028F6P0D20`040@801L;3`080000
5@T=01T=4@0;00<02`430104200D20`04@D900`0100B1PX03P8601L;3`0C1`T08ADG02dQ8`0U6A/0
200006MKG@0o<cD02@000186200M4A<04@D701@82P804PH600X04@D501861P0B1PH04PH601451@0B
1PH04`L701H:2P0C1`L040@41P0B1PX00`0C1`/050P<01<72`0201452@0401862@0B1PP04PH80186
20805@T;01T04`L90186200F2P`04@D701@82P0B1PP04@D801T=4@0B1PX0304401L;3`0;00<05PX>
01@8300B1PX03@8500/00`0<00@05@T<01D92`0A1@L040@600l31@0D20X05@T;00D040@600L04PH8
00X0000=0`@04@D70186200;0@80710B00805@T;00D0300201041P0D20X040@401451@0301861P0D
01451@0D20P040@400P0000Q5AD040@401471`0=0@<040@601P<3P0I3@l04`L901041P0>0P@04@D7
01@82P0B1PP040@601451`0B1PP201041P040186200C1`T040@601D92`@050P:00<04PH801D92`0E
2@/0100D20X01P0?0`D04`L901H:300K3a404`L9018621Cooooo000Kooooo`805@X@00/04`P>0187
3@0C20h04`P>0146300C20h03P<900l42P0F2a4040D901<8300501@:2`0701H<3@0B20T05P`=01<9
2P0G3@h040H701882@020147200701882@0C2@X050X;01<92P0B20T04@L801882@0201<92P0B01D9
2`0?0`D05PX<01L;3@0A1@L050P:01451`0E2@/06Ph@01D92`0@10H050P:01<92P0@1PL04PP901L=
3P0D2P/04@L80P0B20T03@0H3Pl04PP901882@0T6A/040@801H:3P0X71l04`T:0147200F2P`04`L9
0186200D20T0100G2`/301H:2P0401L;2`0B1PH05@T901861P8050P800L03`<301L<300Q5aD081HD
01D;2@0D2PT050X800804`T801T04PP601H<2P0>10803P@201L=3@0A1PX05``@01T>4P0B1`/05P`?
01<8300?10P05``@01462P0D2@d06@hB01P=4`0@1@/05P/A01D:400K41H04@L<01H;4@0E2Q0050T?
00805P/A00@05@X@01<8300E2Ph05P/?0P0D2@d00`0G31006@hB00l4200201H;3`08020E6@0K4AD0
8QTJ01LA4@0F41005a4A01@>3P0N61P201<=3@8050h>0P0E3`l201LA4@805@l?0P0G4A401P0M5aL0
6Q@D01LA4@0I4a<06Q@D01TC4`8061@C00L06ADD01/G5P0N6QT081`K051<B`1ACD`07a/J008081`K
01808AdL01lI6`0L5aT081`M024M7P0N6a`081hO028P8@0F5QH08R8R02DU9@1JFUX09RHV01hJ6@0J
6AH07ahK028Q7P0Q8Ah2028S7`0701lQ7@0L7QX08B<O01XO6P0P9B408B4Q02<S8`0202@T90808bDT
00H0:R`[02X^;@0X;2/0:Rh]02T_;@0U:bT202Tb<@0702Pa<00Y<S40;3@f030h>P0]=CP0<SXm03<k
?`02034h?P0V038k?@0c?C`0;CLh03M1@`0lAdT0NHB805MSJ00f@dT0?TeD03Q6CP16E5d0?4YE03U6
DP0jAU40?4QE03m;F00lB5D0?TYH041<FP1NJWP0EF5`049>G@0lB5L0B5=T04=@FP0oCU40?Da?045@
D`14DeH0@E1C03m>D@11D5<0?Da?045@D`0hAdX0@E1C041?E012DEH204ACF00604=BE`16EEX0?4]@
04QGG01CHVL0AEAI0`1;FUl03@19F5d0BUUN04YIGP1:FEh0DV5V04aKH01@Gf@0C5]P04eLH@1HIf`0
CEaP05ASIP1CHf<00P1AHF40701BHV80E6AT04iNGP1>GUh0D61P05=SH`1FIVH0EfMX04]JG`1LJg40
HW5g061_M01MK700EfIY05UYJ@1JJVT0Ff]Z05a/J@1NKV/0Gfm/061`L01TM7@0HW9b06=cL`1XN7P0
IWIf06=cL`1YNGT206QhN00906MgM`1PL700HVe_06A_L@1UL780I6ma06IaL`1XLgD0IW5c0080J7=e
0180Ig9d06UdMP1]N7X0JWEi069]L@1OJVh0HVe_061[K@1NJF/0GFUY05]WI@1JIV@0FfMU05aXIP1M
JFT0FfU[05QVJ@1EHfH205]YK00505ARI@1GIFP0Df5T051NH@1=Feh00P1<FUd0A`1?GEh0CUaO051N
H@1;F5h0AU=K04UFGP11CUH0>dQ>03e:D010CU40@U1A04IDE@12CE<0D5]Q061[L@1<Ee/0?TU=04QC
EP0lAdT0=d=303U5A@0`?3`0=41003M0@@0h?D00=CXm03<h>`0e>Sd0<SLj02/`<`0Z;c80;C8e030e
>00]<SD0;S<f03PlA00e>4L0<cQ403U1BP0d?D80;CHk02Tc=@0Y<c80:2h^02<W9P0Y:bX0;Rh^02`[
;00Y:BT0:b/[02l_;`0^;Rh0:RXZ02LW9`0V9RH08R8R02<S8`0W9bL0;Bd]02`/;00O7al09bLW02h^
;P0Q8B409RHV071`L011@D408b<S024Q8@0P820092@T00<08b@X0P0T9BX07`0R8bT08b<[020P:00P
82T0820Z02TY<`0L72D081lU01lN8`0Q82D08b8W028Q9P0L6b007QdR01HE6P0Q82D061LL03He>P0L
6b0071/Q01/J801QH6D0>STn01dL800J6Q`071`N01XJ6`0I6AT06QXJ01/K6`0J6QX00P0J61/0100I
5aX061HI01XH6`0J61/201TG6P805aDH0P0I5aX01`0H5QT0EE=F01HD5`0M6ah06QPK018@4`0E4aH0
0`0F51L201LE600b04@oA00S7R<061<H01hI7P0>2Ph06A@I01PC600N6Ah07APM01D@5@0D3a@04`hB
018>3P0F4Q405a<B01HB4@0G4a8061@C01/G5P0E4A00510?01HB4@0H51<05a<B01/E5@0M5aL06aDE
01D?3`0L5QH050h>01H@400J51@0618B018<300D3Ph0618D01H;4P0L4AL04`P>02LL8P0?1PP07a@H
01T>4P0E2``060h?01/A4P0H3Pd04`T901lE5P0?1@H201<92P0:01X@4@0I3a005P`=01882@0D2P/0
5`d>01H<3@0C2@X050X;01L=3P807Q@E00D05`d>01<92P0G3@h05@/<01<92P0201L=3P0=01H<3@0C
2@X040H701@:2`0F30d04@L801T?400?1@H05P`=01<92P0E2``05P`=01@:2`0201D;30804@L80P0C
2@X01@0A1`P04PP901@:2`0D2P/04@L800804PH80P0C1`T201@82P0B01P<3P0A1@L060`>01hB500E
2@/04PH800l5200=10H0I5UM02PM8@0G31003`@800d31P0@1`T05@X>00h31`0D2@d03`@81P0B1PP0
200F2P`04@D701<72@0E2@/04`L901@82P0E2@d050P<0`0B1PX0;00C1`/040@8020D600M4AD04PH:
01452@0F2Ph05@T=0105200D20`06`lC01D:3@0>0PH040@801<72`0D20`05PX>00d11@0D20`04`P:
01D;300?1@H0<bLY01P<3P0C1`T03`@601dA4`0<0080BCdo08YnP00P51H05PX:01D9200D20L05@T8
01D:2@0F2`X05@T801@9200B1PD05P/:01P<2`0D20P04@D81@0A1@T5010420030145200A1@L04PH8
00804PH800h04`L901051P0M4A<02@0001<72@0?1@H07a<E01872P0B1PX03`<7028F6P2FRXh0710D
01<72`<04PH:00D05`/?01dA5@0H30l03P8401041P0201<72@8040@61@0A1@L03P0B1PP04`L90188
2@0C1`T050P:01<82@0=0@<03@8301<72@0;004040@60186200A1@D04PH60P0C1`L201861P0701L;
2`0<0@4060d=069FEP0U6AT04`P801041P020186200@01061`0@1@H04PH800l31@0B1PP050P:00l3
1@0>0P@04`L901H:300B1PP03P8401<72@0G2`d05PX<01<72@8040@60P0A1@L0100>0P@04PH80186
200B1PP201451`0701041P0?1@H04PH801<72@0A1@L04PL90187200Dooooo`006oooool05`0D2A40
4`P?0146300A1Ph04@H=0146300A1Ph03P<:0146300B1`l040D<01873@0@1@T05@/<01<92P0?1@H0
3P@500l51P0>10D04`T:01P>3`0A1`P060h?00804`T:00d04@L801061`0B20T050X;01D;300H3Pl0
5@/<01<92P0A1`P040H700l51P0D20X06Ph@00804`L901X05PX<01451`0E2@/03P8401451`0F2P`0
5@T;01L;3@0D2P/040H701<92P0J414060h?01@:2`0G3@h04PP901H<3@0A1`P06@l@04<h>`0F2Ph0
200001X>4P0D20`0710D01041`804@D700<04`L901@8200B1PP00`0B1PH05`0A1@D04PH601861P0D
20P06Ph>01@8200A1@D04PH60104100E2PX040H401L=300P5Q@04PP601061@0C2@P05@/900h40`0=
10@060h<01@:2@0F30`05@X>008040D901404PL;01H;3`0G31004@H:01L<400B1`/05P/?028G700?
10X06@hD00`31`0I3Q@04`P>01P=4`0F2a405@X@01@93`0201H;4@0401D:400A1PX04`P<01D:3P80
4PL;01D05``@00/0100D2@d060dA01872`0I3Q805@X>02<J7@0E3`l04PX<01@;3P0B2P`07QPH01D<
3`0D3@h050h>01H=400F3a005@l?01PB4P0G4A400P0E3`l201H@400<01/E5@0J51@05Q0@01@>3P0G
4A406aDE01`F600I51@061@A01XF4`0P7AP0924L0P1iMW40C00P7AP0:BDR024M6P0L61L07ATJ020K
7`0[9bP0;2PY028O800O7Ah07ahM01LG5@0S8b406QXH02h^;00L6aT06QTF01HE4`0N7AT08R4O01lO
7@0R8R0071`J01TK600G6AH07R0M01/M6P0Q8b808b@V020Q8`0Q8R@09bPZ02X[;@0X;2d09RPZ02T]
;P0W:b`0:2`]02D[:`0Q9bL0<3Th02hg=P0[=3<0:C8a02/c=@0]=CL0<3Pk03<k?P0a>Cd0<3Lm03@k
@@0e?T00<Shn03Q2@`0`>cd09C0b06YeN@0oBe00;ca203Y9CP0`?dH0=4=:0390B@12CeP0>TA>03M1
C@14CUX0Ae5M04==F@10BUP0IW:004mKJ@19EF<0@dmM04A@GP10CUL2041?DP0L04IEF017EUT0@U5D
03m>D@10Ce80>TU<03i=D00jBD`0B5MJ04=BE@15E5L0AeIJ04EDF@16EEP0CEaP04MFF`1FIFP0I7=g
04aKH01>GF00C5]O04]JG@19F5/0BUUL04UHF`17EUT0C5]O051OI080DF1U01T0Df9W04aKH01CHVH0
EFAW05ATI01BHV80D61P051PG`1BHV40CEeL051PH01BHV80DF5Q05MVJ@1YN7/0EFAY05i]M01GIVd0
D5mT05ETJ@1MK6l0F6MZ05UYJ@1JJVT0G6a[0080GVi]00h0H71`06=bM01OKfl0HFmb06MfM`1VMWH0
KG]l06elO@1UMGD0I79c06IeM@1SLG80J7Ad05m[J`80I71`00<0G6QX05m[J`1QKFd00P1UL7804`1T
Kg40J7=e06iiN`1VLGD0GVU]05]VJP1QK6l0HVea061[K@1OJV`0G6QX05]WI`1LJ6P0GVYZ061/K01P
KVl0KG]n06MeMP1HIVT00P1CHF@08`1DHVD0DV1S051NH@1=Feh0BUQK04UGFP1:FE`0BeUL04aIG`16
DeT0@4]A03m:D010Be40?TU=04A?D`13DE@0@4i?045?DP15D5D0@diD04iIG@0mB4`0?TU=06IaL`1?
Fe/0<S`m03I0@@0[=CH0;cTj03Dm?@0c>CL0<SHe030e=@0b>3P0;c<f0080:2d`03@0;S8e038g>P0^
<cH0<CDh030c>P0W:CD0:R`h02hb>P0T;2l08BT[028[:`0U:bT092XX02<V9P0];Bl0;bla02l^;`0X
:2H0820P024Q800V9R@092@T02LW9P0Y:BL09BDT02LW9`0[:bT0<C4a05iNGP0`<C<06Q/M02LW:@0P
8B<0>3Tk07MfN`12@dD08R<U02<S9@0N7b408R8T020O900I6Qh0820T024P9@0H6Ad09RH[01hM8`0K
72408B4Y02`[<`0`<3P09bH^0P0Q82D05P0S8RL09B@Y02<R9`0M72407ahS028Q9P0O7R<05QDJ075`
M@0n?D8061LL028P9@1gMgT0928W01/J700E5AL07A/N01/J700J6QX071XK01/J6P0G5AH301PF6@05
01TG6P0K6A`071XM01TG6P0G5AP00P0E4aH07@0G5AP06ALJ014?4P0M6Qd03@/>03<^<P091PT07A/N
01<>4P0E4QD04a4D01<>4P0C41<06A@H01@?4`0]:2h06aHJ00h93P23OX805a8F018=4@0G4QH07QTM
01<>4P0H4aL071PI01LC4P0H51<05a<B00805A4@0P0G4a803P0E4A805Q8C01LC500E4A804`l@06eW
I`0K5AD0618B01LA4@0F41005@l?01H@400E3`l05Q0@0P0I4a<0=`0H4Q@05PdB0146300K4AL081LL
01`A5@0E2`h05`hA01P>3`0F3@h050/<01H<3@0G3@h05P`=01@:2`0N51D04@L801X@4@0D2P/04`T:
01@:2`0H3Pl040H701882@0I3a004PP900l51P0C2@X060h?01H<3@0B20T05P`=01T?400E2``050X;
01<92P0A1`P04PP901`B4`0?1@H03P@501P>3`0E2``04@L800l51P0@1PL081HG00h41@0B20T04`X;
01D<3@0B20T04@P901H=3P0C2@X00P0@1`P00`0D2P/050/<0147200201D92`0F01@82P0C1`T04PH8
01451`0H30h04PH801/?4@0S5aT060`>01451`0F2`l02`0401<8300G31004@H:01872`0A1PX03P<7
01L<400F2`l03P<701D:3PH04PH800X06Ph@0186200@10H04@D700l31@0B1PP060`@01H:3P0D20`0
4`L;0P0B1PX01@0I3A405PX>00l31`0B1PX060`@00805@T=00<040@800h21P0K3a<00P0D20`20186
2P060104200C1`/03@4501L;3@0a9BL020000P0F2P`0300800006@d?01H:3009000060`>01L;3@0Y
7Al05@T901871P0@1@<03`@201050`804PL500L04`P60146100<0@004@L501H;2@0A1`H04@H70080
4@D71@0A1@T08@0C1`/05@T=01<72`0@10L040@601451`0B1PP040@601451`0@10H0>2`^01H:300H
30h07Q8D08]oP@1LD5<07a<G00P0000D2P`040@800X00P0C1`/05PX>01<72`0>0PH03`<701@8300I
3A005@T;00h2100=0@<04`L901@82P060186200800l31@0I3@l05PX<00l31@0@10H04`L901041P0>
0P@200l31@0402HJ7010=3H04@D501861P804`L70P0B1PH03`0<00005@T901L;2`0A1@D03P8200l3
0`0A1@L04PH800h2100:00003@430186200@10H04PH801<72@0200d10`0301@82P0S5aT06`lA0080
40@600P04PH800l31@0B1PP04`L901H:300H30h050P:00`00P804`L90P0B1PP201451`0600d10`0@
1PL04@D700/00@0A1PL04@D75?ooool001_ooooo00d04`H@01L:5014=d005@PB01L:4`0B1@l04@H>
01L:500C1Q005@PB01853`0B1@h04PH:00<04`L900<050P:01D92`0C1`T01@0C1`T201862P0F0188
2P0m<SD0=2T/01T=4@0C1`/060`@01@8300A1@T04`L;01452@0G2`d04PH800d10`0O4aD05P`=03X^
<00g:bd04PH803HZ;00H30h04PH801P<3PL050P:00H04PH801D92`0C1`T040@601<72P0B1PX401<7
2`080105200C1`/05@T=01H;3P0B1PT04`L;01D:2`0D20X30186200301@82P0F2P`05@T;00<050P:
0P0E2@/01@0B1PL04`L901H:2`0B1PL04PH8008050P900X03`D601<7200@10D04@H702TM7P0D20T0
50T:01451`0A1`P05`/?0P0B1PX201<63@0501@73P0D1`l04PH<01D93@0G2`l00P0E2@d0200J3Q80
50P<01@8300B1PX0710D01lC5`0T61`06@dA0P0D20`00`0F2Ph050P<01X>4P0401H:3P0?01L;3`0H
3A406PlD00l52P0I3a@050T?01P=4P0G3A805@X@02<I7P0P5QX060dC01P>4`0L4aL050`?0080618D
00H05@lA01H@4P0L5QP05a4C01H@4P0I4aD201/E5`1e01D?4@0S6b40;2@V01/D4@0T81P09B4D03dj
:@2UXi80gmo?05aMC`0d=2T08b<K01hM6@0L6Qd071XO028P900Y9bX06aTK02<R8@0K6QL06QTD01/K
500O7aL08B4H020O6@0Q81l07alO01lO7P0R8R807QhO01XJ6`0Q8B809BDX024Q900S8RH09bH[02@U
:@0R9B/08bL]024U:P0Q9B/0:2`b02P]<P0T:2d092T^02DZ;`0a=S/0:2db02`a=@0W<2h092dZ02Pa
;P0[=3<0;SHh038j?00^=SP0;SHi03@l?`0e?D00<SXm034k?P0d@T@0@4a?03U7BP0`?T40=dE803I4
A`0d@TD0>DM:03Q6BP0kBDd0=dE903Y5BP0f?d<0=cm403e5B`0lA4d0>45:03m7D`12BeL0DEYY04eG
I`1:EVH0@4aM04aHI00oC580CEYP04EBF01:Eed0@DiD03e:D00nBe40@4eC049?E@13D5H0AE=G04ME
F013DE80AE=E03m=C`10CTl0MXB604QFF01=Fe`0JGMi06]iN`1AGf00B5IH04UGE`1;FET0AeEF04AB
D`1;FET0DEmQ059PH`1AGf80DV1S0080Df1V04d0DEiS05ARI@1IIfP0G6YZ05=QH@1DHf00BUUE04UH
E@1@GUh0EVAU051NHP1=FV00DEiU05=PJ01GI6`0F6E]05MTK01GI6/0FVM]05QUJ`1MJfl0HFma069`
LP1NK6h0FVQY05m[L01QKG80IG5f06=^M01TL7@0LWj2092KW`1^NWd0GVY/06=_K`1QKFd0GVYY065]
JP1QKVP0HVmY06A`K@1SKf`0Gf]X06=_K@1ULG00HVi^06=_K`1TL700GVU[05YXJ`1KJ6h0FFI/05MU
JP1MJW00FVQ/05e[K`1JIf`0FfQ]05UVJ`1GIFT0FfU/05ITI@1JJ6P0FFMW05]YJP1FI6D0CE]L055O
HP1?GF00C5YM04]HGP19EU`0AeIK05Y[LP11D5L0A59G04QDF00204=<CP1>04A=C`17D580ATmA045<
CP0oBTh0@4]?04QCE`19E5P0?dY>045:C@12C4h0?DI803U2@`0i@D80=Cdm03U1@00k@d80=3Td030d
:`0_<RX0;c8]02X];00Z:bd0:bda02LY;P0/;3<0=SPm030b=`0`<CH0=SLl02`/<@0X:2d0:R/^02XZ
:`0_<2h0:R/Y02PY:00W:2L0:RX]02HU:P0V9B`0:RT/02DV8@0S92009RLS02h_:P0W:2@0:b/W02<T
7`0Q8Qd08B4N04E6@@1=CD/07b0R02@X:`0V:2d08B<Y02@W;`0U9S00<c@o02DX<00N8BP092H[028V
:@0Q8bH081lT02DS:P0T8RL07adP020O800N7A`0:2LV028Q800N71l09R@Y02TW;@0S82L08R0U0P0R
82<00`0T8RD08b4T01lM800201lM800G01dK7P0P7R408R0S01lM800k>3X0920S01`I6P0M6A/061DF
01hK700K5aP06AHG01`I6P0Q7Ah081`M01PD5@0J5QL07ATJ01LC500L61T06QHG01`H6@0J5QL00`0K
5aP08@0J5QL06ADF01`G6@0J51H061<D01TC5@0I51H05a8D01`F600G4A<061<E01TC5@0H4Q@07ALI
02LQ8`0M5aX0618D01TC5@0J51D06aDF01LA4P0F40l061<A01`G5@0H4`l04`h:01PB4P0F41006Q@D
01TC5@0F41806A<E01`F6@0201TC5`0501XC6@0C3A8050hB028L7P0K5AL00P0H4Q@05`0G4A<06A<E
01TC5@0E3a405a4C01/E5`0F41804P`>01H@4P0G4180614C01PB500I4Q@05a0B02hX:P0@20/05a0B
018=3P0I4Q@04`T=02DJ7P0G31006PlC00<050T=00`05P/?01@93@0E2Ph05P/?01D:3P0G2`h04PH8
01P<3P0C20X040H701P<3P0F2P`201L;3@0O01H:300D20X050P:01<72@0D20X05`/=01H:300B1PP0
50P:01L;3@0D20X04`L901H:300G2`d050T:01<:2`0C3@d03`P800l7200C3@d04``=06QPH@2c[Jd0
>c@d02PQ8@0J51@040P901882@0B1PP04@D70186200401@82P0:01<72@0B1PP04@D701041P0B1PP0
3`<501@82P0H30h05PX<01D92`@04@D70P0C1`T03P0>0`H05@T=01D93@0J3Q804PH:01452@0B1PX0
50P<01452@0B1PX05PX>01452@0F1`X05@H90P0D1@P201H72P8050D8100C10L601451`0401@82P0C
1`T04PH8018620804@D701l08QHG01P<300C1`L04`L701@8200E2@T05P/;01<92@0C1`L04@H601/?
3`0`92@0?Bl_00l10@0L3Ph04`D501P<300A1@D05`d<02DK6P0K4A004@T70189200?1`D04PX800`3
0@0A20H0>2h^02PN7`0D2P/04@D700<050D:00<04`@901<4200C10L0100C10L0200G20/07PlB01h?
4P0D1PP06@X=02dN8@0Z6ah050D80P0E1PT0200C10L04P<601831P0E1`T03@0101P:300H2@`03001
0`0C10L0100D1@P04`@701<41`0C10L201831P0_01421@0B0`H04P<601441@0>10<04`L701871`0B
20P05`d>01D:2`0@10H04PH:00d31@0J3Q80;b<V01H72@0E1`L04`D50184100C1@D04PD501@61P0@
0P805@P801861P0?0`<0;b4Q01@82P0C1`T04@D700l31@0@10H04PH801061`0H3@h0@CDg01D;300B
1PP05`/=01l@4`0J2`h04`@701421@0D1@P05@H901@5200C10L00P0B0`H0100C10L050D801<41`0D
1@P201D62@0301@5200C10L04`@700D04`@75?ooool001_ooooo00h070lH00h12P0C1Pl0200401H9
4P0A10d040<<00h22P0A10d03@0901hA6P0K3QD050P<01@82P<04`L900<04PH801@82P0D20X0100D
20X02@0C1`/07A4E01@8300^8RH0:alS00h21P0E2@d08ADI01`@500201<72`0:01@8300C1`T07Q8D
00l31@0E2@/04@D702lS9@0/828040@601D92`80710B00<02P0001@82P0D20X0100D20X201862004
01<72@0@10H04PH801D930804`L;00X050P<01<72`0B1PX040@802XN8P0:00804`T;00P0000A1@T0
60`?0P0C1`T00`0B1PP04`L901<72@0301D92`8050P:0P0E2@/0500B1PP04@D701H:300C1`T04PH8
01L;3@0E2@/04PH801T=3`0C1`T09ATK08j2P`18?3`05@T;01<72@0A1@L04PP:01862P0C1`/04`H=
0P0D1`h01P0D1`l04PD<01@8300F2Ph050P<01<72`8050P<00/040@801T=4@0J3Q804PH:01`@500H
310050P<01L;3`0L41@06@dA01H:3P0401L;3`0801P<400I3A4050T?01L<4P0E2Q006@hD01D:400O
51X201L<4P0_01D:400G3180714G01H=4P0I41<04`d?01/E5`0V828091hP01H@4P0B30h06Q@F01/E
5`0G4A<05Q0B01`F600J41P07QDI01dE4`0N6A<0;b/N04=0;`2[ZYP0dm?204a=?`0R8QP07QdG01XI
5`0G5AX08AlU01TG700G5AP06aTK034`;P0O7Q/07ahI024Q6@0T91`08B4G01lO5`0L71/07QhN024Q
8@0R8R807QhP01/K7@0P82800P0X9b`01P0V9BX08b8X01hO900W:c4092T_02<X;P8092T_00`0<SLm
04U>E00Q9R`0:c0f02DZ<00R9bd0:Rlc03@m?@0U;Rd0:C8a03<l>`0a>C/202hf>00Q030h>`0e?D00
=cm203Hm@`0a>cl0;C/n05ARI@1PKW40;ce0030n@@0hATT0=dE803U7BP0mBdh0=TA70390@`0e?d80
:c<f0499C`0lA4X0@T]B03Y3C015CUT0?dUE075jR@1DGfh0@4aL04iIJ`12CeX0>dQ>04UFG014DEL0
AeAJ00<0@DiD0140A55G04UFG01=FV00CeaQ055OHP1:F5T0B5IG04aJF`17EEH0@Dm@04=ADP14DU<0
BeUJ04eKG018EUL0BEMH04ECD`0204UGE`0304MEE@1=Fe/0DEmP0080E69U01T0DEmR04iKH@1?G680
DUmU04mMH01^O7d0NXR904eKF`1;FUL0CeiK04mMG@1BH600EfEW05MTJP1EHVX0EF9[05ERJP1FHf/0
F6E]05]XL01JIfh0EfAZ06=aM01QKg80GF]^00<0FfUZ01T0GFQ^065/LP1YM7X0JWEi06E`M01TKg<0
Q8nA06ehNP1NJF/0GVYZ061/K01SKfd0GFUU06IbK@1XM700Hfm[05eYIP1MJFL0Gf]Y05iZJ@1JIVH0
G6QX065]K@1NJF/0G6Y]0080F6E[00@0EF9X06=`MP1BGfD0F6E[0P1MJW0205AQI`0I05aZK@1AGf00
E69R055OG`1@GUh0DV1Q051NG`1:F5/0CUaO04mMH01=FV00AeAJ04ACF01QLWX0A5=J045@E@14Ce<0
?4A703Y2A00kA4<0>D5303a4AP12C4h0@TeA045<D00204=>DP0@03]6BP0lATP0?TQ:03Q1@`0f?T00
>T=2038i>@0^=3@0<SPh030e;`0c=R/0<cH]038d;`0W:BP08b@V02//<080:RXb03@0<S8i02`]<P0[
;340<c<h01lN8`0k>Sl0;Bd_03Ti>@0c<c40<C4_02TY9`0V9RH0;2`_02/Z;`0V9B/08b8U020P7P0X
:2H0;bl]02/[:@0X:2H08b<Q02HV900Y:BL08B4O01TI5`0S8b40824S02DV:00V9b/08b<[02DU;@0U
9Bl09bLa02<S;@0T92d09bP]02DV:P0S92P071/Q02@Q:00P7R807A/N028P8@0/:bT08R4O020O7@0P
7Ql08R0U02@R9`0T8BL08b4V0P0Q7b803P0S8B@08R0S01/I700T8RD08AlR01TG6P0C4A@06aTL02HT
9`0_:b`081`M01dI6P0N6Q/06QHG0P0N6Q/201/G600301<?400G4a@08QhO00806QHG00H05A4B01`H
6@0N6Q/040`=01DA4P0G4a@201TE5P0:01XF5`0I5AH06Q@F01LA4`0F41805a4C01PB500F4180618D
01XD5P805Q0B00L06A<E01LA4`0F41805@lA01LA4`0J51H06A<C0080618B01d081/H01hI5P0F4@h0
5Q4=01XE4@0G4A409AlO040j>P0[9BD05@lA02PR900?2@/04`dA01`F6P0C31<0;2D/014;3`0K5AP0
4@/=020J701MEeT050h@01dG6@0E3a405Q0B01XD5P0M5aT05a4C018<3P0201TC5@80618D01X05a4C
04U3A@3CcLl0@cdo01/E5`0=1`T07QPJ0189300H3A406@hB01H;3`0B1`/0:b0T024F6P0F2`l050T=
01D:3P0F2`l05@X>01462@0K3a408ADG020D5P0K3a404PH801041P804PH800`05`/=01X>400H30h0
4PH801<72@0I3@l0710B01L;3@0B1PP04`L901@82P0H30h201/?4@0A01D:300J4A801@0000h8200D
3Ph03`T901LA4@1IDe<0ViFE03Pb<P0600002`D5018:2`0B20T04PH801451`0C1`T0100D20X02@0C
1`T04PH801451`0@10H04PH800`00P0H30h08ADG01H:30030186200@01451`0B1PP050P:01@82P0E
2@d03`<700P0000900404PH:01hB5P0@10P05@T=01452@0@10P04`L;01452@804`@700@050D801D6
2@0G20/06@X=0P0E1PT0100D1@P04`@701<41`0B0`H701451`<04PH80P0C1`T0900@10@05PX:01D9
2@0@10@04PH601H:2P0A1@D0Ac/k01dA4@0J3Ph03`<300P0000L3Ph04`D501/=3@0C1@D06`l?01<7
1`0E2`X06a4@01@:2@0A2@L04`/901081P0A2@H03PH401@<2P0I3`h03@<4020F5`0C1`T04P<80142
1`0B0`P050D:01@52@D04`@700P0408400l00`0C10L05PL:01@5200?00<03`8301831P804`@700L0
4P<601421@0F1`X03`0301/<3`0b8bH070d@00@04`@700<050D801<41`0C10L00P0C10L301831P0?
01<41`0C1PH06a0>00P0000L41003`<309N;S@1MDE<09a/M00l41`0I3A404PH:00l31P0B0`H04082
00805PP800P03@000184100=00005@L702XL700P4Q803@0001D71`<04`L901404PH801451`0A1@L0
60`>00h2100F2P`0200001H:300<0P<04`@701831P0C10L050D801<41`0>008050D801<41`020183
1P0401<41`0D1@P04`@701@520805@H900<050D801<41`0C10L01@0C10LDooooo`006oooool03P0G
2Q<04PD>00`0200A10d06PdF00d02@0F2A804@@=01<63`0800@05`XC00/01@0E2@d050P:0P0C1`T0
0`0B1PP04@D701@82P0501@82P0501H;3P0;00<06PhB0105200800000P0D20`00`0L41@05`/?0145
2@0201452@0<01P<3P0^8R@07A4C01L;3@0800003P8400h41@0D20X02@0001451`0=0@<04PH81P0E
2@/01`0B1PP050P:01@82P0@10H050P:01T=400D20`00P0C1`/02@0E2@d05PX>01L;3`0T61`03P86
024E6@0:00804PH:01<72P0601<72@804PH800X04`L901@82P0F2P`06@d?01@82P0A1@L050P:0145
1`0?0`D04@D70P0D20X02@0F2P`02`010186200b9RL02@0000l51P0<00803P8401X>4P0201<72`<0
50L>00H05@P@01P;4P0I3A406@dA01H:3P0C1`/201862P0502<G6`0_8bL0710D01/?4`0<00@00P0G
2`l01@0I3A406PhB01T=4@0H31006@dA008060`@03@05`/?01P<400I3A404PL=01X?5@0B1`d0714G
01T>500/8BL07a@J01`A5`0E2Q005``B01X?5@0B2@h06A0C018<3P0L5QP0:B<U02XT9P0K5AL04`d?
01TC5@0J51H05a4C01PB500M5a/050XB01XA5@0S6aT071LA02HR5`0Z9aP0?cd^05iNC`0S8aL08B4I
02@S7P0D4Q<05A<H01lM8P0L6Ql0928U028P8P0N7A/07QdI01lN6@0Q81/08R8J01hN500K6a<0820O
0P0K6a/05P0M7Ad0820R02@T9P0O7b409B@Y02LV:`0T8bP07ahT01`M8P0L82L092T_01LL8P0/<CL0
UIZP08R=T`16Be407b@Z02T^=00S:2h0;c@j03Dj?P10B4T202hg=P05038k>P0/=3H0:C4c038j?00b
>Sd00P0d?3l0:P0b>Cl0=Cm302hl?`0oCE00D5iQ03=1A00]>ch0<Cm203U7BP0hATT0>TQ;03M5B00i
AdX0=d5502`d=`14Be40=3a3049;DP0oB540A4iG06UcO`2RZkX0Hfem045=G@1<EfT0C5QS03Y7C@17
E5X0AU=I04MDFP10CE<0@e1F049?E@15DUP0BeQN051MH`1AGf<0?D]>049@D@15De@0A59C04MEEP80
BEMH00L0BUQI04MEEP15De@0B5IG04IDE@16E5@0BeUI0080C5YJ00`0D5iN05=QHP1GIFP0EfEX05=Q
I01>Ff40CeaR05ERJ01>Ff40MXB708BBU016E5D2059PH00705=QH@1DHV<0EV=X05ERJP1CH6T0D5eV
05aYL@0205QUK@0X05]XL01KJ6l0EfAZ05m]L01MJfh0FfU/05aZJ`1NK6d0H6i_069]L`1TKgD0JgIl
06iiO@1XLgL0H6]_06=^L01OJV`0GVU[05m[J`1QKFd0HVi/05eYI@1RKVT0Hfm[061/J01MJFH0G6QV
05m[J@1PK6/0G6QX05eYJ@1QKFd0FfIX05m]L01DHFL0HVme05ERJ01PKG<0EfAZ05YWK@80FFI/00X0
DUmU05AQI`1KJF`0CeeN055OG`1=Fe/0BeUI04mMGP1BH640CE]N0P1>G5l0@P1:Eed0A55G041?E00m
C5D0AeIM04UFG00kATT0=Cdo03a4AP10BDP0>41203Y2A011Bdd0@4]?03]6BP0iA4P0>dI:03Q3A`0m
AdT0@D]=03]4AP0d?3h0=d0o038j>@0d>SX0>Clo03Hk=P0a=2/0:RdV02T[9`0V9bT09BHZ02TZ<00X
:300:RXb02d]=00S92T09RL/030`=`0b<CL0<C0f02XY;P0];Bl092@T02DU8`0T92809RHV02XZ:`0W
9R/092<X01lO800Y:BL0<c<a030`;P0X:2H0<C4_028R800W9bD0:RXX02PX9P0I6AL08B4O02DU9@0U
9RP09bP[02LV;0809RH^00`0:2Ha02LW;`0Y:Bl09bH[02<T9P0T92H06QPM02<P9`0Q7b<08AlR02XX
:@0l>cT2020O7@0:020N7`0N72407Q`Q024N900U8bP09B<V028P8`0L6Qd06aTL01dK7P806aTL00L0
81hQ024O8P0J61/061HI01lK700H51D071PI008081`M00l08alP024M7P0L61T07ATJ01<?400Y9BH0
7QXK01TE5P0N6Q/07ATJ01TE5P0N6Q/04Ph?01DA4P0G4a@00`0H51D03@0G4a@06Q@F01LA4`0F4180
5a4C01PB500G4A<050h@01/E5`0J51H06A<E01/E5`0B30h00P0E3a409@0F4180618D01H@400D3Ph0
6A<C01lJ5`0M61D05A0=01D@300I5100618A028L700g<C409AlO01D?4@0U7b405a4C01PB5P0E3a<0
4P/B01TB6@0F41@07ALI01`F600c;Bl0CDM9010:300J51H05@lA01H@4P0I4aD071HH01PB500E3a40
6Q@F01TC5@0H4Q@00P0F41803P0Q6ad0N79d01dG6@0>20X040X<01LA4`0L4aH06PlC01D:3P0?10P0
=R/_08QmP@1QEUX05``@0P0E2Ph201H;3`0E01P<3`0D20X03P8401D:2`0D20X040@601@82P0B1PP0
40@601H:300I3@l050P:01451`0F2P`06`lA01dA4`0J3Q005@T;00l31@0A1@L050P:00805`/=00D0
50T;00l61`06000040X:00X41002014;2`0700L10@0R71`030H601<=3@0=1`L03@H601061`020104
1P0301<72@0F2P`05PX<00<04`L900T04PH801451`0A1@L04`L900/00@0G2`d081@F01<72@0A1@L0
0P0C1`T06@0B1PP04`L901@82P0E2@/050P<01862P0H31005`/?01D93@0:00803`<701D93@0A1@T0
3`<701862P0A1@T050D801<41`0D1@P05@H901L82`0H2@`05PL:01D62@0D1@P00P0C10L00`0B0`H0
4PH8018620040186200301041P0A1@L04PH800804`L901X050P:01H:2P0I3@d05`/;01<71`0@10@0
4@D502LK6`3Fb/X0G51@01dA4@0I3@d0:1`L01430`0D1PH05`T901@61P0K3`l04@D501061@0C2@P0
3`D4018:200E3@/04`/900h71P804@T700@02`4100L0000L4Q<04PH80`0B0`P00`0D1@X050D901@5
200501@520804P<600D060T<01`=400J2`h05@H901831P0201<41`804P<600L050D800h00P0@0@@0
7@hA01<41`0=00404P<600804`@700D050D801<41`0C10L04`@701@5200301D62@0I01@5200>0`<0
6@h<01<71`0T61P03`<308b0PP1NDU@09QXL00X00P0?0`L03@4501@82`0H2@`040820184100C1@D0
3`4102@F5P0K3@d0300000l30`0L3Ph05PP800`0000201041P804@D700P040@600l31@0D20X02000
01D92`0900006Ph@01L;3@804@8500H04P<601D62@0D1@P03`0301@5200C10L201831P0401<41`0D
1@P04`@701@520805@H900<050D801<41`0C10L01@0C10LDooooo`006oooool03P0C1Pl06PdF00d1
2@0I31D06PdF01D84@0=0PT05PXB01T<5@0>0`X070lH01452`0E2@d050P:0`0C1`T70186200H01@8
300H31006`lC00l51`0A1@T04`L;01L;3`0B1PX03P8601<72`0E2@d040@801@82P0J3Q0030830187
200A1@L050P:01<82P0A1@L06Pl@01@82P0L41803P<41P0E2@/0300C1`T05@T;01H:300B1PP05PX<
01X>4@0E2@d04PH:01<72`0G2`l06`lC02HJ7P80D4A800@0>Rlb01@8300@1@P05PX=0P0C1`T00`0D
20X04`L901<72@0201@82P0901<72@0B1PP04@D70186200D20X04PH801451`0D20X04`L9008050P:
00/06`lA01T=3`0C1`T05PX<01461`0A1@H06Ph>01D;300M4A<05PX<01<72`0201@8300A01@73P0E
20l05@P?01H94@0G2Q405PX>01D93@0F2Ph05`/?01H:3P0G2`l04@L901X>4P0>0PH05`/?01P<400B
1PX00P0F2Ph00`0B1PX04`L;01P<400201T=4@0E01P<400G2`l060`@01P<400E2Q006a0F01D:400I
3Q@05P/A02PM8`0N4aT08AHL01X?5@0H3A<06a0F01P?500I41<05@lA01PB500L5QP07ALI00806A<E
02l05a4C01XD5P0N61X07aTK01TC5`0M4a/07Q@K01hE5`0G4Pl06aL?01hJ400N6a009bDK02<S6P0V
9B009R@S028P8P0M6al07adQ01LE600O7B007Q`M01lN700N7AT07QdH01lN6@0Q81T07AdE01XI500O
7ah07alO02@T900Q8B407QhP02<S9@0T92H09B@Y02LV:`0T8bP08b8X02@U:P0T:2`082DY02<X;00e
>Sh0@TM;02L/<00202T^<P0A02/`=00V:bl0;S<g02DZ;P0`>CT0;CHe02hg=P0]=CL0;SHh038j?00_
=cX0<CTl038j?P0b>Cl0<cY003DoA@0nBe400P0d@DL09@0gA4X0;ca203I3B@0oC580;ca2034nA00^
>d40?T]A03DoA00j@DL0?dQ=03M0AP0mATd0>TA=049<EP1FH6X0BEEQ04QDH@1<F6H0@4aL07J3SP16
DeT0?daB03a9C`12CeD0@4eC04QEF`15DUP0@e1F04EBF016DeT0@TmD04=AE016E5D0AE=D04IDE@1:
F5T00P17EEH304YHF@0S04]IFP14DU<0AUAD04]IF@1<FUX0BeUI04iLG01@GUl0EF=V05=QI01AGf80
DEiT059OI@1CH6H0EV=Z04YGGP1HIF/0CU]P05YXJP1<FU/0Df5S05=PI@1CH6H0Df1X05APJ`1GHg00
IFmi05iXL@1IHf`0FVE[05aWK@1KIV/0FfIZ05eXJ`1OJV`00P1PJfd0;P1OJV`0GfY_05mZK`1NJFd0
HFa`069]L01JIFL0H6]]061[K01LJ6P0FfMW061/K01RKV`0I71/05iZIP1LJ6@0H6aX069^J`1PK6X0
G6QX065]K@1OJf/0GfY/05aWJ@1BGEl0FfQ]05ERJ01jQhd0L7f305ISJ@1EHVP0JGIl05aYK`1HIF/0
E65W059OI@1DHVD0Df5R059PH01AGel0CE]K04mMGP1DHV<0C5YM04UGFP17EEP204ICF@0>04MEFP1;
Ff80>dY@03a9CP13CU00?dM903U2@@1<DU80?TM603e5AP0oBD/0>D=7038m@@0kATX203a7B`0n041:
C013CDl0?dQ:03<k?@0`>CP0;cLf03Lm?@0j@400<3Da02HY8@0Q8ad0:B/X02`];`0X:Bd0:2T_02h^
=P0c<c/0<C4h02<T:@0Z:bl0ATI>07MeP@0^;CH0<2lf02<S9P0W9bP0:BTX038b<00j>SP0<C4`02LW
:00Y:BX0;2`[020P7P0U9B<0MWId04i>C00f=S@0:BTW02XZ:00U9B<08b<Q02DU8`0Q8Al0:RTW02LW
9P0Y9bX0:bT]02TW;@0X9B`0:2D]02XY;P0Z:2d09R@X02LV:00Z:2P08R0U02HS:P0R82@07Q`O01hL
7@0/:bT202@S8@0A02<Q8P0O7B807Q`Q020N900L6Ql08AlR028P8`0L6Qd07adP038`<`0Z:2/07Q`O
01`J7@0V92L08R0S01`J7@0O6a`00P0N6Q/00`0M6AX06QHG01TE5P0201TE5P807a/L01H0B4A501dI
6P0M6AX06aLH028N7`0C3a006QHG01hJ6`0H51D06ADF01PD5@0G4a@05Q8C01DA4P0J51H0618D01LA
4`0I4aD06Q@F01TC5@0L5QP06A<E0P0D3Q002@0F41806A<E01LA4`0D3Q004`d?01LA4`0I4a<0618B
01XD500301PC400A01HA3@0D3`/071LD01HA3P0A30T05@l?01PB4P0E3`l050h@01XD600B31007QPL
00P21P0K5AT06aDG01H@4P0b;2h00P0L5QP0300E3a406A<E01LA4`0F4180618D01XD5P0K5AL06A<E
01PB500G4A<05@lA01@>40805a4C01l071HH01LA4`0F4A804Pd>01P@4`0F2`l04`X<01/@500P5AT0
<BHZ01hC5`0H3A405@X>01H;3`0G31005P/?01@9300B20T09Q`M03lf=P0Q5aP05@/<01T?400D2P/0
4PP901P>3`0L4Q<06@l@01H;300E2@/050P:00805PX<00<05@T;01451`0B1PP00P0B1PP0400C1`T0
5P/<00l51P0K4Q<04@P900L0000G3Pl050/<01L>3`0D2``040L801<:2`0=10D04@P901L<3P0F2P`3
01<72@030186200C1`T04`L900@04PH800@050P:00h2100B1PP05`/=0P0A1@L201<72@0B0186200C
1`T050P:01D92`0h;30060d@0105200B20X081@H01P<400A1@T050P<01452@0B1PX05@T=01452@0G
20/05PL:0P0D1@P00`0E1PT05PL:01D62@0301D62@8050D81P0C1`T00`0A1@L04PH80186200201<7
2@0F01@82P0B1PH03@4100h20P0D20P05@T901<71`0D20P0?S8b020D500B1`L060`<01T=3@0F20P0
5@L701430`0G2@T060`<00l30`0I3`h05`d<01@:2@8050`:00T04`/9018:1`0H40h040P601061@0?
1@H04PP901041P0D1@X00P0E1P/00`0B0`P04`@801@5200401@5200301<41`0A0PD04@8500804044
00@04@8501<41`0C10L050D80`0E1PT01`0A0`D07PlB01<41`0@0`@06@X=0102100E1PT00P0C10L0
0`0D1@P04`@701<41`0201831P0L01<41`0D1@P04`@701831P0D1`L05P/901861P0G2`/04@D501P<
3P0H3@h040@601L;3`0C1`/04@D901D9300G20/040820184100C1@D04@<302@F5P0H2PX04`D501<7
1`0C1PH0408201D820@04PH801004@D701041P0f:R`040H701051`0=0`@040H70187200F1`X050D8
01831P0D1@P05PL:01D62@0D1@P04`@70P0B0`H0100C10L050D801<41`0D1@P201D62@0301@5200C
10L04`@700D04`@75?ooool001_ooooo00d05PT@01L:4@0<00H05@P?01@73P0J3A@07A0G03<V;@0P
4aX05PT@01442`0=00L04PH:00<04`L90P0D20X601<72@0H01@82P0<00806`lA01X>400H30h040@6
01@82P0A1@L03P8401<72@0F2P`04`L901451`0K3a4060`>01T=3`0B1PP040@601P<3P0=0@<02P00
01@:2`0800008aLI1P0D20X00`0B1PP04@D701@82P0201<72@0>01D92`0D20X050P:01@82P0E2@/0
5PX<01/?4@0`92H0THF701lC5@080000;b<U00d3100B1PP301@82P030186200C1`T050P:00<050P:
00D05@T;0186200D20X0710B01lC5@0201H:300<01@82P0C1`T03P8400h3100D20X04@D700l41@0H
30`07Q8D01dA4`0=0@<040H80P0D20`301D83`0401H94@0V6B008ADI01T=4@805PX>00`050P<02dQ
9@0C1`/081@H01/?4`0P51P05PX>01<72`0D20`04`L;01T=4@0O4aL201T=4@0301P<400G2`l05@T=
00805PX>0P0D2@l01P0Q5Q`060dC01<83P0E2Q0050T?01X?5@806@hD04D07A8H01XA5P0L4aH07ALI
01`F600I4aD0618D01TC5@0M5aT06aDG024K7@0Y8bD09b4S01/E6@0O5Ad08ALN01@;3P0L5QH06QDB
02LR700N6a@07Q`F01XI5@0C4Q0081hO01XH6`0P7R406ALJ01hL7`0/:R/081hN01dL6P0O7QX07A`H
01hM600P7aX07ahI01hM6@0N7Qd092@T02h^;P0U9BD06a/M020P8P0U9BL09RDZ02XY;P0W9R/09RD[
02//<@0Q9BX09b``02`a=@0W;3006b0T02`a=@0Z;c<09b``01dR9P0X;C40<SLk03Ll@00_=cT0<CTk
03@l?P0_=cT0;cLj03@l?`0_=cX00P0b>Cl0;00c>T00=Se503DoAP11CU@0=dA:03E2B00mBU00<d16
03M4BP0e@TP0;CY005UVK00^>d40>4E;038l@`1@FF00=Ci504A>EP0oBE80@D]D04A@F@12CeP0?DUE
04EBGP0nC5T0B5IS096NZ01=FV00=D9803i;D@1;F5h0?T]A041=D`12CeD0@DiD04QEF`1=FV00BEMK
049@D`0mBd`0@4i?04YHF@19EeP0@Dm@0P13DE805018EUL0BEMH04MEEP17EEH0BUQH04iLG01=Fe/0
BUQH04eKF`1@GUl0Df5T051NH@1BH6<0FVM]05]XKP1BGfD0BeQP05]XL01FHfX0@e1F0P1DHVD03@1@
GF<0DUmU059OI`1?FfL0Dem]065]N`1IHf`0FfI/05YUJ`1II6X0F6=X05UTJ01MJ6`00P1MJ6X02@1L
J6P0FfMW05YUI`1MJ6`0GVU]05UTJ01KIVP0H6]]05aWJ@0205YVIP0905=OG`1EHEl0H6aZ06A`KP1P
K6P0GFUV05aXIP1MJFL0GFUX0080GFUY00h0HFa]05mZK01OJV`0GFQZ05=NH01KJ6h0CEYP05i[L@2;
V9h0H6ec05=PIP1EHVP0Df1V05AQI`80Df1V05d0EfEX051NGP1<FUX0CeeM04aJFP17EEH0B5IG04QF
F@15DeH0A59E04EBF017E5X0BEIL03i=E00oC580?D]>03a7B@0k@dD0>d5103Y0?P0h?Sh0>T=2045:
C010BT`0?4I803a7B`0iA4P0>4=703I0@P0e?d40=Sm1038j?00f?ch0>40o03m5A@12B4P0;S8^028T
7`0T9R40;Bh^02`]<@0Z:c00;Bdd02/[<`0^;SH0;Rle024R9`0T9BT0>3M005]II`0[:CH0;2Xc02<R
9`0`<3808b<R02`]:00d=C00:R/V02<S8@0W9bD0;Rh]03Ti>@1@D500j^[Z09bLW013@d<0:b/[020P
800W9bL092@T02h^;P0Z:RT0:bXX02LS8P0Y9BD0;2L[02TT:00W8RP09B0V02TT:P0Z9BX0:BDV02`X
9`0X92<07adR01hK8P0R82@09B<V024O800X9bD07QdK01dL6P0L6Q/00P0M6b00100N72808R0U028P
8`0O7B0201TG6P0:024O8P0D4QD05aDH03Hd=`19AdX0:2HY00`:3@0I5AH071PI01dI6P<071PI00d0
5Q8C01`H6@0I5AH06aLH02LS900H51D0;b//00d92P0U8B807ATJ01`H6@0D41405a<D00@061@E00l0
5Q8C01PB500F41805Q0B01PB500I4aD0618D020J700I4aD09AlQ02@N800G4A<071HH01dG6@0G4A<0
0P0E3a400`0C3@d04P`<01TC4`0201HA3P0K01TD4@0H4`l05Q4=014<2@0N6AH081/H02`W900X8R80
5Q0@024K6`0A2`d0618D01<=4@0m=c/03@L;01H@4P0H4Q@05Q0B01@>400C3@l07aTK01XD5P0I4aD0
618D01LA4`0I4aD06Q@F0080618D01405a4C01H@4P0E3a4040X<02DO8@0E3a4081XL01@>400T7R00
40L:01lD600A1PX09AXN02XO8`0P5AT04`P<01P=4@0201H;3`805``@02L06@lA01X@4@0>10D08ALH
02/Q8P0H3Pl05P`=01D;300D2P/05@/<01T?400K4A806Pl@01<72@0A1@L04PH801D92`0C1`T04PH8
01@82P0F2P`04`L90186200E2P/04@L801892P0=10D0<BPY01482@0?1`P01P0001D<3@0G3Pl030<4
01<:2`0@1`P06@d?01L;3@0D20X00P0C1`T00`0A1@L04PH8018620050186200501@82P0A1@L04@D7
01D92`0B1PP0100A1@L201<72@0<01D93@0;0@<06@dA01452@0Q5AT04`L;01@8300A1@T040@801H:
3P0K3a<04PH:0P0E1PT201@520805PL:00H04`@701@5200E1PT05@H901H72P0G20/801<72@804PH8
0P0A1@L04P0I3@d05@T901<71`0C1`L04PH601451@0C1`L0300000l30`0J3Ph07A4A00P0000I2`/0
5PP801430`0F20P04`L701H:2P805`d<00D05P`;01081P0>1P@040P601L?300201@<2P0401<9200E
2``03P@501451`@04`@900<04`@801<41`0C10L00`0C10L02@0B0`H04@8501<41`0F1`X060T<01H7
2P0C10L04P<601<41`0301@5200700l3100D1@P0404400l00`0A0PD02`0001421@0201<41`0G01@5
200C10L04`@701421@0B0`H04`@701D62@0C10L04P<600`10@0B1`D060`<01861P0=0@404PH801H:
300=0@<03P8600P0000:00804@D801421@0B10@00P0D1PH01P0B10@04@<301@61P0=0000300001D7
1`8060X:01405@T;01@82P0B1PP040@601451`0C1`T0<bLY01041P0H30h04@D700d10`0@10H05`P;
01D62@0C10L05@H901H72P0201@5200701<41`0B0`H04P<601<41`0D1@P04`@701@5200201D62@03
01@5200C10L04`@700D04`@75?ooool001_ooooo00D05@P?01@73P0@0`X06@`C01<63@0201L:4@07
03DX;`0M41L06@`C01@73P0H31004@D90186200201<72@0301@82P0E2@/050P:00D050P:00P06@d?
01H:300>0P@040@6020D5P0=0@<03P<401<72@804@D700T04`L90186200@1@H05PX<01@82P0A1@L0
4PH801D92`0@10H00`0E2@/00`0H30h02P0001<72@0501<72@0:01041P0>0P@04PH801<72@0@10H0
4PH801@82P0E2@/05PX<01<72@8040@600/05PX<02dQ8`0D20X07Q8D00P0000G2`d04PH801@82P0E
2@/050P:0186200201041P0F01451`0F2P`06Ph@01dA4`0H30h06Ph@02LK7@0X71h05PX<01451`0E
2@/05PX<01@82P0K3a4050P:01041P0L414050P80186200<00806`lA01H:3P8050P<0P0E20l05`0F
2A005PTA01hA600H31004PH:01<72`0F2Ph05`/?01`@500=0@D04@D900d11@0_8bL08aLK01T=4@0G
2`l05PX>02@H700]8BD06`lC01P<400G2`l05PX>00<05@T=00l06PlE01P=4`0b9bd09Q/Q024F700J
3aD04`P>01L<4P0F2a4060dC01/@5P0C2Pl04`X=01H@4P0I4aD00`0H4Q@06`0E3a405a4C01hH6P0S
7Al081XL01H@4P0F3A808QTN01H=400U7al06A<B02<N6P0G4a006aTE01hM6`0U8b@0>cTk01@B5@0V
92L06aTL03Xh>@1HEUL0=SDd00l>300M71P06QTE01/J5P0201hM600N01hM6@0S8b8092@T02XZ:P0R
8R807AdO02HV:00R8R@09B@Y02/Z;`0X9b`09B@Z02TZ;`0S9b/0:2da01/P900V:bl0:c0d02L/<00X
;C409BX^028W:`0/<CD08RL[02/`=00W;c40:S8d030h>P0a>C/0<CTl0P0d?3l07P0f?D<0=3]1034h
?P0d>d<0>D=:03Q5B`0[>3h0=dA:049?E@0e@TP0<d16034nA00kB4h0SIZP04AAE`0nBe40@TiD075j
P@0j@dX0B55I03Q2B`0oBE80Ae9K045>E`1>FVH0B5EQ04MEHP14DUl0BEMP03A1A`80@TmE0100=T=9
03a9C`1?G680A55G045>E015DUP0BEIL04=@E@16E5L0A59C04UGF018EUL0@U1A04YHF@18EUL0A59C
0P17EEH07P12D540B5IG04MEE@1:F5P0B5IF04ABDP17EED0BUQI05ITI`1BH6<0EVAW069_M@1SL7H0
EV=Y05AQJP17E5d0AE9J05ERJ01;F5h0EVAW059OI@1DHFL0DUmX04YFI01>FVP0Gf]j04mIHP1GHVP0
G6M]05UTJP80Ef9V03@0G6MY05]VJ01JIFL0FVIV05]WI`1LJ6P0F6=U05eXK01HHfL0F6=U05iYJ`1J
IFL0FfMW05m[J`1KIfL0FfMU061/JP1IIF<0Ef=O05eYIP1LJ6H0F6AR05EQH01GHf<0HFe]06=^K`1O
JV`0H6]]069]K`1KIVX0C5UO05i[L@17E5X0H6ec04eJH01IIV`0EF9X05]XKP1LJFl0DUmU04mLHP1E
HfH0DV1Q04eKF`1BH600DEmO04MEEP16E5D0BUQK04MEF015DeH0A55G0P13D5H0EP18Eed0?daB03Y5
B@0lADL0@TQ80457A`0k@Cl0>Clo03]1@@0lA4H0=d5303@n@00oBTh0>dI:03Y5B@0h@T@0=Cm103Q1
@`0j@T@0@T]:03a3@`0f?3`0=C/k02T]:`0W:BH0:2XW02PY:`0U9RX0;Rld03Hf?@0/;3@0:RXb02h_
=@0T9BX08B8V02<R;00Z:3H0<Blm03<b>`0c<SL0>c/m01dM6`0Q8Qd0:2TT02<T7`0U9R40:BTW02TY
:011@D40?3`l0:j^[P1aLG40<C4a02h^;P0M7Ad0;2`/024Q8@0T92@0820O02`X9`0U8Ah09R8Q02/V
:P0V8BD091lU02DP9P0Z9B/0:bLY02XV9`0[9bH07a/I020N8`0L6B008b4U02HT9`0O7Ah081lM01lN
700M71X07A/L024O900S8BH0924W02PV:`0T8RD081hQ0P0O7B006`0L6Qd09bDX01`J7@0N71l09B<V
020N8@0V92L07ATJ020L7@0M6AX06aLH01XF5`0H51D04`l@01lK700K5aP081`M01PD5@0]:BX0NWIg
024M7P0J5QL04`l@01/G600I5AH05A4B01LC500401TE5P0<01H@4P0D3Q0050h@01H@4P0H4Q@05a4C
01`F600O6A/0?3Hh03/e=`0K5AL05a4C0P0B30h00`0E3a406A<E01XD500201TC4`0H01TD4@0H4a00
6A@A01XE4@0K5Q806QDB01LB3`0A30T05a8?01/E5@0E3`l06Q@D00@0000T7R00:28V0:^UZ@1=Ad/0
6aDG01lI6`05004091hP00@0000O6A/06A<E0P0K5AL00`0I4aD05a4C01LA4`0201TC5@80618D00T0
5a4C01dG6@0400008adO01LA4`2BS8h081XL01H>4@0U6Qh00P0C20`01@0B1`/06@hB01dB5P0H3A40
5P/?00<05``@00T040H802HL7@0G3@h04PT:020F5`0B20T060h?01H<3@0D2P/00P0A1`P02`0D2P/0
60d>01D92`0D20X05`/=01T=3`0E2@/03P8401<72@0G2`d050P:00804@D700d04PP900L0000F3@h0
HeYK01D<3@0=1PH03`H701892P0?1PL04PT:01L>3`0?1@H050P:00804PH800<050P:01H:300G2`d0
1P0B1PP01@0?0`D05`/=01<72@0A1@L06@d?00804@D70`0@10H03P0B1PP04`L901H:3P0?1@L07Q8F
00`0100G2`l03@4501D93@0@10P03`<701P<400M4AD04PH:0P0C10L0200D1@P05@H901L82`0I2Pd0
4P<601<41`0D1@P05PL:0P0H2@`601<72@0K01@82P0C1`T04PH80186200A1@L040@601861P0F2PX0
5@T901451@0B1PH05@T901871`0Y7Ad03@4101P<3008000060`<01D71`0G2@T050H601D71`0B1PH0
7A4A01@:2@0I3`h06Q0?00805Ph<00d06Q8@01L?300<108050`:00d40`0?1@H03P@501<72@0B0`P0
4@870183200D1@X050D900D04P<600T05`P;01H72P0A0PD04P<601@5200B0`H03`430101100A0PD0
0`0C10L01`0F1`X0404401831P0F2@X03@0101421@0E1PT00P0C10L05`0D1@P04`@701<41`0C10L0
5@H901L82`0I2Pd05`P;01D62@0D1`L05``:00P0000F2PX03`<302DI6`0]8B<05@T;01452@0E2@d0
50P<01041`0B0`H050H600804@<301`050H601430`0@0P804`D501L92@0D1PH03`410184100C1`T0
4PH800l31@0=0@<03P8401451`0D20X0200001@82P0?0`D05@T;01X>400E1PT050D801D62@0F1`X0
50D801421@0D1@P04`@70P0B0`H0100C10L050D801<41`0D1@P201D62@0301@5200C10L04`@700D0
4`@75?ooool001_ooooo00H04`H=01H9400@0`X040<:01H9400C1Pd201D83`0F01X=500I31<050L>
01P<400A1@P050P:01<72@0A1@L04PH801@82P0@1PL04`L901X>400E2@/02@00028F600D2@X05@T;
00l51P0I3@l03P8401D92`8050P:0P0C1`T20186200501L;3@0D20X04@D701P<3P0I3@l00P0A1@L0
2P0G2`d05PX<0186200E2@/06@d?01<72@0B1PP050P:01D92`0D20X201D92`804`L90P0B1PP00`0C
1`T050P:01@82P0201<72@030186200C1`T04`L900@04`L900P05PX<01061`0M4A<05PX<01P<3P0C
20T04PH800d3108060`>00T03`<501P<3P0F2P`05PX<01L;3@0F2P`04`L901D92`0F2P`01@0D20X0
4P0D20T060`<01P<3P0@10H03`@501P<400E2@d05`/?01D83`0D1`h06PdD01H94@0G2Q405@T=01@8
300F2Ph05`/?01@830805`/?00<05PX>01D93@0F2Ph00P0G2`l0100H31005@T=01L;3`0N4QH201P<
40805`/?0`0F2Ph201X?5@0?01T>500H3A<05``B01L<4P0J3aD06@hD01/@5P0J3aD060dC01`C600H
3a805Q0B01D?4@0F41806A<E00L06aDG01X08QTM01hE6@0O5QP06A<C01/E5@0K5A@07QXI01`J6@0O
7Ah0928T028P900I5aX08R0R02h/;@0k>CX08R4P024P7P0N7A/081lM02<R7P0U92007QdI01XI5@0P
7a`08B4Q02<S8`807alO01808R8T020P8P0T92H09B@Y02@S:00R8BH092<Y02DV:`0T:B`08BHY02DZ
;@0X;C008RLZ02`a=00V:bh09BX]02H[;P0/<C@202ld=`0g02de=`0^=SP0;cLi03@l?`0]=CP08b/^
030g?@0c>T80=3]3038i@@0f?DD0?4E=03U6CP0hADd0?4UA03Y7C`0iATh0?daD04EBFP0a?TH0?DYB
03M4C01nRi<0?d]C049<E@11Be@0>dE>03m9DP10CEH0@e1I03m<E@0nC5D0@U1J03m=F00kC5H0>dYB
03e:D014DEL0D5eS03M4BP12CeD0@DiD049?E@14DEL0AU=I04AAE`14DUH0B5II03e;C015De@0?4Y;
04ECE017EEH0@e5B04ECE00204ABD`0<04UGF01;FEX0AE=C04ABDP19EeL0AUAD04YHF01AGf00E69U
05MUJ01BH6<0CU]Q0P1BGfD0901CH6P0DUmW04mLI01=FV00CUaP05=QI01CH6H0DUmU04iKH`1EHFh0
HVil06YfQ01BFf@0EEiT05MPI@1JHfP0GVM[05eWJ@1QJfd0GFMX061ZJ`1SKFh0GFMX07f7R01cOX00
FVEW05AOH@1II6H0FFEV05YVIP1PK6`0G6QV05YVI01LJ6H0GFUV05]WH`80G6QV00D0FFES05aXJ01O
Jf/0Ef=S05mZK00205iYJ`0:05mZKP1MJ6`0FVEY04mLHP1QKW@0EV=Y05ERJ01DHFL0FVM]05ERJ0@0
Df1V00X0Df5T055OH01;FET0BeUI04iLG01:F5T0AE=D04UGFP13DE@0A59E0P13D5H03P16DeT0@E1E
03m;D00f@D@0@T]<04U?CP0k@Cl0?D5002lc<P0f>cX0FF5P03a5A`0kADL0>dI:0P0jADT01P0kADL0
=T1203<l?P0f?T00>D9103@l>`80:c4a03H0:Rh]02PZ:@0Y:b/0:BX^02d^<`0`<3P0<30i02l_>@0f
=Sh0:BX`030a=P0J6al0;B`e02d[>@0`;S/0=SDn03Lf>`0b<S@09RHU024R7@0U9R40:BXU02TY9P0/
;2X0<30_02TY:@0[:b/0>CTi03Ph>00`<300;bl_02/[:`0R8R809bLW02<S8`0S8b807Q/J028N700P
71`08ahR024L800P6b408ahT028M8`0T82<09b<T02DQ800N6QT08b4V02@Q:00R82@08b4T02HT9@0Q
81h201hM6`0801lM7P0P7R<08AlT02@Q9`0K6Ah09R@W01/I700T8RD201`J7@0=01hL7`0V92L07Q`O
01lM800K6A`071XM024M7P0K5aP07QXK01`H6@0M6AX0<Bd^02dY:P0201`H6@0C01hJ6`0J5QL071PI
02PT9@0O6a`061@E01`H6@0E4A80920Q01DA4P0S7b005a<D02<O800G4a@06aLH01H@4P0[9BL05a4C
028L7P0401H@4P0601PB500J51H06A<E01H@4P0I4aD050h@0P0E3a400`0G4A4071HF01PB4P0301PC
408061<?01L05Q4=01LB3P0H4`l05a8?01D@3@0D3``0618B01`F5P0A2`/091hP081jO00/9RP071HH
01@>400J51H05a4C04@n@00`:R`0=S0b04a6B00L5QP07QPJ014;3@0201LA4`0401D?4@0K5AL07ALI
01TC5@805a4C00`0618D01TC5@0L5QP07ALI01/B5@0I3Q806a0D01T>4P0F2`l05``@01X?4`0K41@2
01X?4`0901L<400F2`l05@/>01T@4@0K4Q<05Pd>01482@0H3a004@T9008050/<0P0C2P/0100B2@X0
50T;01D92`0F2P`201L;3@0501P<3P0F2P`05PX<01H:300E2@/00P0D20X0100>10D04PP901<92P0@
1PL201<92P0601@:2`0=0`@0>2h_05I<C@0E2``04@L80`0D20X201451`0J01D92`0D20X04`L901<7
2@0B1PP04`L901@82P0B1PP05@T;00l41@0D20X0@CDg02TM7`0E2@/04PH801@82P0C1`T040@601@8
2P0C20/04PL:01@8300E2@d04@D90105200B1PX301452@0401<72`0D20`05PL:01D62@804`@701/0
5@H901H72P0?0@<060T<01D62@0o<3<091DH01<41`0B1PP040@601H:300G2`d04`L901H:300?0`D0
4`L901D:2`0@1@L040H701H:300E2@T09QXJ028F5P0C1`L050P800d10@0E2@T00`0D20P0200C1`L0
4PH601L92@0I2`/05PP801L92@0H30`05PX:0P0B20L03@0C2PX05@d;01<;2@0B2PP04`/801D=2`0F
3P`05P`;01882@0A1`P04@D701@52P0C10T00P0D1@X00`0C10P04`@701<41`0301<41`0601@6200W
61/07PlB01841P0F1`X03P02100C10L301831P<04@8500<04P<601<41`0C10L00P0D1@P05P0B0`H0
5PL:01L82`0F1`X02P0001h?4P0Y6Qd06P/>01@6200@10@03`@201451@0?0`<03@4101P<3P0O4aD0
3`<501`A501oLgL081@H00l41P0B0`H201430`030184100C1@D050H600H04`D500H02`4201P<3P0B
1PP02`4201L;3@0>10D2018620@04@D700`04`@701831P0B0`H04@8501831P0C10L06@/=02@E600I
2Pd04`@701L82`0C10L201@520<04`@700L04P<601H82P0V61X02`0001T:3@0F20X05PL:01Cooooo
000Kooooo`0N01<72`0E2@d04@D901452@0E2@d04`L;0104200?0`L04@D90104200A1@T060`@0145
1`0D20X05@T;01<72@0A1@L040@601X>400F2P`040@60147200O4aD0BSi003T];@0F2PX07a<C01D9
2@0@10@06Ph>1P0B1PH02P0D20X040@60186200L418060`>00h2100B1PP04@D70186200E2@/201H:
30@050P:00<05@T;01@82P0D20X00`0C1`T0200B1PP04PH701451@0B1PH04`L701@8200E2@T050P8
1@0C1`L04P0>10@0<BDW0:JJW01XG5h0200001dA4`0O4aD06@d?01X>400B1PP040@601D92`0C1`T0
50P:01<72@0E2@/05PX<01D92`H050P:00d050P901861P0A1@L04`L901D92`0G2`l04PH:01D93@0F
2A006@`C01`?5P0I31@05PT@00805@T=00<05PX>01L;3`0E2@d00P0D20`02P0F2Ph05`/?01L;3`0G
2`l05@T=01T=4@0G2`l04@D901@8300H310301H:3P<05`/?00P05@X@01H;4@0G31806@hD01X?5@0K
41H050T?01H;4@806a0F00<060dC01/B5`0H3a800P0C3@l00`0H4Q@06Q@F01PB500201`F600_01dG
6@0N61X07aTK01lI6`0J4A807A@E01P@3P0O6QL07QTG014;2`0M6AP081dM01lM7P0L6Qd06aTL01`J
7@0>30d09bHT02<R800W9R@06QTG02PW9@0R8Al0FeYH02DT8P0V9B<07A`J028Q7`0T92@09BDU020P
800N7Qh0820R01hN800Q8B<081lT024P9@0U92T09RD[02DV:`0R9bP0;38b01/Q8@0N92@08BLW02`b
<P0_=CD00P0[<C404P0^=3@0;cDe02hc=P0_=cT0:C4d02H^<@0^=ST0>3m503LnA00c>T80>D1803Po
B00g?TP0?4==03a5C`0iATl0>4E>03I3C080@DiG00L0>dQA02`i@P0lBE80<3e603M4C@0jAe00=T5;
0080>dE?00H0=T9;03Y7D00nBe@0A55J045?F00kBE8203Q9D@0?03]<E00lBe<0?DY@03Q5B`13D5H0
>4E;04ICF@17E5X0@TmE03m<DP11CU@0AE9H04ABEP1XMWT0@4i?0080B5IG00H0>TQ903m=CP17EEH0
BEMH04IDE@13DE8204MEEP0/04]IF@19EeL0AeEE055OG`1>G5`0FfUZ04mMH01AGf80CeeP04eJH01A
GV@0Df1V05ISJ`1DHFT0DEiU04iKH@1=Feh0CUaN04aJG@1@GF<0E65X05QUKP1JIW80D5aY055JH`1C
G640EUmT05YTIP1OJF/0HVa^05EOH01LIVL0FF=T06=]K01OJFP0EV1Q05mZK01JIFL0DeiP05EQH@1H
I6@0DEeM05m[J@1IIF<205EQG@1c05IRGP1EHEd0F6AR061/K01LJ6P0F6AT05YVI`1LIfT0FFAV05QS
IP1HHfL0FFAX05QSJ01EH6H0BEIL059OI@1GI6X0E65W04EBF01;F5h0Df1V059OI@1AGV@0D5eS055N
I01AGf80CUaL04aJFP1?GEd0D5iN04UGF014DU<0@4iA04=AE01;FE`0C5UO049?E@0nBe40>DI<04A?
D`17DU@0@DU:03i4@P10A4<0>S`i02X^;@0]<C00=Shm03i6B011Bd`0?4M;04QCE`16DED0>TA603@n
@00g@480=Si003@m?00_=cH0:Bl_02D[:`0/;c00;Rla02d^<P0^;c@0:BTa02l_>@15ADl0ATI@03<c
>`0W9bh09BHZ03@e>@0Z:S80;2Xg02l]>00c<ST0<S4f02d];`0T92<0:BTW02d]:`0S8b4092@T02TY
:@0Z:R/0:2PZ02LW:@0/;2h0:RX/02PX:P0S8bD07QhP028R900M7Al061PJ01hN7`0T8b402`X801XH
6P0N71l09R@Y02DR:@0N6b808AlT02DS9`0T8RD08b4R028P800M6b007Q/R01`J7P0M6ah08R0Q024P
7P0201hM6`0N01hL7@0O7B8081hS028O9@0G5AX081hQ03/i?01EDeH0;B/^01XH6`0W9BP0928U024O
8P0Z:2/07A/N020N8@0O6a`061@E01/G600L61T06aLH02<O800Y9BH07QXK01lK700L61T05A4B01XF
5`0D41406ADF0P0J5QL06`0D4140:RHW02HR8`2c[k00:bLX010<3@0O6a`061@E01PB500/9RP03`T;
01H@4P0H4Q@040X<01PB500F41805@lA01LA4`0I4aD0618D01D?4@0F41806aDG01TC5@0C3@d05@l?
01H@400201D@3@0P01@?300C3PX04`h:01LB300G4Ph061<?01LB3P0E40d050l<00l:1`070@405Q0@
01TC4`0=1`T04`d?018<3P0C3@l071HH01LA4`0/9RP0<bd_020J700A2`d04P`>01lI6`0C3@l05a4C
01XD5P0F41806Q@F01dG6@0K5AL201XD5P0G01PB500G4A<05Q0B01H@4P0H3a8060dA01L<400I3Q80
60dA01H;3`0C20`05P/?01X?4`0H3A4050T=01D:3P0G3@l01P0001<:2`0K4Q<04PT:01dD5@0E30d0
0`0D2``201<:2`0701D;300H30h05`/=01H:300D20X04`L901H:300201D92`<050P:01804PP901D;
300C2@X04@L801@:2`0C2@X01`0001`B4`1`IVL0[ZBU01`B4`0?1PH04@D701<72@0E2@/04`L90186
200C1`T2018620<04@D700l04PH801L;3@0=0@<060`>00X0000;00409ATK01X>400D20X04`L90186
200@10H05@T;00P0000A1@T00P0800000`0I3A407Q8F01862P0301452@0301<72`0D20`050D800@0
5@H900T050D801H72P0H2@`04@8501T:3@0C10L05PL:01<72@0B1PP00P0F2P`03@0C1`T050P:00l3
1@0L41803P8401P<3P0N4Q@03P8400h30`0@10@060`<01D92@0H30`00P0C1`L04P0G2`/05PX:0186
1P0A1@D04`L700l20P0D1PH04@<301T;2`0I3@d04@D501H<2`0a9bH0KfET01TA3`0G3`d06A4?01@<
2@804`/900X04`T80147200@1PL040@601@52P0F1``05@H;0183200D1@T05PL:0P0E1PT02@0D1@P0
4`@701D62@0Q4QD06P/>00l10`0D1@P04P<601D62@0301@520H04`@700<050D801D62@0D1@P00P0E
1PT00`0B0`H050D801<41`0301<41`0501@5200;00004P<601T<300B1`D00P0E2@T0300@10@03`<5
00P0000J3Q00K61T08MkO`0H31008ADH01D62@0E1`L050H6018410P04`D500H05`/=0186200:0040
7A4C01lC5@0L418201<72@040186200A1@L04@D701041P804`@70P0B0`H201<41`0601@5200K30l0
4P<600d00@0?00<030000P0C10L201831P804@8500H060T<01@5200I2Pd070d@03<T9`0O41<Doooo
o`006oooool201@830804`L;0P0D20`0600B1PX050P<01@8300C1`/050P<01P<400B1PP05PX<01L;
3@0D20X040@600l31@0K3a404`L901D92`0C1`T0200001H:300=0@40200001/?3`0E2@T05PX:00l3
0`<04@D50`0B1PH0200>0P@040@601@82P0J3Q005PX<01041P0H30h05@T;0P0B1PP0100F2P`06@d?
01<72@0D20X201451`050186200A1@L04`L901<72@0D20X00P0C1`T0100B1PL04PH601861P0C1`L3
01@820D04`L701<04`L800P00018?3h0=RX/01<72@0H30h03@<401@82P0E2@/04PH801T=3`0L4180
5`/=01@82P0A1@L05@T;01L;3@0E2@/04`L900D050P:00<05PX;01L;2`0D20X00P0B1PP0200A1@T0
4`L;01862P0C1Pd05@P?01L:4@0F2A405@P?0P0E2@d01P0F2Ph05`/?01L;3`0B1PX04`L;01H:3P<0
60`@00H050P<01L;3`0I3A405PX>01L;3`0H310201D93@1K01H:3P0G2`l060`@01P<400E2Q005P/A
01L<4P0I3Q@06PlE01/@5P0H3A<06PlE020E6`0O51X06a0F01`C600H3a804P`>01@>400I4aD06aDG
01LA4`0H4Q@06A<E01XD5P0K5AL07ALI01dG5`0K4a407QHC01<;2@0M61D08A/J018<300M6AP07Q/K
01`J6`0J61/06aTL01hL7@0S8R006QTG014@3P0L6aT081lM024P7P0M71X0>CPf01@C4@0R8Al07A`J
01TH5P0T92@09BDU024Q8@0O7al08B4S020P8P0R8R@07QdR01lN8`0U92T09B@Z028S9`0O92D0:2h^
02dc<`0^=3@0=C/k05EKF`0b>3P0;S@d02dc<`0_=CD0<3Hf02le=@0`>3/0?4A703U1A00b>Sd0<3Lm
02lf?00f?DD0?DA<03PoB00g?TP0>T5;03M1BP0mBU<0?daE03I3C00203i;E00`03I3C00]>T<0?4UB
03M4C@0nBe@0<3e603]7D00lAU00?DMA03U5CP0mBU<0@DiG04=AFP10CUL0?DiF041AF@0lCED0>4UA
03I6C010CE<0>DI<04AAE`0mBU00A55G04QEF`15DUP0?T]A03m<DP12CeD0?daA041>D@14DU<0@U1A
03a:B`1=Fe`0B5IG04ECE017EEH0AE=D04=ADP17EEH0B5IG04IDE01;FET0?Ta<04eKF`1EHf<0DV1Q
0`1?GF00;`1?G680DUmU05ERJ01BGfD0D5eS04iKH01=Feh0CE]L04aJF`18EUL0CE]N051MHP1@GFD0
E65Z05EPJ`1BFf80E5eR05YSJ01LIVP0GVQZ06=]K`1GHF80IFm`05eWJ01NJ6L0FVAS05iXI`1JIVH0
GVU[05IQH`1FHV80G6QX05EQH@1IIF<0EV9O05=OF`1DH5`0Ef=O05UUH@1IIF<0IG5a061/K01HI6@0
FfMX069]K`1LIfT0FfIY0080FVEY06X0F6=X05AOI@1IIV`0D5eS04eJH01DHFL0Hg1f082=T`1GI6X0
Df1V051MH`1=FV00BeQN04YHF`1=Fe/0C5YJ04eKF`1>G5`0BEMH04IDE@10CU40AeEH059PH`1BGfD0
@TmE03]8CP0nBe00?dY>04E?D@11B4T0?T9104Q<B`0d=S<0;c<b03Xn?@0f?3`0@TY<03e7B00kADP0
AE1D04=>DP0h@T@0<cdo03U2A00g?d40<S/j030g=`0]<c<0:Bl_03Xn?`0e=SP09BHZ02l`=P0b<SX0
<S8l04E5C`11@D/0:BTa038c>00I6Qh0=SLi02@T:P0]:cH0;bhf034`=P0_;c40:b/[02/[:P0l?3X0
?Shl02LW9`0U9BL0:RX/02LW:@0U9BL092@V02HV:00W9bT0:BT[02HV:00M7Al0:RX/02PX:P0U9BL0
7AdO01@D500Q8B409bHZ030^<`0R8BL0928X01`I8P0P7bD09R@Z02HT:@0T92H0:2HW024O900S82L0
81hR01lM800S8B808b8P01lN700N7A/07Q`M0P0N72407P0P7B<07Q`Q01lM800X9RT0?S`o024O8P0O
7B007Q`O01/I700R82<0=38e020N8@0O7B007a/L01LC500K5aP07ATJ01XF5`0K5aP0;RX[01hJ6`0J
5QL06ADF01HB4`0N6Q/05a<D01DA4P0M6AX09b<T01XF5`8071PI00l0J6AU01LC500F4Q<05Q8C00h:
2`0:10H04@/=01LA4`0Q6ad050h@01XD5P0I4aD05Q0B01@>400F41800P0I4aD02P0G4A<04`d?01D?
4@0D3Q004`d=01LA4@0I4a<061<@01LB3`0F4@h201@?2`0=01PC3@0H4`l05a8>01LB3P0F4@h05A0=
01XE4P0F4100618B01dG5`0:10H07QPJ020J700201<=3`0<014;3@0U7b40@C/m02TS9@0@2P`06Q@F
01dG6@0E3a4050h@01TC5@0E3a405a4C0`0I4aD00`0J51H06A<E01PB500201PB500601P?4P0D2@d0
4`P<01P=4@0L4AD06PlC0P0G3100300H3A405P/?01<8300C20`06Q0B02PO800F3@h04`X;00H0000K
4Q<05Pd>01D<3@8050/<0P0C2P/00`0D2P/05@T;01D92`0201D92`0401H:300E2@/05@T;01D92`80
50P:01404`L901D;300G3@h05@/<01<92P0F30d04`T:00d3100H3Pl0:1hO02/Q8P0I3a0040H70104
1P0C1`T05PX<01@82P03018620804@D700<040@601451`0B1PP00P0?0`D02`0G2`d03`<501T=3`0J
3Q007A4C01D92`0C1`T04PH801041P0E2@/04`L;00806@dA00@060`@01862P0800004PH:0`0A1@T0
100C1`/050P<01<41`0E1PT201H72P0801D62@0C10L06P/>01T:3@0G20/04@8501D62@0I2Pd201@8
2P0<01D92`0D20X04`L901<72@0B1PP06@d?00P0000K3a40=2PZ02LK7@0F2PX02P000P0D20P0600G
2`/05@T901<71`0G2`/05@T901451@0E2@T06`l?01`>3P0?0@4050H601X<300A1@D03@4100h40`0c
:BP0L6IU01H>300A2@L05@d;01H>2`0C2`T04@T701471P804@L800H05PX<01421`0A0PL04@8701@5
2P0G20`201H72P0:01D62@0C10L04`@700l2100B0`H04@8500d00@0C10L05@H901H72P805@H90P0D
1@P501<41`0401@5200E1PT04P<601831P804`@701D05PL:01D62@0@0P@02P0001T:3@0H2@`02P00
01L82`0@1@D04@H401<71`0E2@T040@400h2100F2P`03002024E6@0`92P06PhB00`2100@0@@00P0@
0P800`0A0`<04`D501D71`0601<51@0701<72@0@10H05@T;01H:300U6A/03P@501@82P0201<72@80
4@D700<040@601@5200C10L00P0B0`H01P0C10L050D800`0000D1@P04P<601421@805PL:0P0E1PT3
01@5200701<41`0J2`h04`@701421@0C10L0814D00d00@0Dooooo`006oooool01`0E2@d050P<01H:
3P0F2Ph050P<01D93@0C1`/00P0I3A405@0F2Ph050P<01452@0C1`T05PX<01L;3@0D20X04PH80145
1`0C1`T04PH801T=3`0Q5AL0:1`N04/o@@1=@D403P8201061P0A1@D04`L701@8200401<71`804PH6
01405@T;01dA4`0O4aD05@T;01041P0D20X05PX<024E5`0P51H05@T;0186200D20X06@d?01dA4`0F
2P`04`L901D92`020186200801<72@0E2@/05@T;01<72@0D20T05@T901@8200C1`L201861PH04`L7
01<060`=01461`0F2P`04PL801X>400C2@X050T:01P<3P0F2P`05@T;01<72@0A1@L05@X;01<72@0B
1PP050P:01H:300D20X04`L900D050P:01D05`/<01`@400M4A<05@T;0186200F2Ph06@dA01D93@0C
1Pd05@P?01@73P0F2A4050L>01D93@0G2`l05PX>01L;3`0I3A404`L;01@8300F2Ph0100H31001@0F
2Ph06@dA01/?4`0G2`l04PH:00<05`/?0P0H3100100I3A406@hD01T>500I3Q@201P=4`0:01L<4P0L
4AL07A8H024F700N4aT06@hD01XA5P0J4A@05a4C01PB50806Q@F0P0H4Q@06`0I4aD06Q@F01/E5`0L
5QP07ALG024I5@0O614071D@01TD400Q71P071LD01hJ6@0J5aL06QPI01dK700P7Ql07adM01dL6@0Z
:BD0?chj01dL600Q81d06aXH01`K6@0D4a40:2LU02@S8@0202<Q8P07028R8P0U9BD08B4Q028R8P0U
9BL092@V02PX:P0202@S:00:02LV:`0V9B/08b@X03Pm?`0g?Cd0;S@d028X:00S:BT0;S@d02/a<@80
:2h^00`0;38b02hd=00^=3@0FV9U03Y2A@0Z<SD0<3Lm03Dl@P0_=S`0<SU103PoB@0g?TP203i5C`0g
03U2C015DU/0BUMP03a9DP0iATl0>4E>030mAP0hADh0:cQ103a9DP0iATl0>4E>03]8D@0mBU<0?daE
03e:D`11CUL0@e5J04ECG012D5T0?e1G04=DF`0oD5L0>TeC03e=D`1BGfD0@TmE045>E00nBe40A55G
04UFG015DUP0@DiD04AAE`17E5X0@e5E04aJG@1AGf00@Dm@04aJF`0jB4T0F6IW04QFE`1:F5T0AUAE
04=ADP15De@0AUAE04YHF016E5@0CUaL04UGE`13DE40CE]L04iLG`0204aJG@80CU]Q00l0DUmU04]I
G@1:F5X0BUQJ04iLG@1?GE`0C5YI051NGP1;FEX0B5II05MTJ`1RKgL0FVI_05MPI`1IHFD00P1QJF`0
2P1PJ6X0JG5c06Q`LP1TK6d0H6UX06E^K@1LIF@0H6YY05QSH`1IIFD2055MG@0b05QTH`1FHV00DemM
05EQGP1FHUh0F6AP05aYH`1QKFT0Ef=Q069^KP1MJFT0Ef9T05eXJP1SKW00GfY^05aWJ`1II6P0F6=Y
05EPIP1@Ff40BeQN055NI01EHVP0DEiT05]XKP1kR8h0Df1V051MH`1>Ff40C5UO04YGG@1:F5/0CUaM
04]IF@19EeL0B5IF04QFE`17EEH0B5II049@D`13DE@0@TmE045>E014DEL0?4U=03Y4A`0kADL0ADa<
03m3@P1>Ddl203Pj=`0703e1?@0f>cX0?DE403Dn@00i@dH0=T5503@o@`0203@n@00l03M0@P0d?3h0
;SLf02he=@0_=CD0;38b030c=@0Y:Rh09RL/030a>00/;3H0:RXf02h^>@16AU00;2`d069SJ00e=SX0
:2T[02h^<P0`;cD0<c8h03<b=P0_;c00;Bd/02TY9`0_;bd0<C4a024Q8`0T8bP0;2/`02d/<@0];Bl0
:BT[02HV:00Z:R`0:b/]02TY:`0J6Q`08b<U01`L7P0U9BL092@V04a=C`0Z:bd09BHY04=3BP1HF600
92@]024P:P0S8b`092@/024Q9P0N7b80820S02<R9`0W92/09B<W020N8@0R824081lM0P0O7Q`0700N
71d07A/P01dK800M6b406QPM02HT9`0K6A`0928U01hL7`0P7R407A/N01PF6@0F51L0928U01LE600L
6Qd07a/L01XF5`0K5aP07QXK01`H6@0H51D08AdN01LC500L61T07QXK01PD5@0I5AH301PD5@0>01/G
600H51D0;BTZ04M3A00O6a`05a<D01TE5P0X92D081`M01TC5@0L5QP06aDG01dG6@0L5QP201TC5@03
01H@4P0E3a405a4C00806A<E00X0618D01TC5@0N61X06aDG01@>3P0E3`l06A<C01PC400G4Pl05Q4>
0P0E40`00`0J5@l061<=01LB300301LB3P0;01D@3@0C3P/07QTF01<=3@0E3`l07ALG04@n@00J51H0
50h@01`F600D3Q000P0J51H201PB500601H@4P0P6Q`071HH01/E5`0I4aD06Q@F0P0I4aD201/E5`0F
01XD5P0H4Q@05a4C01H@4P0I41<06@hB01P=4@0J3a<06a0D01T>4P0J3a<06@hB01H;3`0L4AD08AHJ
01dB5P0]8bD0_;Jf04e7A`0D3Ph07ALG00`61P@04`d=0P0B30`0100E2``05PX<01H:300E2@/201@8
2P805@T;0P0D20X201<72@0B01D92`0F2P`04PH801<72@0G2`d04PH801H:300;0@806Pl@01hC500Q
5AL03`@501451`0C1`T05@T;01@82P0B1PP04`L90P0B1PP301451`0D0186200D20X040@601@82P0A
1@L05@T;01051P0L41805@T;01<72@0B1PP040@601D92`0E2@d03`D701D93@0@10P07Q<F04i2AP0B
1PX301452@0401<72`0D20`05@H901H72P805`P;00X05PL:01D62@0H2@`050D801X;3P0D1@P060T<
01431@0E2@/05PX<0P0C1`T03P0F2P`05@T;01L;3@0@10H06`lA00d3100K3a40?c<e02DI6@0C1`L0
50P801451@0D20P04@D50P0E2@T201451@0J01`@400S5aL0?Bl_00d0000C1@D05PP800l30`0K3`l0
5@/:01061@0J40l05@d;01L?3@0@20H06A4>01H>300E3@/05@/:01H<3@0G3@h050P:01@52P0H2@h0
50D:01421`0E1PX301@520804`@700L05@H901H72P0K30l060T<01<41`0D1@P04P<600805@H90P0D
1@P201<41`<04P<600<04`@701@5200C10L00P0D1@P05P0C10L05PL:01L82`0G20/05PL:00d10P0S
5AL04@@601/>400B1PH03`@201451@0C1`L040@401451`0C2@X04PP9024E6@0D20`05`d?01H:3@0E
1PT201@61P804`D500<050H601<51@0C1@D0100C1@D01P0?10D03`D601H;3@0X7Ah0OG5c01P>3`@0
4`L90P0B1PP201@520804`@70P0D1@P01P0C10L05@H901<41`0B0`H050D801<41`8050D80`0C10L2
01831P0501X;3P0<00405PL:01@6200H2P`05?ooool001_ooooo00d05@T=01<72`0H310060`@01<7
2`0E2@d040@801L;3`0C1`/04@D901<72`0?0`L04`L900805@T;0P0C1`T09`0E2@/02`0101L;3@0P
51H050P:00T0000W6ad08QPH02LL6P0900007A8@01L<2P0=0P005``:01H;2@0E2PP050T701871@0A
1@D040@601T=3`0M4A<05PX<01D92`0L41804PH801451`0?0`D04@D701lC5@0X71h0;20R02lS9@0Q
5AL05`/=01D92`0?0`D04@D701<72@0201D92`0301<72@0C1`P04`P600X04`P601804PH701@82P0I
3@l040@601D92`0>0P@06@d?01451`0;00405`/=01dA4`0/8280;b<U01<72@0D20X04`L90186200C
1`T601@82P0301<7200B1PH04`L900804`L900X04`L;01D93@0A1@T05@P?01X=500F2A0050L?01<6
3@0E2@d060`@0P0F2Ph00`0J3Q805PX>01H:3P0201D93@0901H:3P0G2`l06@dA01L;3`0J3Q806`lC
01L;3`0K3a<06@dA00@060`@00D05`/?01T>500I3Q@06@hD01P=4`0201L<4P0701/@5P0J3aD06a0F
01T>500E2Q006A0E01XA500201hH6P0401TC5@0G4A<06Q@F01/E5`@071HH00h071HF01TB300M5Pd0
=c0X01TD3P0I514071LD01dI600N71X07QdK01dL6P0N7A/081lM02h]:@807A`H00/05aHB02<R7`0M
71X08B0N020O7@0S8R007adN01PF5`0R824092@T02LW9`02028R8P0302DU9`0T92H08b<U00808b8W
00X08R4V02<R:00T9BT0:Rl`02dc<`0N92@0:Bl_030f=P0]<c<0;S@d0P0[<C404P0_=CD0<CLg034g
=`0k@dH0=ci403Dl@P0i@4H0=3]302Xa>@0b>D40=3]503Y1B`1:DE/0AdiH03Q1B`0d@DX0=D9;03Q5
CP80>dQA04@0=dA=03a9DP0^>d@0?DYC041=EP0hADh0=D5<03m;E`11CET0?daF04=@F@14DU/0AEAM
041AF@0lCE@0?U1G03a?E@0mD5H0B5QN06]hOP1DHFL0@e1F03a9C`0mBU00@4eC03e:D011CU@0AE9H
04AAE`11Ce<0Gfe`0;2n_`1EHf@0>TQ904=ADP0nC4d0CE]L04mMGP1:F5T0AUAE04QFE`17EEH0CUaL
04=AD@1=Fe/0@4i>05YXJ01GIFH0E69U04mMH01>G5l0CeaR04]HGP1?G680EfEX05ARH`1BH640Df5Q
051OG016EE40?di;04QFEP1<FU`0AU=I04YGG@1FHVT0GVM/05UQI080GVIY00T0I6a_07^3Q@2OYjT0
SiRH06]dL`1YLVl0I6eZ05USHP1NJ6T00P1FHV804@1GHf<0EV9Q05MSH@1MJFD0H6aX05eYI@1HIEh0
Df1I05=OF`1HI680FFEU05EQH@1HHfD0H6]^05iYK@1JIFT0F6=X0080Ef9X00/0E5mU051KH@1EHVP0
D5eS04=@EP1DHFL0P8fC0:Vf_01>Ff40C5UO04]HGP0204YGG@1I04]IG01<FU/0BeUI04UGE`15De<0
@U1A045?D00lBTd0@U1C04IDE`0nBe40>DI<03e:D01HHfL0GVQZ04A>C`0nA4@0;30_03m1?P11@ch0
@dE203Tk>00j?cd0?TA404I>D00jADP0=3m3034l@00b?3h0<cdo03@m?`0a>C/0;3Dd02T`<00Z<300
:c4a02HZ;00Y:Rl0<S8j038b>`0Y:C<0:2Pd02h^>P0P82X07AdU038c>00N7b<0<C8d020P900Y:2d0
;2/`02/[;@0W9bL09bLU02XZ:00^;R`0;bl_02d]<00c<SP0?3]303/j@00b<CH0;Rdb02/Z;`0`;c@0
;2/`02<R9`0Y:2d0@d97024P9@0];340EUEJ0=SIg@14B4/04aHK03Dh?`12ADh061XV02T[=`0W:S<0
9BP`02<V:`0Q9BP07b4U01hM8`0U8RT0:2HZ028P8`0R82400`0O7Q`0200M6a`06aTN01/I7P0K6Al0
5Q@I02DS9P0F51L07A/N0P0J61/01P0O7B008R0S01TG6P0L6Qd06ALJ01hL7`8071PI0P0K5aP02P0L
61T06ADF01`H6@0L61T081`M01XF5`0C3a007a/L01HB4`0K5aP201TE5P0>01lK7015@D80Z:BU01TE
5P0N6Q/07ATJ01HB4`0L61T05Q0B01LA4`0A2`d040X<01hH6P0D3Q0201H@4P0801LA4`0I4aD06A<E
01H@4P0G4A<06aDG024K7@0M5aT201<=3@0401D?3`0D3``050l<01@?308050l;00@06QD?01PC3@0G
4P`05a8<0P0H4`l04@0P6aP050l<028M6P0D3Ph04P`<01@>3P0I4aD05@lA018<3P0?2@/0618D01`F
600I4aD07QPJ01LA4`0I4aD07QPJ00806aDG0P0M5aT01P0J51H06A<E01XD5P0J51H06A<E01PB5080
5a4C00H06a8E01lD600O51P0714E01P=4@0G310201D:3P0901T>4P0U6Qh09Q/O01hC5`0H3a409b4Q
018<300H4Q8071HF00804`d=00<050h>01<=3@0C3@d00P0B30`0100D2``05@T;01D92`0D20X201<7
2@<050P:0P0C1`T0300B1PP060`>01L;3@0D20X060`>01`@4P0G2`d04`L901L;3@0:00403P8400`0
0P804`L90P0D20X00`0B1PP04@D701@82P0201<72@<04PH800<04`L901D92`0:00000P0F2P`0100>
0P@07Q8D01H:300B1PP201<72@0901041P0D20X0200001452@0K3a<040@80106200b9RX04PH:00<0
4@D900@04`L;01@8300G20/05PL:0P0E1PT03P0F1`X05`P;02<D5`0L3A005`P;01P9300D1@P03P02
01<72@0F2P`04@D70186200H30h05PX<0P0E2@/07@0:00005@T;01H:300800003`<301861P0A1@D0
3`<301P<300A1@D050P801861P0A1@D04`L701L;2`0I3@d05PP800h0000G2@T070h>01@8200E2@T0
3`D501`B4@0J40l03`L501@<2P0A2@L04@T6008040P600`04PP701<92P0C2@X04@D701D62`0O41D0
6@X?00d00`0B0`L04`@701@5200E1PT301H72P0500h00P0H2@`05`P;01831P0I2Pd0100C10L30183
1P<04`@701h050D801D62@0D1@P04`@701421@0>00804`@701H72P0@0`D060T<02dN8@1nKg8070d@
00X0000I30`04@H401L;2`0F2PX040@40186200K3a402@0001L;3`080000:AdQ02PN800I2Pd060X:
01H8200D1PH801<51@0601H:300>0P@02`4200`00P0A1@L050X;0P0A1@L201<72@0301@82P0E2@/0
5@H9008050D800L04`@701@5200E1PT05@H901@5200F1`X060T<00806@X=0P0C10L201831P804@85
00H03P0201431@0B0`H0404401X;3P0K30lDooooo`006oooool02`0F2P`04`L901T=3`0I3@l04`L9
01H:300@10H05@T;00l31@0>0P@050P:00804`L901l05@T:01@82P0B1PP050P:01L;3@0H30h04@D7
01D92`0E2@X0200001`@400T61L0ZIfM048g=@0>10@06Ph>020E4`0I3Pd05`/;01H;2@0D20L04PH6
01451@0D20X05PX<01T=3`0B1PP0300201041P0C1`T050P:00805PX<02`04`L90186200K3a408QHH
01L;3@0D20X05`/=01<72@0@10H04`L901D92`0F2P`04`L901861`0A1P@04PH601<81`0D2@L05@T9
01@9200C20H04`L701<81`0C20H04`L701D92P0>0P@0710B01L;3@0I3@l040@601451`0H30h07A4C
02`P8P0G2`d04PH801lC5@0D20X05PX<01<72@0@10H04PH801D92`D050P:00l05@T;0186200A1@L0
5`/=01T=3`0C1`/05PX>01@8300N4AP09APO01lB6@0I31<04`L;01D93@0H31000P0F2Ph01`0K3a<0
60`@01L;3`0E2@d050P<01D93@0G2`l00P0F2`l01@0L4AD06a0D01X?4`0[82@06@hB008060dA00@0
5``@01H;3`0F2`l060dC1@0G3Q<02`0I41D05`hC01T@5@0H3a@05PdB01`C600I4aL08A/M020J7P0I
4aL05Q0D00806aDI03006aDG01/E5@0K5AD06aDD01XE4@0J4`/091dC0519@@0V8A/07QTF024K6`0K
5aH0920O028Q7`0N6QT071TH024P700G4a0081hJ01PG4`0M71P061LD02DT8P0f=C<0<c8`018@4@0X
9RL06aTJ028R900W9bT0:2PZ028T8`0Q8R408b<U024R900S92H09bLY02DV:00T9BL0:2PZ02//;P0]
<S809bd]02@Z:P0[<C409B/[034g=`0]<c<202T_;`0Q02`b<P0]<c<0;C8e02hf>P1:DEL0A4]A02lf
?@0b>D40>T5903PoB00g?TP0?4E?04iGH018D5/0@DYD03]8D@0e?dT0>TE?03]8D00jA4d0=418034n
AP0h@T`0A51I05UUL@18DUh0?TYF04=?F`15DEd0@TiJ04EBF`16E5d0@e9K0080?4eE01T0@E9I03e@
EP0lCE@0>4Q>05]XKP1<FEl0A55G03m<DP0mBU00@DiD049?E@18EE/0BUMM04EBF010CE<0=dE8075o
P00gADH0D5iO03=1@P11Ce00@U1A04ABD`11Ce00@4i?0080A59C02P0BEMH04MEEP15De@0CE]L0:Bb
/`23TI80DEmP04]IFP1:F5T0BUQK04ECEP18EUT0AeEF04IDE@19EeL0DEmO059QGP1;FUL0CEaI04QF
EP0oCDh0AE=F059OI@1HI6X0HF]]05QPHP1JHV@0Ff=V06Y_LP28SI00k_?f0=kTi@29TY40Ig1]05mX
I@1HHV40G6QV055MG01GHf40FVIV0P1CGed0>@1EHEd0FfMS05eYI@1JIf00EfAM05QTH01KIfD0EV=S
05=QH@1KIVP0Hg1b05e[KP1II6P0EV9X05ERJP1IHf`0EV9Z059OI`15DUP0D5eS04eJH01?G640E69U
06EcMP1@GV40CE]N04]HGP19EU`0AeAJ04MEF01:F5T0C5YK04]IFP15De@0?Ta=03a:B`11Ce80@TeA
03m:CP0iA4P0@Da@04eHG02LYjT0D5YK01dU9`0i@Cl0;C4`02hc;`0f>cL0@TI503Di>00l@D40?D=3
04mGF@0lATP0>TA603I0@P02038j?@0i03Dm@00c>cd0<3Dh02X`<@0Y;bl0:Rlb02la=@0_<3D0:b`a
02LW;`0/;3@0:2Pb01hN:00W9c406ATQ024R9`0X:Bd0:BX/02DV:@0Y:Rh0;Bd_02//;@0W:BP0:BTY
02`];00Y:bX09bLY02LW:`0V9b`0;Rdc03@c>@0`;cD0;2/a02d/<P0f=CX0<C0f02PW;00N7B80<c8g
02LV:`0f=CX0>c/o04I7C00`<cX092H]02<S;@0T9c009bPd02DU<@0P8b`07b0Y02<T:@0R9BX08B8V
01`K8@0U8RT0:BL]00809B<V00D08R0Q020O7@0O7Q`07A/L01/I700201XH6`0>01dK7P0V92L05aDH
01lM800H5QT071XM00l=400L6Qd07A/N01lM800J61/05aDH01TE5P0K5aP201TE5P0W01/G600I5AH0
5A4B01TE5P0J5QL0510A01hJ6`11?Ch09b<T01lK700J5QL07QXK01DA4P0Q7Ah0<Bd^01@@4@0E4A80
2`L801PD5@0C3@l08A/M01D=400V828091/N01/C5P0I4aD05`hA01L?4P0H4Q@071<F01XB5@0E3a40
6A<E01D?4@0G4A<05@lA01<=3@0F41005@l?00<05A0=01@05Q4>01HA3@0K5Q4061<?01LB300G4Ph0
61<?01TD400L5a@03`X700`7100G4A4071HF01TC4`0J51H05@lA01PB500M5aT081XL00l92`805a4C
00D05@lA01hH6P0K5AL071HH01PB500201`F600301PB500F41805a4C00806A<E01H06aDG01dG6@0O
6A/07AHH01dD5`0Q5QX07A<F01P?4P0J3a<060hA01XA500V6al0;bDY02PO8P0M4QH06A0B01@>3P0Z
92@0=2h^04]5A@0J51@0618B0P0D3Ph02P0D3@d050/<01@;300B20P04@D501861P0D20X05PX<01L;
3@0D20`201@82P0?01<72@0B1PH04PH601@82P0C1`T04@D701D92`0J3Q0050P:01L;3@0@10H04`L9
00h2100A1@L03`@5008050P:00D04`L901041P0A1@L05@T;01@82P0201<72@0D0186200C1`T050P:
01D92`0@10H05@/<01<72@0A1@L040@601@82P0A1@L050P:01<72@0@10H04`L901L;3`0D20`04PH:
01<72`0D20`201862P<04@D900@04`L;01@8300H2@`05PL:0P0D1@P01P0F1`X060T<038S9P0Z6ah0
6@X=01/<3`805@H902P04PH801H:300A1@L04PH801T=3`0G2`d05@T;01041P0C1`T040@600l31@0G
2`d05PP8020D500K3`l04PL701D;2P0:00004PP701061@0B1PH04`L701<51@0A0`<050H601T;2`0A
0`<04`D501P<300D20P0718A01471P0N51<03`L601`B4@0@20H040P501491`0B2PP050X90P0E2``0
4`0E2@/04@D901P<400D1P/03`0501<62@0C10L050D801H72P0H2@`06@X=01`=400B0`H06P/>01H8
2`0>0P@05`/=01441P0C10L00P0B0`H201421@0N01<41`0E1PT050D801@5200E1PT05PL:01D82P0E
2@/04`L90186200K3a408ADG01d>4@0H2@`02P0001/>400:00007PlB00d20P0C1`L07A4A01X>3P0A
1@D04@D700l31@0G2`d03@<501H:3P0H31004PP90P0C1@D20184100301<51@0D1PH04`D500D04`D5
00H02`0001dA4`0@10H08ADG00P0000E2@/201041P050186200D20X050X;01H:300C1`T00P0D1@P0
100C10L050D801D62@0G20/301<41`040101100?00<05@H901D62@<050D800L04`@701d>4@0@0P@0
7a0C00X0000L3Q003@0001Cooooo000Kooooo`0<01P=300F2PT04`P701<71P0E2@P05`/:01D:2@0B
1`H03`@30145100G30/0710?0P0D2PT01`0F2PT04PH603da<P0R5QP040@601451P0B1PH00P0C20L0
0`0C1`L05Pd<05I<C@0201H<300=00d3100I3`l05P`<01892P0@1`L06a8B00/20`0E2``0<RHX0147
200@1@H050P:01X>400301@82P804`L90P0B1PP05P0E2@/050P:01@82P0E2@/04`L901451`0D2@X0
4PP901<82@0E2@/07Q8D00l51P0T6QX0<2HW01`B4`0@1PH04`T:01<92@0B20P050X;01D;300D2PX2
01<92P0H0147200@1PL04PP901@:2`0B20T04`T:00d3100G3@h07aDF01P>3`0F30d04PT:01H<3@0H
3Pl05@/<01@:2`0C2@X04PP901P>3`0J41405@/<01882@0C2@X050X<100C20`02P0D2@d05``@0146
2P0R5a/0:QlS01P=4@0C20`04PL;01@93@0F2`l201<8300a01P=4@0J3a<05``@01<8300A1PX050T=
01P>4P0G3Q<04@X>02/T:00B2`l0610E04i6B`0Y8RH02P<701P@5@0P6Ad04``@01H?4`0H4QT04`dC
01H@5P0F41L050hD01PB600G4AP05Q0G01TC6@0G4AP04`dD01LB5`0I51P07APL01TD6P0C3QD06QDM
01PC6P0M61h07APK01/G500K61806aT?01/I3@0M6@d07a/@03Te;00K5Q007QPG028L7P02020J7@0@
01lJ6@0P6QX07a/H01lK5`0Q71P08QhJ02<O6`0S7a`08alM02<O7P0N71d071XL01hL7`0R8R@08b<V
024Q9@80:2X^00L07b<U01hQ8`0X:b`082@T024U8`0S9b@092TV00809b/V03409R/V02H/:00S:BH0
7B<P02`b<00Z<2h0:c4_02/a<@0Y;S40;S<f02db=@0/<C@0<3Di030g?P0g?TH0=Ca403]2B`0d?DH0
<ca503Y2C@0g@4`0=d9=03U4C`0kAU80>TAA03U2C`0j@Td0?4I>03e7C@0lADX0>T=803Y4BP0h@DX0
>T=?04M?GP18Cf40@4YJ04ECH01:F6D0AUAQ04MEH@1;FF@0A59M04eKI@0mBe@0CeeV03e<E@0mC5<0
?diE0080@4mF00D0A5=J04EDF`13DUT0@e9I04ACFP0204EDF`0O04=BF@12DEL0?Ta?04ECE00lBT/0
A59C045?D00nC4d0@e5B04ECE012D540BeUJ03a:B`1;FE/0A5=H04aKH010Ce<0EfIZ07n>T@1RLW<0
D61P04eMG01<G5X0D61M051QG01:FUL0CUaM05ARH`1<FU/0AeEF04]IFP0204UGF00J04IDE@17EEH0
CeeN05ARI01CHF80E61P05MQH@1MIVD0HFMX075cM@2ZZjd0j>WZ0=CGf01mPh<0I6e/06]eL`1KIfD0
FfQU05MVHP1JJF@0FVUU05MVH@1IJ6<0DF1K05=RG@1EI5l305IUH020055QG01GIf<0EVIS059QH01A
H640EFAW059PIP1CHFP0E69[05ERK01AGVX0C5US04aIH@1=FUl0CUaO04iLG@1=Fe/0CE]J04]JF016
E5D0BEMI04YHF`19EU`0C5UO04UGF`10CE80AUAH04ECE`10Bdl0AE1D04YDF01BG5h0@D]=03]4AP13
C4h0A4e=03a6@`0c?3P0=Chj038k>00^=C<0;cLd03Lo?@0b>CX0<CPi0418B@10B4X0<3Pj03Pm?@13
B4P0@DI603Xo@00g?3l0<3Dh02X_<P0^<CD0<3@h02ha=@0h>d00>ce102`]<@0Y:Rh0:2T^02<T:@0R
8bP0:2T]02DV:P0a<SH09RL[02h_<`0Y:Rh0;Bla02X^;`0X:b`0:2`]02T];P0Z;Bh0:bl_02HZ:`0U
9bT0;C0b02L[;@0P8RD0<c@j04a<E@0`<3T0;Bde02TY<00X:300:BX_01lP9@0T9BT0<C8f03<d>00e
=SX08R4]03hlB`0X9c@09B<`02<R;`0Q82/0<2hh02HU;@0R8RP08R4W01dM8P0S8RL07Q/U02HS;P0R
7bT0A45903<`=`0Q7b@081hP020N7`0N7A`071/H01/J5P0K6QL07a/K01`H6@0P71d06QHG020L7@0R
7Ql06aLH01`H6@0O6a`2020L7@1401hJ6`0]:BX06aLH01@@4@0d<340>cLh020L7@0K5aP071PI01XF
5`0H51D07QXK02DQ8P0K5AL071HH01XD5P0O6A/05a4C01hH6P0M5aT07aTK01dG6@0I4aD071HH01H@
4P0J41L07A8I01D;400I3Q@07A8G01dC5P0N4aL06@lB01L>3`0I3a006A0@01L?3P0F41006Q@D010:
2P0G4A403PP801dG5`0J51@02PD501TC4`0H4Q8050h>01XE4`0I51406QDB01D@3@0G4Pl05Q4>01@?
300H4a005A0=01/F4`0J5A805A0=01`G500M51D07QDF01T@4@0L4a@07aHG01`C500O5QL401hE5P0c
01hE5`0K5AT07QPL01PB5P0P6Qh06A<G020J7P0@2Ph09AlS01/E6@0L5QX05@lC01/E600P6Q`08a/N
01XC5@0J51H07QHI01`E5`0J51H0:b<V02LP8`0B30h0614C01TA500N5AP05@lA01`G6@0;1`P05a<D
018>3`0D3a005PhA01L=4@0F2Ph05PP=01D92@0F3@L05P`:01H<300E2``050T=01<83P0N4aL081HF
01881`0@1`<05Pd901@9200D20P05`/;00806Ph>00h05PX:01<71`0B1PH04PH601451@0B1PH04`L7
01@5200@0@@05`P;01421@0G20/05PL:01D62@D05PL:00<040H701lC5@0P51H00P0@10H03P0A1@L0
6@d?01<72@0A1@L04PH801@82P0A1@L050P:01451`0F2P`040@601@82P0@10H050P:0P0C1`T02@0D
20X04`L901451`0B0`H05PL:01h?4P0F1`X05`P;01@5200201H72P805@H90P0D1@P01P0A1@D05@T9
00d20P0T61P0DTI601461PD04PH601/050H601H62@0D1@P04@D701X@4@0C30`05Pl?01D=3P0=10D0
50X;01P;3@0H20/05@P801<71P0E2PP05``:01@91`0J3`d08aPF09Z?S@1KD4h060d;01H;2@0N4a40
5@/901L=2`0E2`X00P0D2PT201D;300B01<92P0C20`04`P<01872`0A1PX04PL;0104200^8RH0VhjB
01T:3`0B0PL070`A01H7300E2@d04`T<00/51P0<1`T050/=0P0B1PP301451`0@0186200A1@L03P84
01451`0E2@/05PX<01X@4`1bJfd0Ng=f028I700>1@L0DTM;01D93@0C1`/05@H;01D52P8050<900D0
5@L:01@82P0@10H03P8401<72@0200h3100601451`0B1`P05`/=00l41@0@1@H050H60P0C1@D02P0B
10@04`D501@61P0N410060X:02DG5`0;00005`T901861P0E1`L201@61P0G01<51@0D1PH04`L901<9
2P0@1PL040H901H>3`0C2Pd03`D901X@4P0_8bL03`@701/?4`0G2`l03`D70104200A1@T04`L;00/1
0`0^8RH0O71d01D93@0C1`/00P0A1@T0100C1`X05@T;01451`0A1@H201451@0301461@0A1PCooooo
01?ooooo000Kooooo`0801@8200C1`L04PH601<71`0F2PX060`<01@8200C1`L201861P0<01D92@0G
2`/04@D500h30`08000060`>0186200K3a406Ph@01L;3@0D20P04`L70P0D20P04P0A2@T03@<400d3
100G3@h0308301<92P0F30d06@l@065GF01iKg003`D601061`0J3Q007Q8D00P0000M4A<04PH800P0
00805@T;0P0D20X301<72@050186200C1`T05@T;01@82P0B1PP00P0J3Q002@08000040H702TM7`0>
0`D06a4B024G600E2``04@L801<92P0201061`090147200C2@X04`T:01<92P0D2P/04`T:01882@0D
2P/05@/<008050X;01@05`d>01P>3`0C2@X02@0000l51P0I3a003@<401T?400?1@H08ALH0147200B
20T06Q0A01L=3P0C2@X03`D600h41@0D2P`04PL;01<8308050T=00H05@X>01462P0?10P04`P<01H;
3`0C20`201@93@0701D:3P0F2`l05P/?01H;3`0J3a<05@X>01H;3`0201P=4@1701L<400E2`l02P46
02TS9`0c;C403PP<00L11@0F41@03PP<01TC5`0C3A406Q@H01/E6@0C3A405A0F010;4@0A31804`hD
01`G7@0C3Q@06A@J01<>500H4aT071LM01PC6@0D3aD071LK03@_=00K5Q`081/R02@O9P0M61l06QDK
01XE600I5A806QLB01/H3P0L6Pd0:2HI024O4`0P7A@071TB038^;00J5QL081/O020K7P0O6aX07QXI
01dJ5P0L6A@07aXG020K600Q71T081`K020L700P71d07adP01dL8@0N7B808R4V02<R:00Q8RL0828V
024U:00G6ah07R8S02DY:00R9RD082@S024V8P0R9b<00P0S:2804@0R9b408bTU01hT8P0X;R`0:c4_
01PN7P0f?3`0;C<c02X_<P0/<C@0;C8e02ld=`0c>3`0<SU0038i@@0mA4`0:34j0080>45:01d0>D==
03Q2CP0h@dl0>DEA03Y6DP0kAE80?4AA03e5D00lADd0>45803Dn@`0e?T@0>T=:03a5CP0mAE40@TUI
04A;GP0nB5T0@U1M04MEHP15Df00AUAQ04MEH014DUd0AE=N03E3C011CeP0?deF041?EP0203m>E@06
045@E`16EE`0B5MN04IEG015E5/0AeIM0P18Eeh08@15E5/0@E1F03e;CP1SLG80@Dm@03]9BP0`?Sl0
@U1A03]9BP13DE80AUAE04aJF`14DU<0AE=D04]JG@1<Feh0BUUL049AE011D5<0D5mQ04]KF`19FEP0
BUYI04iNG@1>GU/0B5QG045?D01=Fe`0EfEV04=ADP1CHF80FFMX04QFE`0204ECE00G04aJF`1?GEh0
CeeM04YHF01JIV@0DE]J05]TH`1XKFd0IFUZ08N8RP26Rh`0H6UX05USHP1JIV@0Df9O05]ZI@1CHUd0
E6=N05MVH@1FIF00EfIQ059QG01DHeh00P1FIF009`1GIV40EVEP05IVH`1FIV<0Df=P05=SHP1CHf@0
E6=V055PI@1EI6/0E69[04iLI`1<FVD0D5iW04iKH`1>G600CUaO04eKF`1:F5P0BEQE04mNF`1=Fe`0
CUaM04UGFP16DeT0BUMM04QEF`11CU@0BEIL03m=D019E5P0@Da@03Q2A011Bdd0F69T03Y2A00d?3h0
=3dl03Y3?`02038k>00603@m>P0f?ch0>T=203M0?`0g?d40<c/m0P0j@T@06`0a>C/0=c/l03i2@`16
BT/0=SXk02/_<P0b=ST0:Bd`02HY;P0Z;C80;C0e03Hi@00k?D80:2T]02d^<P0V9b/07AhR02PY;@0P
8BD07b0T02DV:P0/;C40=3Di01TJ7P0[;C00:2`]02HZ:`0202DY:P0402@X:@0N8R<0;c<d01/O8080
<CDf01`0>3`m06]]LP18B580<30j02PX<@0L72@0:BTa0411A`0i>Sl0;2da02PY;@0T9BT0:b`a020N
:`0c<Cl0:bTg02TW=00S8Bh0<Blj028Q:@0N7BD09bH/02d/<P0T8bT07ahS02@Q:P0U8R/07AXR0P0I
5Qd03`0P7R<071XM02<Q8P0Z:2P08R4O01`K5`0M71P07ATH01LC500M6AX06ADF01/G600M6AX06QHG
01/G600301dI6P0801`H6@0J5QL08AdN01/G600P71d05A4B00h:2`0L61T201dI6P0701`H6@0N6Q/0
8AdN014;3@0H4Q@04`d?01TC5@0201LA4`0c01`F600A2`d03PP:01hH6P0J51H06A<E028H800E3180
60lD01H=4P0M51P07A@G01T@4`0G3Q005`h?01T@4@0J4A40610>01D?3`0K5AD03PP802DO7`0I4a<0
4P`<01@>3P0R71`08A/K01hH600M5aL0=2h^02HQ7P0K5Q<07aXG01LB3`0L5a@04Pd:01D@3@0?2PL0
7QTF01PC400J5A805A0=01P?400K4Q<06Q4B01dD5@0O5QL071<D02<J6`0P5aP07QDF00<07A@E00H0
7QPL024L800K5QX0:bHZ02lZ;P0^:Bd2024L800601/F6P0X8bL06aHJ01`F6@0H4Q@06Q@F0P0I4aD0
8P0F418050h@01/E5`0E3a404`d?01PB500G4A<06A4D01`C5P0=1`T040/<02/W:00@3Pl04Pl@01DA
4P0H3a806@hB01P<400H2@h05PX901@;100E2`T05@/:01@:2`0C20`03@8601hC5`0T6QX03P@300/2
000R6A@050T701@8200E2@T201P<300301@8200C1`L04`L700<04PH600H04`L701T:3@0@0@@05PL:
01P9300O41<701@5200401<72@0L41806Ph@0186208050P:00/05@T;01<72@0A1@L04`L901@82P0B
1PP05PX<0186200D20X03P8401@82P020186200;01L;3@0F2P`04@D700l31@0B1PP070d@01421@0B
0`H03`0301L82`0B0`H00P0F1`X201D62@8050D800H040@401D92@0C1`L05`/;01D92@0K3`l50186
1P0>01@61P0I2@`05@H900`00P0L4Q<05@l?00d71`1;ADD0;RDV01061`0C1@P091@G0141100C1PH2
01P<300:01861P0O4a<0;R8R0=O;b`24N7P05@T901T=3@0F2PX050P801@:20805@/:00@04PP700l5
1P0=0`@04@L80`0B1`/03P0@1@T04PL;00d21P0A1@T07A0D00X0000c8RP08a<I01<42@0900409adQ
02HP8P0;1`P030@60P0A1@L30186200@01D92`0C1`T04@D701P<3P0M4A<060`>02HL7P3KeML0ooKi
03P_<P0I41<01`0001872`0C1`/05@H;01D52P8050<900L0:1TM01`@4P0@10H06@d?00l31@0?10D0
5`/=00805@T;00@040@601P<3P0E2@/050H60P0C1@D06`0B10@04`D501@61P0:0000818B00l10@0K
3@d05`T901/=3@0E1`H050H501@61P0C1@D050H601<72@0C2@X040H700`31@0600005`hA00l62@2/
X:@0^Zjb01lC5`0@10P04PL:01lC5`0200h21P0601H:3P0C1`/060`@03DY;@0E2@d050P<0P0B1PX0
100D20/05@T;01451`0A1@H201451@0301461@0A1PCooooo01?ooooo000Kooooo`8050P80P0C1`L0
100E2@T05`/;01@8200D20P401<71`0O01hB4P0G2`/05PX:01D92`0B1PP04`L901lC5@0L418060`>
01L;2`0I3@d06Ph@01/A4P0=0`@07Q@E01061`0=0`@05`d>01H<3@0B20T0HEMH071VI`0?1@H05`d>
00d3100I3@l020000147200:0000:AdO01<72@03018620804@D70P0C1`T03@0D20X05`/=01H:300D
20X03`D60186200L41809a/M09>7R@0h;Bl050X;01H<3@0A1`P00P0B20T00`0@1PL04@L801882@03
01882@<04`T:0`0D2P/03P0@1PL04`T:01D;300=0`@03P@501D;300C2@X04PP901H<3@0C2@X04PP9
01@:2`0G3@h04`T:0P0J41403P0@1PL04PP901472@0B1`/04`P<01@93@0E2Ph05P/?01D:3P0G3100
5@X>01<8300G310060dA1@0F2`l00`0H3A405@X>01H;3`0201T>4P0701P=4@0E2`l08QTN01lI7@0F
41@06A<G030Z;P0201hH700W01TC5`0F41@06Q@H01XD600C3A405a8H01D@5P0O6R00100500h93`0?
2Q006QDK01@?5@0H4aT06aHL01TD6P0J5A/04@`@02@O900F4AL05Q4H01LB6@0E41H071LM01/G6@0J
5Q<06QLB01/H400L6Ph04a45055?A00o?3D0:BHQ03Te<`0I5AH06aHJ01`G6P0M6AX07ATH00807a/H
024081/H028L700S7Ad08QhM028N7`0Q72007adP01lN8`0P7b@08b8W02<R:00Q8RL08BDX01TM800f
>Sd082@U02DY:00M8B008bLV02@Y9@0U:RH09BXT02@Y8`0S:28092XV02@Z:00Z<2h0<SPf03a2@P0h
?Sh0;38b02`a=00_=3L00P0`=CP08`0a=SX0=Se402P_=`0g?TH0>T=<02/d?@1>Ef00=d5;03Q2CP0g
@Th0=T9>03Q4D00h@dl0>T9=03e6C`0lADd0=d1703Dn@`0f?dD0>T=:03a4C`0mA580@4MG04A;G@13
CEd0AE=P04QFH`13DEh0@4iK03m=F010CUT0AE=N03e;E010CUL0?deF0080@U5H00L0@E1G04=BF@17
EUd0B5MN04EDF`14DeX0AUEL0080AeIM0100@e9I03i=D`0lBTd0O8Z;04ABD`17EEH0@e5B04YHF@16
E5D0DEmP04=ADP0nC4d0CE]L04iLG@18F5P0@U5D0P16EEP07P13DUD0EfMW04]KF`1:FUX0Be]K04eM
G@1;Fe/0AEEE05ITI@10CTl0D5iO04UGF01<FU/0BEMH04QFE`17EEH0B5IG04iLG@1AGf00DV1Q04eK
F`1JJ6D0D5aJ05aVI@1RJFT0DeUI06E[J`1ZLG40G6IU05]WI@80Df9O00T0F6MR05ASGP1FIF00EVEP
05=RG@1FIF00DV5L05ASGP1FIF000`1GIV404@1BHUl0DF5N05=SH01GIfH0F6QY05ETI`1DHfP0EFAZ
055OJ01=FfH0C5YU04mMIP1;F600C5YN04eKGP1=Fe`0C5YJ0080C5]H0180C5YK04iLG@18EUT0AE9H
04UFG018EE/0@TmE04aIG`0oCE00DUeQ04=>DP12C4h0A4i@09:LWP1HH680=Cdo04YCDP0h@Cd203@m
>P0603Ho?00h@D00>T=203Dn?@0g?d40<SXl0P0a>C/0?00/=3H0<SHg03<g>00i?Ch0<SHg02da=00d
>3/0<CDh02LZ;`0Z;C80?D1503Tl@`0`<SL0:b``0411A@0g>3`0824U02X[;`0V9b/0IFIZ03@e>@0X
:Bd0<S<g01`M8@0];c80:Rh_02L[;00U:BX08bLX020T9@0M8B80LGEf02HZ:`0G6a`0:2`]01`P8@0h
>Sl06a/U02h^>00V9Rl0<C4i03Ph@014AD/0=CHk02PY;@0S92P08B8V02`]<@0R82d09bDc028P;P0[
:CH0;B/h04Y8D`0o?TH0<c8j02/Z<00Y:2h08b8X02DT:@8081dT00P09bD[01XG7P0Q7b@09B<X01XH
6`0O7B00928S01hL7@806QTG00L061@E01DA4P0U8B8081`M01/G600M6AX06QHG00D06aLH0P0L61T0
1@0C3a005a<D01LC500T824061@E00D06QHG00H05@lA01`F600E3a4071HH01dG6@0K5AL201LA4`0P
01`F602ARhd091hP020J700S6B4050/A01dD6@0J4AH07aHJ01dD5`0H3a805`h@01L>3`0H3a0060l?
01D=2`0I4a<04P`<010:2P12?3`0:28R00D0000H4Q803@L701H@400:10@0H5YJ0>kXj01>BDH02`H3
020K600E40d201LB3`0?018=2P0C3P/08ahK01LB3`0H4a003`X701XA4P0M51D07QDF020G600O5QL0
7A@E01hE5P0M51D071<D00806a8C00D06A<C01@?4`0Q72006aHJ024L800201dH700801XE6@0^:Bd0
91lS010;3`0C3Q807APK01hH6P0O6A/2024K7@0R01hH6P0J51H0:B<U020J700L5QP08Q`N01H@4P0I
4A@0:1lR018<3P0X8b@0GUYK01/I6P0H5AH05A4B01H@4P0G3A405`/?01T:3`0G2`X05`h901L=2`0G
3@`05P`=01D:3P0B1`/050X;01@:2P0A1`D04PP601P?2P0C20H04PH601<71`805@T900<04PH601@8
200C1`L00`0B1PH01P0D20P06P/>00l00`0F1`X0814D02TJ7@<06P/>00X05`P;01@5200B0`H04@85
00T0000>0P@03`<501041P0E2@/05PX<0P0C1`T0200B1PP04`L901@82P0C1`T05@T;01451`0E2@/0
4@D70P0J3Q002`0C1`T05`/=01L;3@0D20X04PH801@82P0M3Q406@X=01L82`0=00404`@700<05PL:
0P0E1PT201@5200401451@0?0`<060`<02`P80804@D51P0B1PH00`0H2@`050D801H:300200h51P08
02HP803DcLd0ShF602DK700?10D070`?01P9300C1`L201H:2P0A0104100F2PX08ADE04/o?`0a9BD0
3`<301T=3@0?0`<050P800l50`0@1PD04@L601<9200D2P/05@/<01@:2`0B1`/00P0A1PX04@0>0`L0
2P4301052@0A1@T03`@602XK801nKG<0?2`b00l01@0K3a<0UXb@07miN`0M6AX04@T;01041P0A1@L0
4PH800804`L90P0F2P`20186200<01H:300G2`d06Q4C05YDEP26OH006A0C01lF6@0A1PX040@801<7
2`0E1P/05@D:0P0D0`T0200S5QT05`/=00l41@0J3Q0040@60186200C1`T020000`0?0`D09@0@1PL0
50H601<51@0C1@D04P@401<51@0D1PH04@<301lA4@0J30`0;AlO02DG5`0<00005@L601@61@0D1PH0
4`D501@61P0C1`T04@L800L0000N4aL03`H900h5200O5QT060`@040d>00E2@d0710D0104200;00<0
6`lC00d21@0?0`L04PH:00/10`0800000P0B1PX20104200401862@0B1PP04@D701451P804@D500<0
4@H501461?ooool04oooool001_ooooo0P0D2PT0100C2@P04PP701881`0A1`H401881`0B01471P0A
1`L03`D601/?4P0D2P/040H701X>400>10D05@T;01@82P0B1PP04`L901D9300F2Pd050X;00h41@0L
4Q<03PD50P0C2@X01`0A1`P04@P901@:2`0H3Pl05P`=01061`0C1`T00P0E2@/00`0O51D0PWIh04Xn
@00201@82P804`L90P0B1PP04@0E2@/050P:01H:300H30h05`/=01D92`0G30h0308301/?4@0@1@H0
:1`N01H;300C2@X04PP901@:2`0G3@h05@/<008050X;00<04`T:01882@0B20T00P0B20T00`0C2@X0
50X;01<92P0201882@0;01<92P0A1`P05P`=0147200I3a007A<D01@;300F30d02P4201P>3`0<0`@0
0P0E2``01`0<0P<08ALH02PN7`0I3a007Q@E01472@0D2@d01@0E2Ph0200G31005P/?01<8300E2Ph0
4`P<01T>4P0G31005P/?0P0E2Ph0400D2@d060dA01L<400G31005P/?01L<400G3A405@`A00l93@0J
51P06A<G01XD600B31004@/?00l93@0J51P2010:3P0801/E6@0G4QP050lE01PC6@0@2a409b8X02TT
:P0J5A/201PC6@0E01D@5P0F4AL081/Q01XE6@0E41D08ahT01PC6@0I51X07APM01PC600J5AL06aLE
01hK5`0R7aP0924H04Y7?`3KfM40UY>=03Pd<00O6aT071PG00808AdN00/081`M024M700Q7AX08AdK
01lK6`0P71h08AdO024M800P7B407adR020O900302<R:00:024R9`0R8bP082@V03<g>022QXL08RHW
028V9@0N8R408RHU02@Y9@809BXV0P0T:B@03@0X;b`0CeQE04QACP0_>3D0F65P02`e=00Y<C<0;SHh
030h>P0b>Sd0<CTl02hf>@0e?4@00P0_>3l05`0nAe00GFM`03@nA`0i@dd0>dMC03Y6DP0iAE40>dMC
03e8D`0nB580?dUB03Y5C00c?T@0<Se303Q3B@0jAD`0>TA>03e7D`11BUT0ATmP04UEI01;FFH0C5YW
0080AeER00P0AUAO049@F`12D5/0CUaU045?F00nC5D0?TeD04ACF@80A5=H00<0AUEJ04EDF@13DUL0
0P11D5D05P12DEH0@E1E03i=DP0lBdl0@U1C04=ADP11Ce00?de>03M5AP1=Fe`0E69S03m=CP19EeP0
DV1Q04MEEP18EUL0CemN04YJFP18F5P0@e=C045AD@1AHF4204mNH@0:04iMH01<Fel0BEQL04EDF@17
EEL0EF=T05ARH`1GIFH0SifN07:0P@80AE=D01T0B5IG04aJF`1?GEh0DV1P051PG`1DHf00Df1N05UW
I01HHf80GVQW05eWIP1LIfH0F6ES05]XIP1?Ge`0EfMT05IUH01HIf80FVUT05IUH01@GeX0Df9M04mN
F@1@GeX0DV5L00<0Df9M04P0DF5N059RH01FIVD0FFUY05MVJ01?GV40EfI[051OI@1=G6<0CeeV051N
J01=Ff@0CU]S04iLH01=Feh0C5YJ04UGE`18Ee@0AEAA04IDE@1<FU/0BUQK04ICF@17E5X0AU=I045?
DP17EEP0?Ta?04iIF`10Bdd0=Cm1034k?01DGUl0>41203Dm?`0g@3l0=d0m03U2?`0h@Ch0=Sll03@m
?00b>cX0=Cdo03U1@`0g?d40=3`o03Dm@00f?T00=c/m02lc=00V:R/0;c<f03@h>`0V:Bd0<C@i03Lj
?`0c=S`0@TE<0454B`0`<SP0;Bhb04A5B@0f=c/06Q/O02HW:`0j>cl0a/O;05UJGP0Y:Rh0;2da02//
<00/;S4202P/;@0702X^;`0[;c00:Bd^02``<@1WJf`0<CDf02DY:P0202/_<00902`^=00W9c40<30j
02h^=`0c<c/0820X02d]=00V9b`0;c0d0080;Rlc01809BH[034_>P0Y9c<09R@`02LU<@0R82/0:RPc
02TX<00O7RH081lU02HU:`0P7bD071/Q01dK7`0H5QX08b4T01TG6`0S8B@201lM800301`J7@0J61/0
6QPK00806aTK00@06QHG01@@4@0Z9RL09b<T0P0I5AH201`H6@0:01/G600J5QL06aLH01/G600F4Q<0
61@E01hJ6`0T82406QHG02HR8`@06QHG02d06ADF01HB4`0E3a40618D01LA4`0P6Q`06A<E01LA4`0L
5QP05a4C01XD5P1LEUP08Q`N01hH6P0I4QT06A<I01LA5@0J51P05a4D01D@4P0O6A/06aDF01LB4@0H
4Q805a8@01@?300H4Q8071HF00l92@0M5aL04`d=01H@400B30`06A<C020J6P0M5aL0BdE508^5Q@0g
<Rl04@`901hI5P0E40d06A@A01@?300I51400P0G4Pl00`0D3``05A0=01dH5@0201XD500301`F5P0K
5AD0618B00<06A<C01006Q@D01/E5@0M5aL07QPH01`G6`0V8BD07APL01hI7@0G4QH07aXN01/F6P0f
<CD0?STm01LB5P0S7R806QHH0P0I5AH06P0L61T06aLH01XF5`0L61T0:bLX02LS900O6a`07QXK01PD
5@0N61T06a@F01dG6@0F4Q<08AlP00h<3@0D4Q<0514B01D?4@0F31005PX>01L:3P0F2`/05Pd801H<
2P0F30/05@/:0P0D2P/0200B20T05@/:01H<2P0C2@L04@L401P<2`0F2PX05@T90P0G2`/00`0E2@T0
50P801@8200301<71`0>01@8200J2`h0404401L82`0M3Q409AHI01P9300L3A006``?01T:3@0G20/0
5PL:01@5200C1`T201@82P0401<72@0D20X04PH80186208050P:0P0C1`T01P0D20X05PX<0186200E
2@/040@601L;3@805PX<00/04`L901D92`0I3@l06Ph@01D92`0@0@@0:Q/N03HW:P0O41<050D801D6
2@0201H72P805@H90P0D1@P01P0B1PH05@T901861P0Z7Qh05`/;00l30`H04PH600h04`@701@62@0D
20X04`T:01892P0S6Q/0UHf>06ILG@0@20P06@d?0101100D1@P04`L701451@805@T900l04PH601@8
200H30`05`/;01X>3P0A1PH08QHF01T=3@0E2`T04PP701471P0E2`X0718C01lE5P0D2P/00P0?10P2
01<8300=01872`0?10P03P@601T<400?0@D09QDK01/;400D1@X040H804a3AP0k=CL02@D601082P02
018620804`L900h050P:01051`0D20X06Ph@01D92`0=0@<040@601@:300O5QT0:R4T01D;3P0>0`L0
5@X>01@830804`L;01004`H:01<42@0C10T04PD801041P0A1PL04`L901451`0>0P@040@601D92`0D
20X04PH801@82P0K3a4050H60P0C1@D08@0B10@04`D501@61P0B1@D060`<07AVIP0E1`L04@D501P;
2`0E1`H050H501@61P0C1@D050H601<72@0<10@03@<401P?4@1HCe807QDH01D<3`0J3Q803P@601T=
4@0=0`D05``?0104200B1PX05@T=01<72`0A1@T04PH:01D;3@0401862P0401862@0B1PP04@D70145
1P804@D500<04@H501461?ooool04oooool001_ooooo00P04PP901<92P0C2@X04`T:01882@0A1`P0
4PP90147208040H700l04PP901<92P0P51P0C4140104200a9BL040H701L;2`0C1`L04`L801<72@0D
20`05@P?01D93@0H3Ph00P0B20L03`0C2@P03`D400`20@0D2PT05@/:01`B4@0@1PD04@L601L=300C
2@X04PH802dQ8`0:0040CD5302LK7@0201D92`8050P:0P0C1`T0300E2@/04`L901@82P0E2@/04`L9
01451`0D20X09a/M00h2100F2P`03`<501P=3`803`D60P0D2P/20147200N01<92P0B20T04`T:01D;
300G3@h05@/<01@:2`0F30d050X;01882@0C2@X04PP900/10P0H3Pl0:b8R01061`0=0`@05`d>00`2
0`0[8B8050X;02DK700<0P<050X;00h41@0B20T0718C01@:2`0@1PL05P/>0P0F2`l01`0E2Ph050T=
01<8300H3A405P/?01L<400H3A400P0F2`l01P0H3A405P/?01@93@0G31006@hB01P=4@805P/?0`0E
2Ph0600F30l06Q4F00`62P0B3A0050hB00d72`0G4AD06Q@H01H@500[9BT0L6Y^034[;`0J51P0BDA:
05aGG@0F4AL06QDK01dH7P0B3A<06A@J01LB600J5A/06A@J01D@5P806A@J01004PdC01HA5`0F4AD0
5a8F01HA5@0H4aL06ADE01/G5P0N6QL08QlJ02@Q6P0Z:B@0OGag04]:AP0_;RX08R4O0`0Q81h01`0P
7ad07ahL01hM6`0M6a`07QTM020K8@0Q72800`0O72<0:P0P7bD09B@Z02DV:`0R8RX08B4Y028S:00S
9bT0=c/l06EYJ00S9bH092PW02HZ:@0R9RD08bLV02@X9`0V:bP09R/W02D[9`0R:RL0<CXi04YCDP0R
:bX08b/]034i>`0/=3H0;cLj02de>00a>C`0=Ce0038j?@0i@TT0:c@k03@mA01HHV/0h>[c08B>U`0j
Ae00@4aH03i;E`0kBE@0?D]F045<E`80@TaE00h0>49;030j@`0b?4D0?4I?03e7D00mAe40ADmJ04A>
FP13C5/0AE5O04MEHP14DUl0?deJ045?G080@4iI00T0?deH05ESK013DEX0AUAM049AF015E5X0@e9G
045@E@12DEH00P13DUL06012DEH0@E1E041?E00oCU<0?TeB041?D`0d@TD0@e5B045?D01<FU/0B5IG
08ZHV@2AWj00EF=T04IDE@1<FU/0BEMH06ilO@1QLG00BEUF03m?CP1;Fe/0BUYJ05ETI`80D5mT00X0
CUeS04aKHP1<Ff80CUaT04mMH01DHV<0FVQY04]IFP10CTl0BUQI0P14DU<204ECE00704IDE@19EeP0
C5aK055TH01AHEh0EVIS05ASH00205]ZI`0>05YYIP1CHf00EfMT059UH@1OKf`0I7=`05QWI01DHf00
EFAQ059QGP1?GU/0Df9O05ETH@1GIV<305QWI00^05ATH`1CHf80DV9R059RHP1@H640CUeP055PI@1?
GV@0CUeT04mNI@1?GVH0CeeV055NIP1@GF80CE]N04YHF015De<0A5=@04QGE016E5D0CUaM05=QI01;
F5h0AeAJ05ARI@1:F5/0AE=F03i<C@0jADL0<C`n03Do@00a>c`0A4i?03e6A@0c?3/0>dA303Y3@00n
AdH0>D9103Ho?P0f?T00<c/m03Y2A00i@D@0=Si102lg>P80:S8e00d0<CDh02X^<@0T:2/09RX]02d`
=@0b=CX0<cHk03XmA00n@DP08bH]01/N9`0Q8bT08B8V00809bP/07H08R<W02X[;`0U9RX0EEIJ03Lh
?00[;300:R/_02TZ;P0R92L08BDV028V9`0V:R/0:2`]02L[;00T:2T07R8S024U9P0U:BX0720Q02@X
:@0V:2h0:b/e01hN:00];CH08B4Y01XJ8P0U9R`0:2T^02<T:00G61`0:R/_02HW:`0[:S80:RTa034`
>@0Z:C408b8Z01hM9@1LFf<0A4=;02HU:`0N7B<071/Q02@S:@0R82<071XK01lM7P0J61T07Q`M01hL
7`0M6ah071XM01/I7P0J61d071XO024O900_:Rh04`l@01TE5P0R7Ql06aLH01`H6@0N6Q/07ATJ01/G
600J5QL06aLH01`H6@0Q7Ah07a/L01@@4@0@30d0:bLX07McM00P71d071PI01/G600L61T06aLH01LC
500K5AL091hP03hh>P18@T@09AlQ01PB500@2P`06Q@F02HP8P0<1PP06aDG00P2100@2a409B4V00H4
1`0G4QH04PlA01TG600Q7Ah06AHF01<B400E4A005Q<A01LC400C3@d06Q@D01hH600K5AD04@/;034[
:`0H4Q805Q0@07ihN01OFET04@/;01TC4`0@2`P07APE0P0H4a003P0K5Q<04`h;01LB3`0D3``02`H3
02LR7`0@2`P08A`I01TC4`0F41006Q@D01TC4`0H4Q8071HF0`0J51@04P0L5QH07ALG01hH600H51P0
6ALJ01<A500K6A`05Q@G024O8P0`;S404a4D01HD5`0L6Qd09bDX028P8`0P7R40928U02PV:@808AlR
00L07adP018@4`0F51L061HI01LE600Q7b809b4T00803`T;00/09b@U01<A4P0I6AT05A@D01@B4`0E
3a405@d@01H;3`0G2`l05P/<01@:200201D;2P0?01@:2@0C2@P040H501061@0E2`X04@L600X0000A
1`D05@T901<71`0A1@D04PH601<71`0A1@D05@T9008050P800T04`L701@8200E2@T05@T;01041P0F
2P`04PH801L;3@0C1`T0100B1PP201451`0700`00P0?0`D05@T;01D92`0C1`T050P:0186200201H:
300901<72@0A1@L04PH801D92`0A1@L05@T;00h2100B1PP03P8400804`L900X05@T;01H:300G2`d0
5@T;01H:300J3Q006`lA00d10`0A1@L060`>0P0D20X201<72@804PH800H040@401D92@08000040@4
00/0000A1@D601861P0901H:300C1`T030020147200C2@X0718C02/Q8P0K4A805@/<00803P8400<0
5@T;0186200A1@L00P0E2@/0800D20X060`>00X00@0F2P`050P:0187200S5aT05PX:01@:200A1`H0
3`D401061@0D2P/05P`=01X@4@0?10P03@8601872`0E2Ph04@H:01hC5`0N4QH04@<801X;400R4AL0
3@0201D62`0H31004@P:018<3P0R7Ql08ATJ100C1`T03P0B1PP040@601P<3P0R5QP07Q8D01<72@0B
1PP040D701L=3P0<0P<03PD601<92P0800004@D70P0C1`T01P0B1PP04@D701451`0A1@L050P:01D9
2`804`L900P04PH800`00P0G2`d06@l@02HJ700800005PX<01@61P804`D502404P@401<51@0D1PH0
4@<301<51@0=0@4060X:01d?3`0C1`L05@L601@61@0D1PH04`D501@61P0C1`T04`T:014720070000
?cHi0189300@20X06`lC00/00`0B1PX03`<701L;3`0:00805`/?00d31@08000040@801`@500A1@T0
0P0B1PX201<72`0401862@0B1PP04@D701451P804@D500<04@H501461?ooool04oooool001_ooooo
00<03`D60147200B20T00`0C2@X09@0B20T04@L800l51P0?1@H04PP901@:2`0A10/06`hD01hB5008
000060`<01050`0B1`D04`L701@82P0D20/04PD<01862P0@1PH04`T800h40`0A1`H03P@301/A400F
30/05`d<00`20@0E2`X06Q0?00/1000B1`P05PX<00X0000F2P`060`>01451`0C1`T00`0B1PP20145
1`0B01@82P0B1PP04PH801<72@0@10H03P8401<72@1;?d405@T;01L;3@0?0`D04PL801<92P0D2P/0
6@l@01P>3`0D2P/04PP90P0A1`P05@0D2P/060h?01/A4P0H3Pl05P`=01L=3P0E2``04`T:01D;300J
41402`4201dC501jL740ETa=01L=3P0E2``08QPI06aRH`0K4A80<RPY00L0000201X@4@0A00X00@0E
2``050X;00T0000L4A@060dA01L<400D2@d04`P<01872`0F2`l040D901<8300F2`l04PL;01L<400F
2`l00P0D2@d00`0I3Q807A8F01`A5@0201@93@805P/?01d05@X>01@:3@0F3A802P@801H@500G4AD0
5Q0D01@>4P0J51P03@L;05I@E03ooOl0NG=g01/E6@15@4H0NWEk01<>500J5A/05a8H01/F700I51X0
5A0F01/F700N6Al05Q4G010;4@0J5A/07APN00d8300201XE6@0501@@4@0M6AX07ATI01/G5P0K5a@0
0P0L61D01`0L6aL0@D0l028Q7`0Y:2H06aXH01lN700J6AL00P0K6QP01P0L6aT07A`J01hL7@0Q7280
8ahU02@O9P808QlV01008B0V020O9@0U9R/09RL/028R:P0Q8BT08R<X02/_;`0O8b808RHU02DY:00Y
;B`09RXY02@X9`0V:RT09b/Z0P0Z;Rd06@0Y;bd0;3Db02L`;`0P:BP0<CXi02lg>@0`>3X0;cLi02hf
>@0Y<C@0;cLj03Q0@`0e?T<0EUmV02/d>`0h@DP0@TaE092JX`1:E5d0>4E>03m;E`0mBUH0>DMB03]9
E00nBe@00P10BU<0100h@T/0<ce603I0B@11Be@203m9D`0A04YDG`16D5`0?dQG03U6E00jB5D0>DMD
03]9EP15Df00BEMR04ECGP0fA4l0CE]T03a:D`16E5d0@4mF045@EP11D5D00P0oCU<09P13DUL0A5=H
04EDF@13DUL0@E1E041?E011D5D0A5=G04UGF00e@d@0@U1A0390@@1=Fe`0CeeN05aZJ`12D540AUAE
04MEEP1=Fe`0BUQI04YJF@10D4d0Be]J04]KF`13De<0MhJ9051OI01?GV<0CUeT04eKI01>G6D0Df5Y
05ARI@1FI6D0BEMH04iLG@1?GEh0@Dm@0`17EEH204ABD`0704IDE019FEP0EFQT051SG`1HJ6D0EfMT
051SG`0205EUHP0B04eMFP1?HUh0Cf9N05][J01_OW/0EVER04iMFP1EI640E6=P04eLF@1BHEh0E6=P
05ETH@1FIF80EfIS05IUHP1CHf80DF5Q0P1>GUh0J@1AH680E6=V04]JG`1AH6H0DF1W04iMI01>G6@0
DV5X04eJH01=Fel0C5YM04]IF@18EUH0AeIC04ACD00oCDh0B5IG04mMH014DEL0?T]A04QFF@11Ce80
>dU<03e;C00f@D<0=3m103]5AP0g@D80<S`m03i7AP0mATD0?TM603a5@P0oB4L0=d0o03Ho?P0i@D<0
=cm103Dm?`0e?D00=Si1038j?@0_=cX0<CTl02hb=@0]<C@0<CDh02T]<00^<CH0@DA902@W;00T9bh0
BdiE030c>P0R9Bh0;Ble02TZ;P0V9b/0:R/_02PY;@0S92P0;2da01hO8`0^;c<0:2T]02HW:`0W:2`0
:R`_02L[;00V:R/0:2`]02L[;00T:2T07R8S02da<P0Z;Rl07b<T02T];P0J7Ql09RP]034a>`0[:cD0
;Rhg024Q:@0e=Cd09bL^02d^<`0/;C407QlS038c=`0T9BT092<Y02LV;P0`;cL08R4Y024P:00T8b/0
>3Lo02HU;@0I61h07ahT024P9P0Y:2d06QPK01XH6@0201lM7P0501`J6`0N71l05aDH01/I700O7B80
0P0J61d02`0R82H0GEQL02l[;00M6AX09B4R01lK700K5aP07a/L01hJ6`0L61T06QHG008071PI0180
:bLX01HB4`0H51D08alP01DA4P0O6a`08AdN01`H6@0I5AH06aLH01XF5`0G4a@07QPJ01<=3`0P6Q`0
:R@V018<3P0H4Q@201`F600Z018<3P0S7Al05@lA01HB4`0^:Bl0A49600h<3`0L6Qd040h@01TG600K
6AX04a8A00d<2P0>3@/04a8?01DD400D3Ph05Q0@01/E5@0E3`l0:28R06QRHP0P6QX0618B044k>`0c
;Bd09b4Q010:2P0N6AH050l<018=2P0I51405A0=01/F4`0G4Pl07QTF01TD4@14?c`050l<020K600J
51@05a4A0P0K5AD0100L5QH08Q`L01XD500I4a<201PB4P0W01TC4`0H51<061HI01hL7`0L6Qd09B<V
01/I700T8RD0GUaO02d[;P0M6ah08b4T01DC5P0F51L05QHH01lM800S8R@05aLI01LE600R8B@05QHH
01dK7P0N7B004A4C01HD5`0A3Q007ATJ01TE5P1;BDX071XK00d=3@0I61T05A<D01HB4`0F3Q405``@
01T=4@0H3@h05`d;00805`d<00/05P`;01D;2P0J40l04PP701471P0F30/050X901H<2P0I3@d05PX:
01@8200201D92@0=01@8200E2@T050P801@8200C1`L050P801D92@0B1PP040@601P<3P0@10H05PX<
01P<3P0201/?4@0K01T=3`0G2`d05@T;01@82P0@10H050P:01X>400G2`d04`L901@82P0B1PP05`/=
01H:300C1`T040@601451`0C1`T04@D701L;3@0A1@L05@T;01451`0@10H05@T;01H:300B1PP04@D7
008050P:00D04@D701P<3P0E2@/060`>00l31@0201@82P804`L90P0B1PP01P0H30`04`L700l30`0H
30`04PL701<71`H04PH600d05@T;01451`0G2`d040H7024G601?ADH0Fe5B00d3100W7Ah040D601P<
3P0:00004`L9008050P:00D03`<50186200J3Q004`L901H:300201D92`0300`00P0H30`050X90080
4`T801D050X901D;300F30d08aTJ01<8300=0PH03`@801052@0>0`L0200101452@0E1``02`0101T8
3P0E1@X04P<80104200B2P/0100000<0000C2`d00P0D20X0400C1`T04PH80186200B1PP05PX<01T=
3`0E2@/03`<501041P0I3Q002@0001L=3P0?1@H050X;00d10`0G2`d201<72@0=0186200A1@L04@D7
0186200<0080304200l31@0=0@<04PH801041P0F2P`0Cd=507eaL`0201451`0K01@61P0C1@D04`D5
0184100C1@D050H600l10@0J30`03P4101L92@0>00004@<301D71P0D1PD050H601<51@0D1PH04`L9
00d3100?1@H05P/?00H0000D2`h03`L900T00@0Q5AT03`D700804@D900T05@T=00X00P0J3Q805PX>
00l31`0B1PX04@D900l31`0@10P00P0A1@T0100@10L03`<501451`0A1@H201451@0301461@0A1PCo
oooo01?ooooo000Kooooo`0401482@0C2`/05`h?00l61`805@`=01L05Pd>01@;300C2P/04PT:01@;
300I3a4050L=01@7300J3Pl06Ph=01D:1P0G3@H050X301P=2@0F2PT04PH801<7300E2@d050X801D;
2@0F30X05@/901<91`0201881P0601<91`0D2PP05@/901@:200D2PT04@D70P0D20X03P0C1`T050P:
01D92`0E2@/050P:01451`0E2@/04@D701L;3@0C1`T05`/=01451`0S5aT05PX<0P0A1@L0;`0E2@/0
5`/=01L;3@0D20X05@X<03hd=@0A1`P0CTA501lE5P0@1`P05@/<01<92P0F30d05@/<020F5`0T6Q/0
60h?01<92P0?1@H050X;01L=3P0D2P/04`T:01T?400<0`@07Q@E01T?400:0@804`T:01/B4P1OEEH0
5`d>02DK700>10D04PP901P>3`0F30d05@/<01P>3`0C2@X05P/>01D:3P0L4AD050T=01T>4P0E2Ph0
5``@00805P/?0P0H3A4201H;3`0601L<400C20`06a0D01H;3`0D2@d05P/?0P0D2@d02@0F2`l05``@
01H<400E314050hB01D?4`0A2`l05@lC01@?4P0201TC5`0402LQ9@1XHVH0>C<g01@>4P805a8H01/0
5Q4G01@?5@0E41H05A0F01XE6`0H4aT040/A03Td>P0H4aT05Q4G01PC6@0K5Q/06QDI01PC5P0O6a`0
71PH01/G5`0K5aH071PG01dI600P71`08A`N01/J6P0R8B408B0O01`J6P0L6aT00P0R8Al0CP0P7ad0
8b8P024P7P0O7Q`08b4R020M900R7bP08AhW01lL8`0O7R@08B0V02<S:00Q8RL08b@X028U:P0P8bL0
7B4S024U900P92<08BDT02<W9P0T:2L09BTX02L[:P0T:2L09b/Z02HZ:@0[;bl08bTY02D^;@0V<2l0
<3Xi02`f=`0[=CH0:38c038l?P0`>S`0;cTk034j?`0e?T<0=Sm403Q2B@0e@4H0;STo03Q2B`0f@d/0
>4E=03U6C`0iAe80>dUD03M5D00iBU@0@4mG04EBF011CU@0=T=:03E2BP0iATl0>TI@03]7D`0hA500
?TYF03U5D@0e@Dd0?T]H04=AGP15Df00@DmL04=AGP13DE`0?deH041>F@13DEX0AeEN04IDG@14DeX0
@U5G049AE080@e9E00<0@U5D04ACEP12DE@00P0oCU43041?DP80@4i?00@0?de>03e;C00oCDh0A59C
0P16E5D204MEEP0X04QFE`1;FEX0@E5@04=CDP15EED0B5QH04eLGP1BHF@0BeYO055PI@1<Ff80Df5Z
04]IHP1CHF/0CE]N04iLG@1@GUl0CE]L04UGF014DU<0BEMH04IDE@15De@0BUQI04]IFP16E5D0EVIU
04mPG01CIV80DVEQ05EYI01;H5/0E6QS059UH@1@Hel0DFAP05AUHP1FIV<0E6=P05]ZI`80D5mL02d0
GVeZ05QWI01BHEh0E6=P055PG@1>GEX0CEaI051OG@1@H5l0C5]M055PH`1BHF@0CeiQ059QI01PKg@0
CeiS04aKH01AH6D0CeiT04YIH01:Eed0BeUM04YHF`16E5@0@U1@045@C@14De00@U1A04ABD`13DE@0
A55G041>DP10CU00@4i?03e;C00jB4T0?4Q803e9B@0h@T<0=d5003U3@P0j@d80>T=003a5@P10BDP0
0P0a>ST06P0i@D<0=Si003a4AP0i@D@0=Si103Q0@`0c>T00:S4g02Ta=@0b=ST0;S8e02/_<P0a=3T0
<3<h038e>`0_<ST0;c8k030c?00_<S/0;C0i02X/<P0X:Bd0:R/_02<T:00];S80=CHj0P0Y:Rh202`]
<@80:BX^00H0:R`_02@X:@0V:R/0:Rh_08>7R00[;c0202<W:00_02X^;`0/<3409RX[02T];P0/;S@0
:2Pb02TY<`0Z:S<08b<[02@T;00Y:C008b@Y02PY;@0Y:Rh092DY03Hg>`0`;cD09B@Z01lN900[:S00
7QdS02@S:@0O7R@07QdS02/Z<00W9Rh08R4Y02DT:`0O7B008AlP03Hd=@1=Bd`05aDF01dK7P0K6A`0
7Q`O020N8`0L6Ql07A/P02DS:01:ADT0:RHW01TE5P0V8R<08AdN01hJ6`0S7b000P0M6AX00`0N6Q/0
6QHG01dI6P0601/G600601LC500N6Q/0Ad=402<O800K5aP05Q8C0P0I4aD201XD5P806aDG100J51H0
400I4aD05a8C03@_=@1THFH04@lB01DB5@0J61X0:2HW01DB4`0E4Q8051<A01DC4@0F5A8061DB01D?
3`0F410201LA4@805Q0@00<05a4A01H@400E3`l00P0F4100200G4A4061<@01PC400G4Pl05Q4>01PC
400I51406aHC0P0I51404`0J5A8061<@01HA3P0J5QD07QXI01PD4`0P71/0:RHU02HR8@0I5A@06QHE
01hJ6@0L61L061@C01PF500K6A`061HI024O8P0H5QT00P0Q7b802P0N71l07adP02@R9@0N71l071XM
01`L7P0K71h07QhP020P8P0N7b4201`M7`0F01HG6@0@4A<06a`N01XK7@0K71h0ATE6028N7`0D4A80
6QTI02XZ:P1TI6@0G5aL01/J6P0D4A805a0B01T@4`0>1@L05`d>01@:2@0K4A005@/:00h40P8060h<
00<050X801D;2P0F30/00P0B20L00`0D20P04`L701<71`0201861P0301@8200@10@04@D500@04`L7
00X03@<401<92P0D2P/04PP901D;300G3@h0718C01L=3P0A1`P04PP90P0E2``0100C1`T04@D701`@
4P0O4aD201<72@0401D92`0C1`T050P:01@82P804`L901P04@D701@82P0C1`T05PX<01<72@0@10H0
4PH801<72@0D20X04`L90186200@10H03`H701D;300?1@H050X;01071`0L4Q<08ALH00l51P0E2``0
4PP901482@0H3Pl201451@804PH60P0C1`L04P0A1@D04PH601861P0M4A406@d=00h30`0F30d050X;
01/A4P0H30h040D604Di>`0J3Q004`L901L;3@0@1PL03@<401D;30H04`L900<050P:01<72@0E2@/0
0P0C1`T06P0C2@T04`T701@:2@0C2@P04PP701D;300F30d03PD601872`0F2`l04`P<00l4200B1`/0
4@H:01452@0C1PX05PL<01D42P0B0PL04`@901862P0A1`X03PP:00`82@0>1PL04@D70P0B1PP201<7
2@0301D92`0F2P`05@T;008050P:00<05`/=01H:300B1PP0100B1PP01`0C1`T040@600d3100?1@H0
40H700l51P0@1@H01P0B1PP03@0C1`T05@T;01D92`0D20X04`L901430`0H2PX04`D500h10@0E1`L0
4`D50184100C1@D00P0F20P04`0E1`L04`D501@61@0F20L05@L701@61P0G2@T04@D701<92P0@1PL0
50T=00l62@0A20/050/>01@8300E2@d050P<01862P0D20`00P0C1`/02P0A1@T05PX>0105200C1`/0
3@<500d21@0A1PT05PX>00`1100E2Pd201D92`0501@82@0C1`L04PH60145100@1@<05?ooool001_o
oooo00<06A0C01D<3`0>1@P00P0C2Pd04`0G3Q40=2/^00`51P0<0`H050/>01H=400<0`H040@801X>
3`0D2@L0304001470@0L4PP06Q0601X@1`0A1P005@X901P<3P0C1`T00P0F30X201L=2`805P`:00@0
40H401471@0A1`D04PP60P0A1`D0100C1`T05`/=01L;3@0D20X20186200;01@82P0C1`T04@D701H:
300@10H05@T;00l31@0H30h04@D701@82P0@10H00P0C1`T201@82P805@T;02003`D602TO800:0040
3@D501hD5@0I3a005P`=01882@0C2@X0308301<92P0I3a0040H701@:2`0F30d050X;01882@0D2P/0
60h?01L=3P0>10D07aDF01061`0O5AH060h?00l51P0700005`d>01882@0J41405`d>01P>3`8040H7
01D06@l@01@:2`0D2@`05P/?01T>4P0H3A40:b0T01T>4P0K41@05``@01H;3`0L4AD07Q<G01T>4P0?
10P06@hB01D:3P0H3A405P/?01@93@0F2`l00P0D2@d03`0F2`l05``@01H<3`0@1``06A<G014;3`0;
1@T04@/?01TC5`0G4AD071HJ00l93@0G4AD04P`@01<=4@0401D@5P805Q4G04D06aHL01PC6@0B3A<0
6A@J01HA5`0I51X06QDK01TD6@0S7R805Q8C01/G5P0M6AH07a/H01`H5P0I5A@06ADF01hI7@0Q7280
7adR01dL8@0M7Al07QhN01hN700M7QT071dH01/L5`0Q8Qd08R8P01hN7@0O7b408AlT028P9`0Q82H0
7ahT020O9@0R8bL08b@X02DY;00V:R/08bLY01lS900O8b808RLR024V8P0R9b<092TU02DY:00V:RT0
8bLV02X^;`0]<C809b//02hb=@0Y;S40:C8d02<];P0M9bP092h_02dg>@0Z=3H0;CLi02hg?00_>3d0
<S]003<l@`0d?D@0B5=I04MBF00b?D<00P0iATh04`0a?TH0=TA=03Q6D@0nCeT0DF9/0352C00jBU00
=dI903Q7C00iB4h0?TaE03a:E@0e@dl0?4YG03Y8D`0hAU00?4YC03Y8D@10CUX00P12D5d05P15Df00
BEMT04ABG@0mBeH0@DmJ04ECG018EUl0AeEN04ACFP11D5D0?Te@03e<C`13DUD0AeII04ACEP17EUT0
?diA03U8B`1GIVT0IgIi049AE00nC4d203m=CP0303i<C@0oCDh0A59C0080B5IG0P17EEH04`18EUL0
BEMH04eMG@1?Gel0CeiQ04MFF@13DUL0AeIK06MfO@1KJW40D5mV059QJ01KJW40EfE]055OHP1AGf00
D5iO04eKG01;FEX00P18EUL08`16E5D0A59C049@D@12D540@e5B055OG`1AHEh0E6AQ055TH01?Heh0
BUmJ04mTG`1;Ge/0BUeI051PG@1CHUl0DV5N06=aL@1EHf<0CeeM059PH01=Fe/0C5YJ04mMG@1AGel0
D5iN04iLG01?GEd0DV1P051PH01:FE`0CEaO051OHP1>GF00CEaO0080CEaQ00/0CeiS04aKH018Ee`0
C5]P04mLHP1:F5`0A59E049@D011Cdl0@U5>04ACD00204ECE00404MEF01CH6H0?D]>03i<CP80=TA5
0100>4I603M3@`0c?cl0=T0o03Q2@@0`>cL0>T=0045:A`0i@Sl0=Sho03e5A`0e?Cl0@TY<038j?@0m
ADP0@TY=0P0j@DL0100c>T009bhf02@[<@0^<CH202d`=@0302HY;P0Q92/0:Rde0080;C0i00/0;c4l
02d_>`0W:CD092H]02DV:P0Z:bl09RL[02h_<`0d=CT09bP/02HW:`0202TZ;P0^02HW:`0U9RX092HY
02L[;00R9RL0:Bd^020T9@0X;2d07b<T02P/;@0[;c0092PY02/_<00Z;Rl09BL]02TY<`0Z:S@0;2`e
02LW;`0X:300:R/a02X[<00Z:bl09BHZ02@U:@0X:Bd092<X02/[;@0P7b@0<2ld020O900Z:Bh09B@Z
01/J800Y:2h0<C0h02`[<`0S8RT07A/P01lM801_KG00VINJ03/i?00K6A`06ALJ01`J7@8081hQ00h0
71XM01LE600B3Pl05Q8C01lK700L61T05a<D01lK7014@4409b<T01/G600S7b006ADF028N7`H06aLH
00H06QHG018>3`0Y9BH07ATJ01HB4`0P71d201PB50806A<E0P0J51H201TC5@0@01XD5P0I4aD0618D
01LA4`0F3aH050hC01/F6P0H4QH04@/>02@P8@0J51H06A@E01LC4P0H4Q8061@B01TD4@<05@l?00H0
50h>018<300A2`/05a4A01H@400E3`l201H@400301LA4@0H4a0061<@00806A@A00<061<@01LB3`0K
5Q<00P0J5A802`0L5a@06A@A01LB3`0@3@`04A0>01HE4`0W9R@09B@R01HE4`0J6AL06APF008071/I
00P06aXH01hM6`0N7B005QHH01DE5`0C4aD0:2PZ024Q8`809BDW00@08R8T02HV:00V9RP08R8U0`0M
8B@301`P8`0C01TM800N8RD0720S01PL7`0L82<08R4S020L7@0R82406APH06][J`3Adm80/K:b01dM
7@0@3Pl03PT;01P?4P0O51P05P`>01`B4`0201D;2P0501lE4`0C2PH05Pd801<:1@0B20H00P0A1`H0
0`0L4Q<05@T901D92@0201D92@0501H:2P0H30`04`L701<71`0D20P00P0C1`L04`0B1PH050X;01H<
3@0D2P/05@/<01T?400F30d03P@50147200E2``050X;0147200?1@H06Ph@01451`0?0`D04`L90104
1P0E2@/00P0D20X01@0C1`T05@T;01H:300C1`T07A4C00805PX<00@0300201@82P0C1`T04PH80`0C
1`T0100B1PP04@D701@:2`0@1PL201@:2`0801`C4`2KTI80]jf^02dS900E2``09A/L01T?400G3@h2
01451@804PH60P0C1`L04P0>0P804`L701D92@0J3Ph060`<01861P0:0P808QPI00h41@0=0`@05PL:
01D62@0D1@P06@d?028F600I3a003PD601<92PH04`L;01l091PL02/O8`0J3Q802`43020D600J3Q00
3`D301@:2@0E2`X04`T80147200B20T07aDF01H;3`0?10P0304501872`0E2Ph04PL;01452@0C1PX0
5@H;01@32@0C0`T04`@90104200?1@P030H800`82@0@20T04`L900<04PH800P04@D701041P0@10H0
4@D701041P0A1@L050P:01H92P8050H600L04`H601861P0B1PH040D400l5100A1`H040L600803`L5
00<04PL70186200B1PP00`0B1PP00`0?0`D040@601451`0201451`0301041P0C1@D04`D500804`D5
00@050H601D71`0D1PH05@L70`0F20P0500E1`L03P0001@61@0F20P04@<301<51@0B1PP060h?00L0
000@1@T01P0001H=400?1PT040@801@8300F2Ph040@800h21P0C1`/060`@0P0>0PH02`0;00<050P<
01452@0R5QX05`/?01hB5P0@10P04PH900P0000B1PP04PH700804PH600<04@H501461?ooool04ooo
ool001_ooooo01T060lB01482`0B2@`02`8501H=400Q61/0=Rd`01D<3`0H3a803`H901072P0G3Q40
40H701H;2P0A1P804@L001P>0`0G3P0060l001/A1P0E2`805``901H:2P0=0@405@/900805P`:0`0G
3@/0100C2@L050X801@:200D2PP201<91`0>01@82@0I3@l06@d?01D92`0A1@L040@601L;3@0@10H0
300201@82P0B1PP060`>01@82P0G2`d301<72@805@T;0P0C1`T04@0D20X05@T;01H;300:00404`T:
01P>3`0J41405P`=00l51P0D2P/06a4B00l51P0@1PL05`d>01061`0D2P/05`d>00804`T:0P0D2P/0
5P0J4140200001hD5@0?1@H0718C00d3100O5AH040H701@;300<0P<06a4B0147200H3Pl05P`=01L=
3P0J41404PP901@9300=0PH04`P<028G6`0c:2`201P=4@0701<8300A1PX060dA01/@500F2`l03P<7
01X?4`0201@93@0901D:3P0D2@d05@X>01@93@0E2Ph05``@01P=4@0F30l03PD:008050hB00T08A/O
02XT:01<ATX03@L;01LA5@0P6Qh06A<G01XD600G4AD00P0D3aD03`0F4AL05a8H01LB600G4QP05Q4G
01XE6`0O6R0050lE01TD6P0F4AL08QdS01PC600S7b005a<B01`H5P0201dI5P0I01`H5P0J5QL06aHJ
01dH7@0L6B007Q/R01dL8P0L6b0071`N01/K6@0J6aH07b0K01/L5`0M7QT07alM020P7`0S8bD08R0U
02<Q:00R8BL081lU028R9P0T9BT08B8U02L[;00202``;`03028V9@0L8Ad092TS008092TU02d09R/W
02P/:`0X;2/09RXY02P/;@0Z;Rl09RX[02hb=@0Y;S40:S<d02dg>00V<340=d5202li>`0Q:bd0:S@f
02df>`0_>3d0<S]003<l@`0b?D<0?DQ>041;D@0d?dD0>4E=03M4C00d@DT0>TQA04=DGP0jBeD0L86;
041AF`0lC5<0>dY=03]:C`0lBe40@4iG03a:E@0e@dl0?D]H03Q6D`0nC5H0D5iW04UGH015Ded00`18
EV<02@14DUl0?D]F03]9E012D5/0AUAM04UGH017EEh0@e9I049AE@02049AE00404EDE`14DeH0@4mB
03e<C`80>TU<00D0A5=F04UHF`10Ce80?de>041>C`02045?D003049@D@16E5D0B5IG0080AeEF0P16
E5D02017EEH0?Te@03]:C`0mC540@e9G04MFF`1AH6D0EFA[0P14DeX02@1FIF`0MXF<07b;TP1BH6<0
DEmP04iLG@1<FU/0BeUJ04YHF@0204ECE00F04=ADP11Ce00@e5B04QFEP1=Fe/0DV5N04mOG01AHEh0
C61K04iSGP1=HUd0B5aH04YJE`1?Ge`0Df9O051OG01EHf<0B5IF04eKF`1JJ6P0CeeM05ARHP80D5iN
01L0CeeM04iLG01?GEd0D5iO04iMH01:FE`0C5]N059QI01CHVD0D5mR04UHG@1:FEh0CEaQ04YIGP17
EU/0CUeR04aIG`1>G600@e5D03Q6AP11Cdl0C5]H03m>B`0204IDE@0<03M5B015DUP0>4I903e;C00g
ADH0=TA503I4A00e@D40<clo02Pb<@0jAD40?4M30`0kA4407`0d?Cd0?4A603<k?@1:DU@0@DU<034i
?00oAdX0>T5703U0AP0`=cd0:2lg02Xa=`0`<cT09BP]03Lj?`0[;S<092L^02X]=@0Z;CH0:bhg030b
?@0_<Cd0:B/g02HX;`0X:Bd0;2da02TZ;P0/;C40;c0d02HW:`0Y:Rh00P0/;C400`0Y:Rh0:2T]02DW
:P0202L[;00i02P/;@0B5QL0;C4b02DY:P0V:R/08RHW024U9P0X;2d0:Bd^02PZ;`0Y:C<0:RXd02d]
=P0Y:C40:b/c02//<P0/;C80;2da02TZ;P0/;C40:b``02PX:P0W9bT09RHX024P9@0K6Ql0>cXo02HU
:`0H5ad07ahT02@S:`0U92`08R4X01/I7P0R82D09B<W02XX;@0H5QT071XM01dK7P0K6A`06QPK01`J
7@0M6a`06aTJ02@P8@0S7b007QXK01/G600M6AX06aLH034];P0O6a`071PI02DQ8P0M6AX071PI00H0
6QHG00<05A4B01dI6P0@30d00P0O6a`00`0E4A806A<E01TC5@0401XD5P0>01PB500I4aD06A<E01TC
5@0H4Q@05a4C02@M900L5A/050hB01H@500D3Q405Q0B01XD5P0I4a@201LA4@0301LB400G4Pl05Q0@
00805a4A00H05Q0@01@>3P0D3Ph05a4A01H@400E3`l201H@400E01LA4@0G4Pl061<@01XE4P0K5Q<0
61<@01HA3P0J5A806A@A01XE4P0K5Q<06A@A01HB3`0H5Q@06aXH024P7P0];2X08R4O018A3`0J6AL0
61LE008071/I00<07A`J024P7P0I6A/00P0S8bD00`0G5aT0;Bd_01LG6@0201dM7`0501PH6P0R8R@0
9BDW01lR900O8bH00P0N8RD06P0O8bH082@W01lS9P0R9RT0;c<f01lS9P0F6Qd07B4T01`L7P0D4Q<0
7Q`M01`L700b<S80LG=b06a]K00?3`l04a4B01XE5P0H3a8060dA01H<3P0M4a@04@L801P>300_9B<0
6Q4<0P0D2`H02`0F30X05@/:01H<2`0U6a`04PH601451@0B1PH04`L701D92@0G2`/050P800805@T9
00<050P801<71`0B1PH00P0F30d0100C2@X050X;01L=3P0B20T201lE5P0E01T?400@1PL03`D601@:
2`0H30h04PH801@82P0J3Q005PX<01<72@0H30h05`/=01<72@0D20X05@T;00h2100V6Q`03`<50186
200G2`d040D600H04`L900d04PH801061`0D2P/040H701882@0]8b@0`[Ri0=_AdP0d:R/02@0001T?
400A1`P0308300804@D50P0B1PH201<71`0B00l30`0B1PH04@D501451@0B1PH04@L601492P0N51D0
4@L801451`0L3A003@0101D62@0Q4QD09a/M01dC500A20T04`X;1P0C1`/01`29OH40XiNK01lC5`0I
3A407a<G00P0000@1PD00P0D2PT01@0C2@P04PP901<92P0>1@H06PlC00803`@800h05@X>01052@0B
1`/04PH:01<62P0D1@X050<901D52P0C10T04@D901882`0=1`T030P901492`804`L900X04PH80145
1`0A1@L04@D701<72@0B1PP040@600h2100?0`D04`H70`0D1PH201861P0701871`0D2PT05@/:0148
1`0>1P@04@T701<:2@06018620D04`L900D05PP80184100C1@D050H601430`0201@61PD05@L70200
4P@301X<2`0K3@d04`D501@61P0D20X0718C01<92P0Q5QX06A0C01P?4P0?1PT05@T=01<72`0B1PX0
40@801452@0G2`l03P8601T=4@0M4AD03@4500l41`0G2`l03P860106200A1@T02@0101472@0E2@/0
4@D701451P804@D500<04PL601871Oooool04oooool001_ooooo00@03@L9010:300_:B/02P@60P0C
3@l0500H4Q@05@lA00`6200;1@L04P`>01082@0B20P050T701@:100H3PD0:R4@03`c800a:AL07QD5
01H<0@0K40X05`/:01871P0E2`L050/60P0C2PD301@;1P<05@`700<04`X501<91`0G2``00P0J3Q00
1`0F2P`04PH80186200C1`T050P:01H:300L41800P0@10H0200G2`d03@<401<72@0D20X05PX<0145
1`0F2P`050P:0P0C1`T01P0E2@/05@X<00`3100I3a006A0A01X@4@805@/<01X04@L801P>3`0G3@h0
718C01X@4@0<0`@05@/<01L=3P0B20T05@/<01@:2`0?1PL06@l@01061`0H3Pl04`T:01882@0F30d0
4PP901H<3@0A20T081HG01H<3@0D2P/07aDF01dC508050X;01<05@/<02HL7P0I3Q805P/?01<8300B
1`/05@X>01H;3`0C20`04@H:01@93@0F2`l05@X>01P=4@0M4QH06@hB01hC5`0K41@06@hB00805@X>
01805P/?01T>4P0I3Q805P`?01P?500B31005@lC01PB5P0<1`X071HJ01PB5P0B31005@lC00`62P0C
3A40618F01@?5@0E41H301PC6@1Z01LB600I51X05a8H01`G7@0K5Q`061<I01XE6`0M61h05A0E01DA
4P0F4Q407Q/H01hK5P0I5A806aLE01hJ6`0O6Qh07APN01PE7@0L6B<07ahV01dL8@0H61X05QHD01TJ
5@0L7AL071dH02HW8P0Y:BL08R8Q01`L7P0Q82D08b8W028Q9P0Q82D08R<V02DW9`0Q9R@07B8O020U
800V;BL09B/V024X8@0S:2808RLQ02<X8P0T:BD09RXY02L[:P0f>ST0:Bd^02L[;00W:bh0;S8e02H[
;P0X<c<0<3`l01dY:@0]>3X0:SDg034l?P0Z=CT0;3Lk02hi?@0`>d40<Ca2038m@`0`?480<Ci403I3
B@0gA4`0<3m603i=E00nC5D0>DYD03I7D@1KK7H0<dE?03];D00mCDd0>TU<03Q7C@0mBe@0?4YF03Q5
E016Df80@e5N03e;EP1;FF80EVE/05=QJ`15Df00BEMT04MEHP0mBeP0>TQC03m=F013DE`0AUAM04ME
GP14DU/0@U5H03m>DP13De<0AUIF04ADE080@51@00P0A5AD041@D00jBTX0?Ti>04ADE010D500?D]<
03m=CP80@Dm@00@0@U1A04ECE017EEH0AUAE0`15De@04016E5H0IgIl05=RJP13DEX0BEQP04aKH`1?
GVD0BUUP04mNI01FIFX0AUEJ04]JG`1CHVL0D5iP04mMGP1=Fe`404aJF`0?04]IFP18EUL0AUAE04ME
EP1:EeP0FVEU05eXIP1>FeT0E6=P04ULF01?I5l0CF9M04]NFP1<G5T0CeeJ0080DeiL00P0CeaL08VG
U`1LJVX0CE]K05=QH@1:F5P0E69R055OG`80CUaL00T0CE]K04]IFP1<Fel0CEaQ04]JG`1<Ff00CUeR
04]JG`1?GV400P18EeX08P1:FE`0BEQK04]JG@19EU`0AE=G04IDE`19EeP0A59B03m>B`10Cd`0?D]<
045?D00oCE00?daB03a:C@0jB4T0?4Y:03U7A`0c@D40=T9003Q4@P1DGUd0=3lk03U4@00h@Ch0<S/f
03U2?`0h@440<SXl03Q0@P0e?D00>4130418B`0c>T0203Dl@P0:02`c>`0^=Cd0=Se3030c>@0a=3T0
>Ca102X]=00^<CP0;c8j030c?080<C<o04X0;Blk02PZ=P0W:C009RL[02`]<@0[;300;2da030a=@0Y
:Rh0:b``02`]<@0Z:bl0:BX^02X[;`0X:Rd08RHW02da<P0P92D0;C4b02P/;@0S9bP07b<T020T9@0c
=cP0:Rh_02DY:P0[;C<0:2Pb02XZ=00];CH0:BTa02XZ<P0^;cD0;Bhc02X[;`0[;300;Bhb02TZ;P0[
:b`05ADE02PX:00N7R008b<U03He>P0P7bD07A`R028Q9`0K6R808b8Z01HE7@0S82P0:2D]02DR:@0R
7bH081dS02<Q9P0N71l07Q`N01hM7@0N71`07A`I01/J5`0I5AD071PI01/G600J5QL07ATJ01`H6@0H
51D07QXK01`H6@0I5AH081`M01/G60H06QHG00H07ATJ01PD5@0R7Ql0920Q01TE5P0F4Q<401/E5`80
6Q@F01D05a4C01PB500I4aD06A<E01PB500G4A<06a4I01dC6P0?1P/09QdR01D<400I41<06Q4D01T@
4P0H3a005`h?01L?3P0G3`d050h>01D?3`0F4100100G4A406@0F41005@l?01H@400F41005a4A01PC
400F4@h061<@01/F4`0H4a005A0=01PC400G4Pl061<@01XE4P0I51405Q8?01dJ6@0F5A<051<A01TH
5P0L6aT06aXH01TH5P0G5Q@00`0K6QP01@0O7Q`07AdO00`<3P0P82807alQ0080820R0P0U9BL0:00T
92H0;Rh`03<c=@0/;c409R/^02@Y;00P9BP07R<V01lT9`0L8B@09R/^03Dj?@0T:B`06QlR028W:P0N
82807A/L028Q8@0J6QX07AlN02DW9P0M7ah051DE01@B4`0I5AH06aDG00X1100F31006@lA01882@0G
3@/0:AlL01XA2`0D2`@050/501L=2`0D2PX040H701P=400C1`P201861P0301<71`0E2@T05`/;0080
5@T90P0F2PX00`0E2@T050P80147200201482@0:01@;300J4A8060l@01@;300E30d04`X;01482@0B
2@X06A0A01H:30804`L90P0F2P`03P0D20X05PX<01H:300A1@L05PX<01/?4@0B1PP05@T;03<W:@0<
0P<05PX<01451`0?0`D050P:0`0C1`T03P0E2@/050T;0147200D2``02P4201482@0C2`/0:R4R044h
>@0E3@h05@`=01<:2`0B2P/04`T:0P0A1@D201861P804`L701805@T901<71`0B1PH04`L701X>3P0O
5A@0F51@00h51P0;0@804@@601X:3@0G1`X05@D801P9300I3@l050X;00d51P0>1@H601<72`0N02dQ
9@0Q5AT02`4301@9300E2`d060`>01D;2@0D2PT04`T801881`0F30d060h?04@j>`0A20X03`@80187
2`0=0PH04`P<01872`0D20`050H;01<42@0D0`T05@D;01011P0?0`L050X=00/51`091@H04@T;0P0C
1`T2018620804@D700H04PH801<72@0A1@L040@601451`0D1`P201D51P0:01D61P0D1PH04PH601@9
2@0E2`X04@T700d50`0;0`403PT601<:2@D04PH80P0C1`T30186200301<72@0E1`L04`D500804`D5
00<04P@401<51@0D1PH0100C1@D0100D1PH05PP701`>3@0L3Ph201@61P0K0186200?1@H07Q@E00`3
1@0=10L08aXM0:NNX@0W6al060`@00h21P0B1PX04@D901<72`0A1`T06`lC02HJ7P0K3a<050P<00/0
0`0L41@0:QhR0105200D20`050T;0187200A1@L04@D600804@D500<04@H501461?ooool04oooool0
01_ooooo00<04`d?01LA4`0i<cD00P0C3@l05`0?2@/03PP:06IPHP0i<cD04`d?00d72@0Q61T02@00
02PM600V718030<0048j9`2m]Ih0Z:2;04Y1;P0J4@80718:01D:1P0G30P05Pd801<:1@0B2@@040L2
00804@P3100C2PD00`0A20<040H401L;300201T=3`0@01H:300E2@/05@T;01L;3@0J3Q007Q8D02DI
6`0E2@/04PH801@82P0800005@T;01<72@0G2`d03`<501H:308050P:0P0C1`T0:P0F2``05`d>01hD
5@0G3@h05P`=01T?400?1PL09adN03P^;`0P5QL03`D601P>3`0C2@X06a4B020F5`0D2P/04`T:01@:
2`0E2``03@<404To@00[8B805P`=01D;300?1@H01`0001T?400B20T02@000147200L4Q<09A/L01hD
5@0D2P/05P`=01X@4@0b9bX07a@H01462P0F2`l07A8F01872`806PlC00<060dA01@93@0C20`00P0H
3A401@0D2@d06PlC02`Q9@0N4aL04PL;00805@X>01805``@01X?4`0J3a<05P`?01483@0D3Q805a4E
018<400?2@d02P@801D?4`0K5AT06A<G01<=4@0L5QX050hB01D@5P0G4QP201TD6P0=01HA5`0D3aD0
71LM01<>500E41H0=S4g01HA5`0M61h05A0F02HQ9@0@30d061@C01LC3`0201LD3`0N01TE4`0L61T0
7QTM01dH7`0J5b007AXU01`K900L6b406aXO01/K6P0K71L07AhH01`M5`0U9R40:BTW020P7`0H61X0
7ahS024P9@0Q8B<07b0R024R900U9bH08bPU028W8`0N8ad072<K024X800V;BD08bPQ0P0S:280400U
:RH09b`X02L[:P0]<C409BTZ02HZ:`0X;2l0=CPm030e>@0V<C40=41003U5A@1LIfT0;3Lk020[;`0^
>Cd202dh?P0P02lj@00a?480<ci403A1A`0b?dD0<3e303A1B@0gATd0AUEL045BFP0gB580@59L03]=
E`0bA4h0>DY?03];B`0lBdh0=dI<03U7D00jB5D0>4ID049?G`12D5d0?D]F03Y8D@13DUT0BUQQ03U7
E00lBUL0@U1M03i<F@0oCEP204ABG@80@e5J00<0@4iG03m>E@0oCU801@0oCdl0300iBDT0?4a<04EE
E@0lC4`0<41003];B`0nC4d0@Dm@04ABD`15De@0AUAE04QFE`<0AUAE00l0AeEF04QFE`1:F5X0IgEn
051NJ@0nC5P0@e5L04ABF`19Eel0I7=j05e/L@1;FUh0CeiQ04iMH01?Gf00101?GEh204iLG@03059P
H@1?GEh0C5YK0080C5YK01H0BEIF05INH01JHf80BUID05UXI@17FED0B5]G04]NFP1?H5d0CUeJ04]G
E@1>EeH0E5eL05EQH@2>W9d0FVQY055OH01HIVL0CUaM05=QHP1?GEh0CE]L0P1>G5d02@1;FEX0CUeR
05ETJP1>GF80BEQM04YIGP19F5d0CeiQ04UHF`0204YIG00j04ADE@14DeH0B5EK03m=D@12D5<0CeeN
04]IF@13DTl0BUUF051NG`0e@d@0>DM:030m@`0c@D@0=D=403A2@P0c@D40<T1003A0?P0e@Cl0GFQT
030k=`0_>SH0=Slj034j=@0c?3T0<c`l0418BP0j@T@0D5QK03@k@@12BDl0>D16034h@00`=cl0:c8j
02T`>00/<cT0>Ca204I9D024Qhh0<C@k02LZ<`0l?dP0=CQ103HhA00`<Sh09RPd02DW<`0Y:c809BHZ
02X[;`0/;C40:b``030a=@0[;300:R/_02PY;@809BHZ03d0:BX^02X];`0P92D0;S8c01lS900]<C80
;c<d02<W:00Q9BH09BTZ038f=`0X;2d08bLX02PZ<00V9S00:2Pb02XZ<`0U9Bd09bL_038c>@0/;C80
9RL[02TZ;P0V9b/09RLZ020P800b<S00>CTi02DU9@0B4Q80820R01PG700N7B8081lU01XI8@0d<c/0
61LO01lL9`0W92l06QLQ00h;500O72<081hS01/I700M6a`07adM01/J5P0J6A@07ahI01XF5@0M6AX0
8QhO01hJ6`0H51D06ADF01XF5`0N6Q/071PI01HB4`0K5aP07QXK00H06ADF00H07ATJ01PD5@0_:b`0
IF5R01hJ6`0I5AH201TC5@80618D0P0G4A<00`0E3a405a4C01PB500301PB500801H<500D2A007A8H
02DJ800J3a@07Q<G01T>4P0I3Q4201P>3`0401X@400I4@l05Q0@01H@40805a4A0P0F41000`0G4A40
5Q0@01D?3`0201H@400?01LA4@0G4Pl04Pd:01<>2`0H4a005a8?01<>2`0H4a005a8?01TD4@0K5Q<0
6QDB01LC400D4Q006APF00807ahL00h061LE01DD4P0I61H06APF01dL6P0L6aT061LE01/J600G5aT0
=SHh05eMG`0`<380:b/]01`L7P807AdO0P0R8R@02@0U9BL0:B`^02P]<@0V:bl092T]028W:`0Q9RX0
82DY02H[;`0202DZ;P0L02@Y;@0P9BT0=3Hh024O800B4Q808b@T014C4P0?4a806QdL01HH5`0V92D0
5Q8C01TC5@0G3Q406@lD01H;3`0I3a0050X901480`0E30H04`X301480@0D2PP05`d>01H<3@0J3a<0
5PX<01H:2P805@T900`05PX:01L;2`0D20P05@T901H:2P0G2`/05PX:01H;2P0A1`P050/<01892P0>
1@H200l61`0601482@0@1`P04PT:01892P0@1`P030<40P0D20X00`0@10H03@4300l31@0201D92`0M
01L;3@0C1`T06`lA02DI6`0I3@l081@F04Tm?`0H30h05PX<01L;3@0A1@L050P:01<72@0B1PP04`L9
01D92`0E2``081HG00d51@0A20T0200001<:2`0N5AH05Pd>00`3100;0P<02P4201892P0600000P0A
1@D201861P804`L701805@T900l30`0B1PH04`L701@8200I3`h04P/<01H=3P0X7Ql05PP;00/0000A
00806@L;01<41`0B1PP05P`=018<300@1`P601<72`0O01872P0C1`/07a<G00h21P0K3a<05`/=01<9
1`0D2PT04`T801881`0D2P/05P`=01H>3P07000040D901T>4P0<0@D04@H:01872`0E2@d04`H:0142
1`0D0`T06@T?01<42@0>0PH04PP;00X41P0<20T04`/=01451`030186200301<72@0A1@L040@60080
4PH800<040@601451`0D1PL00P0E1@D01`0E1PD050H501871@0B20H040H400h60`0?2@D00P0@2`L0
0`0A20P04PH8018620040186200U01451`0@10H03`<501041P0B1PP0408201H8200D1PH04`D501/=
3@0J30`05@L701@61P0C1@D04P@401<51@0E1`L04P@301H81`0E1`L04`D501D71`0A1@L01`0001D;
300E2Ph050/>0189301TFeh08aLK01D93@0@10P050P<00l31`0B1PX07a<G00d21@0200P0000:01@8
300B1PX02P0204/o@`0[7b<04@D900l51P0?0`D04PH801861`8040@400<03`@300h30Oooool04ooo
ool001_ooooo01/060lB01492`0U71l030<600l82@0F3A004PT<07U`L`0n=CP06a8E01092P0B2@X0
5P`;01dB3`0T6Q409A/?081hIP3oonX0oo[U079YE`0Q5`/06a4:00l40P0B1`D060h<01@:2@0B20H0
0`0@1P@401@:200501881P0A1`D060`=01T=3`0H30h00P0F2P`01P0G2`d060`>01041P0?0`D06Ph@
0186208050P:00D02P0001T=3`0B1`P060`>01<72@0201D92`8050P:01804`L901872@0^92D02P01
01@;2`0C2@X03@<401T?400D2P/07Q@E01D;300C2@X06@l@00l51P0O5AH0:1hO01H<3@0@1PL201D;
300S030V9`3?aLH0OgEf0147200B20T04@L801L=3P0R61T0718C00l51P0M4a@03@@501X@4@0F30d0
4PP901@:2`0A1`P04`P;01462P0H3A004@L801X@4@0E2``06Q0A01`B4`0K41@04`P<01872`0I3Q80
6a0D01@93@0Q5QX0>Rlc02@I7@0B1`/00P0E2Ph0@@0G31006PlC01T@4`0E2`l050/@01dG6`0H41D0
3PD:01lI7@0J4QL02`8701dG6`0E3A803@@901`F6P0E3A805a0G01PA600K51/06Q<J01LA5`0C3Q@0
6A@J01@?5@0K5Q`0CdY@01PC6P0J5A`08A`R04<n@`0Q7Ah09B4P01TF4P0I5Q4061D@01TE4`0J5QL0
6aHL01hH8@0M6R<07a`W01TH8@0J6Al0820R028R800L7AP09bPR01/L5`0J6QP07QhN01hN800O7R<0
7QdR020O900P82807b0R024R900T9RD08RLT030e<@0]<R`07R@N01hS7@0T:B<0:2`V0080:B/V02d0
:RdZ02`^:`0[;bh08bLX02L[;00]<C80<CDh04A7C014BDd0;CLi02La<`0H8bD0=T5402Xe>@0oBTh0
<3/o02dh?P0/=cd0;STo034l@P0a?T@0=T=903E2B00X=C/0<Sm703m>E@19Ef00?DiG03m@FP0oCe`0
?4iJ04=CH00iBDl0@51@049AE00kBU00>4I?03Q6D@0hAU@0=dEB03I4D@15Ded0?deF0350A`0hAe00
0P0e@e006010CU/0@DmJ03m=F013DEX0A59K049@F@10CUL0?deF03m>E@12DEH0?diA03]:C@0lBdh0
?Ti>03]:C@0mCDd0>d];03I6AP0lC4`0@U9B03Y:BP0iAdP0?4Y;041>C`80@Dm@01D0A59C04MEEP17
EEP0B5II04UGFP1:F5/0CEYO07>1S01OKGX0CE]X04aJI@18EV40CE]T04ACFP1CHVT0Df9W05UXK@19
F5d0CeiQ04mMH01@GV400P1AGf809P1@GV40D5iP051NH@1<FU/0BUQI04mMGP1AGf00BeQH04I?CP1?
F5L0AE5?05UXI@18Ee@0AeMD04]KF01AH5d0CUeJ04UED`1:E5<0DeaK05MSH`1@GUh0@e5A05]YJ@1:
F5T0C5YK055OH01=Fe`0C5YK04iLG@1@GUl0CE]N04EDF@1@GfD0BUUN04=BE`16EEX0B5ML0P1;FUd0
9@1=G5l0BEQK045@DP10D500AUAG04QCE`10Bdl0@4]=059NGP1OJfT0Kg]k08^FV01@Fed0?dY>03Q3
A`13CU80=40o02hj>00_>cT0=40n03@n?@0a?3P0<Sdi03Ho?00g@3d0=Slk03@m>P0c?3T0=d1105eU
I`0mAdP0Ri>F051GG@0f?D<0<STo02H]=@0Z<CT00P0c>T803P0d>440=CPm01hO9015B4l08bH]02P[
=00_<S/0<SDn03Dg@`0]<C`092Pa02HZ<`0]<3H0:2T]0P0[;3004@0X:Bd0;Bhb02//<00[;300:2T]
02@U:@0V9b/0:b``02`_<@0R9RL0<3@e02P/;@0Q9BH0?d=402/_<00V:R/08bLX00808BDV034092PY
02LY;P0V9Rh09bLa02PX<00T92`09BD]03<d>P0Z:c0092DY02//<00U9RX0:BX^01TI6`0f=SH07AdO
030`<P0L71h06aXO01hM8P0S8RP07A`R01lN9P18Adl0;B`d020M:00H5B009B8[02HS:P0L6B006ALK
01/I700K6AX05aDE018A3@0H5a<0:RTU02LS900K5aP05a<D01lK700M6AX06aLH01TE5P0E4A8071PI
01lK700G4a@06aLH00H06ADF00H0<2`]01/G600I5AH0;BTZ01HB4`0L61T201LA4`0601H@4P0E3a40
5@lA01@>400E3a405Q0B100H4Q@02P0Q61d0718G01/B5`0;00H07Q@H01482`0I3Q806@lA01P?400J
414201/B4`0401/E5P0K5AL06Q@D01XD5@<05a4A01D05Q0@01D?3`0F41005Q0@01LA4@0H4Q4040/8
014<2@0G4Pl05Q4>01<>2P0I514061<@01TE4P0L5aL06aDE01PD4`0M71X05QDC01LF500L6aT00P0K
6QP0300J61T06aTJ01lM7P0M6a`061HG01TG600N7R003Ph@03`l?P0V9RP06a/M02XZ;P808b@X02X0
:R/_02@U:@0U9RX09bX^02<X;00T:Bl09R/`02L/<00X;C<0:Bhc02T^<P0L8BL092T^02H[;`0I7R@0
92DZ02@T9P0M7Al07QlQ01lQ800M7ah061TH024Q8@1ACe00:RDW01<:2`0M51L05Pd@01<:3@0N51D0
5P`<00T0000H3`X07A@?01L>2@0C2@P04`T:01061`0A1PX05PX<01H:2P0E2@T201@8200301D92@0D
20P050P800@05`/;00l03@<401892P0E30d04`T:01D<3@0J41405@/<01482@0?1PL050X;01D<3@0D
2P/03P@501882@0E2@/00P0@10H05`0C1`T04@D70186200<008050P:01hB500?0`D060`>01H<3@0<
00805`/=0187200E2@/050P:01<72@0B1PP04`L901D92`0G2`d0DdU:00l51P0K4A804PP900803`D6
00P02`4201H<3@0G3@h02`4201482@0F30/04@D501461@804PH60P0C1`L0500L410050P801L;2`0D
20P03P820104100>1@<040H501861P0E20X05PH901L72P0F1@X03`0300l31@0G3Ph05`l=01482@0C
1``04`H=100C1`/02P0@10P03P8600h21P0G2a002P0401@8300?1@@050X901D;2P0C2@P201882@0B
00h61P0L4AD04PL;00d21P0B1`/03`@901873@0E20l04`D<01422@0C10/07@hC01T:3`0@10P04PP;
00h5200C3@l060lA0P0A1@L00`0B1PP04`L901<72@0201<72@0A01@82P0A1@L03@4300d10`0A10D0
5@D501D51P0E1PH050H501861P0B1PD03`D301471P0H3`d06a<@01P@3P0C2@T01@0B1PP04`0C1`T0
4PH801041P0?0`D040@601<72@0=00005`T901D71`0D1PH08A<C020B4P0G2@T05PP801@61P0C1@D0
50H601L92@0@0P800P0C1@D04`0D1PH060X:01<72@0[7b405`d>01052@0C20`03P<701L<400E2@d0
3@4501452@0F2Ph040@801L;3`0=0@D04PH:01X>4P0A1@T00P0D20`0300G2`l0PGEi05]?D`0D20`0
308401X>400C1`T04PH80104100?0`D03P8200d10ACooooo000Kooooo`0T01461`0A1`P04@H70187
200D2@X0=b`^020E5P0F2`d05``=01H;300C2@X0:1dN05M:D00l<3806Pl<02HK501[HED0dLbl0<k5
]@0n=2P09AXC01461@0I3A003`@9038W;@0]92X060lD01072`0D2`l03PD901<:300=1PL060lA0108
1`0<1@@040L71P0E2@T01`0B1PH04`L701@8200B1PH04`L701D92@0C1`L00`0E2@T201<71`0601@8
200<0P8060`<01@8200A1@D050P80P0E2@T0100G30`081@D01H:2P0D20P201<71`0401861P0C1`L0
4`L701882@804`X=02D04PT<01<:3@090@<05Pd@01D<3`1=A4L0<BP[01<:3@0F3A004PL901P<3P0a
9BL05@T;01041P0D20X05PX<01041P0I3@l07A4C01@82P0F2P`05P/<01H<3@0G3@`05P`;01D;2P0C
2PH050X801@:2@0F30d05@X?01@93`0C20h05PX>01T=3`0H30h060h?00807A<D00P04@P901/B4`0D
2``0614A01H@400F3a005@/@01T?5`806@hF03T0718J01P=5@0C210091XR01P=5@13>400>Rlg01T>
5P0H3AL06@hG01/A6@0L4aP071@H01XC5P0K5AT06Q@I01PC6@0G4QX0618N01TC7P0J4AX08APO024J
700L5QL071LD020K5`0J5Q<06aPG01PF600G5AX06QLP01`I8P0M6R4071TN01XH6P0I5aP06aXG01lN
6@0K6QH08R0O01dK7@0M6al08b4Y020O9`0P7bH07QlS024R9P0N7b<0:R/]02DV:00/;Bh09RPW028T
8P0Q924092HT02DW9@0W9bD00P0T92803@0U9RD0:BTY02X[:`0Y:R`0:2`_02HZ;@0]<C@0<CDh02db
=P0[<SP0:c8i02/c>P0]=S`00P0]=Sd00`0a?480=D98038oA@02030m@`0U02hk@@0b@D@0<d9503A3
AP0hAdd0>4I>03e;E00nC5P0?TaJ03i;F`1:FFT0=T=E045>F00mBT`0>dU<03e:DP0kAe80>4IA03]9
E@0nC5T0>d]H04IGH@11DUX0>4UA03i>F@0fAUD0?TiK041@F`0jBe80AeIM03Y9CP0lBdl0?DY@03e:
D@0mBU80@DaF045=EP0203i;DP0M03m<D`10CE80?daB03i<D012D5<0@DmB03U7B@0kBDX0?de>04UG
E`16E5@0HW1a04aJF`0kBDX0@DmB041>DP15DUP0BEIM04MDG@19EUl0DUmY07F3SP1<FVD0AUAO04mM
J019Ef80CE]V04aJI01WMGl00P1EHfd01@1=FfD0BeUR05QVKP17EU`0CUeS0080CEaR02l0C5]O04iM
HP1>GF40C5]N04MFF@16EEP0B5MG04IAC`1;EU80BEA@04iJEP1:EU80DUiJ05AOF`1<F5@0CeYF055L
F01;EU80BEEA04YFDP19F5<0BEQE04YIEP1<FUT0C5YJ04]IFP1=Fed0CE]N04]IG01=Fel0DUmU059Q
J01;FV40BUUP04MFG@1?GV@0AUEJ04aKH01>GF40AUEH04EDE`1;Fe`0BEMH04A?D@18DE@0Ae1C04A=
C`0204=<CP0]04M@D`1<EEL0@DY<03]4A`0i@TD0<S/m03Dm>00j@S`0ADe703i6@P0b>SH0=chk03U1
?P0j@3h0>3hl03Dk>P0e>c/0=Chm03M2@`18DeD0=D1208bFV`0kA4T0;CHk02lh?`0b>D40<CQ003e4
CP15BE@0BDaE034b=@0a<3D09bL]030`>@0]<3T0;c8m038f@@0e>d@0=Ca402hf>`0Y<CL0:Blb02X^
;`0Y;Bh0:Rh_0080;C4b00@0:2`]02HZ:`0U:BX09BTZ0P0T:2T02P0V:R`07R8U024U:00R9RT0:2`_
02da=00T:2/09RX]02L[;P0X;2l202L[;P0502LZ;P0Z:c009bL^02DV:`0W:2d00P0Y:Rl0>@0Q8RL0
9RL/02X[<00N7b@0:BX_02DT:`0V9B`09B@[01PG7P0M72<0De9I02@S:P0o?TH06aXR01lN9P0/:c<0
8b8Y020L8`0W8RL061<H02<N8`0G4QL07APL01lJ7P0F4AD081/N01XE600H51H0KVY/02PT9@0R7Ql0
7a/L01hJ6`0I5AH06aLH01TE5P0M6AX06QHG01LC500M6AX06ADE01dI600K5aH081`K010<2`0G4a<0
5a<D01PD5@0H4aH09R4U02@O8`0N6Ad050lC01D?4P0J51H071HH01D?4@0201lI6`805a4C0P0F4182
01D?4@0701/E5`0H4A@06A<E01TB500E3Q405a4C01D>400201LA4`0801L@4P0G4A<06A<E01@=4`0B
3100618E01D?4P0F418201PB501<00l92@0F410071HF01XE4P0D3Pd04`X<01dD5@0D30/04`h<01PC
3P0I50h05Q<=01DC3`0D4a4061DH01XF700E4aL0518D020N7`0E4a@081hO01dK7@0J61X06aTL01`J
7P0Q7b<07Q`P01TF700J61h071/P01lN8`0Q8BD08B8V024S:00Q92T08RD[028V:`0R9Rd0:Bde02T/
=00S:2l08bXa02D/=00W;SD0:C0g02T`>00T:c80;3<j02L^=P0mA4/0GfI]02Xa>@0S9Rd071dS01hO
900P82H06a/N020O8P0N6ad07QTK024I6P0N5AD06Q0?01/A4@0I410071HF02<L700J4Q804@T801hE
5@0C2@T05`d=01/A4@0F2P`04`L901L;3@804`L901h04PH801T=3`0P51H0ACTk01041P0D20X04PH8
01T=3`0C1`T04PH801451`0K41409Q/M01@82P0B1`T04@H801D92`0?10D04PL901D92`0@1@L0714B
081eN@0_9RT040L:01hC5`0B1`/04@L801451`0B1@H401<51@0800l30`0C1`L03`<301H:2P0Q5AD0
5@T901861P0E2@T201H:2P805@T91P0D1`L201D8208050L70P0C1PH00`0E1`H05PP501<50`0201@6
1@0O0104100D1PH07@h@02XK7P0G20/05@H901@61P0D1P@05PL501L81`0G1`T05`L<01H7300@0`P0
5PX>00l31@0G3@`04PT501471P0C1Pl040<=01@73`0E2@h04PH901<72@0D20X05`/?01P<400C1Ph0
5@PA01853@0201L;3@0401D92`0C1`T050P:01H:30805@T;0P0D20X01@0C1`T04`H=01@74P0F21@0
50LB00804PD>00L05@P?00T00`0G2`l04@H801L<3P0]8R<05@X;00D04PH80P0C1`T401451`0M01D8
2P0H2@/05`P;01D62@0C1@H04P<601<41`0C1@L04`H801@62@0D1`P050L901<72@0B1PP04`L90186
200A1@L040@601882@0H3Pl050T:01051P0>0`@050T;04Tj?@0S51L050D80101100D1@P00P0F1`X0
3P0D1@P04`@701T:3@0J2`h050H801D62@0@0@@050H801831P0L3A0040<401@5200C1PP050H80`0C
1PP00`0A1@T050P<01L;3`0201H:3P0:01862P0:00805@T=00h31P0@10P0710D01H:3P0?10L06`lC
01L;3`804@D900L03P<601H:3P0A1@T04`L:01@8300B1PT05PX=01Cooooo000Kooooo`0T01D92`0@
10H03P8401`@4P0F2P`03@4302/O8@0K3a404@D701X>400P51H03`<5034T:`0d:2/03P<101X?2`0A
1`40;bDI044g:`0K4@H050T501<71`0H31003P<900X11`0900L01`0501P?500L4aH03`H900l72@0N
5AH07aHG01482@0B2@X05`h?1P0E2@T01P0A1@D05PX:01D92@0C1`L05@T901H:2P804`L70P0D20P0
3P0C1`L04PH601461P0N4Q804`L701P<300;000050P800h20P08000040@401dA4@0G2`/03`@40P0C
1`L04P0B1PH04`L701<71`0C2@X06a8E01P?4P0C2Pd03`H900h5200H3a801`0100l62@0<0`H05@`?
01072P0B1`X06Ph@02`P8P8060`>00d05PX<01051P0L41806Ph@01D92`0H30h050P:01P=3P0E2``0
5P`;01H<2P0E2`T050/600805@/900h05P`=01D:400D2@l04`P?01H:3P0K3a<06@dA01P=4@0M4QH0
4`P<01hE600F3A0060lB01H@4P806Q@F00D05``B01X?5`0J3aL060dE01X?5`0201P=5@05020E7@0K
41P08AHN01dB6P0J3aL00P0J3QP0:P0I3QH060lD01T@500J4A@06A<G02<M8P0T7bD071HP01H@700G
4Ad05`dF01dC6P0N5AP06A<E01TD4P0M61D08QhM01hK6`0O7B008b4V024N9`0K624081dT01`J7P0O
7Ah07Q`M01XI5P0Q81`09bHT02DS8`0V92L09B<X024N9`0Q82P08b8Z01LH700X:Bd08b@X02@U:01S
I6H0=CHh02PZ:@808B<R00<09bTX02`^;@0Y:2H00P0U9BD02P0V9RH09RLY02PY:`0[;2h09b/^02@X
:`0[;c80<3@g02`a=@0Z<3L202`c>`1`02Tb>@0[=3/0;SLn02`g?@0X=C/0<Ci402`i?`0Y=S`0<d16
03I5B00c@TL0=4=803A3BP0]>d@0B5IO03e;F00iAUH0FFIf04UFI`0d@E@0?d]G03e8C00e@TP0<3e6
03M3C`0gAE80?4UI04YGI`13Df80AEER04QIH`0nCeT0?DeI045AH010D5d0<dA>03U:D@0oCUD0>TU=
03]:C@0mBU00?4U@03a9D@11BeD0@diG03m<E00nBe<0@4eD041=D`0mBU00?4Y>041>D@0lBTd0=D=5
03U7B00oCDh0@Dm?03i<C01?GEh0?de>03E3A01<FUd0A55G04]HGP1=FV80A55J04=@F@1CH6T0D5iY
04ABG@0jB5<0CUaW059PJ`1GIG00FFMb08jLY`1MJgH0GVag05QVL@1BH6X0A59K049AF017EUd0CUeT
04mNI@1BHFH0CEaO04mNH@1@Gf80C5aL04YJFP1;FUX0BEEC05ANG@18DU40C5IE04mIF01@FUT0GFMV
051JF@18DU40BE=B04aFE@1CGed0Ef=Q04mNF`17EED0AE=C04QFEP1;FEX0BEMJ04UFF`80AeAJ00l0
CU]R05ISJ`1AH6L0BUUP04=BF@11D5L0CUeS04=BE`18EeX0AeII045@D`12DU80Be]K04mMGP12C4h0
0P15CE000`11BD`0@4Q;0459C00204=;CP0=03U1A00h@4<0?4A703Q0@P0d>cD0>d8k03m6?`0m@cl0
=C/i038h=P0i?cd0>Clo03Pn?P0203Dk>`0L03@m?00f@D<0;STk02dh>P0_>Sh0<3Tn02hg?00c>T80
>3m7034h@00]<C`0:blj03PkA00/;340=CHk02h_=00[:c@0:2Xf038e@P0`=3l0<SU303<j@P0^=C/0
:34f02P^<@0W:2X092DW02DV:0809bPZ00<0:R/]02//;P0Y:R`00P0W:2X0200Y:R`0:R/^02d^<P0Z
:bl08B8V01TJ7P0V9b/0=CHj100Y:Rh0100X:Bd09BHZ028S:00O82D202TZ;`8071dR03/0:b`a01/L
8@0P8BH08R<X02<T:@0X9bl07ahV01hM9@0S8RX092<[02h]=@1LFf<0F5MO02<R:P0E51`061LO01LF
7@0H4aT091lS01PC5`0F4AD0:RDY03@_<`0N6Ad07aXN01hI7@0J5AT061<G01D@500L61T06QHG01/G
600L61T06QHG01/G600G4a@06QHG01TE5P0G4a@06QHG01LC4P0B3Pd04Ph<01/G5P0Q7A`0EU9B08=o
P00F4Q<05Q8D038]<@0A31006A@I01`G6`0G4AD07aTK01D?4@0>20X09b4S02HP8P0201LA4`<05Q0B
00H05@lA01TC5@0F4180618D01LA4`0C3@l201D?4@0701H@4P0E3a404`d?01@>400F418050dD01@>
4P0201LA5@0Q00d72@0E3a405a4C01XD500M5aL08adM01TD4@0A30T06A0C01892P0A2@L091lK01dH
4P0400004a0;028Q7@0Q81h0=38e04m<D`0O7B804Q0B01DC500A3a006ALH01<A500F51L08R0S01`J
7`0M6b006aTN01XG7P0N6b807QhR00<0824U02D082<X028U:`0T9bh08RL]028V;P0Y;CH0:2lg02Xa
>@0U;3@08bXb030g?`0_=Sh0:S4i02lf?P11B5008BP`02P_=`0^=Cd09Rde03Pk@`0Z;C@092@/024Q
9`0P7b@08b4V01XG6@0I5AH06aDE01XC4P0I4@l06Q0?01`D4`0M5aL07aTI01dF5P0I41405Pd>0080
5`d>02@05P`=01H:300F2P`05PX<01D92`0D20X05`/=00l31@0800006Q0A01P<3P0K3a405@T;01T=
3`0F2P`06`lA01D92`0G2`d04@D701D92`0<00804`L9024E5`0F2P`04@D701<72@0A1@L060d?04a1
A@0A20/02`<501L<400I3Q8050X;01451`0B1@H301<51@0:01<5100A1@D05PX:01451@0C1`L0710@
01T=3@0@10@03`<301<71`805`/;00<04PH601D71`0E1`L0100E1`L00`0F20P05@L701D71`0201@6
1P0501@61@0B10<05`T601<50P0B10<00P0F20L0200H2PX03P0201@5200A0PD06@X=01L82`0E1@D0
5PH60P0G1`P201D62@0I01451`0L41803`<502@J6P0P5QD040D901D74`0E1a@05@PB01032@0?0`L0
50P<01H:300800003`<701452P0=00L03P4801D9300E2@/050P:01<72@0E2@/05`/=01D92`0201@8
2P804`L900d04`L>01D7500F2A<05@PB01853`0C1Pl050L?01442`0G2`l04@D800h2100A1@L03@<4
00H04PH80P0A1@L01@0B1PP04`L901D92`0F20/05PL:00805@H90`0D1@P01P0E1PT050D801<41`0B
0`H04@8501851`804`L90`0B1PP02`0H30h0200000h2100?0`D0300201hB500O41<04@8501H72P0B
0`H0404400805@H900/04`@701@5200J2`h06``?01P9300F1`X03@0101/<3`0@0@@04`@701831P06
01@5200H01D93@0@10P05PX>01X>4P0?0`L03P8600l31`0>0PH04PH:01L;3`0I3A405PX>00/00`0F
2Ph05`/?01<72`0A1@T03@4501862P0F2Ph04@D900d11@0@10P04PH:5?ooool001_ooooo02@03@43
01/?4@0D20X060`>01H:300C1`T05PX<01041P0D20X05PX<01X>400>0P@070lF01L;3P0I3P`04`P4
02TO5P0P5PX07aD901X@1P0@1@404PL701862P0F2A008QLO03T_=`0W7BD02`<701072P0H3a806Q4D
01<:2`0A20T02P8301892P0J414701@8200601T=3@0E2@T04@D501451@0@10@05@T90P0D20P03`0F
2PX05@T901<71`0G2`/0Ac/k01<71`0D20P04PH601L;2`0N4Q806`l?01<8200=0@40710@01H:2P02
01<71`0D01861P0C1`L04`L700l41P0F3A003@@701482`0@1`X04PT<01072P0F3A007QDH01P?4P0@
1`X02P4401@82`0C1`T07a<E01<72@0I3@l20186200801P<3P0G2`d050P:01451`0D20X06Pl@01D;
300E2`/201D;2@0D01D<1`0E2`T05P`:01H<3@0E2Q0050T?01@94@0L3aH05PX>01852`0?10X040D9
020E6P0I41D030<601L>4P0>20`03`T;010:3P0G31@201T>5P<05``D00H060dE01T>5P0N4a/05@XB
01@94@0J3aL201X>600801T>5P0H3a@06a8F01dD5`0L5QX08ahS02@O9@0O6B<201TC7`0V01T?600M
51X07A@I01TC5@0H4Q806QDB02<O7P0K61X0928W02h[<P0T8BX04PlH01lL8`0I5a/07Q`O020N7`0K
6QP07QdI03He<`0V92H08b4V028O9P0P7BH0:BP`01`K8`0b<cP06AXN028S9`0W:2/04Q<E02<T9P0S
9B@092HU02HX9`0W:BP0:2XY02TX9P0W9bL202HV9P809RLY00h0;2d_02L[;P0S9bX0:2`_02``<`0X
;C40:S4h030g?`0_=Sh0:S<j02df?@0b>d80:SDk02Hc>@<0;3To05/0<d1602`k?P0a@4D0@U5F04MF
G@1HIVl0UjF^08FCW`0lBET0A55R03i;G00b?e80=d=@03M2B00a?TH0<Ci8038nC00gA5@0AU=T05=P
L015EFD0@51O04YJI`11DEh0>d]I03];FP0oCe`0?DiH045BF@0fAD`0>DQ<03Y9C00lBDl0>dQ?03]8
D010BU@0AU9K04=@F00mBU80?DYA045>E010CE<0?deA041>D@0mBdh0>TQ:03a:B`10CTl0A59B03Q6
AP0kBDX0?de>03Y8B@14DUD0AE9H04UFG01:Eel0@TmH041=EP18EEh0=TA?04eKIP19Ef80A59M03m=
F01;FF@0B5IQ06ilQ`1>G6L0CE]V04UGHP1>G6H0D5iW05MVK@1?GVD0Df9Y04iMI01@Gf@0CeiQ055P
H`1CHVD0CemO04aLG01<Fe/0DEeM05iXI`1<EUD0CeUH05EOGP1BG5/0C5IE0080BUAC00X0C5IE04iH
E`1@G5X0EfEU055OG`19EeP0AeEF04QFE`1:F5/0CE]N0P1<FEl04@1=FV00DUmW05ISJ`18Eeh0AUEL
059QJ01<Ff80BEQN04EDF@1:FE`0AeII049AE011DE40AEEE04MEEP0lATP0@DU<0080@d]>00l0A4a?
04I>D@10B4/0?dM:03U1A00j@TD0?DE803Y2A00h?cT0=3/d02he;P0_=C40<3Hd02`b<00b>3H00P0e
>c/203@j>P0O03@l?P0^>3X0<3/m03m:C00Z=CT0<CXo02Tb=`0e?4@0<cY202lf?P0c=d809RXe02X]
=P0/:c80=SHn02h^=P0Y:C@0:R`i03DhA00]<Cd0;c<o02lf@00]=3`0:2le02P^<@0W:2X08b@V02@U
9`0U9RP09RLY02//;P0302`];`0902X[;@0Y:R`09bP[02h_<`0Z:bl0:b``038c=`1BDeL0FU]O0080
:BX^0P0Z:bl01`0X:Bd0;Rlc03Hg?00_<3D08B8W01TJ7`0Q8RL00P0Z:c00700N7b@0<c@i02LX;@0I
6Ql0:2L_01dL900J6B408B0X01hM9@0H5al06QTQ02<R:P0T8b/09B@/02<R:P0V9B`07APN02@O8`0N
6Ad05a8F02`W:`0g<SH08QdQ01lJ7P0I51P071LK02@O8`0N6Ad201TE5P0501/G600L61T06aLH01XF
5`0G4a@0100H51D04`0G4a805Q8A01/G5@0L61L05Q8A01hJ6P0Y9BH08QhO01XE601FDED09b8V01@?
500O6Qh06Q@H01PB500J51H050h@01`F600I4aD01P0F41801P0I4aD05Q0B01PB500G4A<04`d?01D?
4@805a4C02T05@lA01<=3`0C3@l05Q0B01L@5`0E3a<02P@801/E6@0E3a403@L901<=3`0J51@071HF
02@N7P0K5Q<05Q4>01P?400A20T040P605=>BP1MF5807aXD01LC3`0D4a404Q4?08n=T036a<T0?3Xo
01`J700J61T05aDF01XH6@0@3Q405aDH020N8@0K6Ah07A/P01/I7P0L6B007ahT028R9`0202<T:00b
028S9`0R9BX08bH/028U;00P9B/08BH]02/_>00/<c/0<3Lo02T`>00X;cL0=Se502lf?P0/<c/0ADaD
06E/M00k@TX0?4=;02T`>00^=Cd0>Cm602LZ<@0T92`081lV020O9@0T8RL071PM01XF5`0K5AL06Q<C
01TA3`0J40l0614@018<300>20P050d=01XA4P0@1`P06Q0A01H<3@0C2@X05PX<01L;3@0F2P`06`lA
01@82P0J3Q005@T;00/00@0C1`T20186200H00l31@0I3@l05@T;01451`0G2`d06Ph@01051P0K3a40
3P8401X>400T61X06Ph@0186200C1`T040@601461`0J3a<04`X=01XA500H3A407a@H00X10P0B1PP0
4`H70`0D1PH01@0D1PD050P801P<300?0`<02P0000803`<300H0710@01D92@0D20P060`<01T=3@0C
1`L801D71`<050H600l04`D401/=300=00006P`901H81`0B1PH0>bd/02TK6`0D1PL04P<601421@0E
1PT0404401D5200F1PT00P0G1`P0300E1`H050H50104100I3@l040@601hC5`0K41@04`P@01@6500D
1QD060XG01@73`80300400L06Ph@01451`0I3@l05PX=0104200K3a<04`L9008050P:00<04`L901H:
300H30h00P0D20X201<72@050186200C1Pd05@PB01L:500E21800P0C1Pl01`0B1@d05@P?01@8300C
1`X04@D700d10`0A1@L01@0B1PP00`0C1`T04PH801451`0301041P0301851`0D1@P050D800<050D8
01L05@H901@5200D1@P050D801<41`0B0`H05@P:01L;3@0E2@/04PH801041P0?0`D07Q8D00P0000N
51D07A4C02DI6`0?1@H05@H90101100G20/05@H90101100201421@80404400P050D801D62@0C10L0
4`@700X0000H2@`04@8501<41`L050D800X0710D01452@0B1PX050P<01452@0S5a/0710D00l31`0B
1PX05PX>0P0A1@T0100@10P05PX>01L;3`0E2@d201@8300600h21P0D20`03P8600`0100?0`L02`03
5?ooool001_ooooo01`05@X;01/?4@0<00804PH801H:300C1`T03`@501P=3P0^8R@06@d?01041P0I
3@l050L=01H;3@0=10<05``8024F3`0I3`L06@l601H<100F2`L05P/;00/00`0H2a8060dC01dB600F
2a404@L<0P0C20`01P1PEUL05`l?01@:2`0A20L04PP701<:2PH050P800L04PH601D92@0B1PH05PX:
01D92@0>0`<050P800804@D50P0D20P03@0A1@D050T903<W9`0C1`L05PX:00l30`0D2@T05`/;01<7
1`0E2@T04@L7038V9P0O4a<00P0C1`L01P0B1PH04`L701<71`0X7Ah0?C8f01H<3`804PL;01H06PlC
01872`0I3Q802P4301872`0F2`l060dA01L;3P0B1PP05`/=01D92`0Q5AL05@T;01X>400:0000710B
02`P8P0C1`T050P:01H;3P0E2`d05@/<0P0E2`T04`0G3@/060h<01L=2`0F30d05@X@01D:4@0E2Q<0
5`XC01853@0J3AD05P/C024F7@20MGd091XR01D;4P0G3AD03PL>00l83P0H4AP00P0F2a<02P0H3AD0
5@XB01@94@0H3AD05@XB01873`0M4QX06PlG01/@600J3aL201X>600;01X?5`0K4QL07QDI020G6P0K
5AT06A@I01PC6@0J51h06Q@P01PB7P0O5Ad00P0O5Q/02P0K5AL06A<D01PB4`0R7Ql06aPK01`J7`0J
5ah05a@L01`I8P0K6Ah201`J7@0A01lM7P0O7Ad061HF02/Y:P0P7R4081hS024N9@0N6b@081lW02<R
:@0c=3P06AXN02//<00M7R408R<U024R900R92<00P0S9B@0100Q8b80828Q02PX:00W9bL202PX:080
9bPZ00L0;c<f02``<`0X;2l0:Rlc02/`=00W;300:S4h0080;SDm06D0:S<j02`e?00`>D00;3Lm02dj
@00X=C/0<3e303I3B@0_?480<T5603A3B00_?T<0@e9I05ESK01JJ740CUaW04ABH00lBET0?T]K04AA
HP12CE/0>D=>03Q5C`0mBEL0<cm@03]8FP1GI7L0Gfan04aKKP10Cf40AUIU03m?G`0nCUd0<41?041@
G@11DU`0@U=J03=2B@10Ce<0?Te@041=D`0oC5<0?daD04A>F013CUL0?T]C03m<E012CeH0@DiD03m<
DP0mBdl0?D]>03a:C@11Ce40?de>03i<C@15De@0>DM8045?D00oCDh0@4i?04ABE@10CE<0@DiD04IC
F@19EUd0AeAK049?E`16E5h0CeeX04ECGP1AGfX0FFMb05ITK`1CHF`0CE]V05ARK@17EF00@4iI051N
J015E5`0GVed04MFG@1@Gf@0BUUN059QIP1?GV40DF1S05=SH`1@H600CUiN04iMGP1CGel0GVYZ04iJ
FP1AGEd0DemO04mKF`1@G5`0DEeM04]GE`0204QDE00^04IBD`12D580A59E04QEFP1:Ee`0C5YN04eJ
H@1:Eeh0BeQP04aIHP1=FV80BeQQ04QEGP1>GF@0D5mV0760Q`1RLGH0A5=H04QGF`14DeH0@e=D04AD
E013De<0?dm?041>C`0mAdT0@TY=04=;CP12BTd0@d]>04A<C`0j@TD0>D5403Lo@P0i@D@0=cm203@l
?P0g?CX0<SPd02le<@0b>3@0<CLe02dc<@0[<C40;cDe030f=P80<3Dh01h0;cLi03I0@P0/=cT0;3Li
03<l@@0d?D80=Ci303LnAP19CEH0>Ce6038f@@0W:cH0;2hj030`>P0d=3l09RDb02l^?00h>TP0?3i=
034d@P0^<Cl0;S8n02dc?00[<3P0:Rda02<T9P0P8B<09BHX02<T9P0U9RP202TZ;00U02//;P0/;Bl0
:2T[02@U9`0V9bX09RL[01dN8P0Y:Rh09bP/024R9P0[;30092DY02<T:00W:2`0:2T]02HW:`0R8bL0
9BH[02l`=@1;C540ADI;02//<@0Q8RL08b@Y030a=P1KG640=CHk020Q9P0Q82H07ahT024P9P0R8BL0
81lU01hM8`0L6b405aHL020O9@0201PG7@0901hM8P0Q72807QTM01`G6`0J5AT06A@H020K7`0L5a/0
6A@H00807QTM02006A@H01hI7@0M6AX07a/L01dI6P0K5aP071PI01XF5`0H51D05a<D01XF5`0K5aP0
61@E01PD500M5aL06Q@C014;2`0G4A40618C01dG6@0J51H08A/N03Tc=`0<1PX071HK06=MH@2VX:@0
>38d01@>400L5QP06aDG01LA4`@05Q0B0P0G4A<01P0N61X06Q@F01`F600K5AL05a4C01XD5P806A<E
03L05Q0B01@>400F41806A<E01PA600G4AD05Q0D018<400I4aD06aDG01H@4P0G4A405@l?01/E5@0H
4a005Q4>01T@4@0D2`/08a/I01XE4@0E40`07aXF01/G500H5aD05aHE04I4A`1ZJ6d0928V018@4P0J
61T05Q@E01XH6@0G5AP08AlR01PF6@0J61d07adR020N8`0N6b8081lU01hO8`0O82@07AlS01`P8`0O
8RL08RH/02@Y;`0U:S009bdd038i@@0f?DD0=Ce6034j@`0c?4D0>dA=0080<CY30340?4E>04A=EP0[
=3d0=Sm802L`>@0X<CX0;38k02HY<00Y;3<08R<Z01dN8`0Q82H07A`P01hL7P0M6AX071LG01TC4`0I
4@l05a0?01TC4`0J51@050d=0107200G3Pl06@l@01H<3@0B20T05PX<01P<3P0E2@/081@F0186200D
20X05@T;0186200C1`T06Ph@01T=3`0J3Q00;b<U02TM7`0E2@/03`<501L;3@0C20X05`/=01451`0H
30h05PX<00804PH800/05@T;01@82P0A1PP03P@704Hm@00S6ad04`P<00h31`0C2@X04`L901@72003
01D71`0=01D71P0@10@050P801451@0@10@050P801T=3@0V6QX06`l?01861P0C1`L050P801451@08
01D71`8050H602P04`D501<5100C1@D06@/801h@3@0E1`H06@`;03X/:`0U5aL050H701H72P0E1PT0
5`P;01021@0F1@h05`H=01L72P0G1`L050L201@60P0A1P@05@T901@8300B1`l03P8>01dA800O4280
3@0@00h13`0D1a404@@;01041`0E2`/050T901P<300E2PX0308201H:300C1`T050P:0P0C1`T00`0E
2@/05`/=01@82P0301<72@050186200C1P`05@PA01H94P0E21400P0B1@d00`0B1@`050L>01042002
01<72`0300l31@0D20X04PH800@04PH800<04`L901@82P0C1`T00P0B1PP0100C1`T04`H801<41`0C
10L601@520805PL:00@05`P;01L9300E2@/04`L90P0A1@L03`0C1`T05@/<00`20`0G2`d04PP90106
1`0G2`d05@H901H72P0C10L06P/>01L82`0D1@P05PL:01D62@0401@5200300h00P0I2Pd04`@700<0
5@H91P0D1@P01`0C1`/040@801D93@0D20`05PX>02lS9`0S5a/00P0C1`/0100E2@d04@D901D93@0B
1PX201452@0601862P0A1@T050P<0104200A1@T04`L;0`0D20`Dooooo`006oooool05P0W6ad07Q8D
01@82P0P51H0710B01D92`0C1`T05PX<02DI6`0@10H04`L900d10`0900405@T<00P0000O51004@H3
01T?1P0A1P004@H101H;1`0F2PX201<72`0<01H;4@0@1@/040D;01L<400D2@d03083020F5`070000
3P@301@:2@0<0P401`001P0C1`L201D92@0<01@8200S5aL08ADE01861P0F2PX040@401451@0F2PX0
5@T901861P0A1PH020000P0F2PX0200<00003P@400d10@0800006`l?01dA4@11=CD07A4A0P0C1`L0
400B1PH04`L701<71`12=cP0Jf5R02TO800@1PL02P0101lE5P0?1@H06Q0A01D;300J41402P0101@:
2`0A1PL301<72@0Z01hB500>0P@06`lA01451`0L4180<2@V01lC5@0G2`d05P/>01D:3P0D2P/050X9
01D;2P0H3P`060h=01L=300F2`h050T?01D:4P0F2Q@08aHP01T<5P0C1Q0040@>00`02P0E2A<060hG
00l53P0=10`07QLO01TB6P0B2a<05P/C01D:4P0I3QH05``D01@94@0M4QX05``D01H;4`0G31@0714I
0P0N4a/201/?6@0=01`A6@0K4QL06Q4E01T@4`0G4AD061<H01PC6@0G4A/06A<O01XD800L4QX071<H
01dD6@0201`F6P0J01XD6017@TH08AdS01PE700Q7RD07AXR01HC6P0G5AX0<c4d02DS9P0I5aX07adP
01PF6@0J61/06aTN01`I800Q7RD08b0X01TH800U92X09bP/0411A@1dMGT0;2d`01TJ700P8B<2020R
8@0802@V9@0W:BP0:B/Z02HV9P0V9bT09bPZ02PY:`0X:Bd202HZ;@0902L/<00V:bl0:Rlc02X_<`0U
:Rh0:C0h02Xa>@0[<SX0:c@k0080;3Dl00<0;CPn02`i?`0^>d400P0d@DL0;P0`?D<0=TE<03]:D@0e
A4/0AeEN05]YLP0_?DH0>4IA04MEHP0kB5L0AE9R04UFIP11C5X0@deI045=F`0nBU/0AU5U04MDI`1=
FFl0EF5g04MFJ`15E6L0@U9R03e=G@14E6<0?dmN061`O@0iBU@0?TmF03]:D@10Ce<0>dY=03a9C`0l
BE00?4UA045;E@0oBU<0?DYB049?E`12CeH0@DiD04AAE`15DUL0?4Y=03]9C012D582041>C`0>03Q6
A`12D540CeeN04eKG00lBT/0@DmB04QFF@19EeX0BUQK04IDE`10CU40>DI<038oB00jAe0304eJH`0I
04aIHP1;F640BEIO04QEGP13D5T0@4eF04MDG@1ULWX0R9FK05QUJ`1FHfT0AeAJ04eKGP19EeX0BUQI
04iLG@1>G5`0D5iN05ESH`1>FE/0E5mQ04mJG01AG5h0B5=E04YEE`0205UTIP0_04]FF014Ce40AU5C
04E@E014DEL0AeAL04YGG`1;F600BeQQ04YGH01<FF80BUMP04UEH@1;Ef<0BEEQ04AAFP13D5P0AE9H
05MTJP1AGV@0BEMK04QFF@11Ce80?Ta=049@D@12D500?Ta<04A@D00nB4X0@TY=0459C00oAdX0?TI9
03m7BP0mADP0=Si103Dm@00f?T40=3`o03<k?@0k@Ch0<CLc03Hl>00a=cD09R`/02D[:`0/<S800P0`
=CP0100/<C@0:Rlb02P`<P0[=CL203Q2A00H03Q1AP0/<cT0<CPn03m3C01JGVL0=c]4030b?P0c=D40
=cU503<c@00`;cd07A`/03hmCP1<Bed0@D5C03XlB`0_<D00:2Xg02LY=@0U:3409RP^028R900Q8B<0
:RX/0P0W9bT08@0^;S00;Bd_02`/;P0[:bd0:BT[02PX:P0Y:B`0:2L/02d/<@0U92T071/P024P9@0T
8bP09B@Y02@S:00Z:Bh0;Rdb02/Z;`0R8RL08B8W02DV:`0_<3D092DZ01dN8`0X:Bh07AhS02DV:`0b
<cP07QlT02TZ;`0Q82H09R<Z02@Q:00201/H7`0@02DR:@0O72<0<Bhe05YGGP0^:c806AHM010=4`0O
6R009R4U01/F6P0R7B406A@H01`G6`0N6Ad06aHJ01PC5`805a8F01l091lS01dH700P6al071LK01PC
5`0L5a/06aHJ01TD600G4QH06aHJ01hI7@0H4aL06ADF014;2`0N61L07ALG02PR8P0L5QL071HH01dG
6@0D3Q406aDI01TC5`0O6Ah0Qh650=WCe`1<ATP03@L9010:300F41806aDG00805@lA0P0F418201LA
4`0601PB500E3a405a4C01H@4P0B30h050h@0P0G4A<04`0D3Q004`d?01H@4P0K5AL081TP01/E6@0N
61`09R0T03dg>@0G4A<0618D01<=3@0D3Ph04`d=01<>2`0B3@X06Q8@01`D4P0B2PP00P0B3@X0500;
1P<05A4@00d;300G5AH0518C01PF6@0J61/071XK02d[;00N71d061HG01DC5P0K6A`05Q@G01PF6`0M
6b007Q`Q01`I800M72808B<W0P0P92L04@0R9RT09BX^02L/<@0X;C<09bhd02/b>@0e?4@0=Sm603Dn
AP0e?dP0=d5:03Y4C@0kADh0>TA=03M1BP0a>d@0<ce60080<Sa501<082Xc02H^=`0X;3D0:Rhg02<W
;@0Q92T092DZ01`M800M7Al06aTJ01/H600J5QD0618B01TC4`0F410040X:01D>3P0J4A804PT:00<0
5@/<0P0F2P`00`0D20X06@d?01451`0201D92`0L01L;3@0N4Q@040@601451`0@10H07A4C01P<3P0>
0P@04`L901D92`0F2P`03`<5020D5P0D20X05PX<01L;3@0E2@/040@600l31@0@1@H08QLK0<2g^P0i
<3<03@8601hC5`0E30d04`L901@720<05@L700d05@L601@8200D20P050P801861P0@10@04PH60145
1@0@10@04@D501<71`0H30`06Ph>00H05@L70P0D1PH301<51@0[01840`0@0P407a4>01H81@0A0`80
6@/:01P:2@0D1PH03`8301P9300C10L06@X=01L83@0G1A005`H>01L6300G1`H050L001<6000A1`40
5PX:01862P0B1Q803@0D01P:8@0_83H060TL01<55P0C1Q8040<:01041P0Z7Ql040D301<81P0g;2X0
91TG01D92@0D20X05@T;01<72@0A1@L04`L901@82P0201<72@804PH800D04@D701452P0B1@`050L>
0185300201032P0701<72`0>0PH04@D901P<400B1PX040@801041`070186200601451`0@10H040@6
01041P0B1@L050D8100C10L501@5200C01D62@0C1PP040@600l31@0@10H04PH801H:30080000<BDW
06iRI00D20X05PX<01451`0@0@@06@X=0102100I2Pd05`P;01@5200301831P090101100A0PD050D8
01831P12<cH07@hA01L82`0A0PD04`@700H050D800T040@801862P0C1`/040@800`1100;00<040@8
00h21P0?0`L00P0@10P00`0B1PX05@T=01<72`0201T=4@804`L;00H060`@01<72`0F2Ph03P8600`2
100U6AdDooooo`006oooool0900F2P`05`/=01D92`0J3Q004@D701<72@0J3Q005@T;01`@4P0F2P`0
;B4S0186200G2`l040H701T=3@0>0`405@X601<80P0F2`L05``801<81P0A1@H06`lA01<72`0@1@/0
5``B01H;3`0C20`04PP90147200D2P/03P@301061@0C2@P05`d<01@:2@H04`L700T050P80104100?
0`<07a<C01/?3`0900006`l?01@8200E2@T00P0J3Ph03@0G2`/05PX:0104100J3Ph04@D501D92@0D
20P07A4A01D92@0L4100200002LK6`0>10@00P0C1`L0;@0B1PH04`L701<71`0C20T0:R0Q00`20`0I
3a005@/<028H6@0A1`P05P`=00T0000D2P/03@<401hD5@0D2@X05`/=01H:300E2@/07Q8D00d10`0G
2`d04`L900`00P0F2P`06@d?01041P0F2Pd050T=01@9300D2P/05@/:01P>300I3`h060h?01H;3`0D
2A405@XB01L;5@0B1@l06`hH01`?6@0I3AL07a<M01X>600201P>5`0@020F7`15?TH0>C8j01PA6@0G
31@05P/C01/@600J3aL05P/C020E7@0J3aL0714I01<8400H3AD06a0H028G7`80710J01807A8J01XA
5P0G3Q804`X=01PB5P0O6Ql081/Q01/E7`0J52007aTU01T?5`0I41D071<H01`F6P0M5a/071DL02@O
9@0H51X201/H7`0F01DB6P0M6R405aDJ0490@`0]:bh05Q@G01hL7`0K6Ah07Q`Q01hK8@0G51/07Q/R
02/X<00S8RX08B0V028S9`0S92P0C4eA01DF6@0W:2X08R<U02@V9@809BLV00H08B<R020R8@0U9BD0
9RLY02LX:P0Y:R`202L[;P0902DY;00X;C40:Bhb02ld>00`=CT0:c0f02`c>`0[<SX0;3<k0080;SLn
08H0;CHm02`g?@0X=C/0<d1603E2B00_?480<d160350A`0eA4/0@E1G03E3C01?GFH0?4YC03m=F01K
JGH0AeAS03e:FP0jAeL0=3m=03m8E`11CEd0@diP06UdR01ZMX`0CEU`04=?I`0mC6<0AUEZ045@H`0n
CF00AEEU04iNK@1mSIX0>daF041AF011D5L0?diB03i=D010CE<0?daC03m<E014CUP0AE5J04AAF@13
D5P0?DYA041=D`1>Ff40DEiS03m=D00lBTd0@e5C049@D@15De@0@U1A03U7B011Ce00AE=D04IDE@0n
C4l0?de@04ABE@17EEP0@DmB03i<C`0oCE00AE9J03Y7D016De`0@TmH04]HH@1EHV/0>TM@04mLI@0k
B540AU=L04YGH01;F640?4U?06IcN@0kB4h0AE9H03i<C`1=Feh0A59C04IDE@1:F5T0CE]K059PH01I
IfL0CEQJ055LGP1@Fed0DeiP04IAD`19E5H0@Da>04UDEP14Ce40@4]=049=C`0oBTh0>TM?03i;E013
D5T0AeAM04aIHP1>Ff@0BeQQ04IBG@13Ce/0AE5M04IBGP13D5T0BeQP04ICF@0oC580?4U?04UGFP0k
BD`0A59C03e;C00oCDh0?de=03a:BP14D500>D=503i6B@0oAdX0?TI903m7BP10B4/0>d=6030h>`<0
;SHi02D0;cLi03Y0?@0[<Bd0<cTe03<i=`0a=cL0>Clo030f=P0c>3/0<CHi02/`<`0V:bh092`^02Pa
=012C4h0BE=E03HoA00b>Cl0>T5703Hj@`16BU<08RH_030b?P0j?4P0=3I203@c@@0_;Sh06aXZ04M6
F01BD6D0ADAH04A5E`0f>4L0;2hj02T/=@0X:380:BT_008092@V00H0<30b02/[;@0[:bd0<30b02/[
;@0W9bT202<S9@0C02DU9`0X9b/07A`Q02DT:@0];340=C@i03<b=`0O7R<081lT01lN8`0V9BX0:bX_
02TX;@0V9R/09RL/02X[<01:Be00A4E:02X[<00202<T:@0i03Pi?P0];S<07b0U024R9`0S82L07Q/R
01XG7P0P7B@08QlV01LD6`0K61l05A8I02PU;00@3A@071TP02DR:00H4aL0:RDY01HA5@0R7B407QTM
020K7`0G4QH071LK01dH700O6Qh08A`P01PC5`0L5a/07aXN01TD600F4AD071LK01dH700J5AT05a8F
01`G6`0O6Qh061<G01XF5`0R71`0:R@S01XD500N61P040X;01TC5@0B30h08A/N00D00`0N61`0614G
02@N8P0k=CT05Q0B01hH6P0R71h06aDG00<05@lA0P0F418201LA4`0501XD5P0F4180618D01LA4`0C
3@l00`0E3a40900B30h04@/=01D?4@0K5AL05a0G018<400=1`/0CDM;07QbM00D3Q005@lA010:2P0E
3`l04`d=01D@3@0D3``04`/901hF500C2`T06aHC020K600G4Pl05Q8A02<Q8P0:20T05Q@E028P8`0A
3a806QPI034_<00N71d05Q@E01DC5P0I5aX061HI01LE6P806aTN00<06QLN01`K8@0Q92L00P0Q9BP0
?`0S9bX09b``02L/<@0U;3809bhd02Xa>00a>400<3U0034k@`0f@4T0=Cm803U3C012C5D0?TQA03a6
C`0g@DX0?TQA02hh@@0i@d`0:38k02dg@00T:c<092Pa024U;@0W:S409RT^01`L8@0K6ad06ALJ01/H
6@0K5aH061@C014;2`0D3Ph07ALG01PA4@0A20T06Q4B01<92P0D2P/05P`=01H:300E2@/04`L901L;
3@0E2@/06@d?00l31@0=0@<05PX<01D92`0G2`d04`L901P<3P0D20X05`/=01D92`0@10H04@D700P0
000U6A/03`<501041P0201<72@0;01041P0C1`T06a0A03DZ;P3Sf]d0@STl00h31`07000050X;01<7
2@0D1`P00`0E1`L01@0E1`H050P801@8200F2PX05`/;00805PX:00@04`L701H:2P0F2PX050P80P0B
1PH601D71`8050H60P0C1@D04P0B10@04P@301h@3`0A0`804@<001840`0A0`805`T801H8200D1PL0
6P/>0101100E1PT05@H;01L54@0G1Q005`H<01L71P804`H001803`@001H:300=00L05PTH01436P0>
01T05`PN0183600E1aP05@PD01442`0A1@L0<2@U02TN700G30X06a4@01050`0A1P@201D92`0301<7
2@0A1@L04PH800<04`L90P0B1PP01@0A1@L04@D801862P0C1Pd04PH;00803`<700L04`L;00/00`0D
20`07A4E01D93@0D20`03`<600D04PH800L05`/=01/?4@0H30h05@T;0186200A1@L04PD7008050D8
01404`@701831P0B0`H050D801D62@0D1@P04`@701831P0A0PD04PD70186200?0`D03P8401041P0C
1`T0<2@V00l31@0201H:300800X0000G2`d03@0101`=400A0`D05PL:01421@0@0`D201831P0:01<4
1`0B0`H050D801P9300G20/0FDY=02HG6P0H2@`03@0101841PH050D800T04@D90104200>0PH04`L;
01T=4@0?0`L0300401<72`0E2@d00P0D20`03@0@10P04PH:01862P0L41@07A4E01862P0>0PH04@D9
00l31`0J3Q804@D901H;3P17>cl05?ooool001_ooooo00P06@d?01051P0G2`d0>Bd_01L;3@0D20X0
40@6018620805@T;00`04PH801041P0S5aT08QHH01451P0F2PT05P/901@91P0F2`T050T801<81`0J
3Pl201hB50804PH:00X04`L;01<72@0B1PP04PH801451@0D20P07a<C01X?3@0A1P@05P/90P0B1PH0
100K3`l04PH601/?3`0c9bL601861P0701H:2P0D20P04@D501<71`0E2@T04`L701P<300201T=3@0?
01L;2`0C1`L04`L701H:2P0?1@D05@T901@8200<0@4050P801L;2`0C1`L0;b<S04/o?`0L41005@X;
00805@T;00H050P:01<72@0C1`T04PH801<72@0D20X401L;3@805PX<01D060`>01T=3`0J3Q0060`>
034U9`0T61X04@D701P<3P0>0P@05P/>01D:3`0D2@`04`T:01@:2P0F30/04`T:01061`0G310060dE
04<g@00h;3P00P0I31H0=`0H2aD05PXD01H:500E2A<03`D>01T?600K4AX0ViBL04Q1B@0=1Ph04@H>
01/@600I3QH06PlG01P=5@0G31@081DM01053@0J3aL0;B8Z044f?P0H3AD06`lI01P<5P0H3AD07A@I
01lF6P0H3a8071HJ01PC600`:c40;BLa01D?6`0O6B@07Q@L01dD600K4QL06Q<J01`E700M5Qh07QTP
01DA6P0G51d061DN01XG800F4aX071XM01TG6@0J61/06aTN01XH7P0L6B008QlV020M9@0Q7RL00P0T
8BX0C`0Q82P07ahT01lP9@0N7b<07AhR020Q900S92H09BHX024S8P0S9B@0:B/Z02HX9`0R92<08R<U
02TZ;00X:B/092P[02P/;`0/<3<09BX^03<h?00/<CD0:c8h02L^=00g?T@0:C0h02/b>P0e?4@0:S<j
02`e?00a>T40<Se303E2B00f@dT0=45703=0AP0d@DP0=DA<03E3C00d@T/0>TQA03i<E`0kBE@0?D]F
04ABG@0nC5P0=TAA03Q6D`0oBUP0>T=B04=?G`1=FF/0IG2405EQM`1?Fg@0AE5Z03m>I@12DFH0AEAW
04YIK01>GVd0CEe/04QHI@0oD5X0?e1G049AF011D5@0>dY=03i;D@11CUD0AE9J08^EW`1CGfP0@DiF
03m<E010CE@0@e1F049?E@10CE800P10CU401P10CU00?de>03i<C@10CU40@U1C04ABE@80A59C00P0
@e5B04ABD`11Ce00?Ta=03m=CP11Cdl0@U1B04A?EP80Ae5J02/0BUAM04iHH@14CUL0ADmH03m9DP0m
Ae00?dUB03i8D@13CEH0BUEK049=D`11C500BUEI04aGF`1<EeX0CeYL04MBE01NJVX0CEUI055MG@1Q
KFd0B5IH04iLG`1<FUd0AE=F041>D@11Ce80AeEH04IDE`14DUD0@e5D041>D@0lBDl0AE9K045=F@13
Ce/0@TiJ04EAG@1BGVX0A51L041<F00oBeH0@TmH0080AU=L00D0Ae9I04IAEP18DeL0AE1D04UDE`02
03m:C00;03i9BP15DE40>TI604UEE@12CTh0?TM903i6B@0mADP0?4A703U1A00h@4<00P0e?D001`0m
ADP0=3`o03Hn@@0^=SP0<CLf03@j>00f?3X00P0e>c/0200f?3`0=CXm03<h>`0g?3l0<SLk02`a=@0_
=CT0:C8d0P0c>ch07@0/<cT0:c0f02db>00e>D80=CQ103Hi@P0f>4@0;S0l02T[=`0X9cL0;B`n038a
@`0k>Dh0Geeb04a;GP19B5T0=CA303/iAP0T92d0<C0i030_=00Y:B/08R8T034a<`0^;S008B4S02d]
;`0Y:B/09bLY00809RHX0180:2PZ02`[;`0M7240<C0e02XY;P0l>d0071/P02TX;@0T8bP0:2L/01hM
8P0_;S<0:BP]028R9`0Q8RL0824V028S:00T9BX202<T:@050452A`0Z:c00824V01/L8@0P8BH00P0P
7R<01@0Q7b@081hS01lM8P0M6b007Q`Q00807A/P00<07Q`Q01lM8P0P7R<00P0M61`201hI7@807aXN
00L071LK01hI7@0I51P06aHJ024L800O6Qh06QDI008071LK01h06QDI01dH700P6al06QDI02<N8P0K
5aX08A`P01`G6`0Y9BH07AHF01hE5@0L4a@06a8C01T@4P0H3a807A@G01/B5P0J4AH06a8G01T@5P0E
31406A<G01LA4`0E3a40618D03@^<00F418050h@01LA4`0H4Q@201TC5@0603D_<@0O6A/05@lA01`G
600H4Q@05@lA0P0D3Q00300a:bd050h@01TC5@0D3Q0071HH01dF7@0E3a<05a4E01hH700J51H050h@
01D?4@<05a4A03h05Q4>01D@3@0J4Pl05Ph;01lG500E40d04@/;01D?3`0C3a005Q@E00l=3P0B4140
6aTJ01LE5P0H5QL03P`=01/I6P0J61T061HI01dK7P0H5QT06aTN01XH7@0N72408AhU01dL8P0M82<0
8RHY024U:00O92L08bP/02H]<P0/<cT0:S8h02Xc>@0kA4/0>T=:03<mA@0gADh0>4E>03Y7D013D5T0
@4eF03M4C@0nC5D0<d1903e:D`0`?DH0=dA=02dh@@0]=Sl0:S8i02L^=@0T:S008RH[01lR9`0J6ah0
7alQ01/J6`0E4a@07A`J01PD4`80618B00T05`l@01D<3@0D2``04`T:01X@4@0I3a0050P:01H:300E
2@/00P0B1PP201D92`0301@82P0E2@/05@T;008050P:0`0C1`T0500F2P`06`lA01X>400E2@/05PX<
01<72@0@10H050P:01<72@0A1@L05@T;01<82P0I3Q80;B@W01H>400A1PX05``@01882@0B1PP050L8
0P0E1`L0100F20P05`T801dA4@0E2@T201<71`804PH601<050P801H:2P0F2PX05@T901@8200A1@D0
5PP80184100E1`L07@l?01L92@0E20P05`T901H8200E1`L050H601<51@0B10<050H500805@L402T0
5@L601@61@0C1@@05`T901D7200P4A@0B3/m024C5@0C1@T05`H@01X94P0J2@l05PL701@6100D1P<0
50T801@73P0C1Q404`HH01<57@0D1Ql0=BHl03<T>00G2AX04PHA01H:400=0`@04`L801<81P0D2@L0
4`P601@91`0E2@P05`/=01D92`0G2`d06Ph@01L;3@0B1PP04`L901@82P0201<72@0B01451`0N4Q@0
8ADG01D9300A1@P05@T<01@8300A1@T060h@01L;3`0A1PT05@T=00l31`0?0`H04`L901@82P0A1@L0
5`/=0P0J3Q001P0V6Q`06@d?00l41@0C1`T03@4301D82P805@H900@050D801<41`0C10L04`@70P0G
20/01@0C10L05PL:01D62@0B1@L04PH800805@X;00l04@L801L;3@10=3H07A4C00d3100J3Q004PH8
01461`0C10L050D801D72@0D1PP060T<01<41`0F1`X00P0D1@P201D62@0701831P0A0PD05@H901D6
2@0A0PD04`@701@5200601<41`804@D90P0D20`01P0B1PX04@D901L;3`0A1@T060`@00d31@8050P<
1P0A1@T01P0C1`/050P<01X>4P0G2`l04@D901H:3QCooooo000Kooooo`0600l31@0A1`P06@d?00/0
0@0B1`P07A4C0P0B1PP201<72@804PH800d03@4301<72@0?0`D05PX<01861P0>0P8040@401@8200H
30h050P:00d10`0;004050D:00<050D80P0D1PH02@0G2@T04`D401P:2@0F20L04`D201T;2P0A1@D0
50P801L;2`0201861P0301L;2`0B1PH04PH600@04PH600T06@d=02HJ6P0I3@d04@D501H:2P0D20P0
7a<C01T=3@0E2@T00P0B1PH03P0C1`L05`/;02DI6@0P51@03`<301@8200E2@T060`<01T=3@0F2PX0
91PH01<71`0M41005PP80P0G2@T201P:2P0701L92@0F20P05PP801L92@0H2PX06@/;01T<3@0201H:
300<01D92`0F2P`05`/=01<72@0P51H06@d?01@82P0E2@/03P8401L;3`0D2@l05@X>0P0E2``02P0D
2P/05`d>01D;300J3a@02P0701X>600F2aH05PTC01H94P0G2Q<201H;4`0l01L<500I3aL040H>02LM
9@0?20l050dD01TB6@0C21006a0H01X?5`0M4QX05P/C01<8400=0PX03`@<01`A6@0J3aL09AXR01L<
501JCUP0?C4k01T>5P0B2@h060lC020G6P0O6Ad05Q0E01D@5P0D3QP05Q0L02@N:00N51`07QDI01dD
6@0L5A`07QHP01hF8@0F41X08alZ00h;5P0=2Q<07AXR02d[<00O7B009R@V01dK7P0I5a`07Q/S01/H
8@0L6B808QlZ02DR;@0N6b@07Q/S02`[<@0P7bD0824V020Q9@0N7b<0824T0P0S92H01P0Q8b808bDT
02LY:00U9bH08R@S02DY:`80:2`_01`09BT/02DZ;P0X;C40:2da01lV;00M92X08RT_02D^=@0h@DP0
<3Lo0458D01<De/0>T=:03M0A`0i@TT0;cY0034nA00c@4H0=D9803Q5B`0jAdl0=D==03A2C@0e@dh0
?deH041>F@0iAe80?D]F0P10CUT0900mBeH0?TaG04EAG00lAE@0BeMW05aWN@1?FVh0?DUO04]GKP17
Df/0>dYQ04]JL01=G6l0AUEX059RL@1>GVd0Be]X04=DGP11DUT0@E1G041?D`0fADP0=45703e:D@1N
Jg<0^lG?055LI@0lBE40=dA<03a9D011CU@0@4eC045?D`13DE@0@DmB041>D080?Ta=0`12D5<04P11
Ce00@4i?03m=CP0mBd/0@Dm?04=AD@0oCDd0@4m<04QFEP16DEL0A4iG04I@F@15CeP0?dUB03a6C`0g
@DX0=3i703I0B@80>dE>00h0@TaE03Y5B`0lAd/0AE1D04IAD`12CDl0Ae9D04IBDP13Cdl0F6AT04mK
F@14D4h0A51?04MEF080BeYO00<0AUEJ049AEP12DEH00P16EEX02P13DUL0@U5F041?E00oCUD0@dmK
045=F`14D5h0A51L045=F@14D5`204MDG@0A04EBFP14DET0AU=K04UFGP17DUP0BUEI04aGF`15D580
>TE703@o@@0oBd/0B5AD03Y6AP1EHEl0Z;Bb049>CP0k@dH00P10B4/02P0i@D@0=Ce003Dm@00g?d80
>d=602Ta=00a>C`0<SXm03Dm?`0^=3<2038h>00B034g=`0b=cX0<cPk03<h>`0`=CT0<CHj02db=P0Y
;S@0:c0f02de>00g?d80=3`o02/`=P0_=3X0=ca203Hi@P0b=Ch0;C0i0P0Z:SH04`0[:cL092He03m1
D010@U40<C1203lnD00c<D<0=35202h/>P0i=T40:2D/02XX;@0S8BD0C4Y=02LU:00Q7b80:BLZ02XX
:`0X9RT00P0S8B@04P0T8RD09bDX02XX:`0R82@0>SPm03Le>P0d<SL0:bT^01/I7P0^;340928W01/I
7P0U8bP0518G03<a=P0R8RL08R<X024R9`808b@Y01<08R<X024R9`0o@4D0:2T^01XK800R8bP0:b/a
028P9@0T7b<09B0T028M8@0N6Ad06QDI01/F6P0O6Qh091lS028M8@0Q720091lS00807APL0`0N6Ad0
5@0O6Qh07QTM01hI7@0K5QX06QDI01dH700K5QX08ahT01LB600D3aD071LM01PC6@0E41H040/A014<
4P0F4AL04`hD01TD6P0E41@071<D01/B4P0201T@4@0;01`C5@0M51L06A0C01XA5@0M51T07aHK01/B
600F3A80618F01PB500M5aT00P0A2`d06`0?2@/0618D01LA4`0C3@l05Q0B01TC5@0d;S008A/M01<=
3`0400005@lA00h82P0M5aT0<B/]08b6R00M5aT09R0R018<3P0?2@/07AHM01H@500E3a<05a4E01LA
4`0F41806A<E01D?3`0201<=3@0>01@?300E40d0614<01dE4P0C2`P06A<B01PB500:10H06aHJ00X8
2@0<2P/06ALH00`;2@0H5aD201HD5@0;01@B4`0I5aP07A/N01XH6`0H5QT06aTN01TG700N72408AhU
01hM8`0O8bH00`0S:2/0500T;2l0:30d02Pa=P0Z<cP0;cTn03<nA00e@4H0>4A=03Q9D`0iAe80>TUD
03m@FP10CUT0>TYD03]<EP11CeX0EVE`03I7D@0c@D`0<3a50P0`>T<07@0W<3L07RD[01dT:P0P92T0
4aLJ034b=00P8B807QhN018B4P0G51@0618B01LA4@0E3Ph050/<01<:2`0E2``04`T:01061`0D20X0
6Ph@01H:300E2@/06@d?01H:300G2`d07A4C01L;3@0D20X05@T;00805PX<00<05@T;01<72@0D20X0
0P0H30h04@0C1`T050P:0186200D20X04@D70186200C1`T04@D70187200;00@050/>00d41`0A1PX0
4PL;01<92P0D20X05@P900805@L700X05@L601@61@0Z7Qh08ADE00l30`0>0P805`/;01<71`0B1PH0
50P80`0E2@T01`0D20P06P`<00d0000I2`/03@0001H:2P0I2`/01@0D1PH04@0D1PD05PP701H81@0E
1`@050H501840`0@0P4060X:01d?400G20/09AHI01X;3P0?00<06@P>01/:400J2Pd05`L:00805@H;
00@050L?01D7500G2AP05PTK0P0E21`01`13=4P0?2e000l1400F2A@0200202TM7`0B1PL00P0C1`L2
01D92@0C01D92`0G2`d060`>01L;3@0E2@/05PX<01P<3P0D20X04@D701041P0A1@L050P:01D92P0A
1@D03`<301D92@0H30`050P:01041P0200P0000A01@8300800007Q4H0145200B1PP040@601<72@0J
3Q005`/=00h3100C1`T040@600l41@0C1`T03P8401<6200E1PT00`0D1@P01@0C10L05@H901P9300H
2@`05@H900805`P;01D04`D802`P8P0Y7Al03P8401@82P0H30h0200001041P0A1@L03`<501D92`0B
1PP04`@700l00`0A1@H05@H900/0000D1@P05PL:01D62@0D1@P00P0E1PT201<41`0401P9300F1`X0
4P<601@520L04`@700`04@D901862P0C1`/04`L;01862P0A1@T040@801472@0800006PhB01D93@0:
008601862P0601452@0C1`/05`/?01D93@0A1@T050P<5?ooool001_ooooo00P05PX<01L;3@0I3@l0
200001L;3@0N4Q@050P:01<72@804@D701804`L901@82P0B1PP05PX<0186200H30h03`<500/0000D
20X05PX<01@82P0=0@<050P:01lC5@0E1P/05@H901@5200E1PT201D71`0801P:2P0D1PD05PP701@6
1@0B10405`T601451@0E2@T201861P0301451@0=0@404`L700D04`L701P05`/;02LK6`0H30`04@D5
01H:2P0B1PH050P801H:2P0G2`/05PX:01<71`0B1PH06@d=03@X:00/82003`<301L;2`0E2@T06@d=
01dA4@0=0@403`<300P0000I30`701L92@805PP800@05`T901T;2`0I30d05`/=0P0E2@/301@82P1B
01X>400F2P`06@d?01@82P0?0`D05``A01@93`0F2a005P/?01D;300D2P/060h?01H;3`0L4AL040@>
01H:500E2AD05@PA01D83`0G2Q805P/C01L<4P0H3A@040H>01H=4P0G3A@0614H02<M8@0E3QD04PL?
01L<500F2a<07A8J01P=5@0G31@0714I01hC6`0H3AD02P0701@94@0J3aL0;20Z01dA6`0J3aL07aHK
01L>4P0F3A00618F01XE6P0H4aT06A<M01dG8`0M5b40718J01dD600M4a/071DM01dE800N5R<071HR
01DA700L6B@04a0I01lL900B41D07A/N02/Y:`0N724061DL024N9`0L6B@08AhY01dJ9@0N6bH05A8K
03`i@@2GUY`081lU028S9`0Q8RH0824U020Q90808R<U00H0828Q028T8`0U9bH08bDT024S8P0R9RT2
02DY;00M02<W:P0S:2`09R/_02T^<P0^=C/09B`b02he>`0/=C`07bP_02he?@0e?4@0?4=;02lh?`0d
?D@0=Ci5030k@@0a?T@0<Sm503A1A`0hAD/0>dQ@03a:E00jB5<0=dE@03]9E00mBeH0>4IA045?FP0o
CEP00P10CUT09@0oCEP0@dmK03m9E@1AGF/0F6Ae04IAI@0hA5X0A51W04QDK010CfH0F6Mk059RLP0j
BUX0AUIV04MGIP16EV<0@U=M049CFP12DEP0@U5E04YIG014DEL0?DYA04EBFP0lAU00AU5J03]8D00h
ADd0>TM>03Y7C@0lBDl0?4U>03a:C@12D5<0AeEG04ABD`0mBd`00P10CU401`0oCE00?de>03i<C@0m
Bd`0@4i>045?C`11D4h00P0nCDX01@12D4l0AU5G041:D`13CEH0@4YC0080=Cm801<0<3Y302li@P0e
?dP0>TA=03]5CP12CE@0?4M;03i9C@16DED0AU5C049=C`18DeD0CUYJ04IBDP13Cdl0BeME03Q4@P17
De80B5II0080BUUN00h0AeIK049AEP11D5D0B5ML04MFF`13DUL0@4mD03i=DP0mC5<0>DEA03Y6E010
C5P0A51L04QDH080BeQQ01T0CEYR04QEG@12CeL0@4eD04=@EP13CU80?TU=03]6BP0nBD/0?4M904QC
E@10C4`0>TI603U5A@0oBdT0Gf]Y03<m?00h@4<0>T9503a4A`0j@TD0=Si103@l?`0nATT0;SHi0080
=3`o00@0<SXm034i>`0^=3<0<SPh0P0c>CT03`0e>Sd0=c`o038g>P0_=3P0;S<g02/`=00Z;cD0:c0f
02de>00d?3l0<CTl02`a=`0]<SP0<cPn02P[=00202lb>`0402/[=`0Z:SH0;2`h02`^?080BD]J0P0d
<dD03@0]:c/0:BLe02DQ;`0Y9Rl08b4V02DS9P0_;C00Y::U055?DP0W9BP0>cTl02<Q900N71l00P0Q
7b80500S8B@09R@W02PV:@0R82@0<c4f010>4`0Y9b`0:bT^028P9@0[:Bh09R@Y01TG700W9BX071XO
02DS:00R8BL08b@Y028S:00T9BX08b@Y0P0P8BH04@0W:2d07QlT01dN8`0C51T071`Q020N8`0S7R80
91lS028M8@0O6Qh06QDI01TD600N6Ad08ahR01dH700I51P06aHJ00H07QTM00T06aHJ01`G6`0L5a/0
71LK01hI7@0O6Qh0THbB05iIG`0R7B<00P0K5Q`0500M61h081/Q02<N900L5ad06aHL01PC6@0L5QX0
7QDF01dD500K4Q<06Q4B01XA4`0I41<060lB01T@500N5AX08QTN02@J8@0Q61d07aTM0`0I4aD0700H
4Q@04P`>01dG6@0?2@/04@/=02@N800F41801`4301@>400K5AL081XL02`V:00C3@l05a4C00@0000O
6A/02`D700h82P0J51H03`T;018;4P0C3A405@lC01LA5@0L5QP07QPJ014;3@0E3`l201PB4P0V01@?
300B3@T05a0:01hF4`0@20D06A<C01`F600C3@l071LK01TG6P0>30d071XJ00l>300M71X05A<D01PF
5`0F51D061HG01XH6`0I5aX07A/N01lM8P0L6Ql07Q`Q01lL8`0K6R007b@W02<X:`0T:B`09BX]02D]
<00Y<CD09c0e02`e>P0d?T@0<3]103E0AP0lBU8203Y;E@0F03i?F@11DU`0?e1J03Y;E@0hBE<0?TmI
04MHHP0`@D/0:3U302djA00a>d@0;cU202Pa>@0P:C0082L]024W;00[;S<0Rhb@05eNH00T92@05ADE
01@A4@805Q0@01H05Ph?01D<3@0E30d03@<401D;300J414050P:0186200F2P`05@T;01/?4@0H30h0
6`lA02PL7P0O4aD050P:01D92`0H30h05`/=01H:300C1`T040@60P0B1PP04@0?0`D03P8400l31@0E
2@/040@60186200D20X03`<501461`0E2Ph050/>01<:3@0E2Ph040D901061`0E2@/05@P900805@L7
00P050H601<5100G2`/08QHF01L;2`0D20P07A4A01D92@805PX:00/05@T901@8200C1`L04@D501/=
3@0J30`05PP800h0000J3Ph05@L701<51@0401@61P805@L60P0E1`@0700E1`H04`D401840`0J30`0
40@401X;3P0;00003P02024B5@0I2@X06PX;01T9300F1@`050@>01D5400B11805@LH01P:6`0G2Q`0
5@PJ01@76@0A11@06P`M00P02@0E21803`8901<72`0G2``201@8200<01@82@0B1PP040@60186200F
2P`05@T;01<72@0J3Q007a<E01H:300C1`T04PH80P0A1@L01@0B1PL04@D501451@0F2PX05`/;0080
4@D701808ADG0104200H31002000024D6`0B1PX04PH801451`0C1`T05`/=01T=3`0D20X04PH80145
1`0B1PP050P:0186200D1PT801@5200P01<41`0D1@P050D801851`0O4aD06@d?0186200N4Q@04PL8
01041P0J3Q005@T;00T0000>0P@040@601L82`0?00<060T<01l@4`0>008050D801L82`0E1PT04`@7
01@5200E1PT04`@701D62@0I2Pd060T<01831P0D1@P701<41`L04PH:00D03`<701`@500^8RH0?30d
01<72`0601862P0400d11@0>0PH040@800l31`803P865?ooool001_ooooo00P07Q8D01L;3@0@10H0
40D601L;3@0?0`D05@T;01@82P804PH801P050P:01D92`0@10H04@H80186200J3Q0050P:01H:3@0H
31004`L:01T=3`0F2P`03@8300l51P0G20/05@H901@5200E1`L05PP801L92@0E1`H05PP701P:2@0F
20D201<50P8050P800@04@D501<71`0E2@T04PH61P0D20P01P0B1PH060`<01861P0B1PH05@T90104
10804PH601H04`L701@8200E2@T05PX:00/0000A1@D060`<01D92@0H30`04`P800h20P0F2PX04`P8
01P<300?0`<060/;01P:2P0G2@T05PP801@61P0C1@D05PP80P0G2@T01P0F20P05`T901P:2P0H2``0
5`/=01D92`<050P:0P0E2@/0800D20X05`/=0186200A1@L05PX?01D:4@0G31405``@01H;3`0E2``0
5P/?01D:3P0F2a405`/E01X>6@0H31P050L?01D93@0F2Pl05``A01P=4@0I3Q806Q4E01<:3@0E3100
6A<F00`6200F41<05``C01L<500E2Q807Q<K0P0I3QH0:`0B20l06PlG01X?5`0O51`08AHN01/@600N
4Q`06`lI01X?5`0I41D06Q4E020G6P0C3A406A<H01HA5`0H4Q`07ALS01@>600I41H06a8F01`B6P0K
51`071@Q01`D8`0F41h0>CA107EbO@0V8b`05a@L01hL8@0J61/09R@V01dK800I5Qd08QhY01lK:@0K
5bD0920]01hK9P0R7bP0;b`d02DT:P0R8BL00P0T9BT0700R8bL08B8U028S9@0T9BL09BLV02HX9`0W
:BP09RPW02DW9P0R9RT092P[02DY;00V:bl09b``02P]<@0V;C<07bH/02/b>00[=3/0:S<j02Pa>00^
=Cd0;3<k038i@@0`>D00=3e402df?@0c?T@303=0AP0603E2B00hADd0>4IB03U7DP0e@dh0>4IA0P0n
C5L04@13DE`0?deF03i<E@0nC5D0?4YC041<E@1:E5l0EV9^04EAH014Cf40?4UL045=HP18EFT0>dYN
045AHP17EfH0?DeL0080AeMV01H0AUIS049CG@12DeX0@U5H041?D`12DE@0=D9804AAF011CUH0?4I@
049=EP0kB500?DYB041=E00lBDl0@e1F04ECE`0nC4l0@4iA04=AD`11Ce00?de>0P0oCE000`10CU40
@4i?045?D00204=AD@09041>C@0nCDX0@U5=04ACCP11D4`0@D]@03e6C@0oB4l0?4E<0080=3e400T0
>T=:03U2B@0lAD`0>dA;03Q1B010BE00Ae1E0419CP0nB4X00P13CDl06015Ce00A4i?04iHF@1DGUd0
@4Y908fGUP1?FUX0B5EK04MFG@14DeX0@U5H041?EP0oCUD0BeYQ04aKHP17EUd0@4mF03U8C`0hATh0
?4QD045=F@10C5P0@DeH04MDG@80BeQQ01d0C5UP04UGF`15DUL0@U1D04=AE017DEH0AU1C049<CP1:
E5H0BE=D06ihN@1DGUl0?TQ803Do?P14CTd0?DM603U3@P0lA4L0>D5403Lo@P0h@4<0<SXm02hf>@0f
?T40>41304I>D@0b>Sd0>T9502H^<002038h>008034g=`0`=CP0<CHi038g>P0c>3`0;c@h02/`=00/
<CL202ld>P0M02Ta=00]<SH0;S<g02ld>P0[;SD0:2/b02`_>00c<cd0<S8l02l_>`0e=D40>SY603Tk
B00h>TL0<SA102d/?00e<T<0=C9102TV<P0[:340:RH[02hY;00W8b<0:2@U03Hd=`0E4aH0:2HY02@R
9@0/:Rd01@0T8RD03`0U8bH0:RP/01XH7@0/:Rl0IfEZ02<Q9P0U8bP07A/P02LU:P0X9R/06aTN02@R
9`0M6b00@3i402DV:`03028S:008020Q9P0M7R<07b0U024R9`0V9b`09BH[01dM8P0P7R<2028M8@09
020K7`0O6Qh071LK01/F6P0O6Qh08ahR01lJ7P0L5a/07QTM00807aXN100N6Ad0500L5a/06aHJ01dH
700K5QX05a8F01PC5`0R7B<05a8H01XE6`0U82H07APN01PC6@0C3Q@08A`R01hI7`0D3aD06aHL01dG
6`0J4A807A<C0P0N51D0300L4A@06PlC01hC5`0J3a@06PlE01dB600R5ah08QTN01@<4@0M5aT04@/=
01<=3`80618D00X05@lA01TC5@0B30h05@lA018<3P0L5QP07ALI020J702UWj40:28T0P0G4A<02P0R
71h04@/=01LA4`0A2`d050h@01LA4`0B2a80618F01XD600G4AD201@>401E01PB500G4A405Q0@01D?
3`0E40d05A0<01PA2P0I4Pd04PX701D?3`0H4QD06A<G04Y5BP1hMWT0:bTZ01@C4P0J6AH02`X701HD
500C4A8061HG01HD5@0G5AP071XM01dK7P0O7B807A/P024O900T8BP081lU01hR9@0O92L08RP[02<[
;@0U;C009c0d02D^<`0Y=3P0<ci302lj@00d?dD0?D]C03a=E`0oD5X0AEIP04AEG`12Ded0A5EO049C
G@13E5h0=TMA03a=E`0fAe40=D==02hkA00[=Ch0:SDl02Tc>@0U;C<08bT^03i3A`31aLP0PH>501`M
7`0O8B005Q@D01PB4P0I4a<06a<D01`C500M51D0;B<T02HL7@0M4a@05`/=01@82P0E2@/04`L901L;
3@0D20X05@T;01hB500F2P`050P:01D92`0201L;3@0901H:300C1`T050P:01@82P0E2@/050P:0186
200E2@/04PH800@04`L900T04`P901@93@0;0PD04PT<01<8300A1PX04PP901D92`0E20T00P0E1`L0
1`0E1`H050H501451@0S5aL06@d=0104100C1`L01@0D20P0200E2@T05PX:00d0000b92@06@/;0143
0`0G2@T06P`<1@0D1PH01@0E1`H04@<201<50P0E1`@05@L600805PP702H03`8201L92P0@0P@060/=
01d>4@0<00005`P201L81P0F1PP05@@?01D45`0G1Q/04`@L01D67@0G21h05PTJ01@85@0B1Q<07a8O
0963T@0U62<03`<901T=4@0C2@/05@T;0186200C1`X05`/?01H93`0C1P`05`/=01X>400G2`d04`L9
01X>400P51H04PH801@82P805PX<01@04`L901861@0@1@803`@20146100B1`D04@D501041@1nLW@0
BCe101<8300G2Q403P4801862P0C1`T05@T;0186200A1@L06Ph@024E5`8050P:00@04PH800l31@0D
20X050H9100D1@P201D62@0A01<41`0A0PD04`@701831P0C10L050H901451`0B1PP05PX<01L;3@0B
1`T04`L900l41@0B1PP050P:01451`0D20X00P0B0`H01P0b8bH0>2T/024B5@0@0`D060T<01D62@80
4`@70`0D1@P0100I2Pd05`P;01831P0D1@P701<41`0301<72`0B1PX04PH:00804PH:0P0C1`/01@0E
2Pd04PH:030T:00]8RD03@8500H040@800H04PH:01<72`0A1@T04PH:01@8300@10PDooooo`006ooo
ool0200H30h03P@501D92`0I3@l081@F01`@4P0E2@/050P:0P0C1`T05P0D20X05@T;01<71`0B1`L0
4`L901T=4@0=0@D03`<701X>4P0G2`l03P8600`20`0h;2`0HeMG01P9300E1PT050D801D71`0G2@T0
60X:01@61@0F20D201L91P0801H81@0D1P<04PH601D92@0F2PX04`L701861P0E2@T601@820030186
1P0@10@04`L700804PH601<05`/;01H:2P0D20P04`L701@8200E2@T050P801T=3@0H30`04`L700h2
0P0I3@d0:1`L00d10@0E2@T06`l?020D500>0P8040D400805`T800@05PP701D71P0E1`H05@L60P0G
2@P0100H2PT05`T801L9200G2P/201H:30<05@T;05H05PX<0186200C1`T04PH801@82P0H30h05@X?
01H;4`0F2a405@X>01H;3`0G3@h050T=01/@500E2Q406@dG01hB7P0N4Ql05@P?01H:300G2`d05P`=
01L=3P0H3Pl060l@00H0000D2``06A<C01D?3`0B30d05@X@01@94@0H3AD09AXR01`A6@0H3AD08aPP
02@I8@0B1`l07A8J01lD700I3QH03@4;01L;5@0K41P06a8G01lF6P0E30l07ALK01XE6P0F4AL06A<M
01dG8`0J51h060lD01XA5@0M4a/07AHN01dE8P0M5B@0D4UI03Lb@00g=3l03``E01TF7P0]:bh07adN
01lM7`0N72407AXQ01lK9`0O6bT061@S02/W=@0Q7RT081dV02/X<00H5a`08R4W02@U:P0U9RX08b@X
024R9@0Q8R@0824S028T8`808bDT00<08R@S02<U900U:B`00P0U:B`04P0W;30092/a02@[<@0P9bd0
<3U006I_MP1BFf80;3Dl02Xc>P0/<c/0;cHn03<j@P0a>T40=3e402/d>`0b?D<0=45703E2B080=457
00X0=D9:03]9E@0iAe@0>TQE04ECGP13DE`0>TQC03m=F00lBU<0>TQA0P0iAe006@0kAe00@D]E04UE
H@0mBEP0Ce][04YGJ013D680B5EX04UHJ`0oCel0AUIU04EEI010D5h0AUIU04EEHP0oD5X0@55H041?
EP1:FEd0LX6403i;D@0nBe80>DI>03@nB013CeP00P0iATh04P14DEP0@TmE04=@EP15DeL0?de@03e;
CP0lBT`0?4Y;03m=CP0mBdh0?4Y=03]9C00kBDX0?4Y;03i<C010CTh0?di;041?B`80@E1;00L0@4m:
03i7C00nAdh0>dA;03a5C00oB4l0>T=:0080=3e400L0>T=:03a5C00nAdh0C5EL04QAEP0oBD/0>TA6
0080?4I802h0?TQ905=MGP0g@D80A4i=03E0?01PJfL0@4]904=@EP0nC5D0>dUB03a:D`10CUL0@U1I
04]IHP1@GVL0CE]T04ABF`0jB540>4I?03Q4D018E5l0B5EN04=@F@19EUh0CEYR04QEG@17E5X0AUAG
04MEF016E5D0@e5B03m9B`18DU@0>49403U3A@1NJ6T0d]cM075kO00kADD0A4i=04iIE@0^>CD0@D]:
03e5A`0oAdX0>T950P0a>C`0500e?D00<SXm03<k?P0f?T40CEEH03@l?`0h@480<CHh034g=`0`=SH0
;c@g034f>@0c>3/0<3Di02db>00W;380;34g03<h?P0a=S`0;C8f0P0^<cL06`0]<SP0;2lf02`_=P0b
=Ch0=3@n03<c?@0c<Ch0>SQ503dmB@0`<Sh0=CM303LiA@0k>TP0<Blm030]>`0T8BX0<2/b02XU:@0d
;Rh08ahK01hJ6@0L5a/06QDI020K7`0/9b/0;RT]02LR9P0202PS9`0C02TT:00X8bL0:2<W01lJ7`0]
:2h0:2<Y02hY;`0/9bd09R4W02/V;00N6Al091lU02dX;P0O6R00?cY0059@EP0W:2d08R<X01lP9@02
020Q9P0<024R9`0W:2d09BH[01TJ7`0O82D06QXO02DP9P0U7b<08A/O01hH700M5a/071HJ0P0M5a/3
01hH700501lI7@0O6Qh07aXN01lJ7P0N6Ad00P0M61`02P0S7R808A`P02<N8P0P6al061<G01TD600>
2@l05A0G020K8P0O6R4201`G7P0;04a7CP2i];/0=2lf030[<P0R7B@0@ca301hE5P0M4a<06Q0A01T?
400L4A@00P0N4aL05@0J3a@060dC01T>500J3aH06A0E01L>4`0L5QP06A<E020J700C3@l06aDG01@>
400H4Q@050h@01XD5P0A2`d02P@601D?4@0B30h030H8014;3@0201H@4P0U018<3P0L5QP03@L901H@
4P0B30h09b4S018;4P0E3a<0618F01TC5`0G4A<05@lA01lI6`0H4Q8050h>01<=3@0F4@h061<?01XC
2`0H4@/050`902@O7P0W8BD04``C014<4P0G5AP040h?01<A4@0F5A404Q4=03Dc<`0T8R<05A<D01HD
5@0P7R406ALJ01HD5`0201/I7P0W024O900V8bX08b8X01dR9@0L92H08BT[02@/;P0U;c409Rlc02L`
=@0Z=CT0<3]003@oA@0h@dT0?DaD03e?F@0nD5X0AEMQ04AFH017FF<0B5YT03I8DP0oDE/0>TaF03a>
F00V>480;Ce6034nA`0^>d<0:cHo02Lb>00U;S<082T]01XO8`0/<3<08RHX01<G600I6Q`04a4A0080
5@l?00T05Ph?01H=3P0F3@h08aTJ01D;300>10D06@d?01/?4@0J3Q000`0H30h00`0F2P`05@T;01<7
2@0301@82P@04`L901<040@601<72@0C1`T040@601D92`0<00805PX<01<72@0@10H06Ph@01H;3@0J
3a<03`H901@;3P0=0PH04`P<0147200B1PP050L800805@L70P0F20L01P0@10@04`L701451@0?0`<0
50P801`@40<04PH600/04`L701H:2P0H30`050H601L92@0@0P805@L701P:2P0=00005PP801D71`02
01@61P0501<51@0B10<04P@301<50P0D1P<00`0E1`H09`0S5AD03`<3020A500L3A00404402DG5P0E
1`005PL201H61`0F11<06@LO01/8900G1bD05`LR01H77P0D21L04`LA01<8400<00T0:A`V00P0100L
3aD0300400h2100E2@/04PH:01D93@0M41P07A0I01X=5P0E2@`05@T;01<72@0?0`D04@D701@82P0A
1@L04PH801@82P0201H:300>01D:2@0B1`<04PL301@91P0E2PP05@T901861`0B1PP04`L;01862`09
00<04`H=01L;3`0B1PP201@82P0900h2100C1`T0710B00d10`0@10H040D600d10`0F2P`04`H80080
4`@701d050D801D62@0E1PT05`P;01<41`0A0PD05@H901<41`0E1PT050L901041P0B1PP03@4300X0
000?0`D04`L900l31@0B1PP05PX<01451`0=0@<050D801421@0J2`h05`P;00d00@0A10D060T<01H7
2P0201831P8050D800H04@8501H72P0E1PT04@8501<41`0D1@P601<41`804`L;0P0A1@T0200B1PX0
4`L;01P<400G2`l03P8601<72`0>10H03@45200A1@T0100=0@D03`<701@8300>0PHDooooo`006ooo
ool0100N4Q8040@401`@400@10@201D92@H050P801h03P8201051@0E2@/07A4C0145200B1PP04PH:
01862@0I3@l03`@50104100O4a<060T<01D62@0D1@P05@L701L92@0H2PX05@L601H81`0E1`@05`T7
01P:2@0G2@P04@D501D92@0J3Ph04`L700h20P0E2@T701@8200=0186200H30`040@40104100L4100
4@D501L;2`0K40h06a0?01D:200C20L06@d=00l30`0201D92@0900h20P0L41803@4301P<3P0D20X0
4`L901451`0G2P/05PP700<05`T800P060X901L9200G2@P060X901T;2P0G2@P05PP701H92P805PX<
05P05@T;01H:300G2`d05`/=01@82P0F2P`04@D701T=3`0P51H05``A01L<4P0E2Q0050T=01D:3P0H
3Pl060dA02@I7@0H3A@04@D?01@84P0C1a805PT@01H:300G2`h05P/?01L=3P0G3@l05`hA02HM7P0B
2@/040L:014;2`0G3Q405@`A01L=5@0Q5Qh0=2Ta02TO9`0S6B404@H>024G7`0J41P06PlG01@:4P0J
3aL06a0H024F7P0H3AD06@lG02dS:`0Q6al071HJ01PC5`0I51X06aHM01XD7`0F41X05a4E01XD5`0M
5Qd07QLO01hG900M5bD0C4ID03Lb@00O72L07a`U01`J7`0L6Qd0928S01dK7@0O7B8081dT01dJ900N
72T0;BTg01dK:00V9340:2Ha01dL900X9bd08R<X02DV:`0V9b/092DY028S9P0Q8R@08b@V100V9bT0
5`0V9b/09RT]02@W;00T9b`08bP]028W;@0O9R`09Rdc01hU;@0h@DP0;CHm02`e?00]=Sd0<CY103@m
AP0c?4<0;CLo03U2B`0e@4H0<3Y203A1B@0f@dT0=D990080=D9:00H0=D=?03A2C`0oCEP0F6I`05ES
KP16E5l203]9E00T03Q6D@0gAE00>TQE041>F010CEH0Ae=O03m<F@1<FFT0AE9S04UFJ01EHWD0EFEe
03a<G016EVH0CUi]03i>G@10D5d0?dmL03]<E@0oD5P0@E1G03e<D@0iAT`0AeAJ03]8C`1AFf@0AU1I
06A`N00iAT`0<d18045>E00oC580>DI<03Q6B@0iAdX0?4Y=0P10CTl04`0nC4d0@e5D045?DP10C500
?dY>03e;C010C4h0@4a<045?C`13D4h0?DU703M6@`0kAdD0?4M903m8C@0j@dP0?TM<04M@E@0oB4l0
0P0i@TT0EP0lADd0>dA=03a5CP1:De/0Ae1E045;C@0mAdP0?4I803Y4A@0mAdP0>dE603e7AP0h@T00
AU5=02dh=011C4T0?de@03U8CP0fAD`0>DM@045?F@15Deh0BUQU055OJ`1@GVT0B5IQ03e;E00kBE80
?DYC055NI`1?G6@0A55J04=@F014DET0B5EK04AAEP13DE@0A59E049@DP0lBT/0@De=04=?C@14D500
DUaM03]5AP1OJFX0A4i?03e7B00^>3T0:S@e03Y4A@0_>CX0;SPj03U2A00d?3l09Rha02de>00g?d80
;cLj02hf>@1@EEP0Ri2D02L/<00m@TD0;C<d030e>00a=ST0=3Tl03Xo@P0m@TD0;S<g02`a=`0U:S00
;2lf03@g?P0c=Sd0<3Dk038g?@0_=3X0:blh02la?@0d=T80:2Xf030b?P0f=T80=cM30P0e=D40>00`
<ch0;C4l02/_>P0a<cl0;blk03Dd?P0T8b/0;BXa02DR900e<C009B4N02DP8P0b<3<09b8X02<O900Z
:2/04@`B02XW:`0V92L0:B@Z02TV:P0X9RT0:RD[02LR:00S7R@0;RT_02<N900G4QP07aXP02<N900/
9bd0:RD[01XE6`0h<cT0K6M]03<a=`0X:Bh08R<X01hO900O82D0824V024Q9`0G5Q`09B@Z02@S:@0R
8BL0>SPn02TT:P0W82L08AXQ01`E700K5AT06aDJ02DO8`0S7B4081XN0P0O6Ad0TP0M5a/07aXP01lJ
800O6R007QTO01dH700M61d07APL01/F6P0P6al07QTM01LB5P0J5AT081/Q01`G7@0D3aH06A@K01lJ
800E41L09R4X0:FPYP0X8bT03`XA01lJ8@0U7b<09ahO020F5@0F3@h050/<01L>4@0J51P06A0E01P?
500I41D06a8G01dB600I41D08APK00l92`0K5AL0<R`^01H@4P0E3a4050h@01TC5@0A2`d05Q0B01D?
4@0J51H050h@01D>400_:B/07A@G01`D5`0=1`T05@`?01H>4@0M5aT06a8E018:3@0B30h06Q@H01LA
5@0F41@05a4E01<=3`0@2P`0618D01TC4`0J51@06A<C01LA4@0F4@h06Q<=01XB3`0G3`d0=S0a03/e
>@0D3Q806aHK01TD600D4Q<04a4@01/G500B3P/0Ddm?03/g>00H51D06A@H02TT:P0D4QL061DJ01XH
7@0I5a`07Q`Q028O9P0O7R@07b8U01hS9P0S:2/09Rha02L_<P0X<CH0;3Dl02hi?`0c?DD0>DI>03]8
D00oCeP0?U1J03e?F`12E5l0@eEO04YLJ01RM7l0BeeW04AFHP0kCEP0?DmI02m1C@0jBU<0=45:03A1
B@0[=cl08bdf02</<`0O:2`0<3Di01/O8P0P92H071dO014B500K6A/06A<E01PB500G41405Pd>01D<
3@0C2@X050X;01`B4`0M4A<05@T;01H:300D2P/04PP90P0F30d01@0A1`P05@T:01D92`0D20X04`L9
00804PH800<04`L901D92`0A1@L00P0D20X0400A1@L060`>01<72@0Q5AL07A4C01P<3P0W6ad08QHH
01462P09008040D900T00P0E2Ph05PX<01451`0C1PL201D71`0601H8200G2@T05@T90104100D20P0
5`/;0P0A1`H03`0E2`X050X901<71`0B1PH050P801D92@0D1PH04PH6020B4P0A0`<050H6024C4`0G
2@T05PP801D71`0201<51@0301430`0D1PD05@L500805@L6024050H501<5100A0`<06`d>00/0000C
1PP050D801840`0D1`005@L401D62`0F1aL06@TS01/<:@0J2bT05`TS01H87`0D2AL04`TA01@93`0F
2A803P4801H9400<0@@0710B01D92`0A1@L03@4500l31`0F2A0050L@01442`0D20/00P0E2@/02P0D
20X05PX<01P<3P0F2P`04`L90186200C1`T05@T;01<81`0@1@<20146100E0104100?0`<050P90145
1`0<00@050P<01P<400900<05PX>01041P0B1PP05`/=00l31@0=0@<050P:00P0000?0`D04`L900l3
1@0J3Q0050L900804`@701d050D801D62@0E1PT05PL:01421@0@0@@050D801421@0D1@P05`X<01@8
2P0?0`D040@601D92`0@10H04PH801<72@0@10H03P840186200C1`T050D801L82`0L3A006``?00l0
0`0F1`X06@X=01H72P0201831P8050D800H0404401@5200D1@P04@8501<41`0D1@P601<41`0<01@8
300C1`/04@D90104200B1PX050P<01X>4P0?0`L0710D00d11@0D20`04@D91P0B1PX201<72`0400h2
1P0@10P05PX>00l31aCooooo000Kooooo`0301@91P0C20D05@X700805P/805D050T6020E4P0A1P@0
7Q<@020E4P0A1`D04@H301@8200?10@040D501451@0F2`/050P801/?400H30d050P80104100A1@D0
50P801D92@0D20P05`/;01T=3@0D20P05PX:01<71`0E2@T05`/:01H:2P0C1`L04@D501861P0F2PX0
40@401L;2`0M4A405`/;01@8200B1PH04`L701D92@0C1`L04@D501@92`0B20X060`?00l41P0U6AT0
M6QX01P=2`0D2@H050T501D:1`0D2@@04@L501881P0C2@P04PP801882@0C2@/04@H:01P=4P0:0@H0
6a0H00l4300A1@h0@CDi01/?3`0C1`L05@T901@8200C1`L050P801L;2`0/82008aLG0188200J3Ph0
60`=0104200Z7R806@dA01@83010=3P05P/>00804PH:00<05PX>01862P0B1PX00P0H31000`0F2Ph0
50P<01@8300301H:3P0501L;400J3A<06PhC01L;400E2Q000P0G3140B@0D2@l050T>01P=4P0F2a40
6PlD01D:3`0E2Q0050X>02HL8P0S6Ql05a4E018;3`0H4AD0618F01TB5P0K51P04`dA01XD600I4QH0
4`dA01PA5@0I418071<E01/A6P0I41h08ATW01lG8P0J51X06aPH01LF5@0J61X07AXQ01DB6`0I5Q/0
6aPL01XF7@0H51`06QHQ01hJ9`0M6RH06QLP01`J800L6Qh06QPH01dL6`0M7Al071/O01dL8@0P7bD0
8b8Z028R:`0P7bX0824/024R;P0P8Bh07R0/01XN:00R8Rd092@/02@T:`0T9BX08b@W028S9@0U9RP0
:2T^02TZ;`0X:Bl0;Bdf02DU;P0W9c008bH^02@W;`0Y;CD00P0Z;SL00`0/<CX0;SDm02he?@0202`c
>`0j02df?@0f@DX0:3@m02hj@`0`?DD0<Ca602llA00d@DX0=D9;03=0B@0c@4P0=D9;03M4C@0kBE@0
=dE?03m=EP10CeH0JGR004ECF`0lBUD0@e1O03Q5EP19EVP0>TML03m=G@0nCEP0@51J04EEH@17Ef@0
AeMV049BH@11DF40@U5T04ACIP1;FVh0AeIZ041?GP10CUT0?TaF03e;E00nC5D0?daD03m;D`0lAdh0
AU5G04]FG00j@dX0CEIM05IQI`0gADP0A59F05i/K`18EUT0?4Y<04=ADP0lBT/0>TQ8045?C`80?Ta<
03H0@deA04==E014CUD0A4eD04==DP12C580@T]A04E?E010BDl0ATmE05EOI@1FH6D0A51@041<BP11
CD`0@di?03i9B`0kAT/0=T57041:D`0g@DX0?4IB03m9E@11BUH0@4Q<03e6AP0lA4@0?dQ8045:B@0l
AD@0?dQ603Y3@00kA400?dQ403a5@00jA400>dM403e;BP12D5<0@DiG04=?GP1>FFd0DEaa04aGJ`1;
EfP0BEET045=F00b?dP0>49:03i9D012CE<0@diE03m:D011C58204IAE`80A4mE04l0@diC045=C`11
D4T0IWM/04EEC014DT`0?DY703m;B`10Bd`0>49603Y3B@0i@TX0<ca503<lA00g@4D0>495034k?@0/
=SP0<CTl03<k?P0j?d80<3@f038f=`0h>cd0;Rlc03Hg>`0`<SH0=CPm03@i?@0_=SX0=cm203<k?P0b
=c/0:bhc02X]<P0];380=C<i03dk@P0g>T<0<3@n02lc?`0d>4H0:Rdo02d_@P0b=DP0SI2P0412D00]
<3/0>3a5030d?@0/=3d0;3@n02de?`0_=cl0;S@k02lc>@1GFUl0?T14028S9P0S8b@092<T02@S9`0U
92X09bD[02DT:@0N7B<08b4W02/Z<00P7bD09bD/02DT:P0W9R`0<2hd02<Q:00[:2l09R<Z02@Q:00Z
9bh0924X00808b0W00T0924X028O9P0Q7RD08QlV024O9@0R8BH09bH[02@S:00M72400`0N7240?@0O
6b406QHL01XG700T7R@081XS01lI8P0R72D081/R01XE700K5Qd07aXP01hI7`0L5a/06aHJ01`G6`0N
6Ah08A`S01/E7P0J51d07QTP01XE700I51/071LM01/F700T7b<0:RDY02<N8P0M61`0618F01TC5`0J
4aP06A8H01/E6@0M5a`071HK01dG6`0Q6b005PlE01L@5@0I4aD081LD01/C3`0M61D05Q8A01/I700A
4AH05aHK01DB600H4aL06Q@H01/A4`0E30d07aHI01@>400O6A/0>C<e01XD5P0E3a406A<E01H@4P0E
3a400P0F41803P0D3Q006a4D01H<400Q5a/0:b0T02<I700F31005``@01H;3`0D2Ph05P/?01P>4@0I
41<05PlA1P0E3a40;@0B30h06Q@F01@>400=1`T071HG01LA4P1ECe00=2h_01@>400H4Q@06A<E01XD
5`0B30h06aHG01HA4P0L5QL05Q0A01dD5P0K4aH071DI01D=5@0Q6R<071DN01`E800T7RP06A<L02<N
9@0L5ad08AlT02DS:@0O7bD09bP^02`_=P0U:S40:2lh02`e?P0^>480<3e603E3C@0kBUH0?U1L04YL
J@1>H6h0AeUV04YLJ@0204YLJP0n04IHI@10DV00?e5O03mAGP0kCE/0=TQC03M7C`0d@T/0:cQ102/g
?`0Y<ST08b/`024V:P0W:bl0<C4e024Q8`0H5aT07ATM01H@5@0J4AH06a8G01P?4`0K41@04`P<01T>
4P0G2`d060`>00l31@0E2P/04`X=01@<400F3Q004PT:00h61@0G3P`050X901<9200D2PT05`/>01L;
3`0D20d04`@801L82`0M3Q4070d@01P9300D1@P04@8501X;3P0F1`X05`P;01<41`0F1`X050L901<6
200C1`T06@/>01851`0E1`T06P/>01L82`0E1PT201H72P0A01D7200B1PH04@H601H<2`0S6QT0>S<a
01@=2`0>20D04@X900`30P0A1`H05@X:01L;2`0L3Ph060X:01@61P0E1`L00P0F20P601@61P0601<5
1@0E1`L05@L701<51@0D1PH05@L70`0D1PH301D71`0=01D:2P0L41D040D>01465`0C2R805@hV014:
8P0@2Ql05a4Q01<<5P0H4AL04PT<01<62P0201@52@<050D801P05`P;01@5200C10L050D901H72`0G
20`05PX<00`10P0I3@l04PL902HJ700>10D04`L901D92`0B1PP04`L901451`0>0P@050P901<7200B
1PL07a<E020D5P0E2@/201451`040186200C1`T04`L:01<62PD04`@901004P<801@52P0D1@X04`@9
01T:3`0H2@h04PD801451`0@10H03`<501041P0C1`T04PH801451`0C1`T04PH80`0A1@L01@0B1PP0
50P:01@82P0C1`T04PH800H04@D701P060`@01472@0B1`X050X<04i2AP0F2`h06PhB00`2100F2Ph0
:AdQ01H:3P0B1PX050P<0104200C1`/060`@01D93@0A1@T05@T=0104200D20`03@4500d31@0D20`2
01862P0301@8300=0`D04`P;00<04`L;0P0B1PX201452@0<01H:3P0@10P050P<01D93@0F2Ph040D8
01452@0J3Q804@D90104200B1PX03P865?ooool001_ooooo02003P<001<8100C20@040D101<8100J
3`/0?34]020E4@16>cL0C44m01hC3`0O51004`L701D92@0L410040@400/10@0<00003@4100h30`0M
4A405`/;00h20P0E2@T0:alO00P0000C1`L050P801H:2P0I3@d04PH601<71`8050P800T04PH60145
1@0F2PX060`<01861P0E2@T06@d=01@8200E2@T00P0?0`<07`0A1@D04`L701<71`1QEET07a<G01H:
3P0J3Q00200001@8200C20H04PL301<8100F2`L050T301D:200I3a003P@501/A4P0J41402`0400l6
200K41@04@H<02hS:@0L4AL04`P@01@8300B1PH04@D501L;2`0F2PX00P0D20P0300E2@T09QXJ02`P
800P51@06@d=00T0000n<SH0`;Bh04e1A@0800003P8601dA5@804`L;00d05PX>01<72`0C1`/0710D
01dA5@0G2`l04`L;01@8300H31005`/?01D93@0D20`05PX>00805`/?03405``B01D:400E2Q0060dC
01/@5P0M4QP03@8801D:400S61h08AHL01H;4@0E2a407A@I01<=4@0@2Ph050hB01D?4`0H4QH06Q@H
018<400N61`050hB00l93@0J51L06Q4B01/B4`0I3aP05@dL01XA8@0I4A`06QDK01`J6@0H5aD05aDF
01LE700C41T06ALL01LE6@0F4aX061DN01TF800I5R4061DP01LD700L6Ql07Q`O01`K6@0O7Q`0820R
00807A`R00D07ahT020O9P0N7RH08B4[01lP:`0201dO:`0?01lR;P0P92l08b<_02@T;@0U9Bd09BH[
02@U:@0S92H07AhP01hO900T9BX0820X02LW<@0T92h0:2/d00<0:Rdf00<0:2`e02T]=P0[;cP00P0]
=3`202/d>`0902`e?00Q;CH0;ca503I3C00b?dP0=dA=02hkA00e@T/0<Sm80080<3e601`0=T=<03Y7
D010CUT0=TA=03Q6C`0fAD`0>dYA02hmA00nC5L0?DYJ04MDIP0jAeX0=41H03I4E@0kC5H0?TmI03i?
FP10D5d0AEET04MGIP19FFT0BEQ[04=BI@11D6<0@E1U03e;F`0jB540?4YC0P0oCEH06P0oC5@0AE1I
045;E00oBU00BeEJ04E>D`0kA4T0?TU=03=1A00iAdX0Df5T03e;CP0hATL0@4i?03Y8B@0nC4d0@U1A
03a:B`0oCDd0@DY?04=<D`17D5L0B55H04E>E@10BE00?4E<0P0kA4/0:00mATd0@4U@04A=D`18E5@0
@De=03e9B@0lAdT0>4=503Q3A`0e@4H0=3m503M1BP0c?DL0?4I@04E?F@0nATP0=d0m038k>00i@T40
?TM603a5A00oB4L0?4E403i7A@0kA4<0=Sll03M1@010C4X0@Dm@04ICF@14D5`0@DeO04QCJ@1KIW`0
Ef9g04IAH`15DEl0=D9<04MDG01=F5h203a7B`1603@o@`12CE40@4]?04IAE@15D5@0@diB045<D010
Bdl0?TU;041?BP2AX9P0@U5<03U8@`19Ee@0=d=303m:C00f@4D0?dQ?04YAF`14BeD0=3e403<m?`0g
@D80@DU;03Lo@@0`>3X0=Si003m4A`13B4/0=3Tl03@h>`0E61d0>3]003Dh?@0[;S<0;C8f03Hn@@0`
>3/0;cLj02`b=P0Y;3409bX_02DT:P0[:2l0<S4g030b>`0`<Sh0;2hk02h`@00/;D40<cA803DfBP11
@U@0;c5002d_?00i?4D0<SHo02lf@00X;cL0:S4i02le?@0Z;cD0:2/a059CF00n?d<0824T024Q8`0[
:bd0:RX^02HU:`809bH/00D092<Y02TX;P0];3808R4W02HU:`02024P9P0@02h]<`0W9B/0:2D/02DR
:@0S82L09b@[02PU;00Z9bh0924X028O9P0O72<07Q/R024N9@0T8RP08b8W028Q9P8092<X00d08AlT
01lM8P0N72407aXP01`G7@0J5A/06Q<J028L9P0N62807aTS020K8P0N6B008ahU00807QTO01D07QTM
01dH700M61`071LL01PC6P0S7BL08A/U01dH7`0]:2l05a8I01`G7@0J5A/07aXN02<N8P0O6Qh071LK
01lI7@0J51P05a4E01XD600L5QX00P0I4aL06P0G4AD06Q@H034[;`0O6Ad05Q0B020F500H40`05A0=
01/G5P0B41<06QTN01XI7`0C4QL03PT=024K7`0C2P`07aHG01L>4@0J51H05Q0B024K7@0E3a407ALI
01LA4`0E3a4050h@0P0E3a403`0C3@l06PlC01P=4@0H3A405P/?01L<400P5AT06a0D01H;3`0C20`0
5``@01X?4`0H3a8050`?01@>400201D?4@0A01<=3`0B30h06Q@F01<=3`0<1PP050h@014;3@0H4Q@0
6Q@F04<m?`0T7R005Q0B01D?4@0500406A<E014;3@0=1`T00P0W8B<03@0:10H05Q0@01XD5P0D3Q80
71DM01`D7`0<1Q007aTU01/E7`0H5Ah08b0W01/I7P0P7b@00P0V9B/0=P0X:2l0:2/b02@X<@0/<c`0
=T1903U3C@0b?dT0>DMB041@G@0nCed0BUaZ04AFI01;GF/0CV1^045CH@1<GV`0BE]Y04MII`18FVP0
AUQV041BH00iBeH0>4UA03M5CP0c@4T0<Sm7034j@@0Z<CP08bP/02@W;00Y:Bh07A`Q01PH6P0O6b00
50dD01<=4@0I4AH06a8G01XA500I3Q8050T=01T=3`0D20X06@d?01P=3P0A20/06Q@H01@>3`0G3Pl0
5`l=00P1000D2PP04`T701@:2@805PX>01@050P=01H7300G20/05`P;01D62@0D1@P05PL:01d>4@0>
00805PL:01L82`0B0`H04`@701421@0@0@@0814D00/0000I2Pd03P4201H72P<05@H901@04`@700h0
0P0M4A405P/:01881`11>CL0TX^901D@3@0;1P<05Pl=01/C4@0F30/04`P701L;2`0]7al070h>0102
0P0B10@05`T901D71`H050H601T04`D501D71`0E1`L04`D501@61P0E1`L060X:01L92@0F20P05@L7
01@61P0C1@D06Pd<01052@0F31@05P`K00h66`0B2R402PHK01<>8P0I5BH02`DA00l5400J3aL04`H9
00D050D800l05`P;01@5200C10L050D801H72P0G20/04@L800d10`0L41808QHH081dMP0k;c404`L9
01D92`0C1`T00P0D20X01`0@10H050P:01@82P0@10H05`/=01H:300@10H00P0A1@L0100B1PP04`L9
01<72@0C1PT601<42@0<01D62`0F1``05`P=01X;400F1``040<60186200E2@/04`L900l31@0@10H0
4PH80P0@10H01@0D20X05@T;01451`0@10H04@D700<04PH800<04@D701@82P0D20X0100D20X03008
00004`L;01H:3P080000@cLk01862P0G2`l03P8601D93@0O4aL04@D901<72`803`<700T040@801@8
300G2`l04@D900T00@0D20`03`D701862P0N4QH00P0@10P01@0;00<03`D702lS9`0B1PX020000080
4`L;0`0B1PX03@0A1@T04`L;01@8300@10P04@D9030T:00k;c<08ADI00h21P0D20`03`<701X>4P0F
2Ph05?ooool001_ooooo100E2PL07P0D2@H04`P501<81@0C20H04PL401D:1`0F2`T03P@301X>3P0A
1@D04`L70188200D2@T060`<01D;2`0F2PX0;R8R02DI6@0E2@T07A4A038V9P0@1@D07A4A01861P0H
30`03@4101<71`0D20P05@T901H:2P805@T901<050P801D92@0A1@D04`L701@8200B1PH05@T901<7
1`0D20P05PX:01D92@0C1`L0@cLj020D5`0D20/04`P901D;2`0I3@d050T700804`P502405@X60187
0P0F30X07Q@F02PM8P0D2`d03`@701lD600D2@d030<5024F6P2MTYH0;28T00/21@0F2``05@T901L;
2`0M4A406Ph>01H:2P0E2@T04`L701D92@0E2PX04`L701@8200D20X02`4303hb=P0H31006PhB01@8
300F2Ph01@0E2@d0100G2`l060`@01L;3`0F2Ph201L;3`0401T=4@0G2`l05@T=01L;3`806@dA00<0
6@hD01H;4@0F2a400P0J3aD0100E2Q0081DK01D:400I3Q@201@93`0Q01P>4`0J4AH05@lC01LA5@0H
4QH05@lC01LA5@0L5QX05@lC03D_<`0/9RX06A<G01LA500K4Q<06Q4C01T?600F3Q`06A4O01/C7@0F
4AD07A/I01/J600F51H08QlW03Pe?`0L6R0061HL01TF7@0L6B8071TS01PE7`0J5b0061DL008071XM
00<06APG01`J6P0N7R400P0L6b407P0N7B@08B0X01lO9`0M7BL07QlY01hQ:`0P8Rh082<_01lS;P0P
82X08R8[02<S:`0S92T08b@X02<T9P0V9bT092DZ03@e>P0V9Rh09RH`02TY<`0W:S<0;2lh02d`>@0Z
;CH0:Rhg02``>@0Y<3P0:S4i02/c>`80;3Dl00h0:cHl02dh@P0`?DH0:cQ107N4S@1?G6D0;CY303=0
B@0d@DX0<d1903A1BP0f@d`0>4E>03i<E`80>DM@00h0@U5H0391B00mC5<0?TaG03A1D@1@GFl0>TMJ
03e9H@0iB5T0?4eG045AG@10DEd0?dmL04ADH`80C5a/00h0AeMX04EEIP14E6D0@e9T041?G00nC5D0
?D]D03e<E00oCED0@DiF045=E@11C580?dY@03m9CP80@4U>00D0>dI:03U7BP0mBdh0?Ta?03m=D002
03e;C@0=041>D00nC4h0?de?041>D00oCDl0@diC04A>E@15CeD0A4iD049<D`10BU40@TaB041:D002
04==E00]03m9D014CU@0@4]>03e9BP10Bdh0@diA03i9C00iA4P0?TU>03Q3B012C5<0=T58049<E01>
F600BE=B041:AP0f@3/0>D=003]5@`0g@3l0?4E503U2@P0i@T<0>D9403Y3A@18DE@0AU5E04=@EP15
DUd0AE5P04IAI@1>FFl0D5]a04A?H`15DF80BEER04EBFP2]^kl0SIRL03]6B@0oBTd0>dI9041;CP13
CU40@Da?0080@4]>0P0oBTd0800nBD/0?4Y904MFE00nCD`0>DI703e9BP0iA4L0=d5503@m@P0i@DL0
@4M>03i5C@0d>d00@4M802lf=@0nADH0A4]<03@k?@0b>3/0CE=F05UPH`0a=c`0<SPm030f?@0Y;c@0
<SDk02X_=00^<cP0=Se202Ta=@0]=SX0;3<h0P0U:2h0<`0X9bh09R<[02HU;@0_<CX0<38n02la?@0k
?D/0=cQ903PiBP0`<D<0<39103DgA00T9S80;S4j02/^=`0^<S`0;S8k02d`>@0Y;3@09BL^028S:P0]
;C<08b<X02LV:`0K6Qd08b8U02XY;P0W9R`09B@Z02HU:`0T8bT0:2L]02XY;`0S8RP092<Y02PW;@0T
8bT08b8X02/Y;`0`;C@09b@[02HS:P0W92/07a`S02DR:@0W92/09R<Z02@Q:00U8RT0:BH]02PV;003
02@S:004028Q9P0Q7b@08b4V024O90<07QTO01L07QLN01lI8`0M5b4081XT01lJ8@0I51/06QDL01/F
700L5ad07aXN01hI7@0L5a/06A@I01lJ8@0K5Al08A/U02<N9@0>2A0081/R01/F700I51X061<G01XE
6@0201`G6`0K01XD600I4aL07QPL01hH700I4aL06aDI038/<00H4QH07aTM014;3`0L5QX060lB01X@
3P0P5Q@0;2@R03La<@0H51P061LL01DA5`0I51X03@H=02DL8@0O51P06Q0B01<:3@0J51H04P`>0080
5Q0B00h05a4C01D?4@0D3Q0050h@01H@4P0E3a404P`>01D:3P0G3100714E01/@500D2@d05P/?01T>
4P805@X>00D06PlC01hC5`0L4aH04PX=01<=3`0201D?4@<04`d?03405a4C018<3P0P6Q`05@lA014;
3@0A30d0618D01TC5@0F41807ALI02XT9P0J51H04P`>020J700R71h02`D7028L7P0I51<07APJ01<>
400G4QP040/E024L9P0F4ad08R0X024Q:@0L6b006a/O028R9P0X9bd0:BT_02LY;`0V:C0092Pa02`d
?@0i@d`0?T]D03U7D@0nCUP0@U9O04QII`0mCed0DVAb08>EX`1VN8H0DVAb05AVM01@HW00Cf5_0080
D69`0280Cf5_04IGHP0kC5D0>4M@03E2B`0_?4@0;3Lm02Ta=`0T:Bl08B@Y020R9`0M7B80820S028N
8`0F3aH06aDI01dF6P0E3Q805@`?01/@500@1@T06Pl@01451`0J3Q005@X;01<:3@0D3Q805Q0A01/B
4`0S6aT05`l=01@:200C2@L04`T80P0F2Ph0100C1``050D:01D62@0F1`X201@5200P01H72P0J2`h0
3P0201/<3`0C10L06@X=01H72P0E1PT05PX;03<T9`0C10L06P/>01@7200D1@P060T<01L82`0E1PT0
50D801P9300E2@T060d<01881`0C2`T07aTG00h91P0C3P/030L501H>300C2@P040H601<71`0E1`L2
01L92@0301H8200D1PH04P@400H050H600H04`D501D71`0E1`L04`D501@61P0E1`L501H8200>01H8
1`0H30P03`<301882P1IDEX0DdaK00`65`0I52T01`4G018:800D31h081@V00h3400C1@X501@52003
01H72P0E1PT05@H900805@H901<05PL:01<72@0A1@L05@T;01<92P0O4aD050X;0186200C1`T040@6
01<72@0D20X040@601<72@0D20X04`L901D92`0C1`T040@600804@D700@04PH801<72@0C1`T04`H9
1@0C10T301@52P805PL<00l04`@901<52@0F2P`05`/=01<72@0?0`D04PH801D92`0A1@L040@601<7
2@0@10H04@D701<72@0B1PP00`0C1`T00`0B1PP04`L901<72@0401<72@05020D600A1@T04`L;0186
2P0D20`00P0A1@T05`0@10P04PH:01862P0>0PH04PH:01<72`0G2`l04`L;00h21P0B1PX050P<00l3
1`0C1`/0?c@g075UJ@0I3a404PL:00/10`0G2`l0;20T0;jb]P0S5a/040@800H04PH:00`05@T=01H:
3P0?0`L08aLK09R<T03Sfml0Ge=G01hB5P0F2Ph03@4501`@500F2PhDooooo`006oooool02@0U6QP0
5``:00`1000>0`4050T701D:200?10804PL501<81P0201050`0301<81P0@10@060`<00806@d=00D0
714A0104100O4a<05@T901/?3`0201D92@07024E5@0<0P803`<301861P0?10@06`l?00h20P020104
100401451@0B1PH04`L701<71`805@T902P050P801D92@0F2PX05PX:01451@0B1PH050P801D92@0A
1@D03P8201061`0D20X05PX<01P<3P0K3`l05`/;01P=2`0D2@L04PL501<8100B1`<030<20<Fj`01[
H6H08QTM081eN@0H3A4050T=02@J6`0B20T050X;01`B4@0Z81l05@X:01@8200F2PX06Ph>01D92@0C
1`L04PH60P0G2`/0100D20P04PH601861P0L414200h21P0401X>4P0;00<02P0200h41P805`/?00<0
50P<01L;3`0G2`l00P0B1PX01@0F2Ph060`@01L;3`0E2@d06@dA00805`/?02`06@dA01X>4P0J3Q80
6@hD01D:400@1@/050T?01dB600Y7R@02@0401873@0k<3H09Q/Q01L<4P0F31806a8G01D?4`0B3100
4@/?01@>4P0V82@01`45018<400K5AT03PP<01/E6@0C3A407A@G01T@4`0I3aT06A4N01TA7@0N5al0
5A0D01/I5P0I61H04a4D01hK900j=d807AXQ01`J800L6B007AXS01`I8P806AHO00H05Q@J01XH7@0L
6Qd06aTJ020N7`0L6b0201/J800Y01hM9@0P82P07alW01dM9`0P8R/092L`02DW<`0S9S407b<^01`O
:00O7bP08B4Y024R9`0R8bL08B8T02HW:@0U9R/0?d1502LW;`0O7bT092L`02HY<P0Y;3D0:Rdf02X^
=`0[;cP0;30i02P_=`0W<3L0:C8i02df?@0/=C`0:C@j02hkA00[>440>dQA02Xg@00_?4D0@4eF034n
A`0gA4d00P0hADh203M4C@0D03M5D00iAe00<d5:041?EP0_?TD0@U5H03i<E`11CUh0@e1R038oDP14
D6P0CE]^03m@FP13Df00A5AQ049BG`13Df80C5a[04YJJ@13Df<204IFIP0M045AH@11D5d0@DmH03i<
E@0lBe<0?TeD045>EP1LJ6l0H6]a04]FFP13CE80ADiC0419CP10Bdl0=dE8030n@@0e@dH0<Cm203U7
BP18EUT0@U1C03a:C@0oCE00BUQK04UGFP14CeD0@diD045<DP0oBU000P0nBDl303a7C@0903e8CP0n
BDl0?TU?04A?D`0nBDd0>dI:03m:CP10Bdl0AU5E0080Ae9F06D0AE1D03@o@`0e@4@0>TE8041;A`0l
Ad40>4<m03Q3?`0iA400=T10049<C@0jA4H0<C/n02hg?00`>D00?TM?03e7D@0jAU<0@TiN04QCI`1>
FFh0F6=i051KL@1<EfT0?TYH04=@F@0nBe40EfEV05=NH00oBT/0>dM7034l?P0oBd`0?DU903e8BP0m
BDX0?4Q803a7B@0kAdP0>dI803]9C00mBU00HFid045<DP0lAd/0=D1402lh?@0c>d40<3Lm02lf?00a
>3d0<SLj034e=00_=300=SXi038g=`0^<cH0=3Tl03Dm@00d>d40;C@j02L_=P0b>d80<CY1030e>`0]
<SP0:c8h02he>`0W<3D0:S<h02he>`0V:c40:B`c02d/=00V8b`08R4Y02X/=@0X:SH09RPd03HhA@0`
<Sl0:R`i02la?`0X:SL09BLc02PZ=P0`<c`09bXc02T/=@0a<C/0;Rhh02@T;00S8RX09RD/034`=P0V
8bX07adS02`Z;`0k>Ch0;B/a02TX;P0302DT:P0802PW;@0[:S00:BP^02HU:`0b<CL0:bX`01dL8P0S
8BP202HS:P0503Pe?00f<cX08QlV01dJ8@0O72<00`0Q7RD02P0T8BP0928X02<R9`0T8bP08B0U01dL
8@0O7B8081hS01hL8@0N6Al201`G7@0901lH7`0L5R0071HP01`F800I51/06aHM030[<P0I51X06aHL
00807QTM00P07APL01/F6`0J5A`0;2H`02dW<@0>2A005Q4H020K8P806QDK0P0F4AD201/F6P0301`F
6P0J51P071HJ0080618F01@0<2X^0<_5b@18@TH02`D900P21P0G4AD040L:01X@3`0L4A409A/L02XQ
900H4QD05a8H01<<4`0F3aH06@lG00l42P0O4aT05P/?01@;3P805Q0B0P0G4A<02`0A2`d04`d?01<=
3`0E3a405a4C01H@4P0B30h07A8F01D:3P0F2`l06@hB008060dA00T05P/?01P=4@0H3A405``@01H;
3`0C2Pd04``>018<3P0C3@l00P0E3a401P0F418050h@014;3@0A2`d07QPJ01LA4`806A<E0P0@2P`0
:P0L5QP06aDG00l92`0G4A<07QPJ00d72@0J51H04@/=038/;00I5A<08alN00h<3@0K6Ad0924X05QG
G`0f=Cd08b<[01hO900K72407b0T01PI7@0W9R`09bP]02DW;@0T:Bl08RTa030i@@0c?DH0<Sm803A3
C@0kC5H0A5AQ049CH@1?HFl0CEm]05U[N@1KKG/0Bee[05U[N@1JK7X0EVQf051RL080CEm]0240B5UU
03a=E`0hBE40=dM?03=0B@0b?4D0;3Dl02H]<`0Y;S@0:B/`020Q9@0J6Ah06AHL01/D6`0V82@08Q`P
01<=4@0H3a8060dA01052@0H3Pl050P:01L;3@0Q5QL0<RT/00@00P0=1`P05@`=01dE4`0C2`P04`T7
01881P0B20L00P0E2@d0:00B1P/0404601<41`0H2@`05`P;01D62@0D1@P070d@0101100E1PT070d@
020A500C1PP070d@01<41`0H2@`04@8501/<3`0L3A0050D801D62@0D1@P04`@701831P0A0PD09ATI
030U900C2@P040P601XC4@0910401`8002<L6P1TG5X050X901D<300H30`050H601X<300G2@T20143
0`0301T;2`0D1PH050H600@050H600T04`D501D71`0E1`L04`D501@61P0E1`L04`D501@61P0E1`L0
0P0G2@T03P0H2PL04@H002<I400C2PD081HH02PP:`0B31X01`4C01<;8P0G3bH08AL`09V=Y@0^8C<0
4`D;1@0D1@P601D62@0601@82P0M4A<0200001L;3@0800005PX<0P0B1PP01@0>0P@040@60186200@
10H04@D700<04`L900D050P:01<72@0A1@L04@D70186200201<72@0301<62@0C10T04`@900<04`@9
0P0A0PL01P0H2@h08Q<H01/<4@0B0`P040<601451`@040@600@04PH800d10`0=0@<050P:0P0>0P@2
018620<04`L900<04PH801451`0A1@L0100A1@L01@0800006PhB01L;3`0800005`/?00804PH:00<0
5@T=01@8300>0PH00P0D20`0100@10P03@450104200D20`201862P0=00l31`0A1@T0>2d`06aPI00A
1@T050P<01dA5@0G2`l03@<5028F6P0C2@/081@H01452@0301862P804`L;00P040@801L;3`0A1@T0
5`/?06YNHP2aYJT0ASXn01<82`8040@800<050P<00T00Oooool04oooool001_ooooo00P07Q<A01L<
2P0@1@<03`@201871@0E2PP05P/901<81P806@h<00/04@H401@91`0I3@d03@<301T=3@1?@d<0GE5A
01@8200B1PH040@401861P0200h20P0801@8200h;2`07Q8B01@8200F2PX04`L700T0000?0`<20104
100Z01861P0C1`L050P801H:2P0D20P04`L70104100?0`<040@401861P0A1@D04PH601<71`0B1PH0
40@4020D500D20P0200001X>3P0800005@T901T=3@0C20H04@H401<81P0E2PP06PhA028G7`0?10`0
4PL=01`A5`0C20`05@/=0147200<0P<05`d<01H<2P0?1@<04@H501861P0C1`L05@T90`0B1PH0300F
2PX05@T901H:2P0D20P040@401T=3P0I3@l05PX<01<72@0@10H07a<E020D5P8060`>00l050P:01P<
3P0H30h050P;01<72`0E2@d05PX>01D93@0D20`05`/?01H:3P0G2`l06@dA01X>4P0G2`l00`0D2@l0
2`0I3Q@08AHL02lT:P0R5ad06@hD02/P9P0?10X03@8801lE6`0D2a004@/?00804`dA01D05a4E02XT
:00V82@07QPL01TC5`0H4QH091hR02dW:`0O5QT06Q4F01X@6P0I4Ah05`lK01/D6`0C3a0061DC01lN
700K6A`04PhI01DA7`0J5b000P0M6R409@0L6B006QLN01XG7P0L6B005aDK01PF6`0I5aX06aTJ024O
8P0N7B<071/S01/J8P0M72@07ahV01dM9@0N7RP07b4Z020S;00Q92d082</01hR:`0L7bP07R4Y01lR
:@0P8bP082@W020T9@0X;2d0;S4f059EFP0e>3l092L`02T/=@0[;SL0:2`e02T]=P0/<3T00P0Z<CT0
2P0X;cL09Rlf02Pa>00/=cd0:cHl02Td>P0_?4D08c0i03Y7D00]>T<2038oB00B03=0B@0gA4d0>4E>
03Q5CP0iATl0>dQA03Q6D@0nC5D0<Cm803a;DP0c@TT0@4mF03Y8D`11CUh0BEIW04]HJ`0nBV80AE=U
0`11DEh02@12DUl0@e=P04YJI`18F6D0@e=R04EEI00oCeh0>d]J03e<E`0303e<D`0>03m>E@11CU@0
GFU_05aWK@11C500?4I903e7B@0kADL0?DQ:03U7B00lBT/0AE=E03e;CP0jB4/2041>D@80?DY@0P16
DeT3045<DP0N03m:D00mB4h0>dI<04E@EP17DUP0@DaB041;D@16DEL0@4]A04A?E@0nBDl0>dI<03m:
CP11C500Ae9F03Y5A`16DE<0@Da>03Y5A`0h@dD0>dM803Q3?@0iA3`0>dI003Y5@@0h@cl0=d5104QB
E00oB4d0=3e30P0`>D80J00f@4T0>D9A03Q4E@13CV80BEAX04]FK01@Fg40@TeQ045<G00jAU80@4eE
04=@E@0e@d@0<Shn03i:B@0lB4H0>4A4041<B`11CD/0?d];03i:B@0kAdD0>TI603Q4@`0f@D<0=3m5
03e7D01JI6d0>TA=03a6C00h@DP0<3Tn03Ho@`0b>Sd0<cPl03Dj?P0b>3P0;2h[034c;P0`=C40;30_
02`b<P0^<cH0<CTl02lh?@0c?4<0;CM002Pb>`15CUL0=S]202/`=P0U;3809Bdc02Tb=`0S;340;3@j
02db>00_<ST0:RXb02DT;00V9Bd0;Bdg02XZ=00P82X0:RXe02PX=00U9C40;bll03XjAP0[:cD0;2`f
02h^>00f=T00:2P`02d/=00/:c<09RD]02DR:@0[:2l09b@[01hK8P0U8RT061DL02TV;@0[:C009B@Z
024P9P0S8RP092<Y02PW;@0[:S00:RT_02@S:@0];3809RD[01`K8@0U8bX08AhU020M900a;SD0<2dd
024N9@0O72<081dT0P0R7bH201lL8`0302<Q9`0S8RL08B0U00808R4V01008AlT01dK800N724091lU
020K8@0M61h07AHM024K9@0R72H07aTS01LB6@0M61l0@3]201/F700L5ad07aXN0P0P6al02@0O6Ql0
6QDL01hH8P1/IW00I5mV03Ha>00@31806A@J01XE6`0201D@500W01/F6P0J5AT07ALK01PB5P0J51P0
6A<G01H@500Y8bL0=S0d01LA5@0J51P08adQ01D?4`0M51L08QPI01L=3P0D2P/040L:01XA5@0J51P0
718J01/A6@0l<SX02`0801L<500N4aT05Pd@01H@4P0L5QP05a4C01D?4@0F41804`d?01@>400G4A<0
6A<E01LA4`0C3@l0714E00805@X>0P0G3100200K41@050T=01`A5@0M4QH06@hB01@93@0C2Pd05@d@
0P0B30h0EP0D3Q005a4C01TC5@0G4A<02`D7018<3P0H4Q@04P`>01`F600H4Q@05a4C01D?4@0?2@/0
6A<E024K7@0=1`T05@lA018<3P0<1PP0A3i00=C>cP0g=3801@@201/K6`0H61/092<Y0:n`]@11@DT0
6Q/P020S:00B5AT05a/N02<W:P0T9BX08b@Y02@V;00U:S008bXb034j@P0a>d@0<Sm8049AF`15EV00
B5YV04YLJ@1OLGl0FF]i04mQK`1MKgd0FVaj061bP01MKgd0FVaj05AVM01=Gfd0Bee[04MII@0mCeT0
>DYD03];E00jAe00?4I?03<l@`0W;S@0:Rle02LY;P0O82D05aPL01PE6P0G4QP07aXN01lI7@0E3a<0
6A<E01D<3`0B2@`05`d>01`B4`0M4a@0?S@d0=O>d@1<ATX040X;00H0000B2PP03`L40P0B20H0200B
20L05@T=01D93@0B1P/040@80186200F2P`05@T;0P0D20X02`0L418050P:01H:300H30h04PH803L[
;@19?Cl060`>01@:2`0Y7Al05@T;00804`L901L03@4301<72@0N4Q@0710B00`00P1EBDT0]:VY034W
9P0>1P@03PP601PC40091040<BXX07I^K00O5A@04PT901/?3`0H2PX06@/;01D71`0A0`<04`D501X<
300601@61P0601<51@0E1`L05@L701<51@0D1PH05@L70`0D1PH201D71`0>01D7100`8aP04`T001P?
1P0L4a402@8900X43P0E3Qh03`LL00`4701FBVH0XI:a02<E;00C1@/501@520805@H90P0F1`X0200E
1PT050D801D92`0J3Q002P0001@82P0@10H06@d?0P0D20X02P0?0`D04@D70186200A1@L04PH801<7
2@0B1PP040@60186200D20X201451`040186200C1`T04`L901<62@H04`@901<04@8701H7300P4AH0
6P/@01@52P0B10P03`<501041P0E2@/05`/=01451`0C1`T03P8400d10`0O4aD06`lA01451`0>0P@0
40@600804@D70P0@10H601451`0@00h21P0G2`l040H801@8300W6al04`L;0104200D20`04@D900/0
0`0F2Ph040@803DY;@0J3Q802`4301D93@804`L;00`0710D01<72`0C1`/0710D01L;3`0?1@L02@01
00d11@0I3A40200001<72`08000201452@804PH:0P0C1`/201H:3P0701452@0800006@hA02hR9P0H
31002`4300l31`0201@8300301862_oooooooooo01;ooooo000Kooooo`0F01861@0D20L05P/:01D9
200B1`H04PH501D9200B1`H04PH501461@0S61L04`P700h4100H30`04PH601P<300U6QX060`<0186
1P0D20P05@T901@820@04`L701404PH601451@0?0`<05@T901861P0D20P04@D501@8200C1`L05@T9
01861P0?0`<04PH601T=3@0G2`/050P801H:2P0201<71`<05@T900L05@/:02LL6`0O51<040D401X>
3P0A1@D060`<00804`P701405@T801L;2P0C20/03PD;01dB6@0D2@l050T=044f>P0l<S<06@l>00l5
100D2PP060h;00`3000D2PL050P801861P0201<71`0?01D92@0F2PX05`/;01<71`0D20P05PX:0186
1P0C1`P05@T;01X>400E2@/060`>01451`0F2P`05`/=00805@T;00<06@d?01L;3@0F2Pd00P0G2`l2
01H:3P805@T=02`05PX>01P<400H31005`/?01D93@0H3A<05@X@01/@5P0F2a4040D;01T>500L4AL0
4`X>01X?5@0E2Q00714G01X@5@0F3A805@lC01TC5`0F41@04`dA01H@500[9BT05a4E01D?4`0J51P0
4@/?01XD600O5QX07A<J01/A6`0D31T091dW01`E6`0I5AD04Q0<01LF4`0N71l09b@^01LC8P0H5Al0
6aPP01`I8@806aPO00`07AXP069PIP0_;C406QPL01hL7`0N71h08R0T01dL8`0N7BH071/T01TG8@0M
7BH2020P:@0B01hO:00M82P08RD]01TL900R9Rh08BD^01hR:P0P92X08bL/02<W:P0M8R808RLW01hR
9`0_<cL092P^02@W<00/;cP0:Rhg0P0T:3401P0W;CD09bhf02D]=00X<CP09c0g02Tc>P80;CPn0100
:cHl02dj@`0d@DX09c@m02llA@0f@d`0=D9;03A1BP0gA4d0>DI?03Q5CP0kB540@DiG03M5D00jB540
<T190P0gATd01`0lBe80?4YE041=G@13D680Df1c04IBJP14DV@00P14E6408@0oCe`0?4aI041@G@15
EF80@U9O04YJI`13E600=TMB03Y:F00iB580=dI=03U8C`0oCU@0@U5F04=@EP15DUH0AE1D049=D@15
Ce80?dU;03e7B@0mB4X0@Dm@04=ADP0kBD/0?D]>041>D@0nC500>dU=03m<D`0hAD`0>TM>03m<D`02
03m;D@80@4aB00/0?d]A03e9C`0lB4h0?TY@03Y6C00lB4h0A51F049>E011C540?TU>041;D00204IA
E@0404E@D`0kATP0AE1B04=>C`80?TU:04/0?TY903I2?@0nBT80@Te8049>B`0mB4H0>DA5045;D00m
Add0=d1903m8DP17D5`0ATmL03]6E`0mB5/0@TeQ05EPM@14Cf<0A4mQ04UEI@10C5T0?daD03]8C@0j
B4X0>TQ803i:B00lB4H0@De;04IBD011CD/0AE5?04A@CP0oBdT0>dM503Q4@P0b?S`0=D5104==EP0h
@T`0?dUC03HoB00c?4@0=Si603@l@@0e?400<cTl03@i?00c>CX0;C4a02h`;@0a<bh09RPS02``;`0]
<c<09bd]02de>00c?4<0=d1707^5SP0i@dd0CeQQ0415C@0]=3/092/b02L`=P0^>3h0=T1503Y3B@0[
<ST0<SHn02PZ<P0V9Bh09bH_055AFP0n?TL00P0V9Rl0600Y:C808R8[02XZ<`0];CH08B4Z02h^=`0J
6R<09bL_02TW;`0Z:2l0:BL^02/X<00Y9Rd0924X02DR:@0V8b/0:BL^024O9P0X9Rd08b8X01`K8@0M
72808B0V02<R:0<09bH/0P0Q82H201lN900402PV;00R7bH07Q/R01hK8P8071TP0P0R7bH202<P9`0c
024N9@0S82L09B<Y024P9@0L6b007A`Q02LV:`0U8bP07A/P01lM8P0T7bD08A`R01hI7`0M5Qd0618L
02dW<@1dKWP0:2<Z01LB6@0S7RD07APN01hI7`0O6Qh081/O01lJ7P0P6b009B0W024K9@0V82X07APO
01D@5`0L5ah07aXP01TD6P0L5a/091lS024L800M61`06Q@H01LA5@0J51P06aDI01H@500H4QH05a4E
05]EF@0O6Ad0618F01TC5`0D3Q805PlA00807aDG01H071<F01`C5`0G3Q<05PdC02<I8@1<@TX081DN
01/@6@0K4QX06A<G01PB500N61X06A<E01@>400G4A<03`T;01H@4P0J51H07ALI01H@4P0C3@l060dA
0P0G31004@0F2`l05``@01/@500F2`l0714E01hC5`0K41@06@hB01XA500D3@l0618D018<3P0C3@l0
@cdo06USI@0F41803`T;00805@lA03l04@/=01LA4`0E3a403PP:01/E5`0G4A<040X<01LA4`0E3a40
6aDG024K7@0T7R003@L902XV9@0I5a<06a/I00l?3@0F5QP051DI03@e>@0H6Al071lT01/N8`0E6A/0
7B4R01XN7`0R8bP08R@Y02@X;@0X;C<09Rde02df?P0^>d<0=D=<04UJH`17FF<0AEMS04aOK01=Gfd0
EfUg05a^O01NL7h0I7J4069dPP1QLh40H7:005]]N`1CIG<0D69`04]NJ`12EF00?DiI03Q9D`0b@4T0
;ca502hg?`0/<c/0:c0f02<W;@0N82D07QlT01hL8@0J5A/00P0H4aL05`0E41@05Q0B01XB5@0K4aH0
60l@01@;300G3Pl0<2HV07=ZK@0V82@05Q0A01<:2`0G3`d05Ph;01@:200C2@L04PP701@8300C1`/0
4`H<01<8300D2@X05@X;008050T:01005P/=01051`0C20X060d?00l41P0>1@D0CT=506mTI@0L4A<0
9a`N069GF@0F2``05@X<01/@4P0?10H06Pl@0P0_92H03P0D2@/0BShn085hM`0B2@T04`/901<<2P0C
3P/06QDB00l81`0L51805`d<01<8200D20P050H60P0E1`L201H8200501D71`0F20P04PD501D71`0D
1PH00P0E1`L00`0D1PH05@L701H8200601D71`0@01@61P0C1@D04`D201d?1@0O4`P04@L101480`0A
30/03`P=00`64@0L52D05P`S01/>:`0=0Ql03`<K01@530805@H90P0D1@P01@0E1PT050D801D62@0F
1`X05@H9008050D801P050P:01451`0H30h04`P901882@0T61X06`lA0186200A1@L04PH801@82P0B
1PP04@D70186200>0`D03P8401<72@0B1PP03P<401H:300c9bT05PX<0186200B10P201@52P0B0143
1`0L3A80408601H8300>0@@04P<801<52@0J2a0040@601L93@0E2@/05`/=01lC5@0M4A<04PH801@8
2P0B1PP04@D70P0O4aD00`0E2@/03`@501L;3@0201451`0=01X>400Z7R003`<501X>400S5aT03P<4
01451`0E2@/05PX>00h31P0B1PX06@dA00`2100201<72`0I01D93@0B1PX03`<701L;3`0A1@T0ACTm
02/O8`0C1`/050P<01862P0C1`/0@cLk0104200L41@05@T=01L;3`0A1PT05`/?01D93@0@1@P050P<
01H;3P0N4QH04@D901862P0201<72`0601862P0A1@T04`L;01452@0E2@d050P<0P0C1`/01P0H3100
5@T=01452@0D20`04@D9010521Cooooo000Kooooo`0301P<300D20P04`L7008050P800T04PH601D9
2@0K3`l02P0001P<300L41003P8201<71`0E2@T00P0F2PX02@0E2@T04`L701<71`0A1@D03`<30104
100A1@D04PH601<71`0201861P0301<71`0D20P050P800804PH600X03P8201P<300K3`l07a<C01H:
2P0B1PH05PX:01dA4@0I3@d04`L71P0D20P01@0M4Q00<bPV02DJ600A1P@06`l?00805@T901H04PH6
01@8200C1`L04`L701872`0E2Q004PL=01052@0@1PL04PP901L=3@0H3Pd04@L50147100E30L06a8=
01X?3P0D20P04`L701861P0C1`L050P80P0E2@T01@0D20P05PX:01T=3@0H30`05PX;00<05@T;0P0D
20X0200G2`d05PX<01<72@0G2`d06`lA01T=3`0F2Pd05PX>0P0G2`l301H:3P805`/?0`0F2Ph03@0B
1`d03P<9024F700L4AL04@H<01052`0E2Q005``B01D:400D2@l05``B01D;400F3A800`0D3Q8201D?
4`<05Q0D03`05@lC01H@500F41@04`X?01L=5@0M4ah04PXG02`U;P0M5aT05a<@01@B3@0I61@04Q0C
01`I9@0I5B@081dX01`I8P0J5b006aPO01XH7@0H5QT0<Blb01hL7`0K6A`07Q`O01/I700I5a`07A`T
01PF8@0Q7bX0;B/f024P:P0H628071`T01/M900G6R406QdT02DY;`0A5Q`0720Y02@Y<00T:Bl07R<W
01hS9P0V;2`09B/[02DZ;P0V:bl0:Bhd02``>@0]<CX0:Rhg02L[=00X;3D0:C0h02H_=P0T;C@0:C8i
02Pc>@0Y=3X202dh?P0502/f?00]>T<0<3e602dj@`0`?DH00P0e@T/07P0b?dP0>4E>03e:D`0jAe00
>DI?03e:D`0e@dh0=49;03E3C00hAdh0?4]B03i=E00lBUD0?DYJ03m<GP1?G6l0Ce]c045?H@0mCEX0
@51M045AGP0nCU/0>d]H03m?G010DE/0BEYT049CG@0kC5H0@E9L041@E`80?diE00L0?4]A03Y9CP0o
CE00?T]>045<D00nBD/0>dE70080>D=500h0?DQ:03Y8B@0e@d@0>TQ:049@D`0oCE00=45603A1A`0o
C5@0@4eF03i;E012CeP0?T]C03i;D@<0?daB00<0@4eC03Y7C@0kB4h00`0lBDl01@0kB4h0?dY>03e8
BP0mB4/0@Da@0080@di@0P0mB4X06P14D500@4a<04YFEP1AGEd0@4a804A@C00lB4H0?d];03i:BP11
C4l0@DaB03a6C`0b?4H0=T1<03e7D`0i@U40@diP04aGJ@16DF<0FVEg04E@H@0f@U00>TIB03U6CP0g
A4X0=dE60P0hATH0C00mBDT0?DU8041<BP12CTh0@De<03i:B010C4`0=T9103A0?P0jATH0@Ti=05YU
I`0oBU00=d5;03I0B@0f?dP0<SY1038i?`0d?3l0=C`n03Hl?00e>c/0;cDc02T^:P0K7AX0<S@_02L/
:00c=cH09B/[02H[;P0X<3<0>D9704]DF`2S[KH0=T19030i@P0Y<3P0<3Lo02/d>`0Z=3X0:SDk051K
H@0mATd0>D1802`c>`0T9c00:BTc020N:@0`<3P07alW04Q8D00Z:S406a`Q02<T:00W:2d0;2db02l_
=`0Q8BT0:BTa03He?@0V8bX09b@[02DR:@0X9B`09b@[02HS:P0N7B<05A8K01PG7`0X:300;Rde02PW
;P0M72808R4W024P9P0O7R@202<R:00;02DT:P0S8RP08R4W02<R:00T8bT0:2H/030]=00a;SD09R<Z
02<P9`0U8RT00`0S82L2024N9@0902@Q:00W9B/09RDZ028Q9P0Q82D0;bhc02d[<00T8RL081hS0080
71LM00H07APN01lH7`0X8R`0:B<]065KI@0Q72<201XE70807QTO01407QTM01dH700L5a/071LL020K
8P0I4ad07ALQ01`G7P0M61l05A0G01`G7@0F4AL06aHJ020K7`0H4aL05a8F01XD600201TC5`0G01PB
5P0I4aL06Q@H014;3`19@dL05a4E01D?4`0J51P06aDI01XD600@2P`04P`>01@;3P0J4AD06Q4F024H
7@0G3Q@06Q0H01hG7`0M5Al03@H>020J7P0G4A<00P0E3a401P0D3Q005a4C01H@4P0H4Q@05@lA01/E
5`8050h@01`06PlC01L<400D2@d050T=01L<400J3a<060dA01T>4P0H3A405``@01T>4P0J4A@05a0B
01LA4`0I4aD05@lA02XT9P14?T005@lA018<3P0A2`d04P`>01D?4@0G4A<05@lA01H@4P0G4A<0618D
0P0G4A<08P0C3@l05Q0B01lI6`0L5QP050h@01H@400G5A405aHB01@D4P0I6AX06APM01<D600F5a`0
61TN01LK7P0I7Ah07R8Q024U9P0T9RX082<X020U:P0Q:2h08b`c02Hb>@0]?4<0<Cm803a>E`10DU`0
?e=N04ePK01BI780FVaj06=eP`1XNXP206]mR`0V06UkR@1VN8H0H7:005Y/NP1FJ7H0DFAa04QLI`13
EF40@59M03a=E`0gA4d0;SU202`e?00[<SX09BT`01hQ9P0N7b@081lT01lJ800F4AD05a8F01<>4P0[
9BL0;bT[00D00@0J4A808aXK00h51P0A20P05a4C01H@500D3Pl05Pd>01TA3`0M5A805P`:01D;2@0D
2PT201<72`0401<7300D2@d050X;01@:2`@04`T:01H03`D60147200J41406a4B01@:2`0I3a005P`=
0147200N51D04@L801882@0700004PP901<92P0700006Q0A00`20`0<00008AHE01hD4`0D30X04@X8
0P0:1@801@0@2PL04@T701061@0B1`H05@T900H050H600P06@/;02<E5@0E1`L04@<301D71`0>0000
50H601D71`805PP800@05@L701@61P0C1@D050H60P0E1`L04@0D1PH04`D201P:0@0H2P405`X101D;
0`0C30H04@`901@=4`0h<3l0:b8e01<6800C12D05PHP01@5300F1`X05@H900804`@701L05@H901H7
2P0B0`H050D801P9300F1`X050D802TM7`0W6ad040@600/10P0l<380QGUk01<72@0H30h081@F01L;
3@0B1PP02P0101451`0K3a4060`>01451`020186200C01@82P0A1@L0<BDW01<72@0A1@L04@@70183
200E1P/07PlD00X0000F1``060T>01X;400N3a@06``A01H7300G20d03P<401P<3P0201D92`0301<7
2@0?0`D050P:00H04`L900h05PX<01041P0B1PP04`L902/O8@0H30h04@D7034U9`080000:1`N00d3
100C1`/04PH:01452@8040@800L04@D90104200<00@03@4501<72`0E2@d05PX>00H04@D900h08aLK
00T00@0J3Q805@T=0104200B1PX030040104200B1PX040@801D93@0=0@D040@801862P<04`L;00<0
4@D901862P0B1PX0100B1PX01P0M4AD04`L;00l31`0B1PX04`L;00d11ACooooo000Kooooo`0=01P<
3P0E2@/04PH80186200C1`T040@601H:30080000710B00l31@0E2@/040@601<71`0401@8200801<7
1`0E2@T05`/;01L;2`0F2PX04`L701861P0D20P201<71`0?01@8200E2@T05PX:01D92@0C1`L03P82
00l30`0>0P802`0001@8200C1`L05@T901L;2`0D20P04@D500H050P801h06a0=02PM6@0T6AD050T7
01X?3@0F2`T04`L701041P0C1`T04PH801451`0C20/06@hB01H;3`0B20T03P@500/10P0B20L050X9
01`B400F30X04@L50106100<0P804PH601D92@0D20P04`L701D92@0F2PX201@8200601P<300J3Ph0
60`<01D92@0C1`L050P80P0E2@T02@0D20P05PX:01D92@0C1`L05`/;01`@400K3`l06@d@01L;3`02
01H:3P0601L;3`0H31005`/?01H:3P0E2@d05PX>0P0G2`l03@0L4AL060dC030U:`0X7B<081DK01D:
400G318050T?01H;4@0G31805@X@01H<4P0H3a@00`0F41@201D?4`0a01LA5@0I4aL071HJ01dG6`0K
5AT0618F01H<500H3QH08aTU01D=6P0M5Ah050h@01lK600F50h06aXF010>4@0B3a/07a//02@P;P0N
6bD06QLP01XG7P0I5a`0518E014?4P0O7Al08AlR01hL8@0R82D08b0W02TW<P0H5R<0<Bll02@R;@0M
72H08b<]028R:P0O8BP0:B`c01/N8`0S9b/07B8X01TM9P0T:30092T_01`Q9@0N8bH0:S0`02@Z:P02
02@Y;@0C02H[<@0W:c@0:2`e02H]=@0W;SH0:S4i02dd?00Z<cX0:34h02dh?P0[=S`0;3Lm02hk@@0]
>T00;3To02dj@`0`?DH0;CY302llA@0303A1BP0303U6C`10CEH0?T]D0080=dA=0100=dE@03I4C@0f
A4d0>DQ?03a;DP0nCE@0?4YE041=G@0mBU`0AeAW04]GK`16E6L0?DeL03Q8E@0oCe`0@e=P0P0jBeD2
03i?F@0=03e>EP0kC5@0>DYB03Y:D@0jBDh0@4mD03e<D@0jBDh0@DmB045=D010Bdd0?DQ:03Y4AP02
03U3A00D03]7A`15De<0B5IG03i<CP0mBdh0@4eC041=E017E5`0@e1I045=F00jAU80?4UC03]:D@0n
CE80@E1E03i=DP0kBTl0?DaA03Q7C00jBDh203e<D@0603]:C`0iAd/0?TU;03a8B00kAdP0?DQ:0P0o
Bd/03`0lAdT0>dI8049=C`11C4h0C5MI05MSI013Cdl0AE5?03]7A`0nBD/0?dY>04=>D`12CE<0>TA=
03<mA`0203<mB@1L03M1CP11CEd0?4QH02Lc@`0^>TP0A51M04AAFP0f@d/0=T=803E3A00fA4D0=dE5
03Q6AP0mBDT0?4Q903i:BP10Bdd0?TY;03]7A`11C4h0?4Q902Xf=P0Y=3H0@De>07f8RP0g@4L0<ca4
03DnA@0f?dH0<SXo038j?@0_=3P0=3Tl03Dk>`0d>3T0;C4`02T^:P0/<Bd082DQ02L[:P1]LW80B4e@
030e>00]=CP07bH/01/R:01:DUX0;3Dl03M0A`0e?4@0:c8j028[<P0`>T409c8h041=D`0g@DP0>3m7
03@k@`0h>d@061PR030`>P0V9Bd08b8X04=2B00Z:Bh0<c8g02HV:00/:c0071/P02`[<@0K6R009B@/
01XI8@0W92X0:BL/02HT:@0X9B`09bH/02/Z<@0[:c<09bH^02TY<P0Y;3D09bLa02DT:`0R8BL09bH/
024P9P0K6R008B0V020O9@0S8RP302@S:@0602<R:00U8bT0<2dd030]=00P7B@07a`S0P0N6b8202DR
:@05028O9P0P7B@08AhU024O9@0R8BH00P0P7b@03P0Z:Bh09bDZ02<Q9P0Q7b@06QDK01dH7P0Q7280
8Q/R03Tc?@0W8B/07QPR01lJ8@0N6B0061<J0P0M61h0400M61`071LK01`G6`0L5a`05A0G01XD7P0O
6B<06aHM02PS:P0Q72<07aXP020K8@0N6Ad061<G01LB5P0J5AT201XD600401TC5`0H4QH06A<G01XD
60<05Q0D0P0N61`03`0T7R805A0D01<>4P0W8RH07QPJ01dF600<0`H0>2ld020H7P0J4aX08QdT028L
9`0I4ad08adQ01/E5`0201XD5P0:01PB500J51H05@lA01@>400>20X05Q0B01<=3`0B30h060dA01L<
40805P/?00<05``@01P=4@0E2Ph00P0H3A403P0F2`l060dA01/B5@0Q6A`03`T;01<=3`0D3Q003@L9
00`6200H4Q@050h@014;3@0B30h050h@1`0F4180BP0E3a4050h@01@>400E3a405a4C01PB4P0G4`l0
5a<@01HE4`0O7Al071XO01<B5`0D51T05QLK01PI7@0K71h0828Q02<T9P0U:2`07b8W01dR9`0P9bd0
92dd02Te?00_?TD0<3i703i?F015Ef40@eMR04mRKP1GJGL0GW1n06IhQP1/OX`0Kh6?0722T01]Ohd0
JWb:06EgQ@1OLGl0G6il05MYM`1:GF/0@UAP045CGP0oD5X0=dA=030kA00^=ch0:S4i02D[<@0Q9R`0
7b8W020P9@0K6Ah05A<F01XG6P0B3A40=c<d0<o9b`1=AdT02`H601L>3`0@1`P0610?018<3P0B3100
4`d>01L>3`0I4@l071@A01P>300G3@/05@/:0P0D20`0100D20d050T=01@:2`0C2@X201882@0;0147
200G3@h04`T:01882@0I3a004PP901D;300@1PL02@000107200@1PL00P0A1`P04P0S6AX06@l@00`2
0`0W7Ah030<302@J6`0:00004PL601D;2P0A2@L03`P6010;200?2PL07aPF01L?3@0=0`803`@30186
1PH04`D500L06P`<03PZ:P0D1PH050H601X<300?0@4050H600@05@L700<050H601<51@0D1PH00P0E
1`L0A00D1PH04`D401P90`0H2@805`X201D;0P0C30@04`/801@>400n=3l0;b@d01<57@0B0Ql04`@K
01D6300F1`X05@H901<41`0B0`H050D801P9300@0@@04@8501T:3@0H2@`04`@701@82P0@10H05@T;
028F600K3a405@T;01H:300W6ad0<2@V024E5`0K3a404`L90186200<00804@D701@82P0?0`D040@6
01/?4@0<008050P:0186200C1`T04`H901h?500<00804@@701P93P0]7R<02`0101X;400=00<040<6
00d00`0J2a0060X>01L;3@0D20X04@D700l31@0>0P@05@T;1@0C1`T0300E2@/040@60186200E2@/0
2`0101H:300@10H0200001<72@0H30h03@4301<82@804`L;00X04PH:0104200@10P04@D901lC5`0D
20`03`<701@8300@10P03P861P0@10P01P0?0`L02`0301862P0C1`/04@D901862P804`L;00H04@D9
0104200h;3008aLK0104200A1@T201<72`0301@8300C1`/04PH:00D04PH:00H060`@01<72`0@10P0
4@D901862P0A1@TDooooo`006oooool0300C1`T050P:01041P0B1PP05PX<01451`0F2P`0?S8d0188
2@0E2@/05`/=00h210L04`L700P060`<01dA4@0J3Ph04@D500d10@0H30`05PX:01D92@8050P800d0
5@T901861P0G2`/06@d=01P<300K3`l03`@401D92@0G2`/05PX:01<71`0B1PH04`L700D050P800l0
50T701D:1P0G30P07A8>01<81@0D2@L04`P601@8200B1PP050P:01<72P0B1PT050T:01T?3P0E2`T0
0P0D2PT0500C2@L0;28P01081`0>108050X901L=300E2`/050T801H:2P0L41006@d=01<71`0E2@T0
60`<01<71`0B1PH05PX:01<71`0B1PH050P80P0C1`L00`0E2@T05PX:01@8200201D92@0601@8200F
2PX060`<01P<300H30h05`/?0P0F2Ph01P0G2`l06PhB01H:3P0D20`04`L;01D93@805PX>00d060dC
0146300K41H05@X@01<83P0G318060dC01<83P0I3Q@06PlE01<83P0G3A<060lD00805Q0D0`0E3a<0
<@0G4AD06A<G01/E6@0K5AT06Q@H01PB5P0J41P04PPA01dC7`0J4Ql06A4J01LA4@0L6A@061L?018A
3@0E4aH071TW01TE9`0J5RD07Q/V01`I8P0I5Qd06QPL01dK700P7Ql06QPI01/I700M6b006QPM01XG
7`0@3QX09B<`07MePP0b<3`08B0[01hN:00H62007R0W01PK8@0R9BX08bL[01hS9`0O9B/082H]028X
;P0R:B`08BLZ01hU9@0T:b/00P0T:bh0300U:c409BXc02DZ<`0T:c<09Rde02P_=`0]=Sd0<ca303Do
AP0]>3h0:CDk02Xf?080:cPn00D0:SLm02dj@`0b?dP0<3e603A1BP0403Q5CP0T03i;E00mBU<0=T=<
03I3C00kBE@0>DM@03Q6C`0hAdh0>TU@03]:D@0oCEP0AE9R03m<GP11CV40Ae=[04eKKP15EF@0>DUG
03Y:E`0oCe`0>daF03M8DP0nCeL0@eAL04MHH00mCUD0=DI>03e=DP0kBTl0@4mD049AE@10Ce80@e5D
03i:C00oBT`0?4M80P0i@d@04`0kADH0?d];04]IF@1=Fe`0?de?03e;CP0nBe40>TM>03a9D@0f@Td0
?TYF04=?G00jAU80>DQ?03i=DP13DUL0?DaA03U8C@0lBe000`0kBTl0:00lBe00?TeB041?D`0oBdX0
?d]803i:A`0mBDP0?TY903i:BP0nBD/0>TE7045<C`0lAdX0?TU<049=D@0lB4`0@TiB045=DP18E5T0
A51G03a8C`0lB500=D1903<nA`0b?DH0;SY303e9D`15DUd0?TYE045=E`0a?TP0>DI=03A1A`0hATT0
>4I703Q6AP0iAdL0>dU703a:BP0lAdT203a7BP1:03e8B`0kATT0=d9503a7BP0c?T40;CPk04=>D@0c
?T40=d9403Ho@P0c?3l0=d5403Q1@`0c>c`0<CPi02X_<@0^=3<0;S<a02/_;P0Z;b`0;C<`02hf=00]
=3<09Rd^03m6A`0_=CP0:2la02L]<00W;S40;S@i02`b=`0_=C`0:c4h03m6CP1HHFT0=d1803<mA@0]
>T40;ca3069]M01>Eel0=3]402LZ=00[:cH07alY024P:00V9B/08R4W02HU:@0];Bh07QhM02@T9@0T
92H08B0U02`[<@0R8BT0:RT_02@S9`0X9bX09B@W02@S:00T92X09RH]02@U;@0R92`08bH_020U;P0U
:380:B/c02@S:@0Y:2h08b8X01dL8P0S8RP2024P9P8081lU01/07ahT020O9@0Q7bD0;2T`02h[<P0Q
7RD09R<Z02@Q:00M6R408QlV02<P9`0Q7RD08QlV01lL8`0M6b407ahS01hM8P0P7b@08b8W01lM8P0M
6b006aTN01TD6P0Q72809R4W028K8P0Z92h00P0N62800`0R7B@050lF01`G7P0201`G7@<071LK0100
71LL01`G7P0Q6bD07QPR014<4`0J5A`0;RT`01/F700P6b406aHJ01HA5@0K5QX06A@H01/E6@0J51P0
6A<G0P0H4QH05@0I4aL081XN010:3P0L5QX07QPL01/E6@0F4AD05QDJ01lO900@3a804`lC01LA500H
4A<050d@01TC600I5A`040hG01LF8@0>31@06QDI01XD5P0201lI6`0901LA4`0C3@l04@/=01XD5P0B
30h05Q0B01@>400E3a405P/?00@060dA00P05P/?01@93@0H3A405``@01D:3P0G31006a8E01/D5P80
5Q0B00/04P`>01<=3`0H4Q@07ALI01PB500E3a4050h@01H@4P0G4A<05@lA01<=3`02018<3P804`d?
04L05a4C01XD5P0G4A<06A<E01/E5`0G4A406ADA01@@3@0E4@h08AdN020L800H51T05Q@I01PG700I
6Ad06QXK01`M700N7b007b<W01lT:00S:Bh0:C8g02lh?`0`?4<0<T5802hoA`0nDET0C61Y04QLI`1@
Hfl0F6Yh05maO`1WNHL0KGn=0763T@1cQI<0LH>A06n1S`1[OH/0IGN5069dPP1JKG/0D6Ab04aNJ`15
Ef80?4eG03M5D00f@DX0;cU202P_=`0U:c8092T_020S:@0M7B80928W028P8`0N6ah0510D01/G600Y
92H05a8D01dG5`0=1PL05@h>01L?3P0B30h04P`@01<=3P0D2``04PX801491P0201L=2`0801D;2P0D
20`050P<01@83@0D2@d050X;01<92P0A1`P201061`0N0107200G3@h06a4B03L];P0[8b<060l@01<;
2`0K4Q<0610@01061`0?1@H04@L801D=3@0K4Q<07QDF00X20P0j<3404PP901L;2`0D2@P081HE020H
5P0A2PP03@P500h91P0N5aD05`l=01061@0C20L04@D51P0D1PH01`0B10@09aTI00`0000G2@T05PT9
01D71`0C1@D0100E1`L201<51@0D01@61P0E1`L05@L701@61P0C1@D06@L901L81`0F2@D050X3018;
0P0B2`@04`d:01/A5`0E2a@05PTK01H67P0=0A805PH=01H72P0E1PT201<41`0301@5200L3A006@X=
00804`@700`05PL:01<41`0F2`d0=b/]034U9`0C20T06`lA01<72@0A1@L05`/=01dA4`0A1@L201<7
2@0H01L;3@0D20X05PX<0186200?0`D05@T;01051P0B1PP04PL80186200D20X06Pd@01<42@0H2@h0
5`P=01H9300C1`T06P/@020A5P0E1P/06`dA01P93P0I2`l03`850`0F2P`00`0C1`T03P8401<72@05
0186208040@600d04@D70186200D20X04@H701<72@0E2``040@601@82P0?10D04PL801@8300C1`/0
4PH:00804@D900L04PH:02@H700G2`l04@D901D93@0?0`L03@<500H04PH:00D03`<7024E6@0F2Ph0
60`@01@830020105200501@8300C1`/05`/?02lS9`0R5QX00P0B1PX301452@030104200B1PX04PH:
00D04PH:00D04`L;01862P0A1@T04PH:01D93@0Dooooo`006oooool0300C1`T05`/=0186200E2@/0
7A4C01L;3@0M4A<0A3Pj00T0000O4aD02@0001L;3@8050P80P0C1`L201@8200501L;2`0C1`L03`<3
00l30`0B1PH00`0C1`L0400D20P05PX:01P<300I3@d060`<01H:2P0C1`L02P0001T=3@0?0`<05@T9
01H:2P0E2@T04`L701861P0C1`L501@8200Y01@91`0C20@04`P401P=2@0D2@D05P/901871@0D20P0
50P:01L;3@0F2Ph04`L;01L<300L4`h05@`701D;2@0H3P`05`d;040f=@0P5QD050X901H<300I3a00
200001P=3@0I3@d0710@01X>3P0E2@T050P801T=3@0D20P04@D501L;2`0D20P05PX:01/?3`0F2PX0
4`L701@8200G2`/00`0E2@T201@8200301<71`0D20P04`L800804PH:00/04`L;01@8300F2Ph05@T=
01L;3`0I3A405PX>01@8300E2@d05``B01D:400201/@5P0;01T>500P5A/05``B01P=4`0M4QP06PlE
01D:400G3A<05@`A01<=4@0D3Q800P0E3a<0=@0F41@06A<G01PB5P0F41@05@lC01H@500I4QP07aDN
01<9500D2AL05@dJ01H?5P0F410040d602XX800H5a<04a4D01TF900J5BT06ADT01lK:00M6R<05a@K
01LE600N71d07A`J01`K6P0X9RL0928W01/I7`0[:340;2Xg01XH9P0[:CH081h[02PW<`0a<C/09BD]
024S:@0O8RL092L/018F6P0V:bl07B@Z02Xa>00Z<CL08BT/01hV:00U;Rd08R/Z02<[;P0T;2l092/a
00808bXb00L0:S4i02L^=P0U;3@09c0g02hi?`0c?T@0;cY00080:SLm04H0;CY002ll@P0_?480;S]4
03A1BP0c@4T0=T=<03Y7D00iATl0>TM@03M4C@0iATl0=dA=03I3C00iATl0=D=>03E3C00fA4d0>TU@
03i=E00oCUD0@4iI04=@H013D680@e1S04A@J010CV40>d]J03e=G00oCed0?TiK03a=E`0jBe@0?TmG
04aMI01AHVT0?DiE03Y<D01;G600BEQM045@E@0mC500@E1C04IDE@11CDl0@4]=03a8B00iA4D0>dE6
03i8B@0nBTX0?D];03m=CP0kBD/0>DM:03i;D@16De/0?daE04MCG`0hA540@4aJ04UEI00iB4l0?DaA
041?E00lBe00>TU>03a;D00mC540>dY?0P0iB4d01@0mC540A5=F03a8A00mBT<0?DU40080>TI201X0
?DU803]6B00g@T@0A4mC045<D010Be40@TaD041=E@13D5P0?DYB04EBFP14DET0?daD03]8D00hADd0
=45902`i@@0Z=cl0=D9:04]HH00`?D<0=T=9030m@`1AGf40LX2003U7A`80>4I604`0>4M403Y9AP0j
B4P0>dI803Y5B@0kATX0?4M;03Y5B@0e@4@0<ci203i9C@0iA4P0CEQL03I1A@16DE<0=Cln034l>00c
?SX0<c`i02`c<@0Y;bd09bd[02H[:@0S9bH08bPT02T^:P0^=3808b/]028/;@0W;c40>T9403Q0@P0`
>3X0;34d02H[;P0Y;S408bLZ03Hi?P0b=CX0?4=<05eVK`0Z<c`07RPa045>EP0_?4@0>D=<045:D`0W
<3T082@_02<S;`0];CL08R0Z02@S:@0`;c@0=CDf01lO7@0];B/09BDS02`/;00A4A<0;2/a02d/=00Q
82H08R4U02PX:P0S92H08B8V02<T:@17BU00C55G02lc?00Z<CT0;3<k02D/=P0S9Bh08B0V0P0V9B/0
300U92X0:2L]02@S:@0U92X08R4W01lN900N7B<07ahT01/I800J5ah06aPO01XG7P807Q/R00L07AXQ
02<P9`0S82L081dT02LT:`0U8RT07A/Q00807A`Q00l07QdR01`K800I5a`05Q@I01@B5`0I51X08QdS
02@O9@0P6B006aDO010:500T7RP081/R01HA600Q72<00P0K5Q`04`0K5QX071LK01`G6`0L5a`05a8I
01TC7@0Q6bD09B0W03@_=P1PFf805Q4G01TD6P0H4aL06A@H01hI7@0G4QH071HJ01/E6@0J51P00`0H
4QH05@0C3A406aDI01LA5@0G4AD06aDI018=4`0:2a0051LL01@E6@0P82805a@F01TC5@0D3Q003``?
00d<4P0=3AD0F5]U03@d?P0O6R005Q0B01<=3`0201@>400901PB500J51H081XL00d72@0?2@/04`d?
01H@4P0F2`l05``@008060dA00@05``@01H;3`0I3Q8060dA0P0G31000`0H3A405`hA01D>4002010:
300c018<3P0@2P`03PP:018<3P0A2`d04P`>01D?4@0I4aD06Q@F014;3@0B30h04`d?01LA4`0K5AL0
7ALI01D?4@0B30h04@/=01<=3`0F4180618B024L5`0I510050l<01XD5@0J51P04`hB01dH7P0P6b40
7Q`O01dK700M71X07AdM01/O8`0O92P09B/`02Pa=P0Y=3X0:cPo0393BP0a@TX0?U5I04mSK019GfX0
DVIb05e_O@1SMH<0JWb:0763T@1eQiD0N8ZH0080MhVG02@0M8JD06anS01WNHL0GW5o05Q^N`1HJgT0
BUeZ03]=F@0kBE@0>DE@030j@`0Y<ST09bdd02DZ<00P8bX07QlU02d[<00T8RD05Q@G01XH6`0A3@h0
4`l@010<3@0=1`L04@/;01lI6@0D30/04P`>018<400C3@h05@`=01D=2`0D30T05P`:01D;2@0D2PT2
01<72`0401<7300D2@d04`X;01892P804@P901l040L800l61`0A20T0>C0a0<k5aP3Id=40@3Lh04Po
@02LTi@091/L01L>3`0I41403PH703Xa<P2IT9405@`=01XA4P0@20T02`8301451@0@1@D07aDD02<K
6@0I4a005A0=00`7100@2PL04`/901<9200B1`H03`<300H05@L700L05PP801D71`0>00006`d=0186
1P0F20P04`D500@050H60P0C1@D04P0D1PH05@L701D71`0D1PH050@701P43@0F1@/05@L701@80`0B
2@004@X001L@200=1@<040L:01454@0A0QD05PPG01@52P805@H900L04`@701@5200E1PT07a0C02@E
600I2Pd04P<600805`P;00H07a<E02dQ8`0X71h04PH801H:3008000201X>4004028F600M4A<06`lA
01P<3P80200001L03`<501041P0D20X05`/=00P0000E2@/04PH800d10`0B1PP050H:01H7300T5AX0
6`hA08enP`17>3d0:1TN0=C5bP0P4AH07A0C01L83@0:000070hB01H:300200l31@030186200@10H0
5@T;00D04@D700`040@601T=3`0B1PP02`0101/?4@0C1`T03P8402dQ8`0C1`T040@601451`0F2P`2
01@8300501<72`0B1PX04PH:01862P0@10P00P0>0PH00`0@10P04@D901452@0601@8300>00h21P0M
4AD050P<01L;3`0B1PX03`@701452@0G2`l04`L;01862P0>10H040@801<72`0B1PX3010420030145
2@0B1PX04PH:00@04PH:00H03`<701862P0B1PX04@D901862P0D20`Dooooo`006oooool03P0C1`T0
60`>01451`0C1`T0710B01@82P0M4A<02@0001T=3`0C1`T04@L801hB500F2PX05@T90P0C1`L0200E
2@T05PX:01L;2`0E2@T04PH601<71`0E2@T05`/;0P0B1PH03@0C1`L05@T901L;2`0H30`040@401dA
4@0R5QH0710@03/_;`0b9RH04`L701451@0@10@00`0A1@D501@8200J01@91`0D2@@05P/701L<200D
2@D06@h<0146100D20P050P:01P<3P0F2Ph04`L;01H<2P0L4``05Pd601L>2@0I40/05@/901/A4007
000050X;01X@4P0Z7b<040D901hC4`0E2@T201L;2`0?01H:2P0E2@T0710@01P<300C1`L060`<01@8
200G2`/07a@C01T>300C20H050T701L<2P0F2`T050T700805@X80P0D2@L0100F2`T050P901862P0D
20`301D93@0:01H:3P0L41@081@H01T=4@0D20`05`/?01873@0>0`T05@X@01873@805@X@04@060dC
01lD6P0Q5Q`06PlE01T>500H3Q@05@`A01<=4@0E3a<05Q0D01LA5@0I4aL06aDI01XD600I4aL0618F
01TC5`0K51X081HO01/A700I3Q`050`G01LA5`0K5AD061D>02TW7`0J6AD06ALJ01HB8@0M62h07QX[
01`I9@0J5b006QLN01XH6`0J61T06APF01dK6`0J61T0518G01LD6P0S82/061HS01PF900F52809B<`
02DT;`0I6B<08R8Z01DG7@0O8RL05QXM02lc=P0T:Bd08BP^02L^=@0U;3807bLZ020X:P0Y<S407RLV
020X:`0Q:B`08RT_024X<00P9bl0:34h02L`=`809Bhe00<0:SDk02hi?`0b?D<00P0/>Cl02@0a?T@0
<T5603=2A`0`?DH0=T=<03A1BP0e@T/0=dA=03E2B`0203Q5CP0d03U6C`0d@DX0=45:03Y7D00b@4/0
<d5:03E3C00iB4l0?TeD041?EP10CUT0?DYJ04AAHP17E6L0@dmW03Y8F`0iBEP0?TiM045AG`0oCe`0
?e1J03m@F@0eATh0@U=J04AEF`0dATX0>D]?049CEP10Ce80?Te@03a;CP11D5<0BUQI04IBE013CU00
?d];03e8B00oBDX0@de<03e9B00kBDT0AE=C03m=C`0`?T40@4eC04]HH00lBE80IG5m03m;F012CUh0
K7R703]:D@@0?4]@0P0mC540500kBTl0>DQ=03Q7C00jBDh0?Te@03Y7@00kB3l0?4U103U6?`0iAD40
?DU803e8BP0g@T@0@diB049=D`11Be@0AU1I04=@F@14DEX0>dQB0P14DEX03`11CUL0?DYB03m<E00h
ADd0;3To02dj@00b?dD0>DI<03I4A`0lBT/0=dE603e;B`10Cd`0>TU603U8A@0303Q7A01H03U7A`0j
ADT0>DA:03]6C00lAdd0>dI<03I1A`0e@4H0;cY0041;D@1iQ8X0CEQN028];`0d?c/0;cPc030i=00_
>3<0:30[02L]:@0T:RH08BLS020U8@0S:2@0:RdZ02/_;P0I8b@0<C`n02/e=`0N:2X06R8U02de>00]
<SD0=3Pi03Hj>`0e=SP0<C8f02/^<`0c>d<0=d1901lX<@0iADd0P8fE06=`N00`>d@0;cQ1034j@`0X
;3L06QXV02DU;`0V92h08R4W02d/<@0P82407alM01/L5`0P8Ad06a/K01hN8015A4T0SXfE03dl@P0U
92P0:R/]02HW:@0R92P08bH[02hc>00U;3806b8Z02`e?@0_>44092df028V;P0P7bD092<Y02TX;P0Z
:Bl0:BP^02<R:00U92X08b8X020O9@0M728071/Q020N900P7B@07a`S02@Q:0808AhU00L08QlV02@Q
:00S82L07a`S02LT:`0U8RT07A/Q00<071/P00T061LL01HD6@0F51T05aDJ01XE6`0N6Al081/Q020I
800N62800P0J51h00`0Q72<07QTP01lJ8@0201XE6`806aHJ00/071LK01`G700O6R407QPR01/E7`0C
3QD07QTP02TT:`0H4aT06aHL01`G6`0301XE6@0901`F6P0K5AT06Q@H01PB5P0G4AD0618F018<400I
4aL05a4E00806aDI00l05Q@I01@G700L82@0BDY>024Q8`0;20X08alN01/G600G51L07A`R02l_=`3;
c]@0Y:N`024O900I4aD00P0D3Q001@0F418071HH01PB500M5aT04P`>00806aDG00<040X<01L<400G
3100100G31000`0N4aL060dA01H;3`0201T>4P0;01@;3P0H41<030H800X41P0C3@l0618D01H@4P0@
2P`04@/=01<=3`0F41800P0G4A<01P0D3Q004`d?01@>400G4A<06aDG01dG6@804`d?04P06aDG01PB
500C3@l05a4A020H500M5A806A4?01TB4`0G4AD04P`@01XD6`0N6Ad07aXN01lK700O6aX07AdM01/O
8`0N8bL08bT^02D^<`0V<CL0:CHm03A5C00eATh0@5=K051TK@1<HVd0EFUf05maO`1UMhD0K7j<07>5
T`1hRYP0O8jL07j@WP20TZ00OHnM07B6U01/OX`0H7>105Q^N`1EJ7H0BE]X03]=F@0iAe80=d=>038l
A@0^=ch0:c0i02HZ<`0P9B/07b0V02DT:@0K6ad05QDG01TG6P0H51D07ATJ02LS900K5AD03`T900L1
0@0J5A<04P`>018<400B30d05@`=01H>300F3P/060h<01L=2`0E2`X201@8300401@83@0D2@d04`X;
01<:2`<04PT:01h04`X;01H=3P0e;2d0iMcM0?olo@1=A4D071<D05=:B`0=1@D01`0001hE5P0E30d0
6a8C03Xa<P0<0`@01P0000l8200M51D04`L700l51@0@1PD04`/901PB3`0K5Q<061<@01D>300L5180
6@l>00d20P0@10@601@61P0801H8200H2PX06P`<01X<300D1PH05PP80184100C1@D201@61P0401<5
1@0B10@04`D501@61P805@L700l050H601@41`0H11005PD=01D62@0D20@04PT0014;000F40H02@40
01XA4P0I3AH03P0?01L95P0B0`P00`0D1@P03P0E1PT05`P;01X;3P0P4A@05PL:01D62@0H2@`050D8
00/00@0D20X04`L900`20`0O4aD091PJ0P0@10H0500H30h05@T;01D92`0H30h0200001H:300J3Q00
3@4301L;3@0@1PL02@0001P<3P0@10H04`L900d10`0I2`l03002028C600D1@X09QLL0P0:0000300k
;3402P0001H:300E1P/0:1TN0185200G2`d03P840186200G2`d04`L901@82PH04@D700h06@d?0186
200<00805`/=01451`0C1`T0QGUk02DI6`0800007Q8D028H6@0E2@d050P<01<72`804PH:00L04`L;
00d11@0F2Ph050P<00d11@0A1@T03P<600H04`L;00`03`<701@8300C1`/05`/?01862P0A1@T06`lC
01X>4P0A1@T03@4501D93@0N4QH201862P0401452@0B1PX05@T=01L;3`H04PH:0P0@10P0100A1@T0
4PH:01862P0A1@TDooooo`006oooool0NP0A1PL05@/;00h30`0?10@05P/=0187200E2@/05`/=0104
1P0D1`X070hB01851`0E2@/05@T:01`@4@0?10@0;20Q038V9`0?0`@06@d>01dA4P0G2``06@d>00h2
0`0F2PX04@D501<71`0E2@T03P@401D92@0H30`0HUIF07a`L00V6QX06`l?01451@0F2P/05@T:01H:
2`0B1PL06@d>01@82@0C1`P03`@401T=3P0C20P04PH701L;2`0E2PP040H401<81@0E2@P05`/:02`Q
800D20P050P901/?400D20T04PH901<81`0D2PH04`T501@:1P0D2@P040D401<81`0D2@P07A8C01@9
2P0L4A8030<401/@400D20L04`L701D92@0F2PX050P901T=3P0H30d07Q8C01<82@0I3@h04PH901dA
4P0G30/04`L801H:2P0F2PT05@T:01P<300G2`X05@T:01H:2P0D2@P05`/<01T=400E2@h06@dC01P<
500L4AH05PX@01P<4`0K3a@07Q<I01/?5`0H31405`/B01/A5`0D31407A@I00h42P0E3A80610E01<9
3P0N5Q/06A0E01T?500F3Q<05PdB01@>4P0F41@05a4E0P0F41@00`0I4aL05a4E01PB5P0201LA5@0c
01TC5`0G4AD050dE01LA600K4a`05a4H02<M8P0b;Bd06QHD01/H5P0H5AD07AXM01PD7@0G4al081`V
01XF7`0H51`06aLM01/I7@0H5QP05aDG01/J6`0M6al07Q`Q02@R:00G51`07AXS020N:00M6R@07Q`V
020O:00O7bP0824Z020S:`0F6R807B4Y07b1R00O92`08RH_020T;@0N92/08bL^02L/<@0S:Bd09R/`
02HZ<00T:C408BH^02`_>00U:c<09B`d0080:30h01T0:C4h02/c>P0[=C`0;CHm02`f?@0[=C/0;CLn
034l@P0b?D<0=3e603E0B@0d?dP0=dA=03Q5CP0c@4T0=TA=03Q5CP0jAdh0>4A:03Q2B00iA4X0=45:
03I3CP0f@dd0?T]F0080?DYE04h0?T]G03]8F011CUh0@dmQ03m:GP0mBe/0@4mK049AG`11D5`0?TeH
04=BG@1:FV80>4Q@03M7CP0kBe40>T]?03i>D`0mCE40@4iB045?E00oCE40?D]?041=DP0oC4l0>dM:
03M3AP0hADL0?DY<045<CP11CU00>DM:03Q5B@0kBDd0>4E<03a9D011CUH0A55J06]hP@1=FF@0>4A@
04AAG00nBe80?D]?03i;C`0oBe00?Ta@03e:C`13Ce@0A59F041=D@0kAd`0>dU=03a9C00jBDD0?4Y3
03a:A@0iAd<0>TM503e:BP0oC4d0>dM903i:CP0lBDd0?TY?049?EP0oCEH0?TeH03m=F015DU`0@E1J
04UGH@0lBU@0@E5H03a;E00_?DD0;cm603A2B@0jB4h203M6BP1S03e;CP11Ce80>dU<03m=D00mBdh0
>TQ;03Q7B@0hATT0>4I803Q3A`0iA4P0>TE803Y4BP0jADT0>DA703M1AP0i@TL0;3Di03U1A`0b>Sl0
?4A703Ln?@0/<c00:c8_02ld<@0[<2l0:2d[02X_;`0N8R40:Bd[024U9@0[;bh0:Rh]02`c<`0W<C40
72DW02Xb=@0T:bl0:2lc02`a=P0_=3P0;30e034e>00[;C80;30e03<j@`0e>dD0:C4j02`e?@1:De/0
=3e502/d>`0P:300:2he02``>01LH6L0;Rlh02LY<@0U9bh0>3Xo02<V:00T9bH07B0O028U8`0V:BP0
9bXY024T9@1ZKFl09RT/02DW;00T9R`09RP]02@W;@0U:2h082@[01dP:`0Q9Bl0:Rdh02LZ=P0T9c<0
9bLb020N:00P7bP0:2L`02d/<`0Y:2l081lU01lN900N7B<081lU01lN8P0K6Ql071XO01`J800J5ad0
7A/Q01lL8`0N6b8081dT00808AhU04d081dT024N900N728071XO020N8`0Q82D08R0U01lM8P0L6Ql0
6QPM01TG700J5Q`07ATO01lK8@0N6R007APO02@N9`0F41T071LN01/F7@0G4QT09B0V02@O9P0N6Al0
61<J01XE6P0M61h06A<K01XD7@0K51d0618I020J8P0J51/06A<J01XD6`0L5Qd06A<J01H@5P0J51X0
6a<K01TA5`0K4AT06a0I01L?5@0K4AT06@hG01L?5@0I41L0714J01L=5@0I4AT06QLP05UHG`3Sh>D0
OW^001`J6`0H5A@0514A01PH6@0D5AT03a8H07EhP@1@DUX0618I01T@500I4AD06@lD01L>4P0F3a80
5`dA01/C5P0M5QT0:AlT02@K7`0C2@d060dB01L<4@0201H;400F01P=4P0I3Q<0714F01T>4`0F2a00
5``A01P=4P0F2a005PdA01@:3`0K51L060lC01L=4P0C30l05PdA01dC5`0D3A005`lB01D;3`0B2Pd0
61<B01H@3`805@l@07@04`h@018=3`0E3a<0618H01PD6@0/:2l061@K01`H700I4Q<05Pl@01PB500H
4A@071HK018=4P0H4QP06QDJ01/F6`0L61/07APK01/I7@0N82H07B4W02<X;P0R:S40:34i02`h@00`
?TL0=4A=03e?FP18FfH0C5m[05AXM01QLh40J7Z806alS01fQIH0P8fO08RDY`2>VZh0U:2b096N[`21
Sil0MhFE06YlRP1NL7l0EVQi04eNK@10DUl0>T]H03I5D00c?dP0;cY302/d?00V;3D08RH`01hP9`0N
7B<071/P01dK8@0G51T06A@I01H@5@0K5QP05@hA02LO8`0J41<060hA01L=400D31006@lC01X@4P0F
3@`05@`<01D;2`0F30`05`d>01D93@0D2@d05PX?01@93@0B20/04`T<01@:3@0C2@/050X<01882P0I
3a8050X=07E[KP2>Q8H09adP01XA4P0>1PL06a4B01882@0D2P/04@H801872@0[82405@`=01<82@0B
1`T05@X;00h20`0C1PL04`P801@92@0D2PX03`D501<92@0B1`P06Pl?01P=3@0A10D05`T;01L:2P80
4`H600T04@@401851@0M4100304101H92@0G2PX040<301D92@0C1PH00P0B1@D201<61P804PD51@0C
1PH0A00C1PP05`TA01<63P0I31407aHE02DN6@0A2PD0610;00d61P0G3Q007A<I01@8400B1Ph040<9
01<52`0D1`X05@P<01L93@0H2Ph04`H901X<3`0B10L05PP;01P:300@10H04PP900l31P0B1PT050P;
0145200>10H04PH901<52@0F2@`05PP<01/>4@0D20/06@dC04Tl@P0i;C802P0201H:3`0A1PP04@D7
01P<3P0B1PP060`=00h30`0C1`T03P0501H83@0@10L04P@901D8300H2Pl04`P:01/=4P0C1`X060X?
00l41P0F2Pd060`>00h41@0I3@l05@X;01L;3@0B1PP04@D70P0B1PP03P0A1@L04PH80186200A1@P0
5@X=00l31P0A1@P04PH901H:3@0S5aX04PH901<72P0@10L04PL:100C1`/201862P0Z00`2100F2Ph0
5PX>0104200D20`04PH:01<72`0@10P04`L;0104200A1@T04`L;01@8300C1`/040H801P<400G2`l0
50P<01D93P0C1``04PP=01863P0F2a40304601<73`0C1`h03P<701D9400G2a805PX?01853@0B1@`0
4@@:0144300D1`h05@P>01H94@0B1``04PH;00h32@0I3A<03P875?ooool001_ooooo00T03@D301@<
2P0H40h0718A0188200E2``04`L901D82P0F1`X00`0F1``201<72@0G01lC5@0>0P@0=2PZ03<W:@0N
4Q@02@0001D92`0B1`P0300201H:300A1@D05PX:01hB4P0?10@07a<C01@8200Y7Ad0flo?0?kblP17
>c/04PH601/?3`0P51H00P0C1`T05@0;00406@d?00`00P0B1PP07A4C00l31@0J3Q00=BT[01041P0B
20P081@D01H:2P0=0@40BShn0:fQX@0P51@03P8200/0000C1`L050P801P<300201D92@0301@8200C
1`L04`L700805`/;0P0D20P0>P0?0`<02@0001D9200G30X05`/;01H:2P0D20P05@T;01dA4`080000
3`<701T?4@0C1`/0300401D9300C1`T04PH801L;3@0D20X04`L901L;3@0C1`T050P:01X>400F2P`0
5@T;01D:3`0@1@d060dE01@94@0M4QX05@XB01L<500F2a<05``D01P=5@0I3QH05P`D01H=4P0H4QH0
5Q0D00h8300L5QX05a4E01<=4@0I4aL04P`@01@>4P0B310050hB01D?4`0G4AD0618F01@>4P0C3A40
5Q0D01LA5@0I4aL201LA5@0@01/E6@0H4QH06A@H01PC5`0F4AD05A0D01/F6P0Q72006QDI01D@500F
4AD06QDI01dH700J5AT081TP01hH7P806aHL02P071PN01/I7P0/:Rl08AlT01`K800F5AX07A`Q01TH
7@0J61d0920V01dK800K6R006aXQ02h^=P0W:S<08RH`01PL9`0B5R808BHb02<W<P0T9S80:B`e02@W
<00R9Bh09BPa02@W<00[;SL09BPa02P[=00V:C80<SDn02HZ<`0X;SH09B`d028Y<@0U;3@0:c8j02he
?@0/<c/0<CQ00P0^=Cd0>00c>T80=3]302hf?P0a>d@0<Sa503E2B`0hATl0=TA=0391B@0a?TH0<d54
03Q3AP0g@D80=3i003Y5CP0d@4`0=T9>03m;E`18E680G6Qf03e9E`0g@e<0>DEE03a8F00kAUP0>4ED
03a:E@17EF00CE]V041>F@0jB540?DaD03a;DP0hAdh0?4]A041?E00oCU<0?4Y@03i;D@10CE<0@e1F
049?E@11CU@0@4eC03a9C`0gA4X0=T=903]8CP0lBDl0?daC03a9D@0jAdl0>DI>03E2BP0hADd0>dQ@
0P0iATh0;@0kB500?4UA03e:D@0oBU00?dY>041;C`0oBTh0?DQ<03a7B`10Bdl0@TeA03i9C@0g@TH0
>DA803]6B@0oCDd0?Da903a:BP0kBDT0?4Y:03m=CP14DU<0?de>049@D`16E5L0@U1C04ABEP0kBE80
=dQB03a=E`0kC5H0=dQB04UJI02EY[00EVMa02dnB00mCUP0>T]E051QJP10CUL0>4M>03e<D`13DUT0
?TeD03a;DP0203Y9D00d03Q7CP0fAD`0=4=:0391AP0g@TH0>DA603M2A00e?d40=3i003Do@@0h@4<0
>D54034i?00b=c/0=3Tm02db=@0]<C@0:Bd^02hb<`0`=3D0;30a02T];P0e>CX0:bl`03e1@P0M8B80
7b<T038f=`0U:bT0:S0_02/a<@0^<cL0:Rhg028V;`0Y;CH0=c]403/oB00n@dP0<3Di02P]<`0b=T00
<SI102/_>P0_<c`0<CDn02T]=P0U:S007B8X020U:`0Z;c<0:2da028W:`809BX`01H08bP^02P]<@0W
;2l082DX024W9`0F71`06R0N01lU8P0P9R@09R`/02hc>P0S9Rl09BPa02<V;`0Z:S@092@_028R;P0T
8Rl0:BLe02/Y=`0W9C<08b4_0P0R82d08@0R82`08R0[020O9`0O7RD06QTO01DD6@0H61/07AdO01`L
7P0L6ah07adP01hL8@0O7280:2D/02LT:`0P7B@06aPO01`I800Q7bD071XO01XH6`0M6al07adR01hL
8@0K6Ah07adR024O900K6Ah05A<H01LE6P0K6Ah07Q`Q01dK800201TD6`0602<N9@0F4AP09b8Y01dH
7`0@2a805Q4H0P0K5Qd0100M61l06A@K01TB6P0J4a/201/D70<06Q<K00D06a@L01dF7P0M5Qh071DM
01/D700201/?6@0701X>600H31H05`/E01H:500I3AL06`lI01dA6`0201X>600@01`B6`0T6RD07aLR
05aEG014?dD07AXL01LF500E5A<03`l@01@E5`0H6Ah06QdT04i=E@0N5ah07Q<I01/@5P<06PlE00<0
7A8H01/@5P0H3A<00P0G318201H;4@1C01D:400D2@l050T?01H;4@0G318050T?01<83P0D2@l060dC
01/@5P0J3aD04@H<02XO9@0:00D04@L<01/@5P0C20h03`@:01D:400F2a406@hD01P=4`0U6Qh050d:
01<>2`0D3``05Q0@01<?400A3@h04@`B01`I800F4a`0;bdh0:bZ]@0h=Ch05Q4G01<>500N6Al06aHL
028M8`0G4QP061<I01TD6P0J5A/071LM01hI7`0M6b006a/S01XM900U:C409B`d02lf@00g@DX0<Sm8
03I4D@0mCEX0@59N04UKJ@1DIg<0HWB006alR`1cOi80PhjR09>K/P2NYKd0YJ_50:R^aP2QZ;d0RiJX
082;W@1bP980HW6405UZO01?H740@E9R03]=F`0hBED0<D9<02hkA00[=3h09B`f02<W<P0N82P00P0N
7BD09@0L6R8061DL01PC6@0E3QD071DL01L>500P5A/06@hD01/>5@0I3Q805``@01`A5@0O51P060dA
01H;3`0A1PX04PL;01@93@0E2Ph050T=01462P0F2`l04PL;01D:3P0I3Q805P/?01D:3P0@1@T06@hB
01062@0P5AT08AHJ01892`0I3@l04`L901P<3P0J3Q000P0A1@L01`0@10H060`>01dA4`0J3Q004`L9
00d10`0B0`H00P0F1`X301D62@0B01<41`0D1@P05@H901D62@0D1@P04`@701861P0A1@D06Ph>01/?
3`0M4A40;b<S00l30`0E2@T04PH600l30`0@10@03P821P0B1PH00`0C1`L04PH601451@0201861P0J
01881`0>1PP04@P;00L00@29P8<0[:>V01XA500B2@`04@P;00h5200I41<06a8E01482`0?0P/03P48
00d01`0>0@P05@T=01T=4@0@10P05PX<00h2100F2P`060`<01881`0A1`X201072P<04@H:00<04@D9
01@52P0F1``00P0H2@h01`0E1`l05PTC028E7P0L3aL040<:01D83`0C1`/00P0A1@L08@0A1@H04@D5
0146100H30d06@dA01@8300A1@T04PH:01452@0@10P03P8600/00`0@10P06@dA01L;3`0A1@P05@T;
00d10`0B1PP03@4301451`0>0`@04`L901@82P0A1@L03@4300h2100A1@P06@dA00h41P0<00@05`/?
01472@0901862P0<01452@0@10P040@800P0000:00803`<701@8300E2@d050P<00d11@0<00@050P<
0P0B1PX07`0A1@T03@4501D93@0C1`/060`@01H:3P0@10P04`P@00h32`0C210040D=00L0100@1@d0
4PL?00`22@0X7BD06PlG00d42P0F2a<04PD>01443@0?0P/040<<01<63`0F2A804@@=01L:4`0=00T0
5@PA01H94P0;00L05?ooool001_ooooo02D04`/901081P0?1`D06@l>00d51@0J41404`L901<6200E
1PT05PL:01P93@0I2Pl040@600l31@0C1`T03`<501hB500C1`T04PH801`@4P0F2P`04PH801451`0V
6Q`06@d=01451@0:00004PH601X>3P0:00009a/K06QLG01lL700:alO01451@0=0@40:AdO00804PH8
01D050P:02@H6P0C1`T05`/=02HJ700A1@L02`4201`@4P08000060`<00l30`0>0P804PH600P0000M
4A404PH600h20P0900009ATI00h20P0?1@D00P0E2@T00`0D20P04`L701<71`0201@8200:01<71`0F
2PX04`L701<71`0D2@P05@X801H:2P0C1`L040@401<72@804@D700D0710D024E6@0K3a<09QXN0146
200201@82P0401L;3@0D20X050P:01T=3`8060`>00`06Ph@01@82P0B1PP04@D:00l42P0H3A<04`P>
01/@5P0G31805@X@01H;4@0G318201H;4@0L01T?500H3a@02`D901PB5P1hLWH0SHN;01@>4P0E3a<0
4P`@01<=4@0?2@d04`dA01/E6@0D3Q805Q0D01PB5P0F41@05@lC01LA5@0F41@0618F01LA5@0H4QH0
71HJ01TC5`0I51P05a8F01HA5@8061<G03<04`hB03<^<P0K5QX061<G01dH700I51P05a8F01dF7@0N
61h07APN01hI7`0N6R007A/P01/I7P0D4QL05QDJ018A5P0K6Ql07A`Q01TG700Q7R@081dT02@S:@0K
6R4061PP018E7P0R9Bl08bDa02X^>@0O8bl0;c<n02d_>`0/;cP08RD^01hQ:P0S9Rl092L`02LZ<`0P
8b`09bXc02/^=`0]<3T08RH_02D[<`0X;cL0:c8j02`c>`0[<SX0:S4i02`c>`0b>D400P0_=Sh0=@0c
>T80=3]3038k@P0g@DX0<ce6030mAP0a?dX0;Ci80351B@0a?TH0<T1303M2A@0i@d@0=d9403a9DP0c
@D`0=dE@03Q6D@16E640JGN4049@G@0gA5@0>TMG03m<G00nBe`0?DYI03e;EP10CUT0AUAO041>F@0l
BU<0>DM?03U8C`0kBU40?4]A03]:C`0nCE80?4Y@03U6C00mBU00@DiD049?E@11CU@0@4eC03e:D00j
Add0=dA:03Q5B`0mBU00@DiE03U6CP0jAdl0@DiF0080=dA<00L0?T]C03U6CP0hADd0>4E=03Y7C`0m
BU40?T]A0080?Ta?00/0?D]>03a:C@0kBD`0?4Y=03Y8B`0kBD`0>DM:03M5B00mBdd0>dU903Y8B002
03Q6AP0L03Y8B00nC4d0@Dm@03]9BP11Ce80AU=I03m<DP0lBU40?TaE03Y;E@0oD5X0?DiH03M8DP13
E5h0bM[T07J7T@0jBeD0AeQR03E6D00^?dP0?deF03Y9D00kBU40>TU@03Q7CP0iB4l0=dI=03Q7CP80
=dI=01D0=DA;03=2A`0f@DD0=d9403E0@P0c?Cl0<S`n03<m?`0f?T40>D5403<k?P0a=SX0;c@h02/`
<`0Y;C00;30a038f=`0`=3D0:bl`030d=@0R9RL00P0T:2T0:@0L8240=3Pi02HZ:`0T:RP0:S0_02hd
=00`=CT0:Rhg02<W<00_<c`0=CU2034e?P0g?480<cPl02db>00^<C/0=CM3030b?P0_<S/0;C0i02LZ
<`0M82L07R4X028U;00X:c009BP]020S:00U:2d08bH[02@W;00[;S<0:Rha02<W:P0/<380<SHg01lS
900N8R80720Q02P/;`0N8RX06ahW00808RD^00@0;2`f02LW<P0S8bl09B<`0P0X9S<0:`0U8c008R0]
02DS<00W9C008AlZ01/I900O7RH09bH]02@S:@0M72406aXN01hN800O7b407A`P01/I7P0I5a`06aTN
028P9@0Q7RD07AXQ01/H7`0M6b0081hS01`J7`0J61d07A/P01hL8@0K6Ah05Q@I01`J7`0P7R<06aTN
01LE6P0J61d06aTN01`J7`0O7B809b8Y01@?5P0P6b8091lV04]6C@0M61l00P0P6b80100J5A`05A0G
01TD6`0I51/201XC6`<06a@L00<06Q<K01TB6P0I4QX00P0K51`0100J4a/06A8J01/@600N4a/201/@
6005020E7@0H3AD06@hF01/@600L4AT00P0J3aL06@0K4AX05P`G01L?6P0C31<07QTO01@A4`0I5aP0
4Q8B01@D5@0>3a405QLL04=4B`3PgnL091dT01hC6@0H3A<06@hD01X?5@0G31809AXP024F700J3aD0
5``B01T>500L4AL00P0F2a4201@93`0>01D:400F2a405P/A01<83P0F2a406a0F01dB600H3A<081DK
01<83P0U6R0081DK00L00P0I3Q@201lD6P1B01<83P0A1P`04PL=01T>4P0D30T04@`901<>2`0E3`l0
4`l@014=3P0G4QP02`P?01LD6`0M6R<0f]OR06eZL`0H4aT03PT?010;4@0=20h06A@J01LB600F4AL0
5a8H01TD6P0L5ad07aXP01lM8P0P82P07b8Y02HZ<P0S:S80;3<m03DoB00b?dP0=D=@03];F00oDEd0
BE]Y05EWM01OLGd0JGV807N3UP2=UJX0W::j0:^`b`2b]]<0/;K@0:J]a@2BWK40QY6U07J4U`1UM8L0
FV]m055RL`13E6@0?DmM03U:E`0b@dd0;ca502/d?P0U;3H08RHa01hP:00K72406aXP01TG7P0H5A`0
6QDL014:4@0Q6al06a8G01X?5@0L4AD06`lC01P=4@0G31006PlC01/@500G31005P/?01D:3P804`P<
0P0H3A402P0A1PX06@hB01872`0B1`/060dA01H;3`0C20`03P<701D:3P0C20`200`11@0E01482P0E
2@/040@601D92`0G2`d040@601451`0>0P@060`>01lC5@0M4A<050P:00d10`0A0PD05@H901H72P0C
10L04@8501@5200C10L050D800805@H900/050D801<41`0A1@D04`L701`@400K3`l05@T901dA4@0@
10@05PX:01@8200201861P0300h20P0B1PH04PH600@04PH600<04`L701861P0A1@D00P0B1PH08@0B
20L06Q0C00/21@0J4A@0@CPk04U0@`0<0`H03PD800l62@0A20/07aHI01dD5`0?1PT04PD>01H9400D
1`h03`8901862P0F2Ph04@D90186200=0@<05`/=01P<300B20L040H:01482`0B2@`04`P<01462P0@
1@T04@D901@52P0301D62`0:01@63P0F2A804`H?01853@0C1Pd04PH:01@8300@10P040@601451P80
4PH601<07Q8C020D600E2@d04@D901@8300B1PX06@dA01H:3P0=0@D05PX>01/?4`0D20`040@70104
1P0F2P`04@D701`@4P0@10H03P@5008050P:00T04PH800h2100>0P@03@8400P0000H3Q008QHJ0965
R@0H31001P0B1PX301452@080104200?0`L03`<701X>4P0F2Ph040@801452@0B1PX30104200H01<7
2`0B1PX04@D90104200>0PH05`/?01D93@0F2Ph040@800d21@0Z7bL09AXR03<X<00Y7RH05P/C030U
;@0_92`04`P@07mdO00m<SX050TA01<8400C1Pl04PD>0P0@0``0200C1Pl050L@04e0B@1;?TL04`H?
02@G800>0`X04PD>5?ooool001_ooooo03`04@T801<:2P0=1@D07A<C01@:2`0=1@D05@T;01D82P0F
1`X05@H901L82`0G20`04`L901H:300>0P@050P:01D92`0C1`T05PX<01<72@0?1@H05@T;00T0000A
1`P06@h>00d10@0D2PX06`l?04a0@00H30`03`@401dA4@0R5QH050P801T=3@0K3`l06@d?00l31@0F
2P`06@d?02TM7`0I3@l04`P902PL7P0M4A<04`L900h41@0O4aD05PX:01<71`0@10@05P`<01861P0F
2PX04PH601dA4@0B1`L0=b/[01X>3P0D20P201D92@0K01@8200C1`L04`L701<71`0F2PX04@D501@8
200A1@D07A4A01<9200F2`T050P801D92@0F2PX05@T;01<72@0L4180;R8V06YNHP0G2`l060`@01@8
2`0G2`d060`>01H:300D20X05@T;00805`/=01`05PX<01D92`0F2P`05`/=01H;3@0C20/060dA01@9
3P0M4QD05@X>01@93P0F30h05``@01<83@0D2@`06Q0D01<:3`0L5QX04`dA01hH700Q6al04`dA01LA
5@0?2@d05a4E014;3`0J51P09b4U0P0D3Q8301H@500;01D?4`0D3Q805Q0D01H@500G4AD071HJ01TC
5`0F4AD05a8F01TD600J5AT00P0K5QX0200`:bl06aHJ01`G6`0N6Ad05a8F01hI7@0L5A`07ALN0P0M
61h01@0L61h06ALL024O900J6Ah08b8W00807ahS0P0K6Ql08@0K6R008R0V028Q:00R8BT0C4aD05=E
GP12A4h0:2/e01PK9P0Q9C007b<^02DX<@0X:c@08B@]01lR:`0T9c009BPa02P[=00U:3409bXc02/^
=`0Y;3D09BTb02H]=P0S:c@0:30i02`d?@0]=Ch0<3Q002de?@0b>T<0<3Q002lg?`0203<k@`0C034j
@@0b?4D0<ce603Y7D@0iBU@0=4E?0311B@0a@4L0<Sm503I1A00jA4D0>dI803M5C@0iAe80>4IA03U7
DP0iAe@0AeER04ECH00304AAH@0@04AAHP10CE`0?D]F045?FP17EF00@DmJ041>E`0nCED0>dYA03e<
D`0mC580?4]@03e<D@0oCE80?T]A03e:D0<0>dQ>00`0>DI<03Q5B`0iAT`0=T=903Y7C@13D5H0C5UP
03U6CP0d@DT0AU=K03a9D@0gA4`503e:DP0K03m<E010CE<0?deA03i<D00mBTl0?4Y>03a9CP0lBTh0
=dA903]8C@0lBTh0=T=803a:C@0iAdP0>DM703Q6AP0iAdP0>dU:03i<C@0gADL0?D]=03a:CP0nBe40
AE9H03a:D@0mBe@0>T]E0080?TmI0100>T]E03e>F016Ef40@55K03Q9D`0nCeT0A5EO03i?F00iAe00
=dI=03U8C`0mC5<0?4]B03I5C00jBE00=dI=0P0eA4/01@0hAdh0>dY?03@o@`0g@T@0=T530080=T12
00P0>49402lg>P0c>ch0<SXm02ld>00[<3@0;34d02lc=P80;C4b00<0:bl`02L[;00[;c000P0Z;Rl0
4`0/<340:Rh_02T];P0_<c@0<3Hd02`b<@0V:bh09b`a02X^=`0/<3T0=3Q203Di@P0b=Sl0<SLm038g
>`0^<cT0:2/e030b?P0];c/00P0Y;3D0100W:S<08B@[02DX;`0Y;3<202/^<`0A02X]<P0V:B`071lS
01/O8`0S9RX09RX]02@X:`1?DeL0LWEi02hb=P0P8bL08bL[01hQ9`0S:300:2Xe02h`>`0S9S000P0Q
8B`0<@0W9c<0:2Hc02TW=00V93408b4^02<Q;@0T8Rh09B<^028P:P0P7bP092<[02XY<00X9bd08b8X
01lN8`0N7B407A`P01lN8`0O72806aTN01dK800N724071TO01/I7`0M6R007Q`Q01dK800L6Ql06aPN
01`J800P7B<07adS01/H7P0L6Al06aTO01XG7@0O72808QlU01`J800K61h081hT01lJ8@0N6B006aHM
01hI800k=Sd07APO01/F7@0L5ah00P0H4aX0100L5ah06aHM01XC6`0K51`301`E7@0301/D700H4AT0
614I00@0614I00H05`dE01lE6`0N51X08aTO02lU:`0T6R0501X@5P0@01T?5`0C2aH07QLP01D>5P0D
3aD04`lB01DC5@0F51H04Q4C00l>4`0G5Q`0@D5806m/M00O5Ad06@hD01H;4@806PlE00H050T?01`A
5`0L4AL06@hD01H;4@0G318401T>508060dC01@05``B01X?5@0M4QP0714G01X?5@0G31805@X@01P>
4`0E31006@hD048g?@0^8bT05``B03`a=`0m<SP06@hD01P=4`0P5A/04`P<01TA3`805@h=00@05@l?
01<>3`0A2`l040/A0P0C3aH02P0G51d09b@^01PE7P0D3aD04`hD01TD6P0H4aT06A@J01/F700I51X2
01PC6@0b01XE6`0M61h07A/P01lN9P0O8RT092P`02<Z<P0Z<C/0;cU302`i@P0a?d`0>d]H04AFHP1A
Hg40Ffej05m_O01XMHD0NhBH096G[`2PYL00];OD0<;3i032a>@0]K[G0:>Ya@2DV[H0OhVQ06YiS01N
Kh40EVMh04QIJ@10DV00>daH03=4CP0_?4D0:C<l02@[=@0Q9C008B<[01lP9@0K6b006APM01TH700K
5a/0618F01hH6`0O5QX060dA01L=3`0H3@l301L<400<01H;3`0E2Ph05@X>01L<400F2`l05@X>01H;
3`0H3A40714E02DJ7P0I3Q804@H:0P0F2`l0100D2@d04PL;00h31`0F2`l201@93@0301882`0F2P`0
4`L900805@T;0P0A1@L201H:300501@82P0B1PP04`L901H:300H2@`00P0G20/01@0C10L04@<501T:
3@0C10L050D800805@H900`050D801<41`0B1PH050P801P<300F2PX040D501861P0C1`L05@T90145
1@0B1PH201L;2`L04`L701804PH601451@0B1PH04PH601<71`0H3Q40E4Y>085gN`0]92H03`L801dC
5P0?1@P04@L;01472P0D2Ph04PP<00d21P0H2a@202HI800c01X=500C1`/050P<01<72`0G2`d04`L9
01@82P0F2PX04`T801472`0C2Pd050/>01@93@0@1@T03`@801@8300F1``05`P=01H7300C10T04P@;
01T<5@0?0PX040@:0185300=0@D05@T=0104200@10H04@D701861`0C1`L05PX<01D93@0A1@T03`<7
01452@0C1`/07Q8F01T=4@0A1@T060`@01@8300?0`L04@D800h2100N4Q@05@T;02hR900H30h04@D7
008040@60`0B1PP01P0D20/04@L901T=4@0@1PP050P<01D:3@H04PH:0P0@10P01P0A1@T04PH:01@8
300F2Ph0:1`P01lC5`8040@802H050P<01H:3P0E2@d05`/?00l31`0D20`04PH:01452@0E2@d05`/?
01<72`0J3Q8050P<01452@0D2A403P<;01T>5P0G31@02`8801/@600D2A4050XA01/B600<0`T06@lF
01463P0D1a004`H?01853P0A10d04PD>01<63`0R5ah09AXQ00`1200J3AH04@H=01H94QCooooo000K
ooooo`0801@;300A20T04@P901@:2`0E2``03`D601D92`0G2@`201L82`0501D62@0C10L04PH801L;
3@0A1@L00P0D20X0:`0M4A<08QHH01@92P0800004@H702`P8P0F2P`0300001X>3P0P51@03P@404e1
@@0`92@0710@00P0000:00004`L701X>3P0@10@040@60186200I3@l04@D701/?4@0<008060`>00P0
000;004060`>00d10`0J3Q0040@401<71`0I3@d08QHF01/?3`0@10@03`<301861P08000050T900l3
0`0D20P00P0E2@T0300D20P04`L701<71`0B1PH06@d=01451@0D20P04@D502dQ8@0A1PD04`P601<7
1`805PX:00l04PH801X>400:00007Q8F01472@0/82@0P7Ah01L;3P0J3Q00710B01D92`0D20X05PX<
0186200C1`T00P0G2`d02@0F2P`04PH800l41@0?1@H05@/<01882@0L4Q<060h?01D;300201H<3@80
50X;00@05P`=01482`0?2@d040X>0P0>20`02@0L5QX06A<G01H@500G4AD04P`@01D?4`0L5QX0618F
01H@500201@>4P<05@lC00H05a4E01D?4`0G4AD06aDI01PB5P0G4QH201TD600A01HA5@0G4QH06aHJ
01/F6P0H4aL07QTM01`G6`0H4aL08QdQ020I800O6B007QTO01dH7P0L6Ah06QPM02l]<P0G5AX00P0I
61d03`0P7b@08R4V01hM8`0H5ad081lU020O9`0U9Bd0I6A/020P:P0Z:cD0GF1Y03HhA00R9C005a/V
01XM9P03028U;P1602HY<P0U:3409RTb02/^=`0Q92d0:Rdf02LZ<`0T:3409Bdf02Xc?00h@DX0>dA=
02lh@@0^=d00<3U203<lA@0^=d00;CHo034j@`0b>d@0<Sa202`f?`0]>T<0>dUD03Q9D`0^?dT0<D9;
03A2B`0d@dP0=T9703Y4AP0kATP0>DM?03I4C`0_?DP0?D]F03]9EP0iAe@0>4IC04=@H012Cel0>dQH
03e:F`11Ced0@e5L04MEH016E5l0?4YE03e;E012D5P0?TeD03]:D@0mC580?TeB03]:C`0gAD/0>DI<
03i;D@12CeD0?DY@03M4BP0d@DL0=dA:03U6C00gA4X0>4E;03m<DP1CH6L0AE9J038oA`<0=dA<00<0
>dQ@03a9D@0lBE400P0mBU80100lBE40?4U?03]8CP0jAdd403Q5B`0803M4BP0iAT`0>4E;03A1A`0g
ADT0=dE603Q6AP0jB4P303]9BP0R03Q6B@11Ce80?DY@03m<DP1=FV00@TmF03a:D`0iBU@0>daF03e>
F00lCEL0>DYD03A5C`0fAe40>DYD03M8DP0fAe40>daE03=2B@0d@dX0>4M>041?EP11D5L0=4=:03I5
C00c@TT0;ci5030oAP0eA4/0>TM=03U4B00iA4H0=d9403@n@080<S`n0P0_=cX08P0`>3/0;c@h02/`
=00]<SH09b/^02T];P0_<c@0;C4b02<W:00P92D09b//03i2@`0N8R<0:Bd^03<g>00W:b`0<CLg02le
=00_=3L0;34f02/_>00_<c`0<cM2030d?@0f>T<0;C8i02P]<`0[<3H0;2hi02`^>P0Z;3P09bXc02HY
<P0W:S<202LZ<@0E02P[<P0[;S<0:bhc02/_<P0X;2d0720Q01/O800M8B@08bLZ02T]<01CEU/0BdiC
02DX;`0R9B`08RD^02<V;`0P92l06adY01lQ;@0N82`0:2Pd00809bLc01P0:BLd02LU<P0S8Bh08R0]
02DS;P0R82/07adX020N:00Q82P07ahV01/J8@0K6R007A`R01hM8`0M724071/P024O9@0P7B@071TP
01lM8P0N72406aTN01LE6P0F51T201LE6P0B01/I7P0L6B008AhU02PU;00S82L06aPO01hK8P0P7B@0
7AXQ01hK8P0P7B@06AHM01LD6`0L6B0061<J02PS:P0J5A`050lF0P0O6R401P0[9Rd0:B@[01lJ8@0L
5ah07aXQ01TD6`806a@L0`0L5Ad03P0K51`0614I01PA6@0G41P05PlG01L@600H4AT05@`A01XA5P0I
41D06a8G028I7P0K4QL06Q4F0P0H3a@04P0I41D06Q4F01L>4`0L5Ad030D=01PA6@0=20h05a8G01PC
5`0N71l01`D901LE6P0D4AP0;2/b02LT:`0H3QH060dC01X?5@807Q<I00P06@hD01D:400F2a406PlE
01`A5`0K41H05P/A01L<4P8060dC01405``B01H;4@0D2@l05@X@01lD6P0N4aT05P/A01@93`0L4AL0
2P0502XO9@0800<0;R<Y02dR:00H3A<050X?01@93`0201052`060146300N4aL05Ph=01@;300E30d0
5a4B0P0H4QH0D00E41H02PD<00X5300G51d0<2df02LT:`0M61h04PdC010;4@0E41H040/A01PC6@0K
5Q`061<I01LB600H4aT06aHL01/I7P0N7RH082<Z028U;@0Q:3009bhh02`f@00]>T<0<T1=03];F013
EF40CV1^05]]N01RL7/0JgN507f6VP2@U[00XjC20;bmg@3CdoL0f][n0<S:k@2^/]D0W:3308B>Y`1_
OY40HW>505UZN`1<GFd0@eES03]<F@0cA4h0;ca502Tb?00T:cD08bLb02@W;P0S92P071dQ01XJ7@0J
6Q`061HI01/G600D3Q006Q4D01@:2`0F30d060h?01D:3P0G31005P/?01@93@0F2`l05@X>01<8300D
2@d04`P<00l4200A1PX07Q<G028G6`0G31003`@80`0B1`/0500@1@T050T=01H;3`0=0PH02@0201L<
400H30h05`/=01H:300D20X04PH801451`0@10H04`L901@82P0C1`T04@D70186200H2@`04P<60P0F
1`X0100A0PD05PL:01<41`0D1@P201D62@0>01@5200C10L04PH601861P0C1`L050P801H:2P0H30`0
5PX:01<71`0<00003@4101<71`0@10@601861P0301<71`0B1PH04@D500804PH600h04`L701T>4@0V
6al081DI01H;3`0Q5QX02@0201052@0D2@d04@H:00h31`0A1PX05@X>01853@805`XA00X050L>01T=
4@0N4QH04PH:01D92`0G2`d04`L901861P0@1PD04`T=0P0C2Pd0100C20`040D900l4200E2@d201L8
3@0:01H7300C10T04P@:01L:4@0E20l04`H=01032P0>0PH04`L;01452@@04@D700L03`<60104200C
1`/04PH:00l31`0@10P04PH:00803`<701D040@800d11@0?0`L04PH900l31@0E2@/04@D701dA4`0A
1@L03@8300h2100=0@<03`<501041P0?0`D03P85028F6P2>PXH03P8602DI7@0<00@01P0B1PX30145
2@0301<72`0F2Ph06@dA008040@801@04PH:01P<400H31004`L;00P0000D20`04`L;02DI7@0N4QH0
40@801<72`0D20`06PhB02`P900Q5AT04PH:00l4300<0@T03PD;01<840804PL?00H06PlG00X11`0I
3QH05``D03/`>00A1Ph601853P0601D84@0D1a006`hG01<63`0D1a002`075?ooool001_ooooo00P0
5`hA00l62@0Y82<05`d>00l61P0L4Q<04PH801D82@806@/;02/05PP801<51@0=0@<04PH801L;3@0F
2P`04`L90186201>@T@0:1`N01862019?Cl0Og=e01X>400D2PX05`/;01451@0=0@4040@4028F5P0>
10@050P801lC4`0A1PH05PX:00h20P0F2P`050P:01T=3`0D20X08QHH01D92`1HC4h09QXL01hB500E
2``08aLI00/00@0G2`/06`l?01L;2`0900004@D500805PX:00D07A4A01L;2`0J3Ph05PX:01@82002
01D92@0X01@8200C1`L04`L701861P0I3@d040@401H:2P0I3@d0?S8b01<81`0B1`D06@d=01P<300A
1@D03`<500`20`0N4Q@04`L;01hB5P0A1@T07A4E01dA500K3a407A4C01D92`0D20X05PX<01L;3@0J
3Q006@d?01D92`0H30h06@d?01<82@0E2`X07Q@C01471P0H3Pd0718A01L=30<05P`;00H05@/:0189
2@0R6A`06A<G01XD600@2Ph2014;3`0801H@500L5QX050hB01@>4P0A2`l04P`@01lI7@0J51P201D?
4`805Q0D00L0618F01XD600H4QH0618F01`F6P0I4aL06A@H008061<G00@06A@H01PC5`0E41@06QDI
0P0M61`01@0J5AT06A@H01dH700N5ah07ALN00806aHL02H071TN01dK801GEEX0;bhc02DT:@0Q82D0
7QdR01LF6`0M7R<06ATQ01`L900W9bl08B4Y02HV;P0X:3809bLa03/kA@0Q92d06QdV02HY<P0L82T0
8RH_024U;P0P92d09BTb02@X<@0R9Rl0;30i01hR:`0c=d00;30i024U;P0T;3D0;SM0049;E014CEH0
<CY302`e?P80=3e601d0;CHo02/d?@0a>T<0<S]403I0B@0a>dD0;S]403I4C`0a@Dh09SQ403=5CP0i
Ae00>DQ=03M4B@0iA4H0>DM:03Y:DP0a@T`0<45;03]<EP0hB5D0?TiK03=3D00jBUT0>d]J03Y:F@0k
Be/0A5=Q04ABG@02041>F@0A03a:E@0oCEH0@U1H03i=E00kBU40>TU?03]:C`0jBDh0>4I;03U6C00o
C580@e1F03e:D00gA4X0=45703M4BP0iAT`00P0hAD/00`0kB4h0B5EL049?E`0203I3B`0;03Q5C@0i
ATh0?4UA03a9D@0kB500>DI>03Y7C`0mBU80?4]@03]:C`0iB4d00P0gAT/05P0hAd`0=dI;03]:C`0l
Be00>DQ=03Y9CP0kBTh0<d5203E3A00iAdP0>TQ903U7B00e@dH0?4Y=03U7BP0mBU00AeAL04ICF`0l
BE40?deF03i<E@0lBU<203m=EP0<03Y8D@0kBE80=dE>03]9DP0lBU<0=49;03=1BP0f@d/0>TM?03Q5
C@0jAdl0?DYB0`0d@DT0200c@4P0=45903E2BP0e@TP0=D1403I1@`0c?T00<C/m0P0^>3X0<P0g?d80
<3Pk030h>`0b=c/0;C8f02hc=`0V:Rd0;30c030d=`0[;c80:Rha03@h>`0Y;C00Oh>603Pl?`0K7b80
:blb03Lk?00]<c<0;C<d038g>P0^<cP0;C4j03<g@P0g>dH0;C4l03TmAP0[;cL09BX`034f?00f=d80
<c<o034a?@0];CL09bLa02DU;`0Z:S80:2P`02TY<@0[;340:BX_02HW:`0V9bP08B8T028S9@0P8B<0
9BHZ02h_<`0f=Sd092@/0P0R8R`0400T9300:B/g04M;E`0c=D80;S0m02@V<P0V9S808R8]02DU;`0W
9C00928]01lM:00P7RT08R0[020O9`0O7RH2024P:00I01lN900K6R0071/Q01hM8`0P7bD07ahT01hM
8`0O7BD06AHM01HC6P0M6b407A/P01/I700J61/06aTL01/I7P0G5A/06aPO01`I8P0M6R808b0W024N
9@0L6B007Q/R01lL8`0201/H7`0B01dJ8@0J5ah06QLN01dJ8@0T7bH07APO01PC6P0I51/0:bH]01`G
7P16@DP0?3Ln028M900F4AP06QDL01/F7@0K51`071DM0P0M5Qh201`E7@0901TB6P0H4AT05a0H01H?
5`0G41P06A8I01T@5@0I41<060lB00805`hA01L05Pd@01XA500H3a805`hA01T@4`0J4A@05PdB01@=
5@0G4QT08A`R01HA5`0A31806QDK00H11`0J5A/08b4V01PF6`0@3Q@07aXQ01L=5@0H3A<06@hD01/@
5P0201dB600301T>500G31806PlE008081DK01<05``B01P=4`0I3Q@06@hD01P=4`0E2Q004`P>01D:
400K41H06PlE01H;4@0G31807Q<I01P=4`0A1P`09AXP01L<4P0900@07Q<I00805P/A00D0714G01T>
500A1P`09Q/O01H<3@0201<:2`0@01P?4P0H4QH0618F01dF7@0T7bD061<I00l:4@0@2a802`H=03Td
>P0N6Al050lE01`G7@0H4aT08ahT01TD6P805Q4G02P061<I01dH7P0M6b009RH^02HY<00R9Rh07RD]
028Y<`0X<S/0;3U2034oC00jBUL0?e5M04UKJ@1GJ7<0H6ii06YfQ01lQ9P0Ri6[0:6R`02l_=h0emGl
0=oOo`3:bo40/;;H09nSb028TJd0LX6D06AeQ`1KK7d0CUm_04AFI00mCUX0=DI@030mAP0[=3h09bhh
02L[=P0T:2l07R8U0P0J6ad03P0L71h061HG01XF5`0E4A805a4A01892P0T6a`08aTI01@93@0H3A40
5``@01D:3P0G310050T=0P0E2Ph01@0D2@d04PL;01<8300G31005@X>00804@H:00D05@X>01<8300B
1`/03`@801/@500201D:3P0500h31`0Q5QX05@T;01H:300D20X00`0C1`T03P0?0`D050P:01L;3@0E
2@/04`L901451`0D1@P03P0201X;3P0N3a804`@70101100C10L050D80P0E1PT0100D1@P04`@701@8
200B1PH200l30`080104100?0`<050P801@8200@10@04PH601@8200=0@4601861P0301<71`0B1PH0
4@D500804PH600P04`L701<92P0800007Q@E018:2P0B20T04`T:014720804PP90P0A1`P0500D2@d0
40<;01032P0?0PT04@@;01P<400L41@04`L;01451`0I3@l07A4C01T=3@0@1PD05@/>01<:3@0B2@`0
4`P<01462P0@1@T050P<0P0F1``03`0E1P/04P<801@6300A10/050L>01<72`0A1@T050P<01862P0C
1`/04PH:01452@0@10H03`<50145200401862P8040@801L050P<01D93@0@10P040@801452@0@10L0
4`L900/00@0A1@L03P8401<72@0@10H04@D701041P0C1`T05PX<01D92`0D20/03P8603HZ;P0I3A40
200001/?4`0601862P0801<72`0B1PX04@D901452@0C1`/05`/?0104200B1PX201D93@0@01862P0>
0PH02`0301X>4P0B1PX09a/O01lC5`0A1@T04PH:01<72`0H31009ATM01X>4P0B1PX04`P@01@94@80
4PL?00/05P/C01P=5@0D2A407a@L01463P0700@0PgR0034V;P0@0``04@@=01853P0301<63`060185
3P0>0@X03P4:00d02@0E21406PdF5?ooool001_ooooo01@03PD901893@0j<C@09AXN01<:2`0D2P/0
4`L801H92P0J30`06@/:01H81`0B10@05PX<01872@0L4180F4a>02TM7`0:004040@601@92P806Ph@
00X0A3Pj02<G6@0G2`/04`L701H:2P0E2@T03P<301861P0K3`l02`410P0F2PX04@0G30`050P801L;
3@0A1@L05PX<01L;3@0P51H07A4C024F600H30h040H701dA4`1aIFL0?S8d01@8200@10@05@T90080
5PX:02404`L701461P0B1PH06Ph>0104100J3Ph05PX:01051@0F2PX050T901861P0J3Ph05@T901T=
3@0C1`L050T901D92@0Y7Ad050P701P=2`0Q5AD07Q8B00l4100D20X06Ph@01<92P0A1`T04PH:02<G
6`0H31004`L:01T=3`0J3Q000P0E2@/08@0F2P`05@T;01hB500C1`T04PH8024E5`1CAdT0<bPX01T?
3P0R61L0718A00h51@0M4a806@l>01<9200F30/04`T801P>3@0B2@T05@`?00h8300C3A404@/?01PB
5P0D3a803@L;01TC5`0@2Ph07ALK01D?4`0D3Q807QPL01/E6@0201PB5P0901TC5`0D3Q80618F01hH
700J51P091hR05UCE`0K5AT06aHJ008061<G01807APL01`G6`0E41@02`H:01/F6P0B3A4061<G01dH
700Q72006Q<J01XD6P0J5A/06aHL01dJ7`0O7B809bDZ01HE6P0K6Ql201lN8`0601hM8`0C4a/08R</
01XL900R8R/07QhW0P0O7bP02@0];CH07QhW01/M9@0Q8R/06QdU02<W<00T:C808bTa028X<002024W
;`0`02L/=@0[<3T09BXc03PmAP0c>D409bhf02/d?@0[=Ch092hg02li@P0^>440=3i703<lAP0a>T@0
;3Ho02/e?P0`>D<0<C]402hh@P0c@4X0=D5<03M6DP0cAE40>4YF03=5C`0eATh0=DA;03=1A@0e@4@0
=D9703Y:D@0_@4X0<dA>03Q9D`0eAE80?4aI03I6D`0iBEP0?dmN041@G`14E6@0?TeK03i<E`10CUT0
B5IQ04MEH00nC5D0>4I>0P0lBe802P0gAT`0>TU>03a;D00mBe40?4U?03]8CP0lBDl0>4E;03E2B00d
@DL203E2B00B03U6C00kB4h0>TM=03U6C@0gA4`0>4E=03e:DP0lBE40>TM?03a9D@0mBU80>dQ@03Y7
C`0oC5@0@TmG04=BF00mC580>TU?0P0kBU00M@0iB4h0?TeC05YYK`0oCU@0?TeC03Q7C@1;FUl0>DM:
03U7B00kBDX0?4Y<03]9B`0iAd/0?Ta@03Q5BP10CE@0BEIN041=E@0kB500>dYB03M5C@0gATh0>dYB
03Q6CP0d@d/0?4YB03M5C@0iB500;3]303a;D`0jB500=45903i9DP0f@TX0<Si603M3B`0e@DT0>4=<
03E1B@0hA4`0>DE=03A0B00b?T@0;STm03@o@@0^>C/0;CLi02hh>P0g@D<0>413034i?00e?D00<cPl
02`a=@0W;300;S8f02/^<P0_<SH0;C0d034d>017Bdl0<cHj03@g>`0W:Rh0=SXn02ha=@0g>ch0;S@d
02P^;`0X;C40;C8i02T]>00j?TT0=3Q303/oBP1JGVT0>cm802DZ<00]<SP0?cm;03@d@00[:cL0;2`f
02LW<@0V9S00:b/c02PX<00[:c<0:b`a02HW;00T9BT092DV01`M7`0Y:R`07QlR028S:00V9b`071`T
01TI8`0S8bd09bLc02PX=@0W:CD09RTg020R;`0T9S<09RPd02DU<@0Q8B`08R8/02PV<00f=Ch08R4Z
01LF7`0O7RH07ahU024P9`02028Q:003028Q9`0Q82H08B0V00807QdT00d06APO01PG7P0O7BD05a@M
01LD6`0T8RP09B<V02LU:00[:B/07Q`N01dK7`0I5Q`07AXQ00806AHO00l05Q<K01TF7P0P7BD07a`T
01TF7P0F4a/07AXR01`I8@0J5al081dU01hK8`0L5ah05A0G01hI800D3aH00P0N6B001`0f<CP0:bH]
01`G7P0K5Qd07APO01XE700I4QX00P0M5Qh0100J4a/06a@L01dF7P0F3aL201/D700M01<<500O6200
71DL02LO900N5aX06Q8F01L?4`0D3A006A4E01XB5P0H4A@0610D00l82`0J4aH030L:00h93`0K5Q`0
4PdC01LB600E41H06A@K01D?5P0E3aD050lD01D?5P0C3aD07aTO01P?500I3Q@00P0G3180400I3Q@0
714G01P=4`0D2@l04@H<01H;4@0I3Q@04`P>01/@5P0I3Q@0;b@Z034V;00J3aD05P/A01X?5@0I3Q@2
01H;4@0?01P=4`0I3Q@07A8H0146300E2Q004`P>01L<4P0H3A<050X?01H;4@0D2@l05@X@01<83P0G
318060d@00805@/>04D05`dB01P?500G3a@0=2dc07E_M@0D3aD061<I014<4`0N6Al06A@J01@?5@0J
5A/08A`R01<>500D3aD05a8H01HA5`0G4QP06aHL01dH7P0J61d092<[02lb>@0X:c<092/c02P_>@0X
<S`0;S]402/iAP0kBeP0?4iJ04UKJ@1CIG00Gfeh06McP@1eOY80QXbV09ZK^@2e]=L0cLcb0=GDnP38
bO00[[7G0:FYc`28TJh0Lh:E06MhRP1MKWl0D65a04IHIP0mCUX0=DI@03E2B`0_>480:c8l02/_>P0O
8RT08BDX01TL7P0F61X07AhP01LF600Q7Ql05Q8C01PB4`0M5QH081PI02LM7@0E2Ph00P0G3100100F
2`l05``@01H;3`0H3A4201H;3`8060dA0P0D2@d0100E2Ph06PlC01`A5@0I3Q8201L<400=01482P0F
30l04@P:01L<400B1`/04`L901H:300D20X040@601<72@0F2P`04PH801@82P020186200801L;3@0I
3@l05PL:01@5200N3a808Q<F01T:3@0B0`H601D62@0<01861P0C1`L04@D501861P0C1`L04PH600l3
0`0G2`/04@H601`@400H30`04@D51P0B1PH201<71`0P01861P0A1@D04PH601<71`0B1`T03P<400l4
1@0C20X07A8C01@92P0@1@L04PL801@92P0C20X04@H701052@0D1`l05PT@00l42@0D1`h05@T=0104
200E2@d04@D701T=3`0O4aD06`l?01@:2@0D2Ph04`X=0189300B1`/201462P0H01862P0F1``05PL<
01@52P0C10T05PT=00X00P0F2Ph050P<02HJ7P0J3Q8050P<00l41`0@10P05@T=00`2100B1PX040D8
01452@0@10P050P<01<72`0A1@T040@80P0A1@T03@0>0PH05PX>01L;3`0A1PP050P:0147200C20X0
5`/=01<82@0B1PP05`/=01T=3`0F2P`00P0J3Q000`0E2@`040@80105200301D93@0901862P0C1`/0
4`L;01862P0C1`/04PH:01H:3P0W6al040@800803`<70P0D20`0100C1`/04PH:0104200A1@T201@8
300702dQ9@0F2Ph06@dA01H:3P0B1PX04`L;01862P0201D93@0;00h21P0I3Q40Bd1801hC6`0B20l0
40H=00h32`0E2Q804PL?01053@0=0`X00P0G31@00`0D2A404@@=01853P0201<63`8050L@00H04@@=
01H94P0D1a005PTB00d02@0@0``Dooooo`006oooool0200800@05`hC00/21`0X7B409Q`N01lE5P0B
1PH050L70P0F20L02`0E1`H04`D40104100D20X02`0104Hj?00K3a404@D701<72@0F2P`040@60080
4PH800<03P8401@8200D20P00P0C1`L201861P0900h30`0S5aL04@D501<71`0E2@T05PX:0186200H
30h0710B008050P:00T06`lA01T=3`0A1@L06@d?00h2100R5QP0200001<71`0E2@T00P0H30`0400B
1PH03`<300l30`0X71`0=b/[01dA4@0D20P0300002XN7P1hK6`08QHF00h20P1BATH06@d=01861P0C
1`L201H:2P0:01L;2`0F2`X04@H401861P0D20P04PH602<G6@0n<S@05`/=01D93@8050P<00D02`03
01L;3P0E2@/05@T;01@82P0201D92`0l01/?4@090000300201D92`0F2P`081@F01461P0?1@@06@l>
02hT8`0?1@@06@l>01H<2`0H3Pd05`d<01061@0G3@`040L701P?4P0G4AD02P@801TC5`0?2@d050hB
01lI7@0T7R805@lC02DO8`070@D05a4E01PB5P0?2@d0618F00T31`0;1@T08adQ01TC5`0C3A403PP<
01XD600d;S806aDI01/F6P0H4aL05a8F01TD600J5AT05a8F02TT:00a;3007aXN024L800J5AT06A@H
01/D6`0K5A/06QDK01/F700L6Ah07A/P0P0J61d0500M724071/P01XI7P0O82D05APO01XM9P0I72D0
8R8/024Q:`0T92h07AdU02TY<@0T92`08R8Z02LW;`0O8RT09RXc02<Z<P0Y<3P0:S4i0P0V;CD2028Y
<@0:02@[<`0X;cL0:2lg02L`>@0T;CL092hh01lY<`0kADl0;cU303@nB0<0;CM101/0<3Y403<mA`0e
?dT0=T5;03A0C00Y=d80<T=?05a^NP0cAE40>deI03U:E00gB500=dE<03Q3A`0f@dT0=dM>03E6D00g
B580?DiH03Y:E`0dA540?DeJ03m?GP1UMH@0@U9Q03i>GP12DEl00P11CeX02P13DE`0AE=N03i<E@0i
Adl0@4mF03m>E@0hAdd0>DQ=03Q7C00gAD/203Y7C@80>DI<0140>4E;03E2B00b?dD0<Sm503Q5B`0k
B4h0>4E;03E2B@0d@DT0>DI>04QEG@15DUX0?4UA03]8D00oC5@0?T]C03m<E00204ICF`0=03Q7CP0g
ATd0>TU@041?EP0nCE@0>TU@03I5C01?GVD0>DQ?03M6C@0b@DP0A5=I03Q6B@0203Q6A`80=TA700@0
>DI<03a9C`0kB4h0>dQ@0P0lBE40800nBe<0EFA[04=BF@0eA4/0=TE<03A3BP0iB4l0=TE<03Q7CP1D
HfX0>4M>041?EP0c@DP0>TA=03a6C`0f@4T0=3i703M1BP0f@4T0>TA=03@nA`0h@T/0>TA=03DoB00d
?dD0=3m302dh>P0X<cD0=d53030j?00T;S00>D540P0^=ST07P0Y;S80;S<g02hc=`0Z;C80<cHk02P[
<00T9b`0;c8g030c>00[;S<0<3<h03<f>`0b=CX0;2ld02LZ;`0X;C0092T/02hc=`0a=Ch0WJ6/04U=
F00f>TH0<3A003@hA00K7bT09b/d02d`>@0e=D40;2`h02@T<0808R8/0100<C4k02HV;P0_;cL0>3Q0
03@e>P0X:Bh09bP]02<T9`0[;300=cPl02@U:P0[;3407QlT01hN9P0O7bT08R8/0P0U9C402P0T8c40
9RPg02<U=00T9S<09bTf02@T<00Q8B`06ATS01lN9P0Z:C42028Q:@04024P9P0M72807QdS01hM8`<0
7A`R00<07ahT01LF7P0K6R800P0Q82P0>P0U8b`09B8]02HS;00U8bT0=cDh03/i>P0X9RL05Q@E024O
8P0P7B<09B8[02dZ=@0b;cT06AHO01/H8@0N6b@06aPQ01`I8P0P7BH06AHO01LD7@0P7BH08AhW01dJ
8`0Q72<071LN01XE700K5Qd06QDL01dH7`0_:S409B0W01/F7@0J5A`061<J01XE700L5Ad07aPP01`E
7@0J4a/07QLO01/D700G41P030D=01@=5@0F3aL06A8J01PA6@0V7bH050hB01D?4`0@2Ph07aTM018<
400>20`04@/?01dG6`0Q6al201lI7@0<01TD6P0A3180Ee9H07UdNP0J5A`050lF01`E7@0Y8RX0=c0g
02DN9@0J4aX050XB0`0I3Q@301P=4`0?01873@0C20h06@hD01dB600J3aD04`P>01dB600C20h06PlE
01/@5P0E2Q007A8H01T>500H3A<05``B00805P/A00P05``B02PM8`0G318060dC01@93`0@1@/05@X@
01H;4@<050T?0P0F2a40A`0E2Ph050T=01<8300C20h04PT>01<:3`0B2`l0=2dd00/42`0>2@l01`88
01hI7`0D3aD05a8H01`G7@0J5A/05Q4G01TD6P0G4QP05Q4G01TD6P0M61h06QDK01HD6@0D51`0;S4h
020S:`0I82P0;cI002@^>00/>D807R`i03a<F@0gBED0AeUW05=UL01OL7X0I79o079lS`25RjD0TIFb
0:Z/c@2i^n40^k_Q0;>fg02QYLX0Yj_@08N@[01aP9<0IWN905]/O@1?H700AeUW03m@G@0cA4h0=45:
02`f?`0V;CL0:blj02DX;`0M8B@03Q4F028T:00M7R005QDI00L5200J61T06QDG01@>400H4Q808aXM
00805``@1@0F2`l01@0E2Ph050T=01H;3`0F2`l05@X>00@05P/?01005@X>01@93@0D2@d07A8F05=8
C00J3a<060dA01L<400K3a407a<E01/?4@0C1`T05@T;01P<3P0E2@/05PX<0P0A1@L02P0F2P`05@T;
01@5200D1@P05@H901L82`0F1`X04P<601L82`0F1`X201D62@0401H72P0G20/050P801@820804`L7
0P0B1PH01P0K3`l03@410104100<00003P@401@820H04`L70`0B1PH301<71`H04PH80P0C1`T201@8
2P0:0186200A1@T04@@<01T<4`0C1Pd05@P?01X>4P0K3a<04PH:018620804`L900D04`L701881`0A
1`/04@P;01072P0301052@0301452@0F1``05PL<008050D:01005PP<00T0000J3Q804PH:030T:00D
20`04@D901lC5`0>0PH03@<500l31`0G2Q4050L=0104200?0`L04@D90P0C1`/0100@10P050P<01T=
4@0C1`/200X00P0:01<72P0<0080200001T=3`14>3X08ADG0186200K3a407a<E01D92`805PX<0180
4`L:0104200=0@D04PH:01D93@0C1`/060`@01L;3`0C1`/04PH:01<72`0D20`03P8602<G6`0E2@d0
6@dA01862P0A1@T301<72`<04PH:00l04@D901lC5`0=0@D0710D01L;3`0B1PX06@dA020D600I3a40
5`/?01/?4`0L41@0U8VA03H[<`0>10/00P0@1@d00`0B1`l04@H>01463P0201053@804PL?1P0C1Pl0
100E214050L@01D84@0C1Pl201443ACooooo000Kooooo`0>01<94@0@1Pd01P0201T>500@1PP01`00
01P<300I30/060X901L9200D1P<04@<20104100K3a4200d10`0800l31@0I3@l04PH801@82P0A1@L0
4`L901D92`0C1`T201@820804`L70P0B1PH00`0a9BD0F4a<02<G5`0201D92@0C00X0000O4aD040@6
00P0000J3Q00ETY<07a`LP0<0@804PH801T=3`0E2@/06`lA0186200A1@D05`/;01X>3P0I3@d04PH6
00l30`0201X>3P0L01P<300D20P06Ph>01@92@0I3@d0Ac/k01`@400:0000:alO01451@0C1`L050P8
01H:2P0E2@T050P801L;2P0E2PP04`L701861P0A1@D081@F03X^<00F2P`04@D901X>4P0H31004PH:
01T=40805@T;01`050P:01D92`0E2@/0@SHh024E5`0N4Q@04`L902DI6`0B1PP06PlA00l51P0H3Pl0
<bTZ01T?400H3Pl04PP901hD5@0H3Pl050X;01<92P0B20T03PD801XD600A2`l0618F00P21P0M5a/0
2`D90P0@2Ph0500G4AD091hR03H`=00D3Q803PP<05E?D`0X8RH07aTM01XD600D3Q805@lC01XD600L
5QX030H:01hH700J5AT061<G01D@500G4QH06A@H0P0H4aL201LB5P0501XE6@0M61`06aHJ020I800N
61h00P0J5A/0100K61d071XO01/I7P0J61d201dL8@0F01/J7`0O82D06ahW01LJ9@0J72P05QTR01dN
:00M7BL08R8Z01lO9`0R8BT09bH/02TX;P0T92`08BD^01lV;P0U;3@09Rde02<Z<P0U;3@08RTa02H]
=@<09bhf02D09Rlh02/d?`1AFfL08R`h02D_>`0Y<cl08bdi02`f@P0]=d<0;SQ403<mB@0h@Th0>TA@
02llA@0d@4`0=dE@06YkR03OlOl0RYf[03]?FP0hBU@0>DYB03a;D@0hATT0<d9703E7CP0eAe40>TaF
03i@FP0iBeL0=4IB03mAG@10DV00JG^903i@GP0hBET0@E1N0080@DmJ00`0@4iI049@F`0lBU<0>4I>
03a;DP0kBU40>TU?03a;D00kBTl0>dU>049?E@10CE<203I3B@0A03E2B00a?T@0<Ci4034nA00gA4X0
>TM=03Q5B`0e@TT0=T=;03e:DP1:Eel0AU=K03e:DP0iATh0>TM?03U6CP0jAdl00P10CED01P0fA4d0
>T]C03Q9D@0fAdl0=dQ@03]<E080<4590180=dQ@0393B`0jBe<0=DE=03Q5B`0jB4/0>dU<03M5B00f
A4L0>dQ>03a9D@0jAdl0=T=;03E2B`0hADh0?DYC061]M@1:Eel303I3B`0<03U6CP0e@TX0>DI>04YG
G`0^>d<0>4E=038oA`13CEH0>dE>03Q2B`0g@DX0=3i70P0f@4T0200c?DH0=T1903Q2B`0d?TL0=3m5
02lj?P0^>C/09c8d0P0_>C/0:P0f@480<SXm03@l?`14C4l0?T=702db=P0L8BD08B@Y02ha=P0R9BX0
7B0U02/^<`0^<CH0<3<h03Dh?@0g>Sl0;C0e02/^<`0P8bP0:c0c02H[;P0Y;S80;C4j0;Bh``11AE40
>3]:02X^>P0]<Cd0:Rhh03Di@P0f>D80:bXg020N:`0U8c00:2Ha024O:P0`;ST08R4Y02l^=P0g=Sh0
;Rdc028Q9`808B0V00L0>CPn03Lf?00V9B`0<2lg01dL900Q82P09R@_00809bD`00<09R@_02DU<@0X
:cX00P0S9C@02`0T9S<08b<_01lO:P0L72H092<[01lN9@0T8bT0:2L]01`K8@0P7b@08B0U00808B0V
01/081lU020O9P0V9Bd08b8Z02HU;P0V92l06ALR01TF8P0W92l08b0Y030]<`2=Rhh0WI^L05MFE00^
;2d0<2ha01dK8@0F4a`05a@O02@Q:`0K62407Q/T01`I8P0H5Ah08QlX07IcO01bKgP00P0S82T01`0Q
7RL06AHO02LR:@0O6R407APO024L8`0O6R400P0M61l0:@0K5Qd07APO01dH7`0I51/071LN01dF7P0K
51`05a0H01XC6`0M5Qh05a0H028K8`0>1`l071DM02@M9@0D3AD07QLO02<L8`0H4AP07QLN00P1200E
3QD081TP02<L8`0J4aX040X@01H?5P0?2@l05PlF01LB5P0K5Q/0ZjJ/0<K1b00V82T03`LB02HN:@0d
;3@0:R0Y01D;4`0L4aT03P<900806@hD00h060dC01L<4P0G31805P/A01P=4`0C20h0714G01hC6@0D
2@l04@H<01@93`0K41H04@H<00h32@<05``B0P0H3A<201L<4P0:01D:400L4AL05@X@01T>500H3A<0
6a0F02<H7P0F2a405@X@01@93`805@X@04P05P/A01/>5@0H2a805PT@01@93`0B1`d04@P=01D<4@0C
3A403PP<01TC5`0D3Q8071HJ01@?5@0H4aT06QDK01@?5@0C3Q@06A@J01LB600F4AL061<I01/F700J
5A/05aDJ020O9`0I72<09b/c01<J8P0M92h0;CM102Tf?`0Z>4D0?dmL03U;E`15EfD0CEmZ05e^N01P
L7d0KWZ=07f4WP24RJH0V9bl0:^_dP2b]MP0][[M0:>Yb`2UZld0QI2Y0760T`1UMXP0FFYk04mPL017
FFL0@E9O0393C@0c@4T0<S]502D/=P0Y;CP09b/c02DZ;P0F6B007b8W03Xk?`0L6b407Q`Q02<Q900H
4aL04P`@01TC5@0b:Rh201P=4@0801L<400F2`l05P/?01D:3P0H3A405@X>01<8300D2@d301H;3`0C
01D:3P0D2@d04`P<01<8300D2@d03@8600l4200d:Bd02`0401052@0A1PX060`>01/?4@0G2`d04@D7
0186200D20X05@T;01H:300201041P0801@82P0B1PP05@H901D62@0F1`X060T<01L82`0C10L201H7
2P805@H90P0F1`X301<71`<04PH600H04`L701X>3P0G2`/0300001`@400F2PX601<71`0801861P0A
1@D04`L701P<300E2@T04PH601H8200E1`L201@61P804P@400d06`d=01@61P0B10@050H601<51@0A
0PD06PdE01<63@0B1@`05@P?01862P0:00804PH:00<04PH800<04@D501061@0@1PX00P0?1PT0100@
1@T03`@800l4200A1@T201D62`804`@901005@L;00/0000I3@l03P8402<G6@0?0`L0308401P<400<
00H060/B01D83`0F2A804`H<01862P0A1@T03@450P0E2@d0400A1@T03`<700d11@0B1PX060`@01X>
4P0F2Pd03P8400d10`0D20X0;B4S01P<3P0?0`D05PX<01X>400A1@L20186200700l31P0E2@d05`/?
01452@0=0@D02@0101D93@0201<72`0901D93@0F2Ph050P<01<72`0900403@850104200=0@D05`/?
00@04`L;0P0D20`04P0G2`l050P<00d31@0R5QX050P<01862P0;00<081@H01/A4`0@10P0200001hB
5P0V6b<02`0802DJ8P0Y7RH05``D00l430@040D=00<04PL?01<8400C1Pl01@0C1Pl01P0E214050L@
01@7400E21405PTB01<63aCooooo000Kooooo`0D01D;4`0E31<05PdC00`31`0G31406@l@01051@0B
1@D050H501@60`0E20@05PP601P<300@1@H060`>01@82P0H30h05@T;0186200C1`T20186200401D9
2`0G2`d050P801@820804`L70P0B1PH0300D2@T0;b<S01T=3@0C20P050P801H:2P0E2@/060`>01D9
2`0F2P`09ATK034U9`805@T;01L04@D70186200@10H0710B01P<300M4A405`/;01<71`0D20P04`L7
01D92@0@10@04@D501`@400@10@050P80104100C2@T04@L701861P0D2PX04PH601D92@0201H:2P0?
01@8200B1PH04PH501871@0D20P05PX:0104100C1`T06@d?01041P0B1PX05@T=01P<400K3a<05@T<
00805@T;02L050P:01D92`0E2@/07a<E00/10P0J3Q006`lA01hB500B20T06PlA01H;3P0F30l09a`Q
01L=3`0F2`l04@H;01X@4P0G31005@X?0106200G3A8040L<01<=4@0b;30050hB01TC5`0C3A4081XN
00P31P0H4QH03`T=01H@500H4QH0AT1402@N8P0j=3P04@/?01/E6@0N61`00P0I4aL03P0K5AT04P`@
01lI7@0D3Q8061<G01LB5P0F4AD05A0D01PC5`0J5AT06aHJ01PC5`0L5a/05A0D0P0J5AT01P0V7bH0
8A/R01`G7@0L5ad07AXO01lM8P806aTN01807QdR01dL8@0L6b00824V01PJ9@0L82/0:Rdi01`N:@0R
8bh07AlX02HV;P0M7B@08R4X02@R:00O7B<092DZ028W;@0N9Rd2028Z<@1:01lW;P0Q:C4092`d02/c
>P0/=3/0:30h02P`=`0Y<S/0=Cm:05YUL@0b?DT0:cI202hiA@0iA500;3M302dhA00^>DD0<ci:03Q3
C`0iA500>TMA030nBP0eAE40D65_0:6d`P1VNHL0=4QD0353C@0dAdh0?4]A03Q5B`0b@DH0=dU@03=5
C`0fB580>D]E03Q:EP0kCET0@UAP045CH@12E680?e5O04EFIP0lC5X0@e5L049@F`10CUT0@DmJ03e;
E00kBU80?4]B03Y9D00kBU00>dY?03Y9CP0iAd`0?T]A03]8CP0`?D<0=D9803Q5B`0c@4H0<Sm503A1
A`0hAD/0>TM=03U6C00jAdh0>TM?03Q5C@0iATh0>TM?03U6CP0gA4`203Q5C@0;03M4C00mBU80>TQ?
03I4C@0mCUH0=4E=0352BP0lCED0D65Y03Q9D@0a@TX00P0jBe<02P0iBU80=4E=03E2B00gADP0>DM:
03A2AP0c@4D0=T=:03Q5C@0f@d/203A1BP0303I3C00iATl0?T]C0080>DI=00l0>TM>03I3BP0d@DP0
=45803a9D00c@4L0:SLn03m<D`0d@DP0ADmH03M1BP0i@d`0>dA=03DoB00i@d`00P0e?dP01@0d?DH0
<ca5034j@`0_>Cl09c8f0080;cXl03T0<S`n02`f>00h@T@0?TI902Xb=@0]=CP0:c0d02`a=@0_=3P0
;c8h02P[<@0]<3H0<3<i02`_=@0a=3X0=cY002lb>00]<3H09RT_02`_=@0]<3D0;c@g02db=P0N8bT0
;c<m02hb?P0f>TH0;2ln02lc@00b=T809RXe01hR:`0Y;3D0;B`i02<Q;P0P7R/0;bdh02DS;P0O7BP0
9bH^02`[<`0Y:30081lU01hM8`0Q82L08b8[02h]=P0/:c@081lX02@R;00L6b@08b8Z02XY<P0[:S<0
9bH_02DT;@0U9C000P0T9SH0200U9cH09RPf02<S;`0O7bX08R8/01`K8`0K6R008b8W0P0Q82D0:00P
7b<07ahR024P900P7bD07QdS01`K8P0Q82P071XT01XH8P0N72L081hZ02DR;`0V8S00:BHa065OI03h
moP0oOgk07AcL00Z:BL09B<T01XH7@0P7BP06ADS01dJ9P0H5Al06aPR01`I8`0K62808b0Z05UFH01A
CUP06aPR01TF800J5b406QLP01dH7`0J5A`07APO01lJ8@0K5Qd201`G7P0501PC6P0I51/071LN01XE
700I51/00P0K51`08P0L5Ad07AHN01dF7P0N5al04``D018;4`0K51`06A8J028K8`0H4AT05@lG00d7
3P0J4a/0C4I?01/E700?2A4071DN06IPI`21Nh<071DN01TC6`0D3aH05A0D01dI7@1AC580=C0g010:
4`0K4al05@/H01hD7P0L4AX03`H<01X?5@0E2Pl201T>500:01L<4P0F2a405P/A01D:400M4QP05@X@
01`A5`0J3aD06a0F03<X;P80714G00H05@X@01H;4@0K41H05``B01H;4@0H3A<201T>500401H;4@0D
2@l050T?01D:40805``B00<07A8H02DJ800E2Q001@0E2Q00100K3QH060/C01L:4P0E2A4201@93`06
01L>4`0D3140<2P]01LA5@0=1`X0618F0`0D3aD0>@0F4AL05a8H01PC6@0F4AL05a8H01PC6@0I51X0
6QDK01TG700K6R807B0W02T]=@0O9Rh07RD_02Tc?00W=3d0<Cm<03U9EP0oDEd0AeUW04UKJ01GJWD0
Ffil06QgR@1bOI<0Lg^E08B<Z02EW;/0WJ?10:>/b02AW;H0Uj6l086?Y@1bPI@0IWN905UZN`1@HG40
BUaZ049CG`0`@D/0=dA=03i7D@0Y<3X09RXe02@X<P0T:3007R8/01@H800W:S004A0H01`J8@0G5A/0
5A0F01XD6`0H4aP05@hE01T>4`0201P=4@0501L<400F2`l05P/?01T>4P0F2`l00P0C20`03`0E2Ph0
5P/?01H;3`0E2Ph04`P<01462P0B1`/050T=01P=4@0@1PT05P/?00/2100F2`l050T=01<72@030186
200401<72@0E2@/04@D701@82P8040@600P050P:0186200F1`X05@H901L82`0I2Pd05`P;01<41`80
5PL:0P0D1@P201H72PH04PH600H06@l?01861P0I3@d05@T901D:2P0;0@4701861P050104100D20P0
6`l?01H:2P0A1@D01P0D1PH00`0L3Ph04@<300l10@0201D71`0801<41`0l<CL040H:01D83`0Y72<0
:AlQ01/?4`0E2@d201@82P0P01<72@0B1PH04@L601472`0?1PT040L:01<8300A1PX040D90104200E
1P/050D:01<42@0B0`P04`D800h20P0F2P/03@4301L;3@0?0`L05@T=00T00@0D1`h0@C@l024D700N
4AX04@D;01/?4`0Q5AT04PH:01<72`0E2@d201452@804`L;0P0=0`D02P0@1@P04`L901D92`0A1PL0
40D601461`0@10H04`L901D92`0@10H201451`0B01@82`0C1`/04@D901862P0A1@T050P<01452@0=
0PD04PH:01T=4@0E2@d04@D901X@4P0@10P05@T=01L;3`0A1@T04`L;0P0A1@T05`0B1PX04`L;01<7
2`0D20`04PH:01L;3`0B1PX05@T=00h31P0C1`/050X<01<72`0J3a807A4E01/?4`0B1`X05@`B00l6
300G31@04@H>01473P0@1@d04@H>008040D=00<04@H>01<8400D2A401`0B1@h01@0C1Pl03`8;0144
3@0E21404@@=01Cooooo000Kooooo`0H038X<@1XGVL06Q0H01H;4@0B1``04`T:01P<3P0H2`X05PP5
01D7100E20<05@L401P<300?1@H05@T;01`@4P0@1@H05`/=01451`0B1PP050P:0186200G2`d07a<E
0P0D20P201<71`804PH600X0710@01@8200M4A405`/;00T0000E2@T060`>01451`0<00804PH80P0L
4180:P0C1`T050P:01<72@0F2P`05@T;01`@4P0P51@0;20P02@H600G2`/04PH600h20P0E2@T05`/;
01P<300>0P805PX:01L=3@0@10@08QHF00l51@0=0@407Q8B0104100B1PH04`L701D92@0G2`/060`<
01L;2P0C20H04PH601<71`0D20P05`/=01P<3P0B1PP08QHJ04<g>`0F2Ph04PH:01@82`805@T;03/0
50P:01D92`0E2@/060`>01dA4`0800002`4200h2100N4Q@05`/@01/@5P0E2Q005P/A00l42P0D2@l0
5P/A01@93`0C20h03`@:02/P9P0E2a0030<802<M8@1/IVX04P`@01<=4@0D3Q8040X>01PB5P0F41@0
6A<G00P21P0?2@d06aDI00`62P0H4aH071HJ01lI7@0B31005@lC00X4200I4aL09b4U01LA5@0K5AT0
50lC01HA5@0H4aL05a8F01PC5`0J5AT03`X>01dH700D3a<04PdA01PC5`0K5QX081TP01hH7P0201XE
6`0401/H7@0L6Ql071XO01/J7`807QdR01H071/P020Q9P0M7b/07R8]02@X<`0O8Bd09BLb02@W<00R
8RX08R4X02HU:`0S82L081hT02`[<@0X;C<08R/b02@]=00S;3<082T`02</<`0R:c809Rlf0`0W<3L0
=P0V<3T0;CQ302/g@`0T<3`0?DUE030lB00g@dl0;SY602diA@0^>TH0<Ce903E1C@0g@dl0=D5=02hl
B@0eAE80<49@03E8EP0kCU`0<TIB0353C`0cATd0>DU@03U6C00fADX0=DM?03M9D`0oDE/0?DmI03M9
E@0jC5P0?e5M03]=F`0nD5h0>deK04=DI00lCE/0@e5L049@F`0nC5L0@4iI041>E`0nCED0?DaC03]:
D@0iB4h0=dI;03]:C`14DUL0@4eC03Q5B`0b?dD0<d1603A1A`80=D9800H0=dA:03U6C00iAT`0>4E;
03E2B@0f@d/203Q5C@0303]8D00jAdl0>DI>0080?4UA0100>dQ@03m<E00jB500;C]403I7C`0dADd0
<dA<03]<E00nCeL0<T=;03Q9D@0b@d/0>daD0352BP0kC5<0>DI<0P0iAdX01@0iAT`0>4E;03I3B`0f
@d/0=dA<00@0>DI?00P0<Sm703E2B00iAT`0=457034nA00e@TP0;3To03m<DP80<Ci403D0;3To03<o
A@0i@T/0=3e603HoB00h@DX0=Sm803M0B@0f?dP0>T=<03DnA`0a>T<0<3U202`e?00Z=CT0;cXl02/f
>00/=SP0<C/m05ANH011BD`0;SHi03Lo@P0e>Sh0;C8f02T^<P0M82L09BP_01lR:@0]<3L0@dI=02`_
=P0k?TD0BDaC02d`=`0[;SD0<3<j03@g?P0Y;S80;C8g03@i?`0U:C@0:Bdi034e@@0a=4<0N7^:04U<
F`0W:cL08bLb01lR:`0f=D80@T1=02PV<`02020N:@0o01hL9`0R8BT0:RTa02PW;`0U92X08b8X020O
9`0Q7b`08b4^034_?00]:cL07Q`W02<Q;00S8RX09bH^02PW;`0V9B`092<Y02<S:`0N8C4092Dg02LX
>P0V:3H08R4_01lO:P0U9Bd06aXR02DT:@0P7b@05A@I02DT:00N7R0071`N01hN8@0O7R<071/Q010?
5P0D4a/07A/V01lM:00G5B00;2Xg04U6E00Y9C<09R<^04A1AP2LViT0ZJRT059AC@0`;b/0=SDc020M
8P0J5b805Q8P028N;00J5b8061DP01XG8P0H5B005a@O01TF8@0N6bH07AXU00805a@O01<05Q<M01D?
6@0F4AP071LN01XE700F4AP071LN024L8`0I51/05Q4H01`G7P0M61l07QTP01H?5`0G41P071DM01XC
6`0G41P07QLO00807AHN01`05a0H02HO9`1@BE408AXR01TC7@0B31H07QPS07egP`0_:C<05Q0K00l9
5@1^J780OGN2014;5`0J51l071LN014?4P0P71l05Q4E02<N9@0H4Q`03`LD01dB800G31P08QLO01L<
500G3A007Q8F0P0J3aD00`0H3A<05``B01H;4@0201D:400601T>500N4aT05``B01L<4P0[82H091TO
0P0A1P`201H;4@0401X?5@0G318060dC01P=4`805``B00L05@X@01H;4@0G31805P/A01873@0C20h0
5P/A00805@X@0P0F2a400`0E2Q0050T?01P;500201L:4`0:01P;500H3A<060dC01dD6@0F3A80:1lT
01`F6P0J51H06aDG01LB608050lE00@07APN01lJ800J5A/05Q4G0`0G4QP0<`0I51X06QPM01dM9@0H
6b8082@/01<J8P0h?dT0QHnH03i;E00S<Ch0=4AA03I8E00jC5X0AeaX04mUL01CJGH0IGN707:1U01d
P9H0P8ZT08^E/02AVk@0VZJm08BCYP2:VJ`0NhZM0760T`1UMXP0FV]l055RLP1:G6X0A5EQ03=4CP0d
@DX0<S]502@[=@0W:cH06AdX01HJ9@0V:SD03a8M020S;00L72H0518M014@600R7RH06aHM00D01`0F
3aL05``B01L<400501P=4@0301D:3P0C20`050T=00805P/?00<05@X>01@93@0C20`00P0B1`/0200C
20`040D901L<400G31003P<700d21P0>0`L06`lA0P0F2P`02@0H30h05@T;01@82P0D20X05PX<0145
1`0@10H04PH800d10`0201D62@0401H72P0H2@`05`P;01<41`805@H90P0D1@P201D62@<04@D50`0B
1PH01P0h;2`06@d=00l30`0H30`0@SHf01`@40H04@D500X04PH601451@0C1`L060`<01D92@0B1PH0
4P@401<51@0D1PH05@L70P0F20P02P0G2@T04@<301430`0F20P05`T901H72P0F2A402P0400l22@0E
20l201T=4@0=01D93@0E2@/050P:01@82P0D20P04`T80188300>1@P040L:01D:3P0C20`04@H:0145
2@0201D62`804`@900X04P@60104100B1PH04@D60186200C1`/03`D701@8300800804@H<0P0<00P0
3`0=00P07A4E02LK7`0H31003`<701862P0T61`0710D00P0000@1@P06PhB01L;3`0E2@`04@D700X0
000201<72@0301`@4P0?0`D04@D700@04@D701803P8500`0100F2Ph03@4501<72`1REUX0:QhR01X>
4P0>0PH03`<700h21P0C1`/0200003T]<@0=0@D050P<01D93@0D20`2010420@04@D901@04PH:01H:
3P0<00@05PX>02/O8`0U6Ad0;20T01D93@0O4aL0Cd=709Z>TP0S5a/0200500h32`0C2100714I020E
7@0G31@04PL?01463P8040D=00<04@H>01873`0A10d01@0A10d01P0B1@h05`XC00h12P0;00L040<<
00h12QCooooo000Kooooo`0D01T?6019?dL03@<;00l42P0A1P/04@L802<G6@0P4a<06`d:01L91P0E
20804`D201@8200E2@/040@601D92`0A1@L05`/=00l31@0A1@L201H:300401hB500X71h050P801@8
20804`L70P0B1PH01P0=0`<040@401451@0E2@T03P8201H:2P805PX<0P0B1PP02`0@10H02P0002`P
8P0S5aT07A4C01@82P0A1@L02`0101/?3`0[7al08ADE008060`<00T05@T901061P0I3@d0;20P01H:
2P0D20P05PX:01@8200:00000P0L41000`0?0`<060`<01H:2P0201D92@0?01H:2P0H30`06a0?01T>
300E2@T04PH601D92@0F2P`04`L901041P0P51P0BSi201`@500H31005@T<00805@T;010050P:01D9
2`0E2@/06@d?02@H6P0B1PP06@d?01@82P0G2`d04@D:01/@600D2A404`P@01873`0D2A405@XB0P0D
2A40;@0C2100GU=K01`A6@0J4AH030H:02<M8@0D3Q8081XN018=400V82@04P`@010:3P0C3A409AlS
02`V:P0D3Q805@lC01@>4P0N61`0618F01dG6`0B3100:bDY01H@500R72003PP<01@>4P0B3A405Q4E
01/F6P0J5AT06A@H01XE6@0Z9BT0>SDi01`G6`0P6al07APL01HA5@0K51/06aDK01XE6`0K5Q`071TN
01dK800201`J7`0E01lN8`0N7B8071/P024R9`1?Deh0<SM301HJ9P0J7RT07B0Z01lR:`0O7bL08b<Z
02DT:P0S8BH09B8W02XY;`0U:S007bP_024Z<@0R:c8082T`00<08b`c00X092dd02Pa>00Y<ST09c4j
02Lb?@0g@dl06RHb02/g@`0U<Cd07RXf0P0_>dL05@0`?4P0=41<03Q4D00iAE40<cm;03M5DP0eAE80
<D=A02`oCP0gBUT0=DQE03A6DP0cATd0=DE=03M4BP0fADX0=4Q?03E9DP0mDEX0>TiG03E9E00203]?
FP0J03I9E`0oDV00=DQF03]>G@0iBUP0@DmJ041>F@0lBUD0?deH041>E`0lBe<0>4M>03U8C`0hAdd0
=dI;045@E@1@GV@0@DiD03A1A`0c@4H0;S]102dj@00c@4H0=T=903M4BP0hAD/203I3B@0703A1B00h
ADd0>dQ@03U6CP0lBE40>dQ@03M4C00203U6CP0B03Q5C@0kB500=TA<03=1BP0hBE40=DI>03A5C@0i
BU80<45903=4C00hBE40<dA<03Q9D@0gB500>DYB03m<DP0lBDl0>dQ>0P0nBe40100hADd0=T=;03I3
B`0gA4d203Q5CP1003Q5C`0i@d`0>TE;03Q3B@0c?T@0=3m503M2B00e@4H0>DA:03E0AP1?FV00:3<i
03E0AP0`>D80=Ci703@mAP0c?4D0=3e6038kA00a>T<0=d19034j@`0]=Sl0;SM002/d>`0X<cL0<3/m
02Pc=@0R;2h0<3Xl06QbM01IHF@0<SXm02Xb=@0V:bl0:Rlc03Hk?`0S9Rd0;S4h02T/<`0i?4<0F5]R
04U<D`1^LGP0V9^R0413BP0_<ST0<cHm02ha>00^<cL0:2db03<h?P0M8B`0<cM302DX=`1KGVd0h^Gd
08R;VP0Q9C409b/f0412CP0e=400?C]802TW=0808AlZ03P09bD`01dL900U92`09B@/02DT:P0Q82H0
6aXR028P;@0R82h0;2Xh02`Z=`0N72T09R@_028Q:@0Q82H08b8X02DT:P0T8bP08R8Z024S=00U9SP0
9RLi02<U<`0Q82h07QhY02@T;00[:S80<C0e028Q9P0D51H07QhP028R900O7b408R4U02<R9`0O7R@0
7ahU024P:00K6B@06aTU03Pf@`2:R9D0]K;0044mB`0U8Rd07adR02h]:`10?c/092<N01`K5`0Z:BL0
7Q/P01lL9`0L62H0920^01/H8`8061DP0P0D4A`0200N6bH06QLR00d:5@0E4Qd07a`W01dJ900M5b40
6QDL0P0M61l01@0J5A`07APO02<N9@0N6B0071LN00807APO00<08ahU01TB6P0F3aL00P0I4QX00`0E
3QH0614I01L@6002014:4P0`01/D700b:c<05PhH01<=6@0@2QH04`dJ034[>@0<1Q8050hK024K:@0i
<cl08Q`Y04m9E`0S7BX030H@01XH6`0D41<00`0201/F7@0D3AL06a<P028G9@0F2aL06@hF00h12P0D
20d07A4E01`A5`0K41H06@hD01P=4`0G31805@X@01L<4P0J3aD060dC01873@0?10X04PL=01H;4@0D
2@l0714G01lD6P0H3A<050T?01T>500H3A<05``B0P0F2a401@0G31804@H<01@93`0C20h050T?0080
5P/A00@050T?01H;4@0F2a405P/A0P0D2@l0100J3AH06@`E01P;500I31D201T>500=01P=4`0H3a@0
2`8701D=3`0E3a401@0101D@5P0G4QP050lE01TD6P0K5Q`05a8H01HA5`0201LB600d01HA5`0I51X0
6QPM01@D700K7RD0B4aD028Y<@0M92h0Mh6:03I3C00X=T<0<41=03E7D`0hBUP0A5UU04eUK`1@IW<0
HG>306mnT@1`Oi@0NhNN08JBZP2CWkD0XK3308JGY`24UJD0MHFF06imT01TMHL0FFYk04mPL018FVP0
@U=P03Q9D`0hADh0;cU202P_>@0/<3/0<SM202<Y=@0D62@092Ld08>5T@0[:cH07A/V01XH8`1@CEL0
E4iH020J900R6b@05P/A01H;3`8060dA00D06@hB01X?4`0F2`l05@X>01@93@0201H;3`0301D:3P0D
2@d050T=008050T=00H04`P<01872`0H3A406PlC00d21P0D2@d201T>4P0<01T=3`0C1`T050P:01P<
3P0D20X04PH801<72@0F2P`04PH801451`0C1`T03P840P0D1@P01P0E1PT05`P;01H72P0B0`H05@H9
01@520804`@700@050D801D62@0@10@040@40P0A1@D201861P0501P<300C1`L0200003<W9`11=CD0
1`0A1@D301861P<04`L71P0D1PD301D71P0:01H81`0E1`H050H60144300N4AP05PT@01L:4@0H3100
4@D901<72`804`L900X050P:01@8200C2@P04@L;00`31P0>1@P050T=01<8300@1@T04@D90P0F1``2
01@52P0Q01<51`0B1`D03`<301<7200@10H04`L901862P0Q51/040<:00h32@0@0``060/E01@73`0F
2Ph06PhB01@8300?0`L04@D903/_<`0e:Bd03P8600h41P0H31003`<700X00@0B1PP04@D701041P08
00005`/=01041P0>0P@03@4300<03`<501805@T<01862P0D20`0200001`@502fZZh0;20T01X>4P0>
0PH040@800h21P0B1PX0Ac/o0:6EV@0T61`04PH:01<72`0>10H401862P804@D900@05@T=01H:3P0?
0`L05@T=0P0]8BD03`0<00@0200000l51`0/82@0JUiR01L;3`0A1Ph06PlG01<8400<0@T040D=01X?
5`0D2A404`P@01463P0301053@H04@@=00@05PTB01lB6`0B1@h02P060P0@0``Dooooo`006oooool0
4`0B1`d040H<01D;400=10L04`T;0147200E2P`04PL701hC4P0F2@L05``:01061@0C20T05@/<044g
=`0E2P/05@/<00d20`0D2@/00P0B1`T01P0@1PL04PL901P=3P0E2@X050P901<720804PH702@04`L8
01451P0K3a004@D601861`0D20T060`=01D92`0H30h04`L901@82P0G2`d04`L901`@4P0M4A<050P:
01<72@0M4A<04`L901@82@0M4A8060`=01861`0I3@h081@E03L[;00?0`@05@T:00h30`0J3Pl05@T:
01X>3`0G2``060`=01H:2`0A1@H201/?400501<7200F2P/04PH700h4100H30d00P0E1`T06P0F20X0
60/<01L:300F20/05PT;0185200K3A404P@801X=400C1PT05PX<01P<3P0I3@l05`/=01@82P0F2P`0
5`/=01D92`0F2P`050P:0186200E2@d060dB01D:3`0C20d05@X?0P0G31403P0C20d05P/@01hC601D
BDh07A<H0107300E3Q@04``B014;400?2@h0@3Xo08IoQ@0F41D06a@J0P0D3Q<0D`0E3Q@040X?01dF
700H4AL06A8I00`62`0J4aX0ACi507=]LP0Q6R005a0G02LQ9P0N61h05Q4E01LB5@0J5AP06ADG01LC
5P0H4aL05a8F028M8@0H4aP0:bH[05]FF`0K5Q`071HM01`G700P6b008A`Q020L8@0Q7R<081dS01hK
8@0N72807a/Q01lL8`0K6B00FU]T03TlA@0F6R<07AhX01hQ:@0L7bL06ahV02@U;P0o@DP08R<[01lQ
:00R92`0720Z02@[=00L92d09Bdf028Z<`0V;SH09c0h02@]=@0V;cL0:C8j02`f?P0X<S/08Rdf02/g
@P0Y=T00<3a702Tf@00^>dH0<Ci903E2C@0/?4H0<T1=03]8E@0nBeL0=45@03]9F00d@e40=4A@03A6
D@0a@d`0>DYC03A5CP0c@dX0<d9:0080=49:01X0>D]D03=5C`0cAU00<dE?03M8D`0lCeT0@59M03a>
F@0kCET0>4]H03i?G@0iBUL0>T]F03e?FP10D5/0?diI03m>E`10D5P0?TiE03e<DP0hAdd0<d9703]:
CP18EU/0>4E;02dj@080<Ci400h0<Sm503]8CP0hAD/0C5UO04YGG@0`?D<0>4E;03E2B@0iAdh0>DM?
03E3B`0hATd0>DM>03U7C`80@U1H01T0>TQ@03]9D@0iAdh0>4M?03U9D@0iBE00>d]C041@F00nCUD0
=dM?03I6C@0dA4`0<d=:03Q8C`0eA4/0>dQ@03I3BP0lBE00>dQ?03M4B`0_?4@0<Ci603Y7C`0d@DX0
<d180080=D9;02d0<Sm70390A`0f@dX0=D5803<oAP0d@4L0?4M>03@nAP1GHFT0IFmf03a6C@0f@4P0
;SPo03<mA@0f@4L0;cQ0030i@@0^=cl0;3@l030h@00]=Ch0;3@l02dd?@0Y<CP0;3Dk02/e>P0/=SX0
;CDk02H_<`0d?400<STm02T_<`0^<SH0;C4e02/_<`0X;C409R`b01lU:`0R:2h0:C0d03@j?P0m@DH0
PhN=0;Vm`@13Ad/00P0_<cL02@0]<3H0<CDn024V<P0V:cL092Te024U<@0X;3T0;Blm04Q:F00202T/
>01i03Df@P1LGFP0;bdg02LS;@0P7RP09R<]028O:@0Z9c409R@]02HU;P0U8bd09B@]024Q:P0L6bL0
9B<b01XH9P0O7R`07ad[02@S<00n?DX08R4]020O:@0O7bT08b</02DT;@0T92l092He02DU=P0S8c80
8R8`02<R;P0O7RX071/V028P:@0P7RD07adS028P9P0N7B<07ahS01lN900Q82D08R4X020O9P0L6R@0
71XV01lM:`0R82l0:RPg05iKJ`1iMhH09b@a01HC7`0Q7RL08B0U02TX:`0T8bD06aXK01/J7@0M6b40
8b4Y01PF800K62<0510K01XF8@0H4ah05Q8L01TD7`0L5b806ADM028N9P0V8RX081`T01TE7@0N6B00
7QTO01PC6@0O6R406aHL01PC6P0F4AT08adV01/F7P0M5b0071HO01/E7`0S6b<060lH01lE7P0R5b00
7QDN01/A6P0M4Q/06Q4J01lF7`0J3aP04`XC01X@6P0N5b<05@lL01PB7`0D3Q/04P`I01<=6@0I4b00
5@lJ02LQ;02`Zk@0ACm9018<500D3a<04@`?01H@500L5Q/05a0H01TB6`0D31D05@`E01L=4`0>1@T0
5`dC0147300201T>500;01`A5`0K41H05P/A01D:400F2a405``B01D:400F2a4060dC01H;4@0?10T0
0P0H3A802@0E2Pl060dB01T>4`0G31406@hC01P=4P0F2a005``A01X?500201H;40805@X?00@050T>
01<83@0G31405``A0`0E2Pl04@0D2@h05PX@01863@0I3AD05@/C01<:4P0E31@04@TA01<;4`0H3aD0
5`hB00l52@0G3a@050dD01H@5`0C3A@04P`C00804`dD00<05Q0G01PB6@0I4aX00P0K5A`0<`0I5Q/0
71`P01PI7@0H6b408RH^020W;`0R;3D06RHb02dkB00/>dT0>DYI041AH011E6<0CF9`051TL`1KK7d0
I7F706UiS@1bPYL0N8RL07b<X@22TZH0N8VL07Z<WP1aPY@0J7V;061aP`1IJg`0CF9`04MII`0oDEd0
>daF04=AFP13CUL0;CDo02<Z=00Q9Bl06adX02<T;`0O82X0;2`f01LF7`0I5b0061HM01TE700C3Q@0
4@`C01TB6@0H4A@0610C01H?4@0201@<3`0401P@4P0G3A405P`@01D;3P805@X>0`0D2@d0200C20`0
50T=01D:3P0F2`l040D901H;3`0B1`/04`P<0P0A1PX01`0D20X040@60186200H30h05`/=01D92`0B
1PP00P0C1`T201@82P0901451`0C1@P04`D801@62@0D1`T050H901841`0E20X050L900804`D800d0
4`H801@62@0D20P05PX:01<71`0A1@D04`L701451@0E2@T03P@4024E5@1:?Sh050T900804`L701h0
4PH601451@0A1@D04@D501861P0E2@T04`L701861P0E2@T03@<302@H600H2`X050L80185100B1@D0
4`H701@71P0B1@D05@P901D8200D1`L04PD601041@0A1@T04@D;0148200B1P/06PlB01051`0B1`X3
01872@0:0187200B20T040H:00h21`0?0`T04PH<01452@0?0`L04@D901<62@8050H:01005@L;01@8
2@0G2``0304101@82`0A1@P050P;01452@0=0`H03@8601@73@0<0@L050L?01442`0@10P03`<70P0A
1@T09P0B1PX0710D01D93@0?10L04PH:00d31@0A1@T05PX=0145200B1PT04`L:00/10`0K3a804`L:
01041`0?0`H04`L:00d3100G2`h05@T<00l31P0R5AT07Q4E01X>4@0U6A`060/?0143200A10P06@/@
01H83@0@0`L081@H06AHG00G2`l050P<01H:3P0?10L050P<0P0F2Ph201452@0E01P<4@0O4aX04`L>
01863@0;0@H040@;01lC6P0=0PP06`lG01873P0E2A003@<90104300C20h050T>00l52P0E2Q404`P?
00h32P0F2a804@H>00804PL?00h03`<<00h3300B1@l04`D@00l2300@0`h060/E01T<5P0F2A@06`hI
01@74@0<00X050LA01853aCooooo000Kooooo`0J01@:2`0E2``05@/<01<92P0A1`P03`D60147200M
4a@0^:j_05=9BP0@20P0:AlP01dC500=0`@06@l@01lE5P0B20T0718C01X@4@0D2P/0308300l51P0>
10D02`4201L;3@0E2@/201<72@0S01@82P0E2@/08QHH00X0000>0P@06Ph@01<72@0;00404@D701<7
2@0?0`D04@D701@82P0A1@L05PX<020D5P0E2@/04`L901P<3P0B1PP05PX<01dA4`0Q5AL060`>01H:
300M4A<05@T;01041P0J3Q0050P:00h2100<0@803`<501451`0D20X00P0F2P`0100@1PL060`>01T=
3`0>0P@201@82P0301T;3P0E1PT05@H900<05@H900<05PL:01L82`0G20/00P0G20/02@0J2`h0:Q`O
01T=3`09000050X;01451`0E2@/06@d?01@82P0301H:300501@82P0@1@H040H70147200C2@X00P0J
41401`0B20T05P`=01H<3@0C2@X05`d>01`C5@0A20d00P0D3A@01@0N5ah04@XA01L@5`2<QH`0<2T`
008040T@00l05PlF01PA600K51`050dE014:4P0I4QX07aPP01hG7`0<1@d0;BH^00l8400E3QH08AXR
01TB6@0H4aL00`0I5AH02P0J5AP05a8F01TD600N6Ah061<I028M8`0d;cD071LM01hI7`0L5a/201lJ
7P0Y01`G700N6Al09b8Y01dH7`0G4QT081XT024K9@0L6B8081lU02<T:@0L7B8061PP01/L900K7RD0
6alX024U;P0f>T<06R4[01`S;@0Q:380ADUD04]?FP0W:cH0:c8l020W<@0S:S@09c0i02H_>00Z<c`0
:cDn02Pb>`0`>T<0:S@m02`i@@0^>d<0;S]402dkA00_?DH0;ce803A5C`0`@D/00P0`@4d02`0_?dh0
<d1C03I3EP0f@e<0<d5<0350A`0b@DH0=TE90391AP0a@4L0=D=<0080>DMB01<0>daF03a=E`0jBeD0
>T]E03i?F@11DU`0?4eG03Q9D`0jBeD0=dQB03Q9D`0lCUT0>4aG03Q:EP0jC5L0>D]E03]<E00nCeH0
>DYA0080>TU>00H0=4=803E3AP0mBTl0>TM=03=0AP0d@DL203U6C00;04QEF`0gA4X0@DiD04AAE`0e
@TP0?T]A034oA@0d@dX0=DA;03=2B@0fAD`00P0eA4/02@11D5L0@U5H03E4B`0gATd0>4M>03I5C00h
Adh0>dYA03U8C`0203Q7CP0K0391B00d@dX0>4M>03U8C`0gATd0<d9903a9D@0iATh0;S]303Q5C@0e
@TX0>DI>030mA@0hADd0<d1803M4C00c@4P0>4E=0391B00d@dX0>dYA03Q7CP0a@4L0=T=;03Q2B`0^
>440@deF0080;3Dn00@0<CY303E0AP0a?480>DA:0P0a>T40?@0c?4<0;C@l02`c>`0]=3`0<3@m02hb
>`0X;cL0;cHn02Xc>P0Y<ST0;SDm030g?P0/<cT0;C8h02lc>00Z;C80:2/`02/^<`0V:bl092/a01hW
;00S;340:30c02/c=P0`>3/0;c@g04=8B`0/<3<07B4R02X^;`0Y;S80:Bdi01hT=00V;3`08bTg02T]
>@0V:SH09bTf01/M:@0N82`0;blk028R;P19Ae80;BTa02/V;@0T7bH09B4X024N9`0^:c@09B<[02@R
;@0V92l09B@_02<S;`0Q8Bd09bHd02@S<@0/:cT0;B`j04I5D`1dLh400P0N7B/08P0O7R`08R4_028Q
;`0P7bd0828_02HU<`0S8S008R4_024O;00P7RX08AlZ020M:00N6bD06aPQ01`F800K624081lW028Q
:@0S8RX09RD]02@R;@0M6bP06QPV01hK;00Q7Rl07a`]028O<P0Z9cL09bDb02DS<00X9S80:BLb02DS
;P0L6b@201HE7@0;01XI800O7R@081lU01PE7P0W8Bd091hZ01lI900d;SP05@lI01TD700I51/00P0L
5ad0700J5A/05Q4G01hI7`0L5ad05A0F01PC6@0E41H06QDL02<M9`0E3aT06aDO010:5P0B31P06A8N
01P>6@0/82X06`lI01<74@0G2aD06@dG034U;`0]8B/091PR01dA6`0L41X06a0I01H>6`0H4Qh201<=
6@0D01TC7`0A2aD071HP01/E7`0@2a809R4W01<>500N6Al050hB01PB5P0C3A401P0401H@501;ADT0
50hB01dG6`0K5AT050hB018<400T7R8201@93`806PlE0P0D2@l00`0E2Q005``B01P=4`0201L<4P0=
01P=4`0O51P09Q/O020E6@0H3A405P/?01<8300E2Ph0714E01dB5P0H3A4050T=01D:3P0201H;3`80
5@X>0P0D2@d0100H3A405P/?01D:3P0F2`l201T>4P0=01X>4P0R5ad05`hC01L@600D3QP01`4;01<=
5`0B2a<05@hE01H<4`0E2@d05``B01H=5@0201<<500L01@=5@0E3QH05PlG01PA6@0I4QX06a@L01`E
7@0I4QX05Q4G01TH6`0I6Q`06Q`P01XO9@0N8R/07bLa01lY=@0Y=D<0;Ca<03I6EP0oD680@55R04UJ
JP1=GVh0E6Ef05]/OP1PLHD0J7V=0762UP80Lh>J0200MXJM07B4V`1_P9@0HgB605U/O@1CIgL0B5i/
045GI00oDel0=4I@03I4C@0g@d`08bdf020W<@0V:34092<[028Q:@0R8BP07ahT01`I800I5a`061HK
01HA5@0D3a<05A0D01TC5`0;1`P03PX;014=3P0B3Pl0510A01`F60<050/>00T05P/?01P=4@0J3a<0
5P/?01D:3P0B1`/04@H:01<8300G31000`0D2@d301<8300301451`0C1`T04`L9008040@600<05PX<
02@H6P0G2`d00P0:00000`0B1PP06@d?01862005018620<04`L901<050P:01H:300F2P`04@D501L;
2`0A1@D03`<301861P0@10@05PX:01051@0F2PX03@4101@8200F2PX050P801<71`0B1PH04@D50080
4PH600P04@D501D92@0D20P040D500P0000d:2P05`/=01<72@804@D700<04PH801@82P0C1`T00`0C
1`T201451`0701@:2`0@1PL06@l@00l51P0G3@h0308301<92P0301882@030147200A1PX04PD=0080
4@@;014040<:00l31`0?0`L03P8600l31@0@10H04@D701451@0@10H06`lC00l31`0F2Ph040@80186
2P0A1@T04PH:01452@03010420804@D90`0B1PX00`0C1`/08aLK024E6@0201<72`0G00h21P0=0@D0
4`L;00h21P0C1`/05@T=01<72`0E2@d03@4501862P09004040D801@8300=0@D0304301/<4@0F1``0
6``A04/l@@0K3A4060T>01H7300H2@h00P0N3a@0<@0G20d03`<701@8300;0@<03P860104200F2Ph0
4@D901@8300E2@d03`<70104200J3A<07Q<K00T01`0A1@l01`05028F800@10h05@TC00T01`0<00X0
4@D?01P<5P0@10d050T?01@93@0C20`04@H:01052P0>0`T05@X@00h32P0B1`l050TA00l3300>0P`0
3P0=0143400<00/03@0<01H85@0E1a@04P@A0143400B11403@0<01H85@0@0Pl05?ooool001_ooooo
00/04`T:01L=3P0G3@h050X;01<92P0E2``02P0101`B4`13>CX03P@501061`0200L0000601H>3P0=
0`@04`T:01492@0A1`P04`T:0P0B20T01@0M4a@0718C0147200E2@/050P:00<04`L900D050P:01`@
4P0@10H04PH801L;3@0201D92`0301L;3@0F2P`04PH800804PH801003`<501@82P0G2`d050P:01<7
2@0E2@/050P:0186200G2`d0710B01L;3@0B1PP050P:01041P0B1PP05@T;0P0C1`T01@0N4Q@04PH8
01D92`0D20X04`L900805`/=00H06`lA01X>400I3@l05@T;00l31@0A10H701D62@0;01@5200C10L0
5@H901T:3@0Q4aH02000040d=P1ODeD09ATK02LK7@0>10D00P0E2@/0:00F2P`05@T;01D92`0E2P/0
8ALH020F5`0D2P/060h?01H<3@0A1`P06a4B01@:2`0<0P<05P`=01T?4@0@1``04@/?00l93@0H4QH0
5@lC01XD601OFEd08A/O01<=4@0B31006A<G01H@500E3QD04@XA01TB6@0L5A`040T@00P120090PT0
7QLN01L@5`0F3aH07AHM01H?5P0A310201PD5@0;01HB4`0J5QP04`hB01dH700H4aP04PdC02@O9@0>
2A007APN01dK800J61/00P0K6A`0>P0H5QX06aTN02<P9`0J5ah05Q<J02/X<@0N6b@08QlX01lN900[
;3409BH[01/K8`0K72@08B@[01lS;00M8BX05QXS01/R;00P9c407B@^02@X<`0]<C`05a/V01lV<00Q
:380:S4k02H_>01;E5d0624Z030j@`14CUL09Blh02dg@00/>D40:cQ002Xg@00Z>440;3Y302/iA00Y
>DH0<T9?03A4D@0b@Tl0<d=B03A1E00f@eH0=45A034oBP0_?TD0;ci303A3B00c@TT0<T5803=1BP0g
AE00>TQC03=4CP0jBeD203a=E`0G03m@FP12Ded0>DYD03Q9D`0lCEL0=dQB03I7D@0kCEP0=TYE0394
D00fB5<0=TQB03M8D00iBU80=dQ?03Y9CP0mC540=dI;03=1A00f@dP0=D98034nA00c@4H00P0hAD/0
1`0oC580>DI<03U6C00c@4H0;ca203U6C00e@dX00P0eA4/0200b@DP0=DA;03I5C00b@DP0>4M>03Y9
D00b@DP0=4=:0P0fAD`03P0hAdh0>TU@03Q7CP0gATd0>4M>03=2B@0eA4/0>4M>03U8C`0gATd0=4=:
034nAP0gA4`0?4UA0P0]>T805`0_?4@0<Sm7038oA`0b?dL0>DI>02hk@`0hADd0<T5803=2B@0gATd0
=DA;02lnA@0c@4P0>49;038lA@0_>D80;3Dn03<lA@0b>d@0=3m502lj@00e@4H0;SLn0080;cPo02`0
;3<k02/b>P0[<SX0;S8k02da>P0X;cL09bhf02df?@0Z<cX0;3<k034h?`0X;cD0;c@j030d>P0Z;C@0
:B`c02`_=P0X;C<092/c01lX;P0T;C80:2le02H^<P0X<3<08bP/01lS9`0^<SD0;C4d02T];`0Z;c<0
:Bdh024W=@0Y;cd09BPg02DY=@0O8bl07b4^01lQ;@0W:CD0;Rhj01lO:@0Z:3<09b@/02/X<@809B8[
02008b0[02l]>00O7RT0820/024Q;@0R8bl08B<`028T<@0];3X0=SE300403P1NGF/0MgJ401hM:`0L
6bT07Qd[028Q;`0V9C<081l]01`K:@0Q8c00:RTg02LV=00R8Bl07adZ01dK9`0N72L07a`W020M9`0O
72D081XT01hK90807A/V01d07adX02@R;@0Q7b`06aTV01hL:@0P7R`07ad[020N;00K62T05Q@Q01PF
8`0L6RL07adY01hL9`0J62<06QTR01lN9P0P7bL071/R01XI7`0O7R@09R8[02LQ;@080Ph0:B<^06=M
I`0U7bT04`hF01PC6P0201XE6`0B01TD6P0G4QP071LM01LB600M61h05Q4G01@?5@0J5A`05Q0J028L
9P0F41X07aTU02LQ;@0J4ah0:AlZ05Y>F00e:C<09ATS0P0Y7BL0800a9Bl0:AdW01dA6`0J3QP06`lI
01P=5P0@21D06aDQ01H@700Q6bD0?3I002lY<`0500L04PdD01<>5@0A318061<I01@?5@0E3a<05a4E
01D?4`0<1PX04@/?02hX;00M5a/030L:014;3`0U7b<050hB00l93@0E2Q0050T?0P0G31800`0D2@l0
5@X@01H;4@0201H;4@0>01L<4P0I3Q@06@hD01X?4`0Q5QX0714E01L<400F2`l05@X>01L<400O51P0
8AHJ01dB5P0G310201H;3`<05@X>0P0D2@d05`0F2`l05@X>01D:3P0F2`l05``@01T>4P0G2`l03`@:
00H00P0E3QH0618L01LA6`0C3AL040TA018;4P0B20l04`L;01D:400D31@04P/C01<<500E3QH05PlG
00805a0H0P0J4a/0>`0H4AT05PlG01D@5P0J6A`06Q/O01TK800I7R@07B4Z024Y<`0T;SX0:SI402Xi
B@0b@U80?4]N03m?H@17F6P0BU][05AUMP1NKh40HG:406AeR01[O900KGjB06emT`1`P9L0KWjE06]l
T01SM8H0G6n005]_O`1@IW@0A5YW041DG`0^@4X0;C]402Hb>`0P:S<0:C0j02HX<@0V9Bd092<[02<R
:@0Q82H07AXQ01`J7`0I5a`05a8F01<>4P0D3a<06A<G01LC500H51D05a<D014=3P0=2@X03@L901P?
4P0F3A0050/>008050T=00T05@X>01P=4@0F2`l04`P<01462P0B1`/05@X>01@93@0E2Ph00P0F2`l0
3P0E2Ph04`P<01041P0I3@l07a<E01@82P0>0P@05@T;04@h>P0^8R@05@T;00h2100@10H050P:1P0B
1PP201D92`8050P:00h05@T;01H:300>0P804`L701861P0@10@04`L701451@0F2PX050P801P<300;
00005`/;01<71`8050P800<04PH601451@0B1PH00P0B1PH01`0?10@04@D501861P0900006`l?01H:
300D20X0100B1PP601<72@0701<92P0@1PL06@l@01<92P0O5AH04`T:0147200301882@0601<92P0C
20`050L?01<63@0B1@`04@@;0`0?0`L02@0A1@L04PH80186200?0`<0308201862P0:008050P<00h2
1P0201@8300301<72`0B1PX04@D900804@D900<04PH:01<72`0B1PX00P0B1PX05@0A1@T06@dA01H:
3P0@10P04PH:00d11@0>0PH03P@603P/<01`I6P0Ac/o00P0000=0@D06`lC01X>4P0C1`/050X<02LK
7`0A1@T040<701421`0201D62`0302TJ7`0G20d05@H;00804`@901`060T>01T:3`0E1P/04`L;01T=
4@0C1`/05`/?01P<400R5QX03`<701452@0B1PX040@801452@0E20h0PWMo02DJ8P0J3aL03P<;01H;
4`0J41L0;R<[00P01@0R5al03`@<02LL900900H04@H<0P0A1PX0400@1@T03`@900l42P0B1`d03`@;
01873`0C210040D>00l33@0>00d04`DB0143400B11404`DB00l13P0C1A8201844@0300X02@0@0Pl0
200701Cooooo000Kooooo`0900h41@0D2P/05P`=01<92P0E2``0718C01H=3@0?1PL05Pd>00805@/<
00d030<402PN7`0`9RL05`d>01H=3P0C2@X05@/<00`30`0C2@X05P`=02DK700P5QL030<400H04@D7
00D04`L901041P0D20X05@T;01451`0201<72@0301041P0A1@L050P:00805@T;01h04`L901451`0E
2@/050P:0186200E2@/04PH801451`0B1PP050P:0186200@10H05@T;01<72@0?0`D05@T;01L;3@0T
61X04PH801D92`0C1`T04PH801L;3@0B1PP03`D601D92`0C1`T04PH801P<3P0D1`T501@5200=01D6
2@0G20/060T<01P9300F1`X05`P;01P;3@0C2@X03P@502DI6`0F2P`0200001T=3`0501D92`0b01@9
2`0W7Ah0:1hO0147200B20T05@/<01`B4`0F30d050X;01D;300D2P/05`d>0107300D3Q805a4E010:
3P0>20`05@lC01@>4P0:10P06A<G00l93@0D3Q805Q0D01D>5@0C31<05PlF00l83`0J4aX0GeQO024J
8@0K51/06Q<J01<<4`0G41L0618G01@?4`0L61T061@E018>3`0I5AL05A0D01<>4P0J5AX081/Q01dH
7P0M61l061<I01`J7`0I5aX201/I700R01/I7@0Q7b@07a`S01dJ8@0O72<0>SM001/H8@0L6b<06aXP
02HW;00T9BX07AdU01dO9P0O8RT092Pa01TM9P0K7bP09B`f024X<P0J8B/06AdX02HZ=@0T:3<09bhh
028Y<`0P9c40?DI?071iPP0]=Sl09c4j03e7D00Q:c@0;CM102/h@080:CHo02/0;C]502lmA`0jB5<0
:CU603I6D`0gAe@0=TID03U9F00iAUP0>4EF03E2DP0a?d/0<3i70391B00iB4h0>DQ?03E4B`0_?DH0
<3i903A2C@0a@T`0=4E?03Y;E@11DU`0?TmI03Y;E@0kC5H0?DiH045BG00lCEL0>DYD03Y<EP0fBU@0
>TaG04EGHP12E5h0>T]C03Y;DP0kC5<0>dY@041?E00kBTl0=TA80080=dA:00<0=45703=0AP0d@DL0
0P0b?dD01P0lBDl0>DI<03I3B@0hAD/0<Ci40390A`80=DA;00<0=4=:03U8C`0lBe800P0hAdh01`0i
B4l0=DA;03M6C@0iB4l0=DA;03M6C@0hAdh00P0eA4/0700gATd0>TU@03Q7CP0d@dX0<d9903E4B`0h
Adh0?T]C04]HH01oS9@0>TM?03a9D@0`?DD0;ca403M4C00a?TH0=D9:03=0B00iATh0=TE<03E4B`0f
AD`0<d9902lnA@0c@4P0<3Y303]5CP0^>44203Y3C00:034j@`0d?dD0<ci403Q3B@0a>T40;cPo02L`
=`0^=Cd0;C@l02`c>`80;c<l00h0:S4i02H]=@10BE00=d1702Xa>@0]=3/0;3<j02`a>00`=3/0;2lg
02/^=P0/;cL09RXb02T`>0808BX`00@08bXa028Y;`0U;3409b`a0P0Z;S80?P15B4`09RX]034f>P0T
:3<08RPf02db@00/;cd0;S4m02DX=@0P8Rl08B8^02DV<P0Y:C@0;Rdg02HT;`0U8bd0<Rli02TY<P0X
9Rl08b8]02//=`0P8B`08B8_01lR;P0N8Bh08B@b02<U<`0Q82h0:RTg02@S<@0];3X0:bXh03@c@@0Q
82h07ah/02DT<P0W9S@08B0^020O;@0W:CH0;B`j02PW=@0S8S008R0]020N:P0P7RT08QlZ028O:@0R
7bP08adW028O:P0P7RX071XV01dK9`0S8Bd081h[01TG900P7RX07adY01HD800M6bL08Al[0`0L6RL0
4@0J62@071XU028P:`0T8R`07QdU01/J8P0F5A`05QDK01XI7`0P72D05@lK020J9P0O6B@07QPR01H@
6P0M5b006QDL00@06QDK038061<I01@?5@0[9R`07aXP01XE6`0J5A`06A<M01D?6@1cKGL0>C<o01TC
7`0P6BD03`D@02DJ900M4Q/05``E01hC700F2a@06@hG01P=5`0H3AH060dG01X?600M4Q/05`lL01/D
8@0C31P04P/F01hG8P0D3QL05a4H01D?5P0N61l02@<901D?5P0?2A006Q@H01@>4P0H4QH06aDI01@>
4P0>2@`03PP<01D?4`0N61`050hB01TC5`0@2Ph060dC01D:40805``B01405@X@01P=4`0J3aD05``B
01@93`0E2Q005P/A01D:400C20`060dA01D:3P0D2@d060dA01L<400C20`05P/?01L<400201H;3`03
01P=4@0E2Ph05@X>00@05@X>01<060dA01H;3`0I3Q805P/?01<8300E2Ph050T>01493P0F31@040XA
01`H801LF6405a<L018<500C31@04`X@01D:400I3Q@05@dE00H050dE01D06A8J01PA6@0E3QH05PlG
01PC6P0J6Ad06QXO01TK8@0I72<0720Y024X<`0S;CT0:CE502`iB@0gAUH0@U5T041@H@0oD600@eAT
059SL`1NKh000P1QLX@0801UMXT0J7V=06QhS@1ZNY00JGV@069cQ`1JJgd0FFam05mdP`1EJgT0AUaY
03]?F`0^@4X0>4I?02/g@00T;SL0;SDo024S;00S8RX08B0X020O9P0N7B<06aPO01XH7@0I5a`06QDI
01PC5`0F4AD05Q0D01HB4`0E4A80510A0P0C3a006P0G4A<06Q4D01P?4P0D2`h05@X>01T>4P0P5AT0
5P/?01D:3P0D2@d04`P<01@93@0F2`l050T=01D:3P0H3A405``@01H;3`0C20`040@601/?4@0Y7Al0
8ADG01D92`0>0P@050P:0P0B1PP00`0C1`T050P:01451`060186200F01P<3P0F2P`04`L901451`0@
10H03`<501451@0D20P05@T901<71`0B1PH04`L701861P0E2@T06@d=01@8200I3@d03`<301D92@0D
20P04`L701861P804`L700H03`<301D92@0G2`/04@D501@8200A1@D401@82P0>0186200A1@L04`L9
01<72@0B1PP04`L901@82P0E2@/05@/<0147200D2P/03`D601`B4`0?1@H20147200801882@0C2@X0
4`T:01@93@0E210050L>01<63@0B1@`20104200:00l31`0A1@L04PH801<72@0B1PH06`lA02TM8@0D
20`04`L;00d11@8050P<00D04`L;01862P0B1PX04@D901862P0301<72`0W01862P0A1@T04@D90104
200>0`H040@801@8300?0`L040@801H:3P0@10P04`L;01<82`0D20`060`@01<82`0<0P@05PX>00l4
1`0@1@P03`<701@72`0?0PD05@L;01421`0E2@/05@L;01<42@0A0PL040460183200C10T050D:00h3
1P0C1`/04@D901<72`0?0`L050P<00<040@80P0C1`/03P0A1@T0;b@/01873`0C2Q0040D=01@94@0D
2Q407a@L01H=4`0k<3P02`4801H;4`0D2Q003`@:0`0?10P0100?10T03`@:01052`0A1Pd201873`04
0187400A1@l0408>01443`804PD@00P04P@@01433`0A10l040<>01<64@0A0`l081<N020B7QCooooo
000Kooooo`0301882@0E2``04`T:008040H701@050X;00l51P0M4a@0718C00L0000G3@h07aDF01H<
3@0F3@h01`00020F5`0E2``050X;01H<3@0D2P/0200001L=3P0P5QL050X;01<72@8050P:00H05@T;
01@82P0D20X04`L901@82P0G2`d201D92`0C01/?4@0J3Q0040@60186200C1`T04@D70186200C1`T0
5PX<01P<3P0D20X04PH801@82P0F2P`04`L900l31@0C1`T05PX<01@82P0301041P0401@82P0?0`D0
50P:01`@4P805@T;00T05PX<01451`0P51H04PH800X0000K3a403`<500/00@0G2@`01@0E1PT03@0D
1@P05@H901L82`0F1`X050D801D62@0K3A003P84020D5P0C2@X0200001hB500D20X00P0E2@/0400D
20X05@T;01D92`0E2P`04PP901061`0H3Pl07A<D01<92P0E2``040H701T?400D2P/02`42038Y:P0U
71l200h8300501PB5P0M5a/05Q0D01PB5P0A2`l00P0C3A403`0L5QX04`dA00/42`0>1`h06Q<J01TB
6@0A2Q4071DL01L@5`0>1`h05@hE01XC6P0H4AP07QLM01@@4@0201HB4`0N018>3`0D3a806A@H01hI
7@0H4aP05Q4G01`G7@0C3Q@07QTO01HD6@0D4QD06ALJ01/I700K6Ad081hS02<P9`0L6B005Q<J02HS
;00G51d071/S01PI7P0N7b@07AhS01hN9P0O8BP06QdT02T]=P0F6R<08RH_0P0K8R`0>`0P9c4061`W
01`P:`0P92l07RD_02@[=@0W;SP0;cQ1034j@`0c?4D0:C<l02La>P0_>D80:S@n02Tf?`0X=Ch0:SM0
02hlA`0b@4/0=49=0351CP0lC5T0@E5N03a<F`0hB5L0?DYJ03Y7E`0fA540<d5<03A2B`0fA4d0=dI=
03I5C00eA4/0<d5:03=1C00d@Td0<T==0352C00fAe40?TmI03Y;E@0cA4h0>DYD03Y;E@0nCeT0>daF
03Y;E@0jC5H0=4QA03E7D@0mCeT0?4iH03U:DP0jBe<0=dQ?03M6C@0jBDl0=TE:0080=T=900<0=457
03=0AP0c@4H00P0d@DL00`0c@4H0>TM=03Q5B`0203=0AP0;030m@`0d@TP0=DA;03I5C00eA4/0>dYA
03e<D`0jBE00>DQ?03Q7CP0fAD`00P0gATd0200d@dX0=DA;03E4B`0c@TT0<T5803E4B`0d@dX0=DA;
0P0hAdh01P0eA4/0<D1703E2BP0b?dL0?daD02@a>@80;S]300P0:SLo03a9D@0b?dL0<d1803e:DP11
CUH0=dI=0391B080<D1700/0;Se403=0B00^>440>D=<02hh@@0e?TL0:c@m034j@`0b?D<0<ci403M2
B002038k@P0@02</<`0`=cl0;C@l02`c>`0_<c`0<3@m02`c>`0]=3`0<S]202df?@0^=Cd0<3Lo02D/
=00V:S<0:Rdf02LZ<`809RTb02807b</02`c>`0P:C007BH]01lV;P0Q:3009Rdc02<X;P0N8RP0;S4f
028U:P0b=CX09BP_02/_>P0Z;Sd0;S5002``?00`<Sl09BLd01`N:P0S8bl09BDa01hN:00U8bh08b4/
028Q:`0];CL092@^02<T;P0K7BT07b4]02HY=@0Y;CT09b/g0P0S9SD0>00V:CP092@b018A7`0C4R00
:2Le028Q;`0T8c408b8`01lN;00R8Bl07Qd[01/J:00Q82h08bDb02DT<P0P7bd08B0^02<Q;P0N72P0
6aTT01dJ9@0O72H08QlX02HP:P0W8Rl0928`01lM:`0L6RL081h[01lM:P0H5R4071XU01lM:00I6200
61LM01XI8@0K6B<07A/X01lM:P0L6RH061HQ01TG8P0R82X08B0X01TH800H5ah06aXP01XI7`0D3aT0
8A/W02/U<@0L5R40:B<]01TC7@0I51`061<J0P0G4QP03`0H4aT06aHL01`G7@0G4QP07aXP01TD6P0F
4AL06aHM01lI8`0@2Q@0IV1Z01D?6`0C3AT06aDP034W<P0201L=5P0H01D;500K4AX05`dF01L=5P0K
4AX07Q@M01P>5`0E2a@05`dF01@<5`0A2AH05`lJ01XB7@0F3QT08AXR01lH80080@T0614H01/D6`0H
4AP04``C014;3`0E3a<05a4E0P0D3Q802@0H4QH0=Blc01TC5`0U7b<0;BL[051:CP0>20`06@hD01H;
4@0201P=4`0501H;4@0I3Q@0714G01H;4@0D2@l00P0F2a400`0A1P`05P/?01T>4P0201@93@0901L<
400E2Ph06a0D01P=4@0C20`04PL;01@93@0E2Ph050T=00<05@X>0`0F2`l0600G31007a@H01dB5P0H
3A407A8F01X?5@0K4AT071DL01<>5@0;2140;2Tb01LD7@0C3AL04`hE01@<4`0G31806a8G01H>5P0F
3aL05@hF01@=5@0B2a<04@XB018;4`805@hF01H05PlG01PA6@0I51/061HM01XI7`0J6B006A`U01`P
:`0N93407RHc02D^?`0W<d@0<d1A03e<G`0lC5`0?e1P04=DI01=GVh0E6Ee05IWN@1HJG/0Gg220P1R
LhL0501TMHT0HW:9061aQ01HJG/0D6=d04aPL013FFL0?UAQ03a@F`0bA4h0>DM@02`h@@0S;CH0:S4k
02<U;`0T8b/08R4Y028Q:00O7R@071TP0P0H5Q/0400K5QX06QDI01PC5`0F41@0:BDV02<O800H51D0
40`=00d92P0=1`T05`hA01D<3`0B2@`050T=01P=4@0O51P301<8308050T=00<05P/?01@93@0E2Ph0
0P0F2`l03P0E2Ph04`P<01041P0B1PP05@T;01L;3@0F2P`05@T;02DI6`0P51H06`lA01P<3P0B1PP0
30021`0B1PP00`0A1@L040@601041P020186200501<71`0A1@D04`L701451@0?0`<00P0D20P01@0A
1@D02P0001hB4P0D20P06@d=00805@T9100C1`L01P0K3`l03`<300P0000B1PH07Q8B00l30`804`L9
0P0D20X20186200401dA4`0I3@l05PX<01<72@804PH800L060h?01@:2`0G3@h05`d>02/Q8P0M4a@0
4@L800<04PP900<04`T:01<8300B1@d00P0B1@`0100A10/04@D901452@0>0PH200h2100700l31@0@
10@09ATK03HZ;P0G2`l04PH:00h21P0201862P0301<72`0B1PX04@D900804@D900<04PH:01<72`0B
1PX00P0B1PX301452@0F01<72`0B1PX03`<700h21P0@10P03P8601@8300F2Ph03`<700X00P0;0@<0
2@0100P0000I3A4050P<01lC5`0?0`H0404601<42@0<00805PL<00l21@@050D:00P05@H;01H7300N
4QH06PhB01<72`0J3Q805`/?024E6@804@D901004PH:01<72`0C1`/04@D900d2200N4a/0GE9J04a1
B@0A1Ph04PT?00h32`0C21006PlG00L0100:00L06@hE100?10P0500?10T03`@:00l42P0D2A004PL?
01053@0B1a0040@>01853`0?0P`04@@>01853`0C1Q0060/E01T<5P0E21804PD?00h12`0K3QP06PdG
5?ooool001_ooooo00@05P`=01@:2`0B20T040H70P0A1`P0500F30d02`8300l51P0M4a@020000188
2@0A1`P0KF=T079XJ@0J41402P4202dS900C2@X050X;00L0000E2``08ALH01X@4@0C1`T050P:0P0F
2P`0300E2@/050P:01<72@0I3@l05`/=00l31@0K3a40;20R02@H6P0G2`d05PX<01@82P803`<500@0
50P:01dA4`0K3a405@T;0P0C1`T01`0B1PP050P:00l31@0A1@L050P:01451`0D20X00`0A1@L00`0I
3@l060`>02`P8P0201`@4P0901X>400900005`/=01/?4@0D20X05`/=01<72@0<00805`/=00D04`L9
0P0B1PP0300A1@L040@60186200G2`d05PX<0186200J3Q0091PJ028F600J3Q005@T;01H:30<050P:
03X05PX<01X?4@0D2P/04PP901`B4`0J414050X;01<92P0A1`P060h?01D;300A1`P0:R0Q04i5B00T
7R0050h@018<3P0A2`d02PD6014;3@0=1`T04`d?01/E5`0O6A/03`T;01/E6@0E3a<03`T=01<=4@0G
4AD0618F01LA5@0I4aL06aDI024K7`0G4AD09b4U014=3P0@30d06QHG01/G600D41807aXN028M8@0C
3Q<03`X@024L8P0H4aX07aXP01LE6P0E5AL06QXL01/K7@0J6Ad07A`Q024P9P0L6b405QDK0P0J6B40
6P0M72@071dR024R9`0O82D07QhV020R:@0M82L08BD^01dQ:P0O8b`06B0Z01dT;P0O9S00;30k02L[
=P0U:C@072<]024X<P0T:cD07RL`01`U;P0H8BX0:S@m03<mAP0Y<c`0:C<m0P0X=Ch01P0Y=D40;3Y5
02lmB00Y=d@0<41?03=3DP80?TiM00P0>DUH03e:F@0iAe@0=D=@03=1C00fA4d0>4I?03E3C080=49;
0P0gAE00:00fA4l0<45;0393C@0dADl0=DI@03I7D@0gB580>T]E03M8DP0jBeD0>DYD03Y;E@0kCEH0
<dM>03=6C@0fBE00<dI=03A5C@0fAdl0<dA<03M6C@0hAdh0<d9903A1B@0d@DP0<Sm5034nA00b?dD0
<d1603I3B@0d@DL0=T=903a9C`0b?dD0:3Dk03=0AP0jB4l0=DA;03I5C00eA4/203Q7CP0303M6C@0f
AD`0=DA;0080=dI=00@0>4M>03A3BP0d@dX0=4=:0P0a@4L06P0eA4/0<d9903A3BP0gATd0=TE<03A3
BP0_?TD0=D9:034nAP0oC5@0;CY2038oA`0f@d/0;ca403U6CP0a?TH0<Sm703=0B00jAdl0<d9902hm
A00/>d80;Ca302`k@P0`?DD0<C]40P0c?DH0700j@d`0:S<l03DnA`0^>Cl0;CPn02lj@00]=Sd0=3e4
02Pa>00`=cl0;3<k02Xa>@0]<CX0;S8k02/b>P0[<SP09Bhc02@]<P0Y<3P0:S4i02D/=00X;3L0:B`h
028T<00Q8bl09BLc028V<@0Y<3X2020Y<P0N028Y<`0R:C409Rde02T]=P0P92X0;c8i01hQ:00b=CX0
8RD/03@h@`0`=400;30l02PZ=`0/;SX08B<_01lO:`0W9c40:2Pb01dK9P0O7RH0;2/c01lP:P0X:c@0
7b8[028T<00K7BT06alZ02@X=00Z;C`09bdk0P0Q9cD00`0S:CL07Ql/01hM:`0202TX=P0c01`K:@0U
938092<a02<R<00V9C<06aXX01LF900Q82h07b4^020O;@0O7R`09B@b02@R;`0P7RX081hY020M:00P
7BL0924Z02TS;@0X8c409B4`024M;00J5RD071PV01dJ9@0N6bH07Q/T01lL9@0Q7RD071XO01XG7P0N
6b@0920^02LS<@0X93409B8]02<P:`0Y9S00:RL`028O:00N6b<07Q/R01/H7`0N6R<07QPT00d74`0U
7bX0Ee5K02LQ:`0D3aL06A@K00805a8H01@06A@J01`G7@0J5A/06QDK01D@5P0I51X05A0F01LB6@0>
21808Q`V01D?6@0A2aL09R0/01H@6`0n=3l0<2H_01/A6P0L4Q/06a4J01L=5P80718K00d06Q0I01H<
5@0D2Q<04`TB01dE800H41/05`lJ018;4`0;10`04@XB05YCFP0[92/03@H=00<04@/?00h04P`@01<=
4@0G4AD06aDI01@>4P0500<02P@801<=4@0M5a/02@<701lI7@0A2`l060dC01D:408060dC00D05@X@
01P=4`0J3aD05P/A01L<4P0201/@5P0901D:400A1PX04`P<01052@0B1`/060dA01H;3`0M4QH06PlC
00<05``@00@05P/?01@93@0D2@d05@X>0`0F2`l04`0D2@d05P/?020E6@0M4QH05``@01`A5@0G3180
2@0700/42`0F4AT030TD00<02`0A3QP03PPB010;4P0A2A0050T?01L>4`0E31D00`0E3QH00`0C31@0
4P/C01D>5P0201@=5@805a0H02d05Q4H01PE7@0I62006ATR01TL9@0L82/08BLd028Z=`0W<4409311
02TfA`0b?e00<d=C03i@GP14EV@0Bee/04mPL01BHg<0E6Ef05UZO01KK7h0Ffao05i_P`1LKH40G6f0
05Y[O@1CIWL0Bem_03mEH`0mDf00?U9M03=5C`0a?dP0;SY302La>P0V;CL09RPa02HU;@0T8b/08b8Y
024P9P0M6R406QPM01TG700H4aL00P0G4QH03@0J51P061@E01DA4P0B3Pl0510A01LC500H4Q@060lB
01L>4@0F3A0050T=01462P0?10P00P0E2Ph201@93@0301<8300D2@d050T=008050T=0`0C20`30145
1`0901041P0B1PP05`/=01<72@0?0`D03@4301041P0D20X05@T;00H04PH8100A1@L01@0C1`T050P:
01@8200@10@04PH600804@D500T06Ph>01<71`0C1`L03P8203L[:`0F2PX07Q8B01H:2P0E2@T00`0C
1`L01`0D20P07a<C01dA4@0B1PH05`/;01P<300:00001P0C1`T00`0K3a405PX<01@82P0301862007
01@:2`0C2@X05P`=01`B4`0e:b`09adN01<92P0301882@030147200A1PX040<;008040<:00D04@@;
01452@0A1@T05@T=0186200200l31@060104100E2@/07a<G00/00`0?0`L03@450P0C1`/00`0B1PX0
4@D901042002010420804@D90`0B1PX01@0C1`/03`@700/00`0<00@03P8600804@D901@04`L;00d1
1@0>0PH03P8601@8300O4aL04`T;02lS9`0800003P@600/00`0H3100308400h21P0D20`0200001L;
3`0>10H03`<7010420<04@D90P0B1PX01@0>0PH0308401/?4`0E2@d050P<00<04@D90P0@10P03@0A
1@T01`0201/@5P0c:2h03`@:01D:400B1`d05@X@01T>500A1P`02`060146300>10T00`0@1@T05@0?
10P03`@900l42P0?10X05P/B01873`0?10`04PH?00l33@0E21804@@>01D84P0F2A<050LA01P;5@0I
31H05PTC01853`0900H03`8<00P01@0Dooooo`006oooool06`0E2``04`T:01061`0A1`P04`T:01@:
2`0;0P<060h?01/A4P0L4Q<04`T:01882@0E2``08aTJ01lE5P0A1`P05@/<00d4100@1PL050X;00h4
1@0@1`L04@L800d4100B1PP04`L901@82P0301D92`0903T];`0;0@803@4301D92`0C1`T060`>01H:
300@10H04PH8008050P:00T05PX<01<82@0N4Q@06`lA048f>00E2@/05`/=01D92`0G2`d00P0D20X0
1@0C1`T04PH801451`0E2@/05PX<00805@T;02T040@601hB500D20X05`/=01lC5@0B20T05`/=075U
I`1lL78060d>01lC5@0K3a405P/=01<82P0@1@L05@X;01H;3@0?10D06@h?01@92`0C20T05P/=01T>
3`0L4A808ADG01T=3`0R5QP07a<E01D92`0G2`d06@d?01X>400G2`d04@D701@82P0G2`d05P/=01H<
3@0I3a005P`=0147200201P>3`0801D;300D2P/06@l@01T?400C2@X07aHI00h82P0E3a4201LA4`0?
01/E5`0D3Q005@lA01<=3`0@2P`05Q0B01D?4@0G4AD050hB03dg>`0J51P081XN01<=4@0@2Ph06A<G
0080618F02<04`dA028L800H51D0510A01lK700U8B807QTL02@O8`0@2`l07APM01D@5P0G4QP06QDK
01XH7@0L6Ql05aLI01hN800A4A<06a/N01hM8P0I61h08R4W02<R:00L6b<07QdU020O9`0N7b@0824V
01/L8@0I6B406a`T01XM900I7BH0:blh02L[=002020W<@0X02<Z=00Q9C008bLb02L[=P0R:C<09B`f
02L^>00/=Ch0:c@m02H_>00S;CH0:cDn02Xd?@0Z=3h0;3Q302/h@P0/>4@0<d5=03U7D`0e@U40<T9A
02dmC00a@E00<d=C03=3DP0kBE@0=TA@034oBP0d@Td0;ce703E3C@0kBE<0=49<03I4CP0jB5<0=D=>
03=1C00_@4X0=4E?03Y;E@80>DYD01D0?e1J03e>F00eAU00>DYD03Q9D`0lCEL0?e9J051UJ`2<WjD0
BEaS03=6C@0iBU80=dQ@03E6CP0iB500>TUA03E3B`0gA4`0BEIM049?E@0d@DL00P0iAT`03P0hAD/0
>dQ>034nA00a?T@0=dA:03E2B00gA4X0C5YP04MFG@0eA4/0=dI=03E4B`0c@TT0=TE<0P0eA4/01`0h
Adh0>DQ?03]:D@0c@TT0=4=:03I5C00b@DP00P0fAD`04`0eA4/0CeiU03m>E@0eA4/0>4M>030oAP0a
?TH0?4UA06]hP00lBE40>dQ@02llA00b?dL0<d1802llA00`?DD0:cQ0038oA`0c@TT00P0a@4L05P0b
@DP0<3m6030mA@0c?DH0;SQ102li@P0j@d`0:S<l03DnA`0`>d40<Se302/f?00X<CP0>D99034j@@0`
=cl0:C0h02Xa>@0]<CX0;30i02lf?P0[<SP202Tb=`809bhf02H0;3<l02/_>P0/;c/092Hb02T[=`0X
:SL08BDb02L]>P0T;3P08b`f02@Z=@0S:C@092/d028V<00R9Rl08RD]02T/=00R9Bd08bH^02X]>00W
:SL09bXf02/]>@0R8bl0=3E103loB@0K6R@08R4Z02HS;@0N72@06aXR02<U;P0V:C8082</02@V<@0O
8bh07B4/028V<@8092Xg030082Hc01`T<@0N93809BHc024P;P0U93807ah/01hM:`0S8S008R4_02HU
<`1;BUP09RDc01@C8@0U938071h[01dL:P0P7bd0:BPf028P;@0R82`0;2Xe02LT;`0T8B/0924Z024K
9@0U82d09b<c02DQ<00O6bX07QXX01lL9`0O72H06aPQ01/H7`0S82H071XO01TG6`0K62006aLU01`H
9P0L62D07Q/V01dJ9@0N6bD07a`U01hK900M6R8201hK8P0801lJ900I4al071HR024K9P0L5R0050hH
01dH800K5Qd201XE6`0301`G7@0N6Al05a8H00806A@J00d081/Q01PC6@0D3aH06Q@N01<=5`0G4A/0
7ALS014;5`0H4Qd05`lJ02LO9`0H3aP071@L00806Q8J01@071@L01<:4`0H41P06Q4J01L>5`0H41P0
6A0J01L>600F3AL05`hG01P?600K4QX07aHN01P@5`0H41H0610E01<<400H41@04`dA01LA5@<06A<G
00L05Q0D014;3`0F41@06aDI014;3`0B31005Q0D00805P/A00/05``B01P=4`0F2a405``B05A9C`0Y
7R@05P/A01dB600N4aT05@X@01T>4P0201L<400401lD600J3a<04PL;01<830805@X>0P0F2`l0100C
20`050T=01D:3P0E2Ph201H;3`0F01L<400B1`/050T=01/@500H3A404PL;01@93@0@1P`06Q<J01dF
7P0K5b008b0[01<@700B41/04@dF01@>600A2Q805P`D01L=5@0E3QH04``D018;4`805PlG03T030L=
01PA6@0E3QH05@hF01L@600E3QH050`F01LC7@0I5R806aTU01hM:P0P8Rl092Tg028Y>@0S;3d09Bm0
02`hB@0a?Tl0<41?03Q:E`0oDEl0A5ET04EGIP1:Ff/0Cf1a059SM01EIWP0EVMj05QYO01GJ7/0EFIh
05=TMP1AI7D0C65`041FI00kDEh0>DeI0394CP0`?TL0;c]402hh@@0/<cd09BLa02<R:P0Q82P081lV
01lN900N6b807A/P01HD6@0E41@06aHJ018=4@0_:Bd0IF5R03Da<P0G4a@00P0A3@h02`0D3Q005`hA
01P?4P0I41<06@hB01L<400E2Ph05P/?01D:3P0F2`l05@X>00804`P<01405P/?01D:3P0C20`04@H:
01872`0D2@d04`L901D92`0F2P`050P:0186200D20X06@d?01@82P0F2P`04`L90186200201451`07
01<72@0@10H040@601<72@0A1@L050P:01<72@040186200@01@8200B1PH04`L701<71`0D20P06Ph>
00l30`0L4100DdM7040d=00I3Ph07Q8B01<71`0E2@T04@D501X>3P804`L700h050P8040d=00`92@0
4`P801D92@0X71`04`L902LK7@0/82804@D701P<3P0?10D050P:01<72@804@D702d04`L901D92`0D
2P/040H701H<3@0=10@06@l@01H<3@0A20T04PP901L=3P0@1PL04`T:00`31@0B1Pd030460185300B
1P`04`L;00h31P0J3Q805@T;0186200C1`T040@400h41@0D20`03`<701862P0>0PH040@801452@0I
3A4030840105200>0PH03`<701<72`0G2`l04@D901862P0@10P04@D901@8300C1`/00P0B1PX201<7
2`0N01452@0?0`L050P<01@8300<0@@03P8601L<3`1ODeL0:alS01872P0<0P@05`/?01<72`0`9BT0
4PL;00d21P13>3`05`/?01<8300A1@T04`P<01@93@0@1@T04@H:00l31`0A1@T050P<024E6@0I3A40
40@80P0A1@T04@0B1PX040@80104200B1PX06@hD00d3200B1`d02@040146300@1@/030<701@93`0G
31804@H<01<83P0=0PP040D900804@H:01D040D901052P0@1@/04@H<069GGP0D2A4040D=0188400=
0@/04`H@01443P0E21405@PB01443@0@0`d04`H?01443P0B1@h040<=01D84P0A10d05?ooool001_o
oooo00@050X;01<92P0B20T04@L80P0B20T01@0?1@H05@/<01dC500I3a003`D600L04PP91P0A1`P0
200B1PP04@D701451`0B1PP05@T;01L;3@0S5aT04@D70P0E2@/00`0D20X06`lA01<72@020186200=
01<72@0D20X05@T;0186200H30h04PH804Lk?@0=0@<05`/=01H:300E2@/050P:01<72@0201862006
01H:300@10H06@d?01`@4P0C1`T060`>0P0F2P`02`0H30h09QXL02<G6@0H30h06Ph@01H:300<0P<0
4`L900l31@0V6ad03`D600804@L80100200001P>3`0=0`@05@/<01@:2`0:0@8050X;0147200?10H0
5PX<01@82P0E2@/05PX<01041P0?10D04@D70P0F2P`00`0J3Q005`/=01@92`0201L=3P0401H<3@0E
2``050X;01@:2`@05@/<01T050/<01<:3@0A2`d040X<014;3@0C3@l05Q0B014;3@0D3Q00618D01/E
5`0L5QP04`d?018<400C3A40=2hb01<=4@0I4aL05Q0D014;3`0G4AD05@lC010:3P0D3Q806A<G0080
5Q8C0P0K5aP08`0F4A@061<G014<400Q72405a8H01/F700G4QT08R0U00/:3`0T92H0:b/]030`<P0I
6A`071/P014@5P0M728081lU01`K8`0M72@09B@/01hO900M7R<071dR01dM9@0L7RD06ahU01`P:@0V
:S<09BTb01/R;00H7bT07bH`02@X<`0X;3L0:Bdh00809B`f00@09bhh02</=@0T;CH0:34j0P0U;cP0
2P0W<CX0:C<o02diA@0]>DD0;3Q40390C@0hAU<0=dAD0392D@0eAE@203E5E@0903Q8E`0d@T`0<T19
0390B@0d@Td0;C]603A2C@0mBeP0=TAA0080>TQC01D0<d5<0390B`0iBU@0=DI@03e>F00lCEL0=TMA
03]<EP11DU`0BEYT03I7D@0gB580>daF03Y=D`1CJ6d0X[Fk04mRJ00iC580?4eE03Q9D@0gB5000P0i
Ae004@0gADh0>4E>04eJH`16DeT0=45703]8CP0jAdd0>4E;03]8CP0d@DL0<d1603I3B@0e@TP0=dA:
05=QI`1>GF@0=DA;0080=4=:00`0=TE<03U8C`0eA4/0=DA;03I5C00gATd0>DQ?03I5C00a@4L0=dI=
03a;DP0b@DP203A3BP0<04UHG`0b@DP0;3]202Xi@00b@DP0?daD03E2BP0kB5008c0h02`i@@0f@d/0
<3e50P0^>d<01@0b?dL0=459038oA`0_?TD0<3m60080<T5801D0<D17030mA@0_>D8092hg030j@`1=
EUl0<ca502`e?P0/=cd0;cY003<nA00/=C`0;SLn02L`=`0[<SX09bhf02P_=`0/<3T0;c<l03@k@`0Z
<CL00P0Y<SL02P0Z<CT0:C0i02P_>@0[;cX0<CA002h`?@0_<D00:B/j02@W=P0Y;cd202H^>`0802X`
?P0Z<3`09R`h02T]>@0W:SD0:Rdf02LZ<`0O8R/2024S;`0>02la?P0Q8c009bTe01XJ9P0U9Bl0;Bdg
020O9`0T8b/07AXS02PU;P0c<SX08B8Z01lR:`0M82T202<V;`0;01dQ;00T:3<09BTd028X=00O9C40
6Al[01LM:@0L72X071/Y01lN;00K6RP00P0M72X08@0W9S@06aXX02h]>`0E52807ah/02d/>P0N82d0
?Ca:03`kB@0H5bD08R0]02<Q;@0W9C00924/028O:@0P7BH07aTS02<N:`0Q7B/07QXY01dI9`0N6bH0
81dX02@Q:P0P7BH07Q/R01hL8P0G5AX061HK01dJ8P0O6bT07QXX01/G900201hK9P0401`I8`0J5b00
61DN01LD70805a@K00/06A@N01PB7P0J52007aTT01`F800K5Al07QPQ01dH7`0L5ad06aHL01TD6P02
01PC6@0501D@5P0J5A/07QTO01TD6P0J5A`00P0F41X04@0E3aT04`dI01@>6P0D3QT07QHQ01D>5P0B
2a<06A8J01dF7P0E3QH091dU02TR:P0C31@07aPP01dF7P0H4AT05`dF008050XC00/05`dF01P>5`0I
3aL06a4I01XA5P0H3a@05PdB01P?4`0H3a805Q0D01LA5@0201XD600401H@500?2@d04P`@018<4080
4`dA0P0D3Q8301<83P<050T?00`0G55G02LL8P0A1P`06@hD01P=4`0D2@l06@hB01L<400J3a<09AXN
01X?4`0H3A4601H;3`0301D:3P0G31005P/?008050T=0P0F2`l201D:3P0E01H;3`0G31005``@01T@
600?21002@@;04i;E@2?SIX0G5YW028P;@0B3aX04a0I014;4`0G3AD04`TA00h73`0A2Q805a0H0109
4@0B2a<09AhV00804P/C01T04``D01D>5P0E3QH05PhI01TC800J5R@06QLU01TH9P0K6RX0828b020V
=P0N9CL09Bho02`hB00`>dd0<T5?03E7D`0iBeT0?e5O049DHP15EVH0BEYZ04aMK@1>Gg40DV=e0080
DfAf0240DF9d04eNL019G6d0A5UX03mEH`0kDEh0>DeI02doB@0_?DH0;SY302Xd?@0^=Cl0:2Xd02DT
;00S8RX081lV01`K8@0M6R407A/P024O900R7B4050lC00X52@1RG600n_Kg07IbL`0L61T06aLH01HB
4`0B30h060lB01L>4@0F3A000`0E2Ph0300H3A405``@01T>4P0E2Ph040D901D:3P0F2`l05@X>0187
2`0A1PX04PL;01@93@H050P:00<04PH800`00P0@10H00P0G2`d00`0?0`D05@T;01<72@0201/?4@03
01<72@0E2@/04PH800D04PH81P0B1PH02P0C1`L0200003da<@0P51@06Ph>00`0000B1PH050P800/0
000M4A4301<71`0;02XN7P0F2PX04PH601861P0N4Q8060`>03/_<@14>3X06Ph@01lC5@0@10H00P0F
2P`05`0E2@/04`L901<72@0E2@/040H701L=3P0E2``04`T:01L=3P0<0P<06Q0A00/10P0<0P<03`D6
00`20`0G31004@@<020C6P0G2Q402P0401T=4@0E2@d05`/?00804@D701L04PH800l30`0@10H04`L;
01862P0A1@T040@800l31`0D20`0200001/?4`0H31006`lC00P0000<0@@0200001452@0H310040@8
01lC5`0=0`D04@D90104200300l31`0C00d21@0C1`/05PX>00h21P0A1@T05@T=01452@0X72004`L;
00`1100;00<04PH:00/1100?10P02`8400d21P0R5a/03@@600L0000200T00P0900X00`0@1@T05@X>
00l31`0E2@d04@D901@8300@10P0304400H04@D900P02`0600`11`0A1P`04@H<01D:400B1`d040D;
014630<04PL=00h04@H<00l4200A1PX04PL;01052@0@1@X04PL=04Pm@`2ERY40:AhV01X?5`0B1Pl0
4@D?01D84@804PD>0P0C1Pl0100A10d03P4:00h12P0A10d201@7400300l22ooooooooooo01;ooooo
000Kooooo`@04`T:00P04PP901061`0B20T04@L801@:2`0C2@X040H7014720H04`T:0P0B20T40147
200=0186200@10H040@601451`0D20X05PX<00h41@0K3a405@T;01451`0D20X04PH801<72@020186
200901<72@0D20X05@T;0186200E2@/03`<501hB500<00805PX<00805@T;00H050P:01<72@0B1PP0
4PH801D92`0A1@L201H:300501451`0C1`T05PX<01H:300D20X00P0M4A<0400@1@H04PH801D92`0I
3@l0:AdO01L;3@0N4a@060h?01X@4@0C2@X01`0002LM7P0>10D05`d>01H<3@0>10D201L=3P0:0146
1`0D20X060`>01L;3@0B1PP04`L901T=3`0M4A<060`>01<72@8050P:00@050T;01H<3@0F30d05P`=
0P0E2``01`0A1`P04`T:01H<3@0F30d05@/<01882@0F3@h00`0D3Ph0>`0C3@d04P`<018<300A2`/0
5a4A01`F5P0H4Q8050h>010:300L5QP04@/=01PB500G4A<06A<E010:300E3a405Q0B018<3P0D3Q00
618D01HB4`0I5AH081`M01`H6@0E4A<06QDI01@?4`0K5Q/061<I01/F700F4AL081hS028Q9P0N7b40
<C8d01`M7`0H6A`04A8F01<D6@0I6Ql071dR01/K8`0M7BD08b<[01XK800L7B807QlT01lO9`0N82L0
7B0W028V;`0S9c008RH_01dT;P0K8R`06R4[028V<@0U:C@09RXe00808bXd00`092/e020Y<P0U;SL0
92df02Pb>`0S;CH0:38k02dg@`0_>dT0<3a:02lkB@0_?4`2034nCP0T0310D00eAED0=TIF03A4E00g
AeH0<3i602lnA@0gADh0<T1;03I4D@0gAE80?4UH03M5DP0kBEH0>dUD03=1C00a?dX0?TmI03M8DP0k
C5H0>DYD03I7D@0jBeD0=dQB04MHHP0hBE<0>T]E04AEG`0nDEL0<dQ;04ePI00eB4d0<TE;0352B@0a
@TX0=TM?0`0gAE00100g@dl0>dQA03Q5B`0c@4H303I3B@0903Q5B`0`?D<0;3To038oA@0d@DL0=T=9
03]9D00lBe80>4M>0080=4=:00T0=TE<03Q7CP0fAD`0=4=:03=2B@0eA4/0=dI=049AF01:FF000P10
CeH0100b@DP0;Se402hmA00gATd203=2B@0n02hmA00b@DP0:CHn034nAP0b?dL0<Ci603Q5C@0/>D40
<d1802llA00^>d<0=D9:03I3B`0^>d<0;3]202dl@`0_?TD0<3m60350A`0c@4P0>dE>02`f?`14CUL0
KWN004]DG@0f?dP0<Se302hi?`0lAdd0=3e402Xc>P0X<CP0:2lg02Xa>@0V;CD0:Bdf034e?P0_=Sh0
9bhd02`e>@0/=CX0:S4i02P_>00Z<C/0:Rhj02d`?P0^<3l09RLi02DV>00[;Sl0;39202@[>`0T;3T0
:S0n02P^?00O9C40:Bdi02X]>@0[;CT09RPd020R;P0S9C4205YLJ00;01XL:00N7RX0;2`f01lO:@0M
6bD08b0Y020M9P0M6R40:2D/03hk@P0O7b@00P0M7BD03P0W:3009bXa024T;@0S9Rl08RH_024U<00M
8B`061`W01HJ9P0I6RL081l]01lN;00N7B/07ah/0P0R8Bl0?@0];3X0:bXh02HU<`0R8Bl06aXX01TK
:01mO8X0Ogj<01lN;00X9S<0:RPd01`J9@0Q7RT08b0Z01TF7`0L5R008A/V024K9`0N62H071HR01hH
8P0Q6bD09b4[02<N9@0N6B007APO01XE6`0K5Q`07QTR024K:@0O6BL06aDR020J9P0R72P08adX020J
900K5Al06Q@M01/F7@0J5A`061<L01`F8P0N62@071HQ01hH8P0L5R006aDN01dH7`0M61h06aHL01XE
6`0H4aT06aHL01TD6P0K5Q`071LM01TD6P0J5A`06Q@N01TC7@0H4Q`00P0G4Ad07`0H4Qd06Q8M00l8
400S72@08AXR01dF7P0N5al0PGZ2089kP`0N5al04``D01094@0<1`d07A<L01X@6@0G3AH060hF01T?
5`0F31@05`hC01H=4P0D2`l04`X=01D<3`0F3A005Q0D01D?4`0F41@05a4E01D?4`0@2Ph00P0B3102
01<=4@8050hB0P0F2a4401D:400>02PM8`0E2Q004`P>01L<4P0E2Q005``B01H;3`0G31005P/?01dB
5P0F2`l0714E01L<400F2`l201D:3P0501H;3`0G31005``@01P=4@0F2`l00P0C20`06@0D2@d06a0D
01H;3`0D2@d05@X>01T>4P0K41@05@dD01H?5`0Q72<0X9fW0?omo`2g]l<0<C0m01<@6`0F4a`05Q4H
01PA600E3QD050dE01L@60090PX081TQ01@=5@0;10`00P0D3AD06@0E3QH06A8J01`E7@0N5R406aDT
01/G9P0J5RH05aHV01TH:00M7bl07R@d01lV>00U;Sl0:cM702hjBP0_?D`0;d5=0353C`0jC5P0@UAP
04=EH`13E6<0AUMW04UJJP1=GVl00P1@HG<07P1>Gg40BEY/04EHJ@12EfH0@5IT03iDH@0lD5`0:C]5
02/i@P0`?4D08bdf02H]=`0W:C<09bH^02HU;@0N7B@061LM01XG7P0G5AX05A<H01D@500D3a<04@`@
03Xd>02:QXL0>3@e00l;300C3a0040`=01@>40<05Pd@00<05P/?01D:3P0D2@d00P0F2`l02P0G3100
4@H:00d21P0D2@d05P/?01D:3P0B1`/04@H:01872`0D2@d601<72@0801T=3`0E2@/02P000186200D
20X05PX<01L;3@0B1PP202<G6@030186200G2`d04PH800D04PH81P0B1PH06`0G2`/06Q0@01H:2P0F
2PX050P801861P0C1`L050P800T0000L41004`L701D92@0=0@406`l?00l30`0D20P040@401861P0@
10H07a<E024E5`0?0`D040@600X0000E2@/05PX<01D92`0201<72@0P01D92`0>10D06Q0A00/10P0F
30d07aDF00X00@0>1@D0308300l51P0J414060h?04<h?00J3AD0QgZ1071SJP0K3QD03@4500X00P0C
1`/04@D701041P0A1@L04`L701@82P0C1`/04PH:01452@0@10P03`<700`2100E2@d200X00P0301/?
4`0D20`05`/?00806`lC00H040@800d11@0C1`/06`lC01@8300B1PX201452@0301862P0D20`04`L;
00<04PH:01T04@D900d21@0H3100300401452@0?0`L04`L;01872`0:00<04PL;01H;3`0D2@d02`84
01D:3P0N4aL05``@00h31`0D2@d03`@800l31`0F2Ph050P<01/?4`0H31005PX>00H04@D900/03@86
01462P0=0PH04`P<00d21P0=0`H0304500l4200B1`/03`@800d21P0201052@0?01872`0C20`04@H:
01462`0C20h08QLM034V;@0?10`05@XB00d32P0B1Q0050L@01442`0>0@P040<:00804`H=00H04@@;
01032P0@0`X04@@;01032P0=00LDooooo`006oooool01`0D2P/05@/<01D;300D2P/04PP900l51P0E
2``00P0B20T201D;300301061`0B20T04PP900@04PP900@050X;01<92P0B20T04PP90P0A1`P03@0A
1@L050P:01H:300F2P`04`L90186200F2P`04`L900l31@0D20X05@T;00l41@0C1`T00P0B1PP02`0C
1`T050P:01D92`0B1PP03P8401@82P0>0P@06Ph@01<72@0E2@/050P:00804`L90`0B1PP01@0J3Q00
5`/=0186200L41804`L900805PX<01l040@601451`0B1PP040@601dA4`0L418050X;01@82P0B1PP0
4PL901482@0<0P<04@P901/A4P0?1`P07A<D01@:2`0<0`@050/<00h41@0K4Q<05``>00l31@0D20X0
5PX<00d10`0C1`T050P:01451`0B1PP060`>00805@T;00H05P/=01@:2`0E2``05@/<01H<3@0G3@h6
01D;300301D<3@0C3@d04P`<00804@/;00`04P`<01/E5@0C3@d04`d=01H@400B30`06aDE01@>400G
4A<04`d?01/E5`0H4Q@2014;3@0601D?4@0K5AL0618D01H@4P0H4Q@071PI0P0G4a@04`0K5aP06ADG
01/F6P0O6Qh05Q4F01TD6P0M61h06QDL01PF6`0P7b@051DG01lP8P0D5AL07QlR01hO8`0O82D07QlT
01`M8P0K6b<00P0L72@02@0H6Ah06a`Q01`M8P0L72@07b0X024T:`0P92d08bL`028V;`0201lV<004
020W<@0Q9C008RHa02@X<`808RTc04008BPb02L`>@0T;CH092df02`f?`0X<S/0<3Y402hhA00[=dD0
;3Q602diA`0]>TX0;S];034nCP0b@U80>4QH03E5EP0_?e00<41?02hm@`0X=c`0<d99034oB@0oCEX0
>4ED03U6EP0hAED0?4YG03Y8E00b@4/0<Cm:03I7D@0b@dd0=TMA03Q9D`0fAe40>DYD03A5C`0^?dT0
?TmI03E6D00iBU@0AUUO03Y?D@0_@TH0=TU=03iAEP16Eeh0>T]B03M8D00iAe80=TA@03U7D`0hA540
<Ci703A1A`0gA4X0>TM=03i;D@0jAdd0>DI<03A1A`0]>T00<Ci40P0e@TP0800d@TT0<3m603A3BP0k
BU40<T5803A3BP0lBe80>DQ?03I5C00c@TT0=4=:03M6C@0`?dH0EFA[03]:D@0eA4/0>TU@02hmA00_
?TD0=TE<0350A`0_?TD0=4=:03=2B@0hADd0=459049?E`1LJG40>4E=034nAP0e@TX0=4590P0f@d/0
0`0e@TX0;ca402hmA00302dl@`1A02hmA00b?dL0<Sa502Xd?@0_>D80BE9K03HoB00]=Sl0=D1603@o
A@0f@DL0;SLn034j@@0^=ch0:S4i02lf?P0U;3@09b/d02lc?00W;S@092/a02/d>00/=CX0:2lg02L^
=`0[<S`0:2`h02P[>P0X:CX092Dh02//?`0c=TT0:2e002<Z>`0S:SX0:2hn02`b@@0^=480:2/j02/^
>`0X:SL08bDa020R;P0Q8c00J6Ue06EVLP0V9c<07alZ024P:`0P7bT0:2L_02HS:`0L6B409R8Y01hJ
8@0U8RT08R0U01lN8`0O7b@0:RT_02/[<00S9B/07b4W01lP:@0N8BT07B4Y01/O:@0K7RP06a/X02LV
=00O7R`08R4_01hM:`0R8Bl07A`Z02XY=`0Q82h09B@b02<R<00L6bT06adZ00808B0^00P07Qd[01XH
9@0O7BT04Q0K01hK9P0b;cT0:BH_02LQ:`808A/T01X07aXR01hH8@0L5Ql071LO01`G7P0K5Qd06aHN
01hI8@0P6R<07QPQ01XD7`0L5R@07ALU01`F8`0O6BD07QPT02@N:@0U7bT07QPR01`G7`0O6R4071LN
01hH8P0V82`08adY01TC7P807ALQ00<061<K01XE700L5ad00`0L5ad01P0Q72807aXP01/F700H4aT0
5a8H01PC6P806Q@N02806A<M01LA7@0G4Ad0618M04Y3CP0O6B4071HN01LA600K5Ad08A/S02LQ:00/
9Rh04`dD020J8@0D3QD050lE01@:4`0F31@05@XC01H;4`0J3aL05`dD01T?5@0H3Q@05`dA01H<400H
3Q406A0C018<400A2`l04P`@01@>4P0F41@050hB0P0B310201<=4@8050hB0P0F2a4401D:400701H;
4@0C20h05``B01P=4`0E2Q0060dC01@93@0201<8300501dB5P0E2Ph05P/?01D:3P0D2@d00P0C20`0
2P0D2@d05@X>01D:3P0G31005P/?01@93@0E2Ph05P/?01/@500G310201D:3P0E01L<400G3Q<050`D
020J8`0/9S00R8F@0=7Ae`2LVjP092@`00d;5P0C41/04P`E01H?5`0H4AP0GEIN01dF7P0N5al0EDiF
02@M9@0@2a405@hF00804``D01P05PlG01/D700L51l0610Q01/D9@0L5bT071T[01hM;P0P8S<082Hf
028W>P0U;Ch09c1102Hb@P0W=T@0:ce80312CP0fB5@0>deI03mAG`10DV00@E9Q04AEI@19FVX204aM
KP0=04aMK`19FV`0AEQY045FI@0oEF<0?UAQ03Q<F00]?dT0<3i702Pd?@0W<CX0:2li020R;00202DT
;00N01dL8`0G5Q`06aPO01`J7`0D4QL05Q4E01lJ7P0R7B405Q0D01LC500I5AH06aLH00h:2`0D4140
4`d?01D<3`0F3A005`hA01L<400F2`l04`P<01P=4@0E2Ph05``@01P=4@0D2@d05P/?01D:3P0D2@d0
4`P<0P0B1`/00`0C20`04`L901<72@0401<72@0800`10P0G2`d050P:01D92`0@10H05@T;01041P0A
1@L201L;3@0301451`0@10H04PH800D04PH81P0B1PH0700=0`<08aLG01@8200K3`l040@401T=3@0B
1PH05PX:00l30`0Q5AD05@T901<71`0B1PH05PX:01@8200G2`/06Ph>01L;2`0L41804PH800h2100E
2@/04`L901X>400E2@/060`>01L;3@0E2@/201@82P0H01@:2`0C2@X08QPI01882@0D2P/060h?01@:
2`0U6a`0:AlP0107200M4a@0@CHj01863@1@@dX0=RT`01452`0A1@T060`@01452@0@10H03P840104
1P0G2`/05`/=0P0B1PX201452@0@0104200L4A@0N6a`01/A4`0H31004`L;01862P0D2@`05`/?01X?
4P0B20X060`@00l51`0G2`l050P<01862P804@D900/04PH:01<72`0@1@P04@L901<72`0@10P03`<7
01@8300B1PX040@801@8300201862P0>01462@1?ADP050X=01<9300?1@P04PP<01L>4@0=0`L02`44
01<93@0D2Pd04@L:01P<400K3a<201452@0300h21P0=0PD04@D900D04@D900/04PL;01L<400;0P@0
50T=00/1100F2`l04@H:01D:3P0G31004@H:00d21P0201462P0G01872`0D2@d04@H:0187300C20h0
5@X@01<93`0F2a<03`H<01463`0?1@`04PD>01032P0A10/04`H=01@73P0B1@`05PT@0185300?0PT0
4`H=01hA600W6R405?ooool001_ooooo0P0F30d01@0E2``050X;01882@0@1PL03`D600804@L800<0
50X;01D;300<0P<01P0A1`P201@:2`0A01<92P0B20T04@L80147200A1@L05PX<01T=3`0H30h04PH8
01041P0C1`T050P:01T=3`0@10H03@4301H:300C1`T00P0B1PP02@0C1`T050P:01D92`0C1`T03@43
01D92`0C1`T05PX<00P0000201<72@@04PH801T050X;01041P0P51H03@<400l31@0@10H04`L901@8
2P0C1`T04PH801<72@0D20X030020186200j;S00710B01<72@0B20T06Q4B00d41@0E30d071<D00H0
000<10@060l@00803`H700P091/L04@k?00H3Pl03`<501P<3P0^8R@07A4C01041P805PX<00L06Ph@
01hB500A1@L04`L901T>400C2@X050X;00805@/<00d05P`=01T?400G3@h05@/<01@:2`0E2``060h?
01@;300A2`/040X:00l92@0B30`05@l?008040X:01D050h>01D?3`0C3@d05Q0@01XD5P0;1@L06aDG
00l92`0F41805@lA01PB500E3a4050h@01<=3`0G4A<09b4S02dY:P0P71d05Q8C01`H6@0L5aX00P0I
51P03`0O6Ql07QTO00l:400F4AP05A<H01TH7@0G61X071dO01PI6`0T9BP04a@H01LH7@0H6Ah06AXO
01TI8@0201XJ8P0701TJ7`0N7b@07QlT01`L900M7RH08B@[01PL9@02020T;@0601XQ:`0M92h09Rdg
02HZ=@0U:C@09RXe0P0V;CL02@0S:S@08b`e020Y<P0e?TL082Xc024[=00V<3X0:S=102Pd@P0202Lc
@@0I02XgA`0]>TX0?4UJ03a<G011DF40>dYM0391E00b@U40<41202ln@@0b@DP0=49<03a9F@0gA5@0
=D9C03E2DP0iAUH0=TAA030nB@0b@4/0=dQB03E6D00fAe40=dQB03I7D@0203E6D00I0352C00gB580
=TMA02dnB00lCe@0<TM80354B00gBTh0=TU=04AEG00dADd0?4eE041>F@0iAe<0>DMD03Y6E00e@D/0
=dA:03U6C00oC580@DiD03Y7C@0f@dT0=45702hk@@02034nA00:038oA@11CeH0>dYA030oAP0gATd0
<T5803]:D@13DUT0>DQ?03I5C080=DA;01L0=dI=02`k@P0eA4/0;Se403=2B@0[>T40;Ca303I5C00[
>T40<T5804UHG`0_?TD0=dI=03I3B`0lBE40<d1803U6CP0_?4@0?T]C03A1B@0gA4`0>DI>03A1B@02
034nAP030350A`0`?dH0;Se40080;3]202P0;ca402hh@@0c?DH0;3Ho03<lA@0]=Sl0;SM002Pc>@0`
>d40<Ca202Tb>@0`>D0092dd02D/=00Y<3P09bhf02X^=`0_<c`0;3<i02D/<P0X<SD0:34f02H]=@0W
;SL0:c8l02P[>P0d=TL08R<e02X[?`0`<DH0<SA902T^@@0Y<4809B`n02D[>`0Z<400<SQ802d`?`0]
<3h09RPe0P0T9S<03@0P8Rl06ATU02LW<`0W9c<08R8/010>6@0O7BP081lW02DR:@0M6R4071LN01/F
7@0R7B<00P0P7R40CP0N71l08R0S02<Q9P0N7B8071`Q01`M8P0N7b@07b4W01lR:@0P8b`07ah[02/Z
>00M72X0:bXh01lN;00P7bd09bHd02XY=`0E52808b8`03`kB@0F5B<03Q0M02XY=`0N7B/06aXX00D3
400a;c/0928]01lL9`0Z9c40:BH_02DO:@0L5ad06aHJ01dH7P0P6b407aXP01hI800M61l08A`S020J
900J51h071HP01hH8P0K5B807ALU020J:00P6RL08A/W01hH900O6B@08A/U01`F800K5Ah071LN01XE
700K5Ql07QPT01/E8@0F41/06A<M01`F800K5Qh071LN01`G7@0J5A/06A@J01LB600I51X06aHL01PC
6@0F4AL06QDK01XE700I4ad0618L01LA6`805Q0L01D05a4L03hh@P0I51/03PT@014<4`0G4QT050lF
01lJ8@0910/04`hE018=500?2Q408adT01P>5P0R5al081DM01L<500I3QH060dC01/@5P0J3aD00P0I
3Q80200K4A<071<D01L>4`0C3A404P`@01<=4@0B31003`T=0P0B310201<=4@8050hB00@050T?01D:
400E2Q005P/A0P0G31803@0I3Q@050T?01873@0D2@l05``B01P=4`0E2Ph050T=01P=4@0T6Ad06@hB
01<8300B1`/0100D2@d00`0B1`/04`P<01D:3P0201D:3P0301L<400H3A405@X>00<05P/?01D050T=
01<:3`0E3AD05a4K00d:4`0G5B40=CA202HU<`0@3ad03`dJ018@6`0?2a@06a@L01`E7@0h<CT03`P@
01@=5@0P6B401`0801PA6@0D3AD00P0B2a<0500C31@050dE01D=600G3R006A8T01TC9P0G52L06AHY
01PI:`0I72d0724d01lW>00R:c`08blo02@c@00Y>dD0<D=?03=5D@0dAU80>TaJ0P0nD5h08P11DV80
AEIV04MHJ018FFT0BEY[04IGJ@10Df@0>e1O03M=F`0dBUL0;D5<02i0BP0c@DX0930i03<mAP0h?dT0
9BLa02DT;00S8RX08B0W01lN900P7B@05A<H018@5@0K5QX04@`@01HA5@0D3Q806ADF00l;300<20T0
4@d>00d92P0G4A<301H=400401H;3`0E2Ph050T=01T>4P805@X>00<05P/?01<8300C20`00`0D2@d0
0`0C20`04PL;01872`0601@82P0803hb=00D20X04@D701041P0F2P`050P:00l31@0E2@/200d10`03
01D92`0?0`D04PH800D04PH81P0B1PH04`0<00003@<300h20P0E2@T04@D501861P0?0`<05`/;0186
1P0U6AT05@T901451@0I3@d05PX:01P<300@10@05PX:01451@0?0`D00P0=0@<0100D20X02`0100d1
0`0E2@/201P<3P0301D92`0D20X050P:00805@/<00@0Acdn01T?400700006Q0A0P0F30d0400Q5aP0
2`4201@:2`08004070lG0185300=00L06`hE00/00`0<00@06@dA0186200?0`D03P840104100B1PP5
01452@0=0104200=0@D0200001P<400D20`0200001P<400?0`L04@D901hB5P13=c/05`/?00l31`03
01862P804@D901h03P8603/_<`17>cl04`T;01452@0J3Q804PH:00P0000B1PX03P<601452@0?0`L0
6@hB08Z1Q00Q61/03`H901072P0<0`H0BD1302HM800@1`X05@`?00`31P0A20/0:QhR02/O8`0L41@0
60`@01@8300E2@d601452@0T00X00`0B1`/040H900l4200800404PT;01D:3P0G310060dA01872`0?
10P04@H:01052@0B1`/04`P<01462P0A1P/04`P>00T0100>1@X040D=00L0100D21407a@L01443@0B
1@`050L>01H9400D1`h040<:00d01`0A10/050L>01D83`0G2Q406@`C5?ooool001_ooooo00`060h?
01H<3@0D2P/04`T:01882@0A1`P03@<401882@0?1@H04@L801D;300>10D601882@805@/<00H04`T:
01882@0A1`P04@L80186200D20X201D92`090186200A1@L04`L901L;3@0I3@l040@600`00P0A1@L0
4`L900804PH800<04`L901@82P0E2@/00P0C1`T0100A1@L04`L900h2100?0`D60186200Z01<92P0?
0`D060`>01X>400U6A/03P8400l31@0A1@L050P:01<72@0B1PP05PX<01P<3P0900004PH800l31@0M
4A<03@<401@;300700002P8300P0000k<S<040P901XA4P0B2@X050/<02XQ8P1?ATL06@h@01H:300J
3Q00>bla02/O8@0A1@L05PX<00`00P0>0P@05PX<01L;3@0^8R@0<2DW100D2P/00`0E2``05P`=01D;
300301D;300301D<3@0F3P`050l<00<05A0=00h05Q4>00l:1`0D3``05A0=018=2P0F4@h06A<B01/E
5`0C3@l0618D01D?4@0H4Q@06aDG01TC5@805Q0B0P0E3a40:00S7Al0;BTZ028N7`0K5aP07ATJ01`G
6P0K5QX05Q4E01XE6P0I51X04PdC02HQ:00F51T06Q/O00lC500W:b`05QXK059FF00e>C`03a8G01@G
700H6b005aXQ01PK8P0J7B@06Q/P028S:00V9b`08R8Z01dO9P0M82L0720Y028V;`0Q9Bh072<]01lV
<00V;CL09RXe02@X<`0U:C@202H]=`04028Y<`0R:c@0<CY305YSK0808R`e03D09Bli02Pb?`0[=dD0
:SI402Da@@0V<d<0:SM703]8F@0kBe/0?TiN03U8F`0`?e80<41?0351@`12DE@0>TU>03Q6D00e@U80
>4EE03A1DP0c@540=T=C03=1CP0_?DP0<T1;03]<EP0eAU00<dA>03I7D@0hBE<0=dQB0393C@0cA4h0
=4E?03I7D@0nCeT0Kh:803]@D@0iC500>TeA03=6BP14EE`0=DI>041AF@16E5l0>dUE03Y8E@0lB5H0
>4A>03E2B00gA4X0?4U?03U6C00203A1A`0=034nA00`?D<0=457038oA@0d@DL0?deD03a;DP0c@TT0
=4=:03I5C00kBU40?DaC03I5C00303E4B`0303I5C00kBU40<d990080<d9900d0:CPo02/j@@0[>T40
;Ca303a;DP1QL7L0=TE<03=2B@0Q;SH0?4UA03A1B@0[>400>DI>0080=T=;00D0=D9:03A1B@0c@4P0
<Sm7030mA@02030oAP0402lnA@0^?D@0;Se402llA080;CM000L0:38k03<lA@0W<3T0;CHo03E0AP0a
?480=D160080;CHm00@0;3Dl02H]=@0U;3@0:C0h0P0]<CX0=@0_=S`0:C0f02La=00V;c@09bhf02Xa
>P0/<cd0;2ln04Y<G00T9CT0;c1502h_A00/;T<0;35402T`@P0V;Cl09b`o02H[?@0T:SX0;c9102`^
?@0S9C@092Hc02DW=00L7R/06QXV01/K9P0Q8B/071XU01hM9@0S8RX071TR020M900Q7RD06aHM02@O
9P0X8bT081`M02@P8@0P71d07a`M020N8@0O7B007A/O01`K800M72407alT020Q9P0Q8BT0820]02`[
>@0M72X0<S4o00808b8`01@0JfYh03@c@@0N7B/0:BPf061OK@0l>dT0828_01DD8P0<2aT06aXX01HD
8@0Y9c<09R@_01`I900M6R@081dV01`F800L5a`07ALI01hH708081XN014081TP020I8@0W7bX0:b<`
024I9P0M5B807QHS01dE900O5bH08ATX020H9P0P62D07QHS01dE8@0P62<07QHQ01dF7`0201dF7P04
01dF800I4al06A<O01`F8@80618L00`06aDN01/F7@0K5Q`06A@J01LB600F4AL05A0F01TD6P0G4QP0
5A0F01XE6`0J5A`201XD7P0801TC7@0H4Qh0618N01PB7@0=1a404PdD01/F7@0H4aX301D@5`0;00`7
3P0L5ah06QDL020K8P0?2A008ALO02lT;00/8BT06@hF01P=5@0H3A<00P0G31002P0F2`l05P`=01P>
3`0I41405`hC01@>4P0C3A4050hB018<400?2@d2018<40804`dA0P0D3Q80100G318060dC01T>500J
3aD201`A5`804`P>0P0B1`d201D:400401872`0F2`l06@hB024F6P805P/?00L04PL;01D:3P0H3A40
60dA01D:3P0B1`/050T=00805P/?00<050T=01D:3P0G31000P0E2Ph301H;3`0501D<4@0B2Q80618L
010=5P0A3a/00`0@3ad02`0E4b004a4L01@@6@0S72@07AHN01H?5`0N5al03`P@00d63P0A2Q803`P@
00<05@hF0P0F3aL05P0G3aX060lR01XB9`0I4RL05Q<V01LD9`0G62/06aha01dR=@0N9SP08BXk02D^
?`0V=4409cU302doB@0a@dh0<dEA03M9E@0kCEX0?4iL03m@H013E6@204AEI@0I04EFI`13E6H0?e9S
03Y?GP0dBUP0<4IC02a0B`0[?DL0;Sa502Da>P0_>D80=Se702PZ=00T8b/07ahV020O9P0Q82H07AXQ
02<Q9P0F51T08QdQ020K7`0U82@04`dA01XF5`0301PD5@0500X61`0@2P`060lB01L>4@0F3A000`0E
2Ph201<8300401D:3P0@1@T03P<701dB5P<050T=0P0C20`00`0B1`/05@T;01D92`0401D92`080555
A`0I3@l08aLI01041P0D20X05`/=01@82P0C1`T20186200301<72@0D20X04PH800D04PH81P0B1PH0
6@0C1`L08ADE01P<300?0`<03P<301D92@0?0`<050P800l30`0Q5AD050P80104100J3Ph04`L701dA
4@0E2@T06@d=00d10@0C1`T05@T;01L;3@0E2@/04`L90186200E2@/00P0I3@l06`0F2P`050P:01@8
2P0C2@X05`d>03`b<`0I3a00200001<92P0900402P0101061`0D2P/05@/<00d21P0@10/02`0500P0
0P0A10/05`/?034U:@0J3Q804@D700h2100@10H040@401041P0501452@0>01T=4@08000050P<00l5
1`0D20`0200001D93@0;00<0200005A8C02ZWZ80=2P/0104200D20`201H:3P0P01@8300B1PX04`L;
03/_<`13=c/050X<01862P0G2`l040D800P0000N4QH04@H901D93@0A1@T02`8402hU:00700402002
01482`0B2@`08APK00h5200700403@@700`31P0F3A0040@801@8300<0@@040@800h21P0?0`L60145
2@0I00d21P0A1PX04PL;00L0000<0@D07Q@G00l4200@1@T04@H:01052@0?10P03P<700l4200A1PX0
4PL;01052@0@1@X04PL=01<83P0A1Pd03`@<03/`>00E31<04@H>01<63`0201442`804PD<00L03`89
01442`0D1`h04`H=00l22@0:00@02@0301Cooooo000Kooooo`0l01/A5@0D2`h040P901<:2`0B2PT0
3@H401071@0B2PP03`P801482@0D2`l050X?01@9300E2Pd03PD601872P0C2@X050X;01H<3@0E2`/0
4`T901471`0B20P04`T901L<3@0B1`T04PL80146200A1PL04PL90146200C20X050T:01@92`0G30d0
4PL902dR8P0G30d05@X:01461`0A1PH0714B01461`0D2@T04@H601@92P0?10@060d=0187200D2@X0
4`P:01461`0D2@X040D601461`0G30h050T:02XO8@0j;c405P/=0P0C1`T0900F2P`05@T;01<72@0B
1PP05@T;00h2100E2P/0308301<72@0F2``05`d>01H<3@0E2``08ALH079YJP0`9bP040L700h41@0E
30d03`D602@K700?1PL0714B00d3100U6Q/07A8C01<82@0J3a005``=01P=3`0D2@X03@@501H;3@0L
4A<05@/=01H;3P805P`>00@05``?01882P0C20/05@/=0P0F30h0700F2`h04PP:01@;2`0H3Pl05`d?
01D<300D30`06Q0C028K6P0E3@h0614B01TB4@0e;c004`h@01PC500E41406QDF01HA4P0E41406A@F
01LB500L5aP05Q4B01<>400G4Q<07APK01PC5P0K5QP201D@4`3g01XE6@0N61`05a8G01XE6P0Q6b00
<2X_01dJ7`0G5a`07AhQ00`?4@0H61/08B8W01@E700E5A`06AXP01dO9`0L6bD06a/T028T:`0L7R<0
8B@Y02HZ;P0U:Bl0720V01/Q9`0N8b`07RD/01/S:`0J8R/072D^028Z<`0K8Rd08bPe02@Y=@0R:3D0
8RTe024Y<`0^=d80>T=?059LIP0X<S`09c8m02Pd?@0V<cd0;3U502/hA00X=D<0:3E502XgA`0b?e00
;Sa<03A3D@0b@Dl0;ci<02/jA@0_?dH0@51F03i>E@0kBU<0=4=>04EDG`0d@dl0<D1<0310BP0^?TP0
<T5;03I6C`0gB540=TM@03=4C@0b@d`0=dQA03Y;DP0iBU80>T]B03I7C`0`@DT0AUMM07F7S00jCU80
<DA903I9CP0]@4D0>TaB03U;DP10DUT0A5IM03a=EP0hB540=dM@03A4B@0oD540=dE:06=cMP0jBd`0
=dE903Q7BP0dADH0=TA903Q7BP0dA4H0>4I:03E6B`0c@d/0>DU@03A4C00c@d/0=4A<03=3BP0fATd0
<D5903=3BP0dA4`0<T990391B00a@4H0<T5702lnA00c@TP0<3m502He>`0a@4H0;ci403m>E00a@4H0
;ci403U6C@0`?D@0<Sm603A1B00`?D@0>TM>03I3BP0a?TD0;ca3038oAP0d@DP0<Ci502dk@@0^?D40
<Cm60390A`0a?dH0;ca3038mAP0[=Sl0:CDn03@oB00]>440=3m8041;E00a?D@0=417030j@P0_>400
>D9:02Ta>P0W;cL0;C@m02`a>`0W;CH0<3Lo02hh>P0X<c@09S0c02Xb=`0]=Cd0:c<l03<hAP13AeP0
;c55038dB@0_<4H0;C5501XS<`0Z=D80:CA103HoC@0_=dD0:2lk02P^>`0S9cD0>Sa:01TK:00W:3D0
6Q/W024Q;00O7bP09bL^01lO9`0Y:C007QhU028R:@0O7B<08b4W01lM8`0U8bT08b4V01hM700S8R<0
8B0Q01hM7`0P7R808b4W01hK8P0L6R<07A/S024N:00P7BT06aPU01lN:`0U9C805aLT02/[>00Q82d0
6ATV0450C@0O7R/09bLd020P;@0Z:CH051@Q01hK:@0P7B/08Ah/01lL:P0N6bT071PU020K:00O6RL0
8al[02@P:P0P6RL08A/U01`H7P0Y8bX08adU01HB6@0M5b00618L01hI900Y8Rl09Al[024M:00Q6RL0
61<Q020K:@0201`G9@10020K:00I520061<N01hI900J5Ql05A4I01lK8`0?2a806aLO01`G800P6bH0
81`T01/F7`0J5Ah06ADM01PD6`0J5Q`06ADK01LC6@0E4AP05Q4H01TD6`0H4aX04`hE01D@5`0H4aX0
5a8J01TD700E3aP050lG01<=5P0F41X0618I01/E700F3QH05`lG01TC6P0F3aH06A4I01PB6@0E3QD0
6A0H02LQ:00N5Qh040H?01hF7P0L4Q`06a0J01894@0J4AT05`dD01L?5@0G3A@05P/B01L>500J4QT0
5a0F01@=4`0?2@h05Q0E01D>4`0G4AD03PP<018<40804P`?03P050hA018<3`0E3A4050/?01D>4@0O
5AX081PL01@<400;0PH04`/>01D=4@0?1@T040P;01dC5`0B1`/05P/?01L<400H3A404`P<01L<400F
2`l05@X>01T>4P0J3a<05P/?01L<400C2`h05P`?01D>400@1`X04`T<018:3@0C2`h04@L:01H?4@0B
2P`05@/?01XB5`0M5Qd050hE014=5@0G4a`06ADO01@@6P0@3AL04PhG00l;500B3A@06a@L01D>5P0B
31<03`T@01D?5`0?2A004P`D01@>5P<04P`C01L050hE01D?5P0E3QT05Q4P01PC8`0I5RD06ALV01PG
9P0M7Bh06A/[02HX>00O8cD09B`m02@[?00V<D009cQ302LhA00/?DP0=DIB03I8E00hBUH0>D]H03Y=
FP02041CH00f041BH@12E6<0@U=R03U;G00kCE`0=TQE0353D00/?DP0;Ca7030lAP0X<S`09bli02hd
?`0/;ST08B0X020O9`0G5ah0820U01PF700L6Ql04A0E01LD5`0F4QH061@H01LB5P0E41<05A4C01@?
5@0M61d04@dC01L@600C2A407QDL01<9400F2a0040D901dB5@0F2`l06PlC01T>4P0E2Ph04PL;028G
6`0D2@d081DI01dB5P0@1@T04PL;01@93@0E2@/04PH801L;3@0L418060`>0P0F2P`01`0H3@l0?S8d
01lC5@0@1@H04`L901D92`0@10H00P0E2@/0600@10H05@T;0186200A1@L04PH801@82P0C1`T03`<5
01<71`0E2@P04@H50145100B1`H040@301<71P0N4a805``;01D:2@0D2@P03P8200l4100A1PH03@<3
01H;30804PL802<0714A01461`14>CT0;R<T01D;2`0F2`/04`P:01872@0A1PL03P@501@92P0D2@/0
4`P901H;3@0G30d05@X<01<82@0B1`T050X<01H;3@0H3A0050T<00`3100H3A005P/=01@92`0=0`D0
40D700h31@0H31005@T>00h3200H31403`@900h41P0201H:3P0k00d21@0?0`H050T<01<72P0?0`L0
4`L;0104200C1`/03@<50104200>0`H06`lC01P<400@1@P04`P<01X>4P0?10L03`@801X>4P0C20`0
81@H00h31`0@10P040D901D:3P0B1PX04PL;01<72`0>0PH040@801052@0A1`X05@T=00/2100Z7R80
3P<701L>400G30l05PX>03lc=`0E2`h02P8400l52@0@1PX040H900d31`0D2Ph0>c4d01L=4@0F30l0
30@601062@0A1@T050P<01862P0E2@d04`L;01862P0@10P00`0A1@T201862P8040D900@04@H:00d4
1P0M4QH0=2T]0P0?10P01@0A1PX04`P<01<8300C20`040D:00<04PL<01@03`@901H;4@0>0`T040D;
01<83`1MDUT07a@K01@9400D20l04`L=00l32P0B1Pd040@;01863@0C1`h050P>0186300@10/04@D<
01@83QCooooo000Kooooo`0K00l83`0>20/03`T900l92@0@2`L05Q4;00d80P0>2@D03`X7010:300A
2`h04P`@01462P0B1`/03P<701H;3`0A1PT040H701@:2`0D2PX04PP700l5100A1`D04`T701882@0>
10D04@L800804PP901l05P`=01lE5P0F30d03`D601D;300G3@h04`T:07U_KP17?C`091XI01H<2`0Z
81l01`0001881`0@1PD050X901<9200<0P402`4001@:2`0E2``04`T:00l51P0H3Pl04@L801H<3@0A
1`P03P@501061`0F30d05P/=00@04`L9024050P:01<72@0F2P`04PH801X>400K3a4060`>01/@4P0@
1PL04PP900d3100D2P/07Q@E01T?400B20T0718C00l51P0;0@805`d>00l51P0G3@h06a4B01hD5@0C
2@X060h?01<92P0=0`@03P@501H<3@0C2@X04@L800l41`0C20`00`0D2@d701D:3P0=01452@0C1`/0
50P<01<72`0B1PX04PL;01D:3P0H3A4071<F00d41`060000618D01DA4P0201<?40805Q8C00D04`l@
01DA4P0D41407ATJ01LC500201PD5@0601LA5@0A2`l071HJ01TC5`0G4AD05@lC0P0I4aL0=P0L5QX0
6aDI01TC5`0M61`03`dB024P9@0_;S<09bH/014@5`0S8RX061LO01XI8P0Q7bX081hY024O:P0];CD0
;2lf01hS9`0O92P08RT_01/R:00>5A/05b0W01/T:`0L9B`06B</01/U;P0O:C808RPf020V=00Q9cD0
92Xh02P_?00X<3d0:c=002@^>P0R;3P08Bdi02@`?00U<S/09SDm02lmAP0`?TT0:3I302PeA@0]>TX0
>DIF03m=FP0mBeP0@4iH04EDF`0a?dP0;3e702dnB080<45900T0:ca303]<D`0kC5<0>T]B03I7CP0c
A4/0=dQ@03Y;D`0`@DT00P0a@TX0300b@d/0<dA<03A5C00fAdh0?e1G03A6BP0_@DD0>D]?03U<D@0l
CeD0<4=902e0AP80?e9H0200=dY@03Y=D`0lCeD0>DaB03E8CP0fBDl0=dU<03I8B00hBTX0Z[bl049D
E00S=CD0=dU903=5A@0a@d<0=TQ803Y<C00hBTX0<T=80311B@0dADd0<dA<04AEG@17F600<4590352
BP0cA4`0=dQ@0352BP0jBe80=dI=03=2A`<0;Ca100P0:cXo02Th?@0[>Sl0;Se20350A@0b@DH0<d97
030m@`80<Sm501<0<d1603M4BP0d@DL0<Sm5030m@`0_?480<Ci403=0AP0b?dD0;S`o030n@@0e@dH0
=dA:03E2B00a?T@0;CY202/h@00Z=d00;3U20080;S]400P0<3e502/h@00/>D40;CM002`f?`0a>T<0
:C8k02L_>@80:c8l02<09bhh02Xc>P0U;c40930`02Lb=00[=3T0;CHn02`e?P0[<Cl09B/j034fB@0_
<DH0;S1702L^@@0[=d<08c@l04]IHP1PKGH09S4k03LoBP0^=400:Rlk08^?V`17AU@061LU020P;00S
8b/06Q/P02DV:`0W:2d08b@Y01hO900Q8RL07QlT01`M8P0201dN8`0501`M8@0J71X06adL01dO7P0P
82800P0O7R@0500V8b`09b<a02<O;@0U7Rh08Q/]01/G9P0H5b<07AdY02LW<`0K6bL05QHR02h^>P0P
82`08R8^02<S;`0Q8Bd07AdY01`J9`0P6bT081XX0`0O6BL0500Q6bT07ALU01dG9@0S7B/08Q`Z024K
:@0R7BX07Q/V02dZ=@0/:C@08AhY02dZ=@0a;ST0924/020M:00O72L06AHQ01hK9P0H5R804a4N0P0D
4Ql04@0N72T0928]01XH8`0Q7bX030/C01PG7`0>3AD07QdS01`J8@0K61l061DL01DB6@0J5ah061DL
01LD6`0B3aH03``C00<05Q<J01804`hE01HA600H4aX05Q4H01D@5`0H4aX0HeiU04E0A`0I51/081/R
01lJ8@0@2a805P`D01<94@0A1`l05@/C01T?5`0L4QX401L=5@0O01H<500E2a<04PXE01H>6@0L51l0
;RHa01XB7@0M5B0040PC01L?6P0M5B005`lJ01084`0>1Q403@H>01L@600N5ah04P/B00h73@0@2Ph0
5a4E01XD5`0D3Q004P`>01<=3`0A2`d04`d?018<3P0A2`d0618D01/E5`0200h82P0501<=3`0I4aD0
5Q0B01XD5P0c;Bl00P0G310201H;3`805@X>00L05P/?01872`0F2`l05``@01H;3`0J4A@04``>0080
4`d?01005@lA01LA4`0<1PP06A<E02hX:P12?3h050h@01D?4@0=1`T04``C00`5300I4QT04P/B01L@
5`0@2A0050dD0P0C31<02P0D3A@05@hE01D>5@0K5Qd01P4801D@5`0G4QT0:RD/014<4`0D3aH2014<
4`0<018=500E41L0514J014>6P0B41d05QDQ01HF8P0E52805ADS01@F8`0S9C@07b8b0P0W:S/02@0T
;C`09cE202LgA00Z>TL0<d=@03A6DP0eAe<0=TQD03E9E00203eAG00W03a@F`14Ef@0@eES03U;F@0i
BUL0<T9?03Q6D`0a?TX0;cU5030h@`0V;ST092`g02P^>P0S:3804A@K028R:P0N7RD0;Rld03Lf?00J
6Ah05aHK01/I700M6ah05aDH01D@500?2Ph07APN01lJ8@0H4Q`07QPT01H>7@0S62H0OWAo03D[=@0L
4AL06Q0A01D;2`0W72008aPL00804`P<01@04PL;01dB5P0C20`08aPL024F6P0?10P04`P<01P=4@0C
1`T03`<501<72@0H30h05PX<01<72@0D20X03P8400l31@0P51H04PL801041PH04@D700h0300202@H
6P0H30h02@0000/10P0=0@<04`L701D:200@1@<04PL501/@3P0J3`d04PL501@91`805@X801404`P6
0104100D2P/04`T:0147200@1PL03`D600h41@0900004@L801882@0D2``06a4B00L0000C2@X04PP9
0147200201882@0301<92P0D2P/05P`=00805`d>014050X;01<92P0E2@d0200000X00P0K3a<03`<7
00P0000B1PX04@D901@8300B1PX03P860104200<0`D05``@00T00P0300h31`0:00d41P0J3a<02001
00X10`0?10P060dA00d21P0O51P040D901L<408040D900P07a@H00/0100A20X050T=00P00@0G3100
4@H:01052@804PL;01D03`@801052@0A1PX05@X>00h41`0>0`L05P/?01872`0@1@T04`P<00l5200G
31002@0204i3A`0M4QH0714E00/2100;00@0@3Di01462P0@1@T00`0?10P01`0@1@T0;24U05]@E00H
3A405@X>01052@0^8bL00P0A1@T201862P804`L;0P0@10P301452@0;01862P0A1PX040D900h31`0?
10P04@H:01D:3P0>0`L03`@801462P0B1`/00P0A1PX0200A1P`03`@:0146300S61h060dC01873@0?
10X040D;0P0A1P`0200B1`d04`P>02@I7`0B1`d05P/A01T>500C20h05@X@0P0B1`d0100A1P`040D;
01052`0?10XDooooo`006oooool0:P0L5QX04`d@01<=3@0B30`03@P4018=1`0=20803@P400h91P0?
2@/040X=010:3P0E2Ph04`P<01X?4`0T6Ad05@/=01<92P0B20T050X:01<9200A1`H04@L501881P0E
2``04`T:01D;300B20T04@L801H<3@0O5AH08ALH01061`0F30d040H701@:2`0I41007aDD00L0000F
3@d04PP701P>3@803`D40P0E2`X201061@0<01882@0C2@X04`T:01H<3@0T6Q/07aDF01@:2`0B20T0
3@<400/10P0B20T05P/=0`0D20X0300C1`T04PH801041P0B1PP04@D701T=3`0J3Q0060`>01/@4@0I
3a005@/<00l51P804@L800/05P`=0147200I3a004`T:00l51P0G3@h040H701<92P0I3a006a8B02PN
7`0201X@4@0600d3100E2``07A<D01hD5@0Q5aP05P/>0P0G310301H;3`0401P=4@0G31005``@01@9
3@804`P<00<05PX>01D93@0E2@d00P0F2Ph05P0C20`06Q4D00T00`0K4QD05@lA01XD5P0B30h06ADF
01<?400@30d05Q8C01TE5P0C3a00510A014=3P0J5QL05Q8C01PD5@0L61T05Q4E00d8300G4QH201TD
600=01<>4P0H4aL061<G01/F6P0J5AT061<G01dH700`;S<01@@901DD6@0I61h04Q4G024P9P0201dL
900Z01hM9@0K6B@06ALR01lO9`0[;SD06QlS010E6@0?5Q`072<Y01PO9@0G82L072D/01lX;`0N:340
7bTb020Z<`12B5H09bdk028X=P0W;c`092`i024Y=P0X<Sh08bdi028/>00T<3`09S8n02Ld?@0^?DD0
;C]402/iA00U<d00>DIF051MK@16Df<0;ce:02Hd@@0[>D<0?4]B03Q7CP0`@DT0<D9:0P0]?TH0?@0Y
>T40<D9903Q:CP0iBdl0=dU=03=4B`0b@dX0<dA<02hoB@0[?4H0;Ci80393C00b@d/0<D9:03I7C`0m
CUD0>4U@02`mA00cA4/0;T1603mBF00mD5H0<TE;03M:D00dAdd0>DaB03Q;D@0fBDl0<DA:02m2B00d
Add0>Te@03Q:BP0[?Cd0E6IV0353@`0W>CT0=TQ803A6AP0cADD0=dU904=EE@0nD500=DI;0352BP0b
@d/0<dA<03Y;D`0lCED0<D9:03E6CP0dADd0<45902Xk@`1@HFT0A5=J03a;D00`?d@0;ci3030oA00^
?D800P0]?4401P0^?D80;ci3030oA00c@TL0;ca2038oA@80<d1600H0=D9802ll@P0a?T@0;ca202hk
@@0`?D<2038oA@0902dk?P0^?3l0<Cm2038oA@0a?T@0<3e3030mA@0^>d<0:cQ10080;3U20280:cQ1
02dj@`0Z=d00;3U202hh@P0Z=3h0;CM102Xb?@0U;CP0:30k02`b?P0Y;c/09Rlh024Z;`0T;c40:C@h
02`e>P0]=Sh0;3Dn02H/>P0T:ST0<SM:034dA`0_<DH08bXl02<_>`0]?DD0TInX0:Re_P0g@T`09Rhi
02`b?P0V:cL0ADUE0P0H5bD06`0[:cL07AdW01lO9`0U9Bd08R8Z01dM9@0N7RH08B4Y01XJ8P0K6b<0
7alW01dM9@0I6Ql06AXK01LI600K7A`08R<U020O9@0L6b408b8Z02HR<00P72X07aPX020I:@0M6BP0
9B@a028R;P02020P;00301/K9`0H62@07al[00807al[00<07QhZ01`L:00L6RL00`0M6BL201hJ:003
028N;00P72X07ATW00<081`Z00<07Q/W01HC7P0F4ah00P0H5B008`0O72L0=S<n02TV<@0O72L08QlZ
01HC7P0J5b807Q`X01XH9@0R82d07adZ01dK:00N72L06QPR01DD700[:S8081lV01lN900:2@l06aTO
01lL8`0N6b8071TP01hK8P0L6B005a@K01DB6@0K61l04PlF00d:4@0^:c807aXQ01`G7P0I51/061<J
00806A@K00`0B4=:038]=00B3A@04`hE010;4P0L5ah0;bD]020F7P0F31@060hF01H<500J41P201P>
5P0>01L=5@0E2a<05@/C01D;4`0K4ah04@TD018:5@0K4ah040PC01D=600@21<0610K020H8`0H41/2
01084`0H01PA6@0D3A@07aPO01<<4`0L5A/04`dA01XD600I4aH04@/=00l92`0B30h040X<014;3@0C
3@l040X<00l92`0B30h04@/=01H@4P0B30h03`T;018<3P0;1PL06Q@F0P0G310201H;3`805@X>01D0
5P/?01@93@0E2Ph05P/?01@93@0G3Q404P/=018<3P0<1PP04@/=01D?4@0<1PP04P`>03Xd=P1CCDl0
4`d?01`F600=1`T03PL>00P1200N5ah00P0A2Q400`0D3A@04P/B0109400301094008014:4@0?2Q40
1`8900h9400P6b80/jje030[<P0C3QD2014<4`05018=500D3aH04a0I010=600B41d00P0E4b003P0D
4b405QLT02PZ=`0R93<08bHe020S<P0T9cH08BXh02@b?`0X=T<0:cY70351CP0b@Tl0=4EA0P0dAU80
6`0kCUX0>TiI03Y>F@0lCe/0<49@0312CP0eAU80=DEB034oBP0X=D40;3I202Xb?@0T:cL08bTe020V
<P0P9Bh09bXa01hN9P0W:2h0XjBY075`MP0K6Ql06APM01lM800Q7b806aTL01LB5P0201LB600F01PC
6P0M5b40:bD_01H>6`0I3Q`0=2Xe01hD7@0@1@/05`d>01T?3`0H3A406PlC01D:3P0J3a<050T=01<8
300>0`L05P/?01P=4@0@1@T04@H:01@93@804`L90P0A1@L0200E2@/04`L901D92`0@10H02`0101dA
4`0E2@/040@61P0A1@L01P0E2@/0=BT[028F600?0`D05PX<01@82P8050P800D04@D501<71`0N4Q80
8ADE0104100501451@8050X;00/04`T:0147200?1@H03@<400l51P0D2P/0>Bl`01@:2`0I3a0050X;
01882@03014720804PP900`05@/<01H<3@0G3@h05`d>01D;300D2P/03P8601X>4P0H31002`43024E
6@0O4aL201862P0K01H:3P0B1PX0300400d11@0B1`/04@H:00`11@0C20`060dA00h31`0;0P@050T=
00`11@0H3A403`@801052@0>0`L03@8601052@0C20`050T=00d41P0?10P05``@01462P0?10P03P<7
00804PL;01@040D901462P0B1`/04@H:01052@0900803`@801@93@0@1@T04PL;01462P0=0PH04`P<
00h31`0B1`/03@8602LL800700007A8F00`11@805``@00<030<501462P0A1PX00`0A1PX01P0?10P0
91TM00`31@0<0@D03@8601X?4`804@D90P0B1PX201<72`804PH:0`0A1@T0100@10P04`P<01872`0?
10P300d21P803P<700T040D901462P0@1@T040D900l42P0@1@/04@H<02@I7`0I3Q@00`0@1@/40146
300601L<4P0L4AL02`0600l42P0j;cD050T?0`0B1`d3014631Cooooo000Kooooo`0H028L800B30l0
3`T901@>3P0@2`L02`H200d80`0=20D03PT600h82P0?2@`03`T=01L<400A1PX06a0D02HK7`0C2@/0
5@/<01061`0C2@T050X901881`0B20H04`T70P0@1PL04@0B20T040H70147200F30d0;B<T03hd=@0I
3a003`D601hD5@0o=CH04PP801L=300@1PD04PT801L=300F30/06a4@008050X900@04`T801061@0B
20L040H70`0B20T02P0I3a0040P801882@0M4a@07Q@E01H<3@0A1`P04`P901<72@0D20X401D92`80
4PH800H050P:01041P0B1PP05@X;024G600I3a0201@:2`0J00d3100C2@X05@`<01`B4`0D2P/030<3
01882@0C2@X06a4B01P>3`0`9RL0CdE601892P0I41004`T:01X@4@0@1`P040H701X@4@0C2@/05`dA
01L=400E2`l05@/>01@:3P0F310201H<3`0401@:3P0D2Pd050X=01L;3`805@T=00d06@hB01/?4`0G
31006Q4D018:300F3a404P`>01<=3`0F41805a<D01DA4P0C3a005A4B00805a<D00<061@E014=3P0J
5QL00P0F4Q<01@0L61T071LK01D@500N6Ad06A@H00@06QDI00H07APL01`G6`0J5AT07A/N06m]LP0U
92T201TH7@0M024P9P0N7B<06QTP01dL8`0M72@06aXS01`J900M7BD061/R02H[;`0R9b/072<Y01XQ
9`0I82H07RL^01lX;`0Q:S408R`e02H`>@0X<S/0B4iL02T_?@0W;S/0:c=0028Z=`0R:cL0:38n02<^
>P0T;c/00P0W<cl04@0T<CX0;C]302Xh@@0^?4D0:cU503A1D@13D600GFYj02Pf@`0d@Td0=TA=02ln
A@0d@dX0;T1603=4B`0Z?440<D980080;d1702@0;3i302i0A00`@TH0<TA903=4BP0cA4/0=DEB03E5
D`0dA500<T9?03A5D00gB540<D9;03M8D@0lCE@0;d1702m0B00fB4l0=DQ>02`oA@0jCE<0<DA:03mB
F01VNGl0AUUO03U<DP0cAT`0=4M=03=6C00aA4L0>Ta<03a>CP0a@d<0@59B03A6AP0cADD203a>CP0H
0394A00kCDd0>de=03E7B`0_@4P0<T=;03E6CP0dADd0>4UA03E6CP0b@d/0;Ci60352BP0Z>d<0?e1G
03a;DP0fADX0;ci30391AP0d@dP0<3m403=2A`0b@DH0;ci30P0]?4401`0_?T<0;ca2030m@`0_?480
<3e303A1A`0a?T@00P0_?480100^>d40;ca202ll@P0a?T@302lm@0<0;ca20300<3e502hk@`0/>D80
;3U202dj@`0[>440;CY302/h@@0^>d@0;cY402/f@00]=d40:S<m02Xb?@0W;cX09B`h02P^>P0[<cd0
:S<k02Pc>00/=ch0<S]302hg@00T;CH09bdi02H/>@0_=D@0;S51034dA00W;C`09C0k028`>@0/>T<0
>DA>02Tb?@0W;cX06b4]01lT<00K7b/051HS02HV=00J6RH07AdW024Q:P0O7bP08R8[01TI8P0N7RL2
01lO:0807QhW01<07AdV01dN900K7Qh07R4Q01dP800Q8RH092@Y020P9P0P7bL07a`W01dI9P0U82l0
:RDd02LS<@0O7RX071`X02@T<00Q8Bd09BDa00808R8^00<0820/01lO:`0P82`00P0P82`0100L62H0
7QXX01lK:@0P72X201lK:@0301XF900I5B<07QXX00807QXX00X0:2Da02/X<`0P7BP07a`W01`I900G
51l08AhY01TF8@0J5b807a`W0P0N6bH03@0Y9S80?C]801lM:P0E4b007Q`X01@B7@0/:c@0GUeU01dL
8`0J6B008R4W010?5@0I5ah00P0I5Qd03`0E4QT04PlF01DB6@0I5Qd0514H01XG7P0H5A`0514H034^
=@0V8BP07QTP01D@5`0F4AP06A@K01LB6@0201@?5P0<01LB6@0L5ah050lF02TT:`0e;SD08QTQ01P@
5`0M51`05@dD01H>5@0J4AT06A0H0P0H41L06P0J4AT07A@L01H?5`0G3aT05PhH01PA6P0L51h05`lI
01@=5P0H41X05a0I01094P0G3aT091dV01094@0J4aX050dD01L@5`0B2a403`T=01<=4@0E3a804`d?
01H@4P0K5AL05a4C1P0C3@l01P0@2P`050h@01@>400F41803`T;01XD5P805``@0P0F2`l201D:3P03
01P=4@0G31005@X>008050T=01H04`X=01<<3P0=20T040X<01LA4`0?2@/05Q0B018<3P0H4Q@08Q`N
00d72@0?2@/04`d?01@=500<1@`06a@K01<<4`0>1`h05PlF01D>5@0C31<04P/B0P0A2Q40200B2a80
3`XA018=500>2Q00:2<Z09:=U00b;C@04PdD0P0A31<0=@0B3A@050lF01@?5P0D4A`05aDQ01PF8P0G
5B805QHS02@S<@10@4h07Al]020R<00L7bh09BPg024Y=`0R;c`0934n02Le@P0Z>DH0;ci;03A4D@0b
@e00<dA@03U;E`0hBeH0=dYE03M9E@14EV<0EFIc02loC00]?4T0;ca702hiA@0[=D00:S8m02L^>@0Q
:3<07b@`01hQ:`0i?4<0:RXb028R:@0Z:c00<S4g01hM8P0I61d06QPK01/I700G5AP06A@H01/F700A
318061<J00805Q0J00`04`/G01X@700J4QX060lG01P=4`0B1`/06Q0A01@93@0F2`l050T=01`A5@0F
2`l301<830805@X>0P0D2@d0300A1@L060`>01D92`0A1@L05`/=01@82P0<00805PX<01lC5@0<0@80
40@601<72@L04PH800D04`P901041P0B1PP050P:00`20`0201@920804`P700X05@X901D:2P0A1PD0
40D500l40`0?10@04PL601@9200>10D03`D6100A1`P02P0?1@H05@/<044g>00D2`/05@/<00l61`0B
20T04@L801061`0A1`P201882@804@L80P0B20T0:@0A1`P040H701862P0A1@T05`/?01862P0B20X0
;bDW01P<400C1`/05@T=01452@0?0`L04PH:00l5200?1PP081DI00/2100D2@d030<501<8300O5QP0
BCi200l5200>0`L04`P<01P=4@0@1`T04`T<00/2100B20/05P`?00l4200=10H0FDiB040f>@0N5AL0
<RL[01<8300@1@T04@H:00804`P<00<0:1dQ01lD600?10P00P0@1@T02`0D2@d04@H:00d21P0D2@d0
4`P<01052@0C20`07A8F00h51`0N4aL03085008040D900<04`P<01052@0A1PX00P0A1PX01`0@1@T0
4@P:00T00P0F2`l04@H:01D:3P0?1@P00P0A1@T201862P<04`L;0P0B1PX00`0A1@T040@801042002
01462P804PL;0P0A1PX0100>0`L03`@801052@0@1@T200l4200800d2200F2a404`P>01873@0=0PP0
5@X@01873@0A1P`201052`803`@:00H03`D:01@:3`0A1``02`86038W;@0A1P`601873ACooooo000K
ooooo`0:00H0100A2`d02P@400D0000;1P<030L300h91@0>2@H03PP800l92@803`T;00d05P/?0187
2`0C20`06PlC00l51`0E2``040H701<92@0B20L04@L601881P0D2PP0718C00804`T:02D04@L800l5
1P0A1`P04`/;01`B4`0900002@0100d3100K4A80718A04Pn?@0B20L05P`;00L0000A1`H05P`;00d3
0P0>10<03`D401471P0E2`X03P@50147200D2P/05@/<01L=3P0:00404`T:01P>3`0G3@h04`T:0188
2@0C20T04PH801<72@0E2@/05PX<00805`/=01@040@601D92`0E2@/040@601H:300D2@X06@l@01L=
3P0D2P/05@/<01882@0D2P/0DdU:05iDE@0E2``040H701T?400K4A801`0001L=3P8060h?00P07Q@E
02<I6P0J4140308301dC500G3@h04PP901T@4P805@`?0`0D2`h05@0B2@`04`X=01@;3P0D2`h05@`?
01H=400F2`l05`/?01P<400J3a<06a0D01T?4P0G3Q407QDH02HP8P0M5aT08Q`N01<=3`0@30d04Ph?
01@@4@02014=3P0=01HB4`0G4a@04`l@02LS900U8B806aLH01HB4`0E41@05a8F02XU:@0R7B406A@H
01D@500201PC5`0G01/F6P0J5AT061<G01/I700S8RL09B@Y024P9@0E51T05QDJ010?5@0G5Q`071/R
01`K8`0M72@08B0Y01dM9@0V:Bh06b0T00`A5@0/<cT072<Y01/R:00O:2l00P0K92/07`0N:34092hg
02La>P0W;cX07bHc02<[>00U;CX08R/g02H`?00T;SX082`h02@`?00]>DD0;3Q402Tf?`0T<cX09cDn
02dkA00c@D`0:cU602@a@@0^?4X0<d5<03E3CP0`?dL0;3]201l^<`0^@4@0<D=702Xl@00`@TH00P0[
?4<0900Y>T40:ca30312AP0gBDd0>4Y>03Q9D00lC5X0?TiM03Y:F@0b@U40=TIE03e=FP0fAU80>DYD
04=DGP11DUX0>4UA041BF@0fBDl08C@j03A7C@12EE/0@EAJ051SJ@10DeT0=4M=03E8CP0jCE<0=4M=
03=6B@0/?Sh0;T1002do?`0`@T80<D=303a>CP80@UAD00l0<TA40312@P0dATH0=TQ<045BFP0oD5P0
>T]C06QiP@1TMGd0>4UA03I7C`0]?TH0=4E=0393B`0X>D400P0/>d00100_?T<0<d9703A3B00a@4D3
02hm@P0302ln@`0`?d@0<D150080<d1600D0;ca2030m@`0f@dT0=dA:02`i?`0202hk@@0302`i?`0]
>T00<3e300<0;ce00`0^>d40100]>T80:cQ002Xg@00/>D8202dj@`0]02hkA00[>440;CY302dj@`0Z
=Sl0;SQ202Tc?@0_>480:30k024Y=00W;SX0;cM202dg@@0[=Ch0;SQ103@mAP0`>D8092df02`c?@0X
;cX0:C0j02L[=P0`=3l09bhh01lY<`0S<3T07BLa01TS;@0R:cD08BTd02<Y=@0I7RX06al[01<E8P0E
5R<0<30l05=CG`0V9S00;Rhh05YJI00_;cT0:b/e01hN:00T92h08b<]00807QhX01H08R8Z028V9`0W
:b`07b<T01lP900U9R/092DZ02DT;00O72L07Q/V02XV=00/:3H09B<`01`K:00L72P0820/01PH900S
8bl05aLS020P;00O7b/07QhZ0P0O7b/09P0P82`07AXX020L:P0Q7B/08Qh/020L:P0L62H05a<Q01TE
8`0R7R`08Ad[01lK:@0N6bL06AHQ01XG8P0M6RD05Q<N018?6P0D4A`05A8M01TF8@0E4Qd07a`W02@Q
;00k>DD0HV1]02l]>P0H5R807Q`W00X84`0N7BD0GUeU00811`0B4AL08b8X01LF700h=S`0<c0g0P0G
51/0200R7bH07Q/R01`I800H5A`05Q<J01PE700F4aX061DL0P0G4QT02`0N6B009R4X02@O9P0I51/0
6aHM01HA600=20l061<J01D@5`0?2Q407AHM00804``C00<06a@K01L@5`0E3QD00P0D3A@08`0E3QD0
5PlF01PA600J4aX06Q<K02PQ:@0E3QH050dE00l8400>1`l050dE01L@600H4AT05@hF01L@600L5Ad0
5PlG01PA60080@P06A8I01/E6P0H4QH04P`@01D?4P0F41806Q@F01dG6@0D3Q005Q0B00l92`0B30h0
5a4C01@>400@2P`03`T;00805Q0B00<02P@601`F600E3a400P0G310201H;3`805@X>01X04PL;01D:
3P0C20`05@X>01X?4`0H3a807aLJ014;3@0R71h0?cTk01dG6@0H4Q@05Q0B00@000070@<07ALI00`6
200J51H03PL>01H?5P0;10/04@XA00l83`0B2a805@hE01@=50<04``C00D050dD01D@5`0I51/030L>
01<>5@0200`73P03010;4P0A31<04@`C00<04PdD01805Q<M01/I900J62@05aDR01PF8`0O7b`09RDc
010B7`0B52807R0_02LY>00T:ST07b/i020/>P0R;S`0938o02dkB00fA54202loC00G03I6D`0cAE40
<TA@03E7D`18FVH0F6Qe02dlB@0]>dH062@`02Pc?P0W<C/09blj02D/=`0M92h07R8]01TM9P0b=C`0
61PP01HF7@0L7B8061LM01lN8`0H5a`00P0C4A@07P0B41<061<G01D@5P0N6Al04PdD01hH8P1bK7H0
7QHP00`22`0M4a/04`X@01<8300K41@06a4B01T>4P0J3a<05P/?01lD600J3a<05@X>01@93@0E2Ph0
4PL;01462P0F2`l050T=00l31@0C1`T050P:01451`804`L900H06Ph@00`10P0<00808QHH01@82P0@
10H601<72@0601T=3`0E2@/07A4C01/?4@0C1`T07a<E0P0A1`H201L=30<04PP700L04@L600l5100@
1PD04PP701<9200A1`P040H700803`D600T040H70147200C2@X07aDF01882@0;0`<08ALH00d3100A
1`P00`0@1PL80147200701D93@0@10P0200000/10`0a9BT0TXJ:01T=4@0201862P0N0104200B1PX0
5`/?01H;3`0C20`01`0001H;3`0A1PX05@X>00h41`1<@DD0Vi2D01lD600<0@D0308502HK7`2SV9`0
6PlC00L0000<0@D06A0B01@93@0B1`/0JEiR05E:CP0=0PH0714E01462P0?10P04@H:0P0C20`0500P
5AT05@X>00/0100A1PX06PlC01/@500<0`D04PL;00d21P0B1`/03P<701D:3P0;0P@02@0200L0000F
2`l0304501L<400>0`L03`@80P0A1PX01`0@1@T03`@801<8300700003P<700P00@0>0`L00`0@1@T2
01462P804PL;0P0A1PX301052@0700l4200A1PX04@H:01462P0@1@T03`@800h31`0201052@0:0146
2P0@1@T03`@800h31`0>0`T04PL=00h32@0M4QP060dC00/01P804@H<00X040D;00l42P0?10X03P<9
01873@0=10P06@hD00d2200>0`T02@040`0A1P`301873ACooooo000Kooooo`0800`61`0C3@d02P@4
01TC4`0/9b@03`X7014<2@0@2`T3010:2P09010:2`0B1`/06PlC01872`0C20`03`D701@:2`0B20T0
4PP800804@L600H050X801L=2`0P5QL03`H701061`0E2``401<92P8050X;00h04`T:00`3100@1PD0
60h=01T?3P0D2PX050X901D;2P0@1PH03P@401<9200D2PT04@L601881`804PP900@050X;01L=3P0L
4Q<040H70`0A1`P201<92P0501@92P0E2@/05@T;01D92`0F2P`00P0E2@/0200?0`D0710B01lC5@0E
2@/060`>01<82@0@1PL05`d>0P0C2@X0500K4A804`T:03P^;`0h;Rl05Pd>01D;300C2@X05`d>01D<
3@0J4140;bDV01492@0H3Pl06@l@03/a<P0/8R<04PP901T?400A1`P05`d?0P0E30l201H=400301L>
4@0D2`h050/>008050/>0P0E30l06`0I3Q806a0D01`A5@0G310050X>01D<3`0>20T0@S`n075[K@0R
7Ql04`l@01@@4@0F4Q<05A4B01HB4`0K5aP071PI01PD5@0J5QL04Ph?024M7P0P71d05a<D01XF5`0H
5QT04@lB01/I700201PF6@0h01HD5`0G5AP05aDH01XH6`0I5aX05aDH01`K7@0D51H05aPJ01<D5P0M
7R8061TM01XK7`0I6Ql07b0U01`M8P0M7BD0820X01LI800G6Ql082DY02<X;01MI6X08RT_01dT:P0M
9Rd06b@[01dV;@0P:S<08bdf024[=00U;CP09Rhi028Z=@0Q:cD08bdg028/=P0U<S/08Rlh02Ld?@0^
?4D0:cU202Dc>`0S<SP0:CPo02Le?@0b@4/0<d5>02@b?`0^?4T0<d5<03=1B`0^?D@0>4M=0310A00^
@D8202i2@`0W03A7B`0[?T@0;d9902m2B@0cATd0>DaB03]>E00dAd`0;T5803M8E`0cA5@0<D9B0393
D`0eAeD0=dUG03]=FP0lCUX0A5IR04aNJ@0kCEL0=4M>03A7C@0fBDl0=DQ>03M:D00iC580=4M=03=6
C00dAdd0=dY@03I9C`0dAdd0<dE803M9B@0fB4P0=dU903=5A@0kCDd0<TA400<0=DM700H0<D=30312
@P0`@TD0;d1703E6C@0b@dX203U:D@0402dnA@0lCE@0=DI=02`mA080<T=:00X0;Ca10350A@0d@dP0
<D1502ln@`0b@DH0;Ca102hm@P0`?d@0<D150P0`?d@02@0`?D<0<Sm5030m@`0`?D<0<Sm502ll@P0[
>3h0;CY002hk@@0202/h?P0g030m@`0]>ch0;S`o02hl?`0^>d40;CY002/h?P0_?4@0;CY202/h@@0/
>D80;CY302`i@P0]>dH0:3I102Tg@P0Y=D40:3A002`hA00Z=400;cU502/e@@0Z<Sl0;3A102L_?00^
>4@0=Cm:03<mB00[<ch09Bdg02D^=`0Y<3T09bhg02H]=00S:2l0;30g020W;P0P:C408B/d024Z<`0I
8R/07BD_01TP:P0P92l07B4/020T;`0J72P092Hb02<U<@0[:cL07al[01dM:@0i>DD06ATU028R;P02
024Q;@0G02<S;`0T93008R8^020P:@0/<3809RX]01/O8P0N8RD09BH[01lP9@0L72@07A/V01XH8`0O
72L08QlZ01lM:00N7BX09BDa028R;P0[:cL0ATIB02DU<@0O7b/01@0P82`09P0Q7b`08b4^02@R;`0R
82d07adZ01dK:00H5R<06ALT01lM:P0M6bP06aTV01dK9`0F4ah0:2D`02LT;`0I5R408AhY01XG8P0D
4A`06aPS01lL9`0F4ah06aPS01`J9@0F51l06aTT01HD7`0H5R007QdU01XI8@0920h08R4W018A5`0O
7R<05A@I02`Z<00K61l04@hE0P0F4aX01`0D4AP05A8I01/H7`0I5Qd05Q<J01/H7`0F4aX00P0L5ah0
3`0O6R408QdT020K8P0J5A`050lF01lJ8@0F4AP05A0G01PC6P0F4AP0614H01TB6@0H4AP05a0G01TB
6@0301H?5P0;01L@5`0F3aH05@hE01<<4`0[92`0?SLo03Xc>`1:@d/05a0H01@=5@0H4AT00P0F3aL2
01L@608050dE00d0?3Hm059;DP0>20h05a0F01@>4P0E3a<04`d@014;3@0F418071HH01D?4@0O6A/0
50h@00804`d?00P04@/=01H@4P0B30h04@/=01PB500>20X0CdU;03Pb=0805``@0P0F2`l201D:3P0>
01T>4P0L4AD05@X>01D:3P0I3Q8050/>020I6`0V828030H801H@4P0<1PP04@/=01<=3`0?2@/301PB
500401D?4@0B2a80?3Dl014:4@805@hE00l04P/B014:4@0@2A0040T@018;4P0C31<050dD00h:400?
2Q403PT@010;4P0D3aH05a8I010;4P0A31<0100B3A@04P0B3aP06AHQ01HC7P0B3aX04a4N01/I9P0G
5b<0:bXh01hN;00T9S<0828_01lU<P0M9c<08B/g02D_>`0S;SX0:cI2038oB`80;3Y502L0<D1;02m0
BP0]?TP0;3e802XjA`0dADl0:SU402dkAP0U<S`0EV1Z02Ta?00R:C<09R`f02@X<`0O8bh08B@]01PK
8P0N7RH07AhT01XK800I61h07ahS01TH7@0G5AP061HI01HD5`0H4aL05Q4G01PC6@0N6B006aHM059=
D`0H4AP07Q@L01T?5P0D2a00714E01872`0F3@h00P0F2`l02`0C20`07Q<G01P=4@0?10P04PL;01`A
5@0D2@d03`@801dB5P0L4AD05`/=00<04`L900P040@601/?4@0F2P`05@T;03@X:P0f:R`05``=0186
20H04`L900P04PH801H:300B1PP03`<501451`0B1PP05@/<0147208050X;00D03`D601<92P0B20T0
4PP90147200301061`0?01882@0@1PL03`D60147200G3@h0718C00l51P0C2P/05@/<01lE5P0C2PX0
40H70147200@1PL03`D6008040H700<04@L801882@0@1PL00P0@1PL09P0A1`P04PP901452@0@1@P0
4PH:01462@0@1@P050P<01<72`0?0`L04@D90104200?0`L04`L;00h41`0c:2`0RWn301hC5`080040
4PL;01462P0@1@T07aDH01472P0A1PX040D900h51`0]8RH03`D801892`0@1`T040H901H;3`0>1@L0
5@/>01P=4@0?1PP04@H:0P0?10P04P0B1`/04`P<01872`0>10L03@@601462P0@1PT05P/?01/@500F
2`l0<BHZ01D:3P0B1`/02P0300l4200D2@d050X=00d21P8040D900<05``@01052@0A1PX00P0D2@d0
200C20`040D900T00P0F2`l04PL;01<8300>0`L04PL;0P0@1@T201462P804PL;0P0?10P201052@03
01462P0B1`/04@H:00804@H:00<040D901462P0A1PX0100B1`/0200A1PX040D901<83P0J3aD04@H<
01D:400F2a4050T?0P0@1@/400l42P804@L<00D04@H<01873@0@1P/04PL=00l42P0201052`030146
300B1`d04PL=01Cooooo000Kooooo`0Z01`G500C3P`02@<302LQ8@25Ogl050h>01/E5@0N61P02P@4
03<];@0E41003@L701@93@0B1`/07Q<G01@93@0D2P`02P0101D;300A1`L03`D401471P0A1`D040H4
00h41@0@1PL03P@50147200C2@X04@L801H<3@0700006a4B00l61`0K4A804PP901471P0D2PT04`T8
01@:2@0B20L03`D40P0B20L201<9200@01881`0A1`H04`T:01dC500:00405@/<01/A4P0=0`@050X;
01H<3@0K4A804@L801/A4P0C20X05@T;01<72@<04PH80P0C1`T01`0E2@/05PX<01D92`0C1`T04@H7
00l51P0B20T00P0G3@h201882@0;01P>3`0C2@X05@/<01L=3P0A1`P06@l@01X@4@0B20T07A<D01/A
4P0L4Q<00`0E2``01@0D2P/04`T:01882@0C2@/04P`>00<050h@00X04`d?01`F600600805@lA01@>
400I4aD0610C01X?4`0I3Q805Pd@0P0D2`h03@0E3A004@/=01lI6`0W8b@040`=01HB4`0I5AH04Ph?
01TE5P0B3Pl04`l@01HB4`0C3a000`0F4Q<02`0D41405Q8C01`H6@0C4A@06ALJ01@B5@0F51L09bDX
02<Q900J61/06ALJ00805Q@G01/061HI01PH6P0J6QX071hN024R900P8B<07AhQ01hO8`0B4aL071dR
024R9`0R8bP05AHK01hQ9P0L7b@07R<W01dR9P0N9B/08RT_01dT:P0N9bh07BH]028[<P0Q:c@06bD^
01TS;00V<3T00P0R;3D01`0U;cP09C0i024^=P0S<3P093<j02He?00W=Sd00P0T=C`0:00W=S/0;3]2
02Th?`0T<S/0;3Y5020^>@0^?4L0=D=>08FCW011D5L0<D150394AP0Y?3/0<TI703A8B@0/?d@0@eEO
059TKP0iBeD0?4iH0394CP0fBDl0=DQ>02Pk@P0dAUD0>T]K03]<G00iBUX0>4YH03Y<FP0iBeT0<TA@
03e?F`0a@dl0<dE?03M:D@0jCE<0>diD03Q;D@0bAD/20313B@0N03]>E00eB4h0;d98051SJ@1aQ8X0
?U1C03M9B@0bA4@0=4I603E7A`0a@d<0<TA403=5A@0`@T80<TA403E7A`0dATH0=DM:03M9C@0[?D40
;Cm303e?D`0eAd/0;T1402`n@P0[?D40;d550394B00cADT0<T560P0a@4D09P0eA4T0=4=802dl@@0Z
>Ch0;ci302hm@P0/>d00;ci302/j?`0^>d40<Ci4055NI011CU@0=45702`i?`0`?D<09c@j02Hc>@0a
?T@0@TmE03M4BP0d@TD0;ce002`j?@0[>3h09c@j02Xg?@0[>400;S]302hkA00[>440;3U202hkA00_
?DP0;3]602Tg@P0W=D00:3E10P0Z=T80>@0h@dl0EEm[04UCG`0V<3`0;CM302`eA00`>DL092hj02@/
=`0Z<S`07RL`028Y<@0V;C@092`_02<X;00R9bX082DY01dT;00Q:3007B@/01PO9`0J82P08RH_01dQ
:P0O8R/06ahW01dP:@0V:C809bXc028R;P0W9c<0:BTe02@T<00N7RX071`X02DU<@0Y:CD092@`01`L
:00Q8Bd0:2Pb01hR9P0R9bX06AhQ02T/<@0U:2d07b8W01/K8`0N7RH071`T01/J8P0N7BD08R0[020P
;00O7b/07QhZ01dM:@0201`L:00E01lO:`0P82`0820/01hN:P0K6bL06QXV02@R;`0E4b009R@a01dK
:00V93405A<P01`J9`0=2aP05A<P02DS<00I5b@07a`X01dJ9@0L6B@06aPS00<06QLR00h030TD02<P
:`0Y9S406QLR01@A700N72L07adX01dL900J6B405A@L01<B6P0H5ad06APN01PG70806QTN00@06APM
01LE6`0F4aX05a@K0P0H5A`201LD6`D05Q<J00H05a8I01TD6`0J5A`06A@K01LB6@0E41L601LB6@07
01PC6@0G4QP05Q4G01@?5@0C3Q@04PdC01@?5@02018=4`804`hD01D05a8H01L@5`0E3QD050dD01L@
5`0I4QT05PlF00`5300?20l050dD01H?5P0H4AP06A8I01094@0j<c/0D4U@01dF7@0E3a@08A/O014;
3`0B30l00P0C3@l0200B30h04@/=01XD5P0I4aD0618D01H@4P0C3@l04@/=0P0C3@l0100A2`d03`T;
01LA4`0@2P`401P=4@0@01D:3P0?10P06PlC01P=4@0E2Ph050T=01D:3P0D2`h04@T<01H@4P0A2`d0
5Q0B01LA4`0>20X05@lA01H@4P804@/=00T05@lA01<=3`0H4AP0=Bhe01<<4`0B2a804``C0109400F
3aH00`0C31<08@0A2Q403`P?014<4`0?2Q4050lF01<>5@0A31<05Q4H010;4P0B3A@050lF01D@5`0D
3aH04`hE01<=5`0A2aD04`lH01DB6`0D4A`04Q0L02LU<P1@D5`0G5]X02HU<`0K6RP09BTg01@L:@0L
9340;3A1028/>00V<3`0:C<o02/g@`02030lB00b02`jA@0]>dH0=49=030nB@0[>D@0:cQ202Ld?@0[
=Cl0;3Ho02</=@0Q:3808BL`024U;P0O8R/07B0X01/N9@0W9bl07AdT014B5`0K6R006aXO01dL8@0M
6ah05Q@G01DC5P0K5QX050lE01D@5`0E41H040/A010;3`0H4QH060lD01L>4@0D2`h04`P<01@93@0G
31004@H:01<8300N4aL06PlC01D:3P0j;c<05``@01<8300A1PX060dA01lD600T6Ad301@82P0d01<7
2@0B1PP04PH801<72@0G2`d060`>01D92`0B1PP040@600l31@0C1`T040@600d10`0>0P@04`L901@8
2P0T61X06Ph@02XN800@1PL03P8400h41@0H3a006a8C00/20`0A20T04PT:00h51P0A20T04PT:0107
200?1PL040L801<92P0@1PL0308301T?401WGEh0/jVZ01dC500>10D04`T:01D;300A1`P05P`=01<9
2P0<0P<04PP902TO800U6a`04`T:014720D040H700H05@T=01862P0@10P040@801862P0C1`/60145
2@0H00`31@0T6Ad0ACXn01`A5@0:00<04`P<00d41P0D2@d04`P<00l4200800404`P<00h31`0@1@T0
3@8601872`0E2Ph02@0201052@0E2Ph02`8400h31`0L4AD06@hB0P0?10P0100@1@T06a0D01P=4@0@
1@T201462P0E01052@0A1PX04@H:020E6@1[H6@05P/?01@93@0;00@05``@00`31@0F2`l0714E00h5
1`0=0PH04PL;00`21@0=0PH04@H:01T>4P0700003`@800<04@H:0`0?10P05@0>1@P04PT<01893007
00404@P;00l72@0>1@P07A@G01H=401HCe802P4401@;3P0C20`03`@801052@0A1PX040D901@93@0F
2`l050T=01<8300201@93@0801462P0C20h04`P>01873@0>0`T04@H<01D:400<0@L201@93`0?00`1
1`0D2@l02P0501<83P0O5QX06PlE01873@0?10X05P/A00h32@0B1`d040D;01@93`0E2Q0050T?01Co
oooo000Kooooo`0/00/60`0=1`L040X:00@0000U7al0208207egN@1KEED05@l?014;2`0@2`X030L4
00l51P0>1@L091TM08UnPP18?D005P`=01061`0C2@T050X901<9200C2@L050X801D;300F30d04`T:
01@:2`0E2``04PP901H<3@0A1`P050X;00l71`0k<C801`0001@:2@0?1@@0308100h40`0C2@P05@/:
01<9200D2PT201D;2P0?01<9200B20L060h?01X@4@0H3Pl04PP900d3100A1`P050X;01<92P0D2P/0
40H701`B4`0C20T050P:00804`L90`0B1PP03P0A1@L04`L901<72@0C1`T04@D701<82P0D2P/04`T:
0147200B20T050X;01<92P0?1@H04`T:0P0H3Pl01`0E2``04`T:01061`0G3@h04`T:00X00@0H3Pl0
0`0C2@X01@0E2``05P`=01H<3@0E30h04P`>00804`d?00/050h@01D?4@0A2`d07aTK01@>400I4aD0
2P@601XD5P0I41<06@hB01H=400201D<3`0601@>400C3@l040X<01@@4@0@30d07a/L0P0B3Pl01P06
0P<0510A01PD5@0F4Q<07a/L01HB4`805a<D00D05A4B01HB4`0J5QL04a4D01TG6P0201DC5P0401dK
7P0E4aH05aDH01LE60805A<F01/05aDH01LG6@0F61L06Q`L01dN800L7Al06Q/N01XK7`0P8BD07b0T
01/L8@0O82D05QLL01/N8`0I7R80724U01/P900L8bT082L]01/R:00N9bh072D/01dV;@0K9Bh08bdf
03<mAP0V<3T00P0R;3D0<00U;cP09C0i028_=`0R<3P093<j02Lf?@0Y>3l09cPo02Li?@0Y>3`0:cXo
02Xi@00W=Ch0<Cm:02Hd?`0/>TD08Blh05UWL00[>T00;3/n02Xl?00[?ch0;D520313A`0[?TD0@59N
04UKJ@0dAU@0<dEC03I8E00gBE80<dI=0353C@0iBeX0>daL03Y;F`0hBUT0>TaJ03e?G@0lCU/0<TA@
03M9E@0a@dd0=dUC03I9D00gBU00>DaB03Q;D@80=DQ>0P0fBDl03P0[?T@0;d9803mBF01EJ6h0>Ta?
03U;B`0fB4P0=4I60394A00_@D40<TA403=5A@0`@T80<TA40P0dATH02P0dATP0:C/o03e?D`11DeL0
:ce103E7B`0cADT0;Cm302`n@P0_@DD20394B080<3m401L0<D1503=2A`0c@TL0<3m402Xi?P0^?D80
<d9702`k@00Y>3d0=4=802ll@P0`?D<0@DiD038oA@0^>d40:cPn02Ld>P0c@4H0;ca2038oA@1FHfT0
B5EK030n@@0202dk?P0602dj@00Y=S`0:SLm02Xg?`0]>T80;S]40`0/>D80?@0V=3l09SE002Le@00W
=D00:cQ302hjAP0_>dL0;SU503]5D@0g@Dd09c4m02dg@`0_>DD0;CM302hh@P0^=T40:C8k02D^=@0S
:S809B`a028Z;@0R9bX08BHY024V:P0R:Bl08bXb020W;`0L8b/07B8[020T;@0R9Rl0:bhg02<V;`0J
7BH07B0Y02<V;`0O7b/08b<_02HV<P0T93008B4]020P;00N7RX08B4]02<S;`0T93008b<_024T;@0I
7R40;S<f01/P8`0M82D0=3Ll04U<D@0L72@07alW01hN9P0K6R8071/S01lN9P0P82/00P0P82`301lO
:`<08B4]0180820/01hN:P0M7BT09R@a01PF8`0F52407adZ02@R;`0H5R<05aDR01PF8`0S8Bh07Q`Y
01DC800H5R806QLR01TF8@0H5B0201LD7`0C02DR;@0O72L06AHQ018?6P0R7bX05Q<N01TG8P0N72L0
9RD]01DD700J6B406QTO01TH7P0H5ad05aHK01PG700I61d061LL01PF700301PE700301HC6P0E4QT0
5Q<J00805a@K00T05Q<J01DB6@0E4QT071LN01LB6@0C3QD05a8I01XE700K5Qd01P0G4QT02@0D3aD0
5A0F01TD6P0M61h081/Q02<N900G4QP05A0F01<>5002018=4`0601D@5P0I4QT05a0G01H?5P0H4AP0
5a0G0P0D3A@201D>5@0;018;4P0?20l03PL>01dF7P0E3QD07aPO01PA600L5A/030H:018<400C3A00
0`0C3@l07P0B30h05Q0B01H@4P0F41805@lA01@>400B30h04@/=018<3P0V82802@<5018<3P0J51H0
60dA01D:3P0D2@d05@X>01H;3`0D2@d05``@01H;3`0D2@d05@X>01L<400G3Q406A8D028L7P0I4aD0
4`d?01@>408040X<00`03`T;00d72@0?2@/04@/=010:300C31<04P/B01@=500M5Qd03`P?01PA600F
3aH301<<4`0:014:4@0@2A0050lF00l:4@0C3QD04@`C00d83`0?2Q406A@K01D@5`804PdD01<05A0G
01HA600C3AL04@/E01<?600E4Q/0514L01DB7P0G5B809B<`03Hf@`0U938071/Y01dQ;`0P:3D07RHc
02L_?00/=440:S8o0080;3I201`0;cU502diA@0[=d<0;3Q402lmB00Z>4<09S@o02Le?`0T<CX0:38l
02La>P0Q:S<08BPb028W<@0P92d07R4Z01lR:P0M82L0820X01`L8`0H6Ah06aXP01PG700J6Ah07A/N
01/I700J61/071LK0P0E41L05P0E41H04PdA01<>4P0G4A@06A0C01P?4P0E30l05@X>01H;3`0H3A40
7a@H01T>4P0B1`/04@H:01H;3`0W72005P/?01<8300A1PX05P/?01/@500N4aL301@82P804`L900H0
4PH801<72@0G2`d05`/=01D92`0B1PP201451`0B00d20`0K3a40710B01041P0C1`T03`<501L;3@0@
10H07A4C00h3100:00406@l@00X20`0600002`8301892P0>1@H04@P90P0D2``201892P0901@;300C
2@X040H700h41@0N51D0IUaM0:bRX`0O5AH040H700804PP901@03@<40147200@1PL03@<400h41@0H
3Pl05@/<00X00@0A1`P04PP901<92P0B20T040H700h41@0E2@d04PH:0104200A1@T04PH:01<72`H0
4@D900L04PL;01T>4P0S61`050T=01052@0D2@d06@hB00801`000`0E2Ph0200K41@0;24U01hC5`0<
0@D05@X>01T>4P0C20`040D90P0C20`01`0=0PH03`D801052@0?10P050T=00l4200=0PH00`0A1PX0
200@1@T04@H:01462P0=10H0<RL[00L0000C20`02P030P0D2@d02`0J3a<01`0001072@0M4QH02001
01@93@0?10P040D901L<400900804`P<00804@H:01D04PL;01462P0@1@T03`@801@;3P0?1PT040L:
00H0000D2`h05Pd@01/B5@060000ASe00;6XZ`0d:bh030<601<8300?10P040D901462P0@1@T00P0C
20`07@0A1PX040D901462P0B1`/040D900d2200>0`T04PL=01<83P0@1@/0304701/@5P0=10P07A8H
01lD6P0A1P`05``B06QMH`1TFEl03@8800h32@0>1@T081DK01T>5018?D<04PL=00h32@0B1`d040D;
01Cooooo000Kooooo`0J01PC3`0A30T050h=01<=3P0B30h03`T<00l93@0I51H05Q0@00T4100D40d0
30L400`3100h;C406@hB04Xo@`0R61X04`T:00l51P0B20P04PP701061@0?1@<040H401T?400H3Pl2
01@:2`0801<92P0?1@H04@L800d51@0F30d060h?04@j>`0C2P/201<9200301D;2P0D2PT04`T80080
4`T801405@/:01L=300F30/04`T801881`0F30d03PD501H<3@0Z8240:AlP01H<3@0E2``09A/L01lE
5P0@1PL050X;01882@0201@82P804`L91`0D20X04P0B1`T04`T:01D;300G3@h05P`=01@:2`0K4A80
5@/<01T?400D2`/050X;01hD5@0F30d04PP9020F5`0C2@X03`D601T?40H05P`=00@05@`>01<=3`0D
3Q0050h@0P0E3a401`0N61X02@@501dG6@0C3@l04@/=01<=3`0H3a800P0G3Q4201@>400@01D?4@0E
4A807ATJ028N7`0>30d09B<T01@B4`0I5AH04`l@01XF5`0H51D06ADF01LC500F4Q<061@E01XF5`80
61@E00<06ADF01<A500G5aT00P0G5aT0100H61X03Ph@01LG6@0G5aT201PH6P0;01XJ700K6ad06A/J
01`P7`0K7ah06AdL01TM7@0G6a`05a/N01hR9@0K7b800P0O8RL0400^<CH0724U01lT:00N8bL07bH/
02<Z<00N9B/07bP_028[<P0U;SD08R`e02Tc?00mAe0092hg02<]=P0T;SL302@a>@0302He?00V=Sd0
9SLn00809cPo03409cTm02Th?00X=c`0:cY002`j@`0e@dh0;3Y503A2C00V=3d0=D=;02Th?P0d@dH0
:3Xj02]0?P0Z?d40;dA90314CP13EVH0BUa^03Q;GP0cAUL0?E1P03U<FP0aADl0=d]E03e@GP0kCU`0
>DeI03Q;F@0jCEX0?51J05=WL012EUl0=DUA0396C@0gBe80<dM=03U<DP0kCU@0>TeC03M:D00fBDl0
=DQ>03Q;D@0bAD/0=TU?02i1A`0hBe40?4mB0080>D];00L0<dE502m1@@0a@d<0=4I603=5A@0bA4@0
<dE50080=4I60140=4I703=5B@0cADT0;Cm302i0A00cADT0<D=702m1A@0^@4@0<4960394B00a@dL0
<3m40350A@0b@DH0;ci3030oA00203E4B@0G02ln@`0Y>3d0<D1503E4B@0`?d@0<Sm503M4BP0_?480
934g02dj@00^>d40=45702@a=`0/>Cl0;ca202`i?`0_?480;C/n02/i?00/>Sd0;CY002Xg?@0/>Cl0
0P0]>T80;00^>d@0;CY302/h@@0]>d@0;Ca802dmBP0[>dP0:3Q502ThA@0]>dP0<Si<02/gA@0Y=D<0
;SM602lhA`0Z=400;SQ302La>`0^>480;cQ202@]=P0U;SD08RT`02@/<00U;C009BX]020U:00P9BT0
9R/a02<W<00R9Rl092Pa02<W<00N8R/0;2lh01hQ:P0K7RL0:Rdf02lb>`0L7bP07AdW01hN:00O7bT0
8R8/0P0S8bd0500`<3X08R8/01hN:00S8bd08R8/01dP:00T:Rh0@4E902hc=`0K82@06A`Q02@W;00P
8bP09bP]02HW;00R8bP08B0V02<R:P0N7RT07al[0P0P82`2024Q;@03028R;P0P82`07QhZ00807AdY
00h07QhZ01lO:`0Q8Bd07al[028R;P0Q8Bd0GUiZ01lO:`0A4Ad0820/01`L:00T93006aTU01dJ9@@0
71TT01005a@O01TF8@0Q7RT071TT01PE800R7bX0FeUS01`K8`0O7RH07A`S024P9P0F5A/06APN01XI
7P0K6Ql06QXM0P0J6Q`04@0K6Al06aPO01XG7P0H5A`05A8I01<@5`0F4aX06QLN01TF7@0F4aX05A8I
01@A600R7B@07APO01PC6P0K5Qd071LN00L05a8I0P0G5AX02P0F51T05A<H01DC600D4QL06ALL01PF
6`0C4AH040hC01<A5P0F4aT401PB5P0301H@500B31005@lC00805@lC00/05Q0D01PB5P0H4AL04``D
01@=500A2Q404``C018<4@0F41@050hB01D?4P0201H@4P0301D?4@0D3Q004`d?00@050h@00<04`d?
01D?4@0F41800P0C3@l01P0H4Q@03@L901X?4`0F2`l05@X>01L<40806PlC00l04`P<01@93@0E2Ph0
5P/?01T>4P0J4A@06A8D02DO8@0L5QP03`T;018<3P0E3a404P`>00l92`0B30h00P0C3@l0200E3a40
4P/B01lH7`0@2A004@XA01<<4`0@2A005@hE0P0C31<02P0D3A@04P/B0109400G4QT040/B018=500C
3QD03PT@00d83`0C3QD2014<4`0E018=500C3QD04`hE01<>5@0A31<050lG01LA6`0D4AX05A8L01HD
7`0D4Ql06QPU01lM:P0K6bL05aTV02DZ=P0M8bl08BLc02T`>`0L8bl09blj0080:34l00D0:38l02Pd
?@0X=3d0:3Dn02@b>`0202<`>@07020/=@0R;3D08RXc020W<@0T:3408RH_020S;002020S:P0S01hQ
:00G5al071`S020Q9P0G5Q`06aXO01TH7@0I5aX06QPK01PF6@0D3a@061<J01D@5`0E41H061<G01PD
5@0F4A006Q4A01T@400G3Pl05P/?01L<400I3Q803`@801X?4`0G3A005``@02XO8`0o=3P05@X>01@9
3@0C20`05@X>01H;3`0E2Ph00P0E2@/201@82P<04`L900T05PX<01L;3@0E2@/04PH801<72@0G2`d0
40@602DI6`0Y7Al00P0G2`d06P0C1`T04PH801@82P0B1PP05@T;01@:2`0A1`/03`L901T@4`0N5AP0
40L:00d41`0?1PT040L:00l62@0=10L03PD801482`0=0`@04`T:01061`0A1`P06@l@02TO800H3Pl0
3P@50P0A1`P01P0>10D04@L801882@0D2P/04@L801061`804PP900P04@L801<92P0D2P/04`T:00l5
1P0>10D05@T=01862P804@D900<04PH:01<72`0B1PX01@0B1PX0600D2@d04@H:00L0000F2`l04`P<
01462P0>10L05P/?01872`0A1PX0<2HY03`b=@0I3Q809Q/O02LL800=0PH03P@701H;3`0B2@/040L9
01872`0=10H03@<601<8308040D900@0308501462P0C20`04PL;0P0A1PX04@0@1@T04@H:01462P0B
20/03`@801072@0A1`X02@0201462P0B1`/03@@6038W:`0m<cH040D901472P0B20/040D900804@H:
00@04PL;01<8300@1@T04@H:0P0E2Ph05@0C20`040D901D<3`0=10L050/>00P00P0P5aX06A0C04e4
A`0G3Q4040L:020G6P0<10H04@T;01<8300?10P04@H:01872`0@1@T04`P<01872`0201462P0H0187
2`0D2@d04`P<01873@0A1P`03P<900d2200C20h060hC01D:400_92X060dC00l42P0F2a4050X?01X?
5@0K4QH081DK00T0100H3A<02P4500l42P0e:S001`020P0B1`d00`0G31;oooooooooo`0Booooo`00
6oooool09P0910005a8?00T40@0>20X03`T<00l93@0A2`l040/=00`61P0@2PX050l;02XU8@0B20T0
>2da01X?4`0800406@lA00`20`0H3Pl04PP801061@0D2PT05@/901<91`0D2P/05@/<0147200B20T0
4`T:00l51P0P5QL04PP901X@4@0H3Pl03@<401D;300E2`X030810P0=0`802`0A1`H060h=01471P0C
2@P05@/:01@:2@0A1`H040H501<92P0;0@802P0100808ALH00L01`0001`B4`0C2@X04@L801X@4@0F
30d04`P:008050P:00@04`L901@82P0E2@/05PX<1@0E2@/0200E2P`050X;01T?400X7Ql0:R0Q01dC
500I3a002`420P0A1`P02P0J4140;bDV01lE5P0@1PL03@<401H<3@0c:BX05P`=01D;300H3Pl201L=
3P805@/<00`04@X;014=3P0F4Q<05a<D01DA4P0A3@h0100102DQ8P0?2``02@D601HB4`0K5QL201L>
4@0K01D?4@0F41805Q0B01@@4@0L61T08AdN01TG600M6a`0C4Y;01`J6`0B3Pl0>SHg01TE5P0L61T0
=c<d01`H6@0G4a@06ADF01/G600J5QL06ADF01TF5`0F51L05aLI01HF600H61X06a/M00805aLI02@0
6ATK01XJ700K6ad07AdO01`M7`0L7Qd082@R01/O7P0I7A`0720P01TM7P0G6a`06QhP01TM800T:2/0
720S01@H6`0M8RH082DY01lT:00P9bd092/a01lV;00K92/07BH]02</<`0S;CH07bTb020Z<`0O;380
8Rle02@a=`0U<SP09C<h02@c>00U=3T202@f>P0/02Dg>`0U>3`09SPl02Th>`0T<cP0:STn02dl@`0b
@4T09cDn02lmAP0e@d`0:SU002`k@00`?d809CLg02Xo?P0`ADP0=DU@0395DP15Ef/0CEmg03a=I`0l
CVH0>deS03]=H00gBUT0<TEC03Y>FP0jCUT0>TiG03U=E`0eBE80=4Q?049FG@0jCUD0<TM<03I;D00l
DEH0=TY?03Y=D`0lCeD0>TeC03I9C`0eB4h203I9C`050313B@0cAT`0@EAJ03E8CP0dAdX00P0jC4`0
1@0bA4@0;3hn0312@P0dATH0<dE50080=4I60P0cADD01`0Z?3d0>D]=03Y<CP0]?d40;T1202m1@`0e
AdT00P0_@D<01P0a@dD0<TA602m1@`0d@dP0=DA90391AP80;3]003D0<T5602Lf>`17EU/0BEQM02Lf
>`0Z>Ch0<d9702dj@00kB4h0;CY002`i?`0b?dD0;S]102/h?P0^>d40<3e302Hc>@0a?T@0<Sm502hl
?`0Z>3/0:CLj02Xg?@0Y=S`0;S]103E2BP0_?4@0;CY302/h@@0Y=Sl0<d1902/kB00]?T/0:c]802Lg
A00Y>4D0<Cm<02/iAP0^>dT0:CE302Pd@P0Z=T@08Rhj02Pb>`0X<cX07RT_01lX;`0S;3<072D/02D/
<P0W;S@0;cLj02hc=`0202<X;00902DX;`0P8RT08B@[02P[<P0[;SD09RT`028U;00V:C007b8Y0080
6b0V01H061/R020P:00L72@071`T020P:00Q8BT0820X03Lg?`0W9bl07QhV01/K8`0O7bL082<Z01/Q
9`0L8bT05QdS028W;@0M8RP07b@Z01LJ7`0N8BH07b8W0P0N7b@02@0P82P07QhY01lO:`0P82`08R8^
02<S;`0T9300820/01dM:@0201/K9`8071`X00L07QhZ01/K9`0K6bL0820/03PhA02CTil0<S8n0080
5QHR00@04A4M028R;P0G5R406aPS0`0J5b802@0K62<08b0[01dJ9@0D4A`07Q/V028O:P0W92l0J6I`
024P:00201/J800901dL8P0K6Ql06QTN01XI7P0K6ad06ATK01PH6P0I6A/06APL00<061DL00h05a@K
01HC6P0H5A`06QLN01TF7@0F4aX05A8I01@A600N6B007aXQ01dH7`0I51/06QDL020K8PH05a8I00@0
4a4F01@B5`0D4QL05A<H0P0F51T06P0G5AX06ALL01DC600B41D06ALL01XH7@0D3Q805@lC01PB5P0G
4AD05Q0D01D?4`0F41@050hB018<400D3Q804`dA010:3P0F3aL050dE0109400I4QT04P`A00`62P0E
3a<05Q0C0`0F41803@0E3a405Q0B01H@4P0F41805@lA01<=3`0B30h040X<01D?4@040000<bd_00`6
200Q6ad00`0H3A401P0J3a<060dA01@93@0D2@d05@X>01H;3`805``@00T05Pd@01<<3P0G4A<050h@
014;3@0C3@l050h@010:300B30h0100A2`d01@0B2a801004018;4P0J4aX05@hE008050dD0P0B2a80
100D3A@04``C014:4@0A31<200l:4@8050lF01T04@`C01@?5P0A31<040/B018=500F4AP061<J01@=
5@0B2a<05@lF01LB6@0F41X050lJ020M:00R82/06aTU01/I9P0J62D071dZ01`P;00T:3@0=SY602L]
>@0M8bl08RPd00808RXe00<092`g02@^>00V<3X00P0V<c`04`0T<CX08Rdf020Z<`0O:34082P`024X
<00Q9Bh07b<[020S:P0U9Bd08B8Z02<V;@0Q8BT09RL]02DV:`0K6R009B@Y020O900I5aX00P0H5QT0
2P0G4QL061<J01D@5`0E41D06A@H01TE5P0F40l05`l=01H>2`0F3@d201H;3`0=01H;4@0>0`L081DI
01X?4`0;00@0304501D;3P0E2Ph05P/?01L<400D2@d04PL;01462P0301D92`8050P:0P0C1`T02@0F
2P`05@T;01@82P0C1`T050P:00l31@0E2@/04PH800l31@020186200O00d10`0B1PP0710B00T0000A
1@L04`T:01XA500I4aD03PP:00T31@0>20X040X<00l92`0A2`d040X<00h82P0?2@/050/>01P>3`0E
2``0308301061`0D2P/07Q@E0147200>10D03`D60147200@1PL04PP900l51P0200d3100:00l51P0A
1`P050X;01882@0@1PL03`D601061`0A1`P04PP901@830804PH:0`0A1@T601862P0I00l5200A1PX0
40D901T>4P0;00@050T=01D:3P0?10P0304501892`1bIf/0RGj201H;3`0700003P<701<8300H3A40
3`H800L0000=0PH04`P<01872`0/8BD0<RL[01@93@0201052@0301<8300B1`/04@H:00804@H:02`0
40D901462P0A1PX04`P<00L0000L4AD02@0201872`0J3a<030<501H;3`0>0`L06@hB01872`070000
50T=00h31`0B1`/03@8601X?4`0;0@@03`@801462P0D2@d05P/?01@93@0@1@T03PD8014;3@0=1`T0
208401`F600@2P`05Q0B00@0000E3a402P@601@>400G41804PL;01052@0B1`/04`P<00l420804@H:
01T040D901462P0C20`050T=01<8300@1@/04PL=0146300?10X091TO03ld>P0900@05`hB01873@08
00<01`0202<H7P0O51X060dC01D:400G31803P<901T>500H3A<0200300<04`P>00<03`@:oooooooo
ool04_ooool001_ooooo01H04@`601@?2`0C3P/05@lA00d72P0G4AD02`D901LA500>20P0618B00H1
000<1`<05`d>01482P070000714E01872P0<0P<04PP900l51@0?1@@050X90P0E2`T0400C2@X05@/<
01882@0D2P/05@/<01882@0>1PH0308300L0000E2``0200001P>3`0@1PD05`d<028H5`0M4a820106
1@D04PP700@04@L601P>3`0H3Pl07A<D0P0H3Pl01`0K4A8030@401<92P0B20T04@L801dC500Y7Ql0
0`0D20X0100E2@/05PX<01D92`0D20X301<72@0D01@82P0F2``04`T:01882@0L4Q<08QPI01`B4`0D
2P/02@000147200E2``06Q0A02<I6P0L4Q<05P`=0147200P5QL0C493020F5`0J414201@:2`0S01H<
3@0G3@h05`d>01<<3@0A3@h05Q8C01PD5@0F4Q<04Ph?04A0@@3?bl`0?3Pi02<O80070`@03`/<01@>
400G3Q405Q0B01LA4`0F41805A4B00h:2`0D41403@/<00L51P0[:BX030X;02LS9019ADH06ADF01<?
400Y9BH02`L801LC500I5AH00`0J5QL00`0L6AX06aTL01PH6P0201DE5`0501LG6@0F5QP05ADG01LG
6@0H61X00P0I6A/06`0H6QT05QXI01dR7`0G6aX05ATH01/O7`0G6a`092PY01dQ8`0U:B`0A4Q;0496
B@0V:Rd06QlS01dR9P0L8BD07B@Z024X;P0L8bT08R/b01hW;P0R:c808R`e020Z<`0S;CH07R/a02<`
=P0202Db>00W02Dc>00U=3T08c8g028d>00S=CT09CLk02Lj?P0X?3d0<D1202<b=@0Y>3d0;3]2030n
A`0V=3d0:SQ10391B00R<CP09C@h02Lg=`0Y>c/0;41003A9CP0hC5D0;d9B03e?I`14EFl0>daX03a=
I`0iBf<0?4iS03Y=GP0dAeH0>4aF03Q<E@0iCEH0>DeE03A8C`0aAD`0?51F0080=daA00@0=DY?03U>
D`0cAdd0=dY@0P0iC58203M:D00@03=6C00mD5H0Cf9X03I9C`0hBe40=TU?03Y=D00mCdl0>de=0394
A00[?Cd0;Clo0394A00cADD0=DM703A6AP80<TA400`0=DM802<e=`0dATP0DF=U03a>D00hBT`0<dE7
02i0@P0_@D<0<TA603A6B00`@T@203I5BP0G0391AP0]?440;Ca102ln@`0X=c`0AUEJ04MFF`0X=c`0
:STn02dl@@0W=3X0>DI<02dj@00b?dD0<3e302/h?P0W=3X08c0f02Tf?00T<CL0:3Dk02`i?`0^?3l0
0P0Y=cX06`0Z=cd0:3Dk02dj@00f@d/0;ca402`i@P0[>440:3Dn03=0B@0b@Tl0<dAA02loC00Z>TL0
<3m<03Y8E@0a?d`0<Ci<02XfA00W<d40:SI402/g@`0V<3T0:C@j01XU:`0K92/09Rlf01`U;002020W
;@0=02L^=00V:bl0724U01hS9`0V9Rh08R8Z02<S:`0Y;3<0;c8i02d`=`0/;cH0:Rdd028U;002020U
:`0401TN900Q8BT07AdU01`L9080820X01L07AdU028R:P0T92`08R8Z01hN9P0O7bL082<Z01XP9P0X
;cD09B`b028W;@0=4QP02a0F01HI7P0L7b@07B0U01hO900O82D08R8Z024Q;00R8Rh08b<_02DU<@02
02HV<P03024Q;@0O7b/07QhZ00<07AdY00`09bLc02<S;`0I6BD06a/W01TI9@0e=D403`lK00`<600D
52005ADQ02<S;`0M72P301`I900G01dJ9@0N6bH071TT01hK9P0P7BP09B8]03<`>`0I5R406QPR00d<
500H5ad07A`R01XI7`0V9BX06APM01LF6`0I6A/05aLI01@D5P0F5QP05aHJ01HC6P0G51/00`0H5A`0
300I5Qd06QLN01TF7@0G51/05Q<J01DB6@0G4QT06A@K01HA600B3A@06QDL02lZ<@H05a8I0P0C4AH0
200D4QL05A<H01HD6@0G5AX04a4F01PF6`0E4aP04a4F0P0J61d00`0D3Q805@lC01LA5@0201D?4`0?
01PB5P0D3Q804P`@01@>4P0J51P06A<G01@>4P0K51`04P/B00l83`0A2Q405@lD018<400D3Q805@lB
00805Q0B00<05@lA01@>400F41800P0F4180400E3a404`d?014;3@0G4A<04@/=030Z;02PVY`0;BLY
00L10`0E2Ph05P/?01L<400H3A405@X>01052@0F2`l301L<400301H;3`0D2`h05`lB00804`d?0100
50h@018<3P0A2`d05Q0B020J700E3a404@/=01D?4@0@2P`0614H01<<4`0B2a8050dD01`E700?20l0
50dD0P0B2a807`0D3A@04``C018;4P0>2A0040/B00h9400A31<04`hE014<4`0R7B@05Q4H010;4P0B
3A@071LN024L8`0D3AD04P/C01D?5P0G4QT05Q0J01HA700I5R40518M01HD800M6bP06ALT01/L:@0E
6BD082@`03LkA`0Y;CT00`0Q9c<08P0S:cH08RXe024Y=00S;CL09C0j02Db>`0S<3T07b/d020Z<`0O
:34082Pa020W;`0N8R/07R8Z024T:`0U9Bd07AhV01dP9`0R8RX08b@Z01dN8`0I61h071/P01PG700C
4A@04Q0C01@B5@0J5AX05a8I01D@5`0E41D05Q8C01LC4P0G4Ph201H>2`0701D=2`0F30d05@X>01D:
400C20`060dA01D:3P0201`A5@0501X?4`0E2Ph05``@01P=4@0D2@d00P0B1`/00`0F2P`05@T;01D9
2`0301@82P0301<72@0E2@/05@T;00804`L900D05@T;01451`0K3a403@4300P0000201D92`0I00d1
0`0D20X0710B00X0000?10D04@L800T00`0<1`P0100000L10`0W8B<01P0200d72@0@2P`04@/=010:
300?2@/040X<01T?400F30d0308300h41@0<0`@03@<401882@020147200501061`0>10D03P@50188
2@0=0`@00P0?1@H0200>10D040H701882@0?1@H03P@501061`0E2``05`d>0P0C1`/201862P804@D9
1P0C1`/0600?10P03P<701872`0@1@T02`0401X?4`0?10P02`0401@93@0B1`/07a@H02dR9P0:00<0
4@H:01hC5`0F2`l03P<701482P0E2Ph04`P<01462P0900803@8601D:3P801`0000@05@X>00T00P0:
00<05P/?0P0A1PX0500@1@T04@H:01462P0>10L02P0301X?4`0=0PH060dA01T>4P0B1`/0714E00T0
0P0?1PP0714E01462P0C20`0304501@93@0<0@D091TM0P0>0`L05P0@1@T04`P<01@93@0C20`040H:
00l62@0D3Q002@<501XD5P0A2`d03@L901lI6`0400003PP:00@0000>20X01P4201872`0@1@T04PL;
01<8300?10P201052@803P<701/040D901462P0@1@T03P<901<83P0E2Q0040D;01L<4P0V6b406@hD
0148300H3A<04PL=01T>500J3aD01`0201<83P0E2Q004`P>01P=4`0700805``B01873@0L4AL01`02
01L<4P0800<05?ooool001_ooooo02804@/5010:200?2PL040P:01@>400=1``0610F03H_<P0?2@T0
40T8014<2P0@2PP05@/<01<9300@1`T06a0D01`B4`0e:b`04PP901hE5@0P5aH050X901471@0E2`T0
50X;01D;300B20T04`T:01@:2`0A1`P05Pd=01`B4`0B20T04`T:0P0D2P/0600C2@P060h=02DK6P0O
5A@04@L601@:2@0E2`X04`T801881`0C2@P050X901H<2`0@1`H04`T:00/30`0C2PX06@l@01<92@0I
3`l04PT901H<300J4140;bDV03`a<P<050P:00@05PX<01L;3@0G2`d05PX<0`0D20X0500F2P`05@X;
01@:2`0E2``04PP901061`0B20T05P`=01L=3P0C2@X050X;01D;300C2@X05@/<01061`0P5QL04@P9
02`S900A1`P05`d>0`0D2P/0100D2``050X;01@=3P0D3a4201@?400;01D@4@0G4Q<061<E05=>D00I
51H04`h?01TD5@0F4A804`d?01@>400G4A<00P0H4Q@06`0F4Q<06ADF018>3`0I5aP03`h>014A4@0[
:BX0>SHg01PD5@0I5AH05a<D00l;300M6AX05a<D01PD5@0I5AH06ADG01`G6P0Q7Al071XM01PH6P0G
5aT061PJ01LG6@0F5QP05aLI01TI6P0201XJ6`0S01TI6P0F5aL04QHE01/P700C61D04QLE01XO7P0F
71/05Q/K01`R900F6ah07R<V01dR9P0I7R806QlS01dR9`0L8BH07B@Z024X;P0L8bT082T`02H_=P0[
=3/09S0i024[=00W<CX07BX`02<`=P0W=3X09S<i02Dc>@0V=CX0;3e102Ti?P0V>3`00P0T=SX0<`0T
=cX0AEAF02Lf>@0X=c`0:SU003A2BP0^?DD0;3]302hmA00X=cd0;Se1028a<`0`@T<0;4=50318C@0i
D5T0=T]M03a@J@0jCVX0@eId03a@J`15FG80?e=Y03A9FP0kDEh0>4iF03A9D00cBU00=TeC03E;D@0c
Bdl0>E1D0398C00hCe80;TI80357B@0dB4d0>DaB03Y=D`0hBe40=4M=03=6C00eB4h0<DA:05AWK@0l
CeD0=dY@03Q;D@0hBdh0=dU903E7A`020353@`80=4I600<0<dE503I8B00eAdL00P0bA4@0<@0cADH0
:C/m03U;C@1MKg40@E=E02do@@0_@D<0;Cm102m1@`0dATP0=TQ:0394AP0eADX0<T9702loA00a@4D0
<T56030oA00d@dP0;Se202ln@`0a@4D0:STn02Pg?00X=C/0>DI<02Xg?@0c@4H0:3Dk02dj@00^>d40
:3Dk02`i?`0W=3X0:cPn02dj@00Z=c/0:3Dj02hk?`0`?480:SLm02Pe?00`?DD0:CHn02dj@`0^>d@0
9c@l02dkA00U=D800P0Y>TH09P0Z>TL0>DUF04aLJ@0_?DX0:SQ502hkB@0`?4X0:cM602/g@`0S;CD0
7RP]024[<@0S;3<08R/b02@]=00X<3L07RH^020W;P0N92/06b0V02H[<@0R92/07QlW01dN9P0Q8R/0
:B/c02/_=P0X:c<07R4Y01PL8P0P92`09R/b01/P9P0O8BH071dR01dN8`0S92T08B8W0P0N7b@201lP
9@0B01hO900O7bH07B0V01XO9@0M8bT061hT01/Q9`0I7B<08BD/01dP9@0Q8bT0828W01lP900R8bL0
9BH[01lO:P0O7b/0820/0`0Q8Bd301lO:`0?01dM:@0K6bL06QXV01TK9`0C52006adY01XL9`0X:CD0
71dX01/M:00@4A`06a`W03<f@00W:3<07QdX00<07Q/V01D07a`W020M:00P7BP05Q<N01dJ9@0J5b80
9b@_01`I900J62807AdT01LF7@1=C5<04a<J01/J7`0I6Ah06QXO01dM800J6Qd05AHG01TH6`0J61d0
0P0G51/401PE70806AHM0`0H5A`301PC6P0301LB6@0I51/07APO00H05a8I00`05aDJ01HD6@0F51T0
518G01<A5P0B41D03`dB01LE6P0E4aP040hC01LE6P0C41D201TC5`0B01LA5@0B31004P`@01LA5@0H
4QH05a4E01/E6@0R72007QPL01D?4`0G41L06Q<J024J8@0:0`X05@hD01TC5`0D3Q805@lB0`0E3a40
100D3Q004@/=01<=3P0C3@h201@>400801<=3P0J51H040X;01D?400S7Al040X;01TC5@0H3Q4201H<
400;01T>4P0K4A@06Q0C01@93@0F2`l05`d@01P=4@0G31005@`?01@=3`0A2`d00P0B30h03`0A2`d0
4`d?01hH6P0b;2h06A<E014;3@0J51H03`T;02@L8P0X82H05PlE01<<4@0V7bD03@H<01@=4`02018;
4P0n01D>5@0D3A@04P/C01TD6`0N6B005Q4H00l:4@0A31<040/B01HA600D3aH04PdD01@?5P0E41L0
5Q4H01@>5@0B2a@05@lG01LB6P0F41X05Q4K01LD7@0I5R407Q/V01PF8@0F52407AdY028T<00H6BD0
71lZ028U<@0K7RT07b@_02DZ=@0Z<S/08b/e01XR:`0M9Bh07bTb01hZ<`0M:3806B</01hX<@0Q:C00
7bH^01dQ:P0J7B@08B<Z02HV;P0O7bL06Q/R01PJ800O7bL071`R01PH7P0J6Al05aHK01PG700G5AP0
4a4D018@4`0H4aP201D@5`0A01D@5@0A3@h04Ph=01PC400F3``05Q0;01P@3@0H3Pl05`d@01H<4P0I
3a8050X>01H<3`0E2Ph04PP;01/@500C20`00P0E2`h0100B1`/040H:01D:3P0F2``201H:300<01D9
2`0D20X050P:01<72@0E2@/050P:01<72@0D20X05PX<01D92`0A1PL04`L90P0E2@/06`0F2P`05@T;
01451`0B1PP04@D701@82P0A1`P06A0C014:300B30h0=blb085jO00F41803@D8018;3@0E3a4050d?
014:300?20X03PD601<92P0D2P/05P`=01<:2P0>10D03`D601882@04014720804`T:00X05P`=0106
1`0?1@H05@/<0147200B20T050X;01L=3P0J41406a4B100C1`/00`0A1@T040@801<72`0501<72`09
01872`0A1PX04`P<00h31`0G31004PL;01dB5P0Z7b<050T=00803`@800X04@H:01052@0D2@d03`D8
00h41`0D2@d03P<700l4200?1@P03`@80P0B1`/01`0A1PX09a`P02dR9P0B20/04PL;01H;3`0A1`X0
0P0A1PX0:`0@1@T04@H:01462P0B1`/06@hB00d41P0I3Q804PL;00h21P0C1`/03@@600l4200C2@d0
4@L<01883P0B2@`03P<701H;3`0>0`L0=BX^01dB5P0>0`L03`@801052@0A1PX04PL;01472P0>1@P0
4@/=024J701SFeh04@/=00d62@0>1PT02P@600l82`0>1PT04P`>00d6200B1`/040D901<8300D2@d0
0P0?10P00`0C20`04@H:01052@0201462P0I00l4200@1@/040D;01873@0F2a405@X@01052`0A1P`0
4`P>02hS:@0>1@T040H;0148300H3A<04@H<00l42P0D2`l04`T>0148300C20h050T?00d4200>1@T0
4`P>0146300Dooooo`006oooool07`0H3P`040L401081@0B20L04`X801H>300D2PT03PD401081P0L
4Q004`X801D=2P0:0P004``;00X50P0H3a006Q<A00@0000<10807ALD02<N6`0>1`H04PX801H>300D
2P/06@l@01061`0=10D06@l@00d3100H3Pl00P0D2P/00`0=0`@03`D601X@4@0201@:2`0500l51P0B
20T05@/<01<92P0B20T00P0A1`P03`0B20T04`T:01@:2@0F30X050X901<91`0B20H04@L601471@0G
3@`03P@300h40P0D2PP050X9018820020147200;01<92P0D2P/04PP901061`0C2@X05P`=01L=3P0D
2P/04`T:01`B4`0X7Ql00P0D2P/0500?1@H03@<402HL7@0B20T05`d>01H<3@0K4A804@L801L=3`06
00804@P;01/D5P0<1PP04`X=01@=3`0@2P`04`X=01D=400D3Q0050/>0P0F3A00600G3Q4060lB01D<
3`0H3a805@`?01P?4P0D2`h06A0C01@;3P0A20/06Q@F01DA4P0J5QL00`0002@P8@0E4A804Ph?01HB
4`0B3Pl04@d>01HD5@0J5QL05Q8C01LC50806ADF03X061@E01HA5@0P6al04@`@01/F6P0^:Bl091lU
01TD6P0K6A`06QPK01PF6@0F51D05aDF01PF5`0L6Q/071/J01dL6P0N7A/06aXH01@D4P0M7Ad06A/K
01LH6P0I6Q`06a`N01TM800R8bL07R4V01/N8`0L7b@07b<X024V;00O92X07R8Z01dQ:P0M92`07bH^
01hU;@0P:C00:C8i02`e?00V<CL08Rdc02D`=P0R;cD09C8h024^=00M:S008Rle02`i?`1KJFl0=T=9
02Dd>@0Q<3D0<T5601h]<P0T<cP09cHk0P0[>Sl08`0c@TL0;3]002hm@`0`?d@0;Se202ln@`0^?D80
:3Xn02i4BP0bB5<0<dUG03U>H`0fBVD0?4m]04QKN@1AIGh0Ig^C03M=G@0dBUL0<DMB03a@F@0lCUP0
>DeF03a?E`0lCeH0=TYA03=7C@0X>d40=4Q<0315B00_@TH0=dY?03a=E@0mCUH0>T]C0080=DI>00<0
=TM?03A5C@0dADd00P0gB500500dADd0<49503M:B00gBTP0;T4o03=6A00gBTP0<DA20395@`0gBTP0
=TU70395@`0dAdD0>T]<03Y9CP0gAT/0=TE:03=2A`0`?d@0<D150P0d@dP20350A@0@03=4B00U>3h0
<dI<03I9C`1=GVD093Dl0393BP0W>3l0;Ci502hmA00/>d80<D17030mA@0b@DH0;3]00350A@80:CPm
03h0:CHl02dh?P0^>Cl0<Ca2030k@@0_>T00;3Hm02`d?`0[=Cl0<S]4045:D`0/=Sl0:S@n02Tf?P0U
<SX082de02lnA@0]?440:CQ002lmBP0[>DL0:cU602dkAP0a?dX0>4IA02hoB@0^?TX0;3a902/hB00T
<d<08Rhn028Y<`0J82T08b/h02T`@00S;Ch08bi003Y5E`0V<40082Pc01lV<00P9BX07B8V038f?`0M
8B/0:Bdf01<G8P0Q9Bl05A`T01@H8`0N92d061lW00lF800O9Rl07B4Z02HY;P0Q8RH071dQ028S9`0S
92T07QlT01hN9P8071`T00/07alW020P:P0P82X07QhX028R;00Q8B/07AdW01@D7P0R8R`05aLP024O
:P0201hM9@0e024P:00N7BD071`V028R;00S8bd07QhX01/K9@0L72H0:2Pb014A6`0Y:C<08B4[01<C
7@0L72H06QXT01dK9P0N7RP09B@^02LU<00a<3P07QhV01TH7P0F5Q`06AXO01dL8P0P7RL06QPS01HD
7`0K6B@071XU01PF8@0G5B005Q@O01<A700E4ah06aTT01hL9`0P7bX04aHO01@D7P0I6R@09RTb01LG
8@0G6B804aHO01@D7P0I6b@051LN01XJ900H5ah05Q@I01DC600E4aT00P0D4AP00`0G51`061DN01LD
7@0201HC700@01LD7@0N6B006aHM01XE700N6B007APO01@?5P0J5A`05a8I01D@5`0H4aX06A@K01HA
600I51X061<I01HA5`8050lE00T05Q4G01@?5@0E41H05A0F01@?5@0C3Q@04PdC018<400C3A400P0F
41@01P0E3a<04`dA01D?4`0E3a<050hB01<=4@8050hB00<04P`@01XD600H4QH00P0F41@08`0B3100
50hB01@>4P0A2`l040X>01<=4@0G4A<04`d=01LA400H4a007ALG01<>300E40d06Q@D01PC4@0E40d0
50h>01<=300B30`04P`>01hG6@05004050/>01H?4@0@2P`071<F01L?4P0A2`d04`X=01H?4@0I4aD0
4@/?018<400C3A405Q0D00805a4E01@05Q0D00h8300?2@d04@/?01@>4P0K4QD05P/?01<8300F3A00
71<D01@;300K4Q<04@P;018<400C31<04`/E01084`0>1Q404@`B01@?5@8061<I00<04@`B00`73@0B
3A<00P0C3Q@0300A31804PdC01<>5@0L624050hJ01DB700=2QD040dH01TF8@0G51l061DP01XG8P80
6aPS00@06QPS01lO:@0D4Qd061PR0P0T92h0>@0L72H09RH`02XZ=00Z:S@09BD_024Q:`0M82T07b</
024U<00P92d06alX01TM9P0K7bP07B0Y01`O:00I72D06QdV01TL9@0K6b8071/P01XI7`0J61d05aDJ
01hL8@0I5a`05Q@I01DC600G5AX061HK01DC600H4aT040/A01LB5P0@2`l071PI01HB4`0D41404`l@
01<=3`0@2P`02@<701PB5P0J51H02@<501L?4P0D2`h08A/M01<<3P0A20/040X<018:3@0C2Pd040X<
0189300>10D040H701<92P0301D;300401H<3@0A1`P04`T:01D;30804`T:00<040H70147200C2@X0
0`0C2@X00`0@1PL04`T:01<92P020147200L01@:2`0900806Q0D00P00P0H3A4060hA00h5200F2`l0
50X>00d41`0>0`L04`T<00h31`0A1PX03@8602@I7@0;00@040D900/0100?10P05P/?01D:3P0F2`l0
=BX^02DJ7P0E2@d04@D9010420804PH:00<04@D901<72`0E2@d00P0G2`l06P0F2Ph05@T=00d21P0=
0PH03P<700l4200A1PX04PL;00l4200A1PX04`P<01D:3P0A1PX03`@800h31`0?10P04`P<00d31P0A
1PX0304500l4200C20`050T=01462P0>0`L03@860`0A1PX0100J3a<07Q<G01D:3P0@1@T201462P0P
01052@0?10P04@L<02dT:@0f;C805`dB0146300F2A004`H=01@73P0700804`T>00/21`0G3Q<030<8
01052`0B1@`05PP=01H72P0C10L0404401D93@0G31803PH>00L12`081A0040P@01872`0A1PX081DI
02XO8`0J3a<201462P0A00l4200<0@D03@8601052@0?10P040L:01@:3P0C20`040L:01472P0=0PH0
3@@701@:3@0D2@d040L:01052@0A1PX00P0?10P201872`0O00l4200B1`/04PL;01872`0A1PX040D9
01052P0=0PX04`P@01D:4P0A1Ph081DL00L00P0?10X04@H;01462P0N4aL02P4302@I7@0=0PP05@X@
01<83P0G31803P<900l42P0=0PP05@X@0146300=0PP040D;01@93`0Dooooo`006oooool09P0D2PP0
4`T701L=2`0F30X04@L501<91`0>108050X80106100<0P004@L500/3000B2PP02PD201PC400G4Pl0
4Pd:01XE4P0<1`@03PT800@0000D3``020<001D@3@0A1`P02`4200T0000E2``02`4201/A4P0O5AH0
2`4200l51P0I3a004`T:00l51P0B20T05@/<0P0F30d00`0C2@X04@L801@:2`0201<92P0?01@:2`0E
2``05P`=00/1000=0`4040H401H<2P0K4@l07A<A01<91`0F30X06a4?020F500H3P`04PP800804PP9
01`050X;01D;300D2P/04PP901@:2`0G3@h05P`=01<92P0B20T05P`=030V9`0Z82405`d>00T0000S
6AX0>2h_01T?400F30d04@L801@:2`0J41403PL701dG6@0L5QP01P42018<3P0?2@/040X<0P0D3Q02
01H@4P0I01@>400F3Q405P/?01H;3`0H3A405``@01T>4P0G31006a0D01T>4P0O51P06@hB01D;3`0D
3Q004`l@02/W:00H51D07a/L01<?400G4a@07ATJ01XF5`0C3a005A4B01LC500201HB4`<05a<D00/0
5Q4E01`G6`0C3Q8061<I02<N900M61h05a8I01PF6`0G5AP05Q@G01@B4`0201HD5@0C01/J600J6AL0
6aXH01`K5`0K6QH05aHD01/K6`0I6A/061PJ01XJ700L71l06a`P01hO900L7R<06QdR01/N9@0M8BL0
7R<Y01hR:`0201dQ:P0:01dT;00P9bl082L_01hW;P0U;SD0:34h02D`=P0S;S@092le01dZ<0808Rle
02X082dc024^=00U<SP0;ca2024^=00S<3H09c@j02dj@00U<SP0:3Ll02Th?@0[>Sl0:STn0350A@0Z
>Ch09cHk02He>P0Y>3d0:3Ll02Th?@0/?D@0>4eF049HI@17G6d0CF5h04AHL`18FgT0>dm[03a@J@1<
HGH0=DYI03Y@F`0fBU<0?4iH03U;E@0eAe40=dUC03Q;DP0dAdh0=4M=02m2B00fBDh203M:CP0703U;
D@0fAdl0<T=;0311B@0^?dL0;3e50393B`0303U:DP0/03Q9D@0iBU80=dQ<03E8AP0cAT@0;D0n0313
@@0cAT@0<TE303I9A`0jCD/0>Da:03Q;B@0kCT`0>T]<03A3B00c@TL0=TE:03E4B@0_?T<0;3]0030o
A00c@TL0=TE:03A3B00_?d@0:ci4051UJP0Z?D<0=TU?02Tl@P0a@TT0;d170393BP0b@DP0<3m60391
B00^>d<0;Ca102Lf>`0/>d009SDj02Pg?00Z=cd202dh?P0m02lj@00_>3l0;cPo02df?P0/=3l0<CU4
02Ta?00]=D00:S8m02Xd?P0S<3P0<3e503A1B@0Y>3l07Rdb02@b>P0^>TP0;c]:034mB`0a?dX0<Cm9
0390B@0[?4H0:SY602PhA@0V=TH08c=402@`@00R:3@082@`02H]?@0`=dT0=CiD03M3F@0/>4h07RPj
034kA`0P9c408BH/00X?4`0O8b`06B0Z01dT;P0T:cD0:2li01/R;00X;cT05ahX024X<P0M92h0<SU3
04a@F@0P8bP092DY028S9`0O82@071dR01TJ7`0O7bL07AdU01`L900201hN:00>01dM9`0R82/0518M
01LE8014@Td0>SQ301XH8`0L6RD08b4/020N:@0O7BP081hY01dK9P0N7RP2028R;00501lO:@0M7BL0
7QhX05EEG`0K6bD00P0P82X02@0D51h05aLQ014?6P0E4ah08AlZ028Q:@0H5al081lV01/J800201HE
6P0<01`K800O7R<081lV01dK9P0L6RD07Q`W01dK9P0L6RD06ALR01LE800K6B@07adX0P0P7RT03@0H
5b8030hJ00H8500L7RX04aDQ00/=6@0F62@0:2Xf01dO:`0C5B4051HR02<U<@0G5Qh00P0F51T01P0F
4aT05A8I01DB6@0G51`061DN01LD7@805Q<L00@05a@M01XE700H4aX06A@K0P0M61l201LB6@0;01HA
600G4QT06aHM01`G7P0I51/061<I01LB600F4AL050lE01D@5P0G4QP0100D3aD0100C3Q@04PdC01<=
4@0C3A4301D?4`0=01<=4@0I4aL0618F01@>4P0@2Ph03PP<00`62P0?2@d05a4E01H@500E3a<06A<G
01LA5@0201@>4P0:018<400@2Ph04`dA01H@4P0=1`L03`X700X50P0<1`@05a8?01TD4@<05A0=00/0
5Q4>01PC400J51@03PP:010;300O6A/071HH01dG6@0J51H03`T;018<3P0201D?4@0301<=3`0@2P`0
4@/?00804P`@0P0D3Q800`0E3a<050hB00l93@03014;3`0?01L>4`0D2@d05P/?01hE5P0E30/02@40
01491`0D2`d050hB01D>5@0E3AL04PXG0149500=20h03`X@008040/A00<03PT?00d83P0B3A<00P0C
3Q@01P0A31804PdC01<>5@1iMX007AXU00/84`805A8M00@0514L01HC7P0F4ah05a@O0P0H5B00400N
6bH06ALR01PF8@0S8B`020HA00h<5`0R82/0928]02DS;P0T8Rd08AlZ020N:@0O7RP07B0Y01lR:`0P
8b`201dP:@04020S;00N8BX071lX01/N9`806QdV00T07A`S01PF6`0E4aP061HK01LE6P0L6Ql06ALL
01LE6P0E4aP00P0G5AX04`0D4QL01P4501hI7@0N6Ad02`H:02@O8`0B3A40B4=701`G6`0?2Ph08QdQ
018=4@0D3a<0100001LA4`0K5AL02P@600@0000>20X01P0@2P`03P0F30d05@/<01D;300G3@h05P`=
0147200G3@h050X;01H<3@0D2P/040H701882@0@1PL04PP90`0C2@X0100B20T040H701<92P0C2@X2
0147200701@:2`0A1PX04@H:01@93@0B1`/05P/?01lD600201462P804PL;014050T=01D:3P0I3Q80
5P/?02XO8`0B1`/05@X>01052@0;00@04PL;01462P0=0PH08AHJ01052@0D20`040@800l31`030186
2P0601452@0B1PX04`L;01@8300C1`/04PH:0P0?10P01@0@1@T04@H:01<8300D2@d04@H:00<03`@8
00T03P<700d21P0G310060dA00T00P0D2`d01`0001lD600@1@T00P0C20`0200@1@T03`@801052@0D
2@d04`P<01052@0D2@d05@X>0P0A1PX201052@0K01462P0B1`/03@@801LA5@0N5AX03`D:01052`0C
1Pd05@P?01/>5@0G31802P4501H=4P0>20`040P>01052`0B1@`05@P;01L72P0D10D050D700h21P0:
00D030@=00X74P061140208;00803P<700<050T=01T>4P0B1`/00P0B1`/0100A1PX03`@800l4200A
1PX201052@<04@H:00P040D901872`0=0PH04@H:01H;3`0>0`L04PL;01052@803P<70P0B1`/07`0?
10P04PL;01872`0B1`/04@H:01052@0@1@X03`@<00X0200<0`T04@H>01883P0L4AL060dC01462`0;
00@05@X>01872`0800403`@:00/21P0800<04@H<01052`0B1`d03@8801<83P0?10X0304701052`0A
1P`05?ooool001_ooooo02/050X901<9200C2@P04@L601D;2P0R61L0ED]:01<92@0E2`X040H501D<
2`0I4@l05@`=018<300=1`L020<300l:2P0F4100618B00l92@0F41004@/;01PB4P0<1PH060l@04e3
A00k<C80718C03le=P0C2@X05`d>01D;300D2P/03`D601061`0D2P/04`T:01061`0I3a005@/<00l5
1P0F30d04`T:00804PP900L04`T:01@:2`0E2``050X901<9200B20L04`T8008050X900H04`T801D;
2P0J40l07aDD01`B4@0F30`201<92P0501H<3@0G3@h05P`=01882@0C2@X00P0F30d201@:2`0E01L=
3P0L4Q<04@L801H<3@0E2``03PD501H<3@0E2``081HG05aBD`0C2`/040H701XA4`16@480>C<e01<=
3`0D3Q002@@501@>400E3a404`d?008050h@00@04P`>01H>400F2`l050T=0`0H3A404`0E2Ph05``@
01T>4P0T6Ad0714E01H<3`0C3@l05Q8C01@@4@0C3a005Q8C01LC500=2@X04Ph?01HB4`0D41405Q8C
01XF5`0G4a@00P0F4Q<01P0E4A805Q8C01PC5`0F4AD07APL01dH7P805a8H00<05a8I01HD6@0F51L0
0P0F51L0;00H5QP061HG01TG600G5AD05aHD01TH500K6QH06QTG01XJ6P0H61X06ATK01`L7P0N7R40
7AhR01`M8P0L7R<07B0U01hQ:00N8RT07R<Y01dQ:P0N8R/07b</01dT;00P9bl08RTa01hW;P0O:2l0
8R/b028]<`0S;S@08B`b020]<`0S<3H0:3Dk02Tf?00X=C/0934g02Db>00X=C/09C8h02Xg?@0P;C<0
:SLm0P0Z>Ch09P0^?D80:CPm02ln@`0[>Sl09cHk02`k@00b@DH0;Se202dl@@0b@dX0<dI?041CH@16
FFX0C5if04=DK`17F7@0AUMb03M9HP0dAU`0=dYI049FH@0gBe@0>TaF03M9D`0cADl0=4I@03=6C@0_
@TT0<dI<03M:D00cAT/0?4mC03iAE@0kCE<0>DYB03E6CP0fAdl0=dQ@0P0eATh0200kC5@0?4eE03Q9
D@0fAdl0>DYB03mAE00eB4H0;T4o100bAD<08`0`@d40<DA20354@P0aA480=TU703M7B@0a@4D0<T56
03Q7C00iB4d0<T5603M6B`0lBe00=DA903=2A`0d@dP0<45503]>E01ZOh@0<TE;02m2B00eB4h0;d17
0311B00_@4L0<3m603=2B@0d@dX0;S]30391AP0[>Sl0;Ca102He>P0X=c`0;CY00080;3Lm00X0:cHl
02`e?00]=Sd0;cPo02/d?00[=3d0;3Dn03]5CP0_>D80:38k0P0]>T<0<@0Z=d009S@n02Xi@P0/>T@0
;SY903A0C`0f@U00=49=030nB00Y=d00:3Ho02Le@00T<Sl08c=202DeAP0Z=TH08BLc02@Y=00P9cH0
9bi003DnD`0c?U<0;3M<01LQ<P0Z<d005ahX02hc>@0V:bl06QhW01lV<00K8R`08RTc02<Z=00d>dD0
7RD_01`S;@0G7RP0:C0j07AkQ@1?De`071lT01lP900N7b<06AXN01`M8P0R8bP07QhV01dM9@0L72@0
0P0K6bD03@0L72H081lW024P:00R8BT0;B`d02DT;00K6R807ahV028Q:@0Q82P07ahV01hM9@0M72@0
0P0O7bT01`0M7BL071`V01dM9`0N7RP0JFUc020P:P0E5Al00P0N7RP03`0R8R`0EUAO07QfP@0S8B`0
8B0X01`K8`0b<CP07A`R01TH7@0H5a`06aXO01dL8@0M72<07Q`W020N:@0201hL9`03020N:@0J62<0
5aDP00<06QPS00h07adX024P;016AU807al[01`L:00A4Ad07AdY05=CG`3Gemh0Kfmk02d]>@0J6RH0
3PhJ01/J8`8061DL0P0G51/0100F4aX05a@L01PE7P0G51d301HC700301TD6`0H4aX061<J00806QDL
00@05Q4H01PC6P0G4QT061<J0P0I51/00`0H4aX05A0F01D@5P0201D@5P0401HA5`0G4QP050lE01@?
5@805A0F00@050lE01<>500D3Q8050hB0P0E3a<201@>4P<04`dA00L050hB01D?4`0F41@04`dA01LA
5@0B31003`T=00804`dA0P0D3Q802P0C3A404@/?018<400F41805a4B01HA4@0E3`l03PP801LA4@0@
2PX401<=3@0901D?3`0F41005@lA01<>3`0C3@l03PT:01@>400N61X04P`>00<04`d?00<04P`>014;
3@0B31000P0B3103014;3`0K018<400@2Ph04`dA018<400A2`l05@lC01D>500H4AH05@lC014;3@0H
4a@040X;014;3@0C3A4050dD01@<5@0A2AD04@TD018=500E41H04PdC010;4@0F4AL06aHL014<4P0C
3Q@04PdC00804@`B00L04`hE01lL9P0C41/05A8M010=600>2aH04PlJ0080514L0`0E4Qd01@0E4ah0
5Q@O020N:@0I5b807Q`W008081hY00H08AlZ020N:@0N72L07A/V020N:@0Q82/2020P:P0B01hN:00L
72H07AdW024Q:`0J6R@05aLQ01/K9@0H62807AdW02HU;00M6b005aDJ01XH7@0I5a`05aDJ01XH7@0H
5Q/05aDJ0P0F51T04`0D4QL05Q4E01dH700F4AD09B0T01<?4P0E41@0:RDY018=4@0D3a<04`hB00`7
2`0C3Q803@L902HP8P0<1PP06Q@F010:300D3Q000P0A2`d01@0@2P`03`T;010:300A2`d04`T:0080
4PP900D04`T:01@:2`0D2P/05P`=01061`030147200301D;300A1`P04PP900<04`T:0P0B20T201<9
2P804PP901d04`T:01@;3@0m<cH0YIZN01/B500C20`03@@601<8300@1@T05P/?01872`0;0@@060dA
00d21P0>10L06PlC00X10`0C20`050T=00d21P0C20`05@X>00h31`0G31002P4301862P0?0`L03P86
01452@0401862P<04`L;00D04PH:01872`0B1`/04PL;01<8300201D:3P0@01872`0@1@T03`@80105
2@0B1`/05@X>03P]<@0>0`L05P/?01472P0B20/05@X>01872`0C20`04@H:00l4208040D900@04@H:
01872`0A1PX04@H:0P0?10P201052@804@H:01X04`P<0148300=1`/03`H;01883P0C20h04PD<01<8
3@0@1@X03`D:01H<4@0=1PT05Q0D00d52P0@1PX04@D:01D82P0F20P05@H601D6200A1@P04@H;018;
4P0810h030TC01<=508050T=0P0@1@T00`0D2@d04PL;01872`0201<8300A01872`0@1@T05@X>0187
2`0A1PX05P/?01L<400A1PX050T=00X00`0F2`l0:AhR01872`0C20`060dA01H;3`0D2@d00P0C20`0
0`0A1PX04PL;01872`0301462P0I01462`0:0@L08QHP01053@0?10`04`T?01P?4`0A1P`040H:01H;
3`0;0@@04`X<01462P0A20`040H;01P=4`0E2Q003`@:01@93`0@1@/04`P>01052`0A1P`050T?00l4
2P0Dooooo`006oooool0:`0D2PT04@L601061@0>10<05P`;02TO7P1eJfX05`d=02@J6@0O5A@04@L6
01491`0G3Pl02@<300h8200O6AT030H600l92@0500004@/;028L702:Q8@07ALG00L10@0E3@d0=B//
05M=CP0<0`@09Q`M0147200C2@X02P0100`20`0E2``04PP900X00@0=0`@07A<D034W:00W7Ah03@<4
00`20`0B20T00P0A1`P0100B20T04`T:01@:2`0C2@P201881`0901<9200D2PT05@/:01H<2`0@1PD0
3P@301881`0F30/05P`<00804PP901d050X;01H<3@0E2``04`T:01D;300F30d05@/<01882@0C2@X0
6@l@01dC500D2P/04@L801L=3P0E2``05`d>028H6@07000060h?00L0000M4a@040L900`6200D3Q00
5@lA01@>400O6A/07ALI01@>4003018<3P0A010:300D3@l050/>01@;3P0I41<05`hA01H=400E30l0
50/>01T@4`0X7b807QDH01H=400D3Q006ADF01PD5@0K5aP00P0E4A800`0J5QL05a<D01@@4@0301DA
4P805Q8C0P0E4A80200F4Q<06A@H014<400Q72008ahT01HA5`0H4aT05a8I0P0E4aP09`0G5AX061HI
01PF6@0H5QT05aDF01DC4`0E518061LE01/J600J6AL06QXJ01XJ700L71h07alQ020P8`0N7b<071dR
01dO900M82D07R4X01lS:@0M8RP07b</024U<00P92l072<]01hU;`0Q:3808b`e024Z<`0P:C8082Xc
024[=00O:C807R/c01dZ<P0O;3@08Rlg02@a>@0202<`>00902llA00L:C409c@l02Hc>`0[>4009cHm
02Xi@00a@4L0:SU00080;ci500/0:SU00391B00[>T40;Se403A3BP0]?TD0;d9;0354DP0bAE@0>deR
03]<IP0204AEK`0703i@IP0dAUX0?U5P04YNJ@15FF80>TaF03]=E`0203U;E@2?03A7CP0]@4L0=DQ>
03a?E@0bADX0>diB03a?D`11DeT0DV=[05AUK@1:Ff<0?DiF03U:DP0eATh0=TM?03a=E@0jBe<0<dA<
03A5C@0lCE80<TA402Xl?00eAdL0=TQ803E7A`0fB4P0<dE50312@P0]?cl0;T100353@`0fAdP0=4=8
0391AP0eA4T0=dI;03=2A`0oCU<0A5=H03A3B00]?440<D1503A5B@0Q=3X08CHk02Tl@P0[?T@09cY0
03A5C00]?TD0:ca3030oAP0c@TT0<T5802dj@P0Y>3d093<h02/j?`0/>d00<d9703e:D00]>3h0;3Lm
02Td>P0Y<ST0:c@k02hg?P0e?TD07RL^03@oA@1WLWP0=T5702llA00H9Bh06bLc02lmB00T<Sl08Bll
02PhAP0a?Th0=D9B02lmBP0]>dH0;C]502Dc?00S<CX08c4k02@b?`0V<d<0:CI702`hB00N930092Te
01dS<@0O9SP0:314028Z?`0L93T07BDe01TQ;00O9S006R0U02DZ;P1fNh406alX01hR:`0X;3D0=SY3
02lc?00J7RL07b</02@X<@0E6B80?T9;014F700J7B805aPL01/L800L7B407QlT02<T:@0K6b<07AdU
01`L900J6R@07AdW01lO:@0L6b8071/Q01HE6`0Q82H06QTO020O9@0M728071/Q01hM8`0O7R@07QdS
01hM9@0P82X07AdW01/K9@0M7BL00`0N7RP03@0O7bT0:2Pb01hN:00>3QP04Q8L034_>P0i=d80:2Ha
01HE7@0Q82P07A`S020O9@0L6b000`0K6Ql02@0K6R4071XU01XH8`0L6RD0928]028P:`0J62<071XU
01dK9P0201TG8P0>024O:P0Y:3<0Fe]U028R;00B4Q`05ADO020P:P0/;3H0U9BN03loB@0a<C/0820Z
018B700H5R0201PE70805a@K00@05Q<J01LD6`0G51/05Q<J0P0E4QT0100F4aX05Q4H01D@5`0F4AP3
01PC6P0601TD6`0H4aX05Q4H01HA600H4aX07APO0P0C3Q@201D@5P805Q4G0P0E41H201LB60805Q4G
1P0D3Q80100F41@05@lC01<=4@0A2`l2010:3P8081XN00L05Q0D018<400D3Q8050hB018<400D3Q80
4`dA00804P`@00/05@lA02<M7`0?2@T03@L700X4100@2PX081XJ01D?3`0D3Ph04@/;010:2P0200l9
2@0501LA4`0<1PP071HH01/E5`0;1PL00P0H4Q@01@0E3a404@/=010:300A2`d04`d?008050hB00H0
4`dA018<400A2`l04@/?018<400@2Ph2018<400901PB5P0O6R005Q<M00/:4P0:2A403@/A010>4@0=
20`040/?00804@XA00X04`TB01<9500@21<03PT@01@?5@0C3Q@03`X@01<>500H4aT04@`B0P0B3A<0
1P0@2a404@`B018=500C41T04@hG01<@6@804PlH00@0514J01<@6@0D4AX0514J0P0E4Q/0200L6R<0
2PTA01lN9P0Q82P07QdU01/J8P0P7bL071/S0P0N7BD02@0L6b<07A`T01lN9P0P82P07alW01`L900I
6B406QXR01dM9@0201PH800901`L900K6b<08R8Z02`Z<P0Q7b@06aTN01dK800K6Ah05Q@I00<061HK
01H05A<H01@B5`0D4QL04`hB01`G6`0<1`/0=S4e01/F6P0B3A4050lC00T4200D3a<03PT=024L800D
3a<07QPJ02PR900G4A<07ALI028L7P0;1@L04@/=0P0@2P`0400?2@/040X<014;3@0B20T05@/<01H<
3@0A1`P050X;028H6@0a9bP06a4B01882@0D2P/04PP900h41@0A1`P301<92P0301882@0A1`P04PP9
00D04PP900T06@hB02LL800g;3004`P<00h31`0H3A4050T=00l4200G31000P0F2`l03P0/8BD0:AhR
02@I7@0K41@0304500l4200C20`03`@801052@0B1`/03P<701@93@0@1@T04`L;0P0?0`L0100A1@T0
4PH:01862P0D20`501<72`0301872`0A1PX04@H:00804PL;00@04`P<01462P0D2@d050T=0P0B1`/0
1`0D2@d02@0200`11@07000050T=00/0100B1`/00P0A1PX0<00?10P03@8600l4200?10P03@8600l4
200C20`04PL;01462P0?10P03@8600l4200B1`/04@H:01052@0@1`/030H:00d42@0B20h03@8800d0
1`0=0PL0300601D:400C2@l0;bH[00d72`0A2Pd040L:01052@0B1`P050P801871@0?10<03`<501<8
300?2@d01@0600`9400G41H040D900h31`0?10P040D901<8300A1PX040D901462P804`P<00d03P<7
01<8300B1`/05@X>01/@500J3a<040D901D:3P08004050T=02XO8`0@1@T04`P<00804PL;00<04@H:
00l4200?10P01P0A1PX06@0A1P/05@XB00L01@0S6200IEYR01463@0<0@L01`0201H;400;00@0>c0d
06EJGP070000=2T_01<83P0G31804@H<00h32@0A1P`040D;01873@0A1P`04PL=01@93`0>0`T05?oo
ool001_ooooo01T04@L601@:2@0H3Pd05P`;01<9200I3`h04@L600d4100X7Qd09Q`K020F5@0<1080
4@P900`61P0400003@L7020J6P0F41003@L701H@40060000@cdm00P20P0A2`/04`T:008050X;0100
4@L801<92P0:00404`T:01L=3P0D2P/04`T:01@:2`0B20T04@L801D;300O5AH06Q0A01061`0A1`P0
50X;0P0C2@X00`0D2P/05@/<01H<3@0301881`0301@:2@0E2`X05P`;00<050X900T04`T801881`0C
2@T04`T:01882@0D2P/05@/<01<92P0E2``00P0I3a00600D2P/03`D600l51P0D2P/060h?01@:2`0C
2@X06Q0A01H<3@0=0`@06Q0A00l51P0S6AX06@l@01lE5P0B2@/03PP:01D?4@0;1PL03@L901D?4@0>
2@X05Q0B01<=3`8050h@00D04`d?01D=400E30l06A0C01XA500201H=400B01<:3@0?1PT04`X=02DL
7`0I41<04@T<01TC5@0B3Pl06QHG01@@4@0;1`P0510A01DA4P0A3@h04Ph?01@@4@0B3Pl04`l@0`0F
4Q<02@0G4a@061@E01XE6@0?2Ph06aHJ01lJ800G4QP061<I01D@5`0201<A5P0:01DC600E4aH05A<F
01@B5@0F51D05A<D01LF500I61H06aXH01TH5P806QXL01H071`N01lO8@0O82<071dQ01`M8P0K7B80
6QdR01XM900K7bD06QlU01hR;@0R9S408BD`01`S;@0N9Bl08bXd02@]=P0S;3D082Tb01hX<@0P:S<0
8B/d0`0O;3@03P0P;CD0934i02Ld?00L:C40;S]301l/=00W=3`0:SLo02@a>@0U=3/0:cY103E4B`0[
>T40;Se40P0_?TD04`0`?dH0:SU00350A`0hAdh0<D9903=6C`0aA580;d9A03M:G00iBf<0@eE]045C
J`11DfL0>4]L03U=FP0kCeX0?E5J03Y<EP0lCUP00P0jC5H0700fBE00;d9903U<DP0lCeD0=4M<03]>
DP0iC500<49803M8D00nCeL0=TM?02Xk@`0[?4@0<45903E6CP0kC5@0?4eE03I7C`0dADd0=dQ=0312
@P0Z?3`0<TA403I8B00dATH0=DM703=5A@0`@T8202do?`0402m1@@0b@dD0<T560350A@80<T5606X0
<3m403I5BP0gAT/0<T560350A@0c@TL0<T97045DFP0S>3d0=dY@02i1A`0P<cT0<dA;0352B@0_@4L0
=DA;03A3BP0]?4<0:SLo02dl@@0W=S/0;Ca102Xi?P0^?D80=45702lj@00]>3h0:SDk02Tb>@0Z<cX0
;CHm03@m@P0J8bP09c8h05AOI@0Z=C/0;ca403M3C`0K9c<07bdj01`Z=`0Q;Sh0;cm?038oD00d@E40
:3I302Dc@00Z>480938k020^=`0S<C/09cE002Te@`0Y=DD0:S=201lU<@0T:CD08bTg02L]?@0^=DL0
;CE801/R=@0N9CD031@O02<Z=00Y;c@0CE9F08N<TP0T:3409BTb01lS;00X;3D0720Y01DI8P0J7RL0
5a/T02da>P1_Lg`08BH/01/L8@0H6Ad08R<W024R9P0J6b0071dR01/K8`0N7RH07AdU01/K9@0N7RP0
8R8Z01/J7`0T8bT02@P=02@S:@0W9R`07QdR01`K8@0I61h07A`Q01lN8`0M72807QdS02<S;00O7bT0
7QhX0`0P82X03`0I6B<06QXT01PH8P0>3QP05QHP02PX<P0I5b805A<N00L5400N7BD02`XB024P9`0L
6b406QTN01`K800201dL8@0801`K8P0M6bH06QPS01/I900W9C008b4/01LE800H5R4201dK9P0?01XH
8`0K6B@07QdW034a>`0>3QP071`V01PH8P0E5Al05QHP01lO:@0<31H07QhX01TI8`0d=3h05A8L00<0
5a@K0`0F4aX01@0G51/05Q<J01@A600D4AP05A8I00804PdD00D05A0G01PC6P0J5A`07APO01LB6@03
01PC6P0401/F7@0S7RD04`hD01<>50@05A0F00@050lE01D@5P0F4AL05a8H0P0F4AL01`0E3a<050hB
01@>4P0C3A4050hB01D?4`0G4AD00`0F41@01P0G4AD0618F01PB5P0J51P04`dA010:3P805@lC00`0
4P`@01@>4P0D3Q804P`@01<=4@0D3Q806Q@F01LA4@0E3`l06aDE00h8200F410201D?3`804`d=00l0
50h>01D?3`0<1PP06aDG01LA4`040000:bDW00`6200@2P`04P`>01@>400C3@l04@/=00l92`0D3Q80
0P0C3A401@0B31004@/?014;3`0B31004@/?00804P`@00T06Q@H028M8`0G62<05aTU01@D7P0?3aH0
1`H;01@B5@0A3Q400P0C31<0100E2a@05@/F01D;500=1`h2014<4P0600l:400@2a404PdC010;4@0B
3A<04@`B0P0@2a400`0B3A<020D>00/84@0201@A6P803@XC0P0C41T02`0E4Q/05Q<L01HC700F4a`0
3@`D02h]=@0A41P061LO01HE7@0E51`061LO008071/S00@061LO01LF7P0I62006a/S0P0L72@01@0J
6R8071`T01TI8@0G5al06ATQ008061PP02407AdU028P9P0J61d05Q@I01/I7P0J61d06ALL01HD6@0G
5AX061HK01DC600D4QL05Q@I028M8@030080>SDi0:bWZ`0I51P07aXN01dH70080`L05a8F00L21P0E
41@03PT=01/E5`0@2P`03`T;038/;P1<ATP0618D00l92`0@2P`00P0A2`d2010:300=01882@0E2``0
50X;00h41@0?1@H06Q0A02DK700B20T03@<401882@0C2@X04@L801882@0301<92P0501882@0@1PL0
4`T:01882@0A1`P00P0C2@X01@0A1`P01`0001@93@0C20`05``@00804@H:00<05``@01462P0B1`/0
0P0@1@T0200N4aL09Q/O02HK7`0H3A403@8601052@0F2`l05@X>0P0A1PX01P0>10L04@H:01872`0E
2@d04@D9010420804PH:00<04@D901<72`0B1PX0100A1@T0100A1PX040D900l4200@1@T201462P0?
01872`0E2Ph04`P<00h31`0=0PH03`@801@93@0<0@D0714E01D:3P0M4QH01`0001462P0B1`/04@H:
00803`@800P04@H:01052@0@1@T04`P<01052@0?10P04@H:00l420804@H:01d040D900l4200>1@T0
30H:00l62`0A1`d03P<901032P0I31<0200200T0100m<cT0j=oT02`V:P0?1`/040L:01061`0A1`L0
4PP701871@0C20L03`D400X10P0@2@`05Q4E01D@5P0A2Q003@8600`21@0201872`804`P<0P0@1@T0
0`0B1`/04`P<00h31`0200l4200@01<8300H3A405P/?00d31P0H3A402P0300`31@0H3A402@0201@9
3@0>0`L040D901872`0C20`05@X>01/@508040D90`0A1PX06@0B1``05@XB03<W<@0h;CD09a`T00`3
200L4AL03`@:01072P0@1@T0304501hE5`1eJVh0IEYP01`A5`0C20h03`@:01873@0<0@L03@880187
3@0A1P`040D;01873@0=0PP05?ooool001_ooooo00@04`T:01882@0G3@h060h?0P0B20T09@0E2``0
4PP900d41@0A2@T04@L801482@0E30l05Q4B07miN`1LEUP07ALI00h82P0D3Q0081XL01dG6@0=20T0
2`D700h82P0E2``04PT:0147200F30d04@L801<92P0H3Pl09adN01dC500@1PL04PP901H<3@0C2@X0
4PP901061`0A1`P04`T:01882@0C2@X00P0B20T00`0C2@X050X;01D;30020147200>01882@0D2P/0
5P`=01L=3P0D2P/05@/<01@:2`0C2@X04PP901H<3@0G3@h05P`=01L=3P0F30d201<92P805P`=01T0
50X;01882@0C2@X04PT:01hD5@0Z824060h?01@:2`0L4Q<05`d>0147200A20P05P`=01X@4@0F30d0
4@P:01LA4`0A2`d04`d?018<3P0<1`P05Q0B01@>400A2`d04P`>008050h@03004``>01H=400P5aX0
7A@G01D<3`0G3Q407A@G01H=400H3a80:R4T01hE600F3a405A0B01@@4@0F4Q<07a/L05QDE@0F4Q<0
3`/<01LC500T82407ATJ014=3P0H51D05A4B01HB4`0I5AH06QHG01/G600K5QX05Q4E01@?4`0E41H0
6A@J01XE6`0I51/05A<H01HD6@0G5AX05Q@I01DC5`0C4A@05aDH01PF5`0J61T071/J01/J600G5QD2
01TI6`3Q01/K7@0L71h071`O01PI7@0Q8RL07AlT01XM8P0I72<06QhU01/P9`0I7BP07b<^024U<00N
9Bl08RTc02T`>P0O:3408R/d020Y<P0K9Bh07bTb02La>P0M:S808c0h02Db>P0S<3P09S<k02/h@00W
=3`09S<k02/h@00R;cL0:cQ002Pe?@0V=C`0;ci503]:D@0/>d80:CPo02/j@@0V=C`0;3]204QGGP17
EUd0;ci50311B00a@dd0=4IC03=5E00gB5X0<T=F03M8G00oD6@0?4eP03m@H@0hBUP0<49=03U;E@0j
C5H0=TQB0394CP0eAe40=dYA03A7CP0fBDl0=4M=03A7C00hBdl0<dI:0312B00eATh0=TM?03=4C00b
@d/0=TM?03M8D00eATh0=TM?03U:DP0hBE40=DI>03A5BP0fB4P0<dE50353@`0gBDT0=4I602i0@00]
?cl0:cdm02Xl?00[?Cd0;3hn02`m@00`?d@0=DA903I5BP0b@DH0<d970391AP0a@4D0=4=803I5BP0c
@TL0<41502i1A`0Z?d@0;3m502Pk@@0/?dD0;d1702Tj@@0[?4<0=DA;0350A`0W=Sd0:SLo02ln@`0Y
>3d0;ci302Th?@0[>Sl0;3To034l@P0`>d40;CPn02`e?00Z<cX0:c@k02Xe>@0d?d409S4e028_=@0[
>3l0<Sm807Z8T`0lBUH0;ci<02dmC00X>4P0;Ca>02llCP0a?Th08S0m01l]>P0W=3h08Bhf01/X<00S
<3P0;3M202dg@`0W<Ch08BXh02P^>P0S9c8092Tf02<Y>00U:c`0<3M8024U=`0T:SP0:2lj028V<00L
8BH08BHZ028W;@0M8BX08BD^02<W<00Q9Bh07b</01HJ8`0L82T08BD^020T;@0M8BX061`S01hO900K
72007b0T01XK7`0Q8RL0<C8g01lO9`0R8RX0820X01/K9@0M7BL08B4Y01dN8@0X:B`05aPJ024R9@0O
82<07AhP024R900J6ah07QlQ01hO8P0K71l07AhR020P:@0L72H07AdW020P:P0M7BL06a/U01dM9`0I
6B<05ADO01dM9`0H62806ATS01LE800W9C00<c4l01`K8`0O7RH061LN01/J800I61d06QTN01TH7@0G
5Q/05A@K008071XU00<05Q@O01hL9`0N72L00P0I5b8401PF8@0=01TG8P0K6B@05Q@O01lM:00/:SD0
7adX020N:@0J62<0518M01LE800H5R40928]01@A6`0301HC70805A8K00<05Q<K01HC6P0E4QT00P0D
4QL0100E4aP06A@K01TD6`0I51/201LB6@0=01TD6`0D3aH05a8I01/F7@0G4QT05A0G01HA600D3aD0
5A0F01HA5`0E41H050lE01<>5002014<4P0601<>500D3aD050lE01@?5@0F41@05@lC0`0C3A402@0F
41@04P`@01<=4@0D3Q805@lC01PB5P0J51P04@/?01H@5002018<40805a4E00<04@/?01@>4P0E3a<0
0P0C3A401`0D3Q808QdN03H`<P0:10H071HH01<=3`0A2`d00P0D3Q0201<=3`0>01D?4@0F4180618D
018<3P0C3Pl05a4C040j?00E3a404@/=010:300?2@/04P`>01TC5@0N61X6014;3`0=01<=4@0D3Q80
5@lC014;3`0D3Q806AHM071cP@2CV:H08RLc014C700P8BL05QHK010>4`02018;4P0401@:4`0E2A<0
5@/D014;4P803`X@100@2a406P0B3A<04@`B00l:400@2a404@`B01<=5P0D3QP05Q0J01PB700G4A/0
4`dG018<5P0C3AL05Q0J01PB700I4ad05a@M02h[=01SH6T05a@M01/H8@0R7bP07Q/T01`I8P0M6R<0
71TR0P0H5Ah01@0I5al071/S01hM9@0M72@06QTQ00806APP00h092<[02PW;`0J6B4071/S01/J8P0G
5Q`05Q@I01LE6P0J61d05Q@I01PF6`0C4AH05Q@I01PF6`805A<H02D06ALL01D@500P6al04@`@01XE
6@0?2Ph071LK01D@500:1@T05a8F01D@5014?d<061<G01lI6`0R71h04`d?01LA4`0S7Al07aTK00d7
2@0?2@/04`d?01@>400B30h03PP:01D;300C2@X05@/<01X@4@0I3a004@L800h41@0@1PL05@/<01@:
2`0A1`P05@/<00@04`T:00<04PP901061`0D2P/00P0A1`P201<92P0301061`0D2`d04PL;00804PL;
0P0E2`h0500@1@T04@H:01052@0@1@T04PL;00l4200:0@<05`d@01462P0@1@T04`P<01L<400D2@d0
4@L:01<8300A1PX03P<701D:3P0I3A4050P<0P0C1`/0100B1PX04@D901L;3`0D20`201<72`8050P<
00@04PL;01462P0@1@T040D90P0A1PX05`0@1@T04PL;01052@0?10P05P/?01dB5P0V6al07Q<G01dB
5P0K41@03PD701T>4P0C20`05P/?01L<400D2@d04@H:01<8300?10P03P<701872`0>0`L03`@80080
5``@02T04`P<00l4200@1@T04`P<01<:3P0@2Ph03`H;00h42@0D2@l050L>00h3200I31<04@P<03L]
<`2@Qh`040X>01<<3`0@1`P03PD601071`0A2@L04@P800l71P0C2`X04@P900h7200L5QP06A<F0107
2`0>0`L04@H:01<8300@1@T04`P<01P=4@0C20`03`@801<8300E2Ph04PL;01462P0201872`804@H:
00d04PL;01052@0=0PH040H901<8300>0`L04@H:00l4200A1PX04PL;01052@0B1`/06@hB008040D9
0P0A1PX06P0B1`/04PL<01053@0H31H04@L>01@:4@0]8RT071<G01<83P0]8bL050T=01dB5P0S6A`0
4`X<02HK8@0B2@d0<RL]024F700C20h04@H<00l42P0I3Q@060dC01@93`0E2Q0050T?5?ooool001_o
oooo02/06@l@01<92P0B20T04@L800h41@0C2@X06a4B00d41@0P5QL03P@500l51P0C2P/04`X=01LA
4`10>S`0>C<e00`7200B30h02`D700h82P0P6Q`03PP:00X41P0;1@L04`T:00X00@0>10D04PP900d3
100A1`P040H700`20`0?1@H06@l@01L=3P0A1`P04PP901T?400B20T03`D601<92P0H3Pl040H70080
50X;01404@L800l51P0?1@H06Q0A00d3100@1PL0718C028H6@0800004PT:01<92P0L4Q<0308301X@
4@0>10D040H701882@0201L=3P0?01<92P0A1`P04`T:00P0000C2@X060h?00`20`0@1PL04PP901D;
300C2@X04@L801<92P0F30d05@/<00805P`=0P0G3@h04P0F3@l040X<01<=3`0F41802P@601@>400Q
6ad01`43020J700Z92H02`D701/E5`0H4Q@02`D701<=3`0E3a406aDG014;3@8040X<00X050h@024K
7@0H4Q@06A<E024M7P0:1PL061@E03Te=P1cKg007QXK0P0B3Pl0100O6a`05Q8C01<?400G4a@301PD
5@0:01HB4`0E4A804`hB01XE6@0I51P050lE028M8`0Q72805A0G01@A60806AHM00T05aDJ01/I7P0G
5AX030X=01LE600F51D07A/L01TG600F51D00P0M7Al02`0L71h06a/M01/L7`0K72007b0U01`N8`0N
8BH07B0W01XN900M8BX06alZ00807R8^01405Q`X03HlB02LXZh09blj02@/=`0I8B`0<3Y401dW<@0]
=d408c0i01l/=@0W=3d072Tb02Db>`0T<CX0:cQ103I3C00202Db>`0601l/=@0V<c`082hg028`>@0U
<c`0:3Ho0P0Y=d00BP0[>D80;Sa502`j@`0b@4T0;3Y30311B@0a@dd0=dUE03Y<FP0[?D`0=dQH041A
H@0lCEh0?e1P045CH@0fB5D0;d5;03E7D@0bA4h0;T1:03A6D00cADl0<DA;03A7CP0fBDl0;d9803A7
C00bADT0;d9602/m@`0`@DT0>DYB03M8D00`@DT0<D9:03U:DP0/?DD0<dA<03I7C`0_@4P0>4UA03Y<
D@0Q<cD0>D]=02do@@0mCe40;Cm10312A00bA4H0<dE702do@@0[?Cl0:3Xl02Hg>P0V=CX0>dY?03U8
C@0T<cP0;Ca103E4B@0fADX0;ci303=2A`0Z>Ch0<D5602Xm@`0R=c`0;d9802`oA@0`@dT09cPo0311
B00^?dH0;ci50P0a@4L0>P0/>D40;ci30350A@0c@TL0;Ca102Xi?P0/>Cl0;3Lm02Td>P0X<cT0:S<j
02`e?00c?4<0:3<g02Le>00^?3l08Rle038oA`0Z>440<3i902lmBP0]?D`0;ciA0311D`0a@UD0;Se@
02/iB@0Z>4D0:cU602Tf?`0S<3P0:cHl02@^=P0V;cP0:30k020X<`0E6bL06Al[01hS;`0M8Bd07b8a
028U=00N8C00:bdl02L[>00Q9C007b</02H/<P0T:Bd07b@Z01dP9`0P8bX07b8Y01/N9@0R9B`08bH]
01lR:@0N8BP2024T:`0^01`O9P0P8BH07QlS01TJ7P0H6Ad07AhS024R9`0S8b/08R8Z01lO9`0M7BL0
7alY024Q:@0Q8RD04Q<E024R900L7Al08R<U01PI6`0R8bD06a`N01dN800K71h05aPJ01TJ7P0K6b@0
6ATS01PH8P0I6B<06a/U01`L9P0I6B<05aLQ01/K9@0I6B<05aLQ01/K9@0L6RD0R8JA0?Oeo`0h=cl0
5QDM01LF7@0N7B<07A`Q01PG70805A@I00H06aXQ020N:@0G5B005Q@O02DS;P0@3QT201HD7`0<01DC
7P0G5B006ALR01/I900H5b008B0X01XI8@0L6b<05QDM01TH800P7bL06QTQ0`0H5al04`0F5Ad05A<M
01LD7`0B3aX06QLR00h;5P0K6240514I01PE700H5Q/05aDJ01HD6@0G5AT05A0G01PC6P0K5Qd061<J
01D@5`0D3aH00P0F4AP01P0B3A@050lF01TD6`0F4AP04`hD01HA5`806QDK01005a8H018=4`0@2a40
4`hD01HA5`0J5A/07aXP01hI7`0@2Ph05Q0D01LA5@0F41@0618F01<=4@0B31004`dA0P0F41@0100D
3Q804P`@01<=4@0C3A42018<400302<M8@10>Sh050hB00804@/?00h04`dA01D?4`0D3Q80GUQJ06eW
J@0B30h040X<00l92`0A2`d040X<01PB500J51H05Q0B01@>4080618D00/04`d?01TC5@0E3a405Q0B
00/51`0D3Q004P`>01<=3`0600805@lA01TC5@02014;3`0H018<400C3A404`dA01<=4@0E3a<03PP<
01LA5@0?2@d02`D901/H7`2KWjd0];[802L]>@0@4Q`08B4Y01<D6@0?3A804``C0109400L4Q/0?C4k
04m5CP0?2@l03PT?0P0?2Q02010;4@0D00l:400D3aD03`X@010;4@0M61h04@`B00d63P0B2a<0<BXb
05A=E@0P6B404@XB01<<500B2a<050dE01H?5`0E3QH04`lF01@A600E4QT401HC6P0S01LD6`0H5A`0
5a@K01@A600B3aH0518I018A5`0E51X06APN01HE6`0L6b405aHL01XI7`0L6b4051<I010?5@0I61h0
71/P01TG700G5AX04@lD01@B5`0B41D05Q@I01<A5P0B41D02PP=014?500F51T05a8F010;3`0E41@0
6A@H014<400C3Q800P0G4QH03@0@2`l061<G02@O8`0F4AD0JVAV03La<`0D3Q005a4C010:300H4Q@0
4P`>01<=3`0D3Q000P0A2`d0300D3Q003P@500l51P0G3@h0GeEF02PN7`0=0`@07aDF01@:2`0B20T0
6Q0A01061`804@L800H060h?01@:2`0D2P/04@T900l51P0D2P/201H<3@0700l51P0G3@h04`T:01P=
4@0F2`l050T=01<8300201872`0:01462P0F2`l05P/?00X00`0G31003P<701052@0>0`L05P/?00l4
20<04`P<00l050T=01D:3P0=0PH04`P<00h31`0D20`04@D901862P0E2@d05PX>01D93@0C1`/03`<7
01<72`0D20`00P0@10P0100A1PX05P/?01<8300@1@T200l4200=00h31`0B1`/08QLK00d31P0F2`l0
2`0401lD600T6Ad04@H:01/@500900804`P<00l4200201L<400301052@0=0PH040D900804@H:01l0
3`@800h31`0@1@T03`@800T00P0J3a<03PD702DJ7P0700005@`@018<400700<04`T?00l42P0G2Q40
4`H=01442`0<0@L06@lE01XA5P0E3a<020<400/51@0P6Q`02`D7018<300?2@/02`D600/51@0<1PH0
3@H600803PD600<03`D801052@0@1@T00`0@1@T03@0Y7R802`0400l4200;00@04`P<00l4200B1`/0
4@H:00l4200>0`L03`@801872`0H3A400P0@1@T0100B1`/0304501872`0@1@T200l4200;01462P0B
1`/04@H:01@93@0C20`040D900l4200@1@T04PL<01463P0A1@l00P0A1Ph01P0A1Pd04@H<00d2200C
20d040D900d21P8040D91P0B1`d601052aCooooo000Kooooo`0>01882@0A1`P04PP901D;300F30d0
4`T:00L0000H3Pl06a4B00`20`0J41401P0000h520080`@2028L7P0E00X41P0B30h030H801PB5008
0P@02`D701/E5`0=1`T040H701L=3P0R61T04PP901061`0G3@h05P`=02<I6P0O5AH040H700d3100A
1`P03`D600804`T:01`08QPI01@:2`0C2@X04`T:01D;300D2P/04PP90147200B20T04PX:01061`1R
F5T0B3ho00X00@0J41403`D60147200H3Pl04@L801L=3P0@1PL04`T:01882@0D2P/05@/<01@:2`0C
2@X0718C0P0E2``00`0I3a003`D601882@0201@:2`0601D;300G3@h05P`=01D;300D2P/05@/<0`0F
30d01`0D2`d02`D700T31@0<1PP050h@02XT9P0/9RP00P0<1PP030060@807QPJ04@n@00a:bd040X<
01@>400@2P`050h@00h82P0B30h05a4C018<3P803@L900X0=c4c00/7200?2``05a<D00D10P0T8240
3`/<01XF5`0E4A8071PI0P0F4Q<401LC500:01HB4`0E4A8050lC00l:3P0G4QH06aHL014<4P0B3A<0
5Q4H010=50805A8I02H04a4F01HD6@0C4AH05aDH01lM800I5aX07A/L01LE5P0D4Q<06ATK01/K7@0M
7Al07QhP01`M800K72008B8W01hP9@0O8RL07R4X01/O9@0N8R/07B4/01XN:P0S9c<09R`h01hT<00i
?d/08BTd01dU<00L92l08bdg01TS;@0W<C/07R/d02hkA00P;CH0:CHo030mAP808c0i00L0=T=<024^
=`0V<c`0:3Dn02Ld?@0U<c`09S@m00809cDn0P0X=Sl0500U<c`0<Cm802dkA00_?DH0;Sa503U7D00f
Ae40>deI03mAG@0a@e00>4YH03a>G00jC5/0>D]I03Y<F00iBeL0=dUC03U;E@0bA4h0;T1:0P0bA4h0
1@0bAD`0=TU@03E8CP0bAD/0<TE:0080;3m300T0<dE;03I7C`0eATh0<T=;03=4C00iBU80?e1H0311
B@0dADd00P0fAdl02`0mCUH0<D9802Xl?P12E5H0<TA602i0@P0W>C/0E6IX03Y<CP0[?Cl09cTk0080
9CLi01X093Dh02He>P0b@DH0=dI;02`k@00iB4d0;ci302hm@P0]?440=DA902hm@P0b@TL0<4=902Xo
A00]@4H0<DA:03Q;D@0lCE@0;d1702`mA00/>d80;ci50350A`0a?TH0:3Ll02Xi?P80:cXo00D0;Se2
02hk@@0/=cd0:SDk02Td>P0202`e?00:02dg?@0_>T009S@g02Ld>P0R;cL0<Sm703E3C@0a?d`0;Ce:
02hnCP80<D9D01/0;CiB02hmD00[>TX0;C]802lmBP0]>T<09c@l02Pc>@0S;C<09Bhg02/d?@0[<Cd0
8bTe01`R;P0P9C408BDa02HY>00[;C`09BLd02<U=00Z;3P08BD^01XN9`0N92X09BX^028U;00M82L0
0P0O8RT02P0K7RD07b8Y024T:`0O8RT07R4X01lR:@0P8bX07R4V01hO900N7b<201/L800F020Q9P0S
92T07alW01lO9`0N7RH07AdW01hN:00O7bL09RLZ01`M8@0P8B<07b0S024R9P0I6Q`07AhQ01XK7`0L
7Al06AXM01LH700J6al071`U01XJ90806ATS01/06QXT01/K9@0M7BL06QXT01`L9P0I6B<05ADO01TI
8`0J62<0BTQC09BBW@0`;cL061LO01`K8P0F5A/02PT>01dL8@0];3407QdR01DD6`0O7BP071XU01LE
800L6RD05aDP01lM:00H5R400P0G5B002P0H5R406ALR01XH8P0E51`05QDM01/J8P1GEUh0FEQP01DD
700J6B4301PG7`0>01HE7@0N72D03``G01HC7P0B3aX06aPS01`I8P0E4QX06QLN01`J7`0E4aP04a4D
01PF6@0J5A/201TD6`0301`G7P0K5Qd05a8I00805a8I01P05A0G01PC6P0M61l06aHM01D@5P0F4AL0
61<I01LB600F4AL05A0F01<>500F4AL05A0F01@?5@0G4QP04`hD01D?4`0I4aL05a4E01D?4`0I4aL0
5a4E018<400C3A4201H@500V01@>4P0B31005a4E01LA5@0H4QH05a4E020J7P0c;C4050hB018<400A
2`l04`dA01D?4`0D3Q804@/=01LA4`0S7Al0208401HA4P0V82803PP:00d72@0<1PP04P`>02dW:@16
@4803`T;018<3P0A2`d03PP:01@>40090`D0208401LA4`0R71h03`T;00h82P0;1@L2014;3`0G018<
400C3A404`dA01<=4@0A2`l03@L;01@>4P0E3a<03`T=01PE700/;c`0>Ca;01PL:00?41T061TN04A3
B00G51T04``C00l83`0C2A808aLQ02/Q:P0A2a400P0A3183018=4`07014<4P0G4QP050lE01LB600T
7bD06A@J00h73`0201D>5P0602HO9`0@2A404``D01<<500A2Q804``D0P0F3aL00`0F41L0514H01@A
600201HC6P<05A8I0P0F4aX0200E4QT0514H01PE700E51X06aXP01PG7@0J6Al05A@J0P0D4aT201PG
7@0F01/J800T8bT08R0V01XH7@0I5a`04a4F01HD6@0D4QL07A/P01LE6P0>31408R0U00`:3`0=3100
=2lc02<N8P0F4AD04`hB00d8300B3A404@`@01D@508040/?00D061<G014<400R71h04@/=018<3P02
014;3@05010:300;1@L03@L9010:300>20X00P0=1`T06`0L4Q<06a4B00d41@0`9RL060h?01D;3007
00005P`=01L=3P0700007Q@E00l51P0>10D02P4201/A4P07000060h?01T?400J41404PP900/10P0C
2@X0:1hO00/10P0E2Ph050T=01872`0401462P0700P00@0@1@T060dA01`A5@0@1@T08AHJ00d21P02
01D:3P0800l4200>0`L04@H:00h31`0?10P0308501L<400E2Ph201D93@8050P<00T05@T=01H:3P0B
1PX040@801<72`0A1@T040@801@8300@1@T00P0B1`/200l4200>01872`0K41@05@X>00L0000B1`/0
CT=701462P0J3a<01`0001hC5`0i;S806a0D00l4200@1@T201H;3`0301052@0?10P04@H:00804@H:
01`040D900h31`0@1@T0714E00T00P0700007Q<G0597B`0P5AT03@@8010:3P0?1P/060hC00P00`0A
10/02`4501L:4@0G318050X@00H00P0F41@04P`?00X41P0400005@lC00h93@0B3A402`H:0P0=1`T0
100>1`L03`H700l71@0@1PL501052@0602DJ7P0@1@T04`P<00X00`0?10P050T=0P0A1PX300l42003
01462P0D2@d04PL;008050T=00<04PL;01P=4@0A1PX00P0@1@T01P0B1`/04`P<01872`0D2@d04`P<
01872`804@H:00<04PL<01463P0A1@l00P0A1Ph0200A1Pd04@H<01<83P0H3A804PL;00h31`0?10P0
3P<71P0A1P`601873ACooooo000Kooooo`0U00h31`0G31004@H:01872`0G3100304501462P0B20/0
6a0D01D<3P0?10P04`X=01<:3`0>20`05a4E01TC5`0B31004@/?01D?4`0A2`l030L:02LQ9@0O6Ad0
30H801H;3@090@407Q@E00d4100C2@X04@L801882@0;0@8030830147200B20T04`T:01@:2`0201D;
30030516A`0a9bP06Q0A00805@/<00L050X;01882@0C2@X05@/<01H;3`0C20`04PT;0080714E00@0
200101@93@0C20`03`@80P0C20`04P0G30l05`d>01<92P0C2@X050X;01H<3@0A20P05@/<01@:2`0C
2@X05`d>01@:2`0E2``04`T:0147200E2``05`d>01H<3@<04`T:00@050X;01D;300E2``05@`>0P0F
41808`0@2P`03@L900h82P0@2P`05@lA01H@4P0H4Q@05@lA010:300A2`d040X<01D?4@0?2@/05@lA
01LA4`0B30h05Q0B01<=3`0F41806A<E03Pb=00G4a@06aLH01@@4@0F4Q<06QHG01dI6P0G4a@04Ph?
01HB4`0C3a0061@E01TE5P0E4A805Q8C00<05a<D03L05a8F01PC5`0E41@071LM00h93`0P6b408A`S
018?600F4a`061DL01DB6@0G51X05aDJ01@B5`0K6Ad0518E01XH6`0I5aT061HG01HF600J6Q`07AdO
01lO8@0M7R406a`P020Q9P0O8BH082<X01lR:@0M8BP08bL`02L[=`0Q93<07R4`02H/>P0N93807bDc
01hV<`0U;CX0?DEB02La?@0U;c/08bdi024]>@1KIg<0;SY602/g@`0T<3`0:SI202hjAP0W<cl08Bdi
04IBGP10C5P0930l00<09cE000L0:SQ302`jA@0]>dH0:SQ302`jA@0[>D@0?D]F0080>DMB0P0fAe40
2`0jBeD0=4E?03I6DP0a@Dd0=dMD03U9E@0fAe40>4UC03I7D@0`@D/0<D==0080;d5;00`0<49<03A7
CP0iC5<0=dY@03I9C`0dAd`0;T550395B@0gBDl0<T=;02hoA`0dADd203]<E01O03I7C`0b@d/0=dQ@
03Q9D@0jBe<0>4UA02hoA@0eAdT0>D]=0312A00cADL0>de?06eoP@0hBT`09cTk02i0@P0/?T00:S`n
02hn@P0hAd`0;ci303I5BP0X=c`0>TU>030oA00eA4T0;Se203=2A`0`?d@0?4eA02`oA@0`ADX0:Ca2
03A7C@0]@4H0<D9902dnA@0[?4<0:cY102hmA00a@4L0=T=;030oA00d@dP0<3m402dl@@0`?d@0:CHl
02Xe>`0Y=3X09c8h02/d>`0/=C`09Blf02Hb>@0P;CD0;3U202dlA00^?4H0<T1;02`lB@0^?T/0<45?
0352D@0_@500:ca>02/jC@0Z>DX0;CY902lmBP0]>T<09c8i02hg?@0Y<CL09B`c02T^=`0Z;SP08RHa
02P^>P0/<Cd0:2`h02HX=@0S93406a/W02<S<00S92l06ahW024V;@0R:2h082D[02HY<00O7bL07QhV
024Q:@0O7bL00P0K6b<01`0L72@06QXR01PH800K6b<07b0U01LH7@0J6al00P0K72000`0M7R<07b0U
01dM9@02024Q:@0C01lO:@0M7BL07AdV01hQ9P0Z;C806QhR01lR9`0J7B806QdQ01TM8@0J7B8071lS
01LJ7`0J7B808RD[01hN9`0L72H06a/U01XJ900201TI8`0I01lO:@0L72H06a/U01LG8@0D51h05ADO
01XH8`0F51l0928]028Q:@0K6R807A`S01dL8P0J6Ah0<c8g03`k@00R8BH061LN01`J9@0K6B@0:BLb
02<Q;00O7BP06ALR01XH8`0201PF8@805aDP00T06QLQ014>5`0R7bP0:RL`0<C1bP38aLh0924Z01XG
800H5Ah00P0I5Ql06@0G51d05A8M01HB800I5B<061@Q02@Q;00<2A8061DM01`I800N7200518E014?
4P0G5AL06QDK01HA600D3aH06QDL01`G7P0H4aX050lF01HA600E41L05Q4H01`G7P0K5Qd0100E41H0
200F4AL05a8H01LB600J5A/06A@J01D@5P0F4AL050lE0P0D3Q801P0C3A404@/?01@>4P0D3Q804`dA
01@>4P805Q0D00L05@lC01<=4@0F41@050hB01H@500E3a<04P`@00805@lC00X04P`@014;3`0C3A40
5@lC01<=4@0C3Q405Q0D01<=4@0<1PX05@lC0P0B310201H@508050hB00d05a4E018<3P0F41804`d?
018<3P0C3@l05@lA01TC5@0@2P`04@/=00l92`0F41805a4C00@04P`@0P0C3A4201@>4P0@014;3`0O
6Ad040X>00`73@0A41X05AHP010?600>31<04a4E01XG6P0E41@04P/B0109400A1a0040HA00l640<0
40/A00h04@`B018=4`0B3A<03PT?01@?5@0C3Q@04PdC01TD6P0?2Q005@hF01L@600>1`l04@XB01D>
5P804``D00L04P/C01@=5@0G41P0614I01H@5`0E41L05Q4H00<05a8I00<05Q4H01D@5`0F4AP00P0H
4aX0200G4QT05a@K01@A600O72<0514H028O9P0=2Q406aPO0`0H5A`201HC6P0401PF700J61d06ALL
01HD6@805aDJ01L04Q0E01dK800S8BH08R0U08V7S00a;c@0;RT]020K7`0D3a<04@`@00h93@0B3A40
3PT=01HA5@0E41@030L;00h93@0@2`l02`D7018<3P0V828050h@018<3P0200h82P0M010:300C3@l0
4P`>010:300A2`d03`D601H<3@0D2P/04@L801D;300@1PL04PP901D;300E3@d0:R0Q02HM7@0H3Pl0
3@D501<:2`0?1PL06Q0A01071`0G3@h03`D601@:2`0=0`@04PT902XP8@0C2@X00P0A1PX07P0@1@T0
3`@801462P0B1`/04@H:02`Q9@0E2Ph03P@701462P0@1@T04`P<01P=4@0A1PX040H901<8300A1PX0
5P/?01462P0F2`l04@H:01@93@0>0`L040@801<72`0A1@T03P8601452@0E2@d05PX>010420804@D9
00l04PH:01H:3P0E2Ph03`@801@93@0A1PX040D901T>4P0=0`H03@86028I6`0B2@/0AS/o01/@500?
1@P00P0B1`/01`0E2`h040L901<8300A1PX050T=01<8300A1PX00P0C20`0500A1PX04PL;01052@0?
10P04@H:01472P0;0P@060dA00l4200I3Q80200100l62P0@2Ph02`@701<93`0<0`L050L>01<73@0@
0`X03@@80P0B2@h03P0?2Pd03`T=01HA5P060PH04@dD014?5@0B41L03@/B00d9400>2@h040T;0148
2@0B1`L04@H81@0?10P01@0@1`T04@P:01L<400A1PX0308500804@H:100@1@T0100A1PX030<501H;
3`0H3A4200h41`0:00l4200B1`/04@H:01462P0C20`050T=01<8300B1`/04`P<01@93@804`P<00<0
4@H;01873`0B1Q000P0A1Ph0200A1Pd04@H<01<83P0H3A8050T=01872`0D2@d04PL;1P0@1@/60146
31Cooooo000Kooooo`0=01L<400U6Qh05``@00l4200G310050T=00L0000I3Q801`0001462P0D2@d0
3@@700d42@0201LA5@0D018<400>20`02`D901@>4P0;1@T05Q0D02@N8P0;1@T040X<0106200i;c00
DdU:01H<3@0B20T06@l@00X10P0F30d0718C01<92P0?1@H301H<3@0404<i>P3Ugn00WYBE02TO8080
50X;01404PP901061`0B20T050X;01D:3P0<0@D06PlC01H;3`0;00@04`P<01052@0D2@d04`P<0187
2`0?10P06@hA01H<3@0201D;300801H<3@0D2P/06Q0A01@:2`0B20T05`d>00h41@0@1PL201@:2`05
01D;300C2@X04@L801882@0C2@X00P0B20T201<92P0601@:2`0F3@l06A<E01PB500A2`d05@lA0P0I
4aD02@0F41804P`>01TC5@0@2P`04@/=01TD5P0?2``04`l@00X61`0200h:2`0;00/7200<20T02`L8
01XF5`0H51D03`/<00d92P0F4Q<04Ph?01`H6@050@800P0@30d0200D41407ATJ01<?400F4Q<05a<D
01<?400D41405Q8C0P0G4a@05@0G4QH07aXN018=4@0L5ad08ahT04I1A`11?4<03``E018?600F4a`0
4a0G018?5P0G51/09R@Y02PV:`0K6Ah071XM01LE600E4aH07AdO01/K7@0201TI6`0G01XK7P0K7200
6a`Q01/M8P0N8BH071lV01hR:00X;3D051PT02DX=`0Q93<07R@b01/Q;`0V;3X06B4^02<[>00oAe@0
82Xf02@^>P0N:3@09S8n02lkA`0M:CD00P0/>4@07`0R;SX08Bdi02Pd@00Z=T80:cM302Lc?`0/>4@0
9C<n02Hd?`0W=D00:cU402dkAP0_?DP0:3I102Xh@`0U<ch0=D=>034oBP0_?DP0=dQB0352C00dADl0
=dQ@03i?E`0eATh0>DYC03e>EP0gB500=DI@041AF`16Ef400P0bA4h01`0_@D/0<49<03I9D00iC5<0
=DQ>0354BP0gBTl00P0iC5003`0hBU00=4E=03E6CP11DUX0AEIN03i?E`0eATh0?4eE03e>EP0iBU80
=TM?0393B`0a@dP0:ce103M9C@020394B00K02do@`0[?D40:C/o02Pj?P0[?D40<49602do@`0/?440
=4=802Dd>@0d@dP09C@i03A3B00fADX0<d9702/j?`0d@dP0>4M<04aLH@0Z?D<0<dQ=02m2B00lCeD0
:Ca202m0A`0[?4<0;3e400<0<3m602X0<Ci602He>P0Z>Ch0;Ca102/j?`0Z>Ch0:CHl02Ha=`0W<SP0
8bhd02@]=00Y<ST09Blg02Pe?P0^?4L0AE=N03m=F00c@Dh0;Si;02De@P0/?4T0<49>02PlA`0W>TP0
<dED02hmD00Z>T/0:SY902dkB00Y=Ch08bhd028[<00T;3408bP^02LZ<@0[;SH08RHa01/Q;@0Z;c`0
9b/g01lQ;@0P7b/202<Q;00802HV<00J7B@09R/a020V;00K8RP092L/020Q9P0L7B8201lP9@0;01PI
7P0F5a`06AXO01LH7@0D5AX05QLL01/L8@0F5a/06Q/O01/L800I6Qh00P0H6Ah0600S8b/09bL_02LW
;`0Q8B/071`V01XJ900T9bh0?T5802LZ<@0R9B`06A`S01hQ:00L7bH06ahU01XM900G6R407b8Y02X]
=00N7RP07AdW01`L9P0K6bD06ATS01PH8P806ATS00`05aLQ01HF800F5R005ADO01dK9P0K6B@07A/V
01TH800P7bL06QTP01dL8P0F5AX200l>4`0701<B5`0J6B005A<N00l=600^;3L0;2Xe02d[=P0201LE
800M01PF8@0I5b806ALR01TG8P0K6B<03@XA02<P9`0G51/08b0W028O9P0J5ah061DL01LD6`0H5A`0
6AHM01LD6`0G51l07QXY01dI:00F4R000@0902h[=00F4a/061DL01HD600E4aH0518C014?4@0D3aD0
0`0E41L01P0F4AP061<J01<>5@0F4AP050lF014<4`8050lF00L04@`B01<>500F4AL05a8H01HA5`0E
41H03`X@00805A0F00<04@`B01<>500C3Q@00P0F41@0100I4aL06Q@H01PB5P0F41@601@>4P0401XD
600D3Q8050hB01D?4`804@/?01h05@lC018<400A2`l04`dA01@>4P0B31007aTM01H@500E3a<0:28V
00/62@0N61`05@lC01<=4@0@2Ph03`T=01<=4@0G4AD04P`>00`6200H4Q@07aTK00h82P0Y8bD03`T;
01H@4P0G4A<04@/=00P2100B30h7018<400B01D?4`0C3A40:B<W01hH700H4QH04@`C01<>500D3aD0
4@`?01PD5@0@2P`03@L9018<400B2a8040TA01<;5P0G3aX03`XA0P0@2a43014<4P0>018=4`0F4AL0
5Q4G014<4P0E41H030L=0148400B21006@lG01P>5P0O5Ad04@L?01@:4P0F31@201/A6@0401P>5P0C
3A@04`hD01@?5@805Q4G00<05A0F01HA5`0G4QP00P0F4AL201D@5P0>01HB600D4QL07adR01@B5`0Q
7b@04a4F01XH7@0G5AX05Q@I01XH7@0K6Ah06ALL01LE6P0F51T201DC600:01@B5`0F51T05A<H014?
500o?D801`D:04a:C`0M6b0030L;00d830804@`@00<03PT=014<400A31000P0D3a<0200A31004PdA
01<>4P0F41802P@6010:300?2@/020840P0C3@l04@0B30h040X<00h82P0A2`d0618D024G600D2P/0
4`X:00L0000D2P/05P`=01hD5@0@1`P07A<D06ILG@0H3Pl01`0000<05P`=00X03P@500h51P0L4Q<0
3@<401D;300I3a002`4200d3100@1PL04PL;0`0A1PX0;@0B1`/04`P<020E6@0T6Ad02P0301872`0D
2@d03@8601@93@0700005@X>02@I7@0<0`D06@hB01P=4@0:00<04@H:01052@0C20`03`@801862P0H
31005`/?01@8300I3A407Q8F01lC5`0>0PH040@801D93@0B1PX04@D901P=4@0?10P04PL;01052@0?
10P05P/?01/@500Z7b<0IU]O01L<400700006PlC01892`0200`11@0701<:300E2Ph0304501872`0A
1PX040D901462P0201@93@804PL;00@04@H:00l4200A1PX06@hB0P0?10P0500B1`/07a@H01P=4@1?
ATX0FeEI01`C600=0`P04@H<01T<4`0C1Pd05PT@01X?5@0<10P0DDQ=018<400R72403`XA00d83`0E
4Q`0BTQC0P11?dX01P0=2Q<03`XA01493P0B20T04PH8014520D03`@800D02@0201@93@0=0`H05@X>
00d21P0701052@0701462P0O51P08QLK01D:3P0D2@d04@H:01052@0200l4200501462P0B1`/04@H:
00l4200@1@T00P0B1`/01`0@1@T03P<801873`0B1Q004PL?01463P0@1@`00P0@1@/01@0C20d040D9
01462P0E2Ph04PL;00H04PL=1P0@1@/Dooooo`006oooool0:P0B1`/0714E01872`0<0@D04`P<01H;
3`0?10P04`P<00l4200U6Qh03P<701@;3P0C2Pl06A<G01D?4`0?2@d04`dA01TC5`0:10P06Q@H00D0
0`0;1@T0208601D?4`0A1`T0<RPY04Hl?@0G3@h040H701L=3P0J41402P0100`20`0?1@H04`T:01X@
4@0G3@h05P`=03T_<039_l00QWam01D;308050X;00X04`T:0147200B20T04`T:01882`0=0PH02@02
00l6200C20`060dA0P0@1@T0100K41@05@X>00l4200D2P`201@:2`0@01L=3P0F30d04`T:01@:2`0=
0`@04@L801<92P0:00404PP901H<3@0G3@h06@l@01D;300A1`P050X;01D;30804PP901T04`T:01@:
2`0D2P/06a8D028L7P0S7Al06aDG010:300?2@/03PP:01<=3`0J51H0618D018<3P0>20X03PT:010<
3@0E4A804Ph?01XF5`0O6a`0;2PY02dY:P0L61T0510A008030P900`05Q8C01/G600E4A8071PI00P4
1@0I5AH0510A01/G600T8240510A01HB4`0E4A8201@@4@<05a<D01D05a8F010;3`0>2@d05Q4G014<
4P0T7bD0:2<Z01<@6@0E4Q/06QLP01LD6`0D4AP071TP028P9@0V92T06QPM01dK7P0H5QT05aDH01lO
8@0L71h00P0G5aT0900I6Qd071dQ01/L8@0L7R<07R4V01/N9@0L82L0:2`e01dQ;@0S9SD082<b02@Z
>00Q9cD0:Blm01hV<`0P:3D09Bdj01HP;00N:3@092hj028^>P0K9c<07BTe02Pd@00/>4@09C4m02<_
>`0X=400:CE102Hb?P0P;3P0;CU502Pf@@0Y=d80:SQ302/iA080:SQ301@0:3I103a:E@0^?4L0:SQ3
02dkAP0gAE00<D9<02dnB00^?dT0=4E=03i?E`0eATh0?4eE03Y;D`0fAdl0=TMA04iOJ@1SM7h0=4I@
03I8DP80<D==00P0=TU@03Q;DP0aA4X0;D1603I9CP0iC500=dY>03M9C`80=DI>00D0>T]C03i?E`0l
CED0>T]C03a=E@0203A5C@0k0311B@0]?TH0=dQ?02do@`0cADT0:C/o03=5B@14EUX0<49602i0A00_
@DD0:C/o02m1A@0a@dL0<D56030oA00Z>Ch0;ci30350A@0[>Sl0<d9703A3B00a@4D0>4M<03=2A`0j
BTl0>4]A03I;D00aA4X0>4]A02Lj@00nCeH0:ca302dnA@0b@DP0<3m602hmA00_?4@0>TU>0391AP0_
?T<0;3]002Dd>@0V<cT09S4g02Xe>`0V<CL08b`c02Tb>@0X<CT0;c]703M5DP15DV40=dEB03A2C`0^
?T/093A102/kB00_@Dd00P0V>TD08P0dB5@0<d=C02hmC`0[>dX0;C]802Xf?`0U<3H08b`a02P^=00R
9bd092L^02/^=P0S9c807B<_02/a?P0X;3P08B4]028Q;00X9S409bD`03/jA00Y;3<0:bhe01/R:00V
;C<08B@Y020Q9P0K72407AhS01lP9@0I6Ql06Q/P01`M8P0K724301TJ7`0401XK7`0M7R807AhR01XK
7`806Q/P01809RH^02TY<@0W9bl08B4[01XJ900I6B<04QDL02DX;`0L7bH06QdT01/N9@0N8BP06ahU
01TL8`0J7B@061/R01`O9P0U:2l301dM9`0M01`L9P0J6R@06ATS01LG8@0H62805QHP01PH8P0I6B<0
5QHP028P:`0E4ah071XU01PG7`0R8BT051<J01`K8@0M72408b8W020O900G5Q/05A@K024O:P0@3QT0
61HQ00h<5`0N72L05A<N01HD7`0H5R400`0I5b80:@0E4a/061DL024N9@0K61l0:2D/00X73P0N6b80
5a@K01HC6P0H5A`06AHM01LD6`0J5R800@0<01hJ:@0/:3L0;R/f0;Fb_@18ADd05A<H018@500E4a@0
5Q@E010>400E41H05a8I01TD6`0G4QT05Q4H01TD6`0E41L06A@K01LB6@0B3A@050lF01D@5`0A3180
4`hD01HA5`0G4QP05Q4G008050lE0P0I51X2018=4`0701<>500E3a<050hB01TC5`0K5AT05a4E01D?
4`0601@>4P0301PB5P0A2`l04@/?00804P`@02005@lC01H@500C3A404P`@01<=4@0D3Q804P`@00d7
2`0G4AD07ALK00X4200D3Q804P`@020J7P0J51P04P`@010:3P0A2`l04`dA01TC5@0D3Q008A/M034[
;@0M5aT0>S@f02DO8@0@2P`030H801hH6P0K5AL06Q@F01<=4@<04P`@0P0A2`l0500C3A4040X>00l9
3@0J51P040X>014;3`0I41D060lD014;3@0;10D03`T900P20P0A2`d050hB018;4P0>1Q004@TF01D=
600B3A@04PdC0P0C3Q@201@?5@06014<4P0C3Q@05Q4G014<4P0F4AL040/A0P0D2Q801P0G3AD02`49
01X@600G3AD05@/C01L=5@806a4I00@05`dE01@;4`0C3Q@050lE0P0E41H01P0D3aD05Q4G01LB600F
4AL05A0F01@?5@805A0F00H04Q0E01HD6@0A3a@0518G01`J7`0A3a@201@B5`0?01LE6P0H5Q/05aDJ
01HD6@0C4AH04Q0E01@B5`0B41D05A<H010>4`0100@03P`A028P9@0O7B805A<H00804@`@00@04PdA
014<400@2`l040/?0P0A3100:P0@2`l04PdA01<>4P0A31007QPJ00`6200?2@/06Q@F01<=3`0L5QP0
5Q0B01D?4@0A2`d040X<01D?4@0O6A/0:AlP01P>3`0D2P/0308301<92P0D2P/03`D601T?400@1PL0
5`d>00T10@0R61T04PP900`30`0@1PL0=R`]01T?4007000060h?01061`0L4Q<05`d>01T?400L4Q<0
50T=01<830804PL;0P0C20`02@0P5AT03`@801462P0D2@d02@0201P=4@070000=BX^01T>4P020105
2@0501T>4P0d:Bd05@X>00h31`0<0@D00P0C20`0400B1PX05PX>01H:3P0E2@d06@dA01dA5@0P51P0
3`<70104200E2@d04PH:0104200E2Ph03`@800d21P0>0`L201052@0@00T00P0H3A409a`P01@93@07
00005``@01<8300;00@050T=01T@4P07000050T=01872`0@1@T03`@801052@<04PL;02<04`P<0146
2P0@1@T04PL;00h51`0<0@D06PlC00`21@0700004`P<07A[K`24OX80;2<X00P00`0>0`T070lF0144
2`0?0PT040D;02<I7P38_l@0NWAh03/e?00300L00P0805QFHP3hn?l0NGV501/J9P0=2aH03@XC0108
3P0A1PX04`@70145200501052@0801X?4`0X7B403P<701P=4@0=0PH03`D800l4200@1@T201462P80
40D900L0200101872`0G31004@H:00l4200<0@D040D900803`@800<04@H:01872`0A1PX0100@1@T0
3P0?10P03P<801<8400C1a404PL?01463P0@1@`03`@:01<83P0D2@h03`@801052@0B1`/03045300B
1`dDooooo`006oooool03P0C20`03P<701062P0D2@d04PP<00h4200C20`04`T<02/Q9@1@ADT04PT<
01@;3`0?1`d030D<0P0>1`h06`0=1Pd040T@00`5300E3QD03PP=030Z;`0E3a@03@L;01882P0;0@<0
4`T:01<92`0@1PP050X;03<Y:P0>10H03`D601D;3@0B1`X04PP90147200H3Pl050X;02dS900V71d0
4@L801D;300201L=3P0L01@:2`0C2@X04`T:01@93@0A1PX06PlC01L=400>0`L091TM03X_<`0=0PH0
714E01872`0F2`l050X<01482@0A1`P050X;01D<3@0E2``040H7028H6@0d:R/04`T:00`20`0I3a00
4`T:01@;308050X;00@050/<01<92P0C2@X04`T:0P0D2P/0:00D2``05@/<01<;3@0?2@`050hA01LB
5@0>20/05A4D02hZ;@0C3a4050lB01lI700A2`h06A<F020K7@0M6AX05Q8C01@@4@0Q7Ah0:2@U01<?
400I5AH04Ph?01HB500F4A@05A0C01HB4`0C3a0040`=01DA4P0?2``06ADF01<?400F4Q<06ADF014=
3P0K5aP061@E01DA4P0F4Q<301LC500301HA5@0D3a<06A@H008061<I00h06QDK01dH7`0G51`06AHN
020M9@0L6B405a@K028O9@0F51T07A/P01LE6P0M6ah06aTL01/J70<06ATK01l06QXL01/L7`0K7B40
8bDY02<V:`0Q9BT06QhT01TN900T:S808BHb01lS<P0P9C809B/h01dS;`0Y<C`08BXe02@]>00E7BT0
92hi01lY=00W<Cd08Bdi02Lc?`0R;SX0:CE102Hb?P0R;ST09c@n02Tf@00L:C<0;3Q30080:SM100T0
9cE002`jA@0_?DP0<Cm:02hlA`0/>TD0<3i903e;EP0_?DP00P0b@4/0:`0c@dd0;3e702hoA`0_@4P0
<T=;03]<D`0_@4L0=dQ?0393B`0kC5<0<T=:03=4C@15EUl0=dUB03a>F00fB580<dE>03I9D00fBDl0
<TE;03I9C`0jCE40=4M;03=6BP0bA4X0<dA<03Q9D@0gB4l0<dA;03E6CP0jBe<0=TM?0352BP1<GFD0
AEIN02hoA`0eATh0>deA02do@`0fB4`0;T1402<e>@0]?d<00P0Z?4008P0`@TH0:ce102`n@P0cA4P0
<T5603]:C`0^?D80HG1e03I5BP0`?d@0=DA90350A@0eA4T0;3]00352AP0`@dP093Pl0354B@0iBe00
<DA905Y/L@0]?T@0;T15030oA@0]?4<0;Ca203=0A`1WMW/0@E1E02Xi?P0_?T<08c8g02Db>00W<SP2
03<nA00e02Pb>00Z=3/0:C8j02PeA00_?Th0=dIF02`lC00mCE`09cM602LiAP0Y>dL0;Cm;02e0B`0]
@4X0;T5;0392DP0[>d/0:3M502XhA00[=cl0:C<i02<[<@0V:c006AdQ01/N9@0^;cL0;S4j02@Y=@0W
;3T092Pc02DV<P0];3L0;R`e02LU;P0`<3P07R4W02lc>@0N92/06b8X01`O900R8bP071dR01/L8@0P
8BH071dR01hO900M7R<07QlT01lP9@0K724051DJ01TJ7P0K72400P0K72005P0M7R<07alV024Q:@0S
8b/08B4Y01`L9P0H62805aPR02X^=P0D62406QlV01/N9`0P8b`05Q/R01/O9`0M82T08RH^01lS:`0I
72D06QdU01`L9@0M7BL201hN9`0K01`L9P0K6b@06a/U01dM9`0H62406QXT01`L9P0H6280:bTd01dK
9P0E4ah061LO01DD700G5Qd06aXP01HE6`0H5ad06QTN01LF6`0O7RD0@D1901dK9P0K6B@05aDP028P
:`0F51l06ALR00806QPS01/061HQ01HD7`0F51d06QHM01dH800f<CT0HEeT01/E7P0I5A`061@K01PB
6`0I51`06QHM01XE7@0J5R80510P01XF900H52405a@O04U6D00O72@05Q<I01DC5`0E4aD0518D01@B
4`0H4aT00P0F4AP0300J5A`06A@K01<>5@0C3QD061<J01LB6@0B3A@05A0G01LB6@0G4QP05Q4G01@?
5@804`hD00@05A0F01HA5`0L5ad07APN0P0D3aD01P0E41H05a0F018<4@0D3Q<05Q0E018<40805@lC
0P0D3Q801@0C3A4050hB01D?4`0E3a<04P`@00<050hB00@06aDI01H@500C3A404P`@0P0C3A406@0A
2`l06Q@I05eGG@13?D804@XA01H?5@0A2a003`P?014:4@0E3Q@05PlF01D>500A2`l03@L:01H@4P0<
1PP07aTK018<3P0G4A<05@lA020J700`:R`0>C<e01PB500>20X00P0C3A42018<40804@/?01D05Q0D
00d72`0B31003`T=00`72P0O5Q/060d@01D:3P0@1`P050/;01<;2P0E30`05@`>014;3`0C31<05@hG
01<;5`0@2A804@`C014<4P0B3A<0100C3Q@04`0A31804`hD00`73@0A31803@L>01T@600>1@d06a4I
00`42`0D2Q806Q4I01T@600G3AD05PdE01L?5@0H3aD05@dD01<<4`0D3A@01@0E3QD08P0D3A@05@hE
01L@5`0H4AP0618I01PC6@0F4AL08QdS01/F7016@DL06A@J01PC6@0G4QP05A0F01@?5@0E41H05a<I
018@500A3a@05A<H014?4`0E4aL040hC01TG6`0D4QL03@/@00h<400@3Q805Q4E01<>4P0F4AD08QdQ
02<N8P0A310201@?4`0:01D@500A31003PT=00l:3P0B30h03`T;018<3P0<1PP05@lA01<=3`803PP:
00T03`T;014;3@0E3a407QPJ0147200J414050X;00l51P0D2P/00P0@1PL0;00A20T05`d>00T00@0G
3@h04PP901061`0E2``050X;0516A`0Y7b0091XK01H<3@0D2P/03`D600X10P0P5QL09Q`M01H;3P0D
2@d04PP:01872`0A1PX04@L901872`0C2@`04@L901462P0R61/04PL;01482P15>Sh05@`>00`31@0C
20`05``@03L/<00F2`l04`P<01462P0C20`04@H:01@8300B1PX04@D90P0B1PX01`0A1@T05PX>01<7
2`0C1`/040@801452@0G2`l00P0C20`04@0<0@D05@X>01`A5@0B1`/050X=01882`0<0PD04PL;00h3
1`0@1@T050/=01<8300P5AT0A3Tm01072@0F2`l04@H:00803`@800<040D900l4200@1@T00P0C20`0
8P0A1PX040D901872`0E2Ph0308501052@0E2Ph03@8601P=4@0M4aL07QHK00/31`0C2@l040H;01H9
400@10X05`XA01<:3P0B2@h08a/O01@<4@0;1@/071HO00X7400/:3D0S8^G03XiAP0<31P03@XF00h9
4`0@1`h040D901441`0A1PT501872`0C030W:@10=CT04PL;01L<400;0P@05@X>00l4200?1@L04@L:
01872`0A1`T03`@801@93@0B20X06@hA01X?4`0A1`T040D901872`0201462P0E01<8300D2@d04`P<
01<8300B1`/040D900l4200@1@T04@H;01<8400C21404PL?01463P0@1@`03`@:01873@0B1``03`@8
01872`0E2Ph03`@900D040H<1`0A1P`Dooooo`006oooool0S00?1PT04@X<018<3P0C2Pd03`P:00/5
1`0G3Q403@D800H00P0>1@P05@d@014;3`0<1@d03PL?01094@0F3aL030D=01D>5@0E3a<03`T=00/5
1`0J51H07aTI01LA4@0G310060dC00`11@0C20d02@0402/P900D2@h04@H<01H;3`0E2Pl03`@:00l4
200B1`/040D901462P0G31007a@H01@93@0?1PP050T=01<8300H3A409a`P02PM8@0G31003`@801@9
3@0A1PX081DI01872`0E2Ph04PL;01<8300H3A405P/?01<9300@2P`04`X=018;3@0A2`d050/>018:
3@0B30h05Pd@018;3@0>20X04PT<01<;300A30T050`:010:1`0?2PL05@d;01D?300A30T04`/901<=
2P0C3P/05@d;01D>4P0=20l0514H01@C6@092Pl0;2ld0<74b@0i?440:R/`08:1Q`0H5A`01`8902PS
:00F4Q<040`=00h:2`0G4a@061<G01LB5P0<1`/06A@H03dh?P0L5ad06aHL00d;3P0E4a@03`d>018@
4@0C4A8040h?00X82@0K6AX04Q0A01LE5P0F51D05aDF018@4`0D4QD05aDH01DC5P0D4QD05Q@G01<A
500F51L06ALJ01PF6@0G5AP061HI01DC5P0E5AD05aLG01DE5`0F5QP061PJ01DE5`0H61/06QTN0P0K
6Ql06P0J6Q`05QPG01XM700H71/07R0O02@X:00N92@06AlO01`Q900K8bD06B4S01`T9`0P:Bh0624Z
01lW<@0R:c8082T^01hX:P0N:B/07BPZ020[;@0P:bl07BP^01hX<@0S;CT09S900P0R;S`0:P0W<cl0
:SM102Tf?P0Q;SD082dc020^<@0S<C<09cDf02Pf>@0W=ch09CHn02dnB00X>4@0;3a903A4D@0]?D/0
;Ce:02`mA`0[?4D0;Sm70311B@0/?TD0;3m60354B`0_@TP0<4=903I9C@0hBdh0<TI703I:B`0gBdX0
<TI503=7B00hBe80Zkk503iAF00cATd0@EAJ03=6BP0fBDd0>Da@0396A`80:cm00P0fBT/0=00gBd`0
>4]>03E8C00bADT0<dI<03E8CP0mD5L0Ffef04aNJ00bA4h0;T1703e?D`0W>Cd0;T140394B00V>3`0
<49602Hh?00^@4@09CLk02`n@P0^@4@0?e1F02`mA00]?TD0=dQ?03=4B`0eATd0;3e403E6C@0W>3l0
@eAK02dnA@0dAD/0:C/k02e0?P0dATH0>DU903E5A@0_?T40:cXm03M6B@0Z>C`08c8g0350@`0a@4@0
>DM:028`<`0/>Sd0:CLj01l]<00Y=cX202/i?00U02/h?P0W=3`0=dA<02Td?P0b@U8093E703=4EP0m
CV008S=30352DP0_?dl0:c]:02`lB`0^?Td0:c]802XkAP0gAE00<Cm802Pe?@0R;cD09Ble02/c=P0W
;c808RH[02@T;00K6bD0928]02PX=00O8Bd0:2`g02<W<00M8BX08B@[02<V;@0T9bh092L/024V:@02
01lT:003024V:P0L82<0720S008092P[00X06alS01/N8`0O8RT092L^01PK8P0C5Qd05aXR010C6P0J
7B@07B0W0P0P8bX0@`0L7bH06QdV01DH8@0G6R<061/T01LJ8`0E62404aHO02/^=00U9Bd07R4V01/L
8`0K6b<06A`Q020Q:00V9Rh082<X01DG7@0P82P071dR01`L8`0N7RH07AhS01/L8P0O7bL08R<X01/K
8P0F5Qh06Q/P01XJ8@0I6B407alW01lO:@0K6bD07alY01HF800?3aT06ATS014A6@0J6R808b<[024Q
:@0E5Ad06QTQ01`K8@0M72@061LO01DD700F5Ad08R0Z01hL9`0G5B006aTU01TG900E4b005aDP01TH
800H5B005Q@N01`K8`0O72L061HP00/:4P0O72L081hW065PJ00F4ah00P0G51d00`0F4a`05A8K01DB
6`0201DB6@0C01@A600G5A/0518G014?500D4QL06aHM010;4P0B3A@03@P?01D@5`0I51/04`hE00d8
3`0M61l03`XA00<01@0B3A@03@P>01<>5002014<4P0E01D@5P0Q72804@`B01<>500F4AL05a8H01D@
5P0C3Q@061<J00/63@0=20l05a8I010;4@0A31<03`X@010;4@0C3Q8050lC01<>4P0A31004P`@0080
3`T=01d04`dA01H@500D3Q805Q0D01@>4P0B31004@/?018<400C3A4040/?01PD5P0C3a003`X>01<?
4@0B3Pl05a8F01XF600K5aP06A@H01<>4@0=20`03@L;01@>4P0C3A405Q0D01TC5`0B31004@/?01@>
4P0201LA5@0P01@>4P0A2`l040X>014;3`0B310050hB01H@500G4AD04`dA00/52@0I4aL040X>03Tc
=`36`<@091/O01H=4P0>20X03`P:010:300?2@/05Q4C01PB5P0:10P071DL00D01@0J4aX04@/?00h8
300=1`/040X>01@>4P0G4AD5014;3`0=014:4@0L5B006A4L018;5@0>2A004@XB01PB6@0C3Q@07ALK
01@>4P0/:2T06aDG01@>4@05018<400501@>4P0G4AD0618F01PB5P0F41@00P0D3Q801P0F4AD061<G
01/F6P0J5AT06A@H01D@50805a8F03<050lC01XE6@0K5QX05Q4E01DA4P0E41@05Q8D01LC500G4aD0
71LK01DA4P0C3Q405A0D01<?400F4Q@03`T;010:300C3@l050h@01<=3`0B30h05@lA00X41P0D3Q00
3PP:01PB500B30h08A/M00@0000n>3X05a4C010:300H4Q@05@lA018<3P0?2@/04P`>01XD5P0V8280
5@/<01H<3@0?1@H03@<401D;300G3@h03`D601<92P070000718C01061`0K4A800P0C2@X201882@80
4@L803<040H700/20`0?1@H07aDF01@:2`0H3Pl06@l@00h4100G3@`04`T:01H<3011=cH0AC/l01<9
2@0G3@`05P`=01D;2`0>10D06@hB00l4200C20`0304500d21P0<0@D060dA01872`0M4QH0Bd1401hC
5`0<0@D03P<701052@0F2`l05@X>01462P0D2@d06PlC01D:3P0J3a<03`H801`A5@0700003`@80187
2`0M4QH03PD700d21P0D2@d040L901T>4P0?10P00`0D2@d07P0>0`L04@H:01462P0=0PH02`0400`1
1@0@1@T02`0401L<400J3a<0304500X00`0E2Ph04PL;00l4200D2@d040D901P=4@0J3a<050T=00d2
1P0>0`L040D900d31P0?10P04`P<01L<400C20`03P<701052@803P<700d050T=01<8300B1`/04PT=
00h52P0@1``05@/C00h73P0@2A004@XA00l53@0?1P/04@L;00804PL;00H04`P<01462P0A1PX040D9
01462P0B1`/601462P0B00d41@0D3``081TH01XA4P0@2`P03PL601T@4@0400006A8A00H0000=20D0
3`P801L<400G31805P/A01<83P0B1`d04@H<0`0B1`d02`0A1P`040D;01052`0G31803@8800l42P0E
2Q003P<901@93`0=0PP040D;00804PL=00/040D;00`3200;10/04``C00d63@0A2Q402@8800l62`0A
20d04@P<01482`0301872aCooooo000Kooooo`0O010:300A2`d04P`>018<3P0@2P`03PP:00H00P0E
3a406A<E014;3@090`D02086018;4`0E3AL040TA00l8400>1`h06Q<J00/52@0A2`h0:B<U01LA4@0:
1@801`4101P>4P0700806a0F01lD6P0B1`d03`@:01873@0301052`0J01/@5P0V6b406@hB01H;3`0G
31006@hB01462P0=0PH06PlC01H;3`07000030<5024F6P0F2`l03`@800/0100A1PX03P<701X?4`0:
00<05@X>01872`0D2@d05``@01H;3`0B2@`4010:300>014;3@0B30h040X<014;3@0F4180618D01@>
400@2P/04@`901@?300B3@X040/8018=2P0C3P/2014<2@0N018=2P0C3P/04`h;00l:3P0?2Q405a@M
018B6@082a004aPN07QoP`0Y;S802PdD020P9P040@P05@lI014<4P0<20T071PI00T51P0b;Rl03PT=
01LB5P0<1`/061<I03Pc>@0J5A/061<J00l=400H5QL040h?0P0C4A802@0@3Pl030X;01PF5`0A3a00
6QPI01TG600J61T05Q@G01DC5P0301@B5@0401<A500E4aH05A<F01PF6@806ALJ00T05aDG01@D500E
5A<05aLE01DE5@0F5QH061PH01LG6@0I6A`00`0L6b00200J6ad08B<R01dQ800G6aX06QhM01`Q8@0C
6AT0624P0P0K8bD0:P0I8b@06bDW01lX;@0I8b`07BL`01dX;00K9RP06RHV01/W9@0M:BL07RXY01hY
:`0M:2`07RTa024[=`0O:cT08Rhm02Pd@P0[=d<0:CHo028_=`0R<3@08S0c028`<@0U<c<09SDb02Hf
=@0`@4H0:CY203Y;D`0Z>TL0:3Q703Q8E`0^?Td0<41=0311B`0^?dP0;Ci502hoAP0[?TD0;D170395
C080<DA:0100=dY>03M:C@0bATL0=TY903U=B`0gBdT0>De<03A7CP1<GfH0=TU@03=6C00^@DD0>4]?
03I9C@0]@D80;d=40P0fBT/09P0hC4`0=DU803I:B@0fBTX0=4Q903=6BP0cAT/0>TeC03]>E@0eAe00
9CM102`nB00iBe80>4Y>02do@`0cADT0;3i202Pj?P0]?d<093Hj0394B00a@dL0>D]?0353A`1kSI80
MhR?03i?EP0W>3l0;Ci503Y;DP0oD5L0>DYA02Pi@00cA4/0<45802`m@`0/?3/0;Shk0P0a@D001@0_
?ch0;Cdm02`l?00]?Cd0<d950080<T5401H0;C`o03=1A00U<cH0<3i102/i?00T<SD09cDh02Pf>@0T
<SD09C8i04=@F00`?DH0:3I102dnCP0N<4@08SE603]<GP0dAEL0<45A0310D00Z>TX0:SY90P0e@U80
400fA500<T1902Pf?@0M:S007BP/02D^<P0/=3L092T]01PJ800L72@07A/V02TV<`0X9S<09bXc02/_
>00T:34201hS:@0701`Q9`0N8bL08BHY020U:00O92L082DX024V:@02020T9`809RX]00L07B4U01dP
9@0E61l06A`S01LJ8@0H6b@07B0Y00806QdV00D07R4Z024T;@0Q92d07R4Z01dP:@0401HI8P0501LJ
8`0G6R409BH[01lP9@0K72400P0I6Ql02P0J6b0092DZ00T:3`0F5a`09BH[02X[<0092Pl071dR020Q
9P0O82D201`M8P0701dN8`0L7B806AXO01`M8P0K72406AXO01hO900201TI8`0J01/K9@0G5b405ADO
01<C7@0P82X03`lI01HF800A4A/02@TC020P:00J6Al06aXP01PG7P0F5Ad061LO020N:00L6RD05aDP
01/I9@0I5b@061HS01PF8P0H5R405aDP01HD7`0I5b8201PF8@0;018@6`0J62<04@lJ03dkAP0>31L0
5Q@L01PE700G51/05Q<J01DB6@0F4aX0100G51/0500F4aX05A8I01<>5@0D3aH05a8I018=500R7B@0
5Q4H01D@5`0K5Qd040/B01dH7`0G4QT04@`C01/F700F4AL050lE01D@5P0C3Q@03PT?0P0B3A<02P0D
3aD05A0F01D@5P0B3A<05Q0J01D?6@0C3AL04@`C018=500@2a8201@?5@0<01@?4`0C3Q804PdA014<
400D3Q804@/?010:3P0C3A405@lC018<400F41@05@lC0P0C3A405P0D3Q805@lC014=3P0F4Q<04@d>
010<3@0C3a0040`=014=3P0D41405Q8C01DA4P0B3Pl03PX;00h8300C3A404@/?018<400E3a<03`T=
014;3`0C3A4201D?4`0601<=4@0A2`l050hB01<=4@0B31004`dA0P0D3Q8200`62P0F01<=4@0A2`l0
100203hh?00H4QH04@/?010:3P0B31004@/?010:3P0?2Pd01`45028L800;1@T0618F01XD600C3A40
40X>00l93@0@2Ph04P`@01<=4@D04@/?00d04@XA01D?6@0D3QX040XD00h9400A31<04@`B00d83P0J
5AT04@`@024M7P0A3@h040/=00D04P`@00<05@lC01LA5@0E3a<00P0D3Q801P0E3a<050hB01<>4P0E
41@05a8F01HA5@8050lC0P0G4QH0100D3a<06A@H01XE6@0F4Q@201DA4P805Q8C00L05a<D01HB4`0C
3a005Q8C01DA4P0@30d04`l@00804@/=0P0C3@l0400D3Q004`d?01<=3`0@2P`05@lA010:300I4aD0
4P`>00`6200V8280HE]M03D_<@0J51H04`d?018<3P0@2P`200d72@0@00l92`0D3Q00308301<92P0H
3Pl06@l@01/A4P0C2@X06a4B01P>3`0;0@806a4B00`20`0B20T050X;01<92P804PP900P04@L80106
1`0=0`@09A/L00L0000G3@h04@T901@:2`803`D40`0F30/06@0R61L06@l>00/20P0A1`H02`4000`2
0@0N51D01`0001X?4`0?10P050T=00l4200W720050T=01462P0I3Q80=b``01H;3`0E2Ph040D90146
2P0B1`/050T=01052@0=0PH00P0E2Ph03`07000040D901<8300K41@04PL;00/0100K41@05@X>0105
2@0?10P05P/?00P00@0<0@D03`@800P00@0201052@0301872`0C20`04`P<008050T=00T07a@H00L0
000K41@05`h@00X00`0C20`0304500L0000A1PX00P0?10P00`0D2`d02`0401462P0201T>4P8050T=
00X060dA00L0000=10H050T=00`11@0C20`04@H:01H;3`0N4aL060dA0P0A1PX01`0@1@T04@H:0187
2`0<0@D03@8601462P0@1@T00`0A1PX201872`804@H:00<040D901462P0B1`/01@0A1PX01@0A1`X0
2`8300l:1`0E40d04@`900<03@P500H04Pd:00l:1`0D3``04`h;014<2P0C20`301<83PD04PL=00/0
4@H<01052`0@1@/02P0501873@0c:2h0@3Dk01hC6@0800<03`@:0146300201873@0;0146300>1@X0
5@hF00X62`0J5A/02@@:01dG700>20`040L<01072`0@1`X00`0A1PXDooooo`006oooool00`0C3@l0
4P`>014;3@03014;3@804`d?00D04@/=00l92`0@2P`05Q0D014<4@02014:4P0@01<<4`0D3A@02088
014;3`0D3Q40<B/]018<300@2PX04@/<03P]<P1@AD/04@H<01883@0W728050T?01052`805@X@01P0
4@H<01/@5P0Y7R@08AHJ00`21@0900805``@01872`0Z7b<04PL;01H;3`0U6Qh05@X>01462P0>10L0
5P/?01872`0H3A404`P<01dB5P0<0PD050T=01<8300D2@d201H;3`0C01D<3`0C3@l04@/=018<3P0C
3@l050h@01D?4@0=1`T02`D701H@4P0L5QP050h@00h82@0B30`050h>01<=3@0A2`/03`T9014;2`04
018<300U01<=3@0@2Ph05A0E01@@5`0>3A403Q4C00@62`0D5QT030lA00lA5@0>3Q807ATN02LQ:00J
5AT06QHG01@@4@0h=3D0RhN801dH700E41@03`X>01HA5`0/9bd05A0F01@?5@0A3a806ALH01@B4`0I
5aP06aTJ01XH6@0H5QL06ALH01@B4`0F51D04Q0A01@B4`0301DC5P0A01@B5@0E4aH061HI01LE600E
4aH05Q@G01/I700L6Qd05Q@G01@D500E5A<05aLG01DE5@0F5QL061PJ01HF600H5a/00P0I61d08P0J
6Ah06AXN01DF6@0H71h06alQ01`P8P0N8RD06b0S01/S9@0L92P06b<W01XS9`0K92X07RL^01lY<P0N
:38072L/01/V:@0L9bP07RXZ01l[:`0L:2T072LZ01lZ;`0Q:c@07bTd028^?00S;cd09S8o02Lc?`0X
=Cd09C8j02@b=`0U<cH202Le=P0A02Hd=00U=CD0:3Pn02Tj@P0]?TH0:c]803M7EP0Z>TT0;cm>0310
C@0_@4X0;3e602/l@`0/?D@0:Sa602m1B`0cATh00P0dAdh0500gBTl0>4a?0395B00cAdT0<TI703=7
A`0fBT`0>4]A02Hi@00bAD`0?e9H03M:D00cAT`0<TE903=6BP0hBdh0>4a=03I:B`0dB4P0=DU80`0c
AdP0E`0eB4`0>4]@03mBF00lCeH0=TUA03=5C`0a@dd0=4I=0312AP0fB4`0<dE902`n@P0Y>cl0;Cm3
02m1A@0cADT0;3i203=5B@0Z?400FFY`04mPI`0iBU40>T]B02`mA00^?dH0?TmF02Pi@00iBU40<dA;
0352B@0bA4T0<d=30351@00_?ch0;3`k02dm?00^?Sh0=4A402@d=00eA4L0:CPm02dl@@0_?T80:STk
02Xj>P0a@D409cHi02Xi?00U=3L09cHk02Pg?@0X=Sh0BEMQ02Pf@@0a@4`0:S];02m2D`0aA5D0;d1@
02hoC`0c@e<0=TIE0310C`0`?Dd0<T1=02lmBP0]>dL0;3U202<`=`0O;3808bhb02D^<@0R:Rd08RL[
01HI7`0P82P0:RPc03Pf@P0Z:SH082</02HZ<`0R9Rl07R<Y020U:`0R9bd06QlS01lT9`02024V:@80
7b@W0P0M8B@2020T9`0:01`P900L7b@092L^01`O9P0P8bX08RD^01XM9P0F6B806A`S01/N9@807B0W
00X06QdT01TL8`0G6R405QTP01DH7`0G6R406QdT01`O9P0N7b@06a`Q0P0I6Ql02@0K724071dR01dN
8`0H6Ah0:b`a01lP9@0J6b008B8W01`M8P02020Q9P0701hO900J6b006AXO01hO900M7R<07QlT01`M
8P0201PI7P0<01dM9`0Q8B/06a/U01XJ900K6bD06ATS07=cO@15ADl0820Z01dM9`0D51h05ADM0P0I
61h0100H5ah061LO01XI8@0I5b4201DC7P0901LE8@0F52405aDR01LE8@0G5B005Q@O01DC7P0I5b80
5Q@O00805aDP01h06QPS01DC7P0F51l05A<N01LE7P0I5Qd061DL01LD6`0F4aX05a@K01DB6@0C41L0
4PlF01DB6@0G51/05A8I01PC6P0K5Qd05a8I010;4P0U82L04@`C01D@5`0K5Qd0IV5X01XE700H4aX0
6A@K01/F700:1@/201@?5@0501XE6`0D3aD061<I01D@5P0C3Q@00P0G4QP01`0D3aD030H@01H@6P0D
3QP04@`C01XE700G4QT00P0D3aD301<>4P04018=4@0G4AD050hB01<=4@8050hB01404`dA01@>4P0D
3Q8050hB01D?4`0F41@05a4E01<?400B3Pl040`=018>3`0C3a003PX;010<3@0B3Pl04`l@01@@4@02
01DA4P0501@>4P0F41@04`dA018<400D3Q800`0C3A42018<40804`dA00@05a4E01@>4P0C3A404P`@
0P0A2`l0100C3A4050hB014;3`0B3102014;3`0=00l93@0@2Ph04`dA01D?4`0C3A404@/?01<=4@0L
5QX050hB01LA5@1KEET06A<G01@>4P0201<=4@03018<400@2Ph03`T=00D04@/?00d04@/@00h93`0A
31@04@`C00l:4@0A31805Q4G01PC6@0J5A/03PT>01HA5@0D3a@050hB00D04P`@0P0E3a<0100C3A40
4@/?018<400E3a<301D@500701HA5@0D3a<04`hB01@?4`0G4QH05Q4E01@?4`0201LB5P0301HA500E
4A805A4B00805Q8C00D05a<D01<?400C3a0061@E01LC500201@@4@0B01D?4@0D3Q004`d?01<=3`0D
3Q005Q0B018<3P0O6A/050h@00l92`0E3a4040X<01`F600;1@L05A0A00d72@0F41803`T;0`0D3Q00
4P0B30h04@/=00l92`0I3a0060h?01882@0>10D04@L801D;300F30d04@P801<92P0I3a004PP901<9
2P0E2``050X;01<92P804@L800l03`D601<92P0C2@X0718C00`20`0E2``050X;01H<3@0D2P/04@L8
01D;300F30d03@<40147200G3@h00P0?1@H0200U6a`0HeUJ01`A5@0D2Pd040L901T>4P1UFUh07A@F
0P0A1PX0100D2@d06PlC00/1100Q5QX201<8300G00l4200K41@0714E00l4200C2@`0?34e04Ll@00E
2Ph02P4301/@500C20`03`@801`A5@0>10L04`P<01@93@0C2@`05@X>01872`0H3A407a@H01/@500B
1`/00P0?10P04P0B1`/04@H:01462P0A1`X040L901872`0F2`l040L901462P0B1`/05P/?01T>4P0A
1PX0?C8f04i3A`0F2`l04@H:01872`8050T=00L04PP;01H;3`0F2`l04PL;00d21P0=10H05@X>0080
40D900D05P/?01@93@0C20`04`P<01462P0201872`0300h31`0@1@T04`P<00804PL;0P0A1PX01`0@
1@T04@H:01462P0A1PX040D901462P0B1`/01@0A1PX01@0A1`X04@P900d71`0<1PH03@L700803`T9
00L081XJ0:ZTY01SGEd03PP801<=3@0<1`L04@H;00804@H<0P0B1`d01@0C20h04PL=01873@0B1`d0
4@H<008040D;00H05@X@00h32@0?10X04PL=00l42P0C20h501873@0:01483@0X8BT0N7=i0;2[/@0Z
9B/03@P=00d82`0@1``040L;01072P<04@H:5?ooool001_ooooo0P0A2`d06`0?2@/03PP:00l92`0?
2@/050h@00h82P0A2`d04P`>00`6200;1@T01@05018;4P0H4AP01`0701093`0D3Q805@lC014;3P0;
1@L03`T;01`F600<1PP040D;040e>`0?10X05``B00`11`0201873@0501D:400I3Q@050T?00l42P0A
1P`00P0A1PX0300L4AD0:AhR01872`0X7B406a0D01<8300Y7R803`@800d21P0N4aL050T=00h31`80
50T=00<08aPL01D:3P0C20`00`0D2@d01@0E2Ph050/>00l92`0<1PP03PP:00804@/=00T04`d?018<
3P0>20X040X<01<=3`0A2`d040X;014;2`0?2@T00`0>20P00`0A2`/04P`<018<3003018<300A01D=
3`0F41803`T=018?4@0?3`l03Ph@01HF5`0G5aL0410B00d:300@2P`05a4E01TD5@0[9bP04`l@020L
7@0X92D00P0B3A40600D3a<050lE01lJ800A31804@`C01dK7P0T8R<06QPI01PF5`0F51D040h?018@
4@0C4A805aDF01@B4`0G5AH06aTJ01@B5@0J61/07A/N01@B5@0B41<06QPK01PF6@805A<F00T06aTL
01`J7@0F51L051@D01DE5@0G5aL05ADE01HF5`0H61X00P0E51T0900F5AX05aHL01TH7P0H6Ah051DJ
02@W:`0X:c007B0U01<G700H7B<07RD[01dT:`0K8RX06b@[01/T;00K92d07bTc01`V<00K9R`072L[
024/;P0S;S008Rd_01hY;00N:Bd08Rdc02D_>00R;3H09S9002Hb?`0U<Cd09S8n02Pe?P0[>4009C8h
02Le>080:3Hg09X09S@e02@c=P0[>d40:ca403M8D00lC5T0CUi]03I6E@0c@e80;cm<02XkA@0Y>T<0
;Ci50352BP0[?DP0<49>0394D00cAE00=DMA03I9D00lCeH0=DQ?03E8CP0bAD/0<dI<03Q;D@0aA4/0
AUUP03E8C`12EE`0AUUO02`oA@0fBDl09CPl02m2AP10DeL0@eMH03E9BP0dB4T0<TI70395B00dAd/0
=dY>03I9CP0lCeD0>diD02e0A`0[?TD0<DA;03I8C`0[?D40=dU=02m1A@13EET0=dU=02Tk?`0U=c/0
=dU=03i@E00jC500:ce103=5BP0[?4<0;Ci50352B@0Y>T40A5EL08bMY01=GVD0=4E<02hoAP0dAD`0
;3e303A4A00dA4<0<d=20310@00^?Sh0;Cdm020_<P0V=CP0DF1U03I5BP13DUL0;Ca002Xj>P0]?C`0
9SHf020_<P0X=cX09SDk028a>00W=Ch0:3I202dkB016E640;Se<0352DP0X>DT0:CY:03Q9F@0lCEd0
=DED02LdA00Z>4D0<Cm<02lkB@0Y=D40:cM302dg@@0U<3L08bhd02L`=@0X<3@08RX]01lT:00P92T0
:B`c02h^>00f=D0092@`02T/=@0e>D80;30i01hS:@0K82H08RL]01dR9P0R9bX08bP[024V:@0N8bH0
7B8U01XN8@0K7b806QhQ01/O8P0M8BD07R4V024T:`0H6b808RD/02LZ<`0O8R/07B0Y01/N9@0K7R<0
6QdR01PK800D5a`04aHK01DH7@0H6b006A`Q0`0J7B800`0P8BH07AhS01/L8@0301/L8@0901PI7P0F
5a`09BH[05=DF@0[;3408b@Y01`M8P0J6b006a`Q00<07AhS0P0L7B801`0K72406AXO01DF6`0C51T0
8B4[02DU;`0L72H00P0J6R@0400@41X09BD_010@6P0`<3X02@TC01HF800N7BD06QTO01PG7@0G5Qd0
5aHN01HE7@0F5Ah06ALR01/I900K6BD201XH9@0?01dK9`0N72L06ALR01@B7@0H5R406ALR01DC7P0B
41/05aDP020N:@0?3AP081hY01PF7P0H5A`05a@K00<05Q<J02H05A8I01PE700H5A`05A8I01LD6`0E
4QT06A@K00l:4@0E41L05a8I01hI800H4aX07QTP01LB6@0Z9B`03@P?01lJ8@0@2a8071LM010;4@0I
51X01`8801XE6`0Z9B/06A@J01HA5`0C3Q@05A0F01HA5`0C3Q@06aDO01PB700G4A/06QDL01PC6P0C
3QD03`X@014<4P8050lC00<04@`@00h93@0B31000P0C3A40100D3Q805Q0D01PB5P0A2`l201<=4@04
01@>4P0E3a<05@lC01DA4P8040`=00<04`l@018>3`0>2P/00P0E4A8201<?400301DA4P0F4Q<050hB
00805Q0D00D050hB01D?4`0I4aL05Q0D01@>4P02018<400401@>4P0F41@050hB01<=4@804P`@0P0C
3A402P0>20`06aDI03Pb=P0<1PX04@/?01PB5P0E3a<050hB01<=4@0A2`l2010:3P0801XD60070@D0
1002018=400I4aL030H:014;3`0C3A4201@>4P03014;3`0@2Ph04@/?00D04@/?00`03`X>01<>500C
3Q@040/A00l:400R7B<0;RT_01dH7`0A31<03`X@014<4`0?2Pl7018<40@04`dA00D05@lC01LB5P0G
4QH05Q4E01D@500201@?4`<04`hB0P0B3A400`0D4180510A01@@4@0201DA4P0H01HB4`0D41404Ph?
014=3P0F4Q<06ADF01LC500F41805@lA01@>400B30h04`d?01H@4P0>20X081XL010:300<1PP03`T;
01D?4@0C3@l081XL01<=3`0Z92H01@010`0B30h02`0A2`d040X<010:300A2`d03P@501882@0H3Pl0
5`d>01882@0@1PL02@0000<04@L800@04PP90147200D2P/050X;0P0B20T02P0A1`P040H701X@4@0<
10@07aDF01882@0C2@X0:1hO01hE5P0A20T201<:2`0>00l61`0G3Pl0200001892P0:0@804PT:00h5
1P0O5QL06a0D01482P0G31001`0005iCE`0;00@201<8300401@93@0B1`/0200101dB5P804`P<0280
3P<701dB5P0Q5QX04PL;01@:3@2HSI40Y9VM01892`0X7B40L6EY024F6P0:00<04`P<00l4200T6Ad0
81DI01H;3`0C20`02`0401882`0S61`040D901H;3`0B1`/040D901462P0B1`/04@H:01P=4@0U6Qh0
<RL[04m4B007000040D90P0F2`l06`0M4QH04`P<00h31`0G310040D900l4200B1`/02`0400T00P0D
2@d03@8602dR9P0S61`03`@8024F6P0I41808AHJ01H;3`0@1@T0304500h31`0@1@T03`@801052@0?
10P03P<701052@0301872`0301462P0@1@T040D900<04@H:00<040D901462P0B1`/01@0A1PX03@0A
1`X05@`=010:2P0>20P04@/;018<300>20P02`D505I@D00b;2`030H600T30`0:10@00`0C20h60187
3@090146300@1@/040D;01<83P0B1`d05P/A01T>500D2@l04@H<00804`P>0P0A1P`02`0C20h04PT>
01TB6P1MF5l0O7Mm020K8@060PH04@/?00l62`0?1PX03`H900<040D95?ooool001_ooooo0P0@2P`2
00l92`803PP:01L030H8014;3@0D3Q003@L9010:300Z92P0:R<Z00`53@0C31<040T@01PB5`0600@0
4P`@01LA500<1PP05a4C01@>40090`D08AHL00/01P0F2a402`0601873@0201@93`0H00d2200@1@/0
4PL=01052`0A1P`03P@701462P0G3100714E00T00P0E2Ph04PL;01<8300G31004@H:01X?4`0G3100
6@hB01@93@0K41@07Q<G034V:P0U6Qh04PL;0P0D2@d02`0C20`050T=01H=400B30h040X<01@>400G
4A<05@lA01H@4P0G4A<04`d?00804@/=00<04P`>01<=3P0A2`/00P0=1`L0100?2@T040X:018<300C
3@d3018<300L014;2`0C2``05Pd>00l92`0I51D03@T801@@4@0>30/04`l>01LC500E41405Q0@01<:
3@060@80510A00T51P0O6a`01`<401PC5`0B3A405a8F01D@5P0I51X04PdC01<>500C4A@06aTJ01@B
4`805Q@E0`0B41402@0D4Q<03`d>01XH6@0A3a006QPK020N8@0R82<05Q@G014?4P0201HD5`0;01DC
5P0F51L06QPK01/I700F51L051@D01DE5@0G5aL05ADE01HF5`0H61X00`0H5a`06@0I61h06aXP01`M
8P0E61d09BP^02X]=00L7bH04ADK01XN9`0P9bl07B@/01/R;00K92d072D^01XR;@0L9S006B<]01PR
:`0L9bd082/_028]<@0Q;30082/_020[<@0S;CH00P0U;cT01`0Q;CT0:3A002diA@0/>D80:3Dn02Db
>P0U<SP00P0V=3L202Le=P0I02He>00^?T@08S<k02Lh@024U:40Z[[904IFI@0eAE@0;cm<02XkA@0Y
>T<0<45803E6CP0]?dX0<D=?02m1C@0a@dl0=DMC03E7D@0bA4h0<49<0395C00a@d`0=4M>03Y=E002
02`oAP0^03=6C@0gBU40=4M=03A7C@0`@dT0AeYN03iAE@0[?T80=4Q90396A`0dB4T0<dM803=6B@0f
BDd0>4]?03Y=DP0jCE<0=DQ>03Q;D@0iC5<0=4M>03=6B`0[?D40>4Y>02i0A01>H6@0@eEI04iPI00[
?D40;d5503E7B`0_@DD0:C/o03E7C00dAD`0:CY102Pi@00Y>T40?4eD07Z;TP1:Ff80;Ci50393BP0_
@4L0;3i30310@080<D5003/0<41002dm?@0Z>SX07B`_02/j?@19F5d0<D15045@E@0/>cl0:c/k02dm
?00S<c<0:3Lj02Th?@0X=Sh0;Sa502lmB00a?dd0?4UI06]hR00e@e<0:S];02HgA`0[?4`0<D9B0394
DP0^?T`0:cU602dkB00b@4`0;SY602Hb?P0W<ch0:38k01lY<@0I92X07RL/02P`=00/=3L06b0T024U
:`0V:C009BD_02`[=P0K6bL08B@]02hb>`0V:S<06AhT01PM8`0O92X07b@X028W:`0R9bX082DX01hS
9P0M8RD06QhQ01/O8P0201DI700H01XM8@0J7B806A`S01HI800L7bH082</01hQ:P0L7bH07R4V01hQ
9@0L82<06AdQ01HI7P0E6A`05QXN01TL8@0K7b8071lS01XM8P0H6b007QlT01`M8P0J6b006AXO0`0H
6Ah02@0P8BH07AhS02//<@2a/[L03PlD01/L8@0H6Ah06AXO01`M8P0201hO900901/L8@0L7B8061TN
01PI7P0F5a`04a@I01TI8`0L72H06ATS008061PR024071`V01DE7`0<31H0:BTc00X:500L72H07A`T
01XI7`0H5ad05aHM01LF7P0E51`051<L01LE800I5b806ALS01XH9@0H5R<07A/W02@R;@0L6RD04a4L
01DC7P0F51l05A<N014?6P0D4Qd05Q@O00d;5P0K6B@05Q@M01LD6`0F4aX00`0E4QT0600D4AP06AHM
01PE700E4QT061DL010=500H4aX02`H=01HA600G4QT03@P?010;4P0F4AP01@0701dH7`0@2a808A`S
01LB6@0C3Q@04PdC01`G7@0B3A<0;2L]04I1A`<04`hD01404@`B010;4@0@2a4040XD00d74@0A2aD0
5A0G018=500A31<04PdC01<>500E41@050lC010;3`0=20`040X>018<400201<=4@0401D?4`0I4aL0
4@/?01<=4@<050hB00D04`dA01DA4P0A3@h04Ph?01<?4002014=3P0301@@4@0C3a004Ph?00804Ph?
00T04`l@014;3`0C3A405Q0D01@>4P0B3100618F01H@500E3a<00P0C3A400`0E3a<05Q0D018<4002
018<400<01<=4@0E3a<05@lC01/E6@0M5a/0BTA801PB5P0>20`04P`@01PB5P0F41@04`dA0P0?2@d0
2@0A2`l03PP<00@00P0N61`04P`@020J7P0I4aL04P`@01<=4@0201@>4P03018<400A2`l04@/?00D0
4@/?00<04@`@01@?4`0C3Q<00P0?2Q001`0F4AL07APN010;4P0F4AP04PdD01H@6P0?2A001@0B3100
1P0A2`l04P`@01<=4@0E3a<050hB01<=4@D04`hB00P04PdA01<>4P0A31004@`@01<>4P0A31004PdA
01@@4P80510A0`0E4A801`0B3Pl04`l@010<3@0B3Pl05a<D01@@4@0E3a400P0D3Q0301<=3`0?00X4
1P0H4Q@050h@010:300?2@/06Q@F00T31@0=1`T02@@502@N800O6A/04`d?01H@4P0D3Q0040X<0080
3PP:00d040X<01061`0A1`P05`d>01P>3`0F30d0718C00L0000N51D03`D601061`0C2@X05@/<0080
4`T:0`0B20T06@0A1`P03`D603@Z:`1NE5D05`d>01@<300O5AH050/<00h51P0H3a005`h?00`3100E
30d04@P901892P0<0`@04`X;0108200:0@805@X>01872`0A1PX04`P<020E6@0E2Ph00P0D2@d00`0C
20`05@X>00`11@0201@93@0H01462P0>0`L05P/?01L<400>0`L03@8601lD600K41@05``@00`11@0L
4AD07Q<G00d21P0;00@050T=08AiO@2h[K40>Bhb00L0000B1`/050T=01H;3`0;00@03`@80P0A1PX0
300@1@T04PL;01D:3P0:0@<0DDI:0<Bi_@0A20X0:1dQ01462P0C20`02@0200X10`804`P<01<060dA
01@93@0A1PX040D900X00`0@1@T04PT;01D:3P1NDeL0A3Tm00L0000M4QH04`P<01H;3`0B1`/050T=
01052@0?10P04`P<00806@hB00D04`P<01872`0B1`/04@H:01872`0301462P0701052@0A1PX04@H:
01462P0@1@T04@H:01872`0501462P0401472P0C2P/03PP800h8208040X:00L030H600/51@0=1`L0
3PP801LA4@0C3@d05@l@008050T?00@04`P>01873@0B1`d04@H<0`0B1`d02P0A1P`040D;01052`0H
3A<04PL=00X01@0900@04@H<01H;4@0A1P`401873@0:0107300<1@d05A0F01PC6@0?2Q003`X?01@>
4P0@1``040L;01072P<04@H:5?ooool001_ooooo03`040X<018<3P0C3@l04P`>010:300=1`T04@/=
00h82P0B30h040X<01<=3`0Y8bH0DT]A01<>4`0B2a802`D901H@500?2@d02`H900l93@0A2`l03`T=
00h83019@dL09AXP01@:3`0H3A<04PP=00l62P0R5ad04`P>00d2200A1P`04PL=01052`0B1`d04PL;
01D:3P0D2@d04`P<01L<400D2@d09Q/O00l4200>0`L05``@01T>4P0@1@T05@X>01462P0G31004`P<
01hC5`0?1@P04PL;01D:3P0D2@d04PL;01@93@0E30l2014;3@0301H@4P0I4aD050h@00804P`>00D0
4@/=018<3P0D3Q004P`>014;3@02010:300401@>400E3a404`d?018<3P804`d?01P04P`>014;3@0A
2`d04@T:01TA3`0A20P050d;00l81P0O61L04@/900l81P0D3@`04``:01H>300M51@05a4A018>3`0D
41405a<D01<?400B3A404@`@01`G6`0G4QP201D@5P0801HA600@3Q406ALH01<A4P0H5QL06QPI01PF
5`0J61T201@B4`03020N7`10?Sl07adN00806ALJ00H071XM01hL7`0L6Qd05A<F01@B5@0F51L201TG
6P0G01PF6@0G5QP051@D01@F5@0F5aT051DG01DF6@0G61`06AXN01PI7@0G61d061TN01/L8@0M7B@0
61/S01XM9@0M82T06QdV01PL9@0S9c808bXd01hU;`0K8Bd00P0L92l0500I8Bd07bTc01`V<00L9Rl0
7bTb024/<`0O:C407RP`024[<`0Q:c@082Xc02<]=`0X<S`08blk02Pd?`0Z=d009c@m02Hc?00X=Cd0
8c0f0P0S<C@0:`0V=3L0:CLj02Th?00^?TD0;Sm702m0B01/O8T0UJFd03i>G@0^?Td0:SY702Lh@P0W
>440;Ci50352BP0`@Tl0<D=A02/mB`0]?dd0=4ID03=5DP0dAU80=DMC03Q:E@0eAe80=TQD03a>F@15
Ef40@UAN0312C00gBU40;d9903U<D`0dAdd0DVE[04QKH00`@dL0>TeA0354B00dAd/0=DQ<03I9C@0i
C5000P0kCU@0500iC580?4mE04mRJ012EE/0<4=903E7C00_@DD0?DmC02i0A00gBDd0>Ta@09Z//019
Fel0;3i20312AP0_@DD0=DM;02m1AP0eATd0;Ci50P0^?dH0800U=Sd0<45803I7CP0Y>T40=4E<02`m
A00b@dT0<3m20310@00_?cl0;Cdm02`l?00/>ch0:3Lj02Xi?00Z>Ch0;Se402/j@@0W=S`0:Sdk02/n
>`0Y>cX0@E=F0353B00W=d809CE302hnCP0W=dL0<D5A02loC`0Z>TX093I40P0dAU@0<00]?D/0?DeJ
034oC00hAU80;Sa702Pe@00Z=d40:3Dn02<_>@0K9Bh07RL_020Y<00Q:Rl08R/_02@/;`0R9b/08BD[
01lR:@0M82T0;Bhi01hO:`0L82T082@]01`P:@0K82H07B8X01/P9P0L8BD07b@W01hS9P0M8RD07R<V
020U:00/<3<0:Rha01hR9@0K7b807b<W01dP9@0G6R4071lV01LJ8@0G6R<071lX01TL8`0K7b806QhP
01/O80806QhP00P06QhO01/O800J7R006AdN01XN7`0J7R006alQ01`M8P806a`Q0`0J6b00300h>Ch0
5aPM01hO900G61d07b0U028S:00L7B806Q/P01`M8P0N7b@06a`Q01LH7@807AhS00X05aPM01PI7P0J
6b005aPM01@D7P0E5Al06QXT01PH8P0F5R0061PR0P0D51h07P0C4ad07AdW01XJ900I62005aHL01DD
6P0G5Qd06APP01PG7`0F51h06ALR01XH8`0L6RH08R0]01hL:@0H5R806aTT01LE800C4A`05aDP01HD
7`0C4A`05A<N028P:`0F51l05aDP01<A700F51`05Q<J01DB6@D0514H02l05a@K02TV;@0d<CP07a`S
01PC6P0C3QD05Q4H01D@5`0H4aX0?CPo03Ha>00M61l04`hE014<4`0C3QD05A4G01HA5`0J5A/04@`B
01<>500J5A/050lE018=4`0G4QP06QDK01@?5@0@2a404`hD00d84@0Q6bD08Q`V00h9400@2a804`hE
018=4`0A31804@`@01<>4P0K5QX07aXN014;3`0D3Q804`dA014;3`0B31005Q0D01@>4P0301H@500:
01@>4P0B310050lC01<>4P0F4AD050lC00l:3P0F4AD040/?014<40@04PdA00H050hB01LA5@0L5QX0
5a4E010:3P0F41@601<=4@0?01@>4P0C3A404P`@01<=4@0D3Q805@lC01<=4@0?2@d08adQ01<=4@0F
41@03@L;014;3`0C3A404P`@008040X>00/04P`@014;3`0C3A405Q0D010;3P0>2@`03`T=01H@500E
3a<050hB01<=4@02010:3PD04@/?00d04@/>010<3@0B3Pl04@d?00l:3P0@2a403`XA01LB6@0<1Q00
5Q0J00/5400K5B4050hF00D04P`@0P0D3Q8201<=4@0301@>4P0F41@050lC00804@`@0P0B3A402@0C
3Q805A0D018=4@0B3A405a8F01@?4`0E41@05a<E01<?400201@@4@805A4B00H04Ph?01hJ6`0Q7Ah0
510A014=3P0B3Pl201<=3`0@01@>400C3@l04P`>014;3@0C3@l05Q0B02DO8@0J51H030H8014;3@0>
20X040X<01<=3`0P6Q`0@cdo01<=3`8050h@01404`d?014;3@0A2`d04P`>01H<3@0E2``060h?01H<
3@0C2@X07A<D01L>3`17?Ch05P`=01D;300C2@X050X;0147200301882@8050X;01D04PX:0517B00j
<34040H701D;300>1PH03`H90189300@1`X04PT<01D<3`0>1@P04`X=01`C5P0J4A@02P840189300?
1PT040H901D:3P0>0`L00P0C2@`02P0=0`H040D901D:3P0=0PH04`P<01052@0<0@D04PL;00l4200A
1PX201872`0g01<8300G3A005@X>01072@0>10L05P/?01472P0@1PT03`@801<8300P5AT0VXnC0<:k
_`0`9BT0308501`A5@0A1PX05``@00l4200@1@T060dA01H;3`0?10P04@H:01H;3`0E2Ph040L901<9
300A1PX03PD701462P0H3A404`X<01<9300B1`/0304501052@0?1@P04PP;01@93@0>1@L06a0D028G
6`0C20`05P/?01D:3P0A1PX04`P<01062@0=0`H03P<701D:3P0C20`040D901872`0201T>4P050187
2`0C20`050T=01462P0@1@T00P0A1PX201872`0601<8300A1PX04@H:01052@0A1PX04PL;1@0A1PX0
3@0A1`X040L:00h82P0<1PP03PP:010:300B30h03`T;010:300=1`T030H801<=3`0:10H00P0?10X0
100@1@/04@H<01873@0C20h301873@0;0146300@1@/040D;00l42P0@1@/04`P>01D:400C20h03047
00h32@0A1P`00P0B1`d02`0A1P`03@@901@=5@0?2Q002PD;010;4@0@2Pl03PP<01483@0A20`04@P;
00<04PL;5?ooool001_ooooo00D050h@00l92`1WHF<0OGMi01@>400200l92`8040X<0P0A2`d01@0@
2P`05@lC01@>4P0B31004@/?008040X>01@05Q0D014;3`0600@050dD0109400C31<05``B01873@0A
1P`05@X@01@93`0C20h040D;0146300B1`d050T?00d2200F2a4050T=01872`@04@H:00<06PlC0146
2P0@1@T00P0D2@d0600A1PX04`P<00`11@0h;C404PL;01462P0@1@T05P/?01@93@0>0`L050T=00l4
200A20/04@/=01D?4@0B30h02P@600l92`0B30h07ALI00h82P0G4A<0MFma03li>`804P`>00@02`D7
01dG6@0<1PP03@L90P0@2P`03P0B30h04@/=00l92`0>20X04P/;01@<2P0C2`T050/901D;2P0F30/0
5`h<01H<2`0D2PT050/90P0F3P`01@0C3Pd04Ph?018>3`0@30d04@d>00805A0D01L07QTM00h93`0M
61h04@`B00l:400C4A@03P`=01TG600L6Q/03`d>014?400D4Q<05Q@E01hL7@0P7Ql0:RPY01lM7P0D
4QD05aDH01TG6P0D4QD04a4D01LE600301HD5`8061HI01T051<E01hN80082@/08R<U028S9`0F5a/0
4a@H014B5`0E5Q/05aPM01HF7P0G5al06ATQ01<F7`0G6R<061/T01TK9`0M82/07B4/01lU<@0L8Rl0
7bDc024Y=P0M9C805al/00808B/e01807bTc01hX<P0M9c806bD_01`V<P0P:SD0:S@n02/e?`0U;cT0
92hh01h[=00R;cP0:cQ102/h@00T<CT08c0h02<`=P0V<cT202Ld>P0O02Pe>`0X=c`0;3a303A5C@0i
BU80<D5>03Y:F@0]?D`0=4AC02dmBP0[?4H09cQ103=4B`0a@TX0=TQE0394DP0]?dd0<D=A03I8EP0d
AU@0>TaJ03=5D`0hBUP0;3i<02/lC00jC5X0B5YV051RK00bA4h0=DMA04AGGP020313BP0303E8CP0j
CE<0;d980080=4M=0200<dI<02m2B00iC580?E1F03=6C00gBU00>4]A03A7B`0^@DD0;d9603=6BP0g
BTh0;d550312AP0a@dL0=DM;03Q:CP0mCe<06B/_041BEP0a@dL0<TA802i0A00Z>d40=DI=02Xk@P0/
?D@08S<j02Tj@@0/?D@0;Ci502m0A`80<D9904@0:ca202`k?P0]?Cd0<D5102ln@@0[>Sd0<d9702dl
@@0_?T<0;3]202Pg?P0[>T409C@j02@f=P0[?S`0:C/l0311B010DET0=TID03=3D`0K:Sd07bi102dm
C@0^?Th0:c]:02loCP0dA540;cm<02`jA`0kBE@0=TA?03e9E@0K:3408Rlg02<]=P0R;3D0:C<l01lX
<@0O9Rl06B0X024X;P0M92T06R8U01DJ7P0L8BH06AhT01/N9`0V:3<09bTe01dQ:P0O8b`08RH_02@Y
;`0R9bd07R<Y020U:@0S:2`06AhQ02@Y;00J7b8051TL01hR9@1;Ce8092P[01`P8`0L7b<05QTN018E
70809BP_01H02`hG01DH8@0N8BP06QhQ01PL7@0F6Q/061`M01/O800M8B806alP01LK700L82405a/L
01lS900E6AX05aPM01HG700:2a005aPM024R9`0@4AH05aPM0P0J6b005@0H6Ah06Q/P01dN8`0F5a`0
71dR01/L8@0M7R<07b0U01dN8`0N7b@06a`Q01XK800K72407QlT01lP9@0I6B<04a<M018B700F5R00
5aLQ01PH8P0201TI8`0401PH8P0F5R0051@N01HF7P805QDK00@06APO01DD700E51`061HP0P0F51l0
4P0K6BD07Q`Y01/I9P0H5R806ALR01/I900M6bH06aTT01TG8P0G5B005Q@O01XH8`0K6B@04@lJ018@
6`0E4a`04PlF01<@5`<05A8I00L05a@K010=500W92/05A8I01<@5`0F4aX07APO008061<J00@06aHM
01XE701AC5<05a8I0P0F4AP0100E41L050lF01@?5P0A3182010;4@0E01@?5@0F4AL05Q4G00X52`0C
3Q@07QTO01PC6@0E41H061<I00l94`0_:C<0DTaF01D@5`0F4AP04PdD00h93`0K5Q`02PD902DP901G
DUH071LK00804`dA0P0D3Q800`0E3a<05Q0D01<=4@02018<400;01<=4@0B310040X>01@?4`0@2`l0
5A0D01LB5P0@2`l04@`@010;3`0B3A400P0E41@06@0D3a<04PdA01PB5P0@2Ph0618F01LA5@0I4aL0
5@lC018<400E3a<050hB014;3`0@2Ph04P`@00h8300@2Ph04@/?018<400@2Ph03`T=018<400Q6al0
=2hb03li?@0C3A400`0B310201<=4@1G018<400A2`l04@/?01TC5`090`L05@lC018<400D3Q805@lC
018<400A2`l040X>014;3`0B310050hB00l93@0@2Ph050hB01<=4@0A2`d04Ph>01dI6P0B3A0030L;
00h93`0@2a804`hE018<5P0B31L040XF065KI`0o>4401@0300d72`0B3100208601XD600B31004`dA
01LA5@0C3A4050hB01D?4`0A2`l030L;01LB5P0F4AD03PT=01LB5P0E41@05Q4E018=4@0A310030L;
02HQ9@0G4aD03@T:018>3`0F4Q<05a<D00h:2`0A3@h05Q8C01LC500E4A806QHG01PD5@0J51H03PP:
01LB4`0H4Q@05a4C010:300I4aD04P`>00d72@0K5AL02P@600d72@0H4Q@03`T;01H@4P0M5aT04@/=
01D?4@0>20X03`T;00804P`>00<04@/=00l92`0A1`P00P0F30d01@0C2@X05P`=01L=3P0F30d05@/<
008050X;00@04`T:01882@0C2@X04PP90P0@1PL00`0B20T04`T:00h41@0200l51P0701061`0A1`P0
4PP900l62@0F4180208400T31@02010:300<018<3P0H4Q@06aDG00h82P0:10H06a8E01P=4@0A1PX0
40D901462P0M4QH050T=0P0B1`/200h31`0701<8300F2`l04@H:00/0100@1@T03`@801462P0201/@
500400l4200700004`P<01872`804`P<01005@X>01872`0@1@T060dA01lD600C20`05P/?01D:3P0@
1@T03`@801872`0J3a<06@hB01L<400C20`04@H:0P0B1`/0100>0`L04`P<01H;3`0@1@T601462P04
01872`0F2`l060dA01H;3`804@H:00@04`P<01872`0B1`/04@H:0P0B1`/02P0C20`040D901462P0C
20`03@8600h31`0E2Ph05P/?01@93@0C20`201462P8040D901H050T=01L<400D2@d040D900X10`0@
1@T05P/?00d21P0N4aL04@H:01@93@0C20`05@X>00`11@0800409A/O01P?4P0<1PP04@/=00T31@0=
1`T02@<50P0>20X200l92`0D00h82P0=1`T04PL=0146300D2@l04`P>00l42P0A1P`04`P>0146300?
10X040D;01<83P0H3A<050T?00/01P0>0`T04PL=01L<4P0900@501873@0301483@0=1Ph03@P>0080
3PT?00P040/@014;3`0B2@h03PD900l62@0D2@d04`P<00d21QCooooo000Kooooo`0=00@0000>20X0
:B<U03H`<P0>20X0208401@>400A2`d03`T;00h82P0@2P`04P`>018<400301@>4P03010:3P0=1`/0
3PP<00804@/?00@04@XA00X32P0D3A@05``B0P0B1`d02P0E2Q0050T?01<83P0G31804@H<01052`0F
2a404PL=01`A5`0B1`/201462P0B01872`0C20`050T=01P=4@0E2Ph04`P<01462P0C20`050T=01P=
4@0G3100=R/_01T>4P0E2Ph05P/?01@93@0G31004PL;0P0G31009@0I41<03`T;010:300C3@l040X<
018<3P0D3Q0030H800L10`0;1@L0:bDW00l92`0A2`d050h@018<3P0C3@l091hP00X41P0D3Q005Q0B
01PB500F41804@/=010:300B30d05@d;01@<2P0D2`X050X901D;2P0J40l06a4@01P>3@0G3P`05Ph<
01D=2`0B3Pd00P0C3a005P0A3@h04Ph?01HA5@0=20`05Q4E01<>500S7R@07APN01LB6@0J61/0518C
01/I6P0R82406aTJ01LE5P0D4Q<05Q@E01TG600A3a005aDF014?400F51L201LE600R01<A500B41<0
4a4D01PF6@0F51L0518E01HD5`0G5AP05aHH01PI6`0@4A<051DG00l@500E5QX061TM01@E6P0H6Ah0
6Q/P01TI8@0J6R806a/S01<F7`0F6B804aHO018D800F6B@06alZ01TO:`0I7b`0728`01`T<@0J8Rl0
5al/01XT;P806bD_01T072Hb01dW<`0M9c<08b`k02H`?00`>TH0<ce902`f@00X<S`07b`e024^=`0Y
=Sl0:CHn02Hc>`0W=3`082dc02Db>00V<cT0:3Dk02Xg?@0[>Sl0;3a302hoA`0a@TX0;3a90080=4AC
01`0<D5@02dmBP0/?DL0:S]403A5C00b@d/0<dEA03A6E00bA580=TQF03Q:F00eAeD0EFMe02/mB`0Z
?4X0=DIF04=DI01AHg40<D=@02XlAP0cADl0>TaF03E7D@0_@TT0;D1702i1A`0cAT`0<4=90P0bAD/0
E00lCeD0>diD03iAE`0mD5H0=4M=03E8CP0fBDl0=dY>02m2AP0[?T80;d9603Y<D00cADT0=4I:0353
A`0[?D40;d5502do@`12E5P0O8jB02m1A@0R=3P0:ce103]=DP1FIfh0?e1G02Xk@P0U=Sd0;d1702`m
A00]?TD0;3e402/l@`0/?D@0;T150350@`0]?Cd0:c/k030o@P0nCE00I7=h02dl@@0_?T<0;Ca302/j
@@0^?D@0:CPn02@f>00Y>c/0:S`o0393B`0kC5H0<41?02PgBP0S<TD0<d9E03I6EP0dA5<0<d=A02Ph
A@0kBeP0>daG028`>`0/>TD0?D]E038oB00Y=Sh0;3U102<]=P0W<CX0=Ci703@kA@0/<c`0:2lg020W
;@0F7R8051`O01LL800O92T07B8X01hQ:P0S9S008R@`01dQ:P806QhW02P0724W01dR:00M8RP0:Bhb
024V:@0G71l092T/01`Q900H7B002@d@02<W:P0H71l05ATL02P[;`0U:2d0:B`c01@G7P0Z;C@09BPa
01/N9`0T9bh05a/N01DI6`0C5aP05ATK01PL7`0I7Ah05ATK01HJ7@0G6a`05ATK018F6@0I7B00824V
028S:00P8BH06AXO01DF6`0O82D05QLL0P0I6Ql0400G61d061TN01XK800M7R<0824V01dN8`0L7B80
6a`Q01TJ7`0N7b@06a`Q01TJ7`0J6b006a`Q01`M8P0J6R@201DE7`806ATS0P0H62804P0I6B<061PR
01DE7`0E5Al05aLO01DD6P0F5A/06QTP01LF7P0H5al06QPR01HD7`0E4ah05aDQ01PF8`0E4b005A<O
01PF8@<06ALR01T061HQ01LE800?3AP03@/F01LE800F51l04@lJ01<A6P0G51/05Q<J01DB6@0F4aX0
61DL01XG7P0P7B@0<2dd014>5@0;20l06QLN014<4`0:1@`07APO00h9400=20l08A`S00<050lF00L0
4`hE018=500B3A@05A0F01<>500B3A<04`hD008050lE01806A@J00X52`0F4AL04@`B00/6301IE5X0
B49<01<=5`0H4Q`061<J01<>5@0A3A<040/A01dH7P0A31003PT=02<N8P0910P2014;3`804P`@0P0C
3A40300B31004`dA01D?4`0F41@05@lC01<=4@0D3a<04`hB01HA5@0E41@040/?01@?4`<04PdA00l0
4`hB01@?4`0E41@06Q@H01hH700U7b<05Q0D018<400G4AD04@/?01<=4@0B310040X>018<400F41@0
0P0A2`l01@0B31004`dA018<400B31003PP<008050hB00<07QPL00`62P0>20`00P0B310201<=4@09
018<400A2`l03@L;01XD600F41@06Q@H00/52@0?2@d04@/?008040X>0P0A2`l2018<400<00h8300?
2@d04P`@014;3`0@2Ph0510A01TE5P0D41804`hB010;4@0;1Pd061<J0P0B31H02@0M5b40OgV508Z4
S00b;3004P`@014;3`0D3Q80618F00h9300201`F6P0401<=4@0>20`030H:01<>4P803`X>024050lC
00d8300<1`/04PdA02HQ9@2PVil0<B``010;3`0E41@04`lA01DA4P0C3a005Q8C01<?400?2``04@d>
01DA4P0D41404@d>01DA4P0C3a003@L901D?4@0K5AL071HH010:300C3@l0=S0b01dG6@0910D07QPJ
01PB500E3a400P0B30h01P0[9BL0=Bla028L7P0D3Q0040X<014;3@804`d?00T04P`>014;3@0C2@X0
5P`=01D;300C2@X05@/<0147200E2``0100D2P/201<92P0501D;300F30d05P`=01D;300C2@X00`0B
20T201<92P0/01892P0B2@`01`83034[;@070@<04@/=00X41P0>20X07ALI020J700>20X05@lA00@0
000C20`06@hB00h31`0F2`l07a@H00T00P0>0`L04@H:01@93@0E2Ph04PL;01052@0?10P05@X>00l4
200@1@T05@X>01872`0E2Ph040D900h31`0C20`02`0400h31`0A1PX04`P<01872`0?10P04PL;01D:
3P0@1@T301872`0301<8300E2Ph04@H:00<040D900P03`@800h31`0@1@T03`@801@93@0C20`03P<7
01052@D04@H:00@04`P<01L<400I3Q805``@0`0B1`/501462P0601<8300?10P03P<701@93@0B1`/0
4@H:0P0E2Ph0100C20`04PL;01462P0A1PX201052@0:01<8300F2`l04`P<01052@0?10P02@0200/0
100C20`04@H:00h51`80304500X050T=01872`0A1PX0:b4U020G6P0;1@L03`T;01LA4`0C3@l06Q@F
0P0>20X400l92`0:01<83P0@1@/04@H<01873@0?10X040D;00X01@0@1@/05P/A00l42P80200300H0
6@hD01X?5@0E2Q002@0400d3200G318501873@0301483@0?21003PT@00803PT?00D03`T>00h8300?
1P/04@P<01482`0301462QCooooo000Kooooo`0A00d72@0H4Q@03@L900h82P0E3a407ALI01D?4@0A
2`d03@L900`6200@2P`04`d?010:300C3@l05Q0B01D?4@0A2`h00P0=1`/01P0?2@h04P/B00d63@07
0@P0614H01H;4P@050T?00L04`P>01873@0?10X050T?01`A5`0?10X04PL=00<04PL;01D04`P<01@9
3@0E2Ph05@X>01L<400D2@d040D901872`0F2`l03P@701T>4P0L4AD050T=00h31`0C20`05P/?00l4
200@1@T060dA01<8300H3a800P0?2@/03P0D3Q004P`>010:300A2`d03@L901H@4P0B30h040X<00l9
2`0E3a807ALK00l93@0B31002`H90P0D3Q80500I4aL06Q@H01H@500A2`l040X>01<=3P0C3``04Ph<
01@<2`0E2`X05PX;01T=3P0H3@d05P`<01D=300E40d050l=01<?3P0D41405A4B0P0C3a00500F4AD0
5A0D01@?4`0E41H05Q4G01/F700G4QT04a4D018@4@0C4A806QPI01`J6`0C4A8040h?01DC500L6Q/0
3P`=018@4@0H5QL05aDH0P0E4aH05`0I5aX06QPK01PF6@0I5aX05Q@G01<A500E4aH061HI01XI6`0E
5QX03a<F014E600K7b804QDI01`O900D5a`05aXP01PK8P0G6R4061/S01TL9@0H6b@06A`U00806ahW
00H061`V01PL9`0H7bT07RD`020V<P0M9C4201lW=00>01XT;P0K9C007BLc01lX=`0R:c/092dm024Z
?00P:CT0:SA102hhA00X<Sd08B/e024^=P0N:c<202<`>00E01l/=00P;CD07b`d02<`>00V<c/0:3Dm
02/h@00/>d80:c]202Pi@@0Z>d<0;cm<0310C`16EVD0;Si=02dmBP0_@4X0:S]40352B@0/?DD0;d5:
0080=TQC00X0>D]F03U;E`0eAe<0@E=Q03]=F`0mCed0=4EE03Y;F`1:FfX0@UAQ0P0jC5P05P0fB5<0
=4I@03=5C`0_@TT0<TE<03A7C@0oDUP0A5MM03M:D00mD5L0>TeD03Y=D`0fBDl0<4=903A7C00eB4`0
>Da@0395B00[?d00;T9305=VJ017FEd302`n@P0J0353A`0cADT09CLk03=5B@0^@4@0>4Y>02Pj?P0a
@TP0AeQO03A5C00U=Sd0;3e403Q9D00a@TT0=4E<03Q9D00fAdh0;Ci502`n@`0/>cl0:cXm02dl?`0[
>Sd0:CPk03=2A`0Y>3l202Xi@01A02`j@`0_?DH0:cY302/m@P0W>Sl0;3m703E7E00cA5<0;3eA03M8
G@19FFl0FFYk03]=FP0a@dh0:ce60311BP0gB580<3i702<a>P0a?dP0<d1802Xg?`0Z=ch08B/b01TT
:P0L9bd0EEiU065VL@0]<C/0;C4j02@Y;`0U:Rl06b0T01`Q9@0R9b`08BH/01lS;00O8bd07B4/01lS
;00Q9Bh092Pa02H[<@0S:2h07R<Y024V:P0N8bL07R<V01`Q900F6ah0:2d`02/_<P0L82<082@W01LK
7P0Q9BT06QdR01LJ8@0T9bh07B0W01DH8@0P8b`05aXR01PK8@0G6Ql05QXN01LJ7`0I72406AdQ02DX
;@0D5a`051PL01HI7@0?4QL05QTN01PI7P0L7B805AHK02TZ;`0J6b006a`Q00806AXO00h061TN01LH
7@0F5a`05QLL01LH7@0K724061TN01TJ7`0K72406AXO01dN8`0J6b006AXO01LH7@8061TN0P0H6280
0`0I6B<071`V01`L9P0201PH8P0501XJ900H628051@N01LG8@0I62000P0E51X0600K6R406APP01TH
800N7BH071XU01XH8`0H5R805aDR01HD8@0G5B405Q@O01DC7P0D4Qd05A<N01HD7`0E4ah05Q@O01/I
900J62<04@lJ010>6@0G5Ad06AHM01HC6P80514H00d05a@K01dJ8@0R7bH05a@K01PE700G51/040dD
02@O9P0K5Qd0;bXa01HA600J5A`04`hE00805A0G100D3aH00`0G4QP05Q4G01@?5@0201@?5@0=010;
4@0H4aT03@P>01PC6@0E41H030L=03Ha=`0S7BL07aTS01<=5`0:1@`07QTP01<>5@0201@?5@0401<>
4P0A310040/?014<40@04`dA0P0D3Q801`0B31005Q0D01TC5`0H4QH05a4E01D?4`0E41H00P0D3aD0
300B3A<040/A01D@5P0B3A<04@`B010;4@0A31805A0F01PC6@27PHD0C4I:028L808050hB00<03PP<
00l93@0A2`l00P0B31000`0E3a<0618F01@>4P0201<=4@0901@>4P0E3a<05Q0D01LA5@0E3a<03PP<
010:3P0?2@d04`dA00804P`@0P0C3A40200B31004@/?014;3`0D3Q804@/?010:3P0<1PX04`dA0`0B
3100100@2Ph03PP<00d72`0B310200l93@804@/?02h040X>018=4@0<1``061<H02LR:00Q728050lE
01TD6P0;1Pd0>3<j01XF700Q6b@0=S0f018<400C3A405@lC00`62P0C3A404@/?01H@500H4QH05@lC
01LA5@0H4QH040X>01<>4P0J5AT03PT=00l:3P0G4QH04@`@00L31P11?4004PhA01D@500@2`l05A0C
01TE5P0=2@X04`l@00l;300M6AX05A4B01HB4`0C3a0040`=0P0B3Pl00`0O6A/0QGn101TC5@0201D?
4@0?018<3P0E3a404P`>01PB500I4aD03PP:014;3@0F41803PP:010:300D3Q003@L901@>400A2`d0
4P`>00<04`d?00L04P`>01882@0C2@X050X;01T?400M4a@05@/<00<04`T:00D050X;01D;300E2``0
4PP901D;300201L=3P0401D;300B20T050X;01@:2`804`T:00P04PP901482@0?20/08A/O08R2QP0O
6Ad03`T=01<=4@806A<G01`05@lC018<400<1PX050hB01H<400I3Q8040D901872`0E2`h0FDiB01H;
3`0A1PX040D901D:3P0D2@d04@H:01872`0:00<02001034V:P0`9BT0304501<8300=0PH04@H:01<8
300B1`/09AXN0`0B1`/0100C20`040D900l4200E2Ph200l420804`P<00d04PL;01<8300?10P04@H:
01P=4@0F2`l04`P<01462P0E2Ph06@hB01@93@0@1@T04PL;00D04@H:00@04PL;01@93@0E2Ph04`P<
0P0A1PX02@0@1@T03`@801462P0B1`/04@H:00l4200A1PX040D900l4200201<8300301872`0C20`0
4`P<00804@H:0P0@1@T201462P<04PL;0P0A1PX04@0I3Q8040D901T>4P0:0@<04@H:01872`0?10P0
4PL;01052@0;0@@04`T<00h52P0E3a<03@L;00/52@0A2`l030H:00803PP<00P03`T=010:3P0A2`l0
4P`@01/@5P0C20h040D;01@93`804`P>00`04PP=00l42P0C20h040D;01893@0B20d040D;01@93`0?
1PX05P/A01052`0C20h501873@0=01483@0@2A403`XA00h93`0=20h03@P=00d72`0?1P/04PT=0148
2`0?10P040D901D:3P0Dooooo`006oooool01P0A2`d03`T;01D?4@0C3@l050h@01TC5@803@L90P0>
20X00`0?2@/040X<014;2`02014;2`0:014;3@0@2Pd040X>018;4P0A2Q403`P?01`E7@0A2Q8040T@
01D:4@805@X@00<050T?01<83P0C20h00P0E2Q00200M4QP091TO01873@0B1`d05``@01@93@0C20`0
4PL;0P0A1PX01@0E2Ph04@H:01462P0D2@d04`P<00804@H:01/05``@01052@0E2Ph04`P<01L<400A
1PX05P/?01<8300>0`L0:QlS038Y;00=1`T03`T;014;3@0=1`T03PP:00l92`0A2`d06A<E00`7200=
1`T0618D00@00@0B31005a4E01<=4@0T7R800P0D3Q80500C3A4050hB018<400@2Ph04P`@010=3`0>
3@/040`=01@<3P0F3@h06@hB01P=400D2P/04`P<01@=3P0E4A004Q0A014>3`0B3Pl04`l@0P0B3Pl2
01@?4`0V014<400F4AL04PdC01TD6P0K5Q`03`d@01@B4`0E4a@04a4B01HD5@0E4a@0518C01TG600Q
7b003`d>00`:2`0@3Pl05Q@G01@B5@0E4aH06aTL01hL7`0L6Qd05A<F01@B5@0F51L06ALJ01XH6`0H
5aX06a`P01HJ7@0A5AP06ahS01PK800K7R<04aHM01HI800G6R4201HI8P0;01LJ8`0a=3/07R4X01XM
900N8BP06ahV01LK900C6R8072</01/R;00H8BX00P0N9S406@0I8bd06B<^01TS;`0I8S406B8d01TQ
=00R:Sl082Pj02H_?P0Z=40092hi024[=@0T<CT082dc02Db>00V<cT08Bhd01l/<P0Q;SH09C8j02Hc
>`0U<SX09c@l02Lf?@0]?D@00P0Z>d<05`0`@4d0:c]:045AH00/?4/0;Ce:02hoB@0W>440:S]202<d
>`0_@TP0=4M>0354B`0bA4d0=DMA03A6D00kCET0<49@03E7E@0gBEL0<T=C03=4E00lCU`0?e5M0080
:C]702D0>4YD02`nB00^@4X0=dYA0395C00kCUD0@eIM03M9DP0cADl0;3i80354B`0hBe80=4M=03M:
C`0bADT0;T9302a0@@0]@D80;D500395B00L;S806R``03E7B`0a@dL0:3Xn028d>00cADT0>4Y>02Dg
>`0Z?400:3Xn02hoA@0_@4L08c@k02dnA@0V=ch0;3e40080:ca30200=dQ?03m@E`0fAdh0>DY@03E4
B@0]?3l0:cXm0391AP0c@TL0=4=:02Th?`0W=Sd0:SQ102hlA@0_?DH0;Ca50352BP0W>D<0:ce:03=4
EP0^?e<0<41H0351FP13DfX0B5YZ02PjA00W>T409CPl024b>P0_?DH0;3Y301dZ<P80:3Dm02X06bH/
02`g?@0R;C80;SLl02Tb=`0d?D<0HVIa02L[=@0Y;CH07R<Y024V:`0I7R807RHY01dU:@0M92X06b8Z
01`S;00P9c407B4Z01lS;00R9Rl08bP^020U:`0J7bD09R/_01LL7`0N8bH08BHY01dR9@0I7R407b<V
01HJ7@0M8B@08RHY024T:00O8RL07b8Y014D6`0I72<09bXc02<V;`0J7BH201`O9P@06ahU01T04A@K
01HI800V:C0061/R01hQ:00B5A`06Q/P020Q9P0F5a`0?3e202l`=@0T9BX071dR01XK800I6Ql061TN
01HG700E5Q/061TN01/L8@0F5a`05AHK01HG700D5AX061TN00<05aPM0P0H6Ah00`0F5R0061PR01TI
8`0201XJ900701TI8`0G5b4061PR01HF800E5Al061PR01XI8@0201DD6P0F01PG7P0D4a/051<K01PF
800G5B005Q@O01@B7P0C4Ah0518O01PF8P0H5R405A<N01<A700E4ah061HQ014?6P0E4ah07adX01LE
800<2QD04@lJ01LE7P<05Q<J00@0514H01<@5`0A3QD08AhU0P0H5A`01`0?31<0514H01PC6P0L5ah0
4PdD014<4`0?2Q401`0E41L00`0E41H050lE01D@5P0201HA5`0C01<>500L5ad06A@J00l:400B3A<0
7QTO00/6300L5R006Q@N00/63`0@2a804PdD01D@5`0G4QP050lE010;3`0F4AD05a8F00h93@0601@>
4P0;018<400G4AD0618F01D?4`0C3A404P`@01LB600B3A<03PT?010;4@0B3A<00P0>2@l01P0@2a40
4`hD01@?5@0D3aD04`hD01LA5@805@lC00X01`4500d72`0K5AT040X>01<=4@0F41@05a4E01@>4P0@
2Ph04`dA0P0A2`l02@0B310050hB01D?4`0I4aL03PP<01/E6@0H4QH02P@8014;3`02018<40804`dA
00T04P`@014;3`0A2`l05Q0D018<400A2`l04`dA00T31`0A2`l00`0C3A40100A2`l040X>018<400B
3102014;3`0G018<400C3A40:2<Y00l:4@0F4AP08A`S01PC6@0?2Q004`hD03Lb>03Pfn40X9^O02@O
9@0E41@03PP<00/52@0D3Q804P`@014;3`0?2@d04P`@014;3`0=1`/00P0@2Ph04`0D3Q804`hB01<>
4P0E41@04`hB01@?4`0L5a/04`hB00<00P1:ADT0<B``02@O8`0<20X071PI00h:2`0G4a@05Q8C02`X
:@0D41400`0C3a000`0B3Pl0510A01XD5P0201TC5@0501@>400:10H05a4C01XD5P0:10H00P0=1`T0
2@0C3@l04P`>01LA4`0A2`d04P`>01@>400A2`d05Q0B014;3@04010:3008014;3@0@1PL04@L801@:
2`0K4A8081HG01L=3P0A1`P201882@0301<92P0D2P/050X;00804`T:0P0B20T201<92P0P01D;300D
2P/04`T:0147200@1PL03PD6014;3`050@@09b8V00h93@0<1`/06A@H07]fNP2RWJ402PD900d8300E
41@0208600`31P0>0`L050T=01P=4@0R5a/0Uhb@01dB5P0A1PX02`0401052@0B1`/040D901872`0F
2`l201<8300901D:3P0C20`04`P<00h31`0C20`050T=01P=4@0b9b/04PL;008040D900H04`P<01@9
3@0C20`05``@00l4200>0`L201872`0=01052@0B1`/03@8600l4200E2Ph04`P<00h31`0A1PX05``@
01X?4`0D2@d04@H:01<8300501462P804`P<100B1`/201462P0:01<8300D2@d04`P<01462P0?10P0
4`P<01D:3P0@1@T03@8600l420804@H:00@040D900l4200?10P03`@80`0A1PX05P0@1@T04@H:0146
2P0?10P050T=01462P0Y7R802P0301@93@0B1`/040D901<8300F2`l050T=01882`0<0`P04@/?00h8
30080PH04@/?00d82`0?2@d200h83006010:3P0A2`l050hB01dB600D2@l040D;0P0E2Q003@0D2@l0
6a0F00L00P0G31803@8801L<4P0F2a406@hD00l42P0900@050T?01<83P0D2@l01@0A1P`00`0@1``0
3@H>00`73P0200d83P0800h93P0?2@d04PT>00l62P0>1@P04PL;01<8300@1@TDooooo`006oooool0
200=1`T03`T;00l92`0;1@L0618D00`6200=1`T03PP:0`0?2@/03P0>20X04@/;014;2`0@2PX040X<
014;3P0A2`l03`P?01<<4`0F3aH0:24Y01@=5@090PX050T@0P0F2a40=00C20h04PL=01<83P0G3180
4@H<01<83P0K41H04`P>01T>500H3A405P/?01@93@0B1`/04@H:01052@0D2@d03`@801052@0E2Ph0
4`P<00l4200F2`l02P0300d21P0?10P04PL;00l4200B1`/04@H:01X?4`0G310040D901T@4`0;1@L0
3@L9010:300=1`T04@/=01@>400A2`d05@lA018<3P0600807aTK02LQ900A2`l0100202TS9`30^[h0
;RP/00/62@0B310301<=4@0O01D?4`0C41803Ph>00l=3P0B3@l05`hA01T>4P0J3a<060dA01L>4@0F
4A804a4B010@400>3@d04@d>01<?400B3Pl04@d>01<>4P0?2Ph04PdA01PC6@0F4AL040/A018=500C
4A@05A<D01HD5@0C4A804Q0A01DC500201<A4P0501dK700C4A804@l@01<A4P0F51L00P0E4aH00`0F
51L05aDH01HD5`0201DC5P0_01LE600J61/06aTL01LF6@0;310051PK01<G6P082a005aXO00H93P0E
61l061/R01TL8`0H6b@05aXS01PK8P14Adh09BP^01TL8`0M82L07R8Z024U;P0F7BD07RD^01XQ:`0I
8R/08BXd01hV<@0L9S0072Ha01/T<`0K93D06R8f01TQ=P0R:Sl08BTm02@]?P0U;Sd08R`g02D_>00R
;cL07BX`020]<`0T<CL08Bhd020]<`0S<3P00P0V<c/202@a>@0D02@c>P0^?TD0:ca402Pi@@0/?4T0
:SY90351D00/?4/0;3a902hoB@0W>440:CY1028c>P0_@TP0<TE;02e0AP0]@4L0<dE?03A6D00hBUH2
03E7E@040353D@0`@E40=DIF03M9E`80;T1<06D0=4IB0353C@0W>D<0<TA>03Y=E00dAdh0<dI=03Y=
E00fB540=DMA02i0BP0fBE40@5=J03]>E00iC540;T5502Lk?00X?3d0:cm002Xn?@0gBT/0=TQ<03E7
B`0_@DD07c4e02Li?@0X>Sh0838f01d_<`0[?D40=4I:02/m@@0/?D<0;d1701l`=`0/?D@0834h02Lh
?`0a@TT0;Sm60352B@0eATd0;Sm603E6C@0hAd`0;C`o02He>00Z>Ch0:CPm02He?00_?TD0;3]202hl
A@0c@DX0<Cm8030oB@0`@T`0:C]702XlB`0`@ED0;CeD0351FP0iBF80?dmV03i@H00W>D<0;3m502i2
@`0R<cX0:3Ho02@b>`0R;cL0<3e502@a>00nBDl0GVU_03<n@P0H8BH07bP]02D]<P0S9c0061`V02P/
=@0L8BL08RL/02ld>00N9RT06b8W01/R:00J8BT06b8[028Y<`0R9Rl0720Y01PL9@0I7R@0724W01hS
:@0A5QX06b0T020U:002018G6P0:01LL7`0O8bH07b<V01dQ900P92L07b<W014D6@0I72<08bH]01HI
80806ahW00@03a8K01/N9@0K7RD06ahU0P0J7B@0200I72<05QTP01PK8P0K7RD03Q4H01dP9`0O8RT0
4a@I0P0H6Ah0100N7b@04Q<H020Q9P0L7B8301TJ7`0601LH7@0F5a`051DJ01TJ7`0G61d06a`Q0P0R
8bP00`0F5a`05aPM01LH7@0301PI7P0?01HF800H628061PR01LG8@0H62806QXT01PH8P0F5R005ADO
01HF800G5b4061PP01DD6P0D4aT05aHM00804a8J02@05Q@N01HD7`0G5B005Q@P01DC800F52406ALS
01PF8@0F51l05A<N01HD7`0H5R405A<N018@6`0C4A`05Q@O01dK9P0K6B@05Q@L01HC6P0G51/061DL
01HC6P0E4QT04a0G01`I800C41L06AHM00l<4`0C41L05a8I028M900D3aH07aXQ01@?5P0K5Qd2018=
50<04`hE01T050lF01<>500B3A<050lE01LB600H4aT050lE01/F700C3Q@04@`B01HA5`0I51X050lE
01`F800D3QP03@LA01D@5`0>2A004`hE00l:400F4AL05A0D010;3`0C3Q804@`@00804`dA0P0B3103
014;3`805Q0D00/04P`@014;3`0D3Q805Q4G01D@5P0?2Q0040/A018=4`0=20h03PT?014<4P0201@?
5@0?018=4`0@2a40:28V010:3P0?2@d040X>01PB5P0C3A4050hB01D?4`0F41@05a4E01<=4@0=1`/0
4@/?008040X>0P0B31001`0C3A405Q0D00@00P0D3Q805a4E00T31`0C3A400P0B310201<=4@03018<
400A2`l04`dA0080208600L02`D901D?4`0<1PX03PP<010:3P0B31005@lC00805Q0D0P0C3A40:P0B
31004@/?018<400D3A@09b8Y010:500D3aH061<J01@?5P0A31808ahT069MH`3`kO00XijR02dX;00H
4aL0208600@00P0>20`05@lC010:3P0A2`l050hB018<400@2Ph050hB01<=4@0A31001@0400d8300I
51P02PD9010;3`0?2`h05A0D01`G6`0^:Bd081/O00T4200H51H05a<D00d92P804`l@00D081`M014=
3P0?2``04Ph?01<?4002010<3@0>010:300400005Q0B01dG6@0C3@l05@lA01<=3`0<1PP06aDG00X4
1P0>20X030H801H@4P0?2@/200X41P0400/51`0E3a404@/=010:30<03`T;00L04@/=0147200C2@X0
4`T:01D;300H3Pl04@L800<04PP90`0C2@X01@0F30d050X;01882@0B20T050X;00<05P`=01L050X;
01<92P0B20T040L:01H@500>2@d00`0201@?4`0B3A408QdQ0:JQY@2m^[d03PT=014<400<20/03`T=
00`31P0C20`02P0300`11@0;00@0;R<W01H;3`0201872`0@01@93@0A1PX03P<701052@0?10P04PL;
00X10`0:00<05@X>01462P0C20`05P/?01D:3P0?10P07Q<G01052@803`@800@040D901872`0D2@d0
4PL;0P0?10P03`0C20`050T=01@93@0B1`/03P<700l4200B1`/040D900d21P0@1@T04PL;01D:3P0B
1`/03`@801872`0501462P0?01@93@0E2Ph04`P<01@93@0F2`l05@X>01<8300B1`/04`P<01@93@0C
20`04PL;01052@0C20`05@X>008040D90P0A1PX201052@803`@800<040D901462P0@1@T0100@1@T0
4P0F2`l03@8601D:3P0k<3@050T=01L<400@1@T03`@801052@0C20`050T=0188300800@04P`@014;
3`0g<CD0OgUm01HA50803`T=0P0>20`01P0@2Ph04`dA01P=4`0A1P`03`@:01<83P804@H<00`05P/A
00L00P0c:2h04PL=01D:400=0`P0304700L00P0P5A/08aPN01P=4`0;00H501052`0=00l62`0;10`0
2`H=00`73@0=20h03`T>010:3P0B2@h03PD900l62@0D2@d04`P<00d21P0Dooooo`006oooool09`0B
30h03`X;01H@4P0:10H04`d?00l92`0H4Q@05@lA010:300>20X03`T;010:300>20P040/:01<=3P0C
3A004@/?00h83@0=1Pd03@L>014:4P0F3aL030@?01<<500C2A0060dC01L=4P0C2@h04PL=01<93P0B
20d03`@:00l52`0C20h03P<901L=4P0F2`l05@X>01<93@0201<8300401<9300A1`X050T=01<93080
4PL;00l04`P<034V:P0:0@<07a@H01<8300K41@03`@801H;3`0@1@T05``@01@93@0J4A<0;B@W01@>
400>20X00`0A2`d05`0@2P`04`d?00P3100C3@l030L801PB500=20X03`P>00l83`0F3aH0=c0f00h7
3P0C31804P/A01<<4`0B2a404P`A01D>5@0E4Q@04Q8B018@4@0C3a0050`?00805@/?05H05@/>01@<
3`0E4A80518C014A4@0?3Ph04`l@01HB4`0E4A80510A01D@500@2`l05Q4E014=4`0O6R005A4G03<_
=00O7Al04a8A01<A4P0H5QL04Q0A01<A4P0G5AH03P`=01@B4`0D4Q@05aDG01PF600C4A@05A<F01LE
600E4aL0518E01LE6@0K6Ad061HI01HD600G5AT06ALJ01PG6`0E6A`04QLJ04eBEP0g?4006QlT01@I
7`0C61h05QXR01HJ8`0E6B8051PQ01DJ800O8RP05aXO01dP9@0N8BH061`R01lT:P0K8RP082L^01TP
:00K92/092de01`U;P0J92h072Ha01hW=P0P:CX08b/o02@/@P0Q:Cl08RXn028Z?00N9cL07RPe02Xd
?P0iATh0:3Dl024^=00R;cH08c0f02Db>@0S<3P09S<k02Dc>`80934j04<0938k02Lh?`0X>D409CHo
02dmBP0oCeh0;cm>02/kBP0/?4T0;Sm:02XkA@0`@DP0:S]302Xm@P0aA4T0;T5602i1B00dAdh0=TU@
03A6D00dAU40<D=?02XlB@0bA540?4iK03e?G@0eAeD0=dUG03M9E@0jC5P0?4mK0395C`0dAdh0>diE
03M:D@0jCE@0=4I?03Q:E00iBeD0?e5J03a?EP0dAdd0<TE:02i1A@0^@T<0;D1102Xm?@0Y?3`0:C/m
02@e>@0Z>cl0:ca002Hh?00Z>Sl09SPl02Tk?`0Q<cL0;3i204mQI@1@HVL0;3e303A5C00U=Sd0:CY1
02Hf?@0Y>D00;Ce40080:ca304/0=4E<02/mA00]?dD0;cm502ho@`0_@4@0;Ci202Xj@00b@TT0<d=;
02hnAP0`@4T0=4==02loB00^?TX0=DME03A7E`0dAeP0=4IL03=5G@0a@U/0:ceD02TjC`0Y>dX06blf
01da=00M<C407bld02<a>@0N;3<07R/c02ll@`0X=3X07bX_02<^<P0M9RX0;CLi02D_<@0M9RT0:2`e
02<V<00L7bP06b0V01TO900O9RT072@W01XR9P0N9B/072<[01LN9`0L8b`06b0W01`P:00M8RT07b<X
01/P9@0F6b005AXN01HK7P0L8B@07R<V03<h>`0N8bH061`O01/O8P0Q9BP07R8U04A7B`0L7b@05APO
03Hi@00L7bH06A`U01/N9`0B5Ah00`0L7bP03P0K7RL06QdV01TL9@0J7BH05QTR02<V;`1KGVL05aXS
01LJ8P0L7B8071dS01HG700J6b007AhT0P0J6b002`0F5ad05aPM01TJ800G61h05AHK01HG7@0J6b40
61TN01dM8`0T92/092DZ00806AXP00@06AXO01PI7`0F5ad05QHM0P0I6B<02P0G5b405ADO01PH8P0N
7RP06ATS01<C7@0E5Al06ATS01LG8@0F5Ad201@C6@0301PG7P0F5Ad05aHN00805aHO00h06QPS01PF
8P0D4Qh05A<O01PF8@0G5Al05QDN01DD7@0F5Ah05aDO01HE7P0G5B005Q@O01<@6`806AHQ00D05A8J
01<@5`0B3aH04PlF01<@5`0201DB6@0501HC6P0C41L06aPO014>5@0T8BP00P0D3aH201HA6004018=
500D3aH04`hE01<>5@8050lF00D05A0G01HA5`0D3aD050lE01HA5`0201PC6@0301@?5@0B3A<04@`B
00805Q4G010050lE014<4P0A2a@05@lH01H@6@0:1@`06A@J014<4`0D3aD03PT?010;3`0G4QH04PdA
01<>4P0E3a<050hB0P0C3A42018<400<00h8300C3A404`dA014;3`0E3a<07AHL010;4@0N6B006A@K
010;4P0B3A<050lF0P0C3QD0100A318040/B010;4P0A318201<=4@0<01`F6P0C3A404@/?01<=4@0J
51P050hC014;400C31805@hD01<<4P0@2Ph04P`@0P0C3A43018<400300l93@0@2Ph06aDI008050hB
0P0B310201<=4@0W018<400A2`l04P`@00/62@0b;300:28V018<400=1`/04@/?010:3`0@2Ph04@X?
018<4@0B31004@/@01<<4P0B31003`P=014:400D3A@04`hG00h84`0B3AH03`XA010;4P0E41H02@@:
024L801GDUH0@cm001TE5P0D3a40618F01D?4`0C3A403PP<00`62P0C3A404P`@008040X>01X0618F
01TC5`0D3a<05@lC00X52@0J5QT0MW5e06IQI@0E41@05a8F00`72`0@2`h06QDH018<3`0B30h040`=
00l;3@0B3Pl04`l@014<3P0E41<04Ph?01LC500H51H04@d>00h:3080618D00@04@`=01PB500@2P`0
50h@0P0A2`d0600/9RP03`T;01<=3`0C3@l040X<014;3@0F41806A<E01D?4@0B30h04`d?018<3P0A
2`d040X<014;3@0C3@l040H701@:2`0C2P/04@L801<:2`0B20T050X;01<92P<04PP900<040L80106
1`0A20T00P0C2@X05P0B20T03`H701<92P0B20T04@P90147200@1`P03`H900d72`0@2Q002P@;010:
4@0>20l03`T>01XD6P0b;34030P<01TD6@0:1@X04`dA0189300@1PT201872`804`P<00/050T=01<8
300B1`/05P/?01`A5@0O51P040D900d41P0@1@T04`P<01462P0201872`0:01<8300>10L04PL;00h3
1`0D2@d04PP;01T>4P0G3A404@L;01052@804@L;00H050T=01<93@0A1``04@H;01@93P0A1PX40187
2`804`P<00D03P<701462P0C20`04@H:01872`0301462P804@L;00L04`T=0147300?1@T04@H:01@9
3@0C20`04PL;00804@H:040040D901462P0A1PX04`P<01872`0>0`L04`P<01lD600K41@04@L;0147
2P0@1PX040H901462P0B1`/04@H:01052@0A1PX04PL;01862P0@1@T03`@802lU:00d:Rh05P/?00/2
1@0A1`/040D901062@0>10L03@8600l5200A1`X0FE5G02@M900@2A00E4eD0;Zc^P0U7bD04@XA00l8
3`0=1Pd030D<00h73@0@2A004PP>0106300B20h04`P>00l52P0A1P`040D;02XP9P2j/;H0>Bhd00T0
1@0@1P/05@X@01D<4011=cd06a0F01<93P0=10T040D;0P0@1P/01@0@1@/040H;00l6300>1`l03PP?
00803@L=00P030H<00h62`0<0`P04@P<01@;3P0D2@d04@H:00l421Cooooo000Kooooo`@03`T;0P0@
2P`2018<3P07010:300?2@/04@/=01@>400@2Ph040T@01L@5`0200h73P0M018;4`0@2A4030H=01D>
5P0@2Q403@H>01D>5P0B2a405@`A01<=4@0C2a004@P=00h8300B2Pl050/@01TC5`0B2`l04PT>01`F
6P0>1`/050/@00`62P0?20`05PdB014;3`0B2Pl030<800h8300A2Ph00P0>1@X00`0D2@d04@H:01<8
300201872`0801H;3`0J3a<05``@00h31`0C20`0:AhR04e4A`0J51H200l92`1<01D?4@0C3@l0618D
01@>400<1PP05@lA01PB500A2`d03PP:010:300@2Ph04@/>018<3P0C3A405@lB00d72@0D3Q8040X=
01D?4@0;1@T050l@00X82@0>2P/0510A010<3@0B30h06A<E01PB500?2``04Ph?01@@4@0B41407QXL
01H@500B3A404`hB014<400C4A@03@/>01dK7P0D4aD030X=01<C5@0C4QD06QXH01PI500C4a404A4?
01<C4@0F5QH04A4C00`<3P0G5QX00`8702@S:00D4aP07A`Q01PG700C4QL00`8802d/<@0/:c404A0F
01HE6P0J6Ah04a8H00l>4`0A41H02`hC02LZ;`2HVj80PHB;01/N9@0D5ah04A@K01@G7P8061/R06<0
5QTP01<F7@0G6Ql05aXP01hQ:00D5ah0:Bde01`P:@0N9Bd07B@]01`S;@0M9Rl092df02Tb>`0K9Bl0
8B/f02<]>@0P:CP08BXj02Pa@P0b>Td0:C5401PP<`0T;3l082Pk07N0T@3Pj_H0<3]401/X<00D8BX0
934j020^=`0T<S/082hg01X[<`0U=Cd0938k02`mA@0W>D40;d5;02/mA`0R=3h0:Sa803E7D`0X>TH0
:C]902HhAP0/?TX0=DME02Dg@`0X>T@0<49<0353C@0_@D/0<TA>02Dg@@0bA4h0;d5;02`nB00bA4h0
>diE03a>F00hCE/0>DaK03Q>F`0fBeP0;D5<03I<E`0iCeL0=DU@0357C@0lE5P0?eAI0396C00hC5<0
=dYA03A7CP0aA4/0<D9902i0A@0jC500@E=G0310@`0T<cH09cHi02dl?`0O;C009C<f02Le>00lBdh0
C5UO02hm@P0]?440;Ca302hnA@0dAD`0=DI>0311A`0]?d<00P0]?440:00[>3h09c@l02Tf?P0_?TD0
;Sm702doAP0aAD`0<TM=02`oA@0W>T00:Se302m2B00]@4L0:Se503Y<EP0gBED0<dEC02/mB`0Y>dT0
:3Y;02XoDP0Z?e@0;T=G03=5F`0a@eL0:ca?02@eA@0V=TD0834k01/Y<P0Q<3L07R/`01dX;P0Z=C/0
6RD[02dh?P0I92X0:C8h02</<@0Z<cP202<];`0Q01dW:00T;Rl06b8X04E<DP0Z<CL06B0V01TQ9P0I
8RL05b0U01hW;00J8bP05b0U01/T:@0N9B/04QDJ02DX:`0O8bH07QlS02<W:P0I72406b0T014F6P0K
82@06B4T04=;C`0F7R4092T]01TN8P0D6Ad06b0T01hS:@0>4aT04aLP00806AdV05T05QXU01PL9`0N
8Rd07B0Y01`O:00H6b@05QTR01PK900K7RL082</03Hi@P0Y;3D0C4mH01dP:@0E62405APP01LJ8`0G
6R405QTQ01DH8@0F6B005APP01DH8@0H6b806QdU01PK900F6B007alX02PX<P0Q8BT05QHO01LG8@0I
6B4061PQ01`L9P0J6R805QHO01@D7P0C4ad07b8[020S;00F6B804QDN01XJ900I6B<051@N01DC7P0H
5R405A<N01HD7`0I620051<I01<B600F5A/05A@J01LF700F5A/06aXP01PG7`0G5Qh061LO018A6@0N
7B80;bla01dM7`0E51P061LL01lL8`0I5Qd05Q<L01DB6`0O6b@050hH01PB7P0E4AT04a4F00l=4P0B
41D040hC01HD6@0P7R<05Q@I01<A5P0G5AX05A<H014>500F4aX05A8K01@A6P03018?5P80518G00/0
518F014?500A3a80518G00d83P0H4aT03PT?014<4P0J5A/04`hD01@?5@0201<>500?018=4`0A3180
4@`B01XE6`0?2Q004@`B00h93`0;1PX0>C@i02LR9P0N6Ad04PdA014<400C3Q804PdA00804`hD03P0
;RT_01HA5`0A31805Q4G020K8@0>2Pl07QTO00<0100C3Q@050lE018=4`0?2Pl03PT=00l:400?2Pl0
3`X>01HA5`0E41D04`hB018=4`0B3A804PdA02<N8P0S7b004@d>00`72`0D3a@03PT?034/<P0?2Q40
40/B01`G7P0U82P02PD<01<>4`0A31004PdA00l:3P0A31005a8F00h93@0910P04PdA01D@500B3A40
4@`@018<400C3A4050hB01<=4@0A2`l03`T=010:3P0D3Q805Q0D01D?4`804`dA048040T@00l8400C
31<04PdC01L@600>1`h05@hE014:4P0700L050dD018;4`0B2a8040T?00l93@0A2`l04P`@01<=4@0B
31004@/?014:4@0B2a805@hE01@=500B2a404@/?00l93@0A2`l05Q0D01/E6@0F41@04P`@01D?4`0B
31003PP<010:3P0B2`h071<F00H0100R7200[ZV]08n=T00E4aD05A4B00/51`0A20T07a<E01h@400B
20/05@lC01@=500D3A<050hB01@=4`0;10/06A<G01PB5`0D3A@03PP<01@=4`0J51H0100001PC500P
6Q`07ALI00l92`0B30h2014;3@0Y010:300A2`d04P`>00d72@0>20X05@lA010:30080P@03@L901/E
5`0:10H03@L900X41P0?2@/04@/=018<30090`<04`/<01<:2`0@2PX04@T:01<:2`0B2`/04@/;01<:
2`0B2`/04@/;038Y;00C2`h02@<500/21@0D3@l03PP:01/B5@0?20X03@L901072P0>1`T05@`?01<:
3`0E2a800`0F3A803P0E30l030<801@;3P0B2@`05Pd@00h51`0@1`P060dA0146300J3aD04`P>00l5
2P0?10X04`P>0P0A1P`00`0C20h0;R<Y04Hk@@0601462P0H01H;3`0A1PX06@hB00`21@0/8BD03@86
014:300H3a8030H801TB500K4QL01P0401493P0=10T050hB01@;4`0>10`04`TA00/11@0B1`/05``@
01872`0<0@D03`@80P0>0`L04P0?10P04@H:01<8300D2@`01`0001<:3@0>1@T02P<:010;4@0>2@l0
5A0F01D>5@0@1`/04`X=00T0000F30h03`@800`11@805P/?00l04`P<01872`0A1PX05P/?01052@0E
2Ph06@hB00T21@0M5a/01@0100d5200E30l04`X=00l51`0A1`P00P0B1PP201@5200l00`3100H4Q@0
3@L80189300@2P`02`D600l62@0=1`T03PL900l62@0=1`T03PL900X32P0>1`h030D<00d63@0D3A@0
3PP<00X4200>20`04P`@014;3`0?2@/03@L;00H010090`L04@T>00`3200A2`l04@X>00l62`0=1`/0
9b0T01483@0=1`/03`P<01063P0>1`h060lG01/A6@0@20l040T@01063P0?1`h03PL>01063P0?1`h0
40H>01D;500@1Ph04@L?00P01P0F31<06a0F00P00`0H3A801`0001<8300H3A401`005?ooool001_o
oooo00T04`d?014;3@0>20X03@L9010:300B30h03PP:010:300?2@/00P0=1`T03`0@2Ph05@hE00P2
2@0400D030D=014:4P0C31@02P<;00d63P0L5Ad06Q<K014:4P0C31<03PP<00l93@02010:3P0;00d7
2`0<1PX03`T=010:3P0F41@03`T=00h8300I4aL05Q0D01D?4`0A2`l00P0?2@d08P0>20`030H:014;
3`0E3a<04P`@014;3`0G4AD04`P<01872`0E2Ph050T=01462P0D2@d05@X>00`11@0>0`L06@hB01L<
400[8RD050h@00`6200=1`T04`d?018<3P0=1`T03PP:01<=3`0A2`d02P@6014;3@0H4Q@04P`>014;
3@0@2P`200l92`0400X51P0D3Q0030H801LA4`803`T;01/061<D01<?400C3a004`l@00h:2`0<20T0
3PX;01DA4P0F4Q<061@E014=3P070`@03@P;00l93@0A31004`hB014<400B41<040hA00`:3@0F5QP0
4A4C01/K7@0E5AH05ADC01@E400C4a000P0B4Q00400B4Q8092@V00`<3P0C4QL07A`R00l>500@3aD0
@D1601TH7P0F5A/040lE01HE6`0K6R004A0F01DD6P0H5ad201DD6P0901/K800L72@010L>03`oAP0T
9bh03A0G024T:`0G6R4061/R00<06A`S02H06A`Q02d`=@0F6Al07B0W01@G7P0K7RH07b</01dT;00L
8b`06R4[01TR:`0L9Bh07RL`01TS;@0O:C@08B/g01hX=00P:CL09Bhm01<L;@0O9cT06b<f03<kD00^
=T/0>D5D05eWL`0M:C80:cQ102@a>P0^?4D09cDn02Hd?@0W>400;3e5020a>@0Z>d<06b`d02<f?@<0
9CM10800:ce902m1C@0Y>dL0:3Y802DgA@0a@e40AeQX041BH00]?d`0;Cm;02`nBP0]?d/0<dE?02Li
@`0a@dd0;d9902/nA@0aA4/0>DaB03Y=E00iCU`0<DME02m5DP0dBUL0=D]F04=II00jDET0>U5G03Q?
E00]ADT0<TY>03]AE`0hC5<0=TU@03E8C`0bAD`0<T=:02/m@P0^@4@0=4=802`k?`0Z>C`0;3Xm02`h
?00O:Rh09c8f02@`=00`?T40>dQ>02@b>00/>d00<D1703A4B`0eATh0;d1802Xl@@0/?T00;3]002dk
@00[>3h0:S@m02Pd?00]?4<0<3i702m2B@0_@dX0:D1602]0A@0X?D80:Ci302a0A`0Z?TD0;T9;02Tm
B00Y?4X0<dIE02i1D00Z?D`0;T5C02i3F00^A5/0<TML03=5F@0`@e@0;3e=02LgAP0R<cd08c4k02<`
>00L:C4082/a024Z<@0R:c808BXa01DN9@0S;3<0:C8g02D^<`0Y<SL07bT[01lY:P0K9BH09S0a038k
@02ma//0CEIK01@M8P0]=S/04AXO01TR9`0L9BX06R<X01`U:P0P:Bh07RHY01TM800U9RP0824S01hO
8@0N8B<05QXM010E6@0F6al07b@X01<J800U;38072<Y01TN8P8082DY01T07B8X01PM8`0>4aT04aLP
01LK900H72D05a/V01XN:@0M8B`07B0Y01`O:00I72D05QTR01PK900K7RL07B0Y024T;@0D5b00:Rdf
01<F7`0E62406QdV01`O:00K7RL061/T00805aXS00X061/T01HI8P0G6R<06A`U01LJ8`0E62406ATS
024Q:`0K6bD05ADO0P0F5R003`0I6B<06QXT01XJ900L72H07AdW01`O:00>4Q/06QdV02DX<@0O8R/0
4a<M01HF800E5Al05Q@O01TG8P0201HD7`0T01TH800E51X04a8H01DD6P0B4AL04a8H01PG7@0B4AL0
3`hD01XI7`0A41H061LM07elP02_[jl0?3`l01<C500B4Q@0928W01TG7@0>2a803PPB018<5P0D3QP0
81PU01LA6P0@3Q<061HK01HD6@0=2a0071XO02LU:P0E4aP04Q0E01HD6@0C4AH040hC0P0C41T0400B
3aP04PlF01<@5`0D4AP040hC018@5@0D4QD04Q0C014?4P0B41<06A@J00h93`0T7bD01@0601LB600C
3Q@2014<4P<04`hD01l04PdC018=4@0@2`l06A@H01@?4`0:1@T07APL01/F6P0E41@03`X>014<400B
3A403PT=01LB600A31806aHL00d83P0@2a405a8H00l:400K5Q`05a8H014<4P0@2a404@`B01TD600;
1PX04@`@01/F6P0I51P05Q4E00804PdA0P0A3100500B3A404`hB02@P8@0T82404`l@00l:3P0C3Q<0
3@P>01D@5`0B3AD04@/E00h84P0O6B@04`dG00l:3`0C3Q805a8F01<>4P0?2Ph04@`@0P0@2`l01@16
@DD02PD901LB5P0D3a<04P`@00<04`dA00<040X>00l93@0B31000`0C3A407`0D3Q805@lC018;4P0>
1`l02049028K8`0?210091dU00`63@0<1@d03`P@01XC6`0<1@d03@H=01<=400A2`d03`T;00h82P0>
20`03@L;00l93@0B2a805@hE01@=500A2Q803`P?010:3P0A2`l04P`@01<=4@0D3Q800P0F41@04@0C
3A4040X>00l93@0B31004`T>01<8300A20d05a8F034/<00R82<02`T;00`82@0<1PH06Q0A00X0000;
000060`@008040T@01004@XA01@=500E3QD0:b@[03</<`0<1P`030D<014:4@0B2a4040X<04Do@@1?
BD/04P`>02DO8@0K5AL04P`>0P0A2`d0100@2P`04@/=018<3P0D3Q0201dG6@0?01<=3`0B30h04@/=
014;3@090`D081XL01/E5`0600804P`>01PB4P0<1PH03`T900`61P0>20P04P`<00H04@/;02@04P`>
01<=3`0H4Q@03`T;00X41P080P@07aTK014;3@0=1`T03`T;01H@4P0Q6ad04PL?01L<4`0L4AL06a0F
01D:3`0>0`L050T=01@:300<0P<04@L800`20`0@1PL01`0001<83P0800<02P0502TN900A1P`03`@:
01873@0D2@l02`4601052`0L4AL201872`@04`P<01P02`4401052@0M4QH07Q<G04@i?@0[8RD03PH9
01<=3`0@2P`07aTK02@N8P0G4AD03PP<00h73P0D3A@03`P?01094@0K51/05@X?01T>4P0M4QH05``@
01872`0D2@d300l4200/01462P0B1`/05@X=00`20`0E30l04@T>014<4P0300D04@hE00401@0?20l0
2`@801@;3P0<0P<06Q0B01462P0>0`L05@X>01<8300@1@T04PL;00/0100=0PH03P<700d21P0C20`0
4`/?00<00P0F41804@/=018<3P0A20/040H80147200B1PP04`H801@5200E1@H050P;00P2100?2@/0
4@/=00`6200A2`d600d72@0N00l83`0B2a8040T@014:4@0G41L04P`@00l93@040080:28V03Pb=00C
3@l02`H701<=4@0@2Ph04`dA00/52@0>20`040X>014;3`040080618F01D?4`0=1`/040X>00`53009
0PT04``C01lH7`0F3aH030D<1P0>1`h0300@10h03P<<01<8400T6B40>Bhe00L00P0>0`T0<bP]01hC
5`0=0PH02`8401T>4QCooooo000Kooooo`0701H@4P0B30h03PP:00d72@0?2@/04P`>00h82P02014;
3@0A00l92`0<1PP03@L:00h83P0A2Q406A8I03D^=@0M5Qd02`D;00d63@0@2A004@XA01PA600A2Q40
3`P?00h8300?2@d0100@2Ph200h83006018<400>20`030H:01@>4P0B31003@L;0P0@2Ph0400>20`0
4@/?00h8300@2Ph04`dA014;3`0@2Ph050hB01@93@0B1`/050T=01<8300B1`/05@X>01872`0A1PX3
01@93@0>01072P0@2P`03`T;010:300A2`d04P`>04M1@`1?BD/07aTK00d72@0D3Q004P`>010:300A
2`d3010:3008014;3@0D3Q00618D010:300J51H030H801LA4`0@2``2018>3`04010<3@0D41404`l@
018>3`805A4B01L040`=018>3`0G4a@05Q4D01<=4@0B3A404@`@01@?4`0Q7b809R@W00X82`0D51H0
3`lA01LG6@0=3@l04a<B01@D4`0E5AD05ADF01@D5@0C4QD04Q4F01LF6`02018A5`0400d<4P0J6B40
?ci401XI7P805A@I05T04A0E01<B5`0D4aP05A@I01HE6P0D4aP05A@I01/K7`0T9BX06A`P01LJ7`0E
61d07B4U00lB5P0C5Q/04QHJ018E6@0B5AX051LK01DI7@0H6al06A`P01HI7P0N8BH0:Bdc01hS:@0J
8BL06b8Y01`S:`0J8bX06R<[01XS;00G8BX072H`01hX<P0L9S007BLb020Z=P0V<3d082Th01hW>00X
<D<09Bdo020Y>P10BUH0?dYD02Db>`0M:S<0:3Ho01l]=P0L:S<0D65Y05]/M00N;cL0=DI>02Hg?`0U
>3l07c4k024c?@0[?DL0;T1<02doB`0/?TX0;T1>02TkB@0V>4H0=TMG0394DP0bA540<TA@0353C`0/
?TX0<TA>02XlAP0a@dd0<4=:02e0A`0aA4/0=dY@03I9D00hBeP0=TUG03A8E00jCET0?51K04YNJ00k
CeP0HgMn03A8CP0203A9CP1F03U>E00gBe80=4M>03E8C`0dAdh0<45802m1AP0_@DD0;Ca102/j?P0/
>ch0:SPk02Pd>00V<CD0;cXn02/g?00]>T00=45702Le>`0]?4<0;Ci502m0B00cA4`0<45902Xk@@0V
>3`09SDj02Hd>P0X=C/09c@l02Hc?00]>d@0<d=;03E7D00bATl09Se502XnA00Y?4<0:Sa302Li@`0V
>480=4IB04mPKP0cAE@0<45A03=3E@0eAUP0<41E02m2F@0/@5P0:d1E02i0E00/?e009cQ802DeA00O
;ST08c0k02Ld?00K:3008B`b02H_=P0X<CP0A4eD01dV:`0O:2d0624V01hX:P0T;S0082X/02<];P0L
9RL07bTZ024Z;P1MIV/0:C8g01LP9@0B6b006B8W01PQ9P0K92T072DZ020Y;P0T;C8072@W02@X:`0O
828201`M7`0301LJ700D61/04QLK008061dQ00`05ahT010G7@0N9B/06QlS01dR9P0J7b<06b0V01XO
9@0B5ad06AdV01PL9@0J7RL201hR;@0701XN:@0K7RL06ahW01PK900F6B805aXS01TL9@0201LJ8`05
01dP:@0B5Ah051LP01TL9@0K7RL00P0L7bP301PK900901/N9`0G6R<05QTR01PK900G6R<05QTR01/K
9@0M7BL06QXT00806a/U00@061PR01LG8@0C4ad051@N0P0F5R00<@0D5b005ATR01LJ8`0U:3407b8[
01<C7@0I6B<05aLQ01TG8P0L6RD05Q@O01DC7P0J6B406APN01LF700H5ad04a8H01@C6@0I61h071/Q
01PG7@0D4aT040lE01hM8`1XIf/0VIVI030`<00H61T03@d?01XH7@0I5ad06aPO01dG8@0G4A/071HP
01TA7P0N6240518G00d;400F51T05aDJ01DC600H5Q/04a4F014?500D4QL04Q0E014?500C41T00P0B
3aP02@0C41L0514H01HC6P0>31404@lD01DC5P0C4A@04@lB018@4`0201LB600X00h93`0S7R@04@`B
01<>500@2a404@`B01@?5@0E41H050lE01<>500B3A405a8F01`G6`0G4QH04PdA00l:3P0@2`l03`X>
010;3`0D3a<04`hB00h93@0D3aD040/A00d83P0A318050lE00l:400M61h0=2le01XE6`0@2a4030L=
01/F700=20`04PdA01<>4P0>2@d03`X>01PC5`<040/?01`04@`@01<>4P0D3a<04`l@01HB4`0?2``0
3PT=018=4P0>2@l03PT@01D?600D3QP02P@>01H@6`0<1Q004`hC014<400B3A403`X>014<400F4AD0
4@`@018=4@0a;3004@`@01D@500>2@d04@/?0`0B31001P0@2Ph03`T=01@>4P0A2`l040X>018<4080
5@lC01<03PP>01D>5@0U7RD0BT=:00`7300m=Sd06A<I01H?5P0E3QD02`H;02<L8`1IDeP06Q@G01LA
4`0D3Q004`d?018<400D3Q804`dA00<04P/B00H050dE01<<4`0?2@d04P`@01<=4@0A2`l200h8300B
00l93@0@2Ph04P`@018<400@2Ph050X>01L<400F30l040X<00l;300D4A80518C00`92P0C3Q0040L9
01D:3@0H2Ph04`P<0`0@2Ph03@0A2`l04`dA04I0A01VH6@050lB00`62P13?D40<2X^01H@4P0I51D0
9AlQ01D?4@0@2P`01`0A2`d03`0<1PP06A<E01H@4P0=1`T05@lA010:300>20X04P`>014<3@0?2@/0
5@lA030Z;00J51@03`T901D?3`09014;2`05018<3P0=1`T03`T;014;3@0?2@/00P0D3Q007@0>20X0
3@L900l92`0@2P`04P`>01T>5P0H3A@05P/A01@93`0B1``040D901@93@0H3A0060h?028H6@0J4100
4`T:00l4200G31803`@:0146300Z7bD05``B00l42P0B1`d05P/A01<83P0B1`d050T?00@04@H:0P0@
1@T01`0B1`/04@H:01872`0;0P@07A8F00/21@0C2`h00P0>20X04@0A2`d040X>00d72`0<1PX04P/B
01@=500<1@`050dE028K8P0D2@h050T=01H;3`0B1`/03P<701462P0B1`/04@H:008040D901004@H:
01472@0;0P<04@P;00l8300=20h05Q4H01@A600W92/08Q/R00l8300E30l04PP901882P0@1@T03P<7
0P0C20`04@0A1PX04`P<00X10`0?10P050T=00d21P0A1PX08Q/N05iIG@0F41803PP:018<3P0:0`@0
50X=01462P0B1PP04`H8008050D800D04`T;00`6200@2P`0208400T31@0700h82P0N00h83@0>1`h0
3@H=00h73P0?20l03PP<01H@500910L05a4E01hH700;1@T04@/=01LA5@0<1PX040X>00`62P0;1@T0
3`T=00d72`0A2`l030H:00l93@0@2Ph030H:00X32P0K51/0;2D/01PA600:10X05PlF1P0>1`h0300?
0`d05@TB01L<500=10X05PdB01@93`0B1`d050/>00h51`0@1@T03`D801<831Cooooo000Kooooo`<0
40X<00l03PP:00`6200;1@L03@L9014;3@0B30h040X<00h82P0=1`T02P<:00h73P0400@06A8I00l8
3`0O61l00P0=1Pd010080@P05PlF01@=500K51/200l93@0H010:3P0A2`l04P`@018<400@2Ph03`T=
014;3`0?2@d03PP<014;3`0E3a<040X>014;3`0@2Ph03@L;00h8300F41@050hB00`62P070PD091hR
03li?@0F2`l040D90P0A1PX02`0C20`060dA01052@0H3A405``@00`31@0O51P04@P;014;3@0C3@l0
4P`>00803`T;00L06aDG01LA4`0<1PP040X<01@>400B30h04@/=00804P`>00`04`d?01@>400E3a40
6Q@F01lI6`2=QhT0GEMI01XD5P0O6A/061<E01PD5@0F4Q<2010<3@15014=3P0@30d020@5014=3P0F
4Q<0510A01LC500A30l04`dA018=4@0?2Ph040/?01dK7P0N71l05aDH010@4P0F5QP05aLI018B500E
5AL051@F01<C5@0C4QL051<H01DD6P0920h03@`B018A6@0A41P0BdYB01dL9@0B4AL051<H01<B5`0@
3a@06aXO01XI7P0E51T05QDJ01LF6`0E51T04a8G018B5P0F5a/07b<T01<G6@0K7b8041@F01dQ8P0C
5aX05QXL01PL7@0I7B005a/M01DI6P0J7Ql07R8S00<72P0J7R409b/_01XO8`0I8B@072@X01hU:`0N
9b`07BH[01/T:`0H8R/072H_00807RPa0P0M9c403@0T;SP08B/g02H_?P0S;3/06R<b02H_?P19Del0
AU5K024^=`0U<S/08Bhg018P:@0R<3T00`0L;CD00`0W>4009SLo02Hi@00202@f@00a02TkA@0]?d/0
;T1<02LiA@0`@U00;T1>02DgA@0_@500;Cm=02i0C@0mCe/0@59N02m1C@0_@D/0;Cm903=5C`0dAdh0
<DA;03A7CP0hBe40=TU@03I:E00mDE`0=d]F03=7D@0`A4d0>dmH05AXL02calh0BUmU03eBE`13F5d0
?E5G03E9D00cATd0<TE<0313BP0/?D@0:C]002Tk?`0[>Sl0;Ca002hm@00a?d80;3Xm02Dc=P0Y=S`0
9S<i02Tf?00202hmA00c0350A`0]?TH0;3e50311B@0]@4L0:3]102@g?@0R<cX093@k02Lf?@0X=Ch0
9c@n02`jA@0_@4X0<TA?03A8D`0]@dd0<D==0393C@0b@T`0;3Y702TiAP0kBET0D5e^02dmC@0/>Th0
;CU?03U8G@0jAel0BE]c03]?I`0bA5X0>4YN03M:F`0X>4T0:cQ802@b?@0B7bT0218K01lY<P0Y=3X0
82T`030g?`0X;cD08RT_03U0AP0R:Rd07bLZ02<[;P0N9RP08b/]00806b<U00L07BDX01LO8P0E7B00
4a/N01PP8`0I8B@051`O00807BDX01h06b<V01`T9`0K82@08BDX01PI6`0G61X06AXL01HI6`0G6ah0
5AXN01PM8@0A5QX05ahT01hU:`0R:Bl07B8V028W:`0L8BD061dS01/P9P0J7bD06AdV01DI8P0G6b@0
6alZ01LK9P0=4A`05QTR01LJ8`0E624201<F7`0901@G800H6b@08RD^03XmAP0I72D061/T01DH8@0F
6B806A`U00806QdV00<06ahW01`O:00I72D00P0E62402@0I72D06QdV01XM9P0L72H06ATS01DE7`0G
5b405QHP010@6P0200h>600H01DE7`0H628061PR01TL9@0D62405QTR014D7@0?4Q/05QHP01TI8`0G
5b406ALR01`J9@0F51l04a4L01DD700B4AL04A0F01<B600A41H04Q4G01<B600H5ad05QDK0P0C4QP0
3P0=318051@G01@D5P0O7b404a<E018B500H5Q/04a0F01DB6@0S7RD05A0H01/E7`0?1a807QPQ0P0E
4aP0100F51T03@/@014?500J61d201<A5P0601DC600B41D0518G01DB6`0D4AX04a0I0P0B3aH03P0C
41L0518G01@B5`0C4A@04@lB018@4`0H5QT050lE01HA5`0O6R000`0400`73@0B3A<050lE0P0E41H0
2P0D3aD04PdC010;4@0@2`l04PdA00h93@0<1`/04PdA010;3`0D3a<2018=4@804`hB00@04PdA010;
4@0@2a4030L=0P0E41H03`0:1@/03`X@00/7300300@0GEQN028M8`0>2@l05Q4E010;3`080`L08QdQ
03/f>P0G4QH05A0D01@?4`04018=4@0H00h93@0B3A404PdA01@?4`0H4aP05a8H01<>5@0@2a807aXQ
01LA6`0F41X05Q4H01hI7P0G4QH05Q4E01D@500J5AT08QdQ01D@500500@071LK010;3`0;1PX061<G
0P0B3102014;3`8040X>01H04@/?010:3P0B31005@lC018<400@2Ph06Q<J01/D6`0400@06A8I018;
4P0<1@`0;RL^00H01P0@2A006A8I00h73P0T7R803`T<00l92`0@2P`04P`>0P0C3A401P0>20`03`P?
0109400;10/03@H>018;4P8040X>0`0A2`l05`0@2Ph04P`@01H@500F41@04P`@01<=4@0M4aP05@T;
01061`0I4A808QhM065MGP1[J6T00`4201@?4`0J51P05@`A00h52P0E3A804P`@01<=4@0A2`l040X>
00804`dA00d0208601D?4`0M5a/05a4E00X4200H4Q@03@L9014;3@0B30h03`T;01@>400@2P`04@/=
00804P`>0P0A2`d0100@2P`03@L9010:300C3@l2014;3@09010:300?2@/06A<E00/51`0500407ALI
01dG5`0C3@d05a4A00804`d=00<050h>010:2P0@2PX0100@2PX01`0B30h03`T;018<3P0L5QP02PD6
00`6200@2P`00P0B30h01@0C3@l040X<00X41P0I3QH050T@00803`@:01404`P=01L<400900803`D7
01D;300Q5aP05`d=00d3100G310040D;01`A5`0A1P`02P4500/01P0D2@l04`P>01052`0201463004
01052`0@1@T03`@800l420803P<701D03@8601052@0C20`04@H:01872`0G310050/>014:300;1@L0
3PP:00l92`0>20`04`dA00`62P0?20l04@XA00l83`0?21004``C01462`0?10P00`0B1`/0100E2Ph0
50T=01872`0A1PX201052@0=0105200;0@804PT<01D=4P0Q7280ThjE06m/L`3XiN`0Mg1g01@=4@09
00<07aDF0105200200l4200@01462P0C20`04`P<01052@0B1`/05``@01462P0M4QH08aPL02HO8@2B
S8h03`T;00`6200C3@l01P0001@:3P804@H:0`0B1PX01P0<0`D05Q0B00d72@0B30h02P@600l92`H0
3PP:00l03PP<00X4200?2@d040X>00X4200<1PX01@03014;3`0@2Ph02P@8014;3`0=1`/04`dA00X4
200A2`l00P0@2Ph0300?2@d01@0301D?4`0B310030H:00T31`0C3A402`@;00d63@0B2a8050dD01<<
4`L03PL>00`04PH@00/1200O51`05P/C00l42`0F2a4050T?01@93P0G31003`@801052@0N4aLDoooo
o`006oooool02@0<1PP03`T;010:300?2@/030H800T31@0;1@L03PP:00l92`0200d72@0>00h82P0C
3A405@hE00P1200A2Q405PlF03</<`0@2A003`P?00d63@0A2Q4010040109400?2@d200h8300;00l9
3@0@2Ph04@/?014;3`0@2Ph04@/?010:3P0?2@d040X>00d72`0@2Ph00P0=1`/02@0A2`l040X>01@>
4P0K5AT04`dA01XD601TGV80ViFI01H;3`0301052@0G01<8300I3Q803`D800l4200D2@d04@H:01T>
4P0<10H040X<018<3P0A2`d03@L900`6200B30h05@lA01<=3`0>20X02P@6010:300I4aD05Q0B01D?
4@0D3Q000P0C3@l01`0O6A/0BD=50??]k`2HTY@05a4C00h82P0D3a400P0D41405`0A3@h03PX;01HB
4`0R7Ql02@D600/7200E4A804`l@01dI6P0E41804P`@01TD600J5AT050lC01@B5@0@3Q406ALJ014A
4`0D51H03@d?00h>400B4AH04A0E008040lE01`04A0F01@C6@0J6Al092<Y00T8400i>400d<oG0450
B@0@3aD04A0E01@C600E51T04a8G01PG700C4QL051<H01PG700I61d05aHK01DE600D5AL05QXK00dA
4P0>4Q<06ahO00P<3@0E6AX06AdN0P0L8240400J7Ql05a/L01DI6P0B5QL05ATJ03Hj?@0G6al04QLK
01`T9`0M92T07B@Z01/T:@0H8BH05QlT01TT:P0L9Rl201lY<P1i01hX<@0K9Bl09Bli02Tc?@0L9S00
9Blk02Pb?P0V<3`06bD_02D`>P0K:34082df01l/=@0O;CH0938k02`mA@0Y>T80;Ci601//=00Y>T80
9CPo02Dg@@0T=T009SQ202/mB@0^@4`0;Cm;02i0CP0/?T`093I40352DP0bA580:Sa903a>FP12E600
;d5=02m1B`0`@T`0<TA>03A7CP0cATd0=TU@03U<DP0gBU40=TYD03M;EP0_@d`0<4A=02m3C00fBU<0
<TI=06MkPP0hC580;T=802a1AP0`A4X0=DU@03I9D00cATd0;D1702/l@`0Y>T00:3Xn02`k@00]?400
9cHi02Xh>`0]>ch0:cTl02Pe>`0U<SP09c@j02Th?`0^?D@0<D9903A5C@0cA4`0<D9:02Pk@P0U>3l0
:3]102Lh?`0Y>D00:cY102/h@@0X=Cl0:SQ302/lAP0[?TT0;dE@02i5D00_?d`0<Cm:034oB`0Y=d@0
9S=303=0D00_?4d09C9503M3F@0P;480;CUA03E2F`13EFd0=DUQ0312F00mCf<0@eAV03Q7F00K:3P0
;C]604MCGP13CEH0C5IO02H`=P0L8b/0=Se502/b>00i@4H0JG1f01`T9`0202<[;P0501LO8@0L92H0
6R8T024Y:`0E7B000P0G7b80>`0L92L0>T9501PP8`0C6ah072@W01/S9P0F7R40620S01XO8P0I7B00
5aPJ01@E5`0F5aT06A`N01XN8@0A5QX06b0T024V:P0<4aT07bH/02H]<`0E6Qh0<3Di02db=P0J7bD0
4aPN01`Q9`0L82T06QhW01dQ:P0P92l06alZ010D7`0E62405aXS01DH8@0C5Ql04QDN01<F7`0J7BH0
7B0Y030c?00D5b004A@M00hA6P0F6B806QdV01`O:00M82T07b8[020S;00H6b@05QTR01LJ8`0J7BH0
6ahW01XM9P0P82X07AdW00805aLQ01X05QHP014A6`0C4ad04Q8L01LG8@0B4Q`04A4K01HI8P0?4Q/0
61/T01HI8P0I72D06a/U01HF800E5Al05aDP01XH8`0E4ah04a4L01LF7P0D4aT04a8H01LF700F5A/0
61LM01TH7P803@`B01<09RD[01PG7@0;2Q0071/P00@41P0S8bD04a<E01XJ700F51T061HL014>5@0C
3QD07aTR03`f@00N5R40:RD[01/I7P0E4aP05aDJ008040hC02005Q@I018@5@0C4AH0518G018@5@0E
4aP05Q<L01DB6`0D4AX04PlF014>5@0B3aH05Q@I01DC600B41<040hA01<A500J61/07APN00`73@0A
3180>cHl01TD6P0K5Q`061<I01LB600E41H04`hD014<4P0@2a404@`@018=4@804@`@00T04`hB00l:
3P0D3a<04`hB010;3`0?2Ph04@`@018=4@0C3Q@00P0>2@l04P0=20h04@`B010;4@0500H08QdS038]
<`1<Add04`hD018=4`0D3a<04PdA00H11@0M61`0=S4e018=4@0F4AD05A0D01<>4P<04PdA01X04@`@
018=4@0B3A404PdA01@?500D3aD03PT@018=500M61l030H@00X43P0>2A005A0E01LB5P0J5AT05a8F
01@?4`0G4QH04@`@01PC5`1iM7P07QTM00L21P0C3Q8050hB018<40804@/?0P0B31002`0@2Ph03`T=
018<400F41@04P`@00h8300=20d0100401@=500<1@`04P/B00807AHM01T04@XA01<<4`0=1Pd01004
01D?4`0=1`T03PP:010:300C3@l05Q0D018<400>20`05PlF01dF7@0@2A0030D=014:4@0@2Ph03`T=
010:3P0A2`l04`dA01H@500E3a<04P`@00803`T=00l04@/?00l62P0F30d08ALH01H>3`080P807QXK
02TV9`0100007aXN00/72P0@2A002P<:00/52P0@2Ph00`0B31001`0I4aL071HJ00@00P0A2`l030H:
00T31`0I4aL00P0>20X01P0B30h050h@014;3@0=1`T03`T;010:30804`d?01@04P`>010:300G4A<0
3PP:00l92`0E3a4040X<00l92`0A2`d050h@010:30070@<0@3Xl030Z;00R71`050h>018<300=1`L0
40X:01TC4`H03`T900h0208401<=3`0C3@l06A<E010:300d;S004@/=010:300;1@L03@L901@>400C
3@l03`@<01873P805@X@00l050T>01872`0A1PX040D800X00@0C2@X03`D501061`0B1`/07A8H020E
6`0D2@l05@X@0146300;00H00`0B1`d01P0>0`T02P0501@93@0C20`04PL;01462P8040D900P050T=
01H;3`0<0@D0304500L0000800804@T<00d72@803`T;020040X>01@>4P0>20`030D<00l83`0A2Q40
3PL?00X32P0?10T03@8601872`0D2@d04`P<01D:3P0D2@d04PL;01462P0@1@T04@H:01L<3`0B20T0
3PD800h62`0Y92X0/Zfd085nQ@3floX0OWMn01`E6@0700406Q0A00l41`8050T=01004@H:01872`0A
1PX04PL;01/@500L4AD03`@802PM8@0f:bl06a8E00h82P090`D02P@6014;3@0=10L04`T<100A1PX0
1`0B1@`04PP;018<3P0<1`P05@lA00L10`0>20X01P0?2@/07@0<1PX01`45010:3P0B31001`4500T4
1`0;1@T03@L;014;3`0?2@d03@L;00h8300=1`/02@<700h8300<1PX040X>00X5200A2`l030H:018<
40090`L0100200`72P0=1Pd03PL>00d63@0>1`h04P/B00L03PL>00`03P8<00h5300@1@d0304901L<
4`0<0@L03P<901H;400I3Q802@0200h31`0N4aLDooooo`006oooool600l92`0D00h82P0?2@/03`T;
00h82P0A2`d05@lA018<400<1PX040X>00l93@0>20`040X>01@>4P0=20/04@/?01LA5@0B3A00=2hb
01@>4P0B3102014;3`804P`@01804@/?010:3P0?2@d040X>00l93@0=1`/07ALK02HP900C3A4030H:
018<400;1@T040X>018=400B310030L:00h8300G4AD201872`0<01H;3`0D2@d04@H:01<8300?1@P0
4PL;01P=4@0D2@d04`P<01<:3@0A2`d040X<0P0C3@l0200A2`d040X<00d72@0=1`T050h@01<=3`0A
2`d04`d?0P0D3Q00<@0C3@l050h@01@>400G4A<06A<E05iHFP0o>C/04`d?014;3@0C3Pl03PX;018>
3`0E4A802PH701XF5`14@4406QHG00h:2`0F4Q<020@501<?400E41<050hB01D@500G4QH05Q4E01HD
5`0D4QD040hA01DE5`0<30h04Q8D03`l?`0?3Q@040lF01@C6`0E51`051<K018A6@0_;SH0<C0h01PF
8@081Q40:BLb01TG8@0G5Q/06QXL014A4`0D51H00P0G5aT03@0C4aD04Q8D018B500C4aD05ADG01DF
600B4a@08bLV018F5@0W:bX0;30_01`P7`0F6QT00`0G6aX201PL6`0901XN7`0I7Ah061`M04=7B00O
8bD0724T01XR9@0K8bH072@W00<06b@Y02P06B@Z01/V;00N:Bl07bTb01dW<00I8b`05b4Z01lY<P0P
:S<0=T1902La>P19Ded08bdf02Lb>`0S<3P082de02Xh@00R<CP0:SU0020a>00M;SD09SLn020a>00V
=ch09SU002@f@00U=d40;Cm90353C`0bA500;T1<03=5D`0fB5H0;d5?0393D`0^@4h0:ce:02/mB@0b
A500;Cm;0P0cADl0R`0^@4X0<dI=03=6C@0gBU40>DaB03I9D00bADd0<D==03I8D@1=H6P0@5=J03I9
D00jCE@0=4M>03Q;DP0dAdh0=dYA03E9D00iCE@0?E1G03I9D00/?dH0;3e402`n@`0W>Cd0:STn02ln
@P0X=cX09S@g02Xh?00^>d409c@j02Tg?@0Y>3l09SDl02`lA00`@DT0<D=:0353C00cADl0<49<02Tl
A00X>d80:CY202/j@`0[>D<0:CM202Pf@P0/>dP0;Ci:02/oC00^AE80;TEA02hnC00_?D/0<3e=02Xg
A`0S<4809S=6038oD`0/>4l0>dMO020/A@0jAV40>DEP03e=IP0gBF40<D=I03=4F00dAEL0<T9C02/h
B00V<ch092hi01hX<@0V<3T09c0g02L^=00K8RP0:2le01<K7P0/=3L06B4T01DM7`0J8R@06B4S02H_
;P0S;2/092d]01dU9`0A6A`04QXM02D]<00_=cX06b<V01DM800G7b805AdP01LO8P0L92L06QlR010D
5P0K71h04Q<E014B500L7b406QhQ02H[;`0H7B40A4U=00lF700K8RP061lU01PM8@0Q9RX07R<W01TN
900H7B<05Q/Q01PL9@0L82T08RH_02DY=00P92l061`W01LJ8`0I72D061/T01DH8@0D5b005APQ01HI
8P0B5Ah06ahW01PK900E624051LP01HI8P0I72D00P0J7BH02`0K7RL07B0Y01XM9P0I72D06QdV01/N
9`0H6b@05QTR028R;00Q8B/06QXT008061PR01005QHP01TI8`0G5b406ATS01<C7@0L72H0;2lh03<f
?`0C5Ql04A@M01@G800C4ad05ADO01<C7@0D4Qd05aDP0P0D4Qd0800H5al051<I01@C6@0G5Q`05A@J
01LF700M72806APN01<B600M72806APN010?5@0F5AX05A@I018A5P0G5Q/05A@I01DC600D4QL04Q0E
02<N9@0B3A@06A@K01TC6P12?D<06QPM018@5@0D4QL040hC014?500E4aP03`dB0P0B41D00`0@3Q<0
5A<H01<@6@0201<@6@804a0G01D05A8I018@5@0C4AH04a4D018@4`0C4A@061HI01<>500?2Q0061<I
05IAE`0V8BL04PdC01TD6P0G4QP04`hD014<4P0B3A<05A0F01LB5P0C3Q800P0D3a<0100A31004`hB
010;3`0A3103018=4@0601<>4P0@2a4040/A02HQ9`0C3Q@03PT?0P0B3A<01`0@3140GEQN02dX;P0B
3Q<0CDQ>01<>4P0B3A400P0A3104018=4@804@`@01<04`hB01@?4`0@2a403PT?00l:400@2a404PdC
01D@5P0>2@l061<I018=500D3aH0;BP_00h93`0A31404@`@01@?4`0A31003`X>00<050lC00H0D4]?
01PC5`0:1@T04@`@01LA5@0D3Q8201<=4@0701@>4P0E3a<04P`@00d72`0>20`050hB01<=4@02010:
3P0501dG6`0?2@d04@/?01H@500>2@`00P0A2`l0200;1@T04P`@00d72`0B31004`d?018<3P0A2`d0
4P`>0P0B31001P0@2Ph05@hE01XC6P0<1@`030D=01<<4`804@/?02T040X>014;3`0A2`l04P`@00l9
3@0>20`07QPL02LQ9@0K5AT04PX>01L=4P0F31004@/<01<=3@0A3@`04@d=01lL701?CE003`dA00d9
400?2a<03PT?014;3@0D3Q004P`>014;3@0H4Q@03@P901XD5P0E41402`D701`F600@2P`04@/=01@>
400A2`d05@lA01H@4P0E3a403`T;010:300201<=3`0B018<3P0@2P`04`d?01@>400?2@/04`d?01/E
5`0D3Q004@/=010:3014?T009AlQ04Y4AP0O6A/05@l?00/51@0C3@d04P`<0P0A2`/600l92@0>00`6
200@2P`02`D701XD5P0@2P`0=c4c00h82P0?2@/02P@600`6200A2`d030H801463P0B1`h201<83P0A
01<83@0B1`/04PL;01@9300=0`@04PP901471`0G3@h03PD701<83P0D2@l03@<801@93`0<0PL03`D:
01P=4`0D2@l00P0B1`d01@0?10X05@X>01<8300C20`04PL;008040D901H03`@801H;3`0=0PH060dA
00`31@0J4A@040T;014;3@0<1PP03@L900h8300<1PX04@/?00h73P0=1Pd04@XA018;4`0?20l04@H;
00h31`0C20`05@X>0P0@1@T00`0C20`04PL;01462P0201872`0I01472@0B20T04PT<01083@0C3Q@0
7ATO010=500/:C007aPO01P@5@0A20/03@D501<82`0E2Ph05P/?01462P0D2@d05@X>01872`0>0`L0
4PL;00h51`0D2@d06a0D01@:3@02014<3@0400l92`0D3Q005@`A01483@8040L<0P0@1`d01`0A1Ph0
4@X>00X41P0C3@l02P@604Q2A016@4801P0?2@/01P0A2`d030H801TC5@0M5a/03@L;00h830803@L;
00X03@H=00/42`0:10X03PL>00/42`0?20l03@H=00/42`0M5Qd05a4G0P0?20l02P0>1`h02`@;034Z
<@0e;cD040T@01<<4`0?20l030D<014:4@0<1@`600h73P0<00h2300B1a00:QlW01hD6`0A1`d04PL=
00h32@0?1@T04@H:00L0000D2@d03`@85?ooool001_ooooo1P0?2@/0700G4A<02P@601H@4P0=1`T0
618D065KG@0C3A404@/?00l93@0>20`03`T=010:3P080PH03PP<00P21P0B3100618F010:3P0B3100
3@L;010:3P0B31004`dA01H@500C3A4040X>00h8300=1`/200h8300C05I@E012?4003`T=01H@500I
4aL040X>00l93@0500<07aTM00h9300@2Ph03`T=01462P0B1`/040D901872`0A1PX03@8601872`02
01462P0301872`0C20`04@P;00803PP:00<03`T;010:300@2P`00`0@2P`01@0A2`d04P`>01<=3`0C
3@l04@/=008040X<00D04@/=018<3P0?2@/071HH00L10`0201@>400?01PB500@2`d03`/<00l;300C
3a002`L800`82@0C3a004@d>010<3@0?2``040`=018>3`0D3a805Q0D008061<G00@05a8F01<A500A
3a804Q0C0P0B4Q@01@0C4aD04a<F014@600C4A`05A<N0080518M00P05A@L08:1R@1OGVH08b8Z00l>
5P0D4a/061LN01@C60805QHH0P0?3a403`0G5aT061PJ01LG6@0G5aT03`lA00d=3`0P8B<071hM00lC
4P0I7A`0720O00lC4P0J7Qd08BDT01TM700201DI600R01HJ6@0H71/051PI01lS9@0H71l051PK01/O
8`0J7b<06R8U01XQ9P0Q:2h07bP]01LP9@0J8bP06B@Z01hX<@0P:S<07BL`01`V;`0N:3408B/d02@^
=`0]=d00;CPn02@_=@0Q;38092le03]7C@0^>d409C8h01TW;@0K:Rl08C0e02<e>@8093Hj02009CLk
02Hg?P0U>3l0:ce702<e?`0Z?4H0=4IB02i0C00X>TH0?U1N03a>G00eAeD0=TMG0312D00Z?4T0<TA@
02doB`0/?TX0=DMA03U;E@0]?dT0:Ca302/nA@0aA4/0<DA:0313B@0]@4H0<TE<03]>E014Eed0?e9H
03Q;D@80>TeD04/0;T5803E8C`0lCeH0;d=:02Lk@P0dAdh0=dYA02Tl@`0]?TD093Hk02@f>P0Z>Ch0
:STm02Th>`0]>ch0:3Hj02dl@`0U=3/09SDl03Y9D00V=cl0<T=;02m2B@0^@4X0=4MA03I:D`0`A4l0
:cm802@h@@0P<S`09cQ202XjA`0]>dP0<3m=02/kBP0fB5H0:Ci<03mFI00`AeD0;Si>03=0D@0b?e40
;CY=02`hCP0V<TT0:3A<02TeC`0_>UD0=D1L03E0GP0g@f40BEUc03e?I`0gAeh0:3M<02`kCP0hAEH0
@4aL02Da?@0X<Sd08b`e01@M9P0N9Bd08RL]028W:`0P9BT07B8V01`Q9@0L8B@04aPK00hC5P0D6QX0
7R@T03Pn?P0J81l00P0K82<201dR9@0b01PM800F6ah06b0S018G6P0C61/03Q<F01hS9P0[<3<04aLH
01@E5`0F5aT061TK01TL7P0G6ah09b``01XO8`0D6Ad03aHL01DL8P0B6Al05a`P01@I7@0H7B405a`R
01HK8@0O92X05a/T01`P:@0I7BH092Pc02lc?P0K7bX08RD^024T;@0H6b@07b8[02X]=P0F6B8071lX
01/N9`0H6b@05aXS01dP:@0R9Bh05QTR010C700B5Ah071lX01HI8P0I72D201PK900D01/N9`0G6R<0
51LP01TL9@0J6R@05QHP01hN:00I6B<04Q8L01PH8P0D51h05aLQ020P:P0G5b407alY03@g@01JGVL0
:Rdf01PK900C5Ql2018B700801@D7P0F51l05Q@O01DC7P0D4Qd061LO01/J800I61h201PG7@0301TH
7P0K6R006QTO00805QDK02d061LM01TH7P0D4aT0:BP^014@5P0P7bD04Q4G020N8`0B41D04a4F01D@
5P0F4AL05a8H01PA600E41H04a4F01@B5`0G5AX061HK01HD6@0E4aP040hC01LE6P0A3a@03P`A01LE
6P0=2Q<04@hG00d:4`0O72<03@XA01@A600>31401`D:010>4@0X9RT040hA00h<3`0A318040/A01HA
5`0B3A<030L=01<>500I51X00P0>2@l0300D3aD040/A01D@5P0E41@05a8F014=400<1`/05A0D04U4
B00F4AD03PT=01PC5`8030L;00P09R4U00/6300Q72805a8H00l:400E41H03PT?01<>508040/A00D0
50lE01D@5P0>2@l040/?014<4002018=4@0>014<400@2`l06aHJ00h93@080`L04PdA00d8300C3Q80
6aHL018=500I51/06QDL014<4`0E41H200l:400:00`73@0K5Q`0:RD[01@?5@0A310040/?00/62P0G
4QH06A@H00d830H04@`@00P04@/?01<=4@0E3a<050hB014;3`0@2Ph04@/?00h830804@/?00<040X>
01@>4P0@2Ph00P0>20`00`0@2Ph03`T=00h83006018<400<01<=3`0D3Q003PP:018<3P0C3A4071HJ
00@00P0H4AP03PT>00X32P0<1@d04P/B0`0B31006@0A2`l040X>00d72`0@2Ph04P`@014;3`0E3a<0
4@/?010:3`0?20l04``C014;3P0=1`T06aDE01@?3`0>2P/04`hB00T62P0>2a805A@L00P52P0@2P`0
4P`>01<=3`0B30h00P0@2P`00`0A2`d04P`>018<3P02014;3@0O00h82P0Q6ad03PP:014;3@060080
4`d?018<3P0G4A<03@L901<=3`0H4Q@05Q0B00T31@0B30h04`d?00`6200@2P`05@lA00/51`0@2P`0
5Q0B01@>400B30h04`d?00h8200:10@03PP800l92@0H4Q803`T901@>3P02010:2P803`T900<05a4A
010:300@2P`00P0?2@/300h82P0B00/51`0?2@/04@/=010:30080P@05P/C00l42`0;00H03P<90146
2`0?10P04PL;01462@0@1PL04PP90188200@1PL040D91@0@1@/01P0;00H0A3To01<83P0:0@D05P/A
014630803`@800L08QLK00d41P0C20`04PL;00h31`0@1@T04@H:00804`P<00P04@P;014:300<1PP0
2`D700`6200?2@d04@/?00h830<03PL>00/03PL?00h73P0A1P/04`P<01X?4`0?1PP05P/?00l4200B
1`/01`0001L<400201462P0/0106200A1`P03`H900h62`0;1P`02`H=00D32@0I5Qd03`P?014:3P06
00004`T:00d31@0A1PX07A8F00l5200>0`L05``@01462P0D2@d0304500/2100O51P08aPL01D;3P0=
10D030<600d6200>20X03@L;01<<4P0D3A@030D<00h73`0?2100100501H?5@0<1PP040X<00l92`0E
3a406Q@F00/51`0<1PP400h82P0301<=3@0?2@T02`D500803PP:01002P@80109400@2A003`P?00h7
3`0=1Ph030D=00X32`0?21001@0601<<500D3AD04P/C00`53@0>1`l03@H>0P0?2100100L5Ad040T@
00l83`0>1`h300d63@0>059;DP0Y8RT02@8900X32P0A2Q403PL>01L;5@0D2Q40ACY203hc>`0<0`P0
6PlE00l42P0@1@X201462P0301052@0?10Sooooo01?ooooo000Kooooo`H03`T;00P02`D7010:300B
30h040X<018<3P0K5AL04@/>010:3@803`T<0P0A2`h0200C3A0071HI018<3`0>20/04@/>00h82`0@
2Ph03PP<0P0C3A401@0?2@d04@/?01<=4@0@2Ph03`T=00<03PP<00d050lB00X5200C3A402`H901@>
4P0A2`l03PP<01dG6`0:1@P05Q0D00h9300?2@d050T=00804`P<00D06a0D01X?4`0D2@d05@X>0187
2`0201462P0401872`0A20/03`T;00l92`<040X<00@04@/=018<3P0B30h04@/=0P0?2@/00`0A2`d0
4`d?018<3P02018<3P0E01<=3`0G4A<0618D014;3@0F41802@@501D?4@0C3Pl0510A01HB4`0D4140
40`=014=3P0E4A805Q8C01DA4P0D41404`l@01@@4@0E41805@lC00805Q4E00D05A0D018@4`0C4A@0
518E01<C5@0201@D5P0@01@D5`0@3aL04Q0K01@B700C4A/04Q4I01@C6P0H5ah051<J014@5P0C4QT0
51<H014@5`0D51H05QHG01LG60804a<D00l06QXK01TI6P0F5QL04a<D014A4P0C4a@08R<T01@F5P0L
8200Jfm_02<W9`0E6AT051PH014E5@0I7Ad00P0J7Qh0600O8b<07R8S01HJ700L82@06alS01`O8`0M
8BL05a`Q01hU:P0J8BP07B@[01dV;00O:2l09Rlg01PR;00M9c8082Xc01lY=00P:S<08R`f01lY<`0O
:C809Blh02D`=`808B`c00L07bX`020/<P0N:c407R/a02Dc>@0D8bP08S4f00<08S@h00X09CLk02Pj
?P0^@DP08cDo02doB@0[?DL0;3i:03a>FP0hBUH0?4iL0P0`@U002@0iBUX0:ce;0353D00^@4`0;3i:
0353C`0bA4h0;Cm90312C0020354B`0@0313BP0_@TP0;T5702i0A@0Y>d00:ci303E7C00jC580>D]B
02m1B00fB500<TA<03U;DP0lCUH0;d9902a0A`80;d9904H09SU002Hg?P0U=c`08cDi02Lf>`0V=CT0
93<f02Pf>@0V=CX0;3]202Xj@@0X>3l0<D9902`mA@0]?dL0;D1802i1B`0bAE00<dMA0314C`0_@dh0
;41:02XlA`0W>4D093A202XiA`0[>dX0<TAC04QIJP0[@500:D1?03A<F`17FFT0@E5U030nD`0W=D/0
:CU@02LeC`0lBF@0;3YF03U7I00lB6L0<CmP03Y7IP12DV`0?DiW04mOMP0gAU/0<D1C03=0D@0Y=DD0
9S4m02H_>P0I8B/06b<]01`S:P0K82H07B4V020T:00N8RH06QhR01<H6`0I7R004AHF01DJ6P0J7al0
9b`[01HK6P0M8R806QlQ0P0H71h0100K7b407R8T01/P8P0@51H201/O8@0801TN800@51H06Q/M01LH
6P0E5QP061TK01TL7P0H71l201HK7`0J01LL800K8RP0D5MM05ELHP0O92P061dQ01XO8`0L8BL06QlU
01`Q9`0P92d06alX024U;P0[;cX0;30k01HJ9@0R9Bh07R4Z01XM9P0D5b007R4Z01LJ8`0K7RL07R4Z
01dP:@0I72D201LJ8`0602d`>@0a=3d05aXS01LJ8`0M82T06ahW0P0J7BH07P0S9Rl06ahW018E7P0J
7BH051@N01TI8`0E5Al06a/U020P:P0K6bD08B4[028R;00G5b404a<M01TI8`0F6B806A`U00d@6@0?
4Q/04aHO01LG8@0F5R0051@N01DC7P0F51l0518M01<A700F5Ad061LM01HE6`805A@J00<05QDK01PG
7@0H5ad00P0F5A/02`0H5ad05aHL030_=@15A4/05QDL01TH7`0>3A<07AXP01HD6@0E4aP05a8G0080
5Q4F00D05a0F01PC600@3Q<03`dB01LE6P02018@5@0K01DC600K6Ah04a4F03Tg?00@3Q<071XO00X8
400D4AX04@hG00d:4@0K61l04PlF010>4`0?3A8071XM034_<P0K6A`04a4D01LB600C3Q@040/A00h9
3`0A31808ahT03Pc>@0R7B<04@`B00804`hD00L05Q4G00l:3P0E41@04`hB00`72`0;1PX05a<F0080
50lC00H04`hB01HA5@0W8RH050lC018=4`0D3aD200l:400:01<>500B3A<04`hD01<>500A318040/A
01@?5@0I51X040/?014<40804PdA01X04@`@010;3`0;1PX04@`@01/F6P0U82@05Q4E00l:400B3A@0
4PdE010;4`0B3A@050lF00l:4@0@2a404`hC010;400B3A805A0E010;400I51P07QTM01D@500A3100
50lC014<40H03`X>0P0A2`l2018<400>014;3`0@2Ph04P`@010:3P0D3Q804`dA018<400E3a<04P`?
010:3@0A2`h04P`?010:3@0?2@`6010:3@805Q0B00X04@/=01<=3`0B31003`T=00T41`0H4AP030D<
01PA600C31@04@XA0`0B31006@0A2`l040X>01<=4@0F41@04P`@00`62P0@2Ph04P`@014<500B4A/0
30XC010<4P0C3A0071HG018=300=20L05A0@01hI7@0;1`h030LA010;4@0@2P/04P`=01<=3P0B30d0
0P0@2P/00`0A2``04P`=018<3@02014;300>01XD5P0S7Al08adO02`V:00>20X04@/=010:300D3Q00
4P`>01D?4@0@2P`05Q0B00d72@0@2P`200l92`0D018<3P0?2@/03`T;014;3@0B30h03`T;00h82P0A
2`d040X:014;2`0@2PX02P@400l92@0D3Ph03@L7018<300?2@T03PP8018<300A2`/2018<3P804@/=
0P0@2P`0200N61X04@/=00/61`0C3@l02P@601@>400D2A4050T@0P0D2@l02@0C20d04PL;01@93@0C
20/04PP901@:2`0D2PX04PP901462P050146300901@93`0k<3H03@8801X?5@0A20`04PT=01H;3`0@
1@T04@H:00803`@80P0C20`201872`0:01@93@0F2`l05Pd@018:3@0?2@/03PP:00l92`0@2Ph04@/?
00h830<03PL>02803PL?00h73P0H3A803`@801<8300F2`l05P`?01<8300n<cL0:AhR01072@0G3100
5P/?0106200B20T04@P;01083@0=20h03@P?00X73P0>2a801`4701493P0F3A0030<401882P0P5AT0
<RL[01L<400800405@X>01@93@0@1@T04@H:0P0D2@d05@0@1@T03P@600h51P0=10H03PH800h82P0>
20`03PP=00/5300;10d04`hF00l:5@0M5R403@H=00h82P0?2@/02PD601@>400?2@/02`D700`62004
00h82P0600X4100=1`H040X:00h82@0<1PP03PP<0P0=1Pd02@0>1`l03PL@00l74@0?214050dE00/6
300D3AD0208900X32`02014:4P05038[<`0D3AD04P/C01<>500>1`l00P0@2A004P0>1`h030D<00`5
300<1@`0<BXa01`E700=1Pd03`P?0109400<1@`040@>01X>5`0C2Q0040L=01D:4@0?10X04@H<0187
30<04PL;00<04@H:ooooooooool04_ooool001_ooooo1P0?2@/01P0>20X04@/=00X41P0=1`T04`d?
00D00@803PP:0P0?2@/2014;3@0400h82P0F41803`T;00`620803`T;00D030H:00X4200?2@d04@/?
010:3P02014;3`8040X>0`0?2@d01`0A2`l06A<G01LA5@0?2@d05a4E00H0100C3A400P0@2Ph0100;
1PT040X>01<=4@0G310201872`0501T>4P0F2`l03P<701L<400C20`00P0@1@T0100B1`/04PT<00l9
2`0?2@/2010:3004014;3@0?2@/03PP:00l92`<04@/=00<04`d?01@>400C3@l00P0B30h04@0C3@l0
40X<02PR900@2P`03`X;02LQ8`0J51H03`X<014=3P0C3a004@d>01TE5P0F4Q<040`=01<?400B3Pl0
4@d>008040`=00<04Pd@01D?4`0E41@00P0E41@00`0B41<05A<F01DC5P0301@D5P0@01@D5`0?3QH0
4A0H01@C6`0C4QX04Q4G01@C6@0J6Al06APM01@D5`0?3Q<0410B01LG6@0@41004Q8B01<C4`804Q8B
00@061PH01XJ6P0F5QH04Q8B0P0A4A406`0B4a<06a`N02lc=02<T9809RX]01@H6P0P92D05QXM01/O
8@0@51D03a<F01TM7`0E6A`07B0U01/N900I72<05aXQ01<G7`0C5b008RTa01/R;00G7RP05b0Y01TR
;00M9C006R<b01`U=00201dV=@0401hX=00N:3808R`f01hX<P807bTb07/072H_020Z<`0E82H09C4g
02/h?P0L:Bl08S0e01l^<`0R<CH0838f01la=@0P<SH09CLk02Pj?P0Y?4<0:C]5028d?P0V>480<dEA
03Q:EP0gBED07c4o03A6E01<GV`06R/k03M9E`0`@Tl0;Cm;02`nBP0dAU80<dE?02/mA`0Z?4H0<DA;
0395C00_@TT0;d980313A`0^@480;3i202do@`0`@TH0<45802hoAP0b@dX0<T=;02hoA`0hBE40@U=K
03U<D`0fBU40:Se402`oAP0]@4L09SLn02Hh?@0S=CT09cHk02@c=`0Q<3<0938e02<a=`0X=ch0:CY1
02Pi@00Y>T80=DQ?02XmA@0[?DL0;D5<02m3CP0`A4l0<DE@03I:E@0cAe80<49>02`mB`0[>dX0<D5@
03E5E@0W>4P08cI702ToD00lEVD0<4]I03aAI00lCV80<45G02XjD@0a@e/0>daV03Y9IP1cQ:00PI6_
03Y9JP0iBFX0<D1P01h^B00c@e`0Jg^B03e<H@0X=dX0<3e>049;G00X<Sh09Rhj024X<P0E72H061hU
01LJ7`0J7B808B@Y02<W:P0P92L06alR020T9@0G6a`06QhM01`P7`0I7A`06QhM01dQ8P0L82400P0F
6Q/01@0K7b00720Q010D5@0J7Ql092PY00805QXK00h07B4R01lP8P0I6Q`05AHH01HG6@0H6ad061`O
01DJ7P0L8BD06AhR01LN900Z<CL08bX`024V:P806QlS0P0O92X0<P0J7bD061`U01hR:`0T:3405a/V
018F8@0J7RT06ahW01HI8P0S9Rl06QdV01PK900G6R<05QTR01XM9P0L7bP06ahW01PK900G6R<06QdV
01LJ8`0L7bP07b8[014D7@0F6B8061/T01`O:00M82T06ahW01TL9@0H6b@061PR01TI8`0C4ad05aLQ
01`L9P0H62808R8/01@D7P0L72H05QHP00h>600G6R<04QHO018E7P0I72D06QdV01HF800E5Al061PR
0P0I5b80100H5R405aDP01HE7@0E51X401@C6@805QDK04h05A@J01HE6`0F5A/04a8H010?5P0E51`0
20L?01TH7`081`d05Q<J01`J800F51T061<G01HA5@0D3a<05@lC01HA5P0=2a004a4F02LU:P0I5a`0
4a4F03Le>P2<RXl06aTN01TG700A3a@06aTN02@Q:P0>2a@02PL@03`i@01iMWd06aPO014?500?3A80
3@/>01PF6@0@3Q404@lB014<4P0B3A<04`hD018=4`0A31805Q4G01lJ800D3aD03`X@01D@5P0D3aD0
4@`B01<>4P0F4AD04`hB014<400H4aL050lC00l:3P0C3Q804@`@01/F6P0e<3@05A0D01<>500@2a40
5a8H01HA5`0>2@l04PdC01@?5@0C3Q@05A0F01@?5@0?2Q003PT?010;3`0A3102018=4@0J014<400@
2`l030L;014<400D3a<07APL01HA5@0D3aD02@@;01@>600L5R007QTP01PC6P0:1@`03`X@00l:3`0C
3Q8040/?00h93@0F4AD040/?01XE6@0D3a<03@P<018=4@0E41@6014<400801<=4@0A2`l04@/?014;
3`0B31004`dA010:3P0?2@d201<=4@03014;3`0C3A404`d?008040X<00<04@/=00l92`0>20X0200@
2P`02`0A2`d050h@01D?4`0B31005Q0D018;4P090`T05@hE014:4P0B2a804P`@00804@/?0P0@2Ph2
00h8300B010:3P0A2`l040X>00l93@0<2aD04QDT0000300>3QH00@0200h:2`0A2`X03@P501TC4`0a
:bd05A0F00H1200A2`l040X:0`0A2`/2010:2P03014;2`0B30`04P`<00804@/;00H03PP:00l92`0?
2@/06Q@F00/51`0G4A<2014;3@08010:300C3@l04@/=038/;P0H4Q@05a4C01<=3`0B30h201<=3`80
40X<01004@/=010:300@2P`04@/=00l92@0>20P02P@401D?3`0F41002@<301<=3@0K5AD03@L700P2
0P0@2PX020821P0@2P`04`070@<040X<00H00P0>20X05Q0B00H00P0@1@d05@XA01@93`0A1P`040D:
01<8300D2@d04PL:01882@0C2@X050X:01882@0B1`/01@0B1`d0500?10X0DDI<01`A5`0@1@/05@X@
01L<4P0B1`/05P/?00d21P0L4AD02P0300`11@0E2Ph04PL;01462P0C20`05P/?01L>4@0A2@`04@/=
0P0B30h00`0@2Ph03`T=00h8300300h73P0i00h73`0>1`h04@H;01T>4P0C20`05`h@06iSI`0K41@0
7aDH01872`0>0`L02P4300d21P0A1PT04`T:0189300@20d03PT?00d83`0F4aX03@XA00H01P0_:2`0
GeII01hD5@0?1@L03@8600X00`0C20`08QLK01/@500@1@T03P<700l4200C20`03P<701<8300F30h0
3@@500h51P0=1PL03PP:014;3`0F41L04@`C048lAP1gM7h03``G02<P:`0:1``0@3Xl05MAD`0H4Q@0
100000`6200;1@L030H800<03PP:00@03PP900`7100>2@H040X:0P0<1PH01@0?2@`03@H=00d63@0>
1`l03PHA00803`LB00`05`lJ00d63P0B2a<04@XB018;4`0:10/01005020I8@0;10`03PL?00d63P09
0PX200l83`803PL>0P0?20l03P090PT02P<:00`5300?20l040T@00l83`0D218040@=00l4300A1Ph0
40D<00h32@0A1P`04PL<0P0C20`00`0B1`/04@H:ooooo`0Cooooo`006oooool600l92`04018<3P0>
20X03@L900l92`804@/=00@03@L900h82P0?2@/03`T;0P0@2P`0300;1@L03@L900/51`0?2@/04P`>
010:300E3a<03PP<00l93@0@2Ph04@/?01@>4P<04@/?00`040X>00l93@0?2@d030H:01PB5P0500<0
3`T=00d72`0<1PX040X>00l93@1QFel201H@500>00L11@0E2Ph04PL;01462P0G310050T=00d21P0G
310050T=01872`0A1PX04PL;0189300?2@/2010:30804@/=00<040X<00h82P0?2@/00`0A2`d0100C
3@l05@lA01@>400C3@l2018<3P0<010:300;1@L0618D01<=3`080P@03PP:01D@4@0C3a004@d>01HB
4`0U8B807a/L100A3@h0100@30d03`/<01<>400F41@301HA5@0301<A500E4aH05A<F00<051@F00l0
51@G014@5P0C4QX05A@K01@C6@0C4QP05A@I010?500@418051@E01LG6@0E5AD03`l?01@D500E5AD0
0P0F5QH0800G5aL06QXJ018B4P0C4a<05ADE01TI6@0L71`061TJ020Q9@0?4aH092P/00hA5P0@4aL0
6alR01LJ7`0H72004aLJ01LJ7`0P92P061/P01LJ8@0J7BD092L`028U;P0I7BL07B4/01lV<00L8Rh0
61hZ01PP:`0I8Bd05Qh[0P0M9SL01@0N9cP082Tj028[>P0R;3P09S0l00808B/e00H07bTc01/U;`0N
:3407BP^01l[;`0G9BP201PV:@0302dl?`0S<SD08C<e0080838d01D09CLi02Tk?`0V>D00=dUC0353
C@0[?DL0:C]702@f@P0_@Dd0;T1>03E7E@16F6H0C5e]03i@GP0]?d`0<D=?02i0C00`@Th0=4I@03=5
C`0/?TP00P0cATd01@0`@dX0;d980354B00a@d@0;T120080;Cm102T0:ce102Tk?`0cA4/0<45902dn
AP0dADd0?TmI03M:DP0dB4l09SU002Lj@@0^@DP093Dl02@f>`0U=c/0:CPm02He>@0R<C@09C<f02Hd
>P0_@4P0:ca402Pi@@0Q<SX0=4I@02PkA@0/@4T0;T9=02i3CP0_AE00<TQE03E;F00^A540:Ca:02do
CP0b@e<0=dMG03M7F00a@U@0:Sa@02]1D`0202e7F00K0315FP0iCV<0=dYR02XlE00X?5D0=DMR03a=
J`0iC6X0@E=c03U9J`0cAVL0?dm`0392G00kBf@0FfZ103Q4FP0a?U40AU5S034jB`0O:CD0<c]70417
D@0b>D<082@/01DH7@0F6Qd06AdP00806QhQ02h06AdN01/O800F6Q/05a/J01XN7@0A5A@06AdK01HJ
6`0J7Ql05a/L01PL7@0N8R<06QhO01LK700Z;Rl0V9bM08N;S00K7b0051PI020Q8`0J6ad05AHH01HG
6@0H6Qd05a/N00462P0F6al0:2da038i?`0L8bT04aXP01`Q9@0H7B406AhR01lT:P0Q9R`06QlU02L[
=00J7RL06alX01XN:@0L82/07B4/02DX<@0F6B808B@]0P0M82T0100K7RL061/T01PK900I72D201XM
9P0P01TL9@0H6b@09RTb02LZ<`0F6B802`hG01dP:@0L7bP092L`01PK900N8BX0:2/d01hQ:P0J6R@0
51@N01LG8@0E5Al04a<M01PH8P0O7bT04A4K01/K9@0J6R@04a<M01TL9@0D5b002`hG018E7P0H6b@0
5aLQ01DE7`0H628201TG8P0301PF8@0G5B005QDM00805A@J0P0F5A/0<00E51X05QDK01HE6`0E51X0
5QDK01DD6P0C4QP05A@K01PF8@0B4AT0<2lg024P:00@3A@03``B01LE6P0I51P05Q8D01<?400D3Q00
7QTN01<A5P0=2a0061HK010>4`0D4QL0LFmd0?[ho@1<BTl01@<800h<4@0=2a002PL@01<@6@0I5Ql0
3P/B03Ld>`0E4QT02`T>01@B5`0H5QT081hQ01XH6`0?3A003PT?014<4P0E41H04`hD014<4P803PT?
00D03@P>014<4P0D3aD04@`B010;4@0201PC5`05014<400?2Ph050lC00d8300D3a<00P0C3Q804@0=
20`061<G00l:3P0C3Q@04PdC01TD6P0E41H040/A020K8@0M61h03`X@014<4P0G4QP05A0F01@?5@0@
2`l04@`@00804PdA01H04@`@010;3`0A31004`hB00`72`0D3a<04`hB01LB600E3aT03@PB0:VS[@2[
YJl03`XB01HA600A318030L<00l:3P0@30d03`/<01@@4@0=20`04PdA0P0?2Ph00`0B3A404`hB014<
4005014<4004014;3`0@2Ph03`T=010:3P@04@/?00D05@lC01@>4P0B310050hB014;3@0200l92`03
010:300>20X03@L900H040X<00h03PP:00d72@0@2P`04@/=01<=4@0B31004`dA00/42`0B2a8050dD
01<<500E3QD04P`@014;3`8040X>0P0A2`l00`0C3A4050hB01<=4@0200d72`0=01<E7`11B5X0728b
00d?6@030PL04`l@014<2P0B2PL03PH401<;300@2Ph03PL>018;4006010:2P03014;2`0B30`04P`<
00804@/;00`05@lA01LA4`0<1PP02P@600/51`0C3@l05@lA01@>400>20X03@L900H00P0T7R02018<
3P0F014;3@0<1PP03PP:01XD5P0=1`T03PP:010:300B30h04@/=00l92`0?2@T04`d=00`61P0H4Q80
50h>00`61P0K5AD08A/K010:2P0;1@D050h>00h820H03PP:00@01@0101TC5@0K5AL02`D70P0A2`d0
3@0C210050T@01873@0>0`T040D:01H;3`0B1`/04@H90147200B20T04`T901061`0B1`/01@0B1`d0
500>0`T02`8601<83P0C20h04@H<01hC6@0D2@d06PlC01<8300S61`04@H:01<8300D2@d04@H:0105
2@0A1PX050T=01D<3`0@20/04@/=0P0B30h00`0?2@d03PP<00h8300300h73P0J00h73`0>1`h050T>
01`A5@0E2Ph06Q0C079WJ`0O51P04PT;01462P0700007Q<G00L0000N51H04`T:0189300@20d03PT?
00d83`0610X01P<:01PA600D3140:b8U00X00@0@1@P201L<40805@X>0P0B1`/200l4200=01872`0>
0`L05P/?01`B5@0D2``04`X;00h6200:10H030H:00X42`0U82L0RhRA0<K2b`02018@7@0801@@5P1L
EUP0LVa^02dW:@090`D050h@00/51`0<1PP300h82P0700h82@0E40d04@`800/60`0<1PH03PP800h8
2`0200l83`0@00l8400>1Q403@D@00d54@0800/06a<N00X33@0E3AP040PC01L?6P0C2aH03`LB01<=
5P0600T02P8=01PA6P<03PL>014040T@018;4P0D3A@04P/B01@=500C31<040T@00h73P0<1@`05PXD
00/02@0G31@06a0H00h32P0?10X04@H<0187300201<8300301872`0A1P[ooooo01?ooooo000Koooo
o`H03`T;00T03PP:00d72@0D3Q004P`>00/51`0@2P`03@L900l92`0@2P`00P0?2@/01@0=1`T040X<
00h82P0?2@/04@/=00804P`>00P07ALK01<=4@0B310040X>00l93@0B310040X>014;3`804P`@0P0@
2Ph04P0B310040X>00h8300B310020<601D?4`0C3A402P@805aFFP0J51P05a4E00d72`0A1PX05@X>
01<8300F2`l060dA01H;3`805@X>0P0D2@d0100C20`04PT<010:300@2P`2014;3@04018<3P0D3Q00
50h@018<3P8040X<00D04@/=01@>400D3Q004`d?018<3P02014;3@0?010:300F41801P4201D?4@1C
CDl09AlQ01<>3`0?2``03@T:01DA4P0K5aP05a<D018>3`0C3a00510A00805Q8C00<05A4B01HA4`0G
4AD00`0F4AD0100D4QD05A<F01DC5P0D51H201<C5@0401<B5P0A41H04a8I01HE6`8051<H00X05ADH
01LG6@0D51@04Q8A01HF5@0H61D05ADC01@D500C4a<051@D0`0E5AD01`0B4Q805QHF01LG5`0E5AD0
5aLG018C500H6Ah00P0E61h01@0I728051LM01/N900H6b405aXP008071lU02406QdS020S:P0L7bP0
51LQ02@V<P0X:SL07R4/020S<@0I7b`06R0^01/Q<00O9cD09Bdk01hU=P0L93L06R8f01XR=@0M9CP0
7bPi01hW=P0T;C`08bdi02H`>`0T;ST07RPb01dW<00R;C<07b`_03]9C02?WJ00@U5D028a=00S<SD0
0P0S=CL01`0T=SP09cTk02Tk?`0lCeD0;d5;02TkA@0]?dT00P0bA5003@0U=d<0:ce;02@fA01HJWP0
aMKV055SL@0dAU<0>4YF0312CP0Z?4P0<49<03A6D00cADl00P0cATd02P0aA4/0;T5702i1A@0`@T<0
:cdn02Pj>`0W>C/0:C/o02Xl@00]?TD302hoA`1A03=4CP0/?dL0;d=:02m2B@0W>T409CPo02Hg?P0T
=C/09cTm02`k@00Y>3`09SDh02Tg>P0V=C/0>DYB02@e?@0[?4@09cU003a>F00dAe40<DE?02m3CP0a
AU40=4YF03I<F@0eBeT0:d5?02LjB@0Z?4`0;Ci>0350DP0a@E<0;d9C02<eB@0/@eD0:D=D035<GP0U
?580=DaR03eCJ`0_A5`0;4=K03]@K01CIhD0BEmm03M<K013EgT0=Ta]03mBM00`?e`0<D1I0350E`0l
B5h0>TMJ02diB`0V;d0092hj02D]>@0V;CL0<CQ202<W;`0O8RL07R8U01`P8`0J7R406AdP01TM7P0L
820082@T01/O7P0O8b4051TF01dR7P0>4Q<06AdN01PL7@0J7Ql08BDV01TM7P0O8b@03Q8C0080=3Pi
01l061`M01HJ6`0L7Al061TK01HG6@0G61X05aXL01HJ7@0O92P061dQ00hC5`0P9bd05A/Q024X;P0H
7B406b0T01XO8`0M8RP08BH/01XO9@0K7bP0:2`e020T;@0B5R406QhY02P/=`0a=3d071lX01PK900G
6R<08B@]00807b8[01X06QdV01TL9@0I72D06A`U01LJ8`0K7RL071lX01DH8@0S9Rl07b8[01LJ8`0I
72D07R4Z01@G800I72D08B@]01/N9`0I6B<05QHP01XJ900G5b4051@N01TI8`0M7BL06ATS01<C7@80
6QXT00D041<L01XN9`0@4a`04QDN01DH8@0201<C7@0801DE7`0G5B005aDP01HD7`0E4ah051<K01DD
6P0F5A/201LF700301HE6`0I61h061LM00<05A@J00<051<I01<A6P0G5B000P0E51`04@0B4AT040dD
01LE6`0F51T06QDI01HB500B3Pl05Q0B01dH700H5Q/05aDJ01hL8@0E4aP04@lD02HT:@1KFEh0;B/`
00805aDJ01<040hC03Xg@00W92d04a0I01HC6P0J5ah03``C010>4`0G5AX030X=00/9300C4A@04@lB
014<4P0C3Q@04PdC014<4P0E41H05Q4G008061<I00D05A0F014<4P0@2a404PdC014<400201<>4P09
01D@500C3Q8040/?014<400@2`l05Q4E00T4200@2`l06A@H00804PdC00`04@`B00h93`0E41H09b8X
03Ha=`0J5A/03`X@018=4`0@2a404`hD010;3`0A3102018=4@0E014<400@2`l03`X>01LB5P0A3100
5Q4E01@?4`0B3A<040XD01D?6P0]9c40;bTc01LA6P0>2A006aHL01TD6@0C3Q80510A01PD5@0C3a00
4`hB00<04@`@00<040/?00l:3P0?2Ph01@0?2Ph0100?2@d040X>010:3P0@2Ph200l93@09018<400C
3A405a4E01H@500B31005@lC00l92`0=1`T03`T;00804@/=00<03`T;010:300@2P`0100@2P`04P0A
2`d03PP:014;3@0=1`T03PP<014;3`0@2Ph02@8901<<4`0?20l06Q<K00l83`0C3A404@/?00l93@0@
2Ph04@/?018<40803`T=010040X>014;3`0K5AT0HFAb0=gYmP1lQIL04AHR00d=4P0Q7b003@L40108
100G3@/04@L801@:3@0H3Q<03`P:100?2PP00`0@2PT040/9014<2P02018=2`0>014<2P0A2`X03@L9
010:300A2`d03`T;018<3P0?2@/02`D7014;3@0B30h05Q0B010:300D3Q02010:30804P`>00@04`d?
024K7@0E3a404P`>0P0?2@/01`0@2P`03`T;00P20P0F41003PP801TC4`0>20P00P0@2PX00`0C3@d0
3PP800`61P02010:2P803@L90P0>20X200l92`0401@>400G4A<02`D701@>40803`T;00d05``D01@9
400A1P`04@H<01<83@0E2Ph04`P<01462@0A1`P04`T:01<92@0A1`P04@H:00D04@H<00d06PlE0147
300E2Q0050X?01P=4`0?1PX04`P<01462P0D2@d04`P<01872`0E2Ph04PL;00<040D900<04@H:0107
2P0@20/00`0@2P`00`0?2@d03PP<00h8300300h73P0Q00h73`0>1`h04`P=00/1100@1@T04`P<01D<
3P0A1PX03@@6024F6P0A1PX060hA01P=4@0C2P/04PP901482`0@20d03@P>00d83`0<2A0040dD01D>
5@0?20`050`>01<92P0A1`T050T=00l4200B20/04`T<00`31@0?10P040D900804`P<0P0A1PX0500>
10L03PD50107200>1`P03`T;01D?5P0B3Q@040dF02h[=P15@dl040hK010>700=2A803`T;01D?4@0>
20X0618D00d72@0;1@L030H80`0>20X01`0>20T05A0=014<200=20D03PP800l92@0>20X00P0?20l0
900?21003PHB00h64P0=1A801`0:01D=600B2aD0EDeH04]3CP0@2A<03`TB014;500[8bh05Q0I018:
5@0<1Ph03PL?00d63@0>1`h03`P?014:4@0B2a803@H=00h73P0?20l03PL>00l83`0@2A004@D?0146
3`0>0`/040D=01@9400>0`T04@H<018730<04PL;00<04@H:ooooooooool04_ooool001_ooooo1P0?
2@/01`0<1PP040X<00h82P0>20X04P`>010:300>20X00P0@2P`04@0?2@/03@L900/51`0;1@L040X<
014;3@0<1PP03`T;01D?4@0@2Ph02`D900d72`0>20`03@L;00l93@0@2Ph04@/?00804`dA01X04@/?
010:3P0@2Pd03PP:01LA5@0@2Ph07ALK00@00P0A30l02P@800@00P0F3aH02`@;01@>4P0A20/06@hB
01<:3@0@1PT04PL;0189300B20/05@X>01D<3`0F30l04`P<0149308040X<00P04@/=018<3P0B30h0
50h@01<=3`0@2P`03`T;01<=3`805a4C00<04`d?018<3P0A2`d00P0?2@/01`0>20X03`T;01LA4`0A
2`d09b4S00d72@0D41800P0C3Q801`0F4A@030P900h:2`0C3a004Ph?01@@4@0G4QD00P0G4QH01P0F
4AL04Q0E018@5@0A3a@04Q0E01<A5080518E00L04a8C018B4P0A4A404A4A00l?4@0A41D04a8G0080
4Q8D00T04a<D01@D500D51@05QHD01DF4@0C50l04A4>01LG5`0F5QH00`0G5aL08@0E5AH0410B01LG
6@0F5QP04a<E01XJ700M7R403a8G01DH7@0L7bH01@P?01DH7`0H6b806QdT01DH8@0J7BH05QTR028U
;P1>DEX0DeEQ024S<00E5b@071h[01PK:00M8Bd061h/01TO;@0H7R`082Hd02Xa?`0S:S`0<CQ;02T`
@`02028Z?@0@01lX>@0J8c@072Dd01lY=P0X<Sh0:C<o024[=`0N:3808Rdc02Pe>01QKg80kogo069a
M00M;3408c8g02Dg>`809SPl01L09cTm02Tk?`0Y?480:Se401`_=P18FV@0DfE_02XlAP0W>D<09cU5
02i0C00[?DT0AeUW03E7D`10DUd0?4iJ02m1B`0V>4<0:3Y402XmA00]@4L0:3]202Tl@P0202e0AP0R
02/n@P0T>3T0;T120355AP0_@TD0:C/o02Hi?@0a@dX0:S]302Li@@0Y?4<0=4E=0313BP0fBE00B5]R
03=6C@0T=ch0<DA:02Tl@P0V>Cd0:C/o02Ti?P0W=ST0:cPn02loA@1CI6/0:ca302doA`0T=ch0<TA>
03E9D`0dB5<0;d=>0357DP80>DmJ02H0=TaJ0398EP0aA5<0;3i=02@eA@0V=dT0:ca>0313E00R=DH0
9ce>01/bA00Y@e@093eA02m8G00bBF009SaC02HnEP0dBfH0?E9_04eTP`0`AVH0?U9e03A;K@11EGH0
<d=L041?I00/>Th0>DII030mCP0X=4@09Bhm01TS;`0S:cD08BPb01/R;00R:2l07R<Y01hS9`807b@X
00l07R<V01lS9@0J7Ql09BTZ01/O7`0M8B0051TE01TN6`0G6a`07b<T01LK700F6Q/06alP014E5P0B
5QL00P0F6Q/06`0>4Q<05a/L01<G600F6Qd05ALK01@H6`0H6Ad05QTM01@G700D6Ad05AXO00`A5`0M
92X07RD[00lF700I7R@08BH/01dR9P0K82H07R<W01TN8P0U:Rh0<SLm02<X;P0J7bD06QhW00lC7002
01`O:00W01dP:@0G6R<082</01/N9`0K7RP061XV01XL:00N82`071hZ01XL:00D5b006QdV02P[=00W
:S<04aHO01hQ:P0H6b@05QTR01lR:`0G6R804A@M01/N9`0M7BL08B4[01TI8`0J6R@06ATS010@6P0H
62803PhJ01XJ9P0G5b<0410L01PJ9P0K7bX0720[01lS;P0I72L05ALS00805aLQ0P0H5R401@0H5B00
5a@O01@B6P0C4QP05A@J00805aHL00@05QDK01TH7P0J6Al05QDK0`0D4aT0400C4QT04a8J018A6@0B
4AT07ahV01<@5`0B3aD0518G01LE6P0E4QD04`hB01HA5@0F4aH04@lB010>4@0B41D201DC600D01@B
5`0610T04PlE01@A600A3QD07Q/R018?5P050PT05a@L04=0A`0L6B005a@K00`:3`0J61d04a4D00h<
3`0H5QT03`d@00d83P0B3A<201<>500R01HA5`0A31803PT?00h93`0@2a405Q4G01TD6P0B3A<06QDI
01PC5`0B3A403`X>00X52@0F4AD04PdA01<>4P0D3a<02PD901@?4`0>2@d03@P>01<>500E41H050lE
014<4P0:1@/07APN014<4P0F4AL05a8H010;4@0D3aD040/?014<40804PdA04H04@`@010;3`0;1PX0
5A0D00d8300B3A404`hB01<>500E41L05@lH00X5300<1@d05@hF014:4@0@2A006A<G00`62P091@H0
510A00h:2`0@2`l04@`B018=4@0>2@h03PT?014<400A31404@`B014<400A31404@`B014<400C3A40
5@lC01LA5@0F41@04`dA018<400<1PX03PP<018<400A2`l03@L;00l93@0?2@/03PP:010:300C3@l0
5Pd@01D<3`0@1`X040L<00h82P0>20/03PP<00h82P0@2P`03@L901<=3`0>2P/04@/?01@>4P0B3A<0
2PD;00`73@0X8bX0CdYA024K8P0C3A404@/?0P0?2@d0500A2`l04P`@010:3P0C3A404P`@00T31`0;
1@T07AlY07AmSP0Z<D4020/E00X93P0J5QL04P`900`2000J40h03`D500P0000L4AD050`=0P0?2PL0
1@0>2@H03`X7010;200@2`P04@`900804Pd:02@04@`9014;2P0E3`l02@<501D?4@0I4aD03`T;00`6
200>20X05@lA00d72@0D3Q005Q0B010:300F418040X<014;3@0D3Q003`T;00h82P0X8R@07aTK018<
3P0?2@/04@/=01D?4@0C3@d0618B01D?3`10>SX0=2h^00`61P0?2@T04P`<01TC4`0F410200d71`80
3PP:0P0?2@/3010:300S06mYJ`0L5QP04`d?00d72@0?2@/04@P=00l52P0?1P/04PL=01062`0:0@@0
50T=01892`0A20T050X;01<:2`0A20T040D901062`0?1P/040D;01062`0?1P/04PL=00l52P0G3Q<0
3`H;00d2200A1P`04`P<01D:3P0X7B4040D901462P0>0`L00P0A1PX201872`0301052@0?1PT03`P:
00<03PP:0`0>20`500h73P0`00h52@0B1`/060lB01082@0I3Q804@P;01T?4`0K41@05@`?01@;3@0I
3Q803P@70107200?1PT03PL:00`5300;1P`040`B00@01@0700L0=blc01L>4@0I41402`<501<:3@0;
00@04@P;0189300800403@<701<:3@0D2@d03@<701@;3P0E2Ph040L901D<3@0E30l03PL900/52@0?
2Ph03`XA00d:4@0<2A803@XC01<@6`0000T040`C0P0<1PP01@090`D03PP:01<=3`0;1@L030H800<0
3PP:01003PP900P3000=20D050h=014;2`0>20X03PP;00`5300<1@d03PHA00h64`0?1a@040PE018:
5@0A2A@03PHA0P0E3AP03@0>1Q401P0901dF7P0E3QH01P07014:4P0@2A403`P?00h73P0<1@`02`@;
00X32P0;10/00P0>1`h0400?20l040T@00l83`0=1Pd040H>00h4300F31@05``D00h42`0A20d03`@:
01062P0@1`X04@H:01062@0>1@PDooooo`006oooool0?00J5QL03PX;00`82@0?2``03PX;00d92P0;
1`P05A4B00l;300B3Pl02`L801DA4P0?2Ph030L;00/62P0=20`03PT=00d8300G4QH02`H:00X52@0>
2@d030L;01PC5`0?2Q004@`B00X52`0=2@h05A0F018=4`0@2a4050lE01D@5P0A318030L=00/62P0B
30d04`d=00d72@0?2@/04@/?00d72`0@2A004``C01TB6@16?dL02`@<01@=500@2P/060l@00d71`0A
2@X01P0001/E5@0F3Pl040L800l92@0@20T04@P901`F60<04P`@00D040X>00l93@0:1@P05Q0D01<=
4@0200d72`0800/52@0J5AP05A4B01HB4`0D41408AdN01LC500E4A82018>3`0X01<?400D4140510A
014<4@0B3aH01`@;04E3A`081PL05A<D010?3@0@3Pl0De5B01/I7@1NFf807AXQ018@6P0>3QP05QHO
00d<500A3QD04`lD01<>4P0?2``071XG00X;1P0B4`d04Q@>01DG500:30/03a4@010B4@0B51<0418@
00lA3P0E5a@04A<@010B3`0H6QL0418?01DG5P806adL010051DG01DF600G61/051DI01HG6`0J6b00
6a`Q01PI7P0D51/041<H01<G6P0G6Ql05QTN01LJ800K7RD06ahW0`0H6RH05P0P8Rl0;c4n02hb?@0G
6bH05QXU01/O:P0J7RT07b<^01TM:@0P93007R8^01dQ;@0O9300728`02<Y>@0R:3X061la02@[?@0N
9CD0;CA401PQ<00T;Sd201`X=P0E02Hb@00F8Rh072H_02Xf?00[>3h0BEIL06]iOP1CHVT0:CPo01h_
=P0U=Sd09CHn020a>@0U=Sh09CHm03I7CP0jBe80G6ee03E6CP0a@TX0:S]300<0;d180;D0=TM?03]<
E00gBU40;3i802`oAP0[?TH0<4=:02Pk@@0^@DL0<4=902`o@`0[?T80;D1402/n@P0[?d80<DA802m4
A`0R=SX0@UEK02Pm@P1aQH/0;d9802a0A@10EEX09cY002/mA@0Z>dD0:ca603M9DP0jCUD0<4A;02e1
B00X?D8083<i03E7CP0W>Cd07bhe02dm@P0Q=3P08SDi02Tl@P0X>d80;4190396DP0`AU<0;dE@0316
D@0fCeH0=e1G03I<F010Df80=dYI02i1D00R=D@08cI503Q;FP0_@U40:Ca;02LkB`0Y?Tl0;45B02Pn
C00lDf40>e5S02@iC00Y?e@0>4eU03E9I00`AF80>Te^0394J00nDWD0>da_06IeRP1SL800935001hZ
>00K9cD082Xf02<]=`0L9S005b0Y02L`>@0R:c806b<[01dT;00K8RX072<[01`S:@0J8BL08BH[01TN
8P0I7R406alQ01dQ8P0K7ah05a/J01TJ701=CU007b0R01dN800R8bD07b0R01/L7P0G61X06AXL01<D
5P0I6Q`051PK01<F6`0N8RT082D[01@G7P0b=cd041DK01DJ800I7BD07R8[01TM9P0R9Rl07R8[01DI
8P0O8b`06b0V01`Q9@0T:B/07R@T01dS8`0R:2P04QPH02<Y:@0L8B@04aPL01<H7P0L8BL06AhT01HJ
8`0O8bh06AdX01HJ9P0E6BD07b<_03@gAP0a=4<092Pd01LI9@0I6bL05aTU01XM9P0L7bP05aXS01HI
800G6R406QdT01XM8`0D5ah041<J01DH8@0D5b007R4Z01PJ9P0B5200418N01XL:00B5240=3I301<E
8P0F62D03Q0M028X=P0[<Cl0O8:@04M<F00L7R/04A4M01@B7`0E4Qd05Q<M01XD7P0F41X0510H00H0
5A@J02<03@`B01dL8P16AD/08B0V00L6300G5Q`03@`B01LF700O7R@061LM01TH7P0G5Q`02`X@01/J
800<2a004@lD02PV:`0<2Pd04@l@00T7200G5AP04@lB01DC600<2@l05a@K01LD700A3QL06QLP03ll
A@0D4AP05Q@I01TF700_;C802`T>01<A5P03018@5@0Y014?500@3Q<040hC00H41`0@3Q404Q0C00l=
400C4A@030X=00h<3`0;2@`04a4D00l=400A3a805A4E018=4@0C3A405@lC01LA5@0F41@04P`@00/5
2@0F41@04P`@01D?4`0H4QH06A<G00d83P0A31<04`hE014<4`0D3aH030L>01<>5@0E41L081/R00X5
300L5ah040/A01@?4`0B3A400P0@2`l09@0B3A4050lC014<400?2Ph040/?018=4@0C3Q804PdA01<>
4P0B3A404P`@01H=4P0F31805@X@01052`0B20`01`01014;3@0G4Q@03`X>014<4P0C3QD04PdC010;
4@0@2a804PdC014<4`0=20l04@`B00`73P0A31<04@`B01<=4@0F41@03PP<02@N8P0B31001P0@2Ph0
1P0@2P`04@d<014=300A2`/050`?01<83P803`@:01P040D=01L>4`0J4AL03PL>01@>4P0?2``05a<D
018=400K6A`05A0F01@@5P0100D04PlF00h;4`0W92d0c<WB02dY<@0<1@`02`@;01@=500>1`h03`T=
01<=4@0=1`/200h82P0;00/51`0>20X04PhC00`;4@0:2@h030X>014=3P0D3Ph04@`:01491`0B2PP0
0`0C2P/01P0B30`040X:00l92@0A2`/03@L700l92@8071HF00<06A<C01D?3`0C3@d01`0B30`200X4
100@01D?3`0@2PX04P`<01<=3@0A2`/050h>018<300F410071HF010:2P0/9RH08A/K01H@400?2@T0
2P@4014;2`<04Ph?0P0A3@h2010<3@1@014=3P0P71d05a<D00`82@0[9bP02P@6014;3@0?2@/0C4I8
01`F600@2P`071HH05E?D@0E3a4030H801D?4@090`D03@L901<;3P0A2`d02P4401082`0?2@/04@P;
00l72P0>20X04PT<018:3@0?2@/060lB00d5200?2@/04PT<00/41P0@2P`03`H90149300C3@l02P@5
01`C5P0B2@`03P<701lD600[82@050T=00d21P0@1@T040H901L<400<0@D03`@801@93@0900<04`/@
00l93@0:10P02`D900L11@0>20`03@L;00l93@0@2Ph04@/?010:3P0?2@d030L:01H=4P0>20`050dA
00l62`0<1PX03`P<0107300>20`03`P<0107300A2@`03`T;00d72@0>20X300h8300K00l93@0600@0
71HH04@n@00400005PhA00l92`0?1PT03@H800d72@0A20/03`P:00d72@0?1PT03`P:00d72@0?1PT0
20<501L@5`0K5AT02`D900X4200>20`03`P>00`73@0<1`/02`H:008030L=00D03PP;00l92`0?2@/0
3`T;00h82P0200d72@0F014;3@0@2P`03PP:00@0000E3a401`4100d71`0=1`P02`D7010:300@2@l0
4``C00l8400:0Pd02P8?00d54P0A2AH03`LB00d5400C2aH02@8:01<<50803`P@0P0?20l01@0>1`h0
3@H=00d63@0=1`/03`T=00804`dA01@03PP<00T31`0D3Q803`T=00`62P0>20`04@/?018<400=1`/0
3PL;00d72`0?1P/03PL;00d72`0F3A802`<800h8300A20d02`@801@>4QCooooo000Kooooo`0401dI
6P0A3@h03`/<010<3@803PX;01T05A4B00/7200>2P/06QHG00d92P0;1`P03PT=00`72`0;1PX030L;
00d8300<1`/040/?00h:3@0C3Q80HeiR03lj?P0;1PX03PT?00`73@0A31807APN010;4@0400D03PT?
00<040/A02X03`X@00l:3P0@2PX04@/;00h8200@2P`04P`@00l93@0A2Q4030L=01XC6P1@BE405@dG
00/4300<1PP040X;01PB4`0>20T04P`=00`61`0B30d02PD600`61`0S7Ah03`T:014;3P0?2@d040X>
014;3`0@2Ph03`T=018<400<1PX02P@801<=4@0B310040X>018=3`0X92D0HUiO00h:2`0H51D201<?
40804@d>0P0B3Pl0;P0C3a005Q8H018?600C41T0:RP]020N8@0<2P/03P`<010>3`0F51L02PP=01/H
7`0C41/03@dH01DI8`0O7bT04a8J018?5P0H4aP071LK01@@4@0F514030d701lR6P0>4@/04aDB018D
4P0G6AL03Q0>01@F500H6QP05ALE020R800N81h0418@014C4@0B51805QPG01LI600F61L05aPJ01TJ
700D5AT04A8G01<D6@0F5Qh201PH800901LG800E61d05aXN01TL8@0F6Al05APO01HI800K7RL061/U
00806adZ00P061XW01XL:@0O8bh05QXU01lS;P0T:3<06alZ01PL9`807B4/01T06AdX01dQ;00T:3<0
8BDa01hT<P0M8c8082He01hV=00O9cD09blm02/d@P0I8c405b<`028^>`0H9340:3A002Pb>`0L9bl0
;3U002Ld>`2:V9l0Z[S0030nB00R<c`09CHo008093A000P0:ca602`mA@0]?TD0B5UQ0<3Af00kC5@0
;d1802Xk@P80=DI>0P0^?dL0<@0b@d/0:Se403a?EP0kCUD09CPo02/nA00]@4H0:Se102`o@`0[?T80
<4A502m3A00Z?Sl0;T9702m3B@0`A4T0;D5704EIG`0aADX0;T9702m3B@0Y?D<0<dM<02Tm@`0lCUD0
<d5;0352B`0eB4l0<dM>02]2B00W?T@08cY002a1AP0oDUP0<dA;02Xi@00Z?4009c/l02Pk?`0^@DP0
<dE?03Y>F@0jCe/0<dUF0398D`0bBU<0=e1G03QAEP0fC5H00P0eB5H07`0eAeH0;3m=02XmB`0_@U00
<TAC0353DP0^@4l0;3i=02m1D00]@e40<4EE02i3E00/@E@0<dQK03Y>IP16FW<0>4aW0355HP0cAVH0
AEQh041BLP0[>TX0<Sm:020/>00T<3`072Pd01lY<`0@6R<07bTb01hW<00R:S400P0V;SH01P0Y<S/0
7BH_01dV;`0b>D40<3Lo01PO9@806AhR03d0720S020T9@0Q9BH07R8Q01PI6`0O82803a0B020Q8`0K
71h07AhP01lP8P0H6A/071dO01@E5`0E5QP05QXM01/N9@0C5b0051PQ01LK9019CEH07B4Z01`P:@0S
9c0092Pa01TM9P0Q9Bh08bL`02lc?P0I7BL08BH/02DZ;P0P9BL0:S0^06abL02RZ:D0ATa:02D[:P0M
8b<05a`O01TN8P0J7b@07R<X01HJ8P0I7BL061`V01TM:00N8Bl07R8_028U=00P8c<06Qd/01LI9P0E
5b<06adY01dP:@0H6b@05aXS01`O9P0S9Rd082<Z00805QTN01T06ahS02<V;P0I72@06QdU01DH8@0E
5b805QTS01DG900V:3D0Q8JC028T<P0?4Al06al/00hE8`0T:ST0OhJC04iCG`0;3AX05QHS01@B7@0E
4Qd05Q8K01TC700K4ad061@L00D051<I01X05QDK01LF700A41H05QDK01DD6P0A41H06APN00l>500E
51X05aHL014@5P0E51X040lE01HE6`0L6b405QDK00l>500B4AL06ALK010>400A3a405A<F018@500B
41D06QPM00`:40804PlG00P02@H>01LD7@0B41H04Q0E00`:3`0R82D05A<H014?50<04Q0E00D04@lD
010>4`0@3Q<030X=00h<3`02018@4`06014?4P0@3Q404@lB00`:3@0D4QD03`d@0P0@3Q42014<400H
01<>4P0F4AD05a4E01<=4@0F41@03PT=018=4@0A31005a8F00l:3P0B3A<0AD17024L8P0>2A007QTO
04U4BP0W8RP0G5MM02@O9P0D3aD04`hD01@?5@0B3A404@`@0P0?2Ph05@0A31004PdA014<400A3100
4PdA01<>4P0B3A403`X>010<3@0B3@l04`d?01<:3@0E2Ph05`/?00l51`0F2Ph05@`?00h82P0G4Q<0
DdiB01LB6002014<4`0501D@5P0@2a803@P>01HA5`0D3aH00P0F4AP0200;1Pd04`hD01<=4@0F41@0
1P0401@>4P0C3A405@lC1@0A2`l0:00@30h04@h>014=3@0C3`l05`hB01@93`0B1P`050L@01463@0I
3QD03PL<00d6300Z92P04`l@014=3P0?30h03P/>02DQ9`0@3A<07AXQ00h<500=2a<04Q0H01PG8@0P
6bD05a0H00h73P0D3A@04P/B010:3P0B31003`T=00l92`0B30h03PP:00`7200C3@h04`d=010:2P0?
2@T2014;2`803`T900D040X:014;2`0A2`/04@/;018<300200l92@03014;2`0?2@T04@/;00<040X:
0`0?2@T6014;2`0;01@>3P0>20P040X:00X4100A2`/071HF010:2P0B30`03`T900h8200C3@d00P0@
2PX01@0?2@T05@l?01LA4@0A2`/03`T900803`/<0P0>2P/200l;300I018>3`0=2@X04`l@018>3`0=
2@X05Q8C01<=3`0B30h05A0A03Tc=@0K5AL04P`>00/51`0X8R@05Q0B00/61`0<1PP04`d?014;3@0G
4A<03@L9014;3@0>20X03@L900l92`0200h82P04010:300A2`d03`T;00d72@803`T;00h03PP:00l9
2`0A2`d050h@010:300K5AL05@lA00/51`0A2`d05P`?00/1100D2@d04@H:01@93@804PL;00/04@H:
01872`0@1@T04@H:01@;3P0A2@h06A<G01XD600=1`/04@/?00h8300600l93@0601PB5P0D3Q806Q@H
01<>4@0J51P0=S0d1@0>20`00`0@2Pd03`T;00d72@0400h82P0:01PB500=1`T04P`>04M1@`0I4aD0
7ALI00l92`0>20X03@L900h82P<03`T;0`0@2P`02@0?2@/04P/A014:4P070PL0>c@k03@]=0060@@0
40X>00d72`0300h82P0400d72@0?2@/040X<014;3@8040X<01T03`T;00`7200?2@/03PP:01D?4@0>
20X03`T;00/51@0>20P030H800X41P0?2@/03PL>00h73`0?21005@dH01P@7@0E3AX03PHC00l74P0@
21<03PLA00d63P0>2@l04@XB00803`P?00<03`T=00h8300=1`/00P0=1`/02`0>20`04@/?014;3`0?
2@d03@L;01TC5`0E3a<04@/?010:3P0>20`030H:00H03PP<00H02P@8010:3P0C3A402`D901PB5P11
>clDooooo`006oooool00`0A3@h02PH700`82@0200h:2`0i010<3@1IEEH07ATJ00@00@0A3@h04Ph?
014=3P0?2Ph03@P<00`72`0=20`03`X>00d8300;1PX04@`@00P31`0e<3@09R4U00d8300?2Q001005
01@?5@0m>3h081/Q00h93`0A318040/A014<4P0B3A<040/A00h93@0E3a0050h>018<300A2`d03PP<
00d72`0>1`h030D<00H01P0;10`0100501D>5@0C3A003PP<018<3P080`D05Q0D01@>400<1PT0618F
00`6200I4aH03PP<01D?4`0>20`040X>00<04@/?00l05@lC00h8300E3a<03`T=00d72`0K5AT05A0B
00/7200f<S<03PX;00`82@050@803PX;010<3@0A3@h00`0B3Pl01P0F4QT061DN010=50040PP02`T<
00D31P805aDF01d020H901HC6@0:1`h05a@M010?6@0F5Qh04Q4G01TF7@0M6b006aHK01<>4P091`P0
61LF00h@3@0F6aL0314=010B4@0H6QT07AlN00/=300A4a805ALF010B4@0K7A`07R0O018D4`0C5A@0
61XI01@F5@0201LI600301PI6`0K71h05AHJ008051DJ00L051@L01DE7@0F5Qh061PQ010C6P0B5A`0
51LN00<05APO00<0:Rdf01`O:00G6R<00P0H6b@0?`0J7BH092Pc01TM:00K7bX07b<^024U<00S9c80
7R8]01dQ;00F6RD061`W024U<00R9S408RPd02H/>P0i?dd0:30m028Z=`0G7b`05b4]03<nBP0D82`0
7b/g01dY=@0H9Bh06R@^01dY<@0O;3@0:cQ002hkA00_?DH0938m02@e?`0/?DL0;3a902Hf@`0X>4D0
:CY303=4C00`@DT0@eAL02Lh@00^?dL0:S]30311B@0b@d/0;d1802Xk@`0Y>T80:ci502XmA00/?dH0
:3]202e0AP0W>T00:Ca002Xm@@0/?d<0<dM80314A@0W>c`0=TU?0354BP0202i1A`2S02e0AP0O<SP0
;3m502Pk@@0`@dT0?e9H01lb>00Z>d80<T190352BP0aA4/0;d=:02e4BP0`Add093]102Dj?`0T=cd0
:CY103=2B@0Z?4409cXn02Xm@`0_@DT0=DMA03]?FP0kD5`0=deJ03E;EP0bBE@0=DiE039;DP0_ADh0
9CM502doC@0/?T`09SQ602`nC00Y>dT0<TAB02m1C`0W>DL09CM50312D@0^@E80:d1A02]0D`0T>D`0
8CI;02e2F00W>e<0:cmH02a0F@0W>eH0<4AO03e?JP0e@U80<3a801XV<P0C7b/08Bdi01dW<@0L9Rl0
92hg01hW<00P9bl06b8Z00/B6P0C72D04Q/T01`U;P0T:c<07RD]01LN900K82@06QlS01XN8@0L8240
7B4R01/O7P0J6ad06AXL01PI6`0O828061TK02X[;@0O82805aPJ024R900K71h07AhP01lS9P0E61l0
4QHO01<G800Q9Bh03A0I01TM9P0E6B806AdV01XN9`0B5Ql07R8[024U;P0l@4/06QhX01/P9P0P9B/0
92T/0498B02]/k40jNk]05YPGP0Q9bL06AhP01DJ7@0H7B406QlS02db=P0Q9R`05Q/Q01@H8@0C5b40
6alZ01TM:00G6bL061`X01LK9`0T9S8071hZ024S;`0G6R<04QDN01hQ:P0M82L0;2lf02X]=00I7240
3a8G010C600A51T051LN01PK8P0G6R4051LN01<F7`0C5R00@dEA01LI9@0R93008bDb00D95@0H7bX0
6Al[010G8@0B5R805aTU01PJ8`0E51`05a@M01LC6P0D3aH05PlG01LC6P0501<B600T010?5@0H5ad0
5aHL01PG7@0K6R004Q4G01HE6`0J6Al061LM01@C6@0?3Q@04A0F018A5`030PP03@`B02HU:`0Q82H0
61LM010>500?3A0071XO01HD6@0G5AX03P`A02HT:@0I5a`04a0G01DB6@0C4AH04@hD00l=4P0;2@h0
518G01`J7`0D4QL061HK0`0B41D04P0A3a@040hC010>4`0<2Pd02`T<01<A500A3a8030X=01hL7`0I
5aX04@lB01<A500=2`h040hA014?4P0C3Q804PdA01<>4P8050lC01@04@`@01<>4P0@2`l04@`@01lJ
7P1IE5P06QDI01TD6P0K5Q`00`04018=4`0F4AL020<902/V;00:1P/05a8H01hI7`0A3A8061<I014<
40@040/?01@04@`@00l:3P0@2`l04PdA01@?4`0C3Q803PT=00h:2`0E41405@lA0189300C2@d06PhB
01L;3`0I3a809ahQ024K7@050@8061@E01D@5P8040/A00`050lE010;4@0<1`d03`/@06mZL03FdML0
;2L]00`73@0D3aD03`T=01TC5`0?2@d201@>4P0300d72`0B31004P`@00<04P`@01d04@`@014>4@0>
2@d040/?01@;400D2@l05@X@01@8400K41H03@@901LB5P0@2`l00`0200l;300=2@X07APK01@?4`18
@dT09R4W00/83`0500T030PA01LD7@0300T091hW01094@0:0`X040T@014:4@02014;3`0800l93@0A
2`d04`d?01PB500U7b408adN014;2`0?2@T3010:2P803`T900<040X:014;2`0A2`/00P0A2`/200d7
1`03014;2`0?2@T04P`<00804@/;00@04P`<01<=3@0C3@d050h>1P0?2@T04P0A2`/030H601LA4@0@
2PX030H600/51@0D3Ph04P`<010:2P0=1`L03PP801@>3P0I4a<05a4A01<=3@0?2@T03@L700`61P80
30P90P0=2@X200h:2`0I00d92P0<20T02`L8010<3@0F4Q<04@d>00h82P080P@040X<01<=3`0=1`T0
1`4300X41P0B30h08A/M014;3@0<1`P04P`>00l92`0:1@H040X<04M1@`0e;c401`4300h82P0200d7
2@0900l92`0@2P`03PP:00H00P0E3a4040X<00`6200A2`d03`T;00<03PP:00@050h@00L10`0J51H0
:R0T0P0A1PX06`0B1`/050T=00`11@0D2@d04@H:01052@0=0PH03P<70189300A2`l0?cTm048l@00?
2@d05@lC014;3`0B31003`T=00h8300=1`/03PP<00l93@070PD03`T=00T31`070PD05Q0D01TC5`05
00h83003010:3@0?2@/03@L900<03PP:00L02`D700`6200<1PP03@L9018<3P0400006aDG00L03PP:
00l03`T;010:300?2@/03PP:00T4200?2100100401L@5`0N5ah0100200T31`0=1`/03`T;010:300?
2@/00P0=1`T03@0?2@/040X<010:300?2@/03PP:01D?4@040000>S@f06MQH`0P6Q`030H800h8200=
1`L00P0<1PP03P0=1`T030D<014:4P0?21003@D@00l7500@21D03`LD0149500@21<02@<<01D>5P0A
2Q805@hF0P0?20l00`0?2@d03PP<00d72`0400d72`0900h8300@2Ph040X>00X4200;1@T040X>01<=
4@0E3a<04`dA00H03`T=00H04@/?00d72`0>20`03@L;00`62P0C3A4Dooooo`006oooool09@0>2P/0
2PH700`82@0>2P/03@T:010<3@1QGEh08QhO00H20`0>2P/04`l@00X61`0A31003PT=00d8300?2Ph0
40/?00h93@0;1PX04PdA00P31`070`H02`H:010;3`0:1@/05a8H01<>500K5Q`01`88018=4`0=20h0
3PT?014<4P0C3Q@040/A00d8300F41800P0E3a401`0C3@l03`T=00l93@090`L01`07014:4@0M5Qd0
0P0>1`l03P0A2Q0030D<00`62P0I4QP030D<014;3`0;10X07AHM00l93@0=1``02`@;014;3`0@2Ph0
4@/?0`0C3A40300B31003`T=01PB5P0A2`l06A<G02@N8P0F4A<02`L800D10P0G4a@0510A01DA4P<0
4Ph?0P0C3a00?`0D41404@dB01DB6`0<2A005aDK00`:3@0A3a804a4D010>4@0B41D04Q0F01HC6P0C
41T0518I01lN8`0@3Q<04@`B010;3`0C3A40:B@X00X82`0@4A803a<B01<I5`0L8b402`l>01@F5@0L
7Qd03@l>010B4@0B51<03a4@01@F5@0F61L051HE01HH5`0G6AP03a0B01DF600G61X051DG01HG6@0G
61`061TN01LH7@0F5a`05ADM01HF7P0H620051LN01@G800F6B805aXS01PK8`0F6B009BP_01TL8`0E
61l05aXQ01HI800H6b80;S8k024U;P0201TM9P0b01XN9`0M8BX0720Y020T;@0I7BH05ATR01dQ:P0R
9S406R0/01dS;`0a=d<08b/f028Z=@0K8bh05R0Z05QTK@0Z=d0072Tb01/X<@0N:c@05b4[02Da>P0U
<S/08Rlh01`Y=00X=T408Bll02@d@@0Z>TL0:SY902DeA00V=T<09SM002m0B00`@DT08C8j0393B`0X
>D40:ca402Lh@00Z>d<0;d1802dnAP0Y>T80:Ca3028e?00W>T40:Se402`oA@0Q=3X202`o@`0502e0
A00dB4T0<4A502Hj>`0Y?4800P0/?dD0=00bAD/0:3]102Lj@00U>3h0;D1602`oA@0`@dT07S4g02`m
A00a?dP0<45902i1B00/@4L0;DA:02m6C00Y@4H0<DE<03A6CP0dADd0=49;02Pi?`0^@DD0<dI<03M9
D@0kCEL0?51K03]?G@0hCU/0=TaI0358D`0aBU40;DI=02a2B`0W>DL0;Cm=02<e@`0Q<d40;T1>02Pj
B00Z?4X0:ce;02HhAP0R=480:S]:03=5F@0]?e<0;3iD02doE@0[?E<0<49H02<eB`0]?eL203=5G@0G
03A6GP0gBEl06bPh030lB00[=d<03QPT01`V<P0N:38082Tb01lX<@0P9c409B`d01XQ:@0V;CD05AhW
01HO:00I8R/061lW01@K8`0J8BL08RL[01lT:00K7b800P0I7Ah0100G6aX05aPJ01/L7P0G61X201TJ
700<020Q8`0S92H0414C01PI6`0O82808b@V010D5`0L7bH05QXS010D7@093AH092Pa0P0L82T201TM
9P0o01HJ8`0R9Rl07B4Z01XN:@0L82X08BH/020U:`0O92L09R`/05AJF026S8/0:c4a01HK7P0M8RD0
724U01TN8@0G71l0:Bha024V:P0I7R8061dS01@H800G6b@05ATR01PL9`0I7BP05QXU01@F8P0=3a/0
4aDQ01/N9`0m@4T0GF1Y02DX;`0M82L05QTP018E6P0G6Ql06ahS01`P900D5a`03Q4F00lB5`0F6Ah0
6A`S01HI8@0W:S<092L`00022`0Q8bl06alZ00/B700B6B<05ahV01<G8@021@h051DM01HE6`0H5A`0
71TP01HD6@0H4aT06ADL00L05A@J00T03PdC01<B600B4AL03PdC01LF700F5A/04Q4G010?5@0B4AL0
0P0A41H05`0V9B/06aXP07EdNP22PHL09B@Z01HD6`0D4QL0514H00P5300>2a804a4F024O900F51T0
3`dB00h<4@0L6Qd040hC02XX;@091``03P`A010>4`0610T030X?00<04Q0E01404@lD010>4`0@3Q<0
6ALJ01DC5P0B41<02`T<014?4P0l>Sd08AlR01LE600E4aH040hA01DC5P0I5aX05A0D01@?4`03018=
4@0D00h93@0E41@05A0D01<>4P0E41@0BDA800h93@0910X050lE01/F700H4aT05a8H01`G7@0N6Al0
5a8H01/F700:1@/05Q4G014<4P0A3104018=4@04014<400>2@d03`X>014<408050lC00d04@`@00d;
300D4A805Q0B01<:3@0D2Ph06PlC01H;3`0=10H02@03018<3P0A3@h061HG00D040/A00P04@`B00d8
3P0`:c40PWf3010<4@0J5A/061<I014;3`@050hB00<02P@8018<400B31000`0B3100:P0A31004@dC
00/6300>2@l04PP@01<83P0G31804`T>00l42P0=10T04@/?00/7200F4Q<02`H901H@500X8RH02`D9
02`U;00C31<02@@;00T22P0E3QL02P@>00L02P080`X030D=00h73P0@2A003PL>00l93@0B31005@lC
01LA4`0<1PP0100000L10`0C3@h03`T900h8200?2@T04P`<014;2`803`T900<040X:014;2`0A2`/0
0P0A2`/200d71`03014;2`0?2@T04P`<00@040X:200?2@T04P0B30`02@<3010:2P0;1@D030H601D?
3`0A2`/03@L700l92@0>20P02P@4010:2P0C3@d04P`<00h8200=1`L040X:01@>3P<03PX;0`0?2``0
4P0;1`P040`=00d92P0>2P/05A4B01<?400G4A<040X<01PB500>20X04P`>00l92`0@2P`03`T;01D?
4@090`D030L8010:30804`d?00<0;BLY06aVJ01@BT`00P0>20X200d72@0A00l92`0@2P`03PP:00`6
200J51H050h@00l92`0C3@l040X<00/51`0G4A<030H8014;3@070@<04@/=01P?4P0=10L00P0A20/0
100E30l03`H901/B5@0L4aH201072P0C01D<3`0?1PT04P`@03La=@0k=CT03`T=01H@500>20`04P`@
00l93@0>20`03@L;00h8300?2@d06A<G00d72`0N61`030L:00L11@0600h83003010:3@0?2@/03@L9
00<03PP:00L03@L901LA4`0?2@/0208402<M7`0=1`T02@@500D03PP:0P0=1`T300h82P0<00d72@0=
1P`05PlG01/D6`090`T03`P?01`F6P0?2@d03@L;00l92`0A2`d03`T;0P0=1`T300h82P0;00d72@0<
1PP03PP:00X41P0;1PL050h@00H00P0A2`d03`T900d71`0=1`T00P0?2@/03@0<1@`04P/C00h73`09
0@`02P8?00d54P0@21D02`<>018:5@0@21<02P<;00L0200=1Ph00P0?20l00`0?2@d03PP<00d72`03
00d72`0400`62P0=1`/03`T=014;3`803PP<00@03`T=014;3`0?2@d02P@81P0?2@d01P0@2Ph02@<7
00h8300D3Q8040X>00T31aCooooo000Kooooo`0A01<?400?2``040`=00h:2`0:1PL03@T:018>3`09
1@H030P901DA4P0U8B803@T:010;3`0=20`030L;00h93@0?2Ph00P0=20`01P0@2`l04`hB00d9300D
3a<030L;014<4P803`X@00/04`hD00X62`0@2a4040/A00/6300<1`d04PdC014<4P0?2Q003`T=014;
3P0201H@4`0M01<=4@0E3a<04`dA00`62`0F41D06A<I01@=5@0>1`l040TA02dV;P0L5Q`04@/B00P1
200D3A@040TA018;4`0A2Q804@XA02PQ:00D3A<04P`@01<=4@0D3Q804`dA018<400C3A404P`@014;
3`0B31000P0A2`l0200@30h06ADF00l<300@30d04@d>01hJ6`0@30d04Ph?0P0C3a0201@@4@0U014>
4`0=2Q405Q<J00l=4`0?3A806ALK014?4`0<2Ph0518G00h;4@0J5ad04@hF01<A5@0/9bL08A/N01/F
6@0H4QD09b8V03hi?P0I6A`05ALJ018I700A6Q`092h^01/O8@0A4a<051HG014B5@0B4a@05AHH01DF
6@0C51D04Q@E01HG6P0G61T04a@G00l@4`0201@E6003014B5@0E5QT06AXN00<05aPM0P0G5ah01`0G
61l07R4[01`O:@0K7RP071lX01XM9@0E61l00P0J7B<201lS9`0k01XN8@0J7R806AhT01PL9@0J7RL0
720Y01lS;00M8BX0720Y01lS;00N8R/082@]02@X<@0P92d09Rdg01dT;`0M8bh07BH`01`U;`0N9c40
82Xc02Hb>P0G92d082de020]=P0L:C40:cDo01LR;00W<ch05B4]038oB`0O;CT0:3I302De@`0R<T00
8C5002@dA00W=dD09SM102Pi@P0Y>T<0:3U202Lh@@0X>D80:CY302Df?`0V=d00:ca502dnA`0[?4D0
9SU002i1B00aA4/0:3]202Tl@P0T=cd0:ci202`o@`0[?T800P0_@d@0D@0Z?Sl0:C]203A6C@0^@4H0
<TA;02Li?`0mCeH0<dE;02Xl@P0]?dD0:Sa302Tk@P0]?D@0;ci602dnAP0/?dD0:cm502U0AP0X?dD0
93]102@h?`0^@DT0;Sm802Pf@00W>400;T5503A7C@0eB500>D]G03U<FP0fBeP0=deK03M=FP0bBED0
<TYD02i7CP0X?DL0:S]902HgA@0L;C/07Rlm028c@@0P<Cl08S=002PiA`0/?DX0:3U602<d@`0_@5@0
;3eE02TjD00a@UP0=TMN02hoE00_@5D0<49E02XkCP0mCV00=dUK024b@`0[>4D09S4m01/V<P0oBED0
>D=?01TR;@0K92d072D^01`S;@0I7bL04QPP03a2B`0_>4408b`e01/T;@0P9bl07bH^01`S:@0T:Bd0
82DY01XN8@0201TM7P1E01TM700I71d06Q`O01`O8@0L7R407B0R01<F600A51H0<38e02d`<P0F6A/0
7B0R01hQ9@0K82H04QDN01PL9@0S9c005a/T01dQ:P0P92d0720Y01/O:00H72D082@]01LK900K7bX0
92Pb01/P9P0E6Qh06b0S01/Q8@0F71/0:c0a01dS900M8RH092T^01XO900K82@05AXM01LL7`0F6ah0
724T01TN8@0I7R<05a`Q01@I7P0H7B<06AhU01@I800H6RD07Al[01hP;00I72D071lX02HY<P0G6R40
5APO01LJ8@0K7R<06A`Q01HI7P0F6Qd07R8T01`P8P0O8bL0720T01XN8P0G6R005QTO01DH800L7bL0
2@`D010C6`0F6b404QPO014G700D5ah05QTO01`N8`0C51P03`hD01LE6P0D4QL0510F01HE6P0601DD
6P0<01<B600@3aD07A`R01DD6P0=318051<I01HE6`0@3aD06APN02DT:P0M72805aHL0P0D4aT04P0b
<CL0<2le01PG7@0B41L06AHN01PE7`13@4P05Q<J01LD6`0A3Q@040hC01@B5@0=2`h071XL00h<3P1D
DUH071XO01XH7@805Q@I100B41D0200A3a@040hC010>4`0=2`h04Q0C01DC5P0?3A003P`?0P0F51L0
0`0=2`h040hA00l=400201DC5P0301<@4`0B3Q8040`@00804@dA01@03``?010=400=2Pd04a0C00`8
300A3Q403``?00l:3`0B3A805a8G01<>4`0B3Q8050lD014<4@0F4QH02PH:00l:3`0C3Q<061<H014<
40@04`hB01@04@`@01<>4P0@2`l03`X>014<400B3A404@`@00h<3P0B3Q404Ph@018<3`0D2Pl05P/@
01062P0L4QL03`T<018>400@3@l03@/>00l:3P<040/@00`04@`A018=4P0D3a@050lD00X62P0K5Q/0
61<H00X62P0D3Q803@L;01/E6@0?2@d2018<40D04@/?01h04@XA010;4`0=1a005@hF01H<500C20h0
5``B01P?4`0n=CT06A<F00l<3`0?3@l02PP:01D@5@0@2Pl04P/A00D0100C31<03`P?01/C6`0:0@X0
5PdG01484P0B2A<040PA014:4P0D3A@04P/B00h73P0?2@d2014;3`0500l92`0<1PP05a4C038/;P0]
9bP00P0>20P00`0@2PX04P`<014;2`0200l92@05010:2P0A2`/04@/;014;2`0B30`00P0?2@T00`0A
2`/03`T9014;2`03018<3003014;2`0@2PX040X:00H040X:01804P`<00`61P0L5QH0618B00l92@0<
1PH05@l?00d71`0H4Q8081XJ01@>3P0@2PX04P`<01D?3`0C3@d03`T9010:2P0<1PH2018>3`0>014=
3P0@30d03`/<00h:2`0?2``040`=00l;300<20T03@T:010<3@0A2`d040X<01D?4@0<1`P300h82P0<
00d72@0A2`d050h@00d72@0B30h040/<00h92P0:1@H06Q@F01/E5`0B30h03PP:0P0<1PP01P0>20X0
3`T;00d72@0>20X03`T;00h82P8030H800@03@L9018=3P0>20X02P@60P0?2@/03`0;1@L03`H901<:
3@0E30l040L:01@;3P0?1PT05Pd@01XA500>1@P03`H90189300;0PD040X>00`62P0200l93@0301<=
4@0:1@P03`T=00D03`T=00H02`H900d82`0>20`07ALK03La=@0J51P500h83003010:3@0?2@/03@L9
00<03PP:00P03PT:00`6200?2@/05@lA00h92P0<1PP04@/=00h82P<03`T;00d03PP:00d72@0=1`T0
3PP:00l92`0>20X03@L9010:3`070@P03@H=00h73P0:0`X05Q0D00803`T=00L03`T;010:300?2@/0
3`T;00h82P0=1`T03PP:00803@L901T030H800P3100D3Q0040X<00h82P0<1`P03PT:00l92@0;1@D0
40X<01LA4`0D3Q003@H=00h73`0=1Ph040PC018:5`0A2AH03@DB01@<5`0;1@h040TC01XC6`0k=3`0
614I00803`P?00@03`T=00h8300=1`/03@L;0`0>20`0100=1`/03PP<00h8300>20`200d72`0300l9
3@0>20`02P@800L03PP<00D040X>00h8300;1@T03@L;014;3`0Dooooo`006oooool04`0<20T02PH7
00d92P0<20T02@D600d92P0A3@h05a<D00h:2`091@H0920Q00l;300=20`02PD900T4200;1PX030L;
00X52@0?2Ph00P0;1PX03`0D3a<030L;010;3`0>2@l02@@:01<>50080`T03@P>00h93`0S7R@04`hD
00d83P0?2Q0040/A00l:400200h8300F01@>4P0B31003PP<014;3`0H4QH02@<701@>4P0>1`h04P/B
00/42`0>1`l0WIJN08R1R@0E3QH030D=01<<500H4AT040TA01<<500A2Q80FeAL030Y<0<04P`@00<0
40X>00l93@0?2@d00P0B31002@0F41@01@0302@N8P14?d403@T:02HR8`0C3a003@T:018>3`03010<
3@0U014=3P0B3Pl04Ph?018>4`0O72<0IVAY01XH7@0H5Q/04a4F010>4`0?3A803@/@01lM8P0@3Q<0
40dD010<3`0N61P030H6020J700O6A/05Q0D01/F700F5AX051LK014I7013CDl0]/3403Xm@P0L7B40
4A8F018C5`0?41@04a@H01DF6P0C51P05QLK01PI7@0201LH700C01XK7`0H6Ad04a@H01LH700O82@0
7QlS014B5P0B4aL05AHK01HG700G61d05aPN01TK9`0G6BH05aTU01XM9P0J7BD05QTP01PK800201HJ
7@0501@H6@0E6AX07b<V01lT:P0N8R/00P0I7BH201`P:@0601lS;00K7bP082@]02hb>`0b=Sl07b</
0P0H7bT08`0F7BL0:34j01dV;`0M9Rl051hW02@_>00R;cL06bP`024^=P0S<3P05AlY02/f@@0O:cL0
82`h02<`?00V=4408S0m02LgAP0V=TD093A302DeA@0U=D@09SI202XkA@0dADl08c@n02`mA`0K;3H0
9cQ202`mA`0Z>dD093Do02Lh@P0]?TP0<TE<0080:Se402L0:Ca30313B@0Z?D<093Lk02Tl@00W>Sh0
:Sho02m3A00^@T<0:S]203M8C`0Z>d80;d1702Xk@P1EIVd0?TmF02Tj@@0/?D@07c0g02/l@`0V=Sd0
9cHm02Hg?P0Z?D<0;T=802a3B@0W?T@09Se3020d>`0dAdl0=4E?02Hd?`0/?D@0;3m50313BP0_@T/0
=TQD03U<FP0eBEL00P0eBeT0F00eC5P0=dmI03A<EP0Z?TP0<41=02Hf@`0U=D80:c]801`/>@0Q<Ch0
9CE202<c@00U=D80:c]802hnC00]?540A5A[04EEK00X=dh08cA802TiC@0W=TT0;Sm?02@eA00_?dh0
9CM301`/>@0O:cL04adY02dg@`2MYk<0I6ij028Z=@0I8R/06R</014H8P0L82T07b</01hS;00Q:380
7BH_01hW<00N9Bd06B0X01LN900I7R805Q/O01<G6P0E6AX06AdN01dQ8@0F6Qd092P[038f>@0K7b80
3A4D01XN8@0D61/0;C4d02HZ;@0O8bH0;S8e014D6@0C61h06alX01lS;0072a@07R8[01dQ:P0I7BH0
7R8[024U;P0J7RL08RH_01hR:`0H72L06alW01`Q9`0L8BD06AhQ01@J6P0L8R806R0Q01/P900<4AD0
6alW01TN900E6Qh401TN8@0J00/@4`0F6al061dQ01@I7@0F6al06b0T01XO9@0J72L061XV01@F8P0J
7BH071lX01PK900K7RD05QTP01@G7P0E61d05QTN01HJ7@0M8B<07b<T01@H6@0F6Qd051PK01<G6P0B
5AX201dP9@803a8I00d04A@K01LL800?51P04AHJ018E6P0K7R<09RP]02DV:P0F5AX06ALL01DC600C
4AH05A@I00D04a8H02@051<I01LF700B4AL051<I01HE6`0A41H051<I01TH7P0@3aD071/Q02/Z<00I
61h04A0F018A5`0;2Q004a8H01HE6`0;2Q004Q0I01DB7@0=2QD0LVmi010=5P0C41L061DK01LE6P0J
61/02`T:018@4@0F51@05A<F0040100R82D02`T>018@5@0C4AH3018@5@0@014?500@3Q<040hC01<A
500B41<030X=01@B5@0U8bH0928U00d;3P081PT0518E01TG6P0L6Qd0518E00d;3P8030X=01L040hA
018@4`0B41<03`d@01<A50091`X04Q0C01<A500:20/03`X>018=4@0300807QTM01TD600300805a8F
01<>4P0;1PX050lC01D@500=20`03PT=010;3`02018=4@04010;3`0>2@d06QDI01@?4`803PT=0200
3`X>00h93@0=2`h030T<00d8300@2Ph04@T>0146300F2a404P/?00X4200B3A404@lB01DC5P0D3a<0
3@P<00l:3P0D3a<04@`@00`72`0=2@`01`8601@?4`0=20`02`H:00l:3P0A2`l05Q0D038/<00B3100
3`T=01H@50D040X>01X040T@00d74P0C2aH08AXR01lE7P0B1`d04PT>00h62@0R71h01`8600T8300@
3a@05QDJ00X7300@2a405@hE01@=500:0`X05PhE00/12@0F31D06A0H01P>5`0F31D050`D01094@80
30D<00/04@XA014;3`0=1`/02`D900l92`0E3a403`T;00`6200?2@X040X:00l92@02010:2P803@L7
00<03`T9010:2P0A2`/00P0A2`/01@0B30`040X:00l92@0A2`/03@L700<03`T90`0@2PX00`0A2`/0
40X:010:2P04010:2P0@01D?3`080P804P`<00l92@0;1@D05@l?018<30090`<06aDE02XT900H4Q80
2`D501`F5P0N61P05@l?00d71`804@/;0P0C3a007@0A3@h03PX;00d92P0<20T04@d>00/7200@30d0
4Ph?00l;300D41403@L901<=3`0D3Q002`D700l92`0@2P`02`D701PB500h<S@0B49401H@4P0@2P`0
1`4301<=3`0I4aD030H800d72@080P@03@L9008030H801003PP:00l92`0=1`T050h@00/51`0A2`d0
4`d?00l92`0F4180EDmA01XD5P0@2P`02`D701<=3`0>20X03`H90P0A20/02`0=10L05@`?01482`0@
1`X04@P;01D<3`0A20/03PD801@;3P0<1PX040X>00803PP<00X0208600h8300=1`/03`T=010:3P0A
2`l040X>00l93@0=1`/04@/?0P0F41@00`0S7B40100200h8300400h83003010:3@0?2@/03@L900<0
3PP:00/03`T;010:300=1`T02P@600l92`0L5QP030H800d72@0?2@/040X<00l92`0200d72@803`T;
00d040X<00l92`0?2@/02`@:01<<500?20l04@XA018;4P070@D03@L;00l93@0?2@/03PP:00H03`T;
00@03PP:00d72@0@2P`0618D0P0@2P`0500=1`T040X<00h820090`<04P`>01dG6@0G4A<03PL>00l8
400>1`l03@D@00h64`0?1a@03PHC00T1300E3AP0<RXe00`53@0e;SH07QLO0P0?20l0100?2@d03PP<
00d72`0=1`/400h8300500`62P0:10P04@/?00h8300=1`/00P0>20`00`0;1@T03@L;00d72`0500d7
2`0500`62P0=1`/04P`@018<40080PH05?ooool001_ooooo01805Q8C048n?`0D4140510A010<3@03
000020@500d92P0?2``02`L800`82@0H51D03PT=018=4@0I51P05a8F00`82`0<1`/200l:3P0D00<0
0P0C3Q8040/?00/62P0<1`d02PD;00/6300?2Q004PdC01<>500f<CL07APN00l:400910X06QDK00X5
2`0C31<04@XA0109400?2@d200h8300B01D?4`0?2@d03PP<018<400D3Q804``C01@=5@0R6b<07QLO
01094@0>1`l05@hF01@=5@0<1@d05@hF00d63P0A2Q8040T@0P0F41@200l93@14018<400C3A405a4E
01TC5`0>20`071HJ02hX;01:ADP05a<D01<?400<20T04Ph?01DA4P0A3@h03`/<00h:2`0@30d0510A
01LC500D4AD03@/@01/I7P0P7R<030X?00d:4@0B3aH0514H01HD6@0E4aP03P`A00l=4P0C3a005a8?
01PC400B30`040X:01D?4P0G4QP07ahS01DH700R:Bl0MGj30>K`m011A4T03PlD01/L8@0>3a@02``A
01DF6`0>3a@02``A01DF6`0D5AX0414F01XK800B4aP04a@I01PI7P0E5Q/0414F01LH700B4aL06a`P
01dN8P0D5AT06a`P01DF6`0H6b@201LI9@0:01HI8P0G6R8061/R01hQ9P0K7b80720Q00hB4`0M8B40
6alP01XO8`D06QlU03<061dS01TN900J7bD0<cPn05eRJ00J7bD05A`T01/R:P0P9bl08BXa01lX;`0K
92/05B0V01TU:`0J9bd072T_01dZ<00I9Rh08bdg02Ha>`0R;cP07RXf020]>@0W=D009SA1024a?P0O
;c`0830o02@d@`0U=D@0:3Q4020a>`0R<cd0:3U302<d?P0M;SP0:ca603=4CP0eAU00;Ci803=4CP0[
?4H0:ci502m2B@0Z?D@0:3]202Lj@00S=S`07c8f03Q;C`0Y?4000P0_@d@00`0X?3d0;Sm602`mA003
02Xk@P0U02/l@`0mCUD0;Ci502Pi@00R<cX08c@k02De>`0Z>Ch0<49602`oA00[@4D0<d]?03I=DP0U
?4809c]402XlA`1_Oh`0EfEb02XkA00Z?D<0EfYa02`nB00mCe/0>DaJ03U=G@0nE680=TaJ03Q?G00a
BE<0=DeG02XnB@0]?DX0;cm<02XjA`0R<Sl0830m028b?`0202<c@01/024a?P0S<d00;3a:03E4F@0_
?UD0=dEK04mKL@0]?4l0;Sa>03I3E00^?Td093<o01l]>00`@D/09S@o020/>00/=T807bTe03@lB@0W
;c`07B<_01lV<00C6R@06AdX02da>P0N8R/0JVmh02lf@00T;CH07RL`01lV;P0K8RX072<Y01lT:00N
8bL06QhQ01PL7@0L82406alO01HK7P0G72005Q/O01@I7@0C61`051TM01HK7`0J7b<0314E02X_<`0c
>3`05Q/O00X?5@0I7BH05a/T02@X<@0K7bP0RXjG01hR:`0G6b@08BD^02DY<P0M8BX07b</020T;@0N
8RX05AXP01HK7`0M8RH051TL010E600J7b<051TM01lT:P0H72D06AdV01DJ800I7R80724U01PM8@0B
5a/04AHJ01PM800F6ah06AhQ01LL7`0D6A`05a`P01LJ900H6RH05ALS01@G800N8BX05QTR01LJ8@0C
5Qd04QDL018E6P0D5a`05ATL01`P8P0>4Q<03A4B01/O8P0;3a8092P[01HI7P0B5AX010L<0P0I72<0
4`0@4aX061`P020T9`0G6ah03A4D00l@500K72003PlD01/L8@0I6Al04Q4G01PG7@0;2Q005QDK00X9
3`0D4aT05A@J01hM8`0B4AL00P0I61h02`0<2a4071/Q010?5@0G5Q`051<I018A5`0Y:2h03`hD010?
5@0D4aT05A@J00803`hD01d06QTO01LF700>31D06AHQ01PE800F4ad05a@M018?5P0C41H07A/P01LE
600B414061HG00`;2P0<2Pd05A<H010>4`0N72408R0U00h<4@0G5AX02PP=01DC600W9BX0;2X_00h<
4@0<2Pd03@/>00l=4003010>4@0300`:3@0=2`h03`d@00<040hA00h02@L:00h<3`0G5AP01@<601`J
7@0>30l030X=00l=400A3a8040hA01@B5@0K6A`04@`@01<>4P8050lC02h05A0D01@?4`0@2`l040/?
00l:3P0>2@d040/?01@?4`0I51P04@`@00T4200O6Qh02PD9010;3`0K5QX05a8F00X52@0J5AT07aXN
00d830071@P0410B01TD600<1PX06A4F01@;400A20d05@hB00h8300A31005A<F01HD5`0;1PX08ahR
014<400o>Sh02`H:01<>4P0@2`l03PT=01HA5@0>2@d050lC00/62P0C3A404@/?0`0@2Ph2014;3`80
4P`@02`040X>014;3`0B2a8040XF018:5@0C31@05@/D01D<4@0E30l04P/=01<=4@0B3A403@dB00l@
5@041@X02@H=01<@5`0A31<03@P?00X52`0H4QT07AHM00H01017?4@0;24Y06]PJ00E31@05@hF01<<
4`0A2Q40204800P21P0D3Q8030H:00d72@0D3Q003PP:00/51`0>20T04@/;018<300@2PX03PP800l9
2@804P`<00H03`T900d71`0=1`L03PP8014;2`0=1`L2010:2P04018<300H4Q802@<301<=3@<03`T9
01L03@L701<=3@0E3`l04@/;00h8200A2`/040X:00X4100A2`/04P`<00X4100<1PH04P`<010:2P0?
2@T03@L700`61P0=1`L040X:018<300?2@T03@L700h82002010:2P0D018>3`0K5aP02@D600P41@0A
3@h04Ph?00D10P0:1PL04@d>00`82@0A3@h020@501/E5`0@2P`03`T;018<3P0@2P`03@L900/51`0D
3Q0203Tc=@1501@>400;1@L04@/=00d72@0A2`d0100002dW:@0A2`d03`T;00h82P0@2P`03@L900T3
1@0=1`T03PP:018<3P0C3@l03PP:00X41P0C3@l081XL01@>400=1`T040X<00l92`0<1PP03`T;00L1
0`0>20X04P`>014;3@0H4Q@04P`>01TC5@080P@03@L9020J700;1@L02`H9018<400:10P03`T=00T3
1`0?2@d04@/?00H0100:10P02`D900d72`0D3Q803`T=00h8300?2@d04@/?00l93@0=1`/04@/?00`6
2P080PH06A<G01lI7@0@2Pd03`T;00@0000b;2h01000014;3@0?2@/03@L900803`T;0P0>20X02P0A
2`d01P0200P2100A2`d030H8010:300A2`d03`T;00h82P0=1`T200/51`0=00X32@0;10`03PL>0109
400?20l03`T=00h8300=1`/03`T;00d72@0:10H030H800h82P0200l92`0900d72@0>20X04P`>00/5
1`0:10H03@L901@>400C3@l03PP:00802P@40P0?2@/0400;1@L03@H=00h73`090PX06Q8M00@02@0@
21D04PXG00X23@0>1Q4050`G00X32`0600L0:B8Z01dF7@0H4AP2014;3`0:018<400A2`l02P@801/E
6@0<1PX04P`@024K7`0400803@L;00h830803`T=00P03PP<00d72`0>20`04P`@00T31`0<1PX05@lC
00d72`8030H:0P0=1`/200h831Cooooo000Kooooo`0I00h:2`0n>S/03`/<018>3`0>2P/04@d>00h:
2`0<20T03`/<01<?400?2``01P8300h93@0>2Pd03`/>00X52@0D3a<020<7010;3`0=20`061<G01@?
4`0C3Q804PhA014<4P0200d83P0I010;4@0?2Q003@P>010;4@0<1`d04PdC014<4P0I51X03`X@0109
4@0?20l03PL>00h83@0>20`03`T=014;3`0?2@`04@/>01<=400A2`h03`T=0109400B2a<04``C018;
4`0201094@06014:4@070PP07aPP00l84019@TX05a0F0P0D3Q803`0@2Ph04`dA018<400A2`l03PP<
014;3`0C3A405a4E00/62@0J5AP061@E01DA4P0@30d05A4B01HB4`0201DA4P1101@@4@0B3Pl04`l@
01@@4@0D4A<05Q@H00l=4P0?31805A8H010=5@0C41P040dD00h;4P0@3Q@040hC01@B5P0G5AD061@A
01TE4`0C3Pl04@`=01D?4`0D3aD04A0E01HH7@0?5AX08BX^04YCF00H6b805QHM01LG7P0G61h03`lF
01@D6`0U9B`0NWZ101HF7@0L7B<06Q/Q014B600F5Qd06ATP01HG7@0D5AX061TN01LH7@0H6Ad0824U
01lP8`0E5QT06a`O01@E6@0H6b<05aXR01LI8`0F6B405aXP01PK800L82<07b<U01LK7@0D61T06AdM
01XN800H7B400P0I7R@0300J7bD06b0V01/P9P0H7B<07R<Y028W;@0F6b407R<Y028W;@0J8BP07B@[
020W;P8082T_00l07bP^01hY;P0M:Bh06bT]01`Y;P0M:Rl07BX`01XU;00P;3@08Bhg01l/=00N:cD0
82hh028`>`0Q<Sd00P0R<Sh0L00P<3h07bll02@d@00R<ch0:3Q40352C@0_?d/0:CY502/kA`0S=3l0
9CE102hoBP10DE`0?TmI02XmA00]@4L0:Ca302Pk@P0W>T0093Lm024d>00]@4@083<g0314A@0T>3T0
<dM802Ph?`0Z>T40;3a302Xj@@0U=C`08c<j02Ph?`0Y>D00;3a302De?00S<cX09SDk04iMH@1UMgX0
AeYN02i3A`0]ADT0:T970358CP0/@4T0?e5L0;g=e`2AWZd0;Si802Dh?P15F5l0;d5<03E7E@0aA5<0
>DeN03aAHP0cBEP0=diK03YBGP0lE5h0:Ca702lnBP0b@Dd0;ci:02Lf@P0U=4008c8n024`?00P;c/0
7Rdi01l^>P0V=D80;3Q:02TeBP0_>dl0?d]N024^?P0S<400;3Q7024^>P0T<C/082df028`>00K:340
6R@`05YSL00lAE804QXW01hV<`0H7RX08BLa020U<00N8Rd09RTb08F9TP2RYZl0:S4k024Z<`0J8b`0
6R4Y01PO9`0I82H07B8V01lT:00K7b804aLH01@H6@0F6QX061dP01TN8P0H7B4501LL800901hS9`0T
:Bd04QLK01/P900J7RL06alX01<G800S9c005a/T00808bL`03405a/T01XN9`0K7bP05a/T01dQ:P0S
9c007B8Y06ebN00K82@06AhQ01dR9@0L8BD06b0U01hS:@0K7bP04aLS01@H8`0C61l0724W01HK800E
6R006b0U01XO8`0I7R405a`P01/P8`0H7B005AXM01PM8@0H6bD07R0/01/M:@0D5b007B0Y01LJ8`0I
72<05QTP01DH7`0E61d05aXO01PK800J7R4061`N00lC5@0@51P06QhR04A7B`0R9B/05QTO00<05QTQ
03T071lV014D600B5AP041<F01LJ7P0A4QL05ADK01DF700B4QT051@L01HE700@41T06APN00D42P0M
72804a8H014@5P0I61h05QDK00d<4P0E51X04a8H01LF700?3Q@05aHL01TH7P0E51X04Q4G00d<4P0M
72804A0F01@C6@0A41H061LM028Q9`0L6b404a4H028O9`0P7BL061DM01@A600?31<04a4F010>4`0B
41<02@L:01HD5P0A3a4040hB01<A5P0@3Q<03P`A00d;400C4AH03P`A01HD6@0A3a@00P0E4aP01`0>
31404a4D01<A500B41<04@lB010>4@0?3A000P0@3Q404@0A3a8040hA00l=400>30l02`X<01`K7@0;
2Pd04Q4D01DD5P0=30h04Q4D00l>400<2`d03Pd@010?4P0?3A003PX<008040/>02l040`>00l;3@0?
2Pd04`lA01@?4P0A30l03PT<00h:300@30h03PT=01@?4`0I51P02PD902@O8`0=20`01P8501<>4P0B
3A403@T<024L800C4A@051<G02TW:`0?3A405Q4F014;400E3A<03PH<010:3`0L5a`05A<G081oPP2<
S8h06aPJ00T51`060P@05A0C00T41`0M61/030P:01<?4@0B3Q003PX<010<3P0?2`d04`dA014;3`03
010:3P0`014;3`0C3A4050hB01@>4P0B31004`dA01@=500?2A@04@TD018;4`0E2a8050/>01@;3@0B
30h04PlC00X83P0<3QH02PhH03i2C00U9Rh030/B010?5P0A3aD02@L=018=500F41H03PH<01093@0I
3aH09adT018:4P080PT02`@;014:4@0=20d04`dA01@>4P0A2`l04@/=01H@4P0A2`d03PP:00l92P0A
2`/04P`<010:2P0>20P03`T90P0B30`0200?2@T03PP800d71`0>20P040X:00`61P0A2`/040X:0P0>
20P04P0E3`l03PP800h92@0;1@D04@/;00l92@0D3Ph03`T9010:2P0E3`l04P`<00h8200A2`/040X:
00d71`0A2`/05Q0@018<30804@/;00D040X:00l92@0@2PX04@/;010:2P0200l92@0@010:2P0A2`/0
3`T901<?400710@04`l@00/7200B3Pl0:BDV055=CP0T82402`L801<?400=2@X0510A01PB50804@/=
00D04P`>010:300A2`d050h@00d72@0201<=3`0H00d72@0D3Q002@@501XD5P0H4Q@030H801XD5P09
10D04@/=00l92`0A2`d03`T;00h82P0D3Q004`d?00`6200@2P`050h@018<3P0>20X04`d?00h82P0:
10H03@L90P0?2@/0500B30h040X<014;3@1:A4H0V9:D03D_<@0A2`d04@`=018<3P0=1`T06Q@F010;
301RG6006aDI018<400>20`02P@8014;3`0>20`04`dA0P0=1`/00`0A2`l03PT<00h8300200d72`0=
00l93@0>20`030H:010:3P0>20`02P@801@>4P0J51P04P`?00L10`0T7R00SXR:02dW:@0200`62003
00d72@0?2@/03`T;00803PP:00X03@L9010:300C3@l02`D701/E5`0P6Q`040X<014;3@0@2P`03`T;
0P0>20X0300<1P/03@H>00l83`0?20l03PL>00h8300?2@d03@L;00d72@0A2`d04`d?00l92`8030H8
00@03`T;010:300?2@/03PP:0P0@2P`06@0>20X020<4010:300?2@/06aDE018<300<1PP03`T;00h8
2P0>1`h040/A01<=500=1a0030DA01D=6P0=1A805@dH01L?6P0E3AP02`@<00T32P0@2A404@XA0109
400>20`0100=1`/01`0f<3@0;bT]00l93@1<ATX050hB00d72`0>20`00P0?2@d02@0>20`03@L;00l9
3@0Y8bL07ALK00H1100910L0618F00h8300300l93@8040X>5?ooool001_ooooo02D081`M00H20`0K
5aP0JVIW03Da<P0C3a002`L801<?400=2@X020@500h:2`0H51D02`H:018=4@0k=SX07QTM00P41`0;
1PX04PdA010;3`0X8bL0F5=G05iIG@0E41@03`X@00`73@0>2@l04PdC014<4P0?2Q0050lE00l:400C
3Q@040/A01<>500G4QP03`P@00803PL>00@03`P?010:3P0@2Ph03`T=0P0?2@/06`0@2P`03`T;00h8
2P0?2@d03@H=00l93@0C31804P/B010:3P0A2a00204801H@50090`P0=2dd018<400C3A404P`@014;
3`0D3Q8040X>00P21P0<1PX05@lC010:3P0;1@T01`4500d82`0201DA4P80510A03L05A4B01LC500F
4Q<0510A01<?400B3Pl04`l@00h;3@0C4A@08AlT05AAE`0a;SD01@8;00d:4`0;21404PlF01@B600;
2@`03`d@01DD500C4a405QDC01DA4P0D4140618F01/F700<2Pl04a<I01<F6`0D6Ad041LK01/N9@0G
5al030`D00L73`0H62005ADM01HF7P0a<CT05ADM01PH800A4AT06a/S01@D700I6B40410H014B5`0N
7b@061TN018C5`0H6Ad06AXL01<D5P0K71h05AHH00805aXO00/05QTN01DH7@0G6Ql05aXO01HJ7@0O
8bH04QHI01`P8`0I7Al07R8U01TN8P0301TN908061dS00H04QLM020U:`0M8RP09b`b01dR:00I7R@2
01`S:@0A01dT:P0M9R/07bP]020Y;P0T;c<06bL[01LU:00J:2/07R`_02<a=00J9BT07RX_01h[<@0M
:S006bT`01`[<P0R<3P00P0R<c/01P0R<c`07c0j01h_>@0S<d00830m02@d@@80:SY700/09SI301d]
>P0W=d@0:CU602PhA@0eAE80?DiH02XmA@0[?TD0:3]202<f?@02024d>P0=02<f>P0Q=3P09CPl02i2
@`0U>CX0:Cdn03=2B@0/>d80:CPo02Pg?P0/>d80;ci502Lf?@02020_=P11028a>00S<ST08c8f02Lf
>@0S=CL093Pj03M<C`0dC500;TI;02i5B`0^@T/0=DMB03i>F`0e@U80;Si901ha>00X>T@0838n02`n
C00^@E80?e=T03E:F`0fBe`0EF]j02e5D@0T?4P0:3a6034oBP0fA4l0=49=02`jA@0Z>4<09C<n020^
>@0N;3L072Xe01d[=P0P;SX08blo02Da@@0[=dL0=41@01dY=`0R;S/0;CU504UEH@18EEh06RL_02<`
>00R;SH08BTf01`T<@0B6RL07bLd01LO;00D6RH01PXE02@X<`0X;3L0:Rdf01XM9P0[;SL08bXd01dV
;`0G82T00P0E72@0200G7R@06b0T020U:@0M8B@04QHG01<G600H71`05Q/N0P0E6Qh01P0F6al05a`P
01DJ7P0K82@07B8V01PM8@80724U00P04aPN01HJ8`0M8BX06AdV01HJ8`0P92d061`U01dQ:P805QXS
01`05a/T01PL9@0O8b`051PQ01TM9@0_=3X01``@01@I700L8B@07b@X01DJ7`0P92d04aLR01<G900K
7Rd06AdX01/O:P0J7RL05ATS01HJ8`0K82H06AhS01PM8@0K82@06AhQ01HK7P0H7B405QTS0P0P8Rh0
1`0B5Ah05aXS01DH8@0I72<05aXQ01HI800F6Ah00P0G6Ql0A00H6al02PdB014D6@0Q92T02PdB00H9
400B5Ad03Q4J01<F7`0F6B8051HR01LJ8`0M7R<0@dA801@E6@0A4QL06AXO018B6P0J6R@0410J01<C
7P0D52003`lK01<C700R8BL06APN01@C6@0F5A/0LG1f020O9@0`;cD0BdY@01HE6`0D4aT06aXP01DD
6P0>3A<04Q4G01XI7`081`d06QTO00h=4`0D4aT06APN01@C6@0=318040lE01<A5`0I5a`05Q<J01<@
5`0E4QT04@lD01DC600=2a0081hS00X83@0E4aH05A<H01LE6P0<2Pl05A<H01`J7`0E4aP03@/@0040
100K6Ah01`D:0P0:20d01`0H5Q/03@/>00d;3P0>30l03`d@010>4@0A3a800P0@3Q403@0A3a8040hA
00l=400>30l05ADG01LG6@0;2`d020P:00D51`0>3Q0010@600`<3P0C4aD00P0>3Q00200E5AL05A4B
01DA4P0E4A80510A01<?400A3@h03`/<0P0A3@h0500@30d04@d>01<?400J5AT03@P<00l:3P0;1PX0
>C@h01PC5`0G4QH04`hB00l:3P0;1PX040/?010>4@0A41D0Bd]@00l=4P0=20h04P`B0P0D3A@02@0C
3A<06QDK00`:3`22PXL0UiNI01LD5P0B3Pl06QHG014=3P0200d92P0801LC50060P<0510A00h:2`0X
92D04`l@01<=4@0A2`l3010:3P0W014;3`0B31004`dA01<=4@0A2`l04P`@01<<4`0>218040TA014:
4@0C2Ph04PT:01482@0;1PP00@0500P8400I6bT0?dEE0=oUm@22QXl000D;00P;4@0000D01@H;01/I
7`0B3A<05Q4E01H@500b:Bh050/@01@<4P0?21007AHM00h83P0E3QD0:R@X01D?4`0>20`03PP:0080
4@/=00L03`T;00l92P0A2`/04P`<010:2P0>20P03`T900804@/;00H03`T900h8200>20P03PP8010:
2P0;1@D200l92@0?00h8200@2PX03@L700d71`0D3Ph01`4101H@400>20P0<2XZ01/E5@0@2PX05@l?
010:2P0D3Ph03@L700805Q0@0P090`<4010:2P0300l92@0@2PX040X:00803PP801P03`T9018<300A
2`/03PP801HB4`0300009B4R00h:2`0G4a@03PX;00H20`0@30d02PH701XF5`0B3Pl0<2`]018<3P0?
2@/040X<00h82P0=1`T04`d?00X41P0C3@l201D?4@0B01<=3`0:10H0C4I804Y4AP0M5aT03`T;00/6
1`0=1`T030H800/51`0@2P`04@/=01@>400M5aT09AlQ014;3@0;1@L040X<0P0B30h03`0>20X03`T;
00l92`0?2@/04P`>01@>400@2P`05Q0B010:3025Oh40ooWk05eGF@0@2``05@lA00L10`0200h82P05
00`6201fL7@07ALK01TC5`0=1`/00P0@2Ph01`070PD040X>014;3`0@2Ph02`D900H0100?2@d00P0=
1`/200l93@0>00d72`0?2@d04@/?00`62P0>20`04P`@00d72P0?2@/01@0101@?400<1PP04P`>00P3
100=1`T200l92`803PP:00T02`D7014;3@0F41803@L902@N800[9BL050h@010:300?2@/00`0>20X0
2@0?20h040TA018;4P0@2A003@H=00h8300@2Ph03PP<00`6200200/51`0400X41P0<1PP03@L900h8
2P8040X<00X03PP:014;3@0>20X040X<00X41P0;1@L05@lA01hH600D3Ph03@L90P0?2@/06`0?20l0
3`P@00@01@0J4Qd0100900/3400E3QX02P8=01084`0>1Q403@H>01@=5@0?21002`@;00h73P0B3100
3PP<00`62P0?2@d0100201H@500<1PX05Q0D00H1100E3a<03@L;00h8300200l93@0900h8300=1`/0
40X>00T31`0500<03`T=01D?4`0600@03PP<00D03`T=5?ooool001_ooooo01<01P83010<3@0A3@h0
BTI702PT9@0400404`l@00d92P060P<030P901<?400:1PL05a8F00@00`0Q72004`hB00l:3P0B3A40
1P4500802PD900<08AdP044l@00B3A400`0@2a42014<4P08010;4@0>2@l03@P>00d83P0>2@l04@`B
01/F700A2Q8201094@0E014:4@0B2a804P/B010:3P0>20X03@L900d71`0?2@T04@/=00l92`0B3100
4@/=00h82`0>20`040X<014;3P0?2@d02P@600l9300500<04P`@008050hB0100618F01lI7@0M5a/0
5a4E010:3P0:10P050hB01TC5`0G4AD030L900h:2`0@30d03`/<00h:2`0@30d04`l@0`0B3Pl201<?
400b01@A4P0>30d00@0201XG7@091Pd00@0702<P:`0C41T030T@01LE6`0E4aH040hA00h?3`0@4Q40
4a<C01@B5@0E4aH06QDI02HQ9@0E4aH03`hC01<D600P92L04QDI01/K8`0D51h0=SI001DE7`0V9S00
4A4K01`L9P0000T07QhX01`L9P0=3AL06ATS01<C7@0G5b40410H01<C6`0R8RX071dR018C5`0G61`0
5QLI018D4`0L7Qd05AHG01LK700F6Qd201DI700E01HJ7@0G6ah051PK01`P900@4aP071lT01LJ7P0I
7240724U01/P900J7b<06AhR01LL800F6al092T]059GF`0K82@05Q/O01LL800S:2`072@W00806b<V
01006R@V01dW:@0N:2X0@Da>01h[;00D8R<07bd^01d[;00@7Ql062<U01TV:00K:B`07B/^028a=@0W
=S/09C@j0P0R<cX3024b>P0=02<d?`0N;S/07Rhk02<c@00U=D8093A102LgA00X>4D09cM402@d@@0O
;c`0834k02Hi@@0202Hi@00o028e?00R=C/093Lm024d>00L;c<0;T5502e1@P0cAdP07c<d02lnA@0X
=ch093<j02<b>@0W=Sd0:CPo02Xi@00K:S4072/b02He?00U=3/09cHj0310@00gBD/0>Te@0315B00]
ADT0<DQ=03=:DP0^@Td0=TQE041@G`0kB5T0:ca802`oAP0_@D/09cU502m1C`0W>T/0;41B02m4E`0f
Be`0CfEe02DmB@0R>TH0:3a602hlA`0b@4/0<3i902Tg@P0W=D009C<n020^>@0N;3L07B/f01h/=`0P
;ST06bLe028[>P0V;ch0;cQ701lY=@0T;ST051hX0080:cDo05@02A<L01PR:`0G8BX06B4^01lW=00J
8Rl05ad[01HL:P0L82`09RXe02da?00E5b<05aXS020S;00E6B807RD_01`U;P0H8BX05A`T01HM9@0H
7bD061dQ01hS9`0L82<04QHG01<G600I7Ad05Q/O018I7`0C6R005A`R01LN900D6b4072<Y01dT:P0E
728051/Q01dT:P0D6b406QhW01`P:@0N8R/03Q8K01HJ8`0M8BX06AdV01PL9@0K7bP06QhW01TM9P0K
7bP05a`R01hS:@011P`05AXN01/P900S:2/0724U01@I7P0N8R/04QHQ01/O;00X:cX0GF1_02T]>@0E
6B@051PS018F8@0K7bP06AdU01LL8P0J7b<061dQ01DJ7P0H7B<05aTT024S;`0S9C4051LP01LJ8`0F
6B805aXQ01HI800E61l301DH7@0E01LJ7`0B5A`041<J018E700C5Qd071lX00lA700G6BD051HR02DW
<`0N82d04aDQ02<S:P1=CU<071dR018B6P0K6b<04a<M00l?6`0A4al06A/X00802`dJ01D05A@N024P
9P0F5A/03PdC00L6301LFf404a8H02`[<@17AT`04a8H014@5P0G5Q`051<I00D42P0[:S00NGQn028Q
9`0=31805aHL01<B600B4AL00P0A41H05`0E51X06aXO020N8@0G5AX04a4F01LE6P0@3Q<04a4F01DC
600`;C@04a0G01DC600E4aT08b4V00l=4P0D4QL04Q0E014?500G5AX0>CLl04]9CP0T8RL05aDJ0080
3@/@0P0>30l01P0=2`h03P`?00l=400B41<03P`?00l=40@04@lB00d07QhP00h>400Y:B/02`/=00d=
3`0E5AL051@F018B500<30h020P:00h>400D51H04@d>00804Ph?00@04@d>010<3@0>2P/03`/<0P0B
3Pl2014=3P0O01<?400@2`l05A0D00/62P0=20`04PdA01HA5@0B3A403`X>024L800j=CT05Q4E00l=
400F5AX04A4E00d;400J5A/030H=01D>5@0?20l05Q0F018=4`030@H07QhS024Q8`0C41805A4B00l;
300;1`P05Q8C00d92P02014=3P0600h:2`0A3@h03`/<00<0000C3A404@/?0`0@2Ph02`0A2`l040X>
014;3`0A2`l03`T=010:3P0A2Q4040TA0109400A2`l04`X<00804@P902<04P`?01DB6@0V9S809bTj
00hC9`1[LX@0;C<m00@;4@093Q@06QdT038e>P0R8RL05A<H020N8@0V8B@03@L900H00P0;1PX04``D
01`E700@2A00J65X07egN`0U7b<03@L;00h82P0A2`d050h@01<=3`0A2``04@/;018<300@2PX03PP8
00l92@02010:2P803`T901X03PP800l92@0C3@d03`T9010:2P0<1PH02`D500l92@090`<05@l?01<=
3@0400005Q0@01<=3@0Z92@05@l?00/51@0@2PX02`D5010:2P0G4A404P`<00/51@0A2`/05Q0@00`6
1P803PP80P0?2@T400h8200F00l92@0B30`04@/;00h820050@809B4R06UUIP0E4A8020@500l;300M
6AX0<2`]00/720091@H00`0001HB4`0C3@l040X<014;3@0@2P`03PP:01@>40804@/=0P080P@2014;
3@0600@0000B3@h01`4301<=3`0A2`d05@lA0P0<1PP01P0?2@/040X<014;3@0H4Q@06Q@F00h82P80
2`D700<02P@600d72@0?2@/00P0A2`d06P0@2P`04@/=01<=3`0>2P/02PH701@@4@0]:BX0IV9S02hZ
:`0A3@h0?c/l018>3`0D41400`0000l;300F4A@01002018<400A2`l04`dA00H0100I4aL02P@8014;
3`0@2Ph02`D90P0A2`l200h830804@/?00`040X>00h8300A2`l03PP<00d72`0?2@d040X=00h82P0=
1`T05Q0B00X41P0@2P`200d72@803`T;0P0>20X0200A2`d03`T;014;3@0=1`T040X<01<=3`0<1PP0
3PP:100=1`T0400@2@l04``D01<<4`0A2Q403PL>00l93@0B310050hB01@>400>20X03@L901@>400H
4Q@04@/=00d72@0>20X2014;3@0800`6200;1@L03@P9018<3P0400005@lA018<300?2@T2010:3005
00`6200?20l03@H>01H?5`0400L00P0A2AH05@0K4b003@D@01@<5`0@21<02P<;01094@0?21002P<:
00h73P0C3A4040X>00h8300@2Ph06aDI00d72`0J51P01`45010:3P0400803@L;00h8300200l93@04
00h8300=1`/04@/?014;3`803PP<00@040X>00/52@0>20`03PP<100=1`/Dooooo`006oooool02P0>
2P/03@X:00d92P0G4a@01`<401XF5`0810D081`M01`H6@0@30d200h:2`0A00X52@0Q72005a8F00@0
0`0@2`l03`X>014<400=2@`050lC00h:3@0@2`l03@P<01@?5@0J5A/05a8H00d83P0<1`d00P0@2a40
200M61h04PdC014<4P0:1@/03`X@01@<5@0B2a<04@XB0`0A2Q402@0A2`l040X<00h82P0=1`L040/9
01<>300E3a007ALH01/E5P02018<3@0I01H@4@0@2P/05@l@00`61`0J51D01P4101TC5P0J51P06A<G
01<=4@0D3Q804P`@00l93@0O6Ad06aDI02PR9P0@2Ph04P`@01D@4`0B3Pl04`l@01@@4@0@30d05Q8C
01LC5002014=3P0W01<?400D4140510A01<@400I5aP05A<F014?500E4QT05A8M05EBG@1DDEX06aPQ
00h<4@0D4QD04Q0A00lA400=4Q40418B01<C5@0E4aH061<G01dH700D3a<04Q0D01HF6@0Q8RD051DI
014A6@0D51h0?Si800l?6@0F5R0051@N01PH8P0A4A/05ADO01lO:@0B4Q`04a<M00805QHP00`051@L
01TI8@0O7bL071dR01PI7@0K72005aPJ01<E500L7Qd04aDD01HJ6@0F6QP201DI6@0801HJ6`0F6Q`0
5QXM01TL800G6Ql06A`R01`O9@0E61h201`Q9@806b0T0P0J7b<01P0B5a/0?D9601PM8@0K82@082DY
01TN8P<06b<V01T06bDW01`V:00L9RP06B@V01dY:`0P;Rl06BLX020^;`0oCDh09c<d02<`<@0O;Bh0
7R`]01h/;P0M;2h09SDi02<e>00S=3X08S<i020b=`0O<3P08C8m020`?@0R<Sl09CE200809cM403X0
<T9?024a?P0T=440=4AA02XjA`0V=d408C@l024d>`0S=Sd08SDl02<f?00X>d40;3m302<f>P0X>cl0
9c/l02/o@00R=3H09cHm02Tg?`0Z>3l09S@l024_=P0N;3@08S0h024_=P0S<CT0;3Y102Xh@00T<cL0
830`028d=@0/@440;45402i6BP18H6H0DfYb03E9E00eAe@0<T9A03M4E@0_@4`0;d99024c?@0S=D40
:ce;02e0D@0bAUP0BEia04IKK00`AUH0:3m=0318E00U>D<0<3e7034oB@0]>dD09S@n0P0V<cd02@0Q
;cT07b`f020]=`0R<3X08Rli024[=P0U;cP09Bli02hh@`0202Pb?00C02li@`0I8bd07RPb02@^>00S
;CL072H_020X=@0H7b`06b8`01XP;P0E6bT06al[01XN:@0T:3<0EUQT020S;00B5Ah07AlY01LN:002
01XS;00J01HM9@0G7RH05QdS01LL800J7b<05QXM010D5@0C5aP05AXI01PM8@0C6R005A`R01XQ9`0L
8bT061lU01XQ9`0H7bD07bH/01DL8P0I82H07B@Z01`P:@0J7RL07b</01`P:@0K7bP201XN9`807b</
02806alX01LK900E6B805a`R01TN900J7bD08bP/01@I7@0L8B@04QLK01TN9@0E6B@04QHR01PK:`0O
8S<05aX[01PK:`0H72T041@P01lS;`0e>D@05a/U01HJ8`0I7R@05a`R01@I7P0F6b4061/U01dO:`0R
93005aXS01XM9P0I72D05APO0P0D5ah0>`0D5a`04aHK01<F6`0E61l05aXR01DH800?4Q/051HQ01DH
8P0H6RH071hZ01@F8`0S9C<06Q`Z00h@7@0B4AT06QXP01LG7@0E5Ah03@dH01LG8`0C4Ql04aDS02LY
=`0D5BH09RPh04E5D00;2Q007QdS01XI7`0@3aD051<I01<B600>3A<061LM01LF700J6Al03`hD01<B
600T8bT071/Q01dL8P0?3Q@040lE02LV;00U92X04Q4G01DD6P0I61h04a8H01<A5@0N71h05Q@F010>
4@0D4QH040hC014?500A3aD081dU00803``D01003``E01HC6@081P/05Q@I00`:3`0A3a@04a4F018@
5@0G5AX030X?014?500C4AH040hC01DC5P0D4QD04@lB0P0?3A000`0A3a803`d@00l=4004018@4`0>
018B50061PP0;bla010@4P0E5AL04A4C051@DP0h>3X05QHH00l?4@0@41801`L9010<3@0A3@h2018>
3`03014=3P0@30d04Ph?00805A4B02T04Ph?00l;300?2``04PdA01@?4`0B3A40<Rda01HA5@0B3A40
6A@H010;3`0C3Q80<B``018=4@0B41<030/@014A5P0=31803`dC01@>500A2Q805@hF01@>5@091P`0
30/A00X:3P0K6Ql03P/=01LC500@30d05A4B01HB4`0=2@X04`l@06YVI`0i=CH04@d>00<0000e<C80
4`dA014;3`03010:3P0V014;3`0@2Ph04@/?014;3`0?2@d040X>014;3`0B2a804P`@01<=3`0D2`/0
4@X800l:1`0@3@h030/C00/<600O8SH0Uiff0=7GhP1XLWX03QPL010H7@052a404AHJ01DG700A4AD0
2`/=020N800>2``050l@01D?500?21003PL>00l93`0@2Q005@lC018=400C3A42018<3P805a4C00L0
4P`=014;2`0B30`040X:00h8200?2@T040X:00803`T900d040X:00l92@0?2@T04P`<00d71`0@2PX0
4P`<01TC4`0R71`02@<3018<300:1@D07QPH00803`T900h04@/;00`61P0>20P050h>018<300?2@T0
2@@400l92@0B30`03`T901@>3P0I4a<03@L700h8208040X:00<03`T900h8200@2PX00P0?2@T05@0@
2PX04@/;00l92@0A3@h03PX;00l<30060P<06QHG00h:2`0810D05A4B00P41@0=2@X04@d>00d:2P0I
4aD04`d?018<3P0C3@l04@/=01<=3`02014;3@803`T;100A2`d0400>20X05Q0B014<3@0>20X040X<
00l92`0B30h040X<00/51`0>20X02`D700d72@0D3Q004`d?00d72@0>20X200d72@0A00h82P0A2`d0
3PP:00`6200?2``02@D600/7200?2``05a<D00h;2`0@30d0Cd]<02HR8`0C3a001@82018?3`0A2`l0
0`0>20`03P0M5a/03`T=02XT:00;1@T03PP<00l93@0@2Ph07ALK01<=4@0?2@d03PP<014;3`0B3100
4@/?100?2@d02@0>20`03PP;00`6200@2P`030H800/61`0=1`T030H800d72@0200l92`803PP:00P0
4P`>00P2100:10H04@/=00d72@0A2`d040X<00h82P<03@L901403PP:01093`0B2a<04P/B00l83`0>
1`h040X>00l93@0@2Ph04`d?00l92`0>20X05a4C01`F600C3@l03@L900l92`02018<3P0J00T31@0V
828030H801H@4P05004040X<00`61P0;1@D040X<018<3P0>20X03`P?03Tb>P0J51/03`LB01085@0M
5b80<b/h00h64@0?1a8040PC00h73`0?21004P/C00d63@0>1`h300l93@0900h8300@2`h04`dA00`6
2P0H4QH02`H9014;3`0=1`/03PP<00803`T=00D03PP<00d72`0?2@d03PP<00l93@02014;3`803`T=
0`0>20`200d72aCooooo000Kooooo`0X00D10P0C3a002@D600T51P0D41400`0000D10P0F4Q<03`/<
00P41@0<20T02`L8018=4@0K5QX05A0D01<>4P0B3A405A0D00l:3P0F4AD01@0400X62@0;1PX03`X>
010;4@0M61h06A@J00`73@0>2@l05Q4G010;4@0Q72802`H<00l:400>2@l04PdC01<<500A2Q8040TA
00l840803PL>01h03`T=01<=4@0C3@l03`T;00l92@0A2`/03@L701D<3`0D3Ph03`T:00`6200=1`L0
4P`=01@>400E3`l03`T:028L7P0:10L04P`@01@>4P0?2@d04P`@01LA5@0A2`l05Q0D00D00`0Z92P0
50hB00/52@0A30l200l;3006010<3@0<20T0510A01TE5P0C3a00510A0P0E4A807`0D41405a@D00`;
2@0?3@h05aDI010>4`0D4AP071TR014>5@0;20l05aDI00h<3`0:20T04A8C00lC500@4A<04A4C018@
4`0@3Q406A@H00h<3`0H5QT05QHH00d>400B4aH02`/C018B700C4ad05ADO01<C7@0@41X00P0D51h0
200C4ad061PR00T94`0F5R0051@L010@600C4aX05QHN0P0B4aP0800B4aL051DI018C5@0@4A<071hM
01@F5P0F6QT05AXF01DI600D61L05ATI01HJ6`0F6Qd05QTM02<V:`0O8RT0;c8j02@W<00I7BH06QhV
01`Q9`0M8BX07b@Z020U:`0Y;S@06AhT01XO9@0K82H07b@Z01hS:@0K8RP07B@Z0P0N9B/05P0M9R/0
72DZ02df>`0H8bD05R@U01`W:@0J:2T08S0a01d[:`0N;2`08Bl_02<a<@0R<C407bl_024`<`0S=CL0
9CLi028d>00L;S806BXa020a>P0U=T0202Pi@`1l02<d?P0P<3d09cM402hnB`0[>dP09SI301XZ=`0U
=D809cQ102<d?00S=Sd07S0g01/^=00Q=3X0EVU]04EHG00X>cl0<4A501/_<00hC4d0:3Lm02Hc>`0R
<CH08Bld020]<`0O;S<08c4g02Tf?P0P;SH08c4j02Xg@00W=S`09cHi02Dg>@0W>Sd0<dQ;0397C00[
?dH0@eMP03=7D00]?T/09SI303E2DP0W=dD0:Sa602XjA`1:FfP0<45A028cA@0Z?4l0?E1Q03Q;G00/
@Tl0:T1=0357DP0S=3l09c@m02Hc?00O;3D06BH_01XW<00P;CD082df01h[=00Q;SL0934j028_>00P
;CH08bdf01lY<P0X<S/09c4j024[=@0K9Bl0628/020Z=00M9c408bdf01hW<P0L93406R0^028X=P0L
8S007R@b02DY=@0P92l04ADP02X/>00G6R<051LP01hP:@0@5b405b0Y01XS;00E72H05QdU01<J8@0N
8bT07B8V01LK7`0C5aX05ATL01<G6@0F6b4041LO018I8@0H7bL06R4W01HM8`0D6b4072<X01LO8P0O
9bX0?dM:014I700B6B4082La01<J900D6bD061lY01XQ:@0F6RD0720Y01/O:08061`U01T06AhT01LL
8P0I7R807b@X01<H700F6ah05a`O01LL800`=3`07B4/01hR;@0I72X04QDT014E8@0D62@02@dI02@X
<`0a=D007b<^01HJ8`0D62405a/T01DJ800B5ad051PQ00804aDQ00/06Q`X01@G800F6B805APQ01@G
7`0E62405APO01@G7P0C5Qd04QDL018E7P0201LJ8`10018D800L7RX06A/W01/M:@0?4Ah04aDR010B
7`0?4Ah061PT01PG800L6b<06QTQ01PH8@0C4ad08R8]024Q;@040a4061PV01LI9P17AUH0Lg=m028Q
9`0920h05A@J00h=4`0F5A/03`hD01HE6`0H5ad03@`B01/J800<2a405QDK0450A@0X9b`06APM01DD
6@0@3a@081lT01dL8@0F5AX04a8G00h>400B4AH07ahO02d[;00X9RL0518E00/9300<2Pl05Q@I01@A
600=2Q404@hG01LD7@0K6200@T1501XH7@0>314061HK03Hd>@0W9BX03`dB00P62`804Q0E00@05A<H
00/:3P0?3A003P`?0P0=2`h00`0?3A004Q0C018@4`02018@4`0j014?4P0@3Q403`d@00h<3`0?3a40
3PdA00`:3`0C4aD04a8F00h<4@0@418040lB00P62`0920`04@lB00l;300@2`d04@d>01<=3`0C3Pl0
4Ph?00l92`0C3Q00510A01@>400C3Pl04Ph?00`72`0B3A4040/?01dH700C3a804@`@00P31`0G4QP0
4PdC01LB600E41H03`dB018A5`061P/01`@;01TF7@0A31<03`P?014:4P0A31804Q0E00d;400=3140
1PD:01@A4`0810D02`L8018>3`0=2@X05Q8C01@@4@803@T:00D02`L801lK700=2@X04`dA014;3`03
010:3P804@/?0P0B3100:`0@2Ph04@/?018<400C31<04`dA01<=3`0C3@d04@`9010:2P0?30l01@@<
02PX=00U9cP0aLON0>_`o`1WKgH010/A00X@5@0731002`hC00H8300=3Q804Q8D00/9300A3a0030L;
00d73@0D3A@040T@00h73@0D3Q8030H:00d72`0E3a<04`d?00h82P0C3@l04P`>00h82@0A2`/04P`<
010:2P0>20P00P0?2@T0200>20P03`T9010:2P0@2PX03`T9014;2`0=1`L040X:0P0?2@T01P0B30`0
4`d=014;2`0M5aL0HE]K024K6`803PP800d040X:00h8200<1PH040X:014;2`0B30`04@/;00l92@0G
4A407QPH01XD500>20P03`T900804P`<00H04@/;00l92@0B30`03`T900d71`0>20P2010:2P0500P4
1@0E4A804@d>018>3`0>2P/00P0?2``03@0=2@X04Ph?00T51P0>2P/05Q8C01PC5`0=20`030L;00l:
3P0>20`02`D7018<400<1PP00P0A20/0100>1@P050/>00`6200:10H201@>40805@lA00T02P@600d7
2@0D3Q004`d?00h82P0@2P`05@lA00/51`090`D00P0;1@L02`0@2P`030H800X41P0=1`T050h@014;
3@0;1@L02@H600/7200A3@h02`L800804@d>01H030P900L3100:1PL02`L801LC500<1PP04P`@00T0
1@0:10P04@X>01lF6`0>20`030@900h52P0>20`04@T>01483@0=1`/04P`@00d72`0<1PX03PP<0P0@
2Ph02`0?2@d03@L;00l93@0B31003`T=01@>4@0500402`D701<=3`0>20X02@<500803@L90P0?2@/2
00h82P08010:30090`D030H800d72@0>20X04`d?00h82P0?2@/200h82P0:00l92`0@2P`03`T>00l8
400?20l03@H=00`5300>20`03`T=00h830803`T;00l030H800/51`0@2P`040X<00d72@0A2`d04P`>
00d72@0B30h0D4Y<018=3P0F41803@L900h82P0D3Q000P0<1PP07@0C3@l04P`@00d63@0;10`04``D
00h74@0<11400`0901`D8@0E3AX03@D@00l74P0D3AD030D=00P12@0C31<040X>00h8300@2Ph04@/?
00h830090`L01`45010:3P0600@05@lC00X4200=1`/03PP<00803`T=00P03PP<00d72`0:10P03`T=
010:3P0<1PX020<600d72`8040X>0P0?2@d200h831Cooooo000Kooooo`0600`6200D3Q006Q@F01TC
5@0C3@l03PP:0P0=1`T200h82P803`T;00@03`X>01D@500F4AD04@`@0`0>2@d01@0B3A405Q4E00`7
2`0A31004`hB00L03`X>01d03@P<00`72`0>2@d040/?014<4P0I51X02@@:014<4P0C3Q@02PD;00`7
3@0@2a404@`B018=4@0@2`l030L;00/52@0C2Ph050T?00`31P0F3A404PT>01072P0@2Pd061<G01@@
4@0=20/03@P<00l:3P0300h93@0P00l:3P0@2`l03PT=00d8300G4QH03@P<01TD600R7B403`X>018=
4@0A31003`X>018=4@0E41@04`hB01LB5P0I51P04PdA010;3`0E41@0514A014@300B4@l04Q0@018@
4@0C4A804Q0C010>4@0A3a804Q0C014?4P0@3Q4201<A500A010@4P0C4A@05A<F01DD5`0<2Pd0:RX/
02<S9@0J6ad03a0B01@G6@0=3Q<03PhF01HF7P0E5Ad0410H01XJ8P0H62000P0A4AT0:00Q8BT092@/
01@D700E5Q/05QLL01LH700C51T04A8F018C5`0>3a<05AHJ01`M8@0F5a/04a@F01/L7`0K7b007b<R
01DI6P0J7Ql051PJ01`P8`0M8B@051PL02<V:`0G6Ql06A`R01hQ:P0K7b/05adZ01@J9P0D6RP05adY
01TO:`0H7RX07R@_01hU;`0J8B/06B0Y01/R;00P92l201dQ;00J020T;`0N9Bh061lW02/b>P0R:c00
72L[01`V:00J9BL06BLX01TW9`0M;BX08c<`014Q800V=SH08S8b028a=00S<SL09SDj02Th?`0T<cX0
82lf02@e?00/?DD06b`d02/lA00X>D4202Df@0808c=00440<41?01l_?P0U=D@08Blk01l]>00R<cd0
7Rdf01d^=@0X>D00=4I:0314A@0^@T<09CTj02<i=`0bATL07Blc02<b=`0P<S@072d_01`[;P0K;Bl0
834d02Pg?P0W=Sh07c0j02lmBP0T=Ch09CHm02Pi@00W>3l0<DA:03Q;DP0[?TD0;d990313BP0V=d40
:CY402hoB@0X>4H08C51038oD01;FF/0>4MJ02hmDP0dAEP0;Ci@02LhB00Y?4T09CU2028f?@0P<3T0
:3I101PV<@0C8BX06BP_01l^=@0O;S@07bhe02Dd>`0X=Sl07B/f028`>`0T<Sd09S<l01/X<@02024^
=`0h028/=@0K9Bh07RPa01hW;`0I8R/072D/01/T;@0?5b@08BPh01dT=00T:SP0:Blm028X=00C5b80
6alZ01TL9@0H6b@08RD^01hQ:@0C72D041XT01DO:@0K92d05QlX01<J8`0H72D02a0F00hA5`0F5a`0
3a0E01LI7`0V:SD03A@O020W<@0M92h07B@[028Y;`0F7R40620S018J700C71/03aPF01hV:00H8BX0
6B4/014I900J8Rd072@_01/T;@1DFVH0:2li01TP:P0K8R`051TS01DJ800H71l301PL7@1G01PL7`0I
7B00:blb04U<D@0N8BP01PT@01@G7`0D5ah07R4V00`@50082a003a8G01hQ9P0G6Ql061/R01LJ8@0N
8BP05APQ01LJ8`0J72P05QPT01TK9`0H6RH05QPT01LI9@0J72P061XU01<E8@0C5Ql05aXS01DH8@0B
5Ah0820Z07IfP00I6B<051@N010@6P0G5b405ADO01LG8`0Q8Bd06QXV018B7P0I6B<061LN01dL8P0G
5Q`05A@K00d<500F5Ad05aHN01PG7`0E51`04a<K01TG8P0O7RD051<I01<B600S8RP051<I00l>500H
5ad040lE014@5P0R8BL051<I01XI7`0C4AD06ALJ01LE600@3Q006ALH00P61`0V92@05aHD01TH5P0E
51804a8>00h=2`0L71`08R4V01HE6P0B4AH05aHK014?4P0C4A@040hA00<04`hB00T050lC01PF6`0?
3A80518G014?500D4QL04a4F00l=4P0@3Q<00P0A3a@2010>4`804a4D00@04Q0C00l=400>30l03@/>
0P0C4A@0100B41<04@lB018@4`0C4A@2018@5@0T010=4`0J5A`05A<H00`93`0;1Pd030X?014>500:
1@`04@hD00L2200B31004P/=010:300B2@`04P/=018<3P0E30l04`/>010:300B2@`04@X<014;3@0@
30d04`l@01@@4@0C3Q804@`A014<4P0J5A/030P>02XU;00D3QP07ALQ010:500A3QD04Q0F0`0B3A<0
200?2Ph06QDK00h93@0A31004`hB014?4P0P7R4040`=0P0<20T00`0>2P/040`=018>3`06018>3`08
00l;300C3a001P8301PD5@0A3@h03@T:018>3`0?2``200d92P0P00h:2`0?2Ph050lE00h93`0E41@0
30L;03Td>00:1@T040/@01<@5`0D4AP05Q<M04A2C@1_KGP0=SDk010?5@0?3Q<04Q4F00/93P071@X0
40hC018@5@0>2@l03PT=014<4P0>2@d02PD901hI7@0:1@P040`=00H20`0B3Pl200h:2`0@00l;300@
30d040`=00l:2`0?2@/040X<00h82P0;1@L03PP:010:300;1@L03PP:00/51`0<1PP03PP:00X51@80
4P`<0P0@2PX01`0>20P050h>01<=3@0J51@0GeUI01<=3@0@2PX00P0?2`X0400=2@P02`L600`81`0A
3@`03PX900L30P0@30/0510?051<B`0D40l03@T8010<2`0B3Pd01@4000d9200C3`h200d9200:00l;
2P0@30/04@d<018>3@0:1PL0100101<?40030000510A014=3P805a<D01T04Ph?00h:2`0<20T02`T<
01@B5`17AT/02@L<00h<4@0?2Q004`dA0109400B2@h04PL=01<63@0D20d050T=01072P0>20X05a4C
00D00@0_:B/08adO00d72@0A2`d040X<008030H801003`T;00`6200?2P/03@L900T31@0B3@h01000
00d72@0?2@/040X<00l92`0<1PP02`D7018<3P0C3@l04P`>0P0@2P`0100B30h03@L900d72@0>20X3
00l92`0B01483@0G31806A0E01X@5@0F2a404`X?01<93`0E2Q004`X?01473@0B1`d04PT>014;3`0=
1`/02`D901H@500K5AT05a4E0P0;1@T300`62P0400d72`0?2@d030H:00/52@804@/?00<02@@7028L
800400800P0?2@d01@0400804`dA00l93@0?2@d03PP<00803@L;00/03`T=00d72`0:10P03PP<018<
400?2@d03`P>018;4`0A2Q403PL>00d63@02010:3P0W00h8300=1`T03PP:010:300B30h04`d@010;
3`0=20`02PD900d8300>2@d04PdA00L21P0:1@T04PdA00H11@0=20`030H:00/21`0@1``04@/?00h8
300@2A004@`C018=500?2a802`D?00X7400@2QD02P@@01<=6@080P`06A@K00`73@0>2@h02`H:018=
4@0A31002PD;00803@P>00`04`dA00@00P0I4aL03PP<014;3`0>20`04@/?00d72`0?2@d03PP<00/5
2@0B310<00d72aCooooo000Kooooo`0300d72@0?2@/040X<00803PP:00<03`T;00d72@0>20X00P0>
20X200l92`0<00h93@0@2`l04@`@014<400>2@d030L;01@?4`0=20`02`H:00l;3P0?2Ph040/?1P0?
2Ph02P0>2@d03@P<00d8300>2@d03`X>010;3`0C3Q@050lE00/6300@2a4202XU:`0=00d83P0?2Q00
4@`B018=4`0@2a4040T@01883P0B1`d040D;01L>4`0C2Pl03`L;010:3P0200P31`05010;3`0C3Q80
4PdA014<400@2`l00P0A31001P0B3A4050lC00T4200A31005Q4E00h93@8050lC02T04PdA014<400B
3A404`hB010;3`0A310050lC01<>4P0F4AD07APL01/F6P0D4A404Q4=014@300@3``04A0>018A400C
4Q804Q0A014?4@0?3A004@lB018@4`0F4QH05Q4F018@5@0D4AL05Q@H01DE6@0K6R007ahR01/L800G
61`04Q<F01HI7@0N7RD05aLO01DE7@0I6B405QHN018B6P0201DE7@0=01LG7`0I6B4061PP01@E6`0E
5Q/05aPL01XK7`0F5a/051DI01<D600S92P07b0T01TJ7P0201PI7@0?01HG6`0K7b4051PJ01/O8@0;
3a40:Rda01HJ7P0G6Qh0;C0f01<F700M82H07B0X01`P:P0K7Rd06Al_008061h^02X06Al^01TO;@0K
8Bl06b4^01XP;00K8Bd07RD`020W<@0K7Rd07b<`020T<00O8bl07B<^01hU;`0M9B`07bL]01dV:`0O
:Rd08bh`01/Y:P0J:2P0830^06moO@0gAdH072`/02<b=00R<CD08C0e02<b=`0V=C`08c8i024`=`0[
?D807c0g02Df?@0Z>d80:3U102Xk@`0V=d406b/h01`/>@0]?D`202<c@P0?02Lc@@0T<Sh0:cU402/i
A00^?dP0>4UA028c>@0Y?440:C`o02i2A00X?Cl09CXl02<e>@0S=CL08C<e00807S0`05L0838b02Hh
>P0T=C`0:3U102@e?`0O;ch09cM302@e?@0V=cl08S<k02Hg?`0Z>d<08c@l0352BP0fAdl0;d180311
B@0_@4P0;Ca9020]?`0K:3X09395024_@`0U=4T0:cY>020`@00O<4009CM2028e?00N<CP08S8k02Hd
@@0Q;cX09S@m01/Z<@0E92T07Rdb02Dd>@0O;SD093<l02/iA00P;S/07R/f02Hc?@0Q;SL08c0i01l/
=@0S;CH09c4j01LQ:P0N9bh0<SY101`T:`0I8BT051`Y02H]?@0R:CT09bdk02`b@00^=4006AdX018F
8@0I72D061/T018E7P0/<3P0@daE030jA00K92d051dV01<L900H7bL0720X01<H7P0Q92X0<C4h028S
:@0C51`05QXV02X`?@0Y;c/0/[W3065XL00J8BL06B4T01@L7P0M9RD00P0G81d03P0F82004a`T018L
9`0S;CP072Ha04mHHP1SK7H0HFUc03@kA00G7RL06QlY01LM900@5AX05a/M0P0G6a/0400G6a`05a/M
01LK7P0O8bH0<SDi01dP9@0=41D05QTN01@H700A5AL05ATI01LK700A5AL05QXN01LK7`0M82H201PK
8P0401dP:@0G6B@05aXT01TK9`8061XV00@05aTU01DG8`0D5R805aTU0P0E5b<06P0D5R805ALS01DG
8`0B4Q`09BD_00d=5`0S8bd06ATS01HF800E5Al05aLQ01hN:00I6B<04a<M01TI8@0I61l04a8H01TH
7P0D4aT07ahT01@C6@0E51X04a8H018A5`0C4QP05A@J0P0D4aT0700E51X061LM01DD6P0@3aD04Q4G
010?5@0A41H05aHL01DD6P071P`07QdQ01DC500H5QL04@l@01dL6`0@3`d04A0=03dl>027QX80IVEQ
02PW8P0H5a804Q4A01<B600B4AH040lD01DD6@0F51L201@B5@0:01DA4P0D41404`l@01@?400<1`d0
5Q@I010>4`0H5Q/03@/@01<A5P804@lD0`0B41D00`0A3a@040hA014?4P02018@4`804a4D01@04Q0C
014?4P0A3a8040hA014?4P0B41<050lE00l:400@2a4050lE00`83@0E41H050lE01PC6@0M61l02`H=
010;4@0A31805@`A01D<3`8050/>0`0E30l201@;3P804`X=01l04@/=010:300@30h03`X=00h93@0B
3A805Q4G03@`=P0L5al0DD]E01LA700F4A`05@lI00l94`0A31<04`hD01@?5@0C3Q<04PdA01LB5P0>
2P`04Ph?01<?400B3Pl06aLH01HB4`0A3@h040`=00l;300<20T02`L800H040`=00H03@T:010<3@0C
3a003`/<00d92P0@30d601<?400N018=4@0S7R<061<H01dH7@1NFEh050lD00l:3`0@2a005Q4F010;
400C3Q<07aXO01PC600D3a@03`X?010;400N6Ah07APM00`7300?2Pl04`hC00h93P0?2Pl04Pd@00d9
2P0<2@T0:2@U01LC500C3a0030P90P0>2P/0100?2``040`=010<3@0@2``2014;3@0<00l92`0>20X0
40X<018<3P0=1`T04@/=00h82P0A2`d05@lA00l92P0A2`/03`T90P0>20P01`0?2@T030H601D?3`0I
51@06Q@D014;2`0?2@T00P0?2`X0400>2PT02`L600`81`0@30/0Ddm>01@@3`0<20L040`;01@@3`0@
30/03``;01PD4`0@30`04`l>01TE500F4Q43010<2`0<00h:2@0=2@P030P701PD5@1GDe@08alP05=?
D00T82405A4B01<?400D41404@d>0P0>2P/04@0=2`h03`lD02PX;`0N7B@02@L?010=4`0=2@l04``C
0189400@1@`040@;01@63@0D2@h04`X=00`6200D3Q002P@6008040X<00P03`T;018<3P0A2`d03`T;
00h82P0@2P`05@lA00`620804P`>00T03`T;014;3@0>20X03`T;010:300?2@/03@L900`6200>20X0
0`0@2P`00`0B30h050h@00d72@0200h82P<03`T;00T04`P>01D:400E2Q0050T?0146300@1@/04@H<
01873@0A1P`00P0?10X00`0?1P/03PL;00l93@0201<=4@803@L;00H03`T=00h8300>20`03PP<00`6
2P0=1`/2010:3P0:00d72`0@2Ph04P`@010:3P070@D03@L;01D?4`0B310040X>00l93@8040X>0P0?
2@d02@0>20`03`T=00h8300=1`/03`T=010:3P0>20`03@L=01094@0201<<4`0400l83`0=1`/03@L;
00d72`803PP:0P0?2@/0100>20/02`L:00`82`0<1`/200d8300@00h93@0?2Ph04`hB00h93@0B3A40
3@T<00l62`0A20d040L<00`62P0@2Ph03`P?00h9400=20l03P/B00l<5@802`PA00X030HD014;5`0@
2a@0510F00`73@0@2`l02`L800l;300>2@d030L=0P0@2a402`0?20l06A<G010:3P0B31003PT<010:
3P0I4aL03PP<00l93@0C3A4040X>00L03`T=1P0>20`Dooooo`006oooool2010:300400h82P0<1PP0
3`T;018<3PH03PP:00<040/?00h93@0@2`l00P0C3Q801`0>2@d030L;00h93@0R7B4040/?014<4009
10P01P0?2Ph300d8300900h93@0?2Ph03`X>01D@5P0I51X05Q4G010;4@0f<CL0<2/a00803PT?00l0
3`X@00h93`0<1`d030D<01lE6`0F2a4050T?0107300C2Pl040L<00h8300@2`l04`hB010;3`0;1PX0
100>2@d01P0?2Ph040/?00l:3P0E41@05Q4E00P31`803@P<00d02@D800h93@0?2Ph04@`@00l:3P0@
2`l04`hB00l:3P0<1`/050lC02<N8P0Q72005Q<C00804A0<01X04Q4>014@3P0@3Pl04@l@018@4@0@
3Q403`d@010>4@0B41<05Q<I01HA600B3aH0514H01HC6P0F5A/07ahT00h=4`0F5a`04Q<H01<D6@0G
6Ql071`T01DE7@0B4QX06ATQ01/K8`804a<K0P0F5Qh07@0B4QX0410H01DE700C51T05QLK01XK7`0G
61`05AHJ01<D600N7b<05aPL014B5P0F5a/061TM01@E6@0C5aX041@G01hQ9P0H6b00=STo02<V;@0N
8BP0CE1H02<V;`0Q92d05QPS02<W<P0K7Rd06R0`00806b4a01d06R0_01TO;@0M8c406Al/01XP;00N
930082Ha01`S;@0J7RX07b8`020T<00O8bl07b@_020W<@0K92/092dd01XS:00F8BD07RT]01PV9`0Z
>3T07Rh]03e=C@096AT05bLX01h]<00P;c@07bhc020_=003024`=`0403m@E`0Q<ST09SLn01TZ<P80
834i05<06b`f01/[>00Q<Ch0;3a;02LgAP0S<d809C4o02Hd@@0]>dP0<3i:02m0BP0eAU00;3e603A7
CP0dAdd0L8>802Dj?`0S>3/08C<g01h`=00K;Bl07Bl`028d=00U=cL09CLi02Hg?P0/?DH0:CY401/[
>00W>4<07Rlg020a>@0O<3P08S<k02Hg?`0Q<SX0;Sm703E6CP0`@DT0<D9:02dnAP0X>4<08Bll01`Y
>@0S<D8093=602DdA`0U=4P072/n01XZ>P0L;CX06R`f01h`>P0U=Cl09S@o02Pf@@0V=3`09C@k01h]
<P0V=CX093<h01PW;P0/>d<0<T1;02Pf@P0O;3D0:SM002Ld?@0S<3T07R/d02<]=P0O:C8041/Q02@]
=011B4h08RT_01DL8`0?5b@082Lg01TP<00D6RP04ALU01@J9P0201<G8P0Y02@W<00G6R<02@`E0413
B`0h@DP09S4g01DN9P0E7RD05AhS01@K8@0H7B<03a@H01PK800U9R/07QlS01LI7`0Q9C00=ce902L^
>010Ae40=3]204U@EP0a>C`0620R01lX9`0@6AP07RLT01DO800`>D0082Xd01@N9`084Q/0=T1805EN
I@0;4QX04aXQ014H7P0B5ad05a`Q01PM8@0G6ah00`0F6Q/05@0E6A/05ATL00dA500@51P04QDJ00hA
5P0F6Al05aXO01TM800A5AH03A4B01DI700B5AX05QTN01<F7@0I72<08B@[00d@6@0X:c@03a8K01XL
:00201DG8`0O01PJ9P0E5b<04Q@P01HH900H6RH05QPT018D800D5R805aXS01LG8@0E5Al0820Z00d=
5`0@41X07QhX01DE7`0F5R006a/U01LG8@0D51h061PP014@5P0H5ad0SHbB02h]<`0;2Q0071/Q01@C
6@0@3aD04A0F01@C6@02018A5`0O014@5P0>3A<03`hD018A5`0E51X061LM014@5P0G5Q`04a8H01hM
8`0Q82H0L6mc01lM7P0I5aP04a4B01PF5`0M71X0:bXW08n>RP3ooo/0a<>o03Dd;`0L6aH051<D01@C
6@0O7R<051<H00d<4@0F51L04@lB018@4`0301<?400901@?400K5Q`0DDmD01PF6`0=2a005A<H01TG
700A3a@04Q0E00804a4F0P0B41D200l=4005014?4P0B41<04a4D01DC5P0@3Q400P0?3A001@0>30l0
3`d@010>4@0300@09b8X00803@P>00X00`0401LB600C3Q@03@P>01D@5P0?2Q0050lE018=4@0D3Q80
5@`?0P0D2`h0100E30l05Pd@01@;3P0E30l201@;3P0C01<:3@0@2P`03`/<010<3P0@2`l03`X>014<
4@0D3aD04`hE01D@600Q6bD01@0900d74P0:10h040/B00h9400@2a404@`B010;4002018=4@0800l:
3@0C3a004Ph?00h:2`0B3Pl040`=00l;300@30d201DA4P03014=3P0@30d040`=00@040`=00X04@d>
00L3100F4Q<03@T:00l;300A3@h03@T:010<3@0A3@h04Ph?0P0@30d01@0F4AD01P4500d8300A3A00
100300803`X>01L02@@8010;3`0F4AD04`hB01@?4`0@2`l02PD900l:3P0B3A4061<G020K7`0>2@d0
1P45018=4@0>2@d02`H:00l:3@0=2@X01`<401/G600?2``05a<D00d92P0200h:2`0400l;300@30d0
40`=010;3@8040X<0P0?2@/0500@2P`04@/=00h82P0C3@l03@L900X41P0=1`T02@@400`61P0=1`L0
40X:00d71`0<1PH040X:00H0000K5AD030H600P20P0A2`/03PX90P0?2`X200`81`0500l;2P0V8R40
2`L6010<2`0;1`H00P0<20L04`0L61L0LFe/048n?@0@30/0=30_01/G5P0A3@`040`;00l;2P0<20L0
2`L600X61@0B3Pl07a/L02dY:P0e<C8030P901@A4@0>2P/00P0?2``05`0=2@X03`/<010>4@0;3140
71dU0492BP071Ph06ALO00T63@0A31<03`P?01063P0B21006PlE020E6`0B2@`05@lA010:300E3a40
2`D7014;3@0?2@/040X<00@03`T;00H01@0100@000070@<03@L900`6200C3@l300l92`0400h82P0=
1`T03@L900`620<03PP:00<040X<014;3@0>20X01@0>20X00`0D2Q004`P>01<83P0301873@0301@9
3`0E2Q0050T?00804`P>00/04`X?00/52@080PH01P04018<400I4aL050hB018<400@2Ph03`T=00h8
300200d72`0<00h8300<1PX030H:018<400A2`l04P`@01TC5`0H4QH05a4E01XD600400804P`@0P0@
2Ph300l93@803PP<00T03`T=00h8300=1`/03PP<00d6300>1`l04``C01@=500?20l00P0<1PX0;P0=
1`/03PP:00l92`0=1`T030H8014;3P0B3A404@`@010;3`0>2@d03`X>00P31`0@2`l07aXN06YUJ@1?
BTh030L;00P0100B2@h04@P=010:3P0P6Qh08Q/R00T42`0J5A`04a0G00P53P0C41T03``E024K:@0<
1Q805@lI02lZ<@0@2a405a8F00h:2`0<20T02`H:00l:400A31803PT?00`5300N61`03PT<018<400<
1PX201<=4@803@L;00<040X>014;3`0@2Ph0300?2@dDooooo`006oooool00`0;1@L03PP:00h82P02
00`620L03PP:00`040/?00d8300>2@d04PdA01<>4P0?2Ph03@P<01`G6`2WXZH0D4]?00T4200D3a<6
00l:3P0300d8300>2@d03PT=00<03`X>00H06QDL010;4P0O6R402@@;01LB6@0=20l400l:4@0>00h9
400?20l02`4601P=4`0N4aT02P8601@;400K4QL08adQ00d8300<1`/04@`@01@?4`0C3Q8300h93@08
00l:3P0@2`l06QDI00l:3P0500@06QDI01TD600=20`200l:3P08018=4@0C3Q8040/?01PC5`0P6al0
6QDI01@?4`0?2Ph201@?4`03010>3@0?3P`04A0>00805A@B00D03`d>010>400E4aH05A<F01HD6002
01DC600L01LC6@0G4A/04a0I01DB6`0G51d05QDM01XI8@0?3QH071`T01<C6`0F5Qh06ahU01@E6P0C
51T04Q<H01DF6`0H6Ah05AHK01@E6P0C51T04Q<H01<D6@0D5AX05QLL018C600D5AX05aPM01HG70@0
4a@I00T051DJ01DF6`0E5Q/051DJ018E6P0F6Ah05aXQ020S:P0J7BD00P0I72D01P0R9Bl061XV02<U
<@0J72P05ATU01/N;@<06b4a01/06b4`01TO;@0L8S006b4^01`R;P0O9C407R@_01LN:00M8Bd0720/
01hR;P0P9S808BLb01dT;P0F7bP09c4g02@_=@0M:2h07bX^01/Y:P0P;Rl08C4a02/j?@0N;C00:CPl
010O900O;S<00P0O;SD2020_=P0;024`=`0Y>T40834i02<d?00K;3@093Do01//=P0M;SP07bll020`
?@0M;CX00P0R<Sl0M`0Q;Cd0935102/hB00/>DP09CE202@e?`0P<C/08S@n02@g?P0iC580:Ce401@Y
;P0Z?4408S@h01la<`0Q<cD09SPj02Pj?00V>3X0:ca302Lh@@0L;CL06RXg01d^>@0I:S8072de01l`
>00P<CT093Dm020a>@0[?4@0;Sm702Xk@`0]?TH0:S]3020a>P0M;SP0830m02TiA`0[>d/09SE8024`
@`0M;3l07blo01l_?P0H:3D06RXg020_>P0d@Td0A59M02Hd?00V=C`07bhc02@c>00^?D804R4X020_
=`1XMWl0=49=01TV;`0P;CH06bPa01/U;P0F82T0628[01hW;P0C72<04aXQ01XQ9`0F7B<06B0W00TA
700J8Rl06b<`01`R<00I7bd06b4]02<W<P0F6RD051HR01TL9@0G6R<08RD^02L^=P0I8RL04AXP01PO
9@0G7b803aLJ01DJ7P0@5AP04AHI01@H6`0@51D05a/O02T]=P2Z/K/082La02H]=`0F7B@0OHB:030h
>`0F7R407RLV010I600M9R@04adL00hG700I8b/02QDK01XS:P0H8BL08b`a020W;@0O9RX04aPL00lD
600E6Qh06AhQ00805a/L00D05QXK01HJ7@0E6A`05ATL024T:@0201PK800a018E700E61l05QTN01@H
6`0E6A`051PK01/N8`0A51T06ahS04E8C`0L7bH06A`S01TL9@0M82T04QDN01LJ8`0C5Ql051LP01PK
900F6B8051LP01HI8P0H6b@05QTR018E7P0D5b005aXS01`L9@0821006QXR01HF7P0I6B404a<K01DE
7@0F5Qh061PP01DE7@0D51`061PP01DD6P0:2@l0EEAJ01DD6P0[:S00:BP^01@C6@0A41H04a8H01DD
6P0201<B60802`X@01X05aHL00`;4@0=31805A@J00d<4P0D4aT04Q4G01dL8P12@DL0eM?G05YHF`0X
9RL06aTJ01HD5@0K6QP0:2LU06ASH@3=c<P0W9^G02@S7`0E51005A@E01LF700U92T05A@I00P73080
518E00d05A<F01HB4`0D41404`l@018=3`0O6R00EE=H01/I7P0>31405A<H01PF6`0A3a@04Q0E0080
4a4F0P0B41D4010>4@804@lB0P0?3A0300h<3`0?00l=400U82H0P7^1038]<`0D3aD05a8H010<4@07
0PP061<I03Lb>00L5ad03@P>01@?4`0D3Q804`d?00804P`>01`04`d?01@>400B30h04`d?01@>400C
3@l04P`>010:300?2``050lB01D@500C3Q8040/@00l:400B3A<03PX?024L8`0300D07ALP01TC7@0G
4QT04@`C01<>500B3A<040/@01D@500@2`l03`X=0P0B3Pl200h:2`06010<3@0>2P/030P9018>3`0A
3@h02@D61P0@30d05`0A3@h020@500`82@0?2``04@d>00d92P0<20T03PX;00l;300@30d03`/<00h:
2`0=20`05A0D01XE6@0B3A40:bHZ00l:3P0C3Q8030L;00h93@0@2`l04@`@00804`hB00H02`H:014<
400?2Ph02`H:02dX;00Z9BT200X52@0900d8300>2@d04Pd@01<?400V8R<02PH700/7200>2P/04`l@
00803PX;00H03`/<010<3@0@30d040/=00l92`0=1`T200h82P803`T;02<03@L900l92`0;1@L050h@
028L7P0G4A8030H6010:2P0H4Q804@/;00h8200@2PX0100000l92@0C3@d01@0001@>3P0=2@P03PX9
00l;2P0=2@P030P700l;2P03000020@301HB4@030000510?00d9200<20L0?c/j02DQ800:1PD030P7
00P40`0300h:2@0300d9200<20L030P7008040`=00D030P9014=3P0400404@d>00`82@0300h:2`0D
010<3@0A3a8030lF02DX<@2PXj`0CdmI00/:4P0K624040dF00l:4@0>1`l040TA01T?5`0N5AX05Q0B
02<M7`0;1@L04P`>00`6200:10H400d72@0800h82P0=1`T030H801XD5P090`D040X<014;3@0=1`T2
00l92`0700h82P0=1`T03@L900d72@0>20X03`T;00h82P0200d72@0300l92`0>20X03PP:00@03PP:
00L03PD:00`3200<0`P03PD:00l62`0@1``04`X?00805@`A01P04`X?01@;400E31405@lC01H@500@
2Ph0;bT]03hh?00/9RX04P`@014;3`0@2Ph03`T=00d72`0@2Ph03`T=00/52@0?2@d0618F01<=4@07
0PD0100200d72`0B310201H@500300X5200?2@d03`T=00<03`T=0P0>20`02@0?2@d03PP<00d72`0>
20`03PP>00l8400B2a804@XA00h73P0300d72`0I00h82P0?2@/03@L900`620070`D02@@801XE6@0@
2`l00`0200/62P070PH04PdA044l@03el?@0[JR/01PC5`0>1@X05PdB010730090`L05@lC01@=500=
20l040/B018?5P0201LD7@0I00P63P0<1Q@00`09010;500G4QT03@P>05eHG00A3@h03@T:00/62P0?
2Q003PT?00/63@0:0`X040X>00h8300?2@d04`dA01LA5@0>20`040X>00`62P080PH02@<700`62P06
00d72`H03`T=5?ooool001_ooooo00H03PP:014;3@0B30h04@/=00l92`0@2P`200l92`<03PP:00<0
3@L900d8300=20`00P0=20`0200>2@d03`X>00`72`0L5a/0LFa`03D`=00B3A404`hB1P0?2Ph07@0=
20`03PT=00l:3P0@2`l03`X>00h93@0A31<01`<901`G7P0E41L04@`C00d83`0>2A003`XA010;4P0C
3QD05A0G01H?5P0n=3/03`@:01D:400D2a007QDJ01893P1HDUH06QDI00d8300A310040/?00804@`@
01l040/?014<400A31004PdA014=400f<CD0>C@h01<>4P0@2`l04@`@01<>4P0=20`030L;010;3`0<
1`/04PdA01TD600E41@050lC00l:3P0A31004`hB018?400?3P`040l=01LE500I5aL0518D010>400A
3a804Q0D00804Q0E01404@lD01DA6@0G4A`04a0J01DB700G51h05aDO01DD7@0L6R@06ATR00h>5`0E
5Ah04aHM01<D6@0G61d05AHK018C600201DF6`0;01HG700D5AX04a@I01DF6`0F5a`05AHK01@E6P0E
5Q/05QLL01@E6P0C51T00P0E5Q/04`0H6Ah06Q/P01HG700E5Q/05aPN010C6`0B5Ad05APR01/O:@0B
5R0071l[01@G8`0G6RL082<a020R<00F62L06ah^01/Q<@0J83000P0I7bl0100J82l06b4_01/Q;`0K
8Bh201XP;01Z01/Q;00K8R`07b@`01dR;P0N8bl082Hb020W<P0K92h072D^01`V;P0S;SD0930g01dY
<00J9b`06bX^01h]<@0G9RX08c8h024`=P0K:S007B`b024`=`0R<CP082lg020^=P0Q;cL07Rlg02Lh
@00Y>T80;d1902Hg@@0G:3809CI002@e@00R<ch072dh03=4C`0gAe@0931002LdA00]>TX0<3e=02Xj
B00W=dD0:SY703=5DP0T=T40:ce7028f@00_@d/0<dE=02Tk@P0U=c`09SPl02Pk?@0Y?3h08SDi02Tk
@@0W>440;Cm905]/N00V=d4062Xb01/]=@0O<CT072he01la>00M;cL09cU102Tk@`0U=cl0:Sa402Li
@@0O<CP09SPn02Tk@P0W>D<0:ca902dmC@0W=TT0:3M:0350D@0a?e008C0o01h/?00W=D40:3E103A1
BP0e@TX0FFM/02hl@@0Q<3@09C<g01DS:P0M:S<0>4E>02<`?00H8bd06RH_01LR:`0T;SL08R`e01PQ
:@0C72<05b0W01PO9@805adR04X05QdS00hG8@0J8Rh0620/01`R;`0F72T05A/W01DI9@0F6RD06A/W
01PJ9@0G6R@06QdW02P_=@0L9BT04a`O01@L7`0B6Qd04ALJ01LL7`0F6ad06AhO01HK6`0A5QH05AXK
01TP9`0b>D8092/d01`S:`0E72<04QTO01TQ900B6Qd07BDW01/S900J8b804Q/J018L7P0L9R/02A@G
028/;`0G82@07BHX01TO8P0B61X051XK01PL7P0E6Q/051TI01TM7P0I7Al061`N01LK7P0F6Qd05ATM
01/N8`0F6Al05aXP01<F7@0H6b<06A`S01HI7`0D5a`030lE01XM8`0F6Al0<3<i0;Zma00f>D0061/R
024T;@041a007b8[01DH8@D05QTR00@05aXS01DH8@0E624051LP0P0E62401P0J6R805ADM01TI8@0D
51`04Q8J00l?5`805QHN00X051@L01<C6`0E5Ad05aLO01HE6`0A41H0=C@j02DT:P0N7B<071/Q0P0D
4aT0;@0E51X051<I01@C6@0F5A/040lE01TH7P0X9bd05A@J00h=4`0A41H05aHL018A5`0G5Q`06aXP
040oA@32`<D0G5YM01hL7P0H5QP06aTJ01DC500I61H05A@B03Lf<`0^;BX05aHB018A3@0A41805A@J
01PG700B4AH040lD018@4`0F51L06ALJ01TE5P0E4A804Ph?014<3P0B3A<06aTN01<A5P0I5a`030X?
010>4`02014?50<04Q0E00@04@lD018@4`0B41<04@lB0P0@3Q400`0?3A0040hA010>4@0300l=400=
010>4@0?2`l0:B@Y01@?500G4QL02@@901D@5@0D3a@03@P=01HA5P0@2a004PdB01@?4`0201<=3`80
4P`>0P0C3@l06P0B30h050h@01D?4@0E3a404P`>010:300@2`h05A0C01LB5P0D3a<040/?00d83@0B
3A<03PT?01PC6P0L5ah03PT?00l:4@0A31<03PT@01LB600F4AL03@P=00l:3P0>2@d040/>0P0A3@h0
200@30d03PX;010<3@0?2``03@T:01/G600O6a`05Q8C1`0@30d00`0e<C802@D6018>3`0200d92PH0
40`=00d04@`?00l:3@0B3Q004@d?00/72@0D3a803PT<014=3`0B3A0040`>010;3P0@30h03@P;0080
4`hA00l02@D700`72P0L5aX05Q8D00/72@0E4A<06QDH01<>4@0>2@/06aLH034];P0B3`l03@T:00X6
1`0@30d00P0>2P/0200?2``040`=010<3@0A30d03`T;00`6200>20X040X<0P0?2@/02P0<1PP03PP:
00d72@0Q6ad0>C<e02PR8`0>20P04P`<01/E5@0C3@d3018<300C00d71`0?2@T05Q0@01`F5P0=2@P0
3PX9010<2`0>2PT03@T800l;2P0B3Pd040`;01<?3P0710<040`<010<2`0=2@P04Ph=00`81`02010<
2`H03PX901`03`/:010<3@0810D040`=00`82@0E4A8040d=00d92P0?2``040`=00l;300B3Pl04a4D
018E701AE5h0loOn0=kPj@1KG6D05QDN01<A6P0@3QD03@TA00`83`0>2A0040XA00/52@0K5AL02`D7
0P0A2`d200d72@802`D700/03PP:00l92`0<1PP05Q0B02PR900<1`P04P`>00h82P0;1PL040X<00l9
2`0200d72@803PP:00<03`T;010:300?2@/00P0>20X300l92`803PP:0P0=1`T30107300401483@0B
2@h04PT>010730804@P=00T040L<01483@0C2Pl03PT<010:3P0<1PX0618F01H@50070@D00P0@2Ph2
00l93@0>00h8300A2`l04`dA018<400D3Q806Q@H01H@500K5AT0FeEI01LA5@0;1PT04`dA00/62@0A
2`l200d72`803PP<0P0?2@d03@0>20`03@L;00l93@0@2Ph03PP<00h73@0@2A4040T@00l83`0<1@`0
3@L;00h8300=1`/00P0>20X200l92`0`02HP8`0M61`01P85014<400E41@03`X>00X52@0D3a<08A`P
07agN`1<Ad/05Q4E0107300C2Pl040L<00`62P0?2@d03`P?00`73P0:1@`04PlF00`94P0=2Q<0BdQA
01D?7@0E3a/05A0I06AOIP0D41D04`lB010<3@0<20T03@P<00h93`0:1@/030L=014:4@0<1PX03PP<
00@00P0E3a<01@0301TC5`0N61`05@lC00d72`0>20`03`T=300>20`Dooooo`006oooool01@0=1`T0
3PP:00d72@0;1@L030H800<03`T;0P0>20X200d72@0<00h93@0A310040/?00d8300>2@d04PdA010;
3`0<1`/03@P<010;3`0?2Ph02PD91P0?2Ph03@0<1`/03PT=00l:3P0@2`l03PT=00d83P0?2Q4030L>
00T42`0F4AP04@`C01@?5P0=20l00P0<1`h02`0=20l03PT@00l8400G3Q<03P<9020E6`0A20d07QDJ
01XA5P0=1`/030L;00805A0D00<061<G01TD600>2@d00P0>2@d06P0?2Ph040/?010;3`0W8RH07aXN
00l:3P0I51P040/?01XE6@0G4QH040/?01TD600E41@03`X>014<400B3A404`hB01@?4`0F4AD04PdA
010=3`0A40h03Pd;01<B4@0J61T06ALJ0P0G5AP05`0D4QL04Q0E01@B5`0G5AX06ADM01PB7P0C41/0
5A8M01LD7`0G5B009B<^03Hd?`0L72H051@N020P:P0C5Qh051DJ01LH7@0D5AX05AHK01/L8@0G61d0
5QLL008061TN00<05AHK018C600B4aP00P0G61d0600E5Q/04a@I01@E6P0I6Ql061TN01HG700D5AX0
5AHK01LH7@0J72806alX00hB7@0O8bh00`LB01`P:`0E6BD061/Z01HI:00D5bH08bHg01XM;P0C5RL0
6b4a01TO;`805Q`/00T06Al^01/Q;`0J82h06Al/01@J9P0B62@06B0[02@[=@0K8Bd00P0Q9c<0700M
8bl06b<^01hV<@1EGfP09Blh01TS;00O;3@072Tb01l/=00M:c@0@e9J02@c>P0L:S<082lf024`=`0L
:c808c8i02Dd>`0Q;cP07bdf020^=`0N;cL04b@/01PY<@0a@T`08C8l028c?@0]?TP202/lAP0:01`]
=`0S=3h05bPb01/W=P0K:3P07b`l02XgA`0/?4/0:SY902dmC080<49@0380;d5=03Y>F@0O<ch09CM2
01`^>00K;SD08C@i02Hi?@0V>S/09STm028e>`0S=Sd0?U1J09:T/00/?TP06B`c01d`=`0S=Sd083<j
02<f?@0O<ST09SU002XmA00X>d80;3m602Lj@@0M<3D0:3`m02`o@`0Q=3X08SA002PhA`0X=dT0:CQ;
02`iC00U<T<06BHg01h[>`0T<Cd04QlX02Db>`0R;cH0=T=9018P8`0O;C007R`_01XW;@0E8RT07R/d
01dZ=080628[01d072H_03M1BP0g@TP07bP_01XS:P0J8bP05QdS01`Q9@0A5QX05Q`Q01`S;@0O9c80
5alZ01/Q;@0E6bL04aTU01dQ;@0E6BD06Q`X01lQ;@0F62@051LQ01/P9P0C6ah04QXM01@L7P0B6Q`0
51TL01LM7@02018H60805Q`J01<05adL01TP9P0G7RH092/c00T@600E72<061lU01`T9`0I8B@05alQ
01dU9`0F7al06b<U01PR900I8bD0628T01LQ8`0L9BH05QhP00807B<S01l0728R00lC4P0G6aX0ATY9
01/O8P0J7R406AdP01PL7`0G6Qh05QTN014D6@0G6R005APO014D6`0C5Qh03a8K01DH7`0A51/09RT`
04iAF00L7bH051LN034d>`0E61l0AdYA01<F7`0M82T03a8K01LJ8`0I72D05aXS00804QDN00d051LP
01PK900C5Ql04aHO01LJ8`0E62404QDL00h>5P0H62006ATQ01XJ8P0@41P06QXR00805ADM00H04Q8J
014A6@0E5Ad05aLO01<B600F5A/2010?5@0@00d<4P0D4aT04Q4G01DD6P0D4aT04Q4G01@C6@0A41H0
3PdC01<B600D4aT05QDK01TH7P0@3aD07ahT00X93`804a8H01<03`hD02XY;P0C4A@061HI01TG6P0D
4QD03P`=018@4@0C4Q0081lM014@3@0K6QH05QDA01HE5`0H5ad02`X?014@5@0L6b0040hA00803@/>
00`040`=014=3P0B3Pl04`h@01LB600<2Pl04Q0E00l=4P0B41D04@lD00l=4P0@3Q<2014?508040hC
1P0B41<03P0A3a8040hA010>4@0?3A0040hA014?4P0G4QH00`0201<>4P0300806A@H01D@500@2`l0
2`H:0P0H4aL0100@2`l01003018<3P0A2`d2010:3009014;3@0B30h04P`>01@>400F41805@lA018<
3P0@2P`03PT=00804@`@0P0@2`l03`0A31002PD;01LB600:1@/02@@:01LB5`0?2Q003`XA01@?5@0W
8RP0:2<Y01LB5`0C3Q803@P<010<3P02010<3@08018>3`0@30d04`l@00d92P070`@04`l@01LC500<
20T600h:2`0801<?401`K6d061@E01DA4P0;1`P05Q8C018>3`0?2``200d92P0800h:2`0?2``03P/;
00h:2`0S7b002@H601<?400?2``200h:2`8030P90P0>2P/0100D41403PX;018>3`0A3@h3010<3@0;
00l;300<20T04`l@01DA4P0?2``04Ph?00<0000E4A8020@501@@4@0<20T00P0>2P/02@0?2``040`=
010<3@0B3@h040X<00d72@0@2P`04P`>014;3@0200h82P0501D?4@0>20X03@L901@>400@2P/00P09
0`<0600A2`/02`D5010:2P0?2@T01`4101PB4P0>20P05Q0@00d8200<20L03PX9010<2`0>2PT03@T8
00h:2@0;1`H02@D400h:2@0I5A@0510?014=3@0=2@P01`<2010<2`802PH500D05a<B010<2`0@30/0
40`;00l;2P0200h:2@05018>3`060P<040`=00L3100H51D00P0>2P/05@0@30d04@d>010<3@0C3a00
518E01TL8`1VJWD0m?So0>obn`19BU@05QHP014@600@3aL03PdE00h;4P0=2Q403@/@01D@500H4Q@0
7QPJ01XD5P0200d72@0>00l92`0<1PP030H8010:300A2`d03@L900L10`0C3@l01@0101H@4P0>20X0
81XL014;3@0?2@/200d72@0300h82P0?2@/030H800<03`T;00@04@/=01<=3`0?2@/03`T;0P0>20X2
00d72@<040L<01003`H;00d42@0<0`P03PD:01483@0@1``03`H;01483@0C2Pl02`D900L11@0@2Ph0
2@@700X4200K5AT03@L;100>20`03@0;1@T04@/?01H@500@2Ph03PP<014;3`0;1PT0FE=G00P21P0?
2Pd05@lC018<40080PH00P0;1@T0@@0<1PX03@L;00d72`0?2@d03@L;00X4200>20`04P`@00l93@0<
1@/03PL?014:4@0@2A003@H=00`62P0=1`/03PP<00d72@0>20X040X<018<3P0F4A@030L;00X52@0<
1`/020<700l:3P0:1@T03PT=01D@50080`L06A@H00d8300B2@h03`H;01483@0@2Ph030H:00`5300C
3QD06QDL00X73P0C41T0>SM004a9DP0W8Bl01@0;01LA6`0300D06QDK00d8300:1PL02@D600d8300=
20h020<900l:400;10/040X>00l93@0C3A40?SPl02<M8@0@2Ph04@/?00802P@800<03`T=00X4200?
2@d01@0?2@d600d72aCooooo000Kooooo`0>010:300?2@/03PP:00h82P0?2@/040X<01`F600E3a40
3@L900/51`0>20X04@/=014<400?2Ph200d8300400l:3P0A310040/?010;3`803`X>0P0>2@d06@0A
31005Q4E010;3`0>2@d04PdA00/62P0@2`l03@P<01dH700D3a<01`8601<>500@2a<02`D?01TC7@0J
51h02`D?014;5@1=Ae407QPR01PB700E3aT0100801D>5P0C2A000P0B1`d01P0B2@h05@`A01H=4P0B
31003`X>00L21P805Q4E00@0I5mS018=4@0;1PX04`hB0P0:1@T02@0A310030L;00l:3P0C3Q8040/?
018=4@0J5AT06A@H01D@5002010;3`0I018=4@0;1`X05a8F01<>4P0E41@02PD9018=4@0G4aH05Q@E
01@B4`0C4A<04Q0C010>4@0?3A4040hC014?500C4AL05A8I01LD6`0I51d0618N01<@6`0B3aX0514L
01HD7`0201@B7@0B01<C7@0D51h05ADO01DH800C51T030dA01TJ7P0K72007QlS01LH700H6Ad07b0T
01XK7`0?41@05AHJ01XK800D5AX05ADM0P0H62008`0E5Ad04Q8J00X:4P0G5al06a/S01DE7@0G5al0
4Q@K014E7P0D6bD06Al[01<I9@0C6BH06Al]01@J:00H7Rd06Al_01LM;@0F72`06Al_01lU=@0R:3P0
8BLg01hT=00K8C006b4_02@Z>00C6BH06b4]01@J9P0L8bh0=Se701dS;`0Q:3<07bLb00806R8]01D0
7bTc03]5C`0Q;CH0:3Dn01`Y<P0Q;CP0934j02Dc?P0N;3H08Blh00dK9P0P;SL09C<l02<a>P0O;CH0
7B/d01`Z<`0N;3D07bdf020a>`0Q<S`00P0R<cd01@0Q<S`0834k02XkA@0a@T`08c@n0080;3e50140
5bPb02Te@`0B82d07bdj02Db@P0^?Td0;Ce<02/kBP0a@e40;d5?03=5D`0jCE/0:ci<02i0C@0W>D<0
9SU002/nA00202e0A01N0395B@0]@4H08SDk01d_>@0Q<cl093I002@g?P0`@dX0>4]B02<f?@0K;SD0
7S4h01lb>@0R=C`09CPo02Pk@P0[?TD08cLl024f=`0T>C`07c<i02Dg@`0]?D`0:CU802LgA`0[>4T0
9c=4028^?P0T<4008bhk02D_>@0K9Bl07BL_02Ha=`0M:2`082/]01hY;@0M:2h06RD/01LQ:P0T;SP0
?dUB02La>P0H8R/05b0W01<L8`0a>3l072<Y01lV;00R9b`07B8V01/P900K8BH0=ci601lX<@0C72D0
8RTc014H8P0F72P041@P01<G8`0F62D06Q`Y01lQ;P0K7BT04aPN020U:@0K82@03a@G00P=400D6A`0
6R0P00hD500D7A`03aPE01<L6@0@6AL051`O01@K8@0U;3805ahT01<J800L8bT041PK01dU:00S:bh0
6B4S01XR900O9bT05R0R01DN800>5QP08BT[014H6P805adM01P0724P01/O7P0G6aX06AdL020T8`0F
6Qd06alR00X>4@0Q92T05QTN01XM8P0>4AP04aHN018E7P0>4AX03a8K01DH8@0<3aP05aXS02T/=@1?
DU/071lX00/>5`0K7RL201HI8P0801dP9`0@4aX03a8I010C6P0B5A`06QdT01HI800@4aX201HI8009
00/>5@0C5Qd0CU5H02X]=00B5A`0=3@k02DV:`0@4AH04a@I00805QLL00<05aPM01@E6P0D5AX00`0C
51T0500G5Q`020L=01`K8@0C4QP06aXP010?5@0F5A/051<I01<B600D4aT05QDK01LF700I61h040lE
01LF700>3A<01`H<01XI7`0F5A/051<I0P0B4AL04P0D4aT04Q0F010>4`0B41D04a4E01@B5@0F51L0
518C018@4@0F5A<06QTG01TH5P0G5Q@051<F014@5P0A41D040lD014@5@804Q0C00P0518E014=3P0>
2P/04`l@01<>3`0I51X05Q@I01<A5P804@lD00L04Q0E00h<4@0>31404Q0E014?500<2Pl03P`A00H0
3P`?00X01@<601DC5P0C4A@02@L:01<A500A3a805A0D00l:3P0G4QH071LK0P0A31004`0E41@050lC
01@?4`0B3A404@`@010;3`0@30d04`l@00d92P0?2``0510A00l;300E4A8040`=014=3P0=2@X0510A
010<3@0@2`l00`0A3102018=4@805A0D00@04PdA00l:3P0>2@`03`X>0P0;1P`01P0B3A<06QDK00`7
300B3A404@`@014=3`@04@d>00H04Ph?00l;300>2P/03`/<014=3P0B3Pl2010<3@803`/<0P0>2P/0
3@0C3a00<Bd^01`H6@0C3a003PX;00X61`0<20T0510A01<?400=2@X03PX;00/7200@30d0100?2``0
2`0>2P/03@T:00d92P0=2@X04`l@00<0000B3Pl040`=00/7200>2P/040`=00803PX;00D04Ph?014=
3P0?2``05A4B01<?400200l;30803@T:00X040`=01@@4@0C3a0040`=018>3`0C3a0040`=00h:2`0<
1`T020840P0?2@/0100>20X04`d?010:300<1PP2014;3@0400l92`0A2`d03PP9010:2P803PP800h0
40X:01<=3@0B30`04@/;00l92@0=1`L03PP8010:2P091@@05A4@00h:2@0A3@`05A4@018>3@804@d<
00@030T800P40`0810<05a<C0P0>2PT200d9208030P700l03PX9014=300=2@P02@D400d9200<20L0
4@d>018>3`050@805Q8C018>3`0C3a002PH701DA4P0810D00P0>2P/01P0M6ah061PP02DX<@1cMWl0
MgN102TY<P80410H00L02PXA018A5`0000D05QDK0040100>2@d04@/=00804`d?00<03`T;00`6200>
20X01P0>20X01P0@2P`04`d?01D?4@0A2`d02`D700l92`8040X<0`0A2`d06`0;1@L03`T;00d72@0m
=cT03@L9014;3@0C3@l040X<00l92`0@2P`04P`>01@>400A2`l0100201`F6P0@2Ph0100201PB5P0>
20`03@L;00h8300@2Ph03PP<00`62P0C3A404@/?010:3P0300l93@0<00h8300<1PX03`T=010:3P0=
1`/03PP<014;3`0G4AD0HeeQ00l93@070@D05@lC0P0@2Ph00`0?2@d03PP<00h8300200d72`0@00l9
3@0C3A404`dA014;3`0?2@d040X>014;3`0C3A404P`@00l93@0?2@l02`@<00@0100Y8RT0100401@>
4P803`T=02X04P`>00h82P0:10H03@L901@?4P0=20`02`L:010;3`0?2Ph03PT=00L21P0M61`040/?
00l:3P060@D030L;01483@0B2@h04`X?010:3P0?2@d03@H=01<>5@0300D03``C024N9`2>Ri@0gmcU
04Q2D00A2aL050lH00L22@080`T03`X>00L3100810D040/?020K8@0=20h03@P?00l83`0?2@d200h8
308040X>00h02`D900h8300@2Ph04@/?00h8300<1PX05@lC00h8300:10P02`D901D?4`0500<03`T=
00h830<030H:00<03@L;ooooooooool04_ooool001_ooooo00X040X<00l92`0>20X03PP:00l92`0@
2P`03@L900h82P0?2@/040X<0P0A2`d01P0?2Ph03PT=00`72`0<1`/03PT=00l:3P804PdA0P0A3102
010;3`0C01/G6P1]J6`0HEaP01D@50080`L04PdA00l:3P0F4AD08QdQ01/F6P0=20`03@P>00h84@0@
2Q@02P@>00l94`0D3QP05Q0J05]EG`0201D?6@0700l94`0J51h03`P@01P=500E2Q0050T?01893P02
01<:3`0<00l93@080`L06aHJ02@O8`2?RXh06QDI010;3`0>2@d04`hB014<400@2`l04`hB0P0B3A40
1@0C3Q803@P<00h93@0D3a<05A0D00805Q4E00h04`hB014<400F4AD04PdA00`72`0E41@0H5]O02DQ
900S828061HG01`J700K6A/05A<F018@50804@lD00X04@lE01<@5`0D4AP0514I01LC700H4Qd04a0J
018?6@0D4A/05QDN0P0C4A/02P0C4a`051@M01DE7P0E61l06a`P018C5P0D5AP0@T=606]/K`0e=ST2
01TJ7@0701DF6@0F5aX06Q/N01@E600H6Ah05aLO01DE7@0201@D700@01HF7P0P82P06ATQ01`L900G
5al04Q8J03Dg?P0M8B`05QdW010G8P0F72L06b8^01/Q;P0C6BL061h/01TO;P8061h^02D06R0`01lU
=@0W;Cd08BLg01DK:`0A5bH06R0^01dS<@0X;S/06Al[01hT<00S:C@07bH`01hV<00M9C0072@^01XS
;P0J92h06bD_028]>00G8bh07b/f01PU<P0N:cL06bPd028`?00N;3T07R`h01PV<P0M:cL07R`f02@b
?00Q;cT082hh020^=`0Q;cP08S0i00808c@o018093A002<c?`0Q<S`08C8l028c?@0U=Sl0;Sm802`m
A@0V=ch0:CY202@a>`0J:3@07B/g028`?00[>dT09SI402LgA@0_@Dl203E7E@1503A7E@0`@e40<4=A
02TkB00W>T@0:ci702m3B00`A4P09c/o02Hj@00hBe409c]201ha>`0Q=Cd08SHm02`oAP0dAdh093Ln
01hb>@0U>3l0:3a302Pk@P0R=Sd08CDl02Lj@@0W?4009C`m02Lm@@0U>T00:3]502XkB@0U=DD09cE5
02TeAP0T;cl07RTf01lZ=`0N:CD0628/02@^=`0X<SX07RT]01lZ;00L9bT07RT[02<^<P0U<3L082Xc
02D_>@0P:C8072D]028/=00R:c80624X01DL8P0C6Ah05adR01`Q9@0J7b8061dP01LL800B6B405AhV
01<L900F7BL06R4[01LN:@0S9c<061`X00<05QPV01@0<39001dQ:00Q9BX05QXO01@I7@0A5QX04QLJ
01HM7`0C6Q/05QlN01DN7@0G81h0624P020X:`0Q:2d072<X010G700M9BT06R4V024Y;080620S00`0
4QXL02<[;@11BD`07BHX01DM800B6Qd082HY014G6P0F6ad05AXK01PL7@0F6QX2018E500:01LJ6`0M
8B@05a/O02DY;@0>4AH07B0U01LJ800C5Qh05aXR01DH8@8041<M01405ALR01HH8`0I6bH03Q4K01lQ
;00>41/05QTS018E7P0H6b@03a8K01@G7P0F6B006ahU01@G7P0H6b804A@K01@G7P0201dP9`0>01<F
7@0I72<02`hE01dP9`0B5A`04aHM01DF6`0F5a`04Q<H01LH7@0K72404A8G018C600C51T2014B5`0<
01@E6P0G61d04a8H01TH7P0=318071/Q00/:400J6Al05QDK01@C6@0B4AL04a8H0P0D4aT0200C4QP0
51<I01DD6P0D4aT04a8H01DD6P0F5A/051<I0P0B4AL02P0D4aT05A@I01HD6@0G5AX05A<H01<A5@0D
4QD0518D01<A4P0D4Q<201HD500601@C4@0C4QD04A0F014@5@0@3a@04A0E0P0B41<01P0D4QD05Q8C
01@@4@0G4a@05A0A01@?5@804Q0E00T04a4F01@B5`0G5AX08R0U01LE6P0=2a003`dB010>4`0C4AH0
1P0@3Q40500H5QT03@/>01HD5`0U8bH06aTL010>4@0B3A003PX<01LB5@0L5aX05A0C01HA500B3Q00
4Pd@014=3`0@2`h03`/=00h:300=2P/04@h?0P0>2``0300C41403``=01@A4P0E4Q<02PL800h;300B
3a004@h?014<400B3A804`hC01@?4`805A0D00h040/>01<>4@0B3Ph040`<00h:2P0>2P`05A0F02XU
:`0C3Q@03PT?018=4P0B3A4040/?010<3P@040`=00@04@d>010<3@0?2``040`=0P0A3@h3010<3@@0
3`/<00/0510A01<?400>2P/03`/<00l<300>2P/04@d>00L4100C3a002PH7014=3P0300l;2`<040`<
00H04@d=00H20P0B3Ph030P8010<300@3@d200h:2P0>00l;2`0>2PX03PX:00l;2`0@30`04@d=01DA
4@0J5QH0510@00d92@0?2``04@d>01<?400B3Pl3014=3P0=00h:2`0=2@X03@T:00l;300A30h03@L9
014;3@0>20X030H8018<3P0A2`d030H8010:3002018<3P0:01@>400=1`P030H600d71`0@2PX05@l?
01XD500A2`/040X:00l92@803PP800d03`T9014=300@30/03@T801@@3`0>2PT04Ph=00@1000K5aH0
4`l>00d9200Y9B@0;b/Z00<040`;0P0?2`X200h:2@03010<2`0?2`X03PX900804Ph=01X02`L8018>
3`0B3Pl071PI01<?400>2P/04@d>010<3@0D41405A4B01<?40081PT02PT@00d>5P0O7bP081lX00h>
5@092@h03PhE020P9@0820/071/Q01LG6P0D4QD03`/<010:30@03PP:1`0@2P`200l92`8040X<0P0>
20X200l92`8040X<00X04@/=00l92`0B30h02`D7024K7@0>20X040X<014;3@0@2P`03`T;0P0@2P`0
3@0A2`d03@L;01/E6@0910L040/>01dG6`060@@03PP<00d72`0>20`040X>00h8300<1PX00P0>20`0
1P0=1`/03PP<00h8300>20`040X>00h830803@L;00P03PP<00l93@0B31003@L;02PR9P0500<050hB
00h830D03`T=00X04@/?018<400A2`l040X>00h8300=1`/03`T=00h8300;1@T03PP<0P0B3100600B
2a405@hF01@=500d;C@03`X?01TC5`0=20/04`dA01D?4@0A2`d02`D700`6200?2@`020@7010;3`0<
1`/03`X>00d8300?2Ph040`?03dh?00E41@03@T<00h:3@804PT>01`050/@018<400A2`l040T@00h9
400D3aH0924X02/X<@2;R940c<WA04DoC@0@2QH03`TC01TD6`0>2@l03PX=01dI6P0D41403@P<01`G
7@0?2Q004@`B00d63@0=1`/03PP<00l93@0B310050hB0P0?2@d02P0@2Ph03`T=00h8300=1`/05@lC
00d72`0@2Ph0;2HZ02XT:00>20`2014;3`0400l93@0>20`03`T=00l93ACooooo000Kooooo`803`T;
0P0=1`T200l92`0700d72@0@2P`04P`>018<3P0?2@/030H800h93@0400d8300300h93@0@2`l040/?
00@040/?02@0@3/o01HA5@0=20`03`/>014<40080`L03@P<010;3`0>2@d03`X>00h93@0;1P`03@L@
01TC7@090`d03`TC01PB700<1Q00618L010:50070@/0M6ih00<01`0D3AD04@H=01873@0C20h05PdB
01XA5P0L4aP04`dA00T4200@2`l04PdA00l:3P0E41@2018=4@0300d8300C3Q804PdA00803@P<01P0
40/?01<>4P0=20`03@P<010;3`0A310050lC01LB5P0E41@04`hB00h93@0E41@05Q4E024L802MV9`0
?3Lk01<@4P0E4a@06QPK01LE600@3Q404@lD01<A5P0B41D3018?5P0:014>5`0E4AX0618L01@A6P0C
41T0514J01HE7@0I620061LO01HF7P805ADM00L051LM014B5P0J6ad08b@V09ZKW@3nool0N7Uk0080
7AhP04006AXL00h?4@0<3@l05aPK01PI7P0G5al05ADM01@D700E5Ad05aLO01@D700>3QH071`T01/K
8`0?3aL0;2hf02/_>00O9S005A`V01XQ:`0N92l06Al[01@J9P0F72X06Al]01XP;P0K8C40728b01XP
<00@5RH03aDU01LM;@0L8S405ad[03HlBP0m@e004QPT020V<P0Q:3<06B0Z02</=@0M9Rl072D^01lY
<`0P:S@06bD_01DQ;@0T<3`08blk01DS<00L:SL0;S];01HS<`0I9SH0524a01`Y>@0N;3T09cE2028`
?00Q;cX082hi024_>00R<3T08c4l0`0U=D80=P0T=4408S<m024b?00P<C/05bP`028c>`0N;cL09CHm
03a=E01oS9@08c4j024_>00L:S@06b`f02dnB00U=D809cU502HhAP0cAE<0;3m=02@gA@0`@e80;3m>
02/nC00Z?TP0:Si502Tn@`0Z?d<08cPm0314BP0X?4<09SY302a0B00V>T4093Po02Lk@P0Y?D@0<dM>
03I:D@0_@dX0;T9902Hj@@0Q=C`09c]202m5BP0/A4P0:41402ToAP0[?dX09cU702@c@P0W=4@0:3A4
02@_?0<082Xd01405b4Z02H`>@0c?T<08B``01lZ;00R;Bl07bX/01`W:`0I92T051hW01`V;`0S;3<0
8R/b01XS:P0H8BP072DZ01lV;00201/P901i01TN8P0F6Qd051PK01<G6`0I82H08BXa020Y<00?5R00
72<]01/R;00R9S80720/01/M;00H6RT051HU028T<P0J7BH06ahU00lB6P0E61l04QLK00lD600B6Qd0
72@V01DM7`0F82404Q`K01DO800A6A`05QhQ01DM80094A@05QhQ01DM800A6A`09Bd`06adM`0W;c80
72@W010H6`0C6ah05AdP02@/;`0S:2`05Q/O01@I700E6A`05a/L01DI6P0D5AL051HE01HG6@0C5aX0
3Q4F020S:00E61d06A`R00lB6@0?4Q/04QDN01<F7`0C5B405QPT01XL:0092aP07b4^020R;`0K7BX0
3@lK01HH900N8BX051LP014D7@0A51/010L>00X=500@4aX03a8I00d@5`0C5Qd05QTP01<F7@0E61l0
4A@K00`?5P082a806QdT01`O900K72405aPM01@E6P0B4aP06AXO00d>4`0B4aP051DJ014B5`0?41D0
51DJ01TJ7`0H5ad04A0F010?5@1NGF<051<I01/J800D4aT05A@J01HE6`0I61h06aXP01XI7`0D4aT0
6aXP014@5P0G5Q`07A`R00l>500D4aT04a8H018A5`0201<B600601DD6@0G5AX061HK01DC600B41D0
4Q0C0P0E4aH02P0D4Q<04Q0A018@4@0C4Q004a8E014@5P0A41D040lD014@5@0B41<2014?4P0@01@@
4@0E4A805Q8C01HA4`0?2Q003@/@00l=4P0A3a@04a4F01DC600e<cP09bDZ01DC600B41D0518G01TG
70H040hA00`020H900/9300`;S40>SPk01`J7@0?3A004Ph?00l;300B3Pl0510A00l;300@30d301<?
4007018>3`0A3@h04@d>00h<3@0@3Pl03P`=00d;300200h<3@0600/92P0F51D03@/<014?400@3Pl0
518C0P0B3A<04P0C3Q@04`hB01<>4P0C3a0030P9014=3@0C3`h04Ph=010<2`0?2``061<I030[<P0B
3A<02PD;018=4P0A310050lC01@@4P@0510A2`0@30d0200?2``061@E018>3`091@H040`=00l;300a
;Bh08AdN0P0G4a@0100>2P/01`<400d92P0=2@P200h:2@08010<2`0A3@`04Ph=014=300E4A001P81
00h:2@0K5aH200h:2@0X014=300?2`X030P700l;2P0A3@`03`/:00h:2@0<20L03@T800h:2@0=2@T0
30P900h:2`0@30d03@T:00/7200<20T04Ph?01HB4`0J5QL05Q8C014=3P0>2@/02P@6010:300?2@/0
3@L901<=3`0<1PP05Q0B02dW:@0V82803`T;010:300@2P/040X:00l92@0@2PX04P`<01@>3P8040X:
01003`T900h8200>20P03PP800d9200>2PT01`<200d9200:1PD03`/:01lK6P091@@04@d=01LC4P03
00004@d<0`0=2@P200`81`0300/71P0<20L03@T800803@T800L03`/:010<2`0D41404Ph?00`82@0=
2@X03PX;00804`l@01<05A4B00h:2`0D41402PH700h93@0300L04PlF01HC6P0C41L04@lD00X:3001
00@05QDH00H61P071`T0V9RI00h<3@0>2P/03`T;00<03PP:00<03`T;010:300@2P`0100@2P`01@0>
20X03@L900d72@0?2@/040X<00<03@L90P0>20X200l92`8030H800@02P@600X51P0E3a403@L90P0>
20X200l92`0A00h82P0=1`T03`T=00@00P0Y8bL01`8500P21P0G4AD03PP<00d72`0>20`040X>00h8
300<1PX03PP<00l93@0@2Ph00`0A2`l0300?2@d040X>00h8300B31006A<G018<400E3a<02`D900d7
2`0;1@T05a4E00T41`803PP<00D03`T=010:3P0@2Ph03`T=00h8300200l93@0P00h8300?2@d03PP<
00`62P0=1`/030H:00/52@0>20`050dC018;4`0600H030D<00D01@0F41@03PP<018<400C3@l040X<
00`6200=1`T04Pd@01@?4`0>2Pd02PD900@00`0@2`l06aHJ00<00P0Q72002PD901<>4P0B3A420148
3@0K01<:3`0A2`l04P`@018;4P0J5A`02PD<014>5@040@X03``E030]=P0@2QP06A<O01<>5`0>2A00
40/A014<400E4A804@d>00/62P0E41H02PD;010;4P0=1Pd03@L;00h8300?2@d04@/?00804P`@00<0
4@/?00h8300=1`/00P0=1`/01@0;1@T04`dA01TC5`0i<cL08A/O00<04@/?00@03`T=00h8300?2@d0
3`T=5?ooool001_ooooo00H03`T;00h82P0=1`T03@L900h82P0?2@/201<=3`05018<3P0A2`d03`T;
00d72@0>2@d0100?2Ph700h93@0d01LB5P080`L04@`@00d8300?2Ph06A@H010;3`0C3Q803`X>014<
400C3Q803PT?00`64@0D3QX02P@@00l95@0L5R803PPD00X5400C3AT06aDQ09fGX`0B31P04PXE0187
3P0C20h05P/A01XA5P0P5a`08QTN018=400C3Q8030L;00d830070PH05A0D01XE6@0H4aL03@P<01<>
4P0D3a<03`X>014<400F4AD06aHJ01@?4`0A31004PdA014<400B3A404`hB01@?4`805A0D00`061<G
01<>4P0A310091lS00P31`0A3A40518E01HD5`0A3a<03@/@014?500E4QP201<@5`05018?5`0B3aP0
4@hG01DA6@0H4aX00`0D4AP301DD6P0A01<D6@0D5AX05AHK01DH7@0>3a<07QlQ01`M7`1FEeT0XjBV
051AD`0G61X04a@F01DF600D5AL04A8D01XK7P0F5Qh00P0F5R0201LG8@0901HF800C4ad05QHP01dM
9`0H62803`lI00lA6P0R:C407BH]00806B8Y00H06B8Z01HO:00@6B804QXU01@L9`0F7RT201LO;00O
02D[>`0H7Rh051XZ01XP<00L8S4051XX01TO;@0U:cP05Q`X02`b?P0O9S406B0Z028[=00K92d06R@]
01lY<`0O:SD062@`01/W=@0K:3D06bTf024^?P0M:SX062De01DR<`0M:S/072Tj01l/?@0L:CT08Bll
020^>`02020^>@808Blh03d08S0k02De@`0U=D@09CE402De@P0S=3h08S<m01h_=`0H:C406BXb01X[
<P0U=Sd0<dA;06IcNP0O;SD0:3Ln02<a>@0F9bl08S<k02/lAP0`@T`0;Cm;02Dg@`0L<3/0;d9@02e0
C`0_@U40;d9@02XnB00T>3l08SLl02e2A`0[@4D08cPn02Lk@P0]@DX0;T9:02Di@00P=3/08CDl02Pl
@`0cAdh0<TI=02XnA@0/@4L0:3a302Di@00Y?D@0<TM>02i7C00Y@4H0:d5902e1C00Y>dT09CE302Le
@P0X=4809S4l02D_>00U;SL092df00807bPa05X0<CY002Pa=P0M9bT09c4b028/;P0O:2d07BH/01TR
:@0N9c007BH]020Y<00N9bh07RD[028Y;`0L8BH08RL[01hS9`0J7R405QXM01LK7P0H7B00:C0f01DN
8`0@6B002Q4I01/R:P0K8R`06AdY01hR;P0K7B`05aPZ01/L;P0F5bP05aLS01/K9@0B51h051LP01<F
7@0D6Al031<I028Z;@0C7Al06bDW01@N7`0K9BL041PK01LO8P0X<3<0620S01DM800K8bH041LM020W
;@1TJg408bX`01`S:@0B6Al072<Y01lU:`0X;C<05AXP01<G6`0<3a@04aHK01HH700G61`05QLK01HG
6@0G61X02`lB014D6@0>4AH0=3Ln01PK8P0C5Qd04aHO01DG8P0E5b<05QPT01PJ9P0K7BT04A<P01XL
:`0G6BH051HS018D800I6bL05aXS00/>5`0D5b0201<F7@0?034d>`0R9BX03A0E01@G700F6Ah03a8G
01<F6`0I72403Q4F01LJ7`0K7R<07B0U00hA5P0E5Q/051DI00804a@H01/06AXN01DF6P0F5a/05QLK
01<D600@4AD04a@H01LH700P7bD05QDK01/J800J6Al07A`R01LF700M72806QTO01LF700D4aT04Q4G
01<B600B4AL06APN01<B600S8RP0;Rdc01HE6`0C4QP00P0B4AL201<B600901<A600D4AP05A8I01<A
5`0B41D04a4F01HD600G5AP05A<D00804a4B00X0518C01@B5P0A41H04A0E010?500A41D04Q0C014?
4P0>30l04@d>0P0B3Pl0100E41405Q4G01@B5`0E4aP301HD6@0601/I7P0E4aP040hC010>4`0B41D0
7Q`Q1P0@3Q40300K6A`06ALJ01/I700E4aH03P`?01@B5@0B3Pl040`=014=3P0B3Pl03`/<010<3@<0
4`l@0P0B3Pl0100A3@h04@l@014?400@3Pl200d;3003014?40091`P03P`=00803P`=01H020H700l=
3P0C3Q@04`hD018=4`0A310040`>010<3@0=2@X04Ph=01DA400D40d04Ph;014=30060@L04PdC00/6
300?2Q004@`A01HA5@0@2`l040`>3`0@30d03P0A3@h030P900h:2`0J5QL03`/<034];P3@c<d0FEEF
00H20`0A3@h040`=01@@4@0300003@T80P0>2PT01`0@30/04@d<018>3@0810<03@T800P40`0/:2L0
0P0<20L0300>2PT04@d<00l;2P0=2@P040`;014=300@30/04@d<00l;2P0E4A00920O024M7@<040`=
0P0?2``200`82@06014=3P0D41404@d>00d92P0=20T03@L90P0D3Q00300@2P`050h@00l92`0B30h0
7QPJ01D?4@0;1@L05Q0B01D?400A2`/040X:00l92@803PP80`0@2PX200l92@0700h8200C3`h07QXI
00l;2P0;1`H04Ph=00h:2@02018>3@0400l;2P0=2@P02`L600h:2@804@d<0P0@30/300l;2P<03PX9
00h03@T800l;2P0;1`P02PH700l;300B3Pl04`l@00/7200:1PL04Ph?00`82@0S7b002PH700h93@80
3@P>00`03`X@00`73@0;20/04a4B01XE6@0>2``05A@B00`:2`0J6AP00@0000`82@0@2P`2018<3P03
010:300>20X03PP:00D03PP:00H02`D700`6200@2P`04P`>010:300;1@L200d72@803PP:0`0?2@/0
1`0<1PP04`d?018<3P0U7b404@/=00d72@0>20X00P0?2@/200d72@0@00h:3@0a;300P7]o01hI7@03
00804`hB00d8300<1`/03@P<00l:3P0=20`02`H:00X4200<1PX03@L;00h830<03@L;00X040X>00/5
2@0?2@d05Q0D014;3`0G4AD02@<7018<400C3A403`T=0`0>20`01@0?2@d040X>010:3P0>20`03@L;
00804@/?01003`T=010:3P0>20`04P`@01PB5P0A2`l02@<700d72`0A2Q0040TA0109400D3A@04@XA
01LA5@0;1@T03PP<0P0?2@/03P0>20X03`T;018<3`080`L03`X>010;3`0C3Q803PT=00l:3P030080
4PdA00<00P0B3A40@3/o0P0@1``06P0A20d03`T=010:3P0A2Q4061<J00T42`0A3QD04PlH00H3300B
3aP05a4O01XD800500T020<:01<>500?2Ph02`L801<?400E41@06A@J00T42P0?2Q0040T@010:3P0?
2@d03PP<0P0?2@d0100C3A404@/?00l93@0>20`200d72`0600l93@0F41@02`D901PB5P0:1@P06A<G
0P0@2Ph400h831Cooooo000Kooooo`803PP:0P0=1`T200h82P<040X<00@04@/=018<3P0C3@l03PT=
100@2`l0100>2@d03@P<00d8300>2@d300l:3P0I01<>4P070`H040/?010<3`0@2`l04@`@00`72`0B
3A405A0D01@?4`0?2Ph030L=00d84P0A2aL07aTU00`64P0I4al06aDQ010<5P0B31P05@lK00h8500H
4Qh03@D@01873P020146300D01893P0E31405PdB01@?4P0<1`/050lC010;3`0E41@05Q4E01dH700K
5QX04`hB018=4@0C3Q804@`@018=4@0F4AD06A@H014<400>2@d4014<400401<>4P0E41@04@`@01dH
70804`hB00<03PT=01dH700C3a<00P0D4QD01P0B41@04Q0E01DC600F51X0514H01@A6@<0514J01/0
5Q8I01LB5`0E4aP05A8H01DC5`0E51T03`hC00l?4P0@4AD04a@H01DF6@0F6Qd061TK00h?4@0F5aT0
8B8T02//;P0I6Q`07AhP010A4`0D5AL07QlQ01HG6@0E5QT05QHN01LG8@0F5R000P0G5b400`0I6B<0
5QHP01TI8`0201HF800401dM9`0I6b@05A`S01DN90805b0V01D05QlV01HO9`0I8R/0620Z01TR;00L
92l07BD`01XR;`0G7Bd07B<c01/Q<@0E6b/05A/Z01dS<@0I7bd05Q`Y01DK9`0Q9c<07RD`02<Z=00M
9Rl00P0G8BX0400J92h06bHa01LS;`0M:CL06bPf01@R<00H9SH093=305QWM`0Y=TT07R/n024^@00M
:S/08c1101XW=`0R<3d2028`>`2>024_>@0P;SL082hi02<c@@0T=4<09CE402De@P0U=T0093Do01LX
<00K;3@07Rlg024b>@0P<SL0838f028_=00M;3007Rda01/Z;`0Q<cP07Bhf059SJ`1cQHh0=TQA02@f
@@0X?4L09SU702XnCP0^@U40;T=@02XnBP0V?4@09S]202U0A00_ATX0:3i402a1B00^@d`0:Ci602Hk
@P0U>d4093Y002@i@00S>3l08CLm024f?@0R=ch09C]102ToA@0/@DP0;dM=02]4BP0Z@T/0<TMB02m3
C`0[?D/0:3Q602Le@P0V<Sh09S8j02H`=P0V;cD08b`c028[=00O:2l09c0f02D_<@0L9RL082X[01hX
:@0Q:bd09c0f028[<P0P:C808RXb01dU;00G7bH05ahT01PO9@0F6al06QlS01LL800E6A`061`O01/O
8P0M82<04a/N01/T:@17D5L082L_01<J8P0E72H05QXV01dQ;@0H6RT05AHX01lP<P0M7bl07A`Z028R
;`0K6RL06A/W01LI900I7BH06B0W03]2B00K9BT082X]00lI700D7b406B4T01`T9P0^=SP08b/^01dU
:00L92L07B@Z01PO9@0T:c407bH/01LN900F7B<06b0X01TN9@0M8BT02a0G02hb>@0I72804A@I01<E
6@0E5QX05QHJ01DE6@0B4aL04A@I01PK8@0@4aT0>ci501TL8`0N8BT071lX01/M:0806A/W02/061XV
01PJ9`0G6BP05QPX01TK:P0G6BH051HS00h@700D5R804QDN01@G800?4QT082<Y04Q;D@0Y;3403a8G
01<F6`0@4aP02`hC01@G700A51T04aHK024T:@0d=c`082<X018E6P0@4AD05AHJ00l@500F5a/02``@
01dN8P0E5QX04a@H01@E6@0E5QX04a@H014B5P0/:c4081lU01HE6`0C4QP04Q4G00@05A@J0P0D4aT0
1`0C4QP05QDK01@C6@0B4AL071/Q01XI7`0A41H00P0B4AL301<B600A018@5`0C41L0514H01@A5`0C
4AH0518G01LE6@0F51L0518D01<A4`0C4A80518C01<B5P0A41H04A0E010?500A41D00P0B41<0200?
3A005A4B01LC500C3a004`h?01@?5@0C4AH05A<H0P0D4QL00`0C4AH0518G014?5002014?500300l=
4P0C4AH040hA00D040hA00H0:2HY01lM800?3A003`d@01@B5@0@3Q43018>3`0301<?400E4A8061@E
00H040`=00`04a4B010>3`0@3Pl03@/<014?400M6a`0AdE6010>3`0E4a@03@/<00h<3@0?3@h2018=
4`0?014<4P0A31004@d?014=3P0A3@`0510?01@@3@0C3``04Ph:01<?3P0B3A<03`XA018=4`0H4aT0
3@P=00804PdA00<04Ph@018>3`0B3Pl00P0B3Pl01P0@30d04@d>014=3P0A3@h040`=00l;308040`=
01004@d>018>3`0B3Pl04Ph?02/W:00I5AH040`=014=3P0R7Ql0PGen03Lc=00;1`P061@E014=3P0>
2P/040`=0`0?2`T3010<2P0:014=2`0;20L06aLF03hj>@0:1PD040`:00h:200?2`T040`:014=2`80
4Ph<00d03PX800d91`0;1`D02`L501DA3`0H51@03PX;00`82@0=2@X03PX;00l;300@30d03PX;0080
30P900l03@T:00l;300@2`d02`D7010:300?2@/03@L901<=3`0B30h030H800d72@0?2@/04@/=01@>
400=1`P00P0>20P400l92@0A010:2P0A2`/040X:00l92@0>20P06aLF02TU900H51<04@d<01LC4P0?
2`X040`;01DA400B3Pd040`;014=300=2@P00`0>2PT300d9200D01<?3P0?2`X04@d<018>3@0@30/0
4`l>01@@4@0A3@h05Q8C00P41@0=2@X04Ph?01<?400?2``071PI00d92P0>2P/0510A010:3@0>1`X2
01H>4P0=00d82P0@2`/02`L7014=2`0@30X03P`900l=2P0A3@/03@L800l92`0B30h04`d?014;3@07
00l92`0700/51`0=1`T04@/=01@>400B30h03@L900h82P0200l92`8040X<00<04@/=00l92`080P@0
0P0C3@l00`0Q6ad030H800l92`0300h82P803`T;00h030L;00X52@0F4QD03@T<00l:3P0>2@d03@P<
00`72`0=20`03`X>00d8300;1PX040X>018<40804`dA00L040X>00l93@0E3a<06Q@H014;3`0?2@d0
4`dA00804@/?00D02086010:3P0B31002P@801@>4P0600l93@0P014;3`0C3A4040X>00h8300B3100
4`dA01H@500K5AT05@lC00h8300@2Ph04P/A00`53@0B2a803`P?00`5300A2`l03`T=00d72`0>20X0
3`T;010:300?2@/03`X=01LB5P1>BDd04`hB00h93@0A31004PdA00d8300?2Ph2018=4@0M00/72P0C
2Pl04PT>01483@0>20`03`T=0109400:1@`04PdD00d:4@0G51d04a0I00h;500@2QP04`dI02TT;@0Q
72<01P4700d8300;1`P06QHG01hI7@0L5ad02PD;00h9400A2Q404@/?010:3P0>20`00P0?2@d00`0@
2Ph04@/?014;3`02010:3P0700h8300G4AD03`T=014;3`0F41@02`D901PB5P02014;3`0400l93@0>
20`03`T=00l93ACooooo000Kooooo`0>00h8300=20X02`L800`62P0=20X03@T:00`62P0>2@/040`=
014;3`0@2`d03@P<00/62P0=20`200l:3P0600d8300;1PX03PT=00h93@0?2Ph040/?0P0A2`l02@0:
10D07A@G01H@500<1`X05@lC00`72`0@2a402@L<00h<4@0200`;400N01@A600?2A<091hX04]5C`0C
3AL02`D?01LA6`0D3QP05@lI00H02P0E3aT02@<=01094@0F3A4050/>01<:3@0D31005PdB01D?4`0B
31000`0400P32@0D3aD04PdC010;4@0B3A<05A0F01@?5@0;1P`02@@:0P0?2Q001@0A318050lE018=
4`0E41H05A0E00804@`@0`0C3Q803P0D3a<04`hB00/62P0G4aL02@L:00d8300C4A@040hA014?4P0D
4QD05Q@I01@B5`0C4AL0514H0P0E4Q/201HC700401LC6@0G4QP05Q<H01DC608051<H01@06QTN01TH
7@0G61X05QHH01HF5P0E5aL06Q/M01@E5`0E5QT04A8F01`M7`0D5AP03a0D00l@4P0I6Qd04a@H00h?
4@0i>Sh06QXR01PH8P804a<M03805QHP01`L9P0N7RP06a/U01HF800D51h061PR01`N9`0M92`06B8Y
01PP9`0I82P0620Y01DN9`0G7RP05A`W01DM:00I7b/061l[01@J:00O9C<06b4a01TO;@0L8S806b4_
01DK9`0A5bD06R0/02@[=@0Q9c<092/e01<L9@0J92d06B</01PR:`0J92h06bHa01TU<@0I9C<062Dd
01dZ>P0R;cl0528b04EBH`1AGVl08Bi0020]?P0Q;Sl0CU][04YGI`809C=002X0938o02<a?P0P;ST0
82hk020`@00R<T808c=202De@`0U=D809CI001TZ<`0D9Bd0834h02<d>`0O<CD09CLk01h]<00F9BP0
9C@g01l_=00N<3@07Blc02Xl@`0[?TD0:3]202PkA@0C9c80:d5<02LmB`0Z@4h0:Cm<02ToB@0^ADd0
<DQ>02Y1AP0T>d40<4M=02i5B`0]A4`0<DMA0316D@0]@dh202Y1B@0X02U0B00W?TH08STo01dd>P0T
>d40;dI<03A8C`0]A4/09Ce702e3CP0iCUT0<TIA02/mB@0X>DD09C<n028`>@0R;SD08B``01hY:`0N
:Bh082Xc02/f?00S;S<07BPZ028];`0R;2h09S0b02<];`0U;S<08b`c02H_=P0O:2d0624V01XS:00R
:Bl072@W01PM8@0A5QX041DI01<F6`805QTN024041@I010G7@063aH07RD]00894@0A62003aHP018I
8`0F6RD06al[01PK:P0D5bH07R4_028T<@0T9S8061XV01XL:00G6bH051PS00`C6`0h?dL05b0W028[
<P0@6b4072D[01/R:00J8RD072@W01dU:00^=ST072@W01dU:00E72800P0D6b40200J8BL05QdU01TM
:00I7BP092Pc01hR;@1>DEX05APQ0P0D5ah04P0F5Qh05QLL01<D6@0?41D05APO018E7@0O8R/05APQ
018E7P0K7RL05QPT01@F8P0C5B405ALS01HH900E5b@07Al/01<E8`805ALT01@071hZ01DG8`0F6B<0
4QDN00`?600K7RD04QDJ00X=4P0@4aP05aXO01TL8@0G6Ql04aHK018E6P0E61d03A0E018E6P0C5Q/0
1@P=00L:3`805AHJ01001`P<01/L800C51P0?d14010A5@0=3Q804A8F01TJ7P0C51P03@hB01<B600M
728010<901LF700>3A<061LM0`0F5A/02`0D4aT04a8H010?5@0I61h04a8H01`K8@0O7R@040lE014@
5P0@3aD04A0F00@04a8H00H05Q@I01LD6`0E4QT04a0G01DB6@0E4AP2018@5@04018@4P0B41404Q4?
018A50804A0E00`040lD014A4`0B41<04Q0C018@4@0O6a`08alP01TE5P0A3@h040hC014>5@0D4AP2
01DC600801@B5`0E4aP03P`A00h<4@0E4aP04a4F00h<4@0B41D5018@4`0600d;3P0>30d0518D01<A
4P0>30d0518C0P0D4140100A3@h03`/<014=3P0C3a05018>3`03014?400@3Q4030X=00803P`?01`0
5Q@F02XX:@2>S8d0518C01<A4P071@H04Q0A00h:2`0?2Ph040/@018=4@0D3a<05a8E01LC500B3Pd0
4`l>014=2P0?2`P040`9018>3@0=20`04@`B00d8300C3Q@040/?01D@500?2Ph03`/=1@0?2``0600A
31004Ph?018=400?2Ph03PX;010<3P0@2`l04@d>018=400B3A404Ph?059>C`0I5AH04`l@010<3@0>
2P/03`/<014=3P0@30d01P8301LC500300005Q8A010<2P@03`/800H03PX702LS800Z9R<04Ph;00D1
000O6aP200l;200500`81@0@30T0510=01<?300A3@X00P0;1`@01`0D40d04Ph;00d91P0=2@T03PX;
00l;300A3@h00P0B3Pl00`0?2``030P900h:2`02010<3@0?00h:2`0@2``030H800l92`0A2`d06A<E
02HP8P0L5QP040X<01H@4P0?2@/06A<E03Pb=00]9bP040X:00804@/;010040X:00l92@0>20P03`T9
014;2`0@2PX03`T900d71`0<20L04@d<00`81`0B3Pd03`/:00h:2@091@@040`;0P0>2PT00`0A3@`0
30P7010<2`02010<2`803`/:0P0>2PT08`091@@03@T8014=300?2`X0510?00d92P0H51D0;b//014=
3P0<20T03@T:00T51P0b;Rl0P7am010<3@0B3Pl030P901H@4P0D30l02`D701072P0D3Pl03PP800d7
1`0?2PP04Ph;01<?300=2@H030P500h8200=1`T030H800d72@0?2@/04@/=00H040X<00L03`T;00h8
2P0>20X04@/=01<=3`0B30h03`T;008040X<0`0A2`d0:P0C3@l02`D7018<3P0=1`T05Q0B00L10`0A
2`d03PP:00d72@0>20X040X<018<3P0?2Ph04`hB00d830080`L02@@801TD600=20`030L;00d8300?
2Ph03@P<00/62P0@2Ph04P`@01<=4@0A2`l03PP<00`62P0A2`l06A<G010:3P0=1`/040X>00l93@06
00@04@/?00l93@0B31003`T=00h8308040X>00d03`T=00h8300>20`03PP<010:3P0?2@d02`D900l9
3@0K5AT071HJ00l93@0;1@T030H:008040X>00P04@X@00`5300F3aH03PP>00L01`0:10P04`dA014;
3`<040X<01003`T;00`72P0<1`/03PT=014<400;1PX02`L:00/62P0400<05A0D00<00P0910P05A0D
01@>4P0E31404`X?0P0?2@d0500A2Q4040/B00d83`070`X06aDO00<02@0@2Q@03PPF00d74`0K5Ql0
2`H=00T42P0C3Q801P83010<3@0=2@`04PdC00P32@0>1`l03PL>0`0>20`0400@2Ph04@/?00d72`0@
2Ph04P`@01<=4@0@2Ph03PP<07QbMP0X8RH030H:00l93@0C3A404@/?01<=4@0B3102010:3P804@/?
5?ooool001_ooooo01H02`H<010=4@0?3A004PdC00X72`0:20/05Q4G00/8300=2`h03@P>00l;4002
00D030X?010>4`0A3a@0108700d93P0E41@03@L;00h82`0?2@/040X<0P0B2@`06@0C1PP050D80186
2P0B1``04`X?014:4@0>2Q402@P@00X:4P0F6B80000900T<5@0=2A004`hD01@?5@0C3Q@05a8H01XE
6`0N6Al020<900<0100J5A/02@@:01/F6P0C3P`00P0B30`01`0B3@d04@/=010;3`0C3Q<03`XA00d8
3`0=1a400`0@2Q@00`0?2A<03PPB01<=5`0201<=5`0:01/E7`0A2aD03PPB010:500<1Q004`dC01D?
4@0D41404Ph?01DA4P<04a4D03404@lD010>4`0@3a@04Q0E01DD5`0@41003Ph>01<C4`0@41804A4C
01DD600C4QL04Q4G014@5`0C4QX05A@L01LC6`0F4AP04`lF01XG800E51`07AdU01LH7@0E5Q/05ADH
018@4@0?3P`061DE01/L800B5QT051PL01/N8`0F6Qd04QDI00lB5`0B5QT04aHJ01PK800K7b8041<H
01HI8P0D5R80418N00lA7@0B52006adY01`N:P0A4al0418N00806adY02h05aTU01DI9@0D6RH05AXV
01@H900H7BT07bDa01LK9`0L8Bh07R@b01lR<@0K7bh061h/00X@7P0B62H0728^02@Z>00F72P07B@^
01HL:00E72H0;C@l05ELIP0]=3`0624X01`V;`0G92`0524Y01DR:`0L:C808Bhg028^>P0G8c006BDc
020/>P0Q;Sd0RiNU0<GAg`0Q;C/082`j02XfA00Q;S`0938o02@a@@0N;Sd07Bdl0P0N;Sd06P0N;Sh0
7bi102HeB00W=TT09CE502PhA`0[>dP07c0i018S:`0K;3<06b`b024c=`0_@DD093Hj024c=`0P<SH0
9cPo02Df?@0M<3H07C0g02XmA00Q=C`0<4A=02Di@P0S>T809Se70P0V?TP0?P0Y@TT0:dA;02]4B`0`
BDl0E6ed0319D00lEE`0:D9903=;E`0aB5P083M702e4DP0/A5009ce:03I;EP0R=Sl07S8i02Tm@`0/
@DH0;3m50315C@0_AE006Rhi02i2C@0X>T@09cU302<e?00O<3L07Bhe01`[;`0K:B`072X]024_<`0T
<cX08c8i01d[<P0J9bd07BX`01dY;@0U<3@0;CPl02<^<P0I92P062<W01TW:P0D8RD05R4S00lI6`0C
6ad051TL00X?4P0X;C404AHK01TM9P0<4a/05ahV01PO:@001@d05Q/T00@;4`0Z<CT05A`T0P0C6R80
5`0F7BD06B8Y01/T:`0K92/06B0X01`P:@0G6b@05ATR01PO9`0K8RX05ahX01TP:P0G7RP05A`V01PQ
:P0I82X072<]01XN:@0S9c009RXc04aAEP0M8RH06b0T00806AhR00D0724W01XO9P0D62<082@`01`P
;@0201LK9`0601PL:00@51l051PS01<G8@0P8b`041<L0P0E62403P0B5R404aLR00dA700<41/05QXU
01XN:@0K7b/06QhZ01/O:`0L82`06al[01HJ9@0I6bL061/T100F6B800`0H6b<05APO01<F7@0201DH
7`0901DH7@0E5QX06AXN01PI7@0B4aL051DI01/L800H6Ad05AHJ008051DI01L05AHJ01HG6`0F5a/0
4a@H014B5P0B4aL05AHJ01LH700B4aL051DI014B5P0B4aL04a@H00l@500C51P0414E014B5P0F5a/0
51DI014B5P0E5QX05QLK01<D600201TJ7P0301<C600A41H04Q4G00@04Q4G1@0A41H0<P0D51L04Q8D
01HE6P0A3QH040XF01LA7@0G41`05Q0J01`F800B41@02@T701HG4P0D51@05A<H01<A5P0A3a8040hA
014?4P0D4Q<03`d>01`K6P0S8R004a8@010>3P0B3aH05A8M00`:4P0I5Qd020H;010>4@091`X05aDH
00l=400?3A805aDJ018?5P0=2Q403`dB018@5@0D4QD04a4D014?4P0D4Q<03`h<00d;2`0E518061LE
00l>2`0<2P/02`T<0P0C4A@01P0=2`h06aTL01XH6`0C4A@040hA014?4P803P`?03/03P`A01<B5`0@
3a@02PT>01<B5P040PD03`d@010=400B3A404Ph?01<?400D41404`l@018@4P0B4140518C00/92P0J
61T040h?00l=3P0?3P`040l=00l>300<2P/040`=01D@500;1`P061<G00X61`0F4Q<0510A00h:2`0B
3Pl02`L800h:2`0<20T03PT=00T42P0<1`/030L<01HA5`0;1PX030L<01@?5@0A310040/@00d83P07
0PH05A4A00h:2@050@006ADD00d9200C3`h040d<01<?3P0D40l04@d<00/71P0200h:2@0@00`81`0=
2@P03`/:00h:2@0=2@P0?3Pg05mKFP0E4A003PX:01DA40070`803PX9018>3@0A3@`03PX900d920H0
3`/:00T040`<00T51P0;1`P04Ph?00h:2`0I5AH030P900X61`070`@00P0?2``03P0;1`P03PX:01@@
3`0G4a804`l>00d9200<20L03PX901LC4P0810<0510?01dI602MVIP0FEED0P0>2PT06@0<20L02`L6
00h:2@0;1`H02@D401LC4P070`803@T801@@3`0=2@P03`/:01@@3`0300009b<R01TE500?2`X03PX9
00`81`0;1`H030P700l;2P0;1`H020@301@@3`0H51<00P0=2@P0100@30/02`L600h:2@0C3`h200l;
2P<03PX900<03@T800`81`0<20L00P0@30/201TE508040`;01D0:BDV01lJ700C3a0040X<00l;300>
2P/04`l@00X61`0D40l0=30_018>3@0<20L04@d>018>3`091@H05a<D00H30`0D414030P900X61`0;
1`P00P0A3@h02`060P<03@T:00h:2`0:1PL04@d>00`82@0:1PL03PX;01TE5P0K5aP04@d>00803PX;
0P0>20X200l92`0500h82P0=1`T040X<014;3@0?2@/00P0B30h0100=1`T03PP:00h82P0?2@/3010:
3003014;3@0@2P`03PP:00<03PP:0P0A20/201072P803`H900H03PD80189300A20/03PD801072P0B
2@`401482`0801483@0C2Pl02`8701hD700=1@/02@07024G7`0=1@/;00l93@0=010:3P0?2Ph02`H:
010;3`080`L01`8601D@500B3A401`8600d8300>2@d04@`@00/62@0500h:2`0<014=3P0<20T030P9
01`H6@0;1`P03@T:018<401:A4P08A/O01D?4`0D3Q802@<90P0?21004P0?2A4040PC010:500A2Q@0
5@lM00P5400610`04@hE00D3200E41@040X<00/51`0<1PX03`P?00`5300A21003PL>00h93@803`X>
00@04PdA01D@500@2`l03PT=0P0<1`/03P0@2`l04`hB07E`M00U82@01@0400X52@0D3a<03PT=00<0
0P0D3a<01P4501D@500810L04PdA5?ooool001_ooooo00h05Q@J00T7300:20h04a4G00T7300?3A<0
20H<00h;4@0B41H02PP>00/93P0E4aT05a@K00`93`803`dB00D03P/?00`72`0@2Ph04@/>014;3@02
01@;3P0>01D:3P0E1PT05@H901@5200C20`04PP@014:4@0?31@03@dG00hA6P1hO8@0NGj:02HY<P0@
3A46014<400b02HQ9@0@2`l0:2<W01<>4P0@30d040d9010<2@0A3@X04Ph=018>3`0C3a005A0F018=
500A2a@04@/F018<600C3AP05@lH01@>6@0C3AL0618K01LA700A2aD04`hF01`F8@0M5b405Q0I01@>
6@0E41D05Q0B014=3P0D414071PI01HD5`0C4A@05aDH01DD6@0D4aP04Q4F014@5P0C4QD04Q8A018B
4`0C4a@03`l@014A500E51T051<I01@C6P0E51`201HD7P0I01PD7@0F41T06A@O01TG8`0>3QT0;Bdh
010B6`0?4AP051@I01HD5P0E4Q806aLG02h_<`0M82D03Q4F010C600B5AX05APM01XM8P0B5AX041<H
01@G700E61d05QTO01LJ8`0401LI9@0P01TK9`0A4al05QPT01HH900D5R805aTU01HH900G6bL06ah/
01lS<00M8Bh06al/01`O;@0D62D06AdZ01dQ;P0O8S0082@a02<W=00I7b`05A/W02H/>00D6RH05adX
01/R;00W;SP08BPa01<J8P0T:c8061lV01lX;`0I8b`201LT;00601LT;@0I9Rh06BH_01@Q:`0I9C40
6RHc0P0L:3D0B@0hA580@4YF02Lb?P0J9S805B4^024^>`0J:3D07b`k01`/>`0M;C`07blo01h^?P0M
;Cd09SE:024`A00Q<4<09SI602LgAP0V=T<0834l01d^=P0]?TH07Bhd02Li?@0V>3`09CLj024c>00N
;cD093Hk02Tl@P0X>d4093Ln024e?@0[?dL09c]501/b>`0W?DL0:45802M0A`0X@DP0;4E<035:D@0c
C5<09d1703I?EP0X@DP0>U=J02Y3BP0`B5D0:T5C02DlCP0dBUX0=TeK02ToC00Z?d/09c]402<g?P0X
>d80:3]102Tl@00Z?DD09CU302PlAP0V>D80:3Y302Li@@0U=Sd0:3U001l_=P0O;S@072/_01PW;@0Q
<CL00P0O;cH0C00O;SD07Rdd028_=@0O;C808Blc02Ha=@0P:bh06bHY01/U:00E8bL07bhb01HT9`0E
7b405b4R01PM800B5QT06QlR01PM8P0F7B@04aXS01PQ:@0>4Q`061`V01PL9@0G7RH09Rde01XQ:@0K
92T06R<X01/T:@0K9RX072L[01TT9`0M92X07bH/01`S:@0J8BT07B@/01hU;@0M92h06B0Z01TO:`0J
82`05adY01TO:`0H6bX08B@b01HJ9@0T:3<07R<Y01dR9P0I7R406QlR01TN8P0I7R@05Q/R01DI900D
62D06al/01hR;`0G6bP041@Q01HJ9P0@52005QXV01LK9`0A5B005QXV01PL9`0C5b<0720/01/O:`0I
7BT06QhZ01LK9`0J7RX201TM:@0401XN:P0I7BT05ATT01LJ8`805QTQ010061/S01TL900J7BD051LO
018E7@0C5Qh05QTQ01<F7P0@4aX061TM018C5`0D5AT05AHJ01LH700K72005QLK0`0E5QX301@E6@<0
4Q<G00D04a@H01@E6@0D5AT05QLK01<D600201DF6P804Q<G0P0C51P201@E6@0401<D600E5QX05AHJ
01<D608061TM00D05ADJ01DD6P0F5AX05QDJ01DD6@0701<B600W01DE6@0A4QD04a8G01@A600E3aT0
7ADP020H8P0K51d07QTO01DC5P0U9B<06adH01<C4P0D4QL0518E01<A500B41<04@l@018@4@0@3Pl0
4A0>018A3`0@3`d0518A01@A6@1<BE@071TR01HD6@0;2@`04Q4A018@400A40l05A@D00h<3P0=2`l0
4a0E014>500A3aD04Q0E00804Q0C00T04@l@01<A4P0E51<05QDC018A3@0@3`/04A0=01LE5P0@3Q40
0P0P7R407@0N71l0K6Y]01/I700D4QD03`d@010>4@0=2`h040hA00P83@0Z:Bl0=C@j01LF6`0:2@h0
518G00h<3`0?30l040`>010<3@0A30d040`=01TE5P0@3Pl020H7020N7`0T8R<02@L800l=3P0>30d0
3`d>00804Q0A00@040h?01<?400>2P/05a<D0P0A3@h0800>2P/040`=00l;300E4A8040`=01DA4P0A
3@h071LL014<4@0I51T0=2ld014<4@0:1PX04@`A00h93P0<1``050lD01/F6`0I51P04Ph>01<?3P0F
4Q402`L6010<2`0=2@P03`/:01DA400=2PT0:RHU00h:2@0I5A@0510?0`0A3@`03@0?2`X03@T801<?
3P0=2@T04Ph=01@@3`0:1PD05A4@00l;2P0B3Pd040`;00h:2@0=2@P01P0?2`X03@0>2`X02PH701HB
4`0B3Pl05Q8C00`82@0?2``08alP02TU9P0?2``04@d>01DA4P0@30`00P0@30/03P0?2`X03@T800d9
200?2`X03@T800X61@0A3@`01`@302`X9`0C3`h04@d<00l;2P0<20L03@T80P0E4A00300=2@P04`l>
01PD4`0?2`X04`l?020L6`060`804Ph=00h;2P0<20L03@T800h:2@<03`/:00d03PX900l;2P0=2@P0
2PH5018>3@0E4A003@T800h:2@0B3Pd03@T800l;2P0B3Pd03`/:00@03PX90`0=2@P01`0?2`X03PX9
01<?3P0C3`h03PX900l;2P0>2P/00P0=2@X04P0?2``04Ph?018>3`0>2P/03@T:00l;300A3@h030P9
010<3@0D414030P901TE5P0b;Rl05A4B014=3P0>2P/04@d>01<?40803`/<00/071PI010<3@0E4A80
6ADF00d92P0>2P/03`/<014=3P0h=3D0IF5R01LC500200h:2`0400l92`0@2P`040X<010:30<03`T;
00D04@/=00l92`0@2P`04@/=00d72@0200h82P0600l92`0@2P`040X<010:300B30h04@/=100@2P`3
01482`8040L:00D03`H901D<3`0A20/04@P;0189300200l62@@04@P;00P04@P=01893P0A20d040L>
01@:4P0<0PX0308;01<:4P/03`T=00d04PdA01HA5@0@2`l03PT=00/62P0G4QH0:bHZ00X52@0C3Q80
4@`@00`72`060@D03PX<00D03PX;00`02@H601@@4@0K5aP01@4201LC500>2P/02PD801TC5`0=1`/0
5Q0D014;3`0?20l200l8400:01094@0@21<04@TD014:500:11803P/F014>5`0B3aH030X?028M8@80
4P`>00D05a4E01T?5`0D2Q8050/C0109400200h93@<030L;01807APL01LB5P0@2`l03@P<00h93@0@
2`l03`X>00d8300C3Q802PD900d8300@2`l04@`@00/62P0K5QX0=c8f01LB5P0>2@dDooooo`006ooo
ool03P0B3aH02`P?018?5P0<2A002`P?00X73P0D4AP02PL>00/83`0B3aH04a0G02DR:@0B3aH04PlE
0P0B41D01@0:1`/05A0D00l93@0?2@`03`T;00804@P;00h04PL;01@82P0C1`T04`L90188300@2Ph0
4@XA00`83`0?3QH06a/U08:3S`1nP8`02@TC01DA5P804@`@00X050lC014<400>2@d05Q4E01LB5P0?
2Ph030L;00L21P0@30d04@h:0P0A3@X0100A3@`04@d>014<400@2a42010;4P0D00l94`0>21@03`XB
018=4`0A31<040/B01D@5P0D3aH04`hE01PC6@0[9Rd09b8X01LB600L5ah05A0E01D?4@0A3@h04`l@
01`H6@0F51L200d;3P0Y00l>4`0C4QL051<H01@C6@0B4AD04a<E01HF600B4QD03@`A014@5@0D4aT0
4a8H01DD700G5Al05Q@O01DC7P0B41X0>CHo03djA@0D52003@lK01lR;@0D5R804QDN01HH7P0H5a`0
5A<F01LE5`0:2`l02PdB01@G700K7R<06A`Q01<F6`0E61d03A0E01TL8@0R9BX05QTN018E6`0D5b00
0P0D5R800`0E5b<051HR018D800201TK9`0M01<E8@0S9C40<cE101lQ;@0D62@05a/W01`P;00M8Bd0
6AdY01HJ9P0G6bL061`X01LK9`0F6RH061`X01`P;00I7b/0=C]706E[M`0W;CT07bHa01TP:P0A6280
92/c01/R:P0O9R`06R4W01TR9`0G8RP00P0G92`08`0H9Bd06BH^01TV;`0K:3406RHa01/W<`0H9300
8Bdj01LS;`0P:SH092lk01dY=@0O:cL06RLc01TW=00T<Sl0:SY902PhA`0O;cl072`l01l_?`0V=DT0
7bi101d/?`0R<T809cM602LgA00L;CP0=DI>09^/]010DEP05bT]02`n@P0[?Cl0:3Xl00808C<g00T0
9cY002Pk@@0V>D00:3a502a0B@0/@4/0738m02Y0B`0V?dH00P0S?4<0E`0W@4L0:dA;02i7CP0/AD`0
:T=:02]4B`0bBe809d1702i6D`1ZPI40NY6Q02LnC00]@e00>e5N02HkA@0Y?DH09c]202Dh?`0U>3h0
:3/o02i1B00U>D00;D5:020d>`0S=Sd07Rlg028c>`0U=Sh06bXa02<b>@0R<CP06RPa02Lf?@0Q<3L0
8S4h024`=`0N;C@07R/a01h[<00N;2l07RT]01XU:00N:B/072LZ028_=`1IJ6l0=D58014J7`0L92L0
5AXM02<W:P0H71l092T]01@L7`0F7B<04Q/P028V;`0I7BH0;c<l02T`>0083aL08RTa01/T:@0I8RL0
624V01PS9`0G8RH051lS01HM8`0J8BL06B0V01TP:00M92`072<[01XQ:`0G7RP0:Blk02le@@0N9300
51XV00D85`0k?d`0T9BO01`P:`0E6R0082DY01@I700201PM8@0H01DJ800D6B005a/T014E800J7RT0
5a/V01PL9`0K7b/041@P00lC7`0F6RH06al[01LK9`0C5b@08RHb014E8@0/<3`0:Bdi01HJ9P0>4Qh0
5a/W01TM:@0H72P05a/W0P0H72P0100E6BD061XV01LJ8`0D5b0301<F7`0=01@G800C5Ql04A@M01<F
7`0I72D07R4X01<D6@0?41@04a@H010A5@0:2`l03PlC01@E6@0201HG6`0401DF6P0C51P04A8F01<D
60<051DI00h04a@H018C5`0A4QH04Q<G00l@500A4QH051DI014B5P0B4aL05AHJ01@E6@0B4aL04a@H
01@E6@<04a@H0P0E5QX01@0E5AX05QDJ01LF6`0H5a`051<H00804Q4F1@0C4QL09`0E5AX051DI018A
5P0L6A`07ATJ02HP800Y8b<0;RPX00H20@0G5Q@01@D301/M6P0B4Q804a4F01@B5@0E4aH04a4D014?
400>30d0518C01@C4@0C4Q005aHD01<A400C41L0CdaE02DR:00D4QD04Q0A01DD4@0R8Al05aHB028Q
7`0J6AL04@l@01<A4`0D4QL04a4F014?5002010>4@8040h?01T05A<D01PG5@0@3`/03@`8018A3P0C
4A803@/>00X82`0E4aH06QPK01<A500<2Pd02`T<014?4P0D4QD030X=00X82`0E51T020L=01@C6@0?
3Q<03`dB01LE6P0B41<04PlA00804Ph?00T04Pd>014=3P0@30d05A<D00/92P0J61T07adN00`:2`0?
3@h00P0=2``01P0>30d03`d>00h<3@0C3a00920Q04<o@0804Ph?03003`/<01<?400A3@h04Ph?00`8
2@0E4A804@d>01dH700>2@d030L;03<^<P0=20`050lC00d8300@2`l04@`@018=4@0A31003`/<00/7
1`0<20L03PX9018>3@0D40l04Ph=01<?3P0;1`H01@4001XF5@0300001P81014=300@30/04@d<01@@
3`0C3`h04Ph=01<?3P0L61L03PX900d9200F4Q400`00010<2`0A3@`03`/:00d9200>2PT600l;2P09
01TE5@050@803PX;03`h>@1_Jf`08alP010<3@0`;2d0=30a008040`=00D04`l@00d92@0=2@P02PH5
00`81`0200l;2P0?01@@3`0810<030P700d9200D40l05A4@00d9200@30/03`/:00h:2@0@30/05Q8A
01PD4`0K5aH04@d<00800`0000T0BDE406eYJ00S7ah01000010<2`050@006aLF00h:2@0?2`X00P0B
3Pd0100A3@`03`/:00l;2P0=2@P2010<2`0500`81`0A3@`03PX900`81`0>2PT00P0A3@`00`0?2`X0
3PX900h:2@0500h:2@@03@T800@03PX9018>3`0?2``03PX;0P0?2``04@0=2@X04@d>00l;30030000
30P901HB4`0810D03PX;018>3`0>2P/04`l@00X61`0C3a003`/<00T51P0G4a@07ATJ0080510A00`0
0`0005A@D@1fLW<09R8S00L4100O6a`06ADF085mOP3UhN80>3@e01PD5@0L61T2010:30804@/=00@0
40X<00l92`0A2`d050h@0`0A2`d0100?2@/03PP:00h82P0?2@/3010:300400h82P0=1`T030H800`6
20803@L900@04PT<01482`0A20/04@P;0P0@1`X0100G3Q404PT<0189300B2@`200l62@@04@P;00T0
4@P=01<:3`0F3A802`4901@:4P0B21002`4:01H=5@0>20`00`0?2@d2010:3PD03`T=00d03@L;014<
400@2`l03`X>00T4200;1PX061<G00@00`0E41@06A@H00P31`0Z9BT0;BT[00D03PX;00`05a<D00@0
0@1?Bd`0AD52024M7P0=2@X06aDI00d72`0A2`l050hB00h8300>1`h200l8400R01094@0@21<04@TD
014:500D3Q`05A8M00T63`0>2a803`dB00X52@0>20X04@/=01H@500D2Q8040H>01494@0D3A@04PdA
014<400@2`l03PT=00`72`0E41@050lC014<400@2`l03`X>00h93@03008020<701LB5P0B3A4040/?
00<00P8030L;00@061<G028M8@0=20`05a8F5?ooool001_ooooo01D03``E01<@6@0B3aP0104:010=
5P0=2Q<02@H?00P53P0=2Q<05A8K00h;500[:340Hf1W03Le>`0@3Q<06ALL014>4P0;1PX03`T=00l9
300?2@/00`0A20/03@0D2P/04`T:01482@0A2@`040X>014:4@0B3QD01P<<00P73`0M6bH0=C<n01HE
7@0C3a@00P0@2`l02`0D3a<04PdA00l:3P0C3Q80<2/_00d8300F4AD05a8F00X61`0B3P`04Ph=0080
4@d<00<040`=010;3`0D3aD00P0C3QD05P0C3AL04P`F014;4`0A310040/A00l:3`0D3a<04`hD014<
4@0A310081/Q01TD6@0=20`05a8H018=400E3a404`l@018>3`0F4Q<0518E014?4P0C4A@201<B5`0;
014@5@0?3Q@03PdB01<B5`0G5Q/04Q4G00h=4`0A41H04a8J018A6@0C4A`00P0E4ah201<A700>01dK
9P0>3AX051HS02T]>@0U:SH051PT014E800C5al05aPM01@C600C4QL061TN01TL8`0G6R42010C6P0[
01TL8`0H6b804QDL024T:`0Z;C@071lV01HI800I72D05aXS01@G800F6B805aXS01HI8P0J7BH06A`U
01@G800T9c00<cHo01lR:`0C5b8051PS01HJ9@0I7BP06QhY01TM:00K7bX06QhY01LK9P0D62<05ATT
01PL9`0G7BT082Hb04E;E`0>5Al04aXT018I8`0K8RX08bXb01DL8P0G7R@082L]020Y;P0301PS:@07
01XU:`0N:C008B/d024[=@0J92h082Xd01dW<`02020Z=P0H02@^>P0N:C<072Tb02Da?@0K:3<07B/f
02<a?P0_?dh0;3a;01h^?@0M;C`093A402<bA@0R<D@07bi101l_?`0U=D@0:SY70392CP0>7bL0D65Y
01h_=P0C92/0838f0P0R=3@0400N<3807Blb020c>@0O<SP0:3]302m3CP0S=d808CA2024gA00]@e00
;TA>02]2BP0Z@DT0:d9:02e4C00_ATh202i5C@0j0399D@0]A4`09ci602e4D00Z@E40=daM0357E@0M
<d00;T5?03I:E00X?4D0:3]202Dh?P0V>Cl0:ca302`oA@0S=S`09SU002e0AP0Y?4808c@l02Th@@0Y
=d007bdf020]=P0N:c@05B4]01l]=@0Q<3L082lf020^=@0O;3807BX`01hZ;`0O:Rh06bHX01PS9@0N
:2X072HY01TV;P12D5T08blf01@M8P0N9RT061dP01HJ6`0C5aP0724S010H6P0C6ah04A/M01LL8P0Z
;cD0UY^Q06ieN`0T:c406B0V01LP9`805QlV0P0F8BL09P0C7R@04APN01DL8P0F7B<061lW01`S:`0M
92`07RD_01/R;00/<Sh0<cU5028X=00H7RX08RDd01`P;@1VJWD05QXU01lT:P0>4aL04QLJ01HK7`0G
720051TO01HJ8P0J7RL04aLP02da>P0I7BH04QHO024U<00A5B002`lK01@H9@0/;ch08bHe00lB8P0B
5B@05a/W0P0I7BT01P0L82`07B4]01<G8`0K7b/06AdY01PL:0806AdY00D05a/W01TK9`0H6RH05ALS
01@F8P0201<E8@0D01HH900N82`06adY01<E8@0H6RH082</01@E6@0A4QH05QLK018C5`0H6Ad09RL[
01@E6@0E5QX05QLK01DF6P0B4aL04A8F01@E6@0F5a/201LH700>01@E6@0C51P05AHJ01DF6P0B4aL0
5AHJ01PI7@0F5a/04Q<G01DF6P0D5AT04Q<G01<D600D5AT2018C5`<04a@H00L05ADI01DD6@0E51T0
5A@I018A5P0@3a@04A0E00D04a8G02L0410E018C5`0G5aT09R@S01`I500L5a40A40f06APE`0h=Bh0
6aXF028R800I6aP04a<D01<A5P0D4QD05A<F01@B5@0B41403`d>01DC500C4Q003`h<01DD4P0?3P/0
1`D:01XH7@0F51P03`d>014@3P0E510051<?010?2P0D4`l05A@@01@C4@0B4A00518E01<A5P0A3a80
0P0@3Q42010>3`0I014?400B4@l04Q4?014@3P0A40d0108300`:3@0A3a804Q0C01DC5P0?3A0030X=
00/9300?3A004Q0C014?4P0E4aH04Q4F01dL8@0c<SL08B0U00h=4@0H5QT04Q0C018?4@02018>3`06
018=3@0A3@`03@T:010>3`0:20T03`d>0P0<2P/0100?3@h03@/<00d;300@3Pl201<A4P0C00X61`0J
5QL0>CDf00d92P0B3Pl04`l@014=3P0@30d04@d>00l;300S7b00920Q014<400>2@d00`0201D@5005
00@03`X>00`72`02018=4@0B00d8300;1PX03@T:040l?01ZIVD07a/J010<2`0?2`X04`l>01PD4`0K
5aH04@d<00h:2@0:1PD081`K00l;2P0>2PT03`/:0P0C3`h0300B3Pd03@T8014=300F4Q402`L600l;
2P0A3@`040`;014=300?2`X03@T800h:2@H03`/:00X02@H500D10P0N6Q/04`l@024M7P0300005A4B
01@@4@0E4A803PX;0P0B3Pl03`0?2`/03PX900/71P0=2@P04@d<010<2`0=2@P01@4001<?3P0@30/0
4`l>00H20@0:1PD03@T800l;2P02010<2`0?018>3@0;1`H04@d<024M700^:RT04@d<01XF5@0W8b80
2PH501DA400^:RT061@C00X71P0?2`X040`;00804Ph=00P04@d<010<2`0?2`X03PX900l;2P0>2PT0
3@T8018>3@803PX900@040`;01@@3`0F4Q40510?1@0>2PT300l;2P803@T80P0?2`X04P0A3@h03@T:
00d92P0@30d05A4B01LC500<20T06QHG00@00@0D41404@d>00<0000B3Pl0510A00L3100B3Pl05Q8C
00<000804@d>010040`=00P41@0?2``0;2PY02DQ8P0I5AH06aLH00<0000B3Pl04@d>00H20`1mNGX0
hMgN02dZ:P070`@03PX;0P0@2P`2014;3@05010:300?2@/03@L9014;3@0=1`T00P0<1PP0100;1@L0
3PP:00h82P0?2@/3010:300300d72@0<1PP030H800803@L900<03PP:010:300@2P`00P0?2@/200h8
2P06014;3@0C3@l04P`>00h82P0?2@/040X<100?2@/0200?2@d040X>018<400F3aH05a0G018;4P0:
0`/02@@90P0>20`0100?2@d040X>010:3P0@2Ph500l93@0800h8300A31003`X>01<>4P0?2Ph020<7
014<400B3A4200X52@0300@00`1ED5@0BdM900D03PX;00`05a<D00H20`0F4Q<00`0000P41@0?2``0
3`T=00T31`0A2`l02`D900l93@0B2a8200l8400=01094@0@21<04@TD014:500300/0514L01<@6@0:
1`h02@L<01@?4`0=1`T040X<010:3P0200h430090148400@2A003PT=00h93@0@2`l03`X>00/62P0>
2@d04PdA00805A0D00h04@`@00d8300R7B405A0D018=4@0;1PX04@`@00l:3P0:1@T04@`@00l:3P0=
20`02PD901<>4QCooooo000Kooooo`0500/84P0<2A<01P<=02PU;`0@3AL00P0<2A<07`0A3QP01`@>
00`94`0X9Bl0SX^D0>o]l@2/ZZl0<Bld01XH7@0?2a0040/?018<400B30l04@/=01<:3@0B2@`04@X<
018=3@0A30`040/;010;300@2Ph040/?03hi?`0B31D0510H00l:4`0>2Q@03PXB00l:3`0?2Ph0100@
2`l2018=4@0401D@500?2Ph04PdA018>3`<04@d<01X04@d>018=4@0B3A404`hD014<4P0?2Q403`TB
010;4`0B3A404`l?018=400A3@h05Q8B01HA500@2`d03`/;018>400A3@h040`<01HB500G4Q<05@lA
01@@4@0C3a005Q8C01@B5@804Q0C00d04Q4F01@C600E51T05QDK01<B600C4QT05QDL018A600C4QT0
4a8J018A6@0C4A/04a4L00<0518M00X05A<N01@F7`0E5b<061dY018I9@0S:cT05Qd[014H8`0@5b40
5QTQ0P0E5ad01`0@4aX05QTQ01HI8@0A51`051LO01HI8@0I72@00P0E6200200F6B405APP01TL900F
6B8051LP01<F7`0H6b@06A`U0P0E624201TL9@0401HI8P0G6R<05QTR01PL9P805QXT02X06QhX01dQ
:`0K7bT06QhX01/O:@0J7RP061`V01TM9`0L82X08bTd01@J9@0W;ST07RD_024X<P0J8BX092/c020W
;P0J8BL05alS01dT:@0E7b80624W01PS:00I92T06bH[01lZ<00R;3@06B@[01dW<@0Q:c@09Blh01LQ
;00M9c80628/01`W<@0N:c@06RHa028`>P0N;3L06bTe028b@00S<d4201l_?P0J028b@@0S<d@09CE6
02<c@`0P<400830o028b?`0[?4L0:CY4020a>@0O<3P0;3e401PY;`0M<2l0838a020b<P0V>3X09STo
028e>`0/?TP093Q303eAG@1KKWd0@eUX02@jA`0[@T/302]2BP80:D1803h0:3m702]2BP0`Adl0:T59
02]2BP0`AU80:T5>02m5D`15FVL0;T=?02m3CP0kCeT0:Ca602Pk@P0V>Cl0:ce302Xk@P0T=S`08SDh
020c>00Z?D808SDj04EEG@0W=Sh0:3Ho02/h@P0S<3/0<Si;03Q4D@0T<CX07R`c01`Z<00M:S407R/a
01hZ;`0M:Bd07RT/01`W:@0G8R@06bDV01/T:00Q;CH0930l01PR;00J8BT06B4T01/P8P0Q8bD0?T92
02<X:00O9B@05QlM01LO800P9BT06AhS02db>00J8BL05A`R01/R:00H8BP05b0W01PQ:0806B@Z01<0
5R4X01@K8@0G7R@05A`R01HM9@0L8b/07RD]01`S;@0I82X06Al[01XP;00F72P06Al[01XM;00G6bP0
3a<N01lS;P0B5ad05a`P00805a`O01h05AXN01HK8@0G6b<061dT01DJ7`0c>3`07b@Y00`A5P0G72@0
6QhY02T]>@0F6BL05aXY010C900c=TP06A`]01HJ9P0M8Bd061`X01<G8P0F6RD05a/W01`P:`0I7BP0
5QXV01PL9`0I7BP05a/V01TK9`0H6RH201LI9@0:01PJ9P0H6RL061XW02@V<`0T9S8061XV014C800B
51l04a@H010A5@8061TM00<08b@X03Hg>`0E5QX00P0D5AT301<D600601DF6P0F5a/05aPL01LH700E
5QX051DI0P0B4aL01@0?41@04Q<G01HG6`0E5QX04Q<G00804a@H0`0D5AT2010A5@0601<D600@4AD0
414E01@D600C4aH04Q8E0P0A41@00`0A4A@04a8F01<C5P0401<C5P0>01<C600E5Q/03@d?01TH4P0P
7Q00>cPW0;2_V`3YimH0^[RY0492>01LGEP06A/J01@D5`0D4QL301@B5@0C01@B4`0F51D06ALH01<B
400?3P`051<A01HE4P0H5QP03P`?018A4@0F5A803@`701`L5P1cLf`0PH5j03hm=`0G5Q806QTD018A
3`02014?4P<04Q0B00T04@l@018@4@0A3a004@l?01@B4P0D4a404A0>01@B4`0A3a800P0I5aX0400>
30l04a4D01PF6@0B41<03P`?00d;3P0E4aH08b4T01@C600C4QL08B0U01LG6P0?3A403P`?00h<3P0?
30d2010<300D014<300@30/06ADF01/I6P0=2``04@l@010>3`0?3@h040h?00h<3@0?3@h04a4B01PF
5`0J61T07ATJ00l;300C3a0040`=014=3P0;1`P2018>3`0=00h:2`091@H06QHG01HB4`0D3a805a<E
01@@4P0>2P`02`L900d92`0A30l03@T;014=3`0201<?4@0I01HB4`1dL6l0_k^j044m?00<20L040`;
01HB4@0S7ah03PX900P40`0E4A00510?00d9200A3@`03PX900l;2P0@30/03`/:00d9200B3Pd020@4
00/71P0E4A003PX901HB4@02014=300400h:2@0=2@P03PX9010<2`D03`/:00`040`<00/71`0C3`l0
3PX:01DA4@0<20P0510@00l;2`0=2@T0510@01<?3`0@30`6010<2`0300h:2@0E4A003`/:00803PX9
00<020D400l;2P0=2@P00P0@30/00`0>2PT040`;01@@3`02010<2`06018>3@0>2PT030P700T51@0A
3@`040`;0P0=2@P7010<2`<03`/:00@03@T800h:2@0B3Pd040`;0P0C3`h00`0D40l061@C01DA4002
00h:2@803`/:0P0@30/02P0>2PT04@d<00d9200=2@P04@d<00h:2@0B3Pl03PX;00`82@0>2P/2014=
3P0800d92P0/:2T05A4B01@@4@0<20T04Ph?01<?400B3Pl200d92P0301@@4@0=2@X040`=00803PX;
01005Q8C01/G600C3a004@d>018>3`0G4a@03PX;010<3@0=2@X0510A01DA4P0^:R/0510A01HB4`0<
20T03`T;0`0@2P`200l92`04018<3P0G4A<04`d?00l92`8040X<0P0>20X00`0?2@/040X<010:3004
010:3004014;3@0B30h04P`>014;3@<040X<0P0?2@/01P0>20X04@/=010:300>20X040X<014;3@@0
3`T;00h03`T=018<40070PD040T@010:400C31<08Q/S01@=500=1`/03PP<00l93@0@2Ph04@/?010:
3PD03`T=00d03@P<010;3`0;1PX03@P<010;3`0<1`/03`X>00d8300@2`l04@`@01PC5`0>2Pd04@`?
00D03PX;0P0:1PL02P0B3Pl030P9018>3`0@30d03`T=01@>4P0C3A402`D900l93@0?20l200l8400H
01094@0@21<04@TD014:500=2AD03``G00/84@0C41L040hC00X52@0?2@/04@/=00h8300B21005`dE
01@<500B2a803`X>010;3`0F4AD050lC00h93@0@2`l050lC0P0F4AD03P0A31003@P<00X52@0@30l0
71LK010;3`0`:bl0KFQ/01`G6`0B3A404@`@018=4@0C3Q803@P<5?ooool001_ooooo00H04@hI00d;
5@0H5B00P7f801hK9P0>2aH200`9500B00@1300@3AP09R<^08^8T@3RgnH0UiFK01<A5P0?3A804a0D
00H11@0@2Ph040X=00l92`0A20/040L:00d72@0A3`d04@d>0P0?2``200l:3P0Q010;4@0B2a802@8:
018;4`0C31@02P<;018=4P0E41@04`hB00h93@0?2Ph04PdA01D@500D3a<03PT=014<400G4QH03@P<
00`8200>2PT040`;01<?400F4AD05a8F01HA5`0A31803`X@010;4P0C3QD04`hB018>3@0A3@`040`;
00805A4@01X03`/:01DA400B3Pd05Q8A01LC4P0A3@`05a8C01D?4@0@30d0510A01dI6P0G5AP04Q0C
01DC5P0B4AH040lD00l>4`0?3Q@040lF01<B6P0D4a/04Q4I01HE7@0D4a/04Q0J01DC7P80518M00h0
5A@L01LE800A4Q`051PQ010F800L92l0>D5>06M`O`0V<3`07RPd01TQ;@0I82X061`U01PK8`8061/T
00d051LP01TL9@0O8R/05APQ01LJ8`0J7BH05QTR018E7P0H6b@06ahW01HI8P0E62406QdV00808RD^
00@061/T020S;00F6B804aHO0P0L7bP0500F6B8061`U01LK900G6b@06alX01XN9`0E6B806AdV01XN
9`0I7BH05a/T01HJ8`0G6b@092/e01hU;`0G7RP06b8/01LN9P0/<c/092/c0P0H7bD0200C6ah07bLZ
02D]<00D7R005b8V01/V:P0L9b/06bH[0P0I92X0:`0W<ST05b4Z02Pb>`0O:C808R`f04UCG@0S;cP0
;3U201l/=@0P;SP07R`g01l]>00F9S<06RXg02@d@`0O;ch05RHe02HfAP0T=4@09CE502<c@P0I:CH0
4R8_04YJI`0C92h08c@n020a>@0L;CD07c0g028d=00N<Bl07S0`02Li>`0W>T008C@j02PjA00P=3l0
:Se;02/nC@0M<T<0:3i<02@kA00W?TH00P0Y@4P0500W?TH09Ca402a3B`0X?dL0:d9:02Y1B@0]A4`0
:3m80357E00U>dP0;dA?0355D00Y?DP0=4M@02`nB00X>d809cU002`mA00V=ch07Rle0P0R=SL0:P0M
<380;T1409^Z/@10CeL0:3Ho034mB@0M:CH0=d=A04eIJ@0W=3l08Rle01`Y;`0I9R`06BLZ01TT:00I
92L07RT[01hX:P0G8B<05b4R01TR9@0N:380@TiJ03]5CP022A404QLK024U9`0=3`h0Bde<01<H500L
8R003Q@B01<L6@0:3a808BHZ01TN900T:c4020lE01HM8`0I8RT0624X01LP9`805b8X00/04adV01LN
9P0I82H051/Q014H800F7BD06B0X01/R;00N9Bl06b4]01TO:`0201hT<00X01TL:`0L82d06alZ0002
3@0J7bD05a`P01lT9`0I7R405AXN01HK8@0F6b804QLM01PM800=4a@041DH01HK7`0D6Ah051PQ028V
<@0G6bP05QTX01`O<01`LhH061//01PL:00I7BP05QXU01PL9`0L82/061`W01XN:@0F6RD051PS01DI
900F6RD05ATT01PJ9`0F62D04aDR014C80803a4N01406A/X018D8@0B52405ALT01LI9P0F62@06Q/O
01`M8@0/;C408b@X00h?4`0@4AD05QLK01<D600A4QH04Q<G01<D600801@E6@0;01<D600@4AD051DI
01TJ7P0H6Ad04a@H010A5@0A4QH05QLK01@E6@0C51P00P0?41@02P0C51P03PlC00h?4`0D5AP04a<E
010@4P0?3a404A4C01@D5P0F5QP501DE5`0Q014A5P0F5a`04A4C01hM5P0P7`d0?S`W0:n]U03oonX0
VIR404a<@00=3PT04aDD01LG6P0D4QL04a4D018@4`0D4QD05A<D018@4@0>30d05A@B01LF500D4a40
4A0=00h<3@0I5aP02`X7020O6`0F5A00?clf0>[Zh03oooH0N7Q`00806QTD00L051<?00d;300?3@h0
4Q0A01@B4`0C4A804@l@00<05A<D00H04a4B014?400@3Pl03@/>02DS9P0W9BP200l=400?00d;3P0@
3Q403`d@018@4`0A3a803`d@01HD5`0M72403PdB00l>4`0?3a404A0C00D3100?3@h040d=00804Ph=
04@050l>01@@3`0:1PL0:RPY00h<3@050`@04Q0A01DC500D4Q<040h?00`:2`0=2``03`d>00h<3@0;
1`P03`/<00`82@0O6a`040`=01<?400=2@X04Ph?010<3@0;1`P061@E00d92P0D41401@42010<3@0B
3Pl0510A01<?400@30d02PH701PD5@0R7Ql04Ph?00T51P0J5QD0:RHU01DA400@30/03PX9010<2`0@
30`05Q8A01LC4P0;1`H06aLF00l;2P0>2PT03@T800h:2@0B3Pd04`l>018>3@0?2`X02PH500`81`0C
3`h020@302`X9`0A3@`040`;00d9200<20L03`/:010<2`D03`/:00T04`l>010<2`0A3@`04Ph=00X6
1@0G4a801`<200d9200B3Pd00P0>2PT0300A3@`040`;010<2`0C3`h04@d<00`81`0=2@P030P701TE
500300005Q8A01LC4P803`/:01P04@d<010<2`0=2@P030P7014=300@30/03@T800l;2P050@005a<B
01<?3P0D40l06ADD00T5100=2@P07ATH00l;2P0A3@`040`;00h:2@0=2@P03PX9014=300=2@P200l;
2P0900d9200?2`X04@d<00d9200@30/03@T800`81`0?2`X02PH500803PX90P0?2`X2010<2`0900/7
1P0A3@`03@T800d9200A3@`02`L600/7200<20T03`/<00804@d>01l03@T:00l;300D41402`L800H2
0`0@30d04@d>08^7R00g<c@040`=00d92P0<20T040`=00H20`0A3@h01`<400X61`0H51D03@T:00H2
0`0?2``040`=01DA4P0>2P/040`=00D10P0H51D02`L8014=3P0=2@X03PX;00803PP:0P0?2@/01P0>
20X03@L901<=3`0I4aD050h@00l92`8040X<0P0>20X0100?2@/040X<010:300@2P`300h82P0300l9
2`0A2`d04@/=00804@/=0P0@2P`300l92`0500/51`0<1PP04@/=00l92`0=1`T0100?2@/03P0?2@d0
4@/?00H0100L5A`0<b`c01XC6P0H4AT04``C00d72`0>20`03`T=010:3P0A2`l040X>1@0?2@d03@0;
1PX04`hB01D@500C3Q8040/?00`72`0B3A400`0201PC5`0V8BD0S8N;020K7`0?2`d01@0>2P/0300=
2@X061@E018>3`0:1PL03PX;00T61P0>20`03`T=00/52@0C3A403`T=00h73P803`P@01H040TA0108
4`0A2A@04@XD00L13`0=2QD04PlH01<@5`081P/03@P<00d72@0>20X03`T=01P>5P0O5Ad04`XB0109
400<1`/03@P<018=4@0@2`l020<7100>2@d2010;3`0900h93@0:1PT04`hB00T42014?d<0[jZ^02LR
9P0>2@d050lC00802`H:00<081/Oooooooooool04_ooool001_ooooo00P03@XC00h;500>2a@08AhW
01LD7@0>2a@04a0I014>5`8040dF02H04a0I01HC701GE5/0@3i401TG700;2@h03`/@014<400C3A40
40X=00d72@0@1`X04`X=01<=3`0O7Ql0GE]L01TG600>30d06QDI00/62P0>20`02P@801hG7P0>10`0
3`D=01H?5P0F4AD02`H:01dH700A310071LK00H11@0A31003`X>00h93@0@2`l04PdA01<>4P<04Ph?
01404PdA01<>4P0C3Q803`X>00h93`0D3aD05a8H01HA5`0C3a40510?00P40`0E4A001@4000l;2P0B
3Pd030P700h:2@0201@@3`0>014=300C3Pl050h@014=3P0F4Q<06ADF01@B5@0B41<05A<F01<B5`0?
3Q<051<H01LF700D4aX501<B6P8061LO01L0>cY205MFGP0F5A/02@P@01/L900=4QP06R0Y01<K9P1^
MX40g>Kb09jW]P15Ce/0:30l02he?`0H7bL03Q8K01PJ9P072AD061XV018D800L7RX0418N018D8002
014C7`804aDQ00@051HQ01@G800D5ah05QTP0`0G6R40>00H6b805aXQ01LJ8@0I72<06QdT01TL8`0G
72806QlU01TN900J7bD07B8X01PM8`0F6b406AhT01`Q9`0E6R00724W01XN9`0E72H072<]01TP:P0D
6b<06b8Z02/b>00E72805ahT01LO8P0F7R405alR01/S9P0M9bT06R@V01dW:@0L9RP05b0T01TR9`0T
;C8082T_01/T:`0J8bX07BH]020Y<P1DGVL092lh01PU;@0R;cP0938k01/Y<P0M:cH08S<m01TZ=00K
:cP08c=001l_?00M;C`07bln0P0U=D@201l_?00301XZ=`0N;cT08C8l00808c@n01008S<j02Tk?00b
A4@09SPh020b=00W>T009STo02<e?`0Q=D009c]602/nC00Q=dD0738o02TmA`0V>T<08cM00P0hC5D0
400R=Sl0;d=<02e1BP0]@DX0:3a501``>@0U>D<0:Ce802/oBP0]@DX0:Si702PjA00U=d4093Ln02Tj
@P0[>d<202@b>`0@02@f>`0O<C<07Bla01l_<`0U=3T0:3Ln02Le?@0S<3T08blk02<^>`0T;C`08b`m
028]>00[>3h08c4d01PT:0806RDY01807bT[01hX:P0O9bT08RX/020X:P0H8B@072H`03I2CP1[M7h0
5QdU010E6@0J7Al06Q`K01XL6@0J7QX06R0L01dS7`0P9R<201/P8`1?01XO8`0G7b80620S01hU:`0I
8RT05QlV03U2B`002Q<06bD^01TS;00J8BT041LM01<J800I82P04QTQ01HM9@0N9Bl06R4[01TO:`0N
930082Hb01PN:P0M82l07B4^01hR;@0E6B@04AHL01LL800B5aX06b0S01/P900O92X04aPO01DJ800E
6Qd04ALG01PM800;41@03a@I00T=5P0M8B`07b8`010C8P0H6b`06A`^03LjB`1AEF007B4Z01@H8@0E
6B807R8[00dA6P0N8R/0720Y014E7P0G6b@04aLP01DI8P0?4Ad071hZ010B7P0A4al05QPT00T;5`0D
5R806A/W00/=6@0?4Ad0O7j:03Hi@P0m?T<02``@034b=P1LGF404Q<G01@E6@0C51P03a0D01XK7`02
01@E6@0:010A5@0C51P020T=02TZ;P092Ph06Q/O018C5`0G61`05AHJ01@E6@<04a@H0P0B4aL04P0E
5QX04Q<G00d>4P0?41@05QLK01/L800E5QX0414E01PI7@0M7R4061PJ01HF600C4aD04Q8D01@D5P0B
4Q@0410B018B50<04a<E02D04A4F018C600D51H04Q4:01XI1`0V90l0AdD/07ekI01AD3`0?d0d01dN
6@0<3Pd061PK00X83@0F51L04a4D00l=400L6Q/04Q0A01@B4`0?3P`03@`:00h=2`0B4@h03`d>014?
400B4@h04Q4=01/J5@0c<bX0Xj>I0=[JcP1GEdd03@d501PH400?3PT04Q4?00804Q0A00<04@l@010>
3`0@3Pl00P0I5aP03@0D4Q<03P`=01TG600@3Q003@/>010>4@0D4QD05A<F01<A500>30l04@lB00P6
2@0>30l00P0A3a804@0[:B`06ATK00/;3@0=3@l01@D7024P8@0;2@X030X;014>3@0C3`h061@A00h9
1P0@30/061@E014?400I5aP04Q0A008030X;00T03@/<00h<3@0100006QPI00h<3@040P<04`l@014=
3P0@30d00P0B3Pl00`0?2``04`l@018>3`02014=3P03018>3`0C3a004Ph?0080510A01/04`l@01@@
4@0E4A804Ph?01XF5`0G4a@07a/L00H20`0C3a005a<B00/71P0810<040`;018>3@0=2@P03PX900d9
200B3Pd03`/:01<?3P0>2PT030P700l;2P0>2PT030P700D1000C3`h00P0A3@`2010<2`803`/:0P0>
2PT0300?2`X040`;014=300F4Q402PH500<0000M6AP02PH501XF5@0:1PD030P700l;2P80510?0140
4@d<00h:2@0B3Pd0510?00d920070`802PH500d9200<20L03@T800l;2P0A3@`04Ph=014=300@30/0
3`/:00h:2@0200l;2P0901@@3`0C3`h03`/:014=300D40l02PL600/71P0B3Pd03PX900805A4@0100
3PX901`H5`0F4Q404Ph=014=300?2`X04`l>010<2`0810<040`;00d9200<20L03@T8010<2`0?2`X0
3PX90P0@30/00`0?2`X03@T800h:2@0200l;2P0@010<2`0A3@`03PX901<?3P0A3@`06ADD00<0000G
4a804@d<00l;2P0>2PT03`/:00d920091@@03@T:00h:2`@040`=01@030P900l;300B3Pl04Ph?00l;
300<20T0;BTZ01lK700?2``02@D600`82@0A3@h03`/<018>3`0>2P/03@T:010<3@0<20T02`L800d9
2P<03`/<00P03PX;01@@4@0<20T03PX;018>3`0?2``03PX;00d72@804P`>0P0>20X03P0?2@/04@/=
01XD5P0F41802P@600h82P0E3a403@L900l92`0=1`T04P`>01<=3`0<1PP04P`>0P0@2P`300l92`06
01<?400=2@X02`L800l;300B3Pl04`l@0`0@30d00`0=2@X02`L800d92P03010<3@0?00d92P0;1PX0
3PT=00T4200?2Q007aXP00P32@0500L04@/B018<400?2@d02`D9014;3`0H4QH02PD800802`D90240
3PP<00d72`0>20`040X>014<400@2`l02@@800`72`0@2`l02`H:01@?4`0@2`l06QDI08n:SP0F4AD0
3@P;00l;300<20T02PH700/7200>2P/05A4B00P41@0F4Q<01P8301lK700<2@T05@lC01@>4P0@2Ph0
3PP<00l93@0B2a800P0C31@04P0B2a<04@TD01084`0?218040XH02dZ=@1FDe`0L6ed01LE6P0C3Q80
1P0201PB500?2@d05@/C00l53@0<10`03PL>00d830803PT=0P0?2Ph01P0;1PX020<7014<400F4AD0
3`X>00L21P803PT=0P0<1`/0200E41@07aXN01PC5`0F4AD04`hB018=4@0A310040/?5?ooool001_o
oooo02H03@XB02LT:`0l>Cl05A8J010=500?3A<040dE00h<4`0=2a403@XB010=500B3aH061DL01HC
6@0<2Pl02`T>014>4P0A31004@/?014;3P0?2@/04PT<01<:3@0A2`d03@/;01PF5`050`@04@h?00h:
300;1`T040/>01TC5P0=1`X040P<01/C6@0=1`/040`?03`g>`804@`@00<02`H:01HA5@0@2`l00P0?
2Ph0100A31004PdA01<>4P0B3Q02018=4005014<400@2`l040/?01<>4P0?2Pl00P0C3Q<01@0?2Pl0
3@T;014=300G4a804@d<008061@C01@04Ph=01<?3P0A3@`04@d<01<?3P0D40l05Q4A01@>400B3Pl0
5a<D01/G600F51L0518E01LE600D4aP040lD01@C600E51X051<J01<B6P@04a8I01l051<I014@5P0I
61d06APN01LG6P0G5Q/0418G024V:`0_=C/0@daD09bT[P3Wl?D0WjRf03<mB@0k@dl0FV5[01`R;00E
6B8071hZ01XL:@0@4Ql06adY028T<00V:3@05ALT01@F8P0E5b<06Q`X01/M:P0H6RH05QTR00805aXQ
00@051LN01<F7@0F6B0061/R0P0G6R40900I72<06QdT01TL8`0D6Ah05AXO01HK800K82D082DZ01TN
8`0O92T06AhS01hS:00J7b@07R<X01DJ800C6R806R4Z01`S;00J8BT06b8Y01lV;00I8BD06R8V01TQ
900G7b80620S01/S9@0M9bP06B<S01hX:@0O:B/06R@U01LQ900L9BT072DZ01`U:`807BH/03807RL]
01lY<@0I9B`08c0h020]=@0S<3T05B</01l]=`0G:3804b@^02<c?`0Y>DH08C4n02HfA00T=4809CE3
028b@00T=440:CU6024a?P0S<cl093A002<d?`0Q<Cd07c0i02@f>P0W>C`0:3Xm02Pj?P0V>Cl09CPn
02Pj@P0K;cL09CU302PlA`0P=T809C]702LjA00Y?4D0:3]402/nB00/?dT0:3]402TlA@0Q=3h093M0
02XmA`0[?TP0:Ce602PlA080:Ce508@09SY202Dg@00X>T809SQ002Hf?P0X=cl09cDn02Tg@00V=Sd0
7Blb01d^<`0P;cD093<i02Le?@0U<S/07b`e020[=P0X<Sh09c4n01lX=P0H8R/082`a01`X;00H92L0
9c8e02D_<@0L9RP06b@V01`T9P0O9RP08BPY01`T9P0H8BT03ALQ01TR:`0N8bP051TL01@E5P0J6aP0
6AXH01TK600F6aP05AXG01@J600E6a/05A/L01DJ7P0C6ah05AdP01XQ9`0C72<07BH]03m8D@0K9Bl0
7BL`01HP:P0M92`061lU01XQ9`0I82P04QTQ01LN9P0a>4809B`f01TO:`0H7RX06Al[01lU<@0_<T40
5aXX01/O:P0A5B00724W01<H700C61/06AhQ010E6@0D6Al051TP01PM8`0?51L06AlP01PM800G7200
3Q<H01<H7P0A5Ah08RHa00X>6`0H6bT030lO01hQ<00J7RT04QHO01LK900M8BX06QhW01LK900F6R<0
61`U01<G800J7RL05QXS01LK900N8BX04A<M01LJ8P0B5Ah0828]018E7@0E5b4061XU010C6`0M82T0
JFaf04a?E`0F5a/071dQ01@E6@0E5QX07AhR00l@500B4aL06AXN010A5@0C51P04Q<G01DF6P0c=3P0
4a@H00/<400K720201DF6P<04A8F02h04a@H01DF6P0F5a/04a@H014B5P0D5AT04Q<G00h?4`0@4AD0
4a@H01DF6P0C51P04A8F01DF6P0G61/051@E018B4`0A4A804Q8C01@D5@0G5aP05ADF01<C500D51D0
5ADF01@D5@0C4aL051DI01DE5`0D4Pd04a4401HC0P0J5`<0<BhL01/J2P0L6a<0414<00h@3`0E5AP0
6ALL03@b=@0U8bH02`T<01PF5`0C4A804Q0A0`0C4Q005P0D4a004a4B01DC500D4a004A0<018A300F
5Pd0820G03Ph;@0K6a405QH>00`<1@0H5a<04Q4=018A3P0B41004A0?014?3`0@3Pl04Q0A01DC500A
3a4200d;3@0301@B5P0@3Q403`d@00803`d@02P040hA018@4`0F51L04a4D014?4P0?3A0040hA01TG
6P0B4Q@04A4C010@4@0A4A808B0Q01LE5@0G5Q@040h<00`81P0D40d03`/801<?300@30d05A<D00l=
3P0A3a003@/<01@B4`0B41403P`=014?400:20T03`d>00d;300@30d03`/<010<3@0A3@h04Ph?010<
3@0C3a004Ph?0P0A3@h00`0B3Pl04`l@00d92@02010<300400l;2`0A3@d04Ph>010<30803`/;00T0
5A4A07=_K`0F4Q8030P701TE500@30/02`L6014=300C3`h00P0@30/02`0D40l040`;01<?3P0;1`H0
510?00l;2P091@@04`l>00d9200?2`X040`;00<03`/:1@0>2PT0300?2`X040`;01DA400?30/081`K
01HC4P0:1PD071PG01LC4P0F4Q004@d;00l;2@8040`:00T04`l=00h:200:1P@06ADC028N700H5180
3@T800l;2P0@30/00`0?2`X00`0@30/03`/:00h:2@0200h:2@803`/:01@06QHE01HB4P0=2@P040`;
01<?3P0>2PT02`L600h:2P0L61L02@H500l;2`0A3@`03PX900l;2P0A3@`03`/:018>3@0H51<03`/:
00d9208030P700@040`;018>3@0A3@`03`/:0P0@30/00`0?2`X040`;010<2`04010<2`0601<?3P0<
20L03@T801`H5`0d<2l040`<0P0?2`X01P0B3Pd0510?01DA400C3`h03@T:00l;30<040`=00<03`/<
010<3@0@30d00P0>2P/2010<3@0>00`82@0?2``04Ph?014=3P0?2``03@T:00h:2`0A3@h030P900d9
2P0B3Pl03`/<014=3P0?2``200d92P0Q010<3@0C3a004@d>00`82@0B3Pl04`l@00`82@0:1PL04@/=
01<=3`0B30h040X<014;3@0B30h03`T;00d72@0?2@/04P`>010:300=1`T03PP:00l92`0;1@L03PP:
018<3P0@2P`04@/=00/51`0:10H04P`>01hH6P0T7R004Ph?00804@h?01L040d>00h;300>2``03@X;
010=3P0C41404Pl@00l<3@0>2``03``=018?400C41404@h?00h:3P0>2`h04`lC00l;4@0:1``05A4G
01<?5P0?2Q003`T=00X4200300l93@0:010:3P0=1`/03PP<018<400>20`03@L;014;3`0?2Ph040/?
01@?4`803`X>00L03PT=00T4200A31004@d@00H21@0=2@`03`/=00803`/<00l04Ph?01DA4P0I5AH0
4`l@00X61`0<2@T05A4B00T51P0@30d04P`@014;3`0?2@d03PP<00l93@0B2a800P0?21004P0@2A40
4@TD018:5@0C31H0?3I403llA`0V8b`08b0W00X83@0>2Pd0<B/]038/;P0@2Ph04@L?01063P0F3AD0
40T@00l:3P8040/?0P0A31002@0@2`l04@`@01D@500B3A403@P<010;3`0>2@d04@`@010;3`0200d8
300400l:3P0C3Q804PdA010;3`<03`X>5?ooool001_ooooo02L01P@900h<400K6A`00@0400L52@04
0PD03@/@00d;3`0;2@`030X?00d;3`0>314040dD01<@5P0B41D040hC00h:3`0:1@T03`T=010:3@0A
2`d04`X=0189300?2@/03``=00/7200D41403`/<00P41@0L61T03`/<01dG6@0D3Q003`T;01LA4`0>
20X09b8V0<:m`@12?D400P0D3a<01@0E41@040/?010;3`0@2`l04@`@00<04PdA02@04@`@010;3`0?
2Ph03PT=00d8300B3A403PT=014<400B3A404@`@01LC500:1PD06ADF01DA4@0F4Q404`l@01<?3`0?
2`X04@d>01DA4@0D40l03`/<00h92P0?2@/03PX;01<?400F4Q<04a4D018@4`0E4aH04a8G014@5@0E
51T05QDK01<B600B4AL201<B600J01<B5`0D4aP040lD00l?4@0>3Q0051@D00D51@0<30`0:2PY01hR
9@0I7B405A`R02D^=@1YLg`0AU1J01dW<@0?5b4061`W01TM9P0J7BH0418O02X/>@0N82d0008?04i@
G@1ADf0201`N:`0501XL:@0E5b@05ALT01PJ9P0H6b@00P0I72<201<F7@0701XM900H6b805aXQ01HI
800H6b806A`S01LJ800201`Q9@0801/P900T:Bd0:Rlc024V:P0O92P051TM01HK7`0@5AT201DJ7P07
01HM8`0H7bL06R4Y01/R:P0I82H05A`R01PP8`0201TQ900Q01LO8@0H82806b<U02@^;@0H8R405R0O
01XT9@0N:2T08bd^01/U9`0K9BP072DZ01dV:`0N9b`07bP]01hY;`0V<ST0;3U101h[<`0/>T808S0i
02<a>P0P<C/06BXd01X[=@0L;3T06RXg01h^>`0Q<Ch093A102De@P0`@4d0?4aI00<093A100/08c=0
024a?P0P<C/0:S]201`]=00V=ch09SLo01T/<P0J;C<08SDl020d>`02028f?@0501lf?00P=cd0:C]5
02TkA@0]?dT00P0W>D<00`0`@T`0?U1J02i0BP0202PjA00402doB@0Q=3d093Po02@h?`<09CPo00/0
;3i602/lA00U<c`09C<l02<a>P0Q;cP08S0i01l`=`0R<3T08S4h024`=`0202@a>P0<01l/=@0N:380
7BLa01hX<P0N9S<06B<[018M8@0I92P08B`_020[;@0S;Bl07BHX0P0G7b402@0I82406R0P01TP8@0B
6b009c8h01/S:@0A5QT041@E01/M700201LG5@0j01LI5P0E6AP051PI018H600@5QH04ALG01<H6`0A
6A`04QXM01LN900M9Rd04a`S00`E7P0G8B/0628/01HP:`0K8RX06b8X01hU:`0H7bL04QTQ01XQ:@0_
=T008bXd01PN:P0G7BT05Q`X028X=00P8c805APV01HJ9@0S9c8061dS00dB5P0I7R4041DH01/P900H
7B<0=S]20:jc^@0f>cl01PX>01<H700Q9RX082DZ01LL8P0N8R/0ADUC00dA700J7RT061`X00/?6`0A
5Ah06QhW014E7P0H72D03Q8K01/O:0806QhW02<04aLP01XN9`0F6R<05a`R01TL8`0E61h061/P020S
:@0B5A`04QDJ010C6@0O8RT082<X01`O9@0E61l04QDJ00l@500E5QX071dQ02DV:P0A4QH06AXN01@E
6@0000@07AhR010A5@0S92P08R<W0493A`0K720051DI01PI7@0720`0414E018C5`0201<D600901HG
6`0H6Ad06AXN01<D600A4QH051DI018C5`0?41@04Q<G0080414E00D04A8F01<D600C51P04a@F01<C
4`03018B4P0501<C4`0F5QH04a<C00h>3P0@41000P0C4a<0500?41<030dA00d=3`0E4a805a@?01PC
3@0J5P`07QXA01TF3`0E51003`l=014C400C4a@040hC01PF6@0D4QD03`d@01DC500B41404a4B0`0B
4@l03@0B4@h04a4B01<A500D4a805aHB01DD3`0=3@H05QH>024Q5`0I6A0040l:00l>2@0C4Ph00P0A
40`3014@3P0a014?400@3Pl04Q0A00h<3`0E4aH06ALJ04I4B@0@3Q403`d@00h<3`0?3A0040hA01<A
500@3Q40518E014?4P0@3Q405Q@G00l=400@41805aLH00d=3@0?3`l030`;00/:200B4@l04Pl=01PD
4@0U8Ah061<@00h:1`0<20L01@<401@B4`0d<S<05A<D01TG600>30d02@L801@B4`0C4A804@l@00L5
1P0B3Pl04@d>01<?400E4A805a<D01DA4P02018>3`8040`=0P0B3Pl07P0>2PT04@d<018>3@0B3Pd0
510?01HB4@0810<0510?01LC4P0L61L02`L601<?3P0H51<01P8101XF5@0T81l0CDU801@@3`0<20L0
3`/:018>3@0A3@`05A4@00/71P0?2`X0:2@S01HB4@0<20L040`;01`H5`<03`/:00@03PX900d9200=
2@P03PX90`0=2@P200h:2@0:010<2`11?C`071PG01@@3`0C3`h06ADC02@P7@0I5A8040`900d91P80
3PX700H040`901DA3P0G4a004`l<00l;200?2`T2010<2`0400l;2P0>2PT03PX900h:2@<03@T80240
3PX900l;2P091PD08AdL09VEU010?3/061@C01@@3`0A3@`03@T800`8200F4Q401P81014=300=2@P0
30P7014=300D40l04@d<018>3@0?2`X03PX900d9200F4Q405A4@01XF5@0E4A004`l>010<2`0?2`X0
40`;00l;2P0>2PT00P0=2@P00`0<20L02`L600/71P0200`81`0700X61@0D40l0?CTh01LC4P0?2`X0
3PX900l;2P02014=300300h:2@0>2P/03`/<00<040`=00<03PX;010<3@0?2``00P0>2P/0200?2``0
40`=00h:2`0=2@X030P900d92P0?2``040`=0P0H51D01P0?2``03@T:00l;300<20T04Ph?010<3@80
3PX;01L040`=01<?400C3a0040`=01DA4P0D41403@T:00`82@0B30h040X<00l92`0@2P`04@/=01<=
3`0B30h07ALI01TC5@0;1@L02P@6010:300A2`d04P`>00l92`0200/51`0@00`6200A2`d04P`>018<
3P0A2`d03PP:00/7200:1`P03P`=00l=3P0>30d040h?014?400Z:2T071XK018@4@802`T:00l030X;
00d;300A3a00518C018@4@0?3A0030X=00<110071@X04Q0E00H42@081@`091lU01H@50080PH00P0D
3Q801@0500<04@/?00`62P0<1PX03`T=00803@L;00d02PH9018=4@0F4AD01`<600`72`0C3Q804PdA
01TD600H4aL02PH902<N8P0C3Q802`L900803`/<00H03PX;00l;300A3@h00`0000`82@0?2``200P4
1@0300`82@0>20`03@L;00803@L;01H03PP<014:4@0<1@d03@H>00l8400A2A@04PXE01<<5`0:1180
:2D`02dZ<`081@`01@<800d8300[9BL0;RPZ018<400E2a<03P@<01494@0>1`h03@P<0P0>2@d200l:
3P0800X52@0=20`04@`@00h93@0:1@T040/?00X52@0=20`200l:3P0400h93@0=20`04@`@014<4080
40/?00<04@`@018=4Oooool04oooool001_ooooo00H02@L900l=3P0:20T04Q0B00h<3@0D4Q<200h<
3P0>00h<3@0=2`d03@/=00d;3P0>31402`T?00/93P0<2Pl03@T>014<400@2Ph040X=014;3@0C2Pd2
01893005014;3`0?2@/050h@014<3@091@H00P0B3Pl03`0G4a80;b/Z018>3@0<20L06aLG018=400W
8RH050lC018=4@0@2`l04PhA010;3`0A31004PdA01<>4P02018=4@08018=4`0A31804@`B010;4@0?
2Ph03PT=01HA5@0A310201<>4P0E014=3P0C3a40510B01<>4P0N6Qd05Q8D01<>4P0B3A0040/>010;
3`0D3a805Q4D01D@500C3Q004`d?01@@4@0F4Q<061@E01HD5`0C4A@04Q0C00804Q4F00<05aHK01PG
7@0D4aT00P0B4AH03`0C4aH051@F01DE5`0E5AH06QXI00/;2P0F5Q<05aLC024R7P0h>CH061/I010D
5@0G7B0051dQ01XS:P0201XS;00B01DL9@0@51h061/S01/K900F62D08bDd01DG9@0P8S40=3I503/m
C00@4R405QPW01/M;00G6BP06ad/030b@00G6R405aXO0P0H6b001@0I72407b8W01PK800G6Ql05QTN
008061/P01@05QTN01/P900L8B@0724T01lT9`0R9bX06b0S01TN8@0O92L0;C8e028W:P0K82<07R<W
01`S:@0H7bL05QdU01LN900H7bD05alR01@L7`805alQ00/05QhP01TQ8`0L92D07bPV01TR800J8b80
6b@S01PQ8@0J8R@08b/]020X:P0201`T9`0E01lW:P0R:bl07BL^020/<P0N:c407R/c028`>00H9bh0
82hg01TZ<P0S=3`0>4UC03E6D00Y>T@07c0j020a>`0Q<S`072`i01h^>`0U=D808S8o00808c=002X0
93A302DeA00U=D<0<dA@020a?00X>D80:CY4024d?00U>3l08cHl02]0A@0S>3`093Tm02@l?`0K<cH0
9cY2028d?P0Y>dD0:Sa602Hh@P0/?TP0:ce702Dg@@0X>T@0:Sa602doB@0Q=3/08C@j02<f?00U>3h0
9cY002Tj@@0X>D008C8j024_>00V<c`08Bhg01dZ<`0O;CL09C<m02Le@00T<S`2020]=P0H020[=@0U
;cP0:C<l02</=@0J8b/07BH`04E?E@0]>3`04ahP01dW:@0G8B<06bDV01`U9P0L92H07R@T01`R8P0I
7al061lP01<M7P0?6A/05AhO01PM700J7Q`06AXH0P0I6AL0E@0I6QX05aXK01LK7@0G6al04aTI01DK
6`0G7Ad05AdO01DM800H7bD05b0W01`U;00I8B/07BLc01LQ;@0K9C005ahV01TP9P0J8BL05ahV01@K
8`0K8RX06R4[01TP:P0F72P06Al[01dS;`0I7b/05QTX01HI9`0M8B`0HfMb03XoA@0D6Ad04AHI01PM
8@0J7b<04aPN02L[<`1lP8T0JFid01PM8`0[<3H061dS01DJ80083A<05a`R01LL8`0>4aX06alX00dA
6P0S9bl03a@K01LL8P0?51X061dS01DJ800H7B<09BX`01lT:P0B5ad05Q/Q01<H7P0G72405QTM01XM
8@0G6ah0F5aO01TL800@51L05ATM01@G6`0?4aH041@H00lB5P0I7B004a@H02DV:P092Ph0@45501<D
600E5QX0:BX^08Z;S`0W:2`00`0B4aL00`0L7B4061TM0452AP0201XK7`0301DF6P0D5AT04a@H0080
4A8F0P0B4aL0400D5AT04A8F01@E6@0B4aL04A8F01@E6@0B4aL04A8F01@E6@0E5QX04a@H01HF600I
6AT061PH01LG5`0E5AD201@D500C018B4P0@41004A4A01DE5@0F5QH06a/M01HG6`0C4QL05Q<H01<>
4P0E3a<06aDH01D?4P0I5AH04a8B01LG5@0B510051@D018@5@02018@4`0D01<A500E4a@05A<D01<A
4P0A40h04a8@01HE4`0L6aP04@lB00l=4@0?3@l04a8?01@C3P0?3`T03`l801<C2`0E50h04A0<00l>
2P0G5Q@3014@30804A0>01@04Q0A010>3`0D4Q<04@lB014?500@3Q<0;2X_00l=400A3a805A<F01HD
5`0D4QD04@lB00h<3`0D4QD04a4D010>4@0F51L03P`?00P820803`l?01X0410@018A400D4a403@`8
00l=2@0F4Pl08b0K01PD400B3P/04@d<02@R8`0C4A807A/L01@B4`0>30d04a4B02LU9P0;2@X05A<D
00P61`0F51D040`=00l;300@30d04Ph?01<?40804Ph?00H04@d>010<3@0@30d04@d>018>3`0@30/2
01<?3P08018>3@0D40l05A4@014>3@0B3Pd02`L603@`;`0<20L2010<2`0A018>3@0E4A00E51?04]7
AP0=2@P03`/:018>3@0@30/03`/:01@@3`070`8040`;00d:2@0;1`L09b<R01XF5@0;1`L00P0A3@`2
010<2`803`/:00d040`;00l;2P0>2PT03PX900l;2P0A3@`05a<B02@P7`0L61L08alN00h:2@0B3P`0
40`900803PX700T04@d:018>2`0@30T040`9018>2`0?2`P02`L400`81@0?2`T00P0>2PT0100?2`X0
40`;010<2`0?2`X200h:2@803`/:02004@d<01DA40060`80;b/Z01HB4P0@30/04@d<01`H5`050@00
8QhM04]7AP0E4A003@T800l;2P0=2@P04@d<018>3@0>2PT03@T800/71P0C3`h03PX901HB4@0A3@d0
4@d<01LC4P0D40l03`/:00d9200>2PT03@T8014=308040`;0P0?2`X03P0>2PT01P<201XF5@0Q7A`0
6ADD00H20@0?2`X03PX900d9200?2`X04@d<018>3@0@30/03`/<0`0@30d0100?2``03PX;00d92P0?
2``2018>3`0500l;300=2@X04@d>00l;300=2@X00P0<20T00`0=2@X030P900l;300200/7200300l;
300<20T040`=00<04@d>00@040`=00h:2`0A3@h03@T:0P0?2``01@0<20T03`/<014;3@0>20X03@L9
00<040X<00H03PP:018<3P0B30h03`T;014;3@0D3Q02014;3@0;01@>400C3@l040X<010:300=1`T0
4@/=01@>400E3a404@/=00h:2`0>2``00P0;2@X01@0<2P/03P`=00l=3P0A3a0030X;00802PP902P0
3P`=00d;300<2P/03P`=014?400@3Pl03`d@00d;3P0B41<04@lD00T7300A3a@04a0G01`G7@0;1PT0
3PP<00l93@0J51P02`D901PB5P0D3Q803`T=00h8300=1`/04@/?02LR9P0G4QH01`<601dH700D3a<0
2@@8010;3`1aK70091lS00d9300B3A4050lC01@@4P0>2P/03@T:0`0<20T01P0D414040`=010<3@0A
3@h0Ddm@01<?40803@L;0`0>20`0100@2A003`P@01094@0@2A4201084`0?01094`0H4R002`PC00h;
500=2Q4061HK00/62P0;1PL0618D010:3P0E2a<02`4901H>5P0?20l03PT=00803`X>0P0@2`l0300A
31003`X>018=4@0B3A4030L;00d8300B3A403`X>00`72`0>2@d04@`@018=4@803PT=0P0=20`00`0?
2Ph040/?ooooo`0Cooooo`006oooool0100<2`T03Pd;018A3`0>3@/200l>30<03Pd;02<03@`:00`;
2@0;2@X04Q0E00h<4P0A3a@040hC00/7300>2@d04P`@010:3@0>20X04@P;01<:3@0D2`h05@`A0148
2`0C2Pd05Q0B010:300F41804@d<014@3P0O7Q`04A0>010?2`0E51803PX<018=4@0<1`/04`hB00h9
3@03008040/?018=4@0201<>4P804PdA0`0B3A<05P0A31804@`@014<400G4QH040/?014<400A3@h0
40`=01<?4@0Q72804@`B07A_M@0i=3X06A@J01LB600C3Q@04@`B018=4`0E41H05Q4G01D?4P0C3@l3
01@@4@804Q0C03805A<F01@C600B4AH05A@I01DD6P0B4AH04A4C018B500C4aD051@D01DE5@0H61H0
6a`G01PI500D5@l05aP@01PI4`0D5A005aTF01@G5@0:3a8041PK01TP9P0=51`04aXR01TM9P0F6B80
5ADM00l?600G6BH02``N01dN<00>3b40;c1202d^@00F5bT061T[01LH:P0B4bD04a@V01/L;00H6b80
5APM01@G700J7B8071lT01XM8P0I72405aXO01HI7P805aXO00H05APM01<H6`0H7Qh06AlO01HL700I
7al301LM7@0_02D[:`0J82004QPH01LL7`0K8RP06R4W01LN900F7B<0620T01XR9@0I8B@06R8U01PP
8P0F7R005QlO01PQ800F7a`06B8O01dV8`0L9B807BHT02H_;P0O9bT07BDW01`T9P0L92L082P[024[
;@0M9Rd08Rhd02@a=`0hAD/08c4g01`[<P0Y=d006b`d024b>P0/?DL0834k01<T;P0M;SP06R/e01d^
>00N;cT07bll02@d@@0Q<Ch00P0Q<D004@0S<d8093A302DeA00U=D@07bln028b?`0S=3l08S@n02Lj
@@0aA4X0734d01ld=@0Y?ch09clo02Hn@00W>T809SQ20080:3Y400@09CM102@f@00V>4809CM10P0Y
>dD0:`0S=Cl08C@k020c=`0R=CT09CLl02@e?00S=3/07Rhf01/Y<P0N;3D08c0i01h[=00M:S<07R/g
020^>`0T<Sl08c0k01dY=@0M:S<07BTb028/=@0Z<c`092dd01TR9`0J8bX0;3Hj018M7`0@6Q`06bDW
01LQ8`0M9BL04a/M01XR900O9BD07R@S01TO7@0H81h07RPW01<M700K92806QhM00lD400I6AH00P0E
5A<0500H61T07AhR02@U:P0Y;3406AlO01XP7P0L8R80620R01LO8@0I82H07RL^01/T:`0K8bh08R`h
02La?@0D7B/06B0X01TP9P0H7bD05ahV0P0H7bL07P0>5Al05ahX01DK9`0P9S80=3Y602H/>00Q93<0
720]00lC7P0P92l05a`R02<X;00A5QT06QlR00P=4@0=4QP06AhU01lS;00X;3D05a/T01<G800?4a`0
5a/S01XO9@0B5ad07B8X010E6@0<4AL07B8W018G7@805Q/Q02d05a`R01<H7P0H7B<0314G01hS:@0J
7bD03a@J01HK8@0D6Al06AhR01<G6P0H71d020`=01<G60072``06AdN01@H6@0F6Q/04ADF00hB4`0F
6Q/01@T:020Q9@0000@07QlS00d>4P0J6al020T=01lP901nOh<05AHJ01lP900C51P02P/?01dN8P0_
<3@0][Nk038c=`0000@06a`P01PI7@0F5a/05AHJ01@E6@0C51P00P0D5AT01P0A4QH04a@H018C5`0B
4aL051DI01<D608051DI00<04a@H018C5`0B4aD00`0B4Q83010@400g01@D500G5aL051@D014A4@0D
51@05QLG010A4`0A41D05Q<K01<=6@0J4Ql08a/X01D=600I51/040hB01XJ60082PD03Ph=01HD6@0G
5AP0518E00h<3`0=2``0518C018@4@0B4@l04a8@01HE4`0J6AH05A<H01@B5`0C4A<051<A01@C3`0C
4Pd05aHA01TH4`0T8al0:RTW00h=2`0C4A4040l;010?2P0A40`04A0>018A3`0B4A001@<400`:3@0C
4A@04Q0E01<A5P0<2Q0040hA018@4`0201HD5`0301<A500>30l04@lB00805A<F0P0@3Q406P0A3a80
61PH010@400H61P03@d;01@C4@0>3@/04Q4=00l=2@0=2@H05A8=014=2@0G4a0030P7020N7`0>30d0
20H701LE5P0E4a@081hO03@b<`0?3@h04@l@01DC500?3@h04`l@0P0B3Pl01@0C3a00510A018>3`0A
3@h040`=00803`/<00D040`=014=3P0A3@/04Ph;014=2P0200l;200I010<2@0;1`D01@4001<?3008
10<0510=01LC400:1PH06aLF014=300i=C@05A4@00l;2P0B3Pd04`l>00h:2@0@30/06QHE00d9200@
30/04`l>00l;2P0>2PT0100000/71P02010<2`803`/:0P0>2PT0400B3Pd04@d<010<2`0?2`X040`;
014=30030000510?020L6`0400006aLF01DA3`0C40/04@h9018?2P0A3PT200l<1`0700d:1@0:1`80
3P/6018?2P0A3PT03`/9010<2`0300l;2P0E00h:2@0?2`X03`/:00l;2P0@30/04@d<01<?3P0E4A00
5Q8A00<0000D40l02`L600h:2@0;1`H05a<B00h:2@0B3Pd04`l>00d9200@30/03PX9008040`;0P0=
2@P02@0A3@`0510?01<?3P17@d80@3`k014=300N6QT06QHE01<?3P03014=30<03@T80`0>2PT01P0C
3`h0100000l;2P0W8b804`l>00/71P803`/:00D040`;01<?3P0D40l04@d<00l;3003010<3@0400l;
300=2@X03PX;00l;308040`=00@03`/<00h:2`0;1`P03@T:0P0@30d0200=2@X02`L8018>3`0F4Q<0
4Ph?010<3@0?2``02@D60P0@30d400h:2`804Ph?01@05a<D01DA4P0D41405a<D010:300>20X03`T;
018<3P0@2P`03@L901<=3`0=1`T030H800l92`0>20X03@L901<=3`080P@030H8014;3@803PP:00<0
4P`>00l92`0=1`T00P0<1PP02`0;1`P04a0A00/92P0=2``04Q0A00d;30071@H02PP900d;300>30d0
3`d>008030X;100=2``06@0>30l030X=00X82`0:20d04a4F020N8`0J5ah02PH<00P21P0k=CT040X>
00/52@0<1PX040X>00`62P0:10P03`T=01@>4P0L5QX0@Se102XU:@080`L06A@H00l:3P0:1@T00P0?
2Ph01`0G4QH040`?024L800300804`hA00d92P0?2``00`0@30d01P04004030P900l;30030000:RHW
00l;30@03`T=00<03PP<00h73P0?21000P0?210200l74P0?00l84P0:11800`0;00l<5@0?31<05A<H
014<40080P@04P`>00/52@0E2a<02`4901P@600@2A003`X>008040/?0P0A3100200?2Ph03@P<00`7
2`0:1@T03@P<01TD600H4aL04PdA0P0=20`0100>2@d03@P<01<>4P0B3A42014<40804PdA5?ooool0
01_ooooo00H06APF00@30P0@3`d00@0001DD4P061@<400d<2P0M00/:200:20T02`T>00/93P0D4QD0
518G00`9300=20`04PdA010:3@0=1`T03PP:014;3@0C3@l04P`>01H@4P0D3Q003@P900/51`0P71d0
3@T800l>30071P@03P`<01DE4`0920H02PP:024L800>2@d00P0B3A402`0I51P040/?018=4@0C3Q80
50lC018=4@0A31004PdA018=4`0B3A404PdB00804`hB01H04@`@00`72`0?2Ph04@d>018>3`0D3a80
71XM02XU:@3WiNL0IfEX01LB5P0B3Q803`d@01<>4P0E4AD04Q0C010;3`0A31005a8F01PC5`0H51P0
5A<F0P0E4aP09@0G5AX05QDJ01<B5`0C4QL04Q4G010?4`0@4Q404Q8B01<D4`0C5A@051HC01PJ5`07
2@@04aD@01@F400E6140=CPa02X]9`092`H06A`I02/_<00T:Bd051XQ00lC700L82T04aLQ018E7P0S
8b/07AdV01LI9P0K72h04Q<U01hO<@0R8cD05QLY01dN<00J6bd00P0H6RT0A@0F62D04A<P01TL8@0D
61/051HJ01XN8@0L82<051PK01TM800G6ah05ATL01HJ7@0G6ah051PK018G6`0J7b<07B8V01LL800K
82<07B8U02ld=`0M8RD07R<V01DJ7@0H7B008RX]01PO9@0J8RP06B8W01PO9@0H82D06R@V01hU:`0M
9RT06B<U01HN8@0E7R005QhP01PQ800G81l0624P01TR8@0Y<C80@TY<01PP8`0J8RD07BDX01hU:`0P
9bd082T^01`W:`0R;S<082ha03]8CP0L:S007bhe01TX;`0O<3L08S<k020a>@0S=3`0:CY202Hg?`0O
<3P0834i028c?00S=3h09cM4028b?`02024a@00l028b@@0S<d<08c=302@d@`0U=D@09SI302@d@@0T
=T809cU305U/M00S>3d0:Ci102a1@`0P=CH09S/n02XnAP0_@D/0:cm802PkA@0V>4808SHo028e?`0R
=3h09SU202Di@P0M;cT08SDk020d=@0R=CT093Lk024b>@0N;cH072/c01d[=00P;SL08Blj01TW<P0K
9c<06RPd01/Y=P0Q;cX08Bhi01`Y<P0M:S<07b/c01lZ<00O:2l0624U01@N800G8B806RDU01<O7`0Y
<c@07BLX01HP8@0/=SL06b@U01@L7P0I8B<06B8Q0P0E7Qd0@P0N9bH072HU00`E4P0A5aD061dI01<E
4P0I6aP05aTH01<D5P0A5AP051LL01TM8P0H82806R<R01`T9P0H8R@05b4S01PQ9`0B6b@0628[01hW
=00;52<05Ql^01dV=P0L9Bh06b@Y01PP:00H7bL0624X01HN9P0I82X08BXc018I9@0F72P0;3@o01TO
:`0T:3@051PT01PL9`0@51d05Q/P01@I7@0<4A@05AXM01LL800M8RP04QLM014F700@51d092T`0005
2`0D624051TO014F700I7R@04QLL020U:@0E6Qh061dQ01DJ7P0H7B<051TO01LL8P0>4aT082D[01PM
8`8051TO02@03a@J01LL8P0F6b406QlS01DI700B5QL082@U00lC500D61T05ATJ00lC500D61T04ADF
01LK700f>S/0720Q010A4`0G61`030d?01<D5`0=3Q8051DG01@E600E5QX07QlQ00/<3`0D5AT06a`P
00l@500P8BD0:BX^01HG6`0N7b<02``@01@E6@0B4aL4014B5P0401@E6@0A4QH04a@H018C5`804a@H
00<04Q<G01DF6P0D5AT00P0A4QH00`0C51D051@D01DE5@0301HF5P0I018B4P0D51@061PH01<C4`0<
30`03`l?01<C500>3a404A0E01HD6`0?2AD050hJ01lI9@0C3AL061<J018A4`0Q8Al02P`701HF5@0F
51T03P`?014?4P0E4aH04Q0A01DC500201<B400=014@3P0?3P`03Pd:00h<3`0?3A004@lA014?400A
40h040l=00H50@0G5Q807QdJ02@S8@0200l>308040l;03404A0=014@3P0B4@l04Q4@01DC500I5aX0
6QPK01LE600M6b003@/@010?500A4A<04a<E01<A500@3Q4030X=010>4@0B41<05A<E010>4@0?3@h0
5Q@E01PF5`0820P05ADE00H6100B4Q0020L501<B3P0C4@d04@d:01HB3`0?30P05A4>01`H5`071@D0
61LE01TG600@3`d03`h<00h:2@0G51<04Ph=01lK6P0m>CP03`/:010<3@0?2``03PX;00803`/<00<0
3@T:014=3P0@30d00P0?2``0800@30d04@d<01<?2`0D40d04Ph;010<2@0?2`P040`901@@3@0E4@h0
3`/801LC400>2PL030P501DA400810<0510?00d:2@0;1`H05Q8A00h:2@0@30/03@T801@@3`0S7ah0
5a<B00d9200C3`h04Ph=00l;2P0<20L07a/J0P0?2`X200h:2@803@T800<04`l>018>3@0A3@`00P0@
30/06@0C3`h06ADD00@0000b;Rd0510?00L30P0?2`T02`P300/60`0>2PH040d8014<2@0>2PH03P/6
018=2P0?2`L02`P300h91P0A3@X04Ph=014=300?2`X03@T800`81`0>2PT00P0?2`X07P0A3@`04Ph=
01@@3`0C3`h04@d<00d9200?2`X07ATH00T51@0;1`H05Q8A018>3@0?2`X030P700l;2P0C3`h040`;
018>3@0C3`h040`;018>3@060P40510?00P40`0K5aH040`;00/71`0I5A@05A4@00h:2@<02`L60P0@
30/0400A3@`04Ph=018>3@0C3`h06aLD00L3000H5140510=00T50P0B3Pd04`l>014=300@30d04@d>
00l;300;1`P4010<3@0400h:2`0=2@X040`=00l;30803PX;06d03`/<010<3@0B3Pl040`=00h:2`0=
2@X03`/<014=3P070`@03PX;010<3@0A3@h04`l@00d92P0B3Pl03`X=00/7200;1PX03@T;00l;300=
20`040`>01PD5@0F4Q@04PdA01DA4P0A2`d03`T;014;3@0D3Q004@/=00`82@0<1PP050h@014;3@0;
1@L05Q0B020J700S7Ql03`T;00h:2`0C3Q004@/=010<3@0?2P`04P`>018>3`0D3a004`d?014=3P0A
3Pl02`T:010>3`0H5QL040h?00L51P0=2``02PP900T7200;2@X03@/<010>3`0?3@h03@/<00`:2`0=
2``03P`?010>4@0G5AP02@L<034_=02HUY/0L6ed00l:4@0R6b80KFI]024J8@080PH040X>01@>4P0@
2Ph03@L;00h8300=1`T040X>018=400?2``03`X>00h9300A3@h04PdA01@@4P0=2@X00`02018?4003
00005Q4E00X6200?2``040/>010;3`0?2``03PX<018=4@0G4a@04`lA00d8300:1PL040/?00@040X>
00@03`T=00d63@0>1`h03PL>0P0?2100400@2A4040TB010=600=2QD03P/C00P5300A3a@03PT>00`7
2`0C3Q803@L<01TB6@0<1@`040T@00d83P0=20`200h93@803`X>00T03@P<00l:3P0>2@d02`H:01HA
5@0^:Bd05A0D010;3`0=20`00P0?2Ph00`0<1`/04@`@010;3`0300h93@0300l:3_oooooooooo01;o
oooo000Kooooo`0300d;30091`P03P`=00803`d>030030X;00/92P0;2@X02`T:00`:2`0>30d03`d>
00`:300@3Q003`d>01@B500A3a002@L800`:2`0>30d03``=00d:2`0>2``03``<018?3@0>30X03@/9
00h=2`0A3Pl03@/<01<A4P0;2@/05A<E00h<3`0C4AD02`X=010>4@0>30l030X=00h<3`0A3a804a4D
00l=400C4A@0518E01<A500B41<04a0C01@?4@0D3Q404`d?01<=400B30h201<=3`0<018<3P090`D0
71HH018<3P0E4Q802``902`/:@1GF5@0<S8_01PH5@0>3P/04A8>0P0B4Ph0G`0A4Ph04Q8>018@500B
3aT0514K01@B6`0C4QT04A0G00l>500E51X04A0F010?500E5AP04Q4F01@E5@0?50l041@@014E4@0@
5A4041@C00hC4P0I7Qd082HU00lF5@0H7ah0@T]:0498A00=4P/04aPC010D5@0M82D04QDN01PJ9`0N
82`08B<`01/N:00I72@06QdV01TK9`0G6BL05QPW01PI:`0I6R`061T/01PI:`0J72/061XU01@G7`0F
6Ah05APJ01DG5`0F5QL071`M01LH6@0C5AD05ATI01HJ6P0C5aL05Q`K01LM7@0B61P051XK01/P:P0J
82`06B0/03<iA@0L8bd05ahX024W<@0K8RX05QdT01DL8`0G7RD06B4W01PQ:00G8BL051lU01lY;`0G
8RP082/`01/U:`0G8BH06B@Y01/U:`0I92T072H[01XT9`0L9RT06bDX01dV;00F7bD082T_01TR:P0J
8b`07bLa00808RXd03D07RL_02@_<`0N:R`06bTZ01d[;@0N;Bl06bX^01d/<00S=CT08S@i01`]<`0N
;cH08cDj01la=@0S=3X07c4f01l`=`0N;cL062Tb02<c@00Q<D008310028aA00R<DD08S9202TkA@0V
>4808S@o07V;V@0]?Td06bdl028c@P0R=440;d5<02`nB00R=C/09c]102XoB00_A4d0;TE=02Dk@`0N
=3`07SDm02<j@P0M<S/083Hn02<j@P0O=Cd07c<h02Dg=`0V>3X08cDg020b=P02020a>00K01`]=`0N
;cX0<41=02HfA00F93@08S4l028a>@0P;cL07B`d01XX<@0J9c007BT`01lZ;P0X<cD082/Y01LR7@0_
>S<0520J02hj=`0R;R/072PV014M700K9bL06RHV018M7P0G8R<05b4S0080628T02T06R<S01XS8P0J
8b806B8Q01PP7P0G7ad05A`K01lW9P0G7Qh03aLF01lV9`0L92D051lQ01HR9@0M:Bh07b/b01dY<00I
92d05b8_01LS<00O:CX07RTl01TT=`0K9CT06bD`01HQ:00D7BH06B8[01/U;P0I8b`06R</01PR:`0I
8R/072H_01/U;P0F7bL04QTP01XO900B5a`061dR01LL800201HK7`0301<H700G720061dQ008051TM
01h05AXO01@I7@0H7B403Q<H01dR9P0?51P092T]01PM8@0P9BT0DEIJ01TN8P0G720051TO01LL8P0B
5ad051TO01hS:@0M8RP061dS01TN900G72805AXP01HK8@0H7B406QhQ01LK700M8B8051PI01<G600?
4a@601<G600601<E5@0F61P05aTH01HG5`0E5aL05aTH0P0D5QH01`0D5QD051HF01@F5P0D5QH03a<D
01HJ6`0?4a@00P0B5QL06@0@51D04QHG014E5P0C5aP04ADF018F5`0I7Ah05QLI01@E5`0:2`d05QLI
00d>400E5QP06Q/M01PI6`0B4aD05AHH01<D5P0E5QL030h=01LI600H6QT071hM00h@3`0E5aH00P0B
51<03@0A4a803a4@018D4`0I6A`05A@I01TH7@0F5AX04Q0E01LE6P0E51H05A@D01<B4P0A4Ph00P0A
4Pd06@0A4@l07alQ02<S9@0C4a@03`l?018B4P0B4Q404A4?014B3@0@4@`04A8=018C3P0@4@/03a0<
01DE4P0C4a<03`l?01LG601JFU/04a<D014A400>3P`06Q/F018C3P0A4@l00P0@40l03P0?3`l0410@
014A4@0?3`l04Q8B01PH600E5AD04Q8C014B4P0@4AD061/N00l@4P0@4A<05ADG0P0<30`01@0>3Ph0
51<B00/:2@0E4a404@l<00804A0>0P0?3P`2014@3P0>00/:2@0A40h051<A00h=2`0S8Ql02`T7010>
300D40d05Q8?00d91`0C3`d040`801@?300E3``201H@2`0801PA300G4@`040`:00d<2P0?3P`04A0>
018A3`0@3`d200l>300X00`;2@0@3`d051<A00T81@0>3@L02`/400`;1@0?3PT040l:00l>2@0=30P0
40l=018A3`0:2@L04A0>00l>300@3`d030/901@C4@0=30X04a8@00h=2`0?3P`0FEQF01TH5P0=30X0
1PD300h=2`0?2`T0510=00`91`0R7Q`03@T601`H5@0@30T04@d:00h:1`0A3@X0510=018>2`804Q4?
02803Pd;00X91`0;2PP03@`:00d<2`0?3P`051<B061OG@1fMG<05A0@01D>3@0E30d04PX:01/D4`0Q
61T0610@00l81`0A20T04PX:014:2@0B2@X04@`:01@C3`0U920071/G00X91`0A40`03@`901@C3`0@
3``040l;01<B3P0S8Qh03P/80`0B3@X00`0A30T040/8010;2005010;200300l=2@0>3@T03Pd900<0
3Pd900<03@`800h=2@0=30P00P0:2@D00`0<2`L040`9010<2@04010<2@804@d:01h040`9014=2P0A
3@X04`l;01@C3@17Ach030`400h>1`0E50l03`h;00`;2P0B41402`T<00h<400I5a`0N7Ij01XH6@0?
3P`04A0>028Q7`0E51802@P6014@3P0G5Q@04Q4?00h=2`0?3P`03@`:040o?@0F5A<200`;2@0500l>
300=30X030/900h=2`0?3P`00P0>3@/03P0<2P/04a4D018@50020@@05A<H00d;3`0?3A403P`A010>
4`0>31002`T>00`:3`0A31404PT>0P0=1`/05@0>2@d03PX>00d;3P0?2`l03PT=010;3`0=1`/07QDJ
03D/<@0X9BH0514B00H51@0>2``040d>00/92P0?3@h03P/<00d;300@3Pl04Pl@014>3`0600d92P80
3`/<0P0>2P/0F00=2@X02`L8010<3@0=2@X04@`?00P31`0D3a<07APM00`73@0?2Q00?3Pn0;Rc^P1]
J6l091hV01PB6`0P6b<04PdE00`83P0:1P/03@P=00/62P0<20T03`/;014=300?2`/02`L601PD4`0?
2`/03@T901<?3P0J5QH03@T800l;2P0?2`/03PX:00d9200=2@T03``>00L52@0C4AH01P@9034_<`13
@DH02`T>00/93@0;2@h03@/@00d;3`0;2@d040/?00l:3P0>2@d03@P<00h93@0@2`l03PT=018=4@0F
4AH040/@00d83@0A31403`dC00l<500?31<03P/B00d:4@0=2a403`dC00T73@0B3Q@03@T@014=500=
2A006ALK00h<3`0=2`h04@lB00/9300?3A0030X=018@4`0A3a802`T<00h<3`0H5QT02PP900d;300>
30d200d;300700l=3P0>30d03`d>018@4@0=2``04a4B00`:2`0Dooooo`006oooool04`0=2``061HG
00T7200A3a003`d>010>3`091`P02PP900/92P0=2``040h?018@4@0C4A803`d>00P61`091`P01P@5
00X82@0=2``00P0?3@h03`0=2``03P`=00l>300b<Bh0:BPV01<B400>3@/03`d>0040000N71d020H9
010>4@0D4QD04a4F00d;400200h<3`0500l=400@3Q4040hA010>4@0A3a800P0D4QD01@0A3a8040hA
014?4P0D41404@d>008040`=00h04@d>018>3`060P<0;RX[01`H6@1HE5D04`l@00X81`0H61H051@B
00X:200?3`d03@d;00l?3@D04A4?02@04A4D018@6`0B4AT04a8J018A6@0B4AL04A0F01PG700D4aP0
4Q8D01LG5`0D51H05aLF01@F4@0B5140418?00dB3P0>4Q4041@C02T_;@0j@4006R0P00L=3@0Y;S40
=3Xh01HK5@0C5aD06alR00`?500F62<05QPU02T[>00T9S<0418N01DH8@0G6R<201HH900;01PJ9`0K
7B`06ad/01TK:P0Q8c805QPU01PK900M82D05QXM01/O7`0R92400P0J71T07@0>40l08B<R028V9@0W
:b`05a/L020V9P0/<C@0724T01HN8P0221@0728b01XP;`0D6RP06R0^01`R;P0E6bL06B0Z01HM9`0I
82X072<]010I8P0D7B@06RD[06ehOP1TKgD062<Y01HQ9`0M:2h06B@Z00806RD[07l062<Y01`W;@0?
61d06B8W01@M8P0?61l04AXQ01LP9`0O:34072D_01`T;`0N9S407bLb01lX<@0U<3@07BX[01LU9P0I
9bP08C0b02He>00N;C807Blc01`^<P0L;C@07c0g028d>00O<C@08S@h020b=P0Q<ST0834i01`]=@0Q
<Ch08c=202DeA00T=4@08C13020`@00K;CH08cDo01HX<P0bA5806R/k02/lC00O<4007S0n02Dg@`0O
<C`08C@k02m2B@0]@DX0<dM@02XnA`0T>4408cM001hb>`0Q=Ch09CU2024e?P0N<S/08CDn02Lj@00Z
?3h0:C/o02@f>P0O<3L07Rlf01l`=`0E9Rh0;3e70;K7d@26UZ<0>d]H01HV;`0N;C807Rdd01`[<P0H
9bh05R<[01TU;00Z=CT09c8d030l>@0K9R007bXR01/V800Q;B/06BDS01LS8@0>6QP08Rh^020/;00K
9bL06bHX01LR900=61X062<V01TQ8`0J8b807RLV01dV9@0K92<05QlN02L`;`0Z<c804a`K01TR8@0M
9RD0628R01`W:@0I9bX06BH/01PU;@0I9Rh06RL`01XV=00I9C<072Ph01/V>00G8S@06BDg01dW<@0H
8bT04QdS01DP9P0I92X06bH/00806RD[02h06bH/01dX;P0L9bd06B<Y01TP9P0A5QX0724U02X_<`0G
72004QLK01<H700E6Qh06QlS01PM8@0A5QX04QLK01XO8`0P9BT0;S<g00H;3`0G72005Q/O03a1A@0K
82@03a@H01TN8P0@5AT051TM01LL8P0J7bD05Q/Q01DJ800H7B<05AXP01HK8@0H7B<05a`R01DJ800C
61h04aPL010D5`0;3a009b//01/O800<41402Ph?1P0D61T01P0D5QD05ALF01DG5P0C5A@05ALF01LI
60H051HE02D05ATJ00P<3@0=4A8041@E018F5`0>4Q<04ADF00hB4`0@51D04QHG01PL7@0P92D05AHH
01XK7@0E5QP03a0B01PI6`0K71h01@H800`=3`0N7b4051DG01HG6@0C5AD06adL01DG5P0C5A@03Q0?
01DG5P0@4Q4051HE01DG5P0B51<0418A01<E500C51D02`/=00803`lA00<0410B01@D5P0?3`l00`0@
40h02P0A4@l04Q8@018B4@0C4aD0410@00`<300E5AD051@B00l?3@0@40h300l@2`0>010A300A4P`0
4A8<01<D3`0?3`l02@T900`<3P0M7Al03Ph@01XJ6@0410804A8=00L80P0@40h5010@400D01HF5P0A
4A402@T900P8200=3@d02@X900h?4`021PT02P/=010A4`0B4aD05ADE00P8200<30`051<A00X91`0C
40h030P5018A3`0A40h2010?3@0=014@3P0B4@l08b8P00D40P0D4a406APF010?3@0M71X04Q4?00H5
0`0M71X02`X801dJ5`0201<?300301@@2`0D3`/05A0<00805A0<00<04@d:00h=2`0?3P`00P0A40h0
:@0>3@/051<A00l>300?3P`06APF01XI5`0:2@D05A@>01dM5@0>3PH03@`701<B3@0;2PD03`h:00`;
2@0=30X02PT701@C4@0@3`d03@`;00`;2@0:2@L04Q4?010?3@0?3P`02`X802/Z:00=30X030/9018A
3`0<2`T061@A00/7100M6AH0X9bI010<2@0300004@d:010<2@0>2PL0510=00806aLD00H02`X800`;
2@0<2`T02`X800d<2P0<2`T200l>300501LF500g=S@0@d9001<>300E3@/00P0B2PP01@0M5A<09AdK
01`D4P0A2@L04PX800<04`/900L030P500X91@0J6AD06aXF010?2`0=30P030/700804a8>00@00P40
00<200061@405Q@@0`0A3@X00`0@30T03`/8014=2P05014=2PH03Pd900H03@`800h=2@0>3@T02`X6
00X91@0=30P6010<2@@03`/801l040`9014>2P0:2P8092@J00X:0P0?3PT03Pd801DD400A3a002@L9
00X82`0E4aP01087028P9@0F51D03@`:00`;2@071P@03@`:01DD4P0:2@L051<A01DD4P0D4a404Q4?
00/:200G5Q@02@P600h=2`081`D02@P600@03@`:01003Pd;010?3@0A3a002@L:00h<3`0;2@`061HI
00h<3`0E4aH03P`?00l=400>30l030X=00d;3P0A31004P/?0P0A2`l05@0@2`l03P`?00h>400@3a40
40/?014<400B31003@@900L11@091PL040h?00l=3P0B41403@/<01/I6P0<2P/03@/<00h<3@0A3a00
518C01DC500600h:2`03014=3P0@30d040`=00803`/<01l04`l@00T51P0=2@X03PX;00X61`0=20`0
8A`Q00h93`0E41H030L=02DP9`0>2A005@lH00@0200>2A001`<901PC6P0n>Cl03@P=00`72`0>2P/0
3@T900`81`0?2`X0510?00d92003000030P700<0000?2`X0510?00803`/:00T03PX900d9200=2@P0
1`D600h<3`081`T00@0200X82`0X9RT00P0<2Pd0100=2`h02PP;00X82`0=2`h200l:3P<040/?00@0
3`X>00h93@0A31004PdA0P0>2@d00`0C3Q803@/@00d;400200h<4@803`dB00T0518G00H42@0C4AH0
40hC00d;400K6Ah09B<V01@B5@091`X00P0?3A00300A3a803`d@00l=400<2Pd02PP;00/9300?3A00
2PP900`:2`0=2``02`T:00`:2`803P`=0P0<2P/00`091`P07Q`M02DS900Dooooo`006oooool02@0E
4a@0:2HW00X82@0C4A8030X;00h<3@0B41404@l@00l=3P0300h<3@09010>3`0<2P/01@<400X82@0?
3@h07Q`M00d;300?3@h03P`=00803@/<01403`h<01<B3`0?3P`01`H400`;2@0C4A8030X;00d;3005
0`H03`d@00`:3@0;2@h05Q@I00h<3`0?3A0040hA014?4P0200l=400801@B5@0E4aH0518E018@4`0A
3a804Q0C01LC500D4142018>3`0?01@@4@0E4A807QXK00L3100300008QhO010<3@0H5QH03Ph<00T9
1`0O7ad03Ph<0041000F5Q@0410>00<04A4?00<04Q8@018B5@0B41/00P0B4AT2018A5`0Q014@5@0G
5aT04a<E018B4@0H61H05ADC01PH5@0F5a804a<A014B3`0A4a004Q@C010D4`0;3`h02Ph?014G5`0G
7Ad04aPK018H5P0=4Ph020`<010C600A51/05ALR01@F8`0G6BH04Q@Q01<E8@0L7RX05aTT01DG8`0F
62@06A/X00807Al/06X06Q`Z01LI9P0D5R805aXR01HJ7@0?4a@051PF02<U8P0>40d061XG018D4`0L
7Qd07R8Q01`P8@0D61/0724U02<X;00H7B4051/R02@Z>00T:SX061h^01TO;`0Q9cD082Hd01<I9`0M
8bl05QdW01DL9P0L8bd04a`U01XS:P0=61h0F6=Y04YEF`0E82H09S4g01@O9@0F8BL07BP^01hY;`0J
9B/072L]01LP9@0O:2d07BH[01HO9P0Q:S4092dd02</=@0P:C<07bLb020X<`0N9S406b@]01`W:`0M
:B/07R`]01l];P0O;S007B`_01d/<@0N<3@072hb01TZ<@0K;3<07c0g01h`<`0P<SH08C<g028c>P0Q
<SX0834i02<c?`0U=D@09SI502@dA00S<TD08c=302Li@P0^@4X08S@n01h`?P0H:CT0;Ci>01`]?@0Q
<d40:Sa802@f@@0M<3L093Ln02a0B@0cAe009c]402Di@P0Y?DH08SHo024e?P0T>4407c<l01T]=P0J
;SL07c8i028c>P0S=3/0834h0P0N;cH06P0T=C`07Bhf020a>@2R/k`0OHjH04UJI00F9Rh06RT^01/Z
<@0J:C005RD/01@Q:@0D82L06bHZ01XU9`0S;b`05R4K01dX800N:B@000T702`h=P0D81h07RXX024]
;@1]NGT09C4a0P0B7Al0100A71h06RDX01LQ8P0I8R4201XS8P0F01PQ800F7ah08R/Z02H_;P0B6aX0
7BHU01TR8@0I8R806bHX01TW:P0I9R`06RL_01`Y<@0O;3D06bLc01PT<P0I9CD06B@f01DP<P0G8cD0
7bTc01/V;0805R4W02D05b8X01HQ9`0E82H05B0V01HQ9`0G8RP05R4W01DO9@0D71l04QLK01/P900Y
;S806b0T01<H700B5a/051TM01XO8`0I7R805Q/O01XO8`0<4AD0@TM;079gN`0[<3@06QlS01@I7@0X
;C4061dQ01`Q9@0D6Ad06b0T018G6`0G72806AhT01PM8`0G72805AXP00804QLM00/05AXP01HK8@0D
6Al04aPN01<H700N8RD06QhO01DI6P0@51D061`M010D5@06018F5`805ALF00@04aDD018D4`0E5aH0
5aTH1P0F61L0200h?3d03a<D00hB4`0<41404aLH018F5`0D61T04ADF0P0B5QL0800C5aP061`M01HG
6@000@<03@h@01XK7@0I6Q`0EEIH02<T9P0720X04Q<E00`=3`0E5QP05ALG02/];00J71/05QPG00/=
300L7Qd04Q@C01DG5P0C5A@04A<B01<E500B51<04a@D00l?3`0@418051@E01/K6`0J6QX0410@0P0B
4Q802`0C4a8051@B01@D500I6AT071`N01HF5P0A4A4061PH01LG5@0B4Q004A4?00<04Q<>00h04A8=
00`=1`0>3`T051D@01HF5P0E5AD06ATK01HF60020P@051@C01LG5@0F5a804Q<>010@3PD0410@0P0>
3Ph0400A4A4061PH01dM7@0A4Q806Q/O010D5`0M7R003@h@00<41P0O7al07QhN00d=3@0@3`d03Pd;
00l=2P0@30T600l>300;00d<2P0G5Q@02PT701@C4@0;2PP02@P600X:2P0@41001@D303`j>`0B4@l0
0`0C3``301@?2`0@01@@3@0A40h040l=010?3@0A40h040l=00d<2P0B4@l03`h<018A3`0I61H061LE
00d<200P81T08R8J01@D308040l:01l02@P3018A3@061@<030/901@C4@0F5A<02@P601DD4P0A40h0
1PD301<B400?3P`040l=00T81P071P@00P4000d<2P0H5aD01PD300`81P0I5A802PH301LC400=2@H0
8QhK00`81@0C3``0510=01LC400F4Pl04Ph;00804a8@018040l=00d<2P0>3@/04a8@010?3@010000
2`X8014@3P0J6AL040`:01@<2P0A2@L03`L5018:200F3P`050`:018:200C2`T301@<2P0400h:1`09
20@03@`8010?2`804A0<00L03`h:00@3000;2PH06APD02PW8`040`004@h;00<04@d:00<040`900l;
200@30T01@0@30T600h=2@0600d<200>3@T03Pd900/:1P0:2@D03@`81P0@30T06`0?2`P03PX700h:
1`0>2PL03`/8014=2@071`003@d300P80@0=30L010<0014@300>3@/02PP:01XH6`0Y9b`04Q0F018@
5@0:20T02`X801<B40071P@04A0>01@C4@030P0030/900h=2`0200l>300700X91`0;2PP01PD300h=
2`0920H02`X800l>300200h=2`0:00d<2P0>3@/04A0>01@C4@0B41<03P`?010>4@0;2@`0:RP[01TG
6P<030X=00@03@/>00h<3`0A31004PX?0P0C3A403`0@3A003Ph@00l?4@0?3a4030X=00/62P0D3Q80
5PdB00d72`0B3a0030X;00<10P0>30d0108301/I6P0200l=3P803P`=00<040h?014?400?2``01@0?
2``00`0A3@h040`=010<3@0200l;300G014=3P0810D04Ph?00l;300=2@X01@04018=4P0500H04@`B
01@?5@0G4QT020<:00X6300K5Qd050lF010;4P0:1@/0>3<i00P4200;1PX03@T:014=3@0?2`X00P0>
2PT01P0?2`X02@D401HB4@070`8040`;014=30803`/:00P03PX900d9200=2@P04@h?01<A500610L0
9B<V00<1108030X=0P0=2`h200X82`0300h<3`0>2@d03`X>00804PdA00<04@`@00l:3P0?2Ph00P0@
2`l00`0>2@d03`X>01@?4`02010>4`0;00l=4P0>31403@/@00`:3`0F51T02PP=018@5@0>314040hC
01HD6@0E4aH00P0=2`h02P0B41<030X=00T72P0<2Pd02`T<00`:3@0>30l04Q0C01<A500:20T200`:
2`0900/92P0<2P/03P`=00/92P0E4a@02PP900<10P0I5aP04Q0A01Cooooo000Kooooo`0:00P61`0H
5QL0108300l=3P0=2``04@l@01DC500D4Q<04@l@010>3`803`d>00T04@l@01<A4P0:20T03`d>01<A
4P0=2``02`T:00h<3@0=2``00P0<2P/03`0=30X03`h;00P71P0B4@l040l=00d;300C4A8040h?00l=
400=2`h03`d@01XH7@091``03@/>00l=4002014?4P0:00l=400>30l04@lB014?4P0@3Q403P`?00l=
400@3Q405A4B01@@4@@04`l@00`04@d>01TE5P0J5QL03@T:01/G600>3@`061PF00L71@0;2`T05QHD
00/;2@0C4a42010@3P04014A3`0B4Q004a<A01<C5P804Q4I02404Q4G018B5@0B4QD05ADE01dN6P0G
61@04Q<=01<E300?40P051@>01DD400D4a4051@B01DE4`0H5aL05QLF01@F5@0E5QP051LH018F5`0A
5AP04ADF01lS8`0a=CP030lE01`O9`0D5R806Q`Y018D8@0G6BH06Q`Y018D800G6BD00P0F6B808`0I
6bL071hZ01`N:P0J72L04aHP024T;00S9R/051PI01DI600E6AH08B<N01dP6P0J71L041DA01HJ6@0D
61T05a`O028W:`0T:Bl05QdT01LN9P0H7RT0:2hn024V>@0L8C@04QPX01HL;00G7B`06Al]024W=@0J
82d04aTU01PN:P0L9Bh04Q/S00807RT_02h062<Y02/f?00L9bd062<Y01HQ9`0H8bT06B@Z024/<P0_
>T009C0d01LR9P0K9RX05R4W02Ha=`0T;cD06bD^01hX<P0S;CL09Bli02@^>00N:34072L[01hZ;00M
:b`07B/^01d/;`0N;C006RT^01h_=P0M;SD06BXa01//<`0O<3L07c4e01h`=00Q<cL08C8i020a>@0R
<c/08S<m02<c@00Q<Ch07Rhm028b@@0U=D@08S@m0P0Q<cd0@00Q<d407Rlo02@eA@0Q<T807Blm02@f
@P0S=D006Rdd01P[<P0Q=Ch0:Ce6024e?P0R=Sl0:3a502@h@@0Q=Ch07C4j01lc?00P=3d07C4j01`^
>00N;cT07c0j01h_>00M;SH07Rlg01d^=@0X>D007Bhe02Tk@@0G:Bh0:ca201TZ;P0L:bh072/`01`[
<@0H9bh05b@/01TU;00@6al06RDW01`W9P0V<B`0@Da501@P6`0N:RP06RHT01dY:01MJFT07RXZ01dY
:P0D7b405b8T01`W:P0?6Qh041/N01/U9P0I8b805R0O01DO7P0F81l06B<R01HP7`0I8b8201LQ800@
014K6P0H8b<062<W01LT:P0J9bd06RL_01TV;P0H9Bh06bLc01LS;`0H93806bLg01LS<`0F8S806B<[
01TT:0806RDY00D06B@X01HQ9@0A72004ahR01@O8`02018M8@0I01@N8`0C6ah08BHZ01DJ7P0J7b<0
6AhR01<H700F6al04aPL01HK7`0G72005AXN01PM8@0C61`05a`P03a1A@0F6al05a`P014F6P0I7R80
4QLK01@I7@0:3a<05a`P018G6`0201DJ7P8061dQ00<05AXN01@I7@0A5QX00P0D6Ad02@0C61`05AXN
01LL800X;2l04ADF01HJ6`0B5QL05QXK01LK700601<G60805ALF00<051HE018D4`0D5QD01`0E5aH0
7@0l@44061`M01@H6@0A5AH05a/L01HJ6`0C5aP04QHG01HJ6`0D61T041@E014E5P0>3a408b@V030a
<`1MGV004A8D03@e=`0B4aD03a0B02LX:P0G61X05AHH014C4`0O8B0051HE018D4`0=3`h06Q`K0080
4aDD02X03a4@01@F5@0Q8b8071hM010A400A4@l05aLF01<C4@0E5A@06ATI014A4@0C4a<04a<D01<C
5@0B4Q<04A4C01HF5`0K6a/06ATI01<C4`0C4a805QHD01@D4@0?40/04A8=014B300@4@/03a0:014B
300C50h04Q<>010@400A4A40410B00l?4@0T92H06ATH00T91`0G61<03a0:00l?3@0@4102018B4P0:
014A4@0@41003`l?014A4@0?3`l03Ph>00/;2`0?41004A8F014E6080414C00P0;c0b0;Jf]P1:BTX0
7AdM01@C4@0I61H030T701HB3`8040l=0P0A40h2010?3@0E01PG5@0?3P`04A0>00P71@0C4Q00:RTX
03<c=00m?T0030d>00h?4@0D51D0410?014@3`0A40h04Q0=018?3@0C3``04Ph;014@3P0@3`d04A0>
00804Q4?00h03`h<00/:200<2`T040l=00l>300<2`T03Pd9014@2P0:2P<03`l7018A300@3`X04A0;
01/J5P8081lM0P0B4@l01P0=30X081lM01HE4`0:2@L04A0>00l>308040l=00h03Pd;010?3@0A40h0
92<Q01/J600A3@/02`L601TE4P0=2@L06aLD00H20@0?2`P04Ph;00l;208040`9010030P5010?3@0@
3`d03Pd;00/:200=30X0?C`j04Q7A@0C4Q0030/900/:200C4Q003PX700`70`0?2PH050l;0P0B3@T0
0`0A30P040/7014<2003018=2@0=018>2P0@3`/02PT500`;1`0?3PX02`X601DD400<2`P02`X601lN
6P0];2P03@`8010=2P03014=2P03010<2@0?2`P040`900D040`91`0>3@T200l>2P0300`;1`0;2PH0
3Pd900H040`9100?2`P0800@30T04@h:01<C30092@40410801@C3P061@404A0<00d<2P0;2PX04a4D
01HD5`0<2`h03@/>00d;300>3@/04A0>00P71@0>3@/030/900l>300@3`d030/900d<2P0@3`d02`X8
014@3P0:2@L03`h<00d<2P0B4@l03`h<0P0>3@/0300=30X03Pd;014@3P0C4Q003@/=010>4@0;2@`0
6QPK09RFV@14@TD05aDH01@B5@8040hA01X03P`?00l:3P0@2@d04P`@014<400?31004Q8D01DE5`0C
4aD040hA00h:3P0A2`l05@`A014;3`0<2@X0518C01hL7@0e<c@03P`=014?400;2@X03P`=00d;300;
2@X03P`=014?40L040`=0P0?2``200h:2`0;00`8200=2@P030P901@@4@0B3Pl040/?00h93@0<1`/0
3PT?00`73@0@2a400P0>2@l0200I51X020<9014<4P0@2a003PT>03<^<P0J5AT03PX;0P0A3@h0200?
2`X03@T9010<2`0<20L06aLF00h:2@0B3Pd03PX90P0?2`X02@0>2PT03@T800d9200;20T061HI01lM
800:20/00`84010>4@0600h<3`803`X>0`0A310600l:3P04018=4@0>31403P`A00h<4@<03`dB00P0
3@/@00`:3`0=2a002`T>01/I7P0;2@h020H900/930803`d@01@03@/>010>4@0:20/02@L:00/9300?
3A004Q0C014?4P0<2P/03@/<00`:2`0;2@X03@/<010>3`0g=CH03`d>014?400>30d02@L8014?41Co
oooo000Kooooo`803`d>00D03P`=014?400?3@h03@/<00/92P0300X82@8030X;00L04a4B014?4003
0@806aTJ05=ADP1FE5D030X;00803P`=0P0<2P/03P0>3@/01PD30040000:2@L03@`:010>3`0D4Q<0
2@L800P62@0m>ch030X=010>4`0=2a003P`?0P0?3A02010>4@<03`d@01d03P`?00d;3P0@3Q404Q0C
014?400B41404a4B018@4@0?3@h03P`=00`:2`0610D09bDV00`:2`0;2@X051<C01<C4`0=3@d06ATI
014A4@071`L04a<C00l?3`0@41004A4A018B4P0C4a<04a<F01<B6002014@5P0J014A4`0C4a<061TE
02@U7`0M7QH05aT>01LI300A4`H04a@<01DA3P0E4A005Q8A01@C4@0D4Q<071XK01dM7@0F5QP03`lA
00d>400@4AD04aDI02HY;P0g>T005QTP01XM9P0G6BD200lA7P0501PJ9`0G6BH0418O01PJ9`0H6b@0
0P0G6R<201TL9@0d01PK8`0F6Ah061`O01HJ700A5A@041@C010E400@5@l04AH?01HK5@0Z;b/0310?
01PM7`0B5a/06b0V01lV;`0I7b/061hZ01LN;@2l`M@0C55U01hS=P0e>Td06Al`01TO;`0H7Rh05Q`[
020V=00Q9cD05Q`Y01HO:00U;SL062<Y02@_=@0c?T@092le020[<@0O:S006RD[01HQ9`0C7R@06bH/
02dh?P1FHFD08B``02<^<P0L9bd08Rdc01DP9P0I8b`06R@^01lY<`808bdg02H082Xc01`W;@0K:2/0
6RP[01d[;P0[>Cd0>4M<02@c>P0G:2l05BH]01PY<@0J:c<062T`01h`=00L;S80838f01l`=`0M;SH0
8S<k020a>@0T=Cl08S<m01h^>`0P<3d093A1028e?@0N<3X0838l02LiA`0G:3P03b0`02LhB00R=480
8SA0024c?P0P<cX08SDl01`_=P808SDl00T08C@k02<f?@0U>3l08C@k01`_=P0P<cX08cHm020c>P0N
;c/00P0Q<D00?00O;c`072dg01`]=`0L;CD04B8Y01LY;@0M;c40838d02Li>`0F9bL06BTY01PW:P0G
9RX05B@Y01DR:P0E8BP03aXN01@O8@0G8R4062<O02lj=00C7a/08Rh^00`H600C7al09c<c01<N800J
9BL051lQ01dX;00D7b<031LK01`W;00H8R@05b4R01HP8@0E7b005R0Q01TS900E7b0031HG01LQ8P0>
61T05b4R028];P0J9BT06BH/01XW;@0I9Rh05b@/01DR:`0L:C8062D^01`X=00Q;C/07BTg01XV<`0E
82H05R4S01TT9P806RDW00@06bHX01<N800E82805R4S0P0D7b406`0H8bD06b<V02<X;00I7R806QlS
01LL800L8BD061dQ01<H700J7b<07b@X01TN8P0A5QX051TM01/P900h?D40724U010E6@0G72004QLK
01LL800B5a/06AhR00lD600B5a/05a`P01<H700201LL800>018G6`0D6Ad061dQ01LL800C61`04AHJ
01<H700G71l0TYJI02``<@0>4Q<05ATJ01@H6@0E6AX601@H6@03014E500C5aH04aLF00T041@C00d0
20`=00/?40093@h041@E01DI6P0C5aP041@E00dA4P0B5QL051PI010D5@0A5AH061TK00803@h@00l0
6Q/M00d>400A4Q@04A8D01@E5`0H6A/02``>00d>400D5QH02P`;00lA400>40l04aDD00d?3P0A4a80
0`0C5A@02`0N81l071hM01HH500>40/030h901dO6P0i>cH0<cDb01<E500?4180414E00804A8F00@0
414E010A500@4100410>0P0?3`d00`0C4a404A8=00d>2@02010A2`0@00l@2P0=3PP02P/500l@2P0B
4`h071`L02TY:@0a<C<071`N01LG6@0;2`X05QHD00@5000A4Pd03Ph<00l?3`804Q8B01D04A4A00l?
3`0>3Ph04Q8B01@D500H61P07QhN05UJFP1BDeL0DUII01/L7P0?41805QLI079bLP0i>CT06a/K01LF
500H5aD040d;018>2`0@3`d0100B4@l03`0@3`d00@00038a;`0<2`T061LE018A3`0<30`04A8D01@F
6@031`X09b/^014D5@0I6Q`03a0B010@400200l?3`803`h<00<040l=00l>300A40h00P0C4Q002P0A
40h05aHD014@3P0C4Q004Q4?00l>300C4Ph04A4:010@200>3PH2010?2P0900l>2@0F5A4092<Q020O
7@0:2@L040l=01<B40071PD01PD300803@`:01005A@B018A3`0;2PP00P4000H50`0M71X09B@R01DD
4P0E4@h02@D200`81@0E4@h04Ph;01<?300D40d04`l<0P0?2`P00`0@30T03@T600d<2P0300l>3008
018A3`0E51806QTG01HE4`0E51803@`:014@3P0;20L2014<200301@?2`0=20@02PD100803PT50140
3`X6014<200@2`L040/700h;1`0A40`030/701<B3P0I61@04A0<01HE4@0C4Ph03Pd9010?2`081`<0
40l;00/:1P0300l>2P0300h=2@0=30P03`h:00D03`h:1P0>3@T300l>2P8030/700<03Pd9010<2@0@
30T0200@30T0400A3@X04Ph;010?2P071P403@`7014@300:2@D03Pd901TH5P0E4a<030X;00400P04
0`D03`d@00P61`0D4a4200d<2P0=00l>300D4a402@P600T81P081`D03@`:01DD4P0C4Q004A0>00h=
2`0@3`d02`X8014@3P0200`;2@@03Pd;00T03@`:00l=3P091`P04@l@01<A4P0Q7b004Q0A01XH6@0E
4a@00P0A3a006P0>30d03PX;00l93@0B310040/?00l=400H61X07AhP018C5@0;2@`040hA018=4@0A
2`l05@lC010=3P071@H03P`=01TG600:20T02@L800`:2`0?3@h03P`=00X82@0=2``04Q0A1`0A3@h2
010<3@803`/<01H040`<01PD4`0:1PD0?3Pg010<2`0G4a@01@4300`72`0A31005A0E00l:400@2a40
4`hC07MbMP0U82@05A0D00<00P0M61`0:2@U01TE5P0<20T040`=0P0>2P/01P0D41000`0001DA401M
FEP07a/J00L30P<03`/:00X03PX900d9200=2@P03``<01TG60071@H08AlP00l=3P0:2@T040h?0P0=
2``201@B4`0300/92P0?2Ph03`X>00<03PT=00<03`X>010;3`0?2Ph00`0@2`l0500>2@d02`T<00/9
300=2`h03`d@010>4@0A3a803P`?00d;3P0B41<04@lB01dK7P0?3A003@/>00h<3`0=2`h02`T<00l=
400C4A@030X=0`0=2`h200`:3@0<00h<3`0?3A003@/>00`:3@0?3A004a4D08n=T00X9RT03@/>018@
4`091`X01@<65?ooool001_ooooo00P030X;00D3100A3a004@l@01<A4P0?3@h040h?00l=3P803P`=
00T03`d>010>3`0<2P/040h?00800@0L6Q/0EUAE04Q6A`0=2``00P0?3@h03`0=2``03P`=00l>300B
4@h030/900L6100;2PP04@l@00h<3@0D4Q<0>3Hi0;Ne^00d<SD00@0401LE6P0200h<3`0400l=400@
3Q4040hA010>4@804Q0C0P0A3a801`0D4QD05Q@G018@4@0E4a@05aDF01DC500A3a000P0?3@h07P0I
5aP05aDF028P8@0=2``03Pd>01@D500B4Q8030`<00h>3P0=3@d04Q8B00l?3`0@41004A4A018B4P0C
4a<051<G01<B600A41H0410C014A4@0C4a4051D@01XK4`0E5Ph04Q@801DG2P0A4`D051@;01DA3P80
5A4@04/04`l>010>3`0?3@h04Q0A01DE5`0J6Q`05aLI018C5`0A4aL05APO010C6P0G6R<05APQ01XL
9`0L7RX06Q`X01HH9@0K7BX07Al/010B7`0I6bL05aXS01DH8@0G6R<061/R01LJ800V:Rd05a/N01<G
600J7Qd05ATH01LL600F6aD041D>04aAC01oQ8007B4P01<H700G72805A`T02D[=P0]<d409R`j02@[
?00e>Td08bPl02dbA@0P9CP07B<d01XP<00M8c<05Q`[02hd@P0e>dT082Hc01LP:@0H8BX06B@Z020[
<@0jAD/09c8h01<N900I92X06RD[01/V;00F8BL04ahT01/V;01II6P05R4U01hY;@0K9R`08Rdc01@O
9@0O:C800P0L9S009P0M9c407RPb01`V;`0N:Bl07BX]01XX:`0I9bX07bhb02Pg?00jBE007Rlf01PY
<00P<CT07c0h01PY<00O<3H06bda01la=@0M;SD072de024b>P0R<c/0:CY402Pi@`0S=3h08c=002Df
@00V>D00;Cm902@f@00R=480835102XkB`0N;cl08cE302@f@P0N<3/072lf0P0O<ST02`0T=ch0:3]2
02<f?@0Q=3/09cY1024d>`0N<CP07C0g01`_=P0J;C@06R/h00807Rhn02<07Bdl01/[>00L;CL08C8j
00LI7@0J;3008S@e01T[:`0M;bl07c0`01d];@0K:Rd06RT]01PW;00I9Rh05b<Z01dX;P0G8RH06bHW
00XD4`0D7a/072PU01<O7`0<61P06bLW038n?P0?6Q`05R4S01@O8@0I92P051lS01DP900D7b@04adO
01<M7P0401@N7`0701lY:P0>61T07BLX01DO800Z=3D0>49401XX:`0201XW;@0<01/X<00L:C407BXc
01dZ<`0J9c007b/g02Da?@0R;SX07BTe01XU:`0J9BL06B@V0P0G8R@0100J9BL04ahP01HQ8`0G8R@2
01@O8@0<01TT9P0D71l04QLK01@I7@0J7b<041DI01dR9P0F6al04aPL020U:@0Y;S808BHZ0`0D6Ad0
700[<3@06QlS00lD600K82@05AXN018G6`0010P04aPL00dB5P0S:2`06AhR01@I7@0G72005AXN010E
6@0C61`07B8V01TN8P0C61`03a@H014F6P0F6ah092PY01PL7@0I7Ah04aLH01HJ6`0A5AH6018F5`04
014E500D61L051PG014E50803a<B1P0A5A@00`0G6a`07b<T01<G600201<G600L010D5@0B5QL0310A
00lC500A5AH03a<D010D5@0@4A<04a@F02HW:@0=3Q004a@F01@E5`0C51H03@h@014B500E5QP04A8D
01XL700:30/05QPG01<E500H6QT01`T8010B4@0E5aH061XI00lA40804Q@C02H03Q0<00d@2@0@4Pd0
4Q@?020R7@0O8Ah030h=00l@4P0A4QH051DI01DF6P0D5AX05ADH014A4@0?3`d04A4?018B400C50l0
4A8=00l@2`0B4`d04a@>014B300?40X05AH@01HG4@0?40/030`<01@D500E5AL03Ph@01XJ700<30/0
6ATG010A300=3PT03Ph<00l?3`804Q8B01H04A4A00l?3`0B4Q805QHF01<C4`0;2`/02@T904m@D00H
6Ad0:2`_00P92`0I6Q`02@X<01dM7@0E5AD03@d=01@C4@0A40h0518?00h:1`0=30X03`h<0P0@3`d0
400?3P`03@`:014@3P0I61H05A@B010?3@0>3@/030`<00X;3@0=4A@0Ad]>0<gAe00R92L010D700l@
4P0@414200l?3`0900l>3@0?3P`03`h<00h=2`0A40h04a8@01@C4@0B4@l071/I00803`h<00h04Q4?
00l>300@3`/030`601DE3@0:2P803@`701HE400?3PT030/700/:200?3P`03@`:01<B40<03@`:00l0
6QTG00h=2`0B4@l02PT700h=2`0H5aD02`X800/:2@0@3`d03@`:010<2@0E4@h03@T600X6100=2@H0
0P0A3@X01P0H51405a<@01LC400A3@X02PH300`;2@803@`:00d030/900h=2`0A40h01`H400@30@0;
2PP01PD301hM6`0G51404`h:018=2@0F4@d04@`800804Pd901803PT500l:1P0@2`L040/700l:1P0?
3@T05A@@00T8100920H03@`800H50@0A40`05A@@00l>2P0F5A402PT5020O6`0;2PH300l>2P0300h=
2@0=30P040l;00D040l;1P0>3@T00`0?3PX040l;00l>2P0200`;1`0300h=2@0@30T040`900@040`9
0P0A3@X0>@0@30T04@d:014=2P0C3``030/600L60@0:2@@04Q4=00l>2P0A40`03Pd;00T81`0A3a00
3P`?014?4P050`@03@`:02<R800H5aD05A@B00T81P0;2PP04A0>010?3@0=30X040l=01@C4@0=30X0
2`X800h=2`0A40h020L500d<2P0:2@L030/900h=2`0?3P`03Pd;00d<2P0;2PP020H701<A4P0B4140
<2h_018@4@091`P04Q0A00h<3@0=2``04@l@010>3`0>30d040X>018=4@0A310040lA01XK7@02028S
9@0A00X:300>30l03PT=00d72`0C3Q805A8C00<10P091`P01`D600l=3P0C4A804@l@01@B4`0@3Pl0
2@L800X82@0>30d01P0A3@h2018>3`804@d>01@040`=00/71`0@30/01P8105iJF@0H51<07a/L014<
3`0A310020<7014<4@0>2@l04`hD00/72P0[9bP020<700l;3@0I5AH01@4201<?40802@D600X05A4B
00h:2`0;1`P04`l?014=300300004Ph=014=300E4A003PX90P0?2`X01P0>2PT03@T800d9200;20P0
0`4201LE5P802@L800@04Q0A010>3`0<2P/03@/<0P0G5AH01P0:20T040/?00l:3P0=20`030L;00d8
308040/?00D03`X>010;3`0A310040/?00`72`0600h<3`0600l=40071@P040hA00d;3P0?3A002`T<
0P0<2Pd01`0=2`h03`d@00l=40091`X030X=010>4@0A3a800P0?3A002`0@3Q403`d@010>4@0=2`h0
30X=00l=400D4QD04Q0C00l=400:20/00`4400804Q0C5?ooool001_ooooo00D02@L800h<3@0A3a00
2`T:00`;2`0700`:2`0K00h<3@0B41403`d>00/92P0>30d05A<D010>3`0>30d04@l@00d;300;2@X0
40l=00l>2`0>3@/03@`:00h=2`0>30d03`d>00h<3@0Q7b80EUAG01@B5@0C4AH020H;00h<3`0B41<0
4@lB00803`d@0P0B41<0:P0C4A@04@lB00l=400@3Q404Q0C01<A4P0D4Q<06aTJ01<A4P0<2P/04Q0A
01<A4P0?3@h0HEmP03dk?00;2@X03Pd>01<C4`0=3@d0410@01DE5@0A4A405QHF00`<300J6QX03`l?
01LG5`0=3@d05ADG01@C5`0G5aX04Q8C01HF5P0;2`T04a@?01@E3P0A4PX05AL<01LI3@0B50P05aL@
01HB3`805a<B00/05Q<B01@B4`0D4Q<05aHF014A4`0J6Q`061PJ014B5P0K7B<03Q4I01DH7`0301@G
7P0i01DH800C5Qh04A@N01@F8@0G6BD06A/X01HH900H6RH06QdV01XM9@0J7B@061/P01DI700M8B80
51PI01HJ6P0<40l05a`J01LL5`0J7aX0>3`i059HE`0H7Ql05a`Q01DL8`0C6R<051`W01/R<@0O9SH0
7RDg01PM<00M8S@08bPj01DK:`0Q9cL0CeET01@J:00G7B/07R@a028X=00M8bl051dV01`U;@0G8RP0
6RD[01HQ9`0M:2h062<Y01/V;00I92X07BP^01PS:@0L9bd062<Y01DS9P0F92L06BLZ00807BX`00`0
6BH/01h[<`0M:S<06RL`020]=P0L:C807b`d028]<`0N:Rl07BX`01l/<P0Q;cH2020_=P0701TZ<P0K
;3@0834i01l`>00L;C@07c4f01h_=P0201d^=@0=01`]=00K;3<0834i01l`>00T=Cd08c@l024b>`0U
=Sh0;D1702<e?`0T=T008cE3020a@@02028c@`0`020b@00R=4007c4l01ha>00R=C`06bhd01T/<P0O
<SP08cHl020c>@0R=C/072le020c>@0O<SP06bhd01X]<`0K;CP08310028b@P0P<3l07Bdj01l`>P0O
<3P072hb01d_<`0N<3406bh/01T/:P0I:RT07bl^01HV9P0E92L05RDZ01@Q:@0M:C005B0V01<N8P0M
:2X0628R01DO7@0L9bD04AdM020/;00I9BH04ahP01hY:`0/=cX0;CPl0P0P:c407`0I92X05R4V010K
7P0D7b405b8T01@O8@0B7Al051lQ01HQ8`0D7b405B0R01TT9P0J9BL062<V01h/<00>6b40;S]303Q5
C@0I9Rh06RL_01LT;@0E8R/0<Ci70<GBf`2^^l@0:cM101HQ9`0N:Bd06RDY01PS:00C7R800P0D7b@0
8`0@6al04ahS01LR9`0D7b<05AlT01LO8P0N8bL061dQ01DJ7P0H7B405Q/O01XO8`0H7B405AXN01<H
700F6al04QLK02P]<@0L8BD0<cPl02H[;`0F6al0:Rlc01LL800B5a/05Q/O01TN8P0D6Ad04AHJ01PM
800D6A`04aPK01@I700E6Qd04aPK00805AXM00L04aPK01XO8P0A5QT03A8E01@H6@0E6AX051PI00H0
4aLH00D04QHG01@H6@0F6Q/041HD01DK6@02014G5@0401<I5`0?5A<051XH00hD4P804ALE00h03aDC
01<I5`0F6Q/041@E01HJ6`0A5AH0?411038f=`0@51D03A4B00lC500D61T041@E00/?40804Q<E00@0
5QLI014B500F5aT04a@F1@0B4aD07P0B4a@0418A010B4@0@4Q404A<B01<E500B51<071hM03Tk>P0C
5A@05ALF01LI600G6AD04A<=010B3@0B50l04aD@018D4@0@4Q404a@F01@E6@0@4AD03PlC01<D6@0J
6Q`05QHD018B400A4@h04Q<>014B3@803a0:00T04A8<01<D300C50`04a@<01<D3P0E5Q003a0;01<C
4`0?3`l00P0A4A<07`0B4Q@03`l>01@D4P0A4Pd051D?018B400@41004Q8B01@D500@41004Q8B01PH
600820P05ADE00T92@0C4a<03a0@02X[;`0T:2/03PlA01PI6`0@4A<03`l?018B4P0A4A4040l=00l>
300A3P`04`l<00l>300A40h00P0C4Q005P0A40h03`h<01<B400Q81h01PD401<B400>3@/04a<C018C
5@0:3Q404aLJ05eQI00B51H03PlA00d>400<30d03Ph>010@400?3`d02`X800h=2`0@3`d300l>3080
3@`:00P051<A010?3@0B4@l02`X800l>2`0A4@X03Ph600l?1`804a8=01<04A0;00d<2@0=30X02`X8
00l>300:2@L040l=014@3P0@3`d04A0>00d<2P0<2`T040l=00h=2`0?3P`030/900h=2`0?3P`03@`:
00803`/800@040`9014=2P0A3@X04@d:1P0@30T500l>300L00`;2@0K6QP08B0N00h=2`0@3`h04a8@
014?300@3@P05a<?00l<1`0A3PT040d9014=2@0@3@P03`/7014>2@0B3`X04Ph:014>2P0?3PX03@`8
00h=2@0C4Ph05aHB01@C3`0@3`/03`h:010?2`804A0<01H03Pd900l>2P0J6AD05aHB00/:1`0@3`/0
3Pd9014@300E51004a8>010?2`0>3@T04Q4=00X91@0<2`L040l;00d<200F5A40;B`X01@C3`0=30P0
3Pd90P0=30P01`0E4@h06QHC01XF4`0@30T030P5018>2`0C3``00P0>2PL01P0@30T03PX700h:1`0=
30P051<?01HE4@803Pd900X03@`:00h=2`0>3@/03Pd;00h<3@0=2``02`T:00h=2`0a<2h03@`:0P0A
40h01P0;2PP03Pd;00d<2P0=30X03`h<010?3@L03Pd;00/02`X800T81`0B4@l03Pd;010?3@0:2@L0
30X;01HD5@0>30d030X;01@B4`0200h<3@0H00`;2`050`@040h?00`:2`0;2@X04P`@00h93@0<2@`0
5QHH02`];`0h>C/071dO00/;3@0>3@l04@dA00X5200B3A403P`=010>3`0E4a@061HG01<A4P0@3Pl0
3P`=0P0=2``01P0>30d03`d>010>3`0=2@X03PX;00l;30<04@d>02@04Ph?010<3@0?2``03PX;00`8
2@0=2@P03PX700l;200B3P`0510?01DA400B3Ph03`/<010;3`0?2Ph03PT=00l:3P0A3@h04Ph=018>
3P0B3Pd040`<00h:2`0<2@T03`/<01TE5P0?2``04@d>00T51P0<20P030P7014=300@30/02`L600d9
200=2@T200l;2P0C00d9200>2PT030P700T61P0F51D0518C00X82@0>30d02PP900d;300C4A803P`=
00P61`0@3Pl03@/<00/62P0@2`l04@`@00h93@02010;3`<03PT=0`0=20`200h<3`8040hA00h03`d@
00h<3`0?3A003@/>01<A500R82<05aDH00d;3P0:20/03`d@01DC5P0@3Q403@/>010>4@H03`d@1`0>
30l01@0U8bH05Q@G01<A500>30l04@lB01Cooooo000Kooooo`0601`J6`0=2``09B<T01XH6@091`P0
5A<D1P0?3@h01P0:20T03@/<00d;300;2@X03P`=01DC508040h?01404@l@00h<3@0=2``04A0>00l>
2`0>3@/03@`:00h=2`0>30d03`d>014?400=2`h03P`?00`:3@0M6b002`T>00d;3P0200l=400700h<
3`0?3A004@lB010>4@0E4aH05Q@G01<A500200l=40805ADE00/06QXJ01<C4`0=3@d04Q8B014A4@0=
3@d02PX:00h>3P0P82002PX;01<C5@0200l?4@0V00h>400<30h0410B01<C5@0G5aT03@d?01XJ700>
3Q00410B00T92@0=3@d04Q8@01hN70092@L02`/801HG4P0G618030d7028S6`0>3`L06a/F01@C3`0B
4@l04A0>018A3`0D4Q<05QHF01lQ800G61X02`/=00T=3P093A004QDK00d@6@0C5Qd04QDJ014D6@0C
5Q/201HI7P1@01HI7`0F6B005aXS01TL9P0Q8c008R@a02<U<@0Q92d07B0W01TL800F6Qd06alP01DI
6P0G6a`04QHG01PL7P0;4A40728P00lE500C61/03A8F00/B5P0A62004a`U01TQ;@0J8c806b@c01hV
=@0I7bl041HT01<I:00M8c404ALU00L=6@0G7BT05Q`W01LN:00I82X06R4Z01LP9`0N9bh062<Y01dX
;P0H8bT06RD[01@O9@0K9R`06B@Z01lZ<00I92X06RD[01<N900D8RD062LZ01/Z;@0J:Bh062L/01LV
:`0A82L08c4i01PV;`0_?DH06bTb01XW;`0R;C<082`b01h[<@0P;CD07R`c01XY<00H9Rl06BXb01`]
=@0N;cT072dg01X[<`0O<3L07Rlf01d^=@0L;C@201X[<P0T02Hg?P0N;cH08C8i02@e?00Q<ST0834h
024d>`0N<3X08S@n02<e@`0O<4008C920352DP0Q<d407Blk01`^>@0M<3L083<j01d^=@0K;3<07c0g
024b>@0O<3L0834h01l`=`0Q<ST07c0g01`]=00K;3<06b`g01h^?P0R<T808C5001`/>@0L;CL07c0h
0P0N<3@0900L;Rl06B/[01P[:@0I:RP05BDT01PX:00I:2X072/^02<`=P0K9bd06bH/049=D@0nBD`0
628S020Z:@0X<c<02A@F02@_<@0F8B<09C0b010K7`0H8bP04ahT01XU:`0W<ST07bTb01LQ:@0C7R80
5B0R01LR900E828051lQ01DP8P0D7b405R4S01TT9P8062<U01`06B@W01PU:`0A7RH0NXN?0;:oa`0b
?dL04b0X01`Y<@0E8RX08c0h07J3R`1]NX805b@/01/U;P0H8bT041/R00lI8P0B7B<05b4Y018L9@0A
728051lV01@N9`0@6b404Q`T01<J800A5QX04QLK0P0D6Ad03P0H7B405a`P010E6@0<4AD06QlS00dB
5P0D6Ad05a`P01<H70021`/04QLK01DJ7P17C5006b0T0`0F6al03P0B5a/051TM018G6P0A5aL04aTI
01HL700G7Ad05A/K010F5P0G7Ad06R0P01@J6P0A5aL041HF0P0D61T201<G60804QHG02@04aLH010D
5@0@51D04QHG014E5P0@51D04ALE01HL6P0C6AL04ALE010F500=4a404ALE00/A3`0>51804aTG01PN
700M8b404ADF018F5`0H71d03A4B018F5`011@H041@E018F5`0D61T0310A010D5@0L82405aPJ014B
500K71h04A8D01<D5P0E5QP5018C5@0A018D500A4a803a4@010B4@0E5aH06Q`K01PJ6@0?4A004Q@C
00/=300F61L02P`;018E4`0B5a<04AHB018G4`0A5Q800P0?4a802`0B5QD04aLH010D5@0>4Q<04QHG
01TI6@0G61<04a@?018C3P0C50l04a@>00804Q<=02@05AH>01HG3`0E5Ph04a@;014B300B4`d03a0;
01LG5`0@41003Ph@00d=3`0?3a403Ph=014A3`0D5A003Pl:01TI5`0G5aL06QXJ01TI6@0B4Q803Ph>
018B4P092@T051@D00/;2`0E5AD05QLF0<G6bP29SI005aPJ00H72@0<3@l06QXJ010@400?3`l2010?
3@04018?3@0D40d03@`:00l>308040l=01803`h<00d<2P0@3`d071/I00X91`0D4a403`h<014A4@07
20X03a0B00D6200L7Al03PlA00h>3P0:2PX03Pd;010?3@0?3P`2018>2`0401DD4P0C4Q004A0>010?
3@803`h<00L05A@B00/:200100002@P601LF500E51004Q8;008041080P0C4Pd0400B4@`071/G00/:
20020@0040l=018A3`0D4a4030/901@C4@0;2PP03@`:01@C4@0=30X03Pd;014@3P0?3P`2010?3@05
00`;2@0B3P/040`900h:1`0?2`P0200@30T00`0=30X040l=010?3@0300h=2`0A01LF500T8b4040l=
00`;2@0H5aD03Pd;014@300?3P`02PT801LF4P0L6aT030/9018A3@0@3`d04A0=014@300?3P`00P0>
3@T200d<200500h=2@0?3PX04A0<010?2`0=30P00P0:2@D01`0?3PX05QHB02l`:`2/[JP0KVmZ00/<
1`0B4`h00P0?40/0500=3PT02P/600X;1P0?40/071/G014@300;2PH03Pd9014@300R8Ad0AdI201LF
4P0920H05QDA00h=2@0;2PH04@d:01LC400M6AH05Q8?0P0@30T02P0F4Pl04@d:014=2P0B3P/03`/8
00h:1`0?3P`05A@B01HE4`0@3`d300l>300<00d<2P0<2`T03@`:014@3P0D4a404Q4?00H50`071P@0
40l=00d<2P0;2PP03`h<0P0>3@/01@0@3`d04A0>00l>300<2`T03@`:00803Pd;0P0@3`d08`0A40h0
3`h<01<B400<2`T03`h<00`;2@0F5A<06QTG00l>300;2PP04A0>00h=2`0=30X03`h<00`;2@0^;B/0
9bHT00h<3@0?2Ph04@`@00l=400A4Q@06a`N020T9@0G6a`010D7010@4P081PT07QTM00P31`0>30d0
3@/<00l=3P0B414040h?00803P`=0P0=2``00`0>30d03`d>010>3`0200h:2`803`/<0P0>2P/2010<
3@0400l;300>2P/03@T:00h:2@803PX70P0=2@H00`0<20L03@T8014=300201<?400300h:2`0=20`0
3@T900803PX702803`/800h:1`0=2@P04@d<01@@3`03000040`=018>3`0<1`/04@d=01HB4@050@00
3@X901hJ6@0E4A005Q8A00/71P091@@040`;00l;2P0B3Pd04Q0>00h=2`0[:RP040l=01XI5`0;2PP0
3`h<00T81P0C4Q005A@B020O7@061@@03`X>0P0D3a<02@0@2`l04PdA014<400B3A404@`@010;3`0>
2@d03@P<00`72`0200`:2`803P`=00<03@/<00`:2`0@3Pl00P0>30d0100K6AX0518C014?400<2Pd5
00d;3PH04@lB1P0>31401P030@H0=S@i00h<4@0=2a00518G00/93QCooooo000Kooooo`060040000B
4140JVQY02<Q8P0H5QL00`421P0@3Pl01`0;2@X03@/<00d;300<2P/03P`=01<A4P0?3@h00P0@3Pl2
00d;300>00l>300?3P/03Pd;00d<2P0>3@/03P`=00l=3P0=2``02`T<01DC5P0?3A002@L<018@5@0>
30l300l=4026010>4@0A3a8040hA01<A500D4QD04Q0C00l=400>30l0410@014A4@0D51@03Ph>00T9
2@0=3@d02PX:01DE5@0F5QH03Ph>01<C4`0;2``04A4C00d=3`0B4Q@0410B00T92`0>3Q004a<E014A
4`0C4aD061PJ00h>400D51D04Q8@01HF500D51807AdK00`<2P0?3`d05QHD010@3P0D51406a`G00l@
2`0D51005QDA01DD4P0D4a4051@B01DE5@0A4a802`d<01<D5P0G6a`06AdN01dQ900H6b403Q4H01DH
7P0A51T04ADH01@H6P0E6AX05QXK01HJ7P0F6Ah05QTP01PK900E5bH06A/Z028T<P0T9S807b8[01LJ
800E6A`061`M01@H6P0E6A`05APM01DI7@0N8bH05a`O01<H6`0Q9RX03a@J01<J8@0F7bP06b@]01lW
<`0H8C005Ah]01HP;@0D6RP04aTU01XP;@0L8S006Al[01lV<00H7bT05ahW01PO9`0I82P06b8Y01XS
:P0L9B`05B0V01dX;P0J9B/072L]01LR:00K9R`062<Y01`W;@0F8BL06RD[01@Q9`0@7R405bHY01/Z
;@0J:Bh06BP]01XY;P0J:C005bH^010N9`0[>D8072Xc01/Z<@0S;CH08Bdc028_=@0S<3P08Blg01d/
<`0L:S<201`]=@0401X[=@0I:S@06R/c01h_=`D07Rlf01009CHm02@e?00U=Sd093Dl020a>00O<3L0
8cHm02<e?`0W>D<09CM5020a@@0Q<T80?4eM02LiA`0R=400838m0P0N<CP0100P<CP07c0g020a>00P
<CP201d^=@<072dd00`07c0g02<d>`0O<3X072`k024a@00P<3d06b`f01X[=@0K;3@06R/b01T[;`0H
:R`201LY:@0K01LX9P0<71T05RHU01XZ:`0P;c80;S]1020/<P0?6R0092lc02Xe>00K9BL07RPY01PR
900951H07BPZ01XU9`0h@dD082/_01@O900C7R@05b8X01dX;`0H8R/06B<[01LR9P0G8R@062<U00<0
5b8T02T04A`N01DP8P0J9BL06RDW01/V:00P:bh082dc014N9P0Z=cl0?4UA00HC6`0E8RX07BXb01TV
;P0>6b<05B8Z01`Y<@0I9Rh07RPa01@N9`0E7bP072H`020Z<`0E7bT04adW01@N9`0E7bP041XT00`F
7`0>5b407B@Z018G6`0F6al07R<W01lT:00N8bL03A8F014F6P0I7R80<CHj01@I7@0201HK7`0L010E
6@093Q806AhR01<H700J7b<05a`P01@I7@0F6al05AXN014F6P0C61/05Q/N01HL700G7Ad06AlO01LM
7@0C6AT04ALG01HL700G7Ad04ALG01HL700D6QX05QXK01DI6P0D61T05ATJ01@H6@804aLH0P0=4A80
2P0B5QL05QXK01HJ6`0A5aD05Q`J01DK6@0A5aD03Q@B00`B400A5aD200dC4@0:014G5@0C6AL051XH
014E5P0>4Q<04QHG01@H6@0H71d04ADF018F5`805QXK00T02@d>01/O800f>S/06a`N01<D5P0O8280
4A8D00h?4@0D5AL01@0B4aD0<@0B4a@04A<B010B4@0A4a805QPG01TK6P0J71/051HE00T;2P0B51<0
71hM00lA400C5QD03a@@00lC4P0C5aD05ATH01@H5`0A5A@03a<B010D4`0>4Q803A4@00lC500C5A@0
4Q<>010A300?40/0414<010A2`0A4P`04a@>01HG3`0G61005AH>014C200<3@L04a@>01DF4@0B4Q80
20P801@D5P0O7b404Q8D01<C4P0A4@l03Pl:01HG4P0L71X00P0I6AT03`0F5QH0410@00d=3@0@4100
30`<018B4P0;2`/04a<C01HG5P0Y:Rh08BDX00`=3`0L7Al051DG00h>3P0200l?3`05010?3@0A40h0
4a4>01DA3P0>3@/0100@3`d0100>3@/010<1014@3P0920H2014@3P0>01@C4@0>3Ph04A8D00d?3P09
2@/04A4A018A3`0=30X04Q4?01DA3P0C3``05A4>01TE4P0D4a42014@3P0:010?3@0?3P`04A0>05IE
D`0M71X03@`:00X91`081`H04a8>010?2@803Ph600D03`h9010?2P0@3`X02PT500X91`02010?3@0:
00@30@0?3P`04Q4?00l>300920H03Pd;014@3P0<2`T04Q4?01DD4P804Q4?00@040l=00`;2@0E4@h0
4Ph;0P0?2`P00`0@30T04@d:010<2@05010<2@0H00h=2`0<2`T02`X800d<2P0A40h04Q4?010?3@01
000030/902LV900D4a402`X800L6100C4A802PT800h=2`0100004Q0@010?3@0>30d03`h=010?3@0>
30d03@`90P0=30P200h=2@0500d<200@3`/03@`800/:1P0?3PX00P0@3`/01P0F5Q80ADI10>?Tg`28
RH@01PL2014B3@80414<01L03Pl:00/<1`0<3@P0414<01TH500C4Ph04A0<010?2`0=30P04Q4=01PG
4`040`003`h:01<B3P0920@030/700L3000=2@H0510=014=2P0?2`P040`901HB3`02014=2P0901<?
300?2`P03@T600D40P0;2PP03Pd;00`;2@0@3`d04A0>00803`h<00/03Pd;00l>300A40h04a8@01DD
4P0?3P`06APF00`;2@0920H04A0>00l>300200h=2`03010?3@0A40h03`h<008040l=0P0>3@/0900=
30X030/900<2000C4Q003`h<00@30@0@3`d020L500d<2P0B4@l03@`:00/:200@3`d03`h<00X91`0>
3@/020L502d/:P0Z:BL04Q4?010;3`0@3Q403Ph@00h?4@0C5aP061`M014E5P010P@04Q<E00X82`0c
;S803PT=010>3`0>30d03@/<00h<3@803`d>00L03P`=00d;300=2``03P`=00l=3P0@3Pl04@d>00<0
4Ph?0P0@30d00`0?2``040`=010<3@02014=3P05014=2`0A3@X040`9010<2@0>2PL00P0>2PT01`0?
2`X04@d>010<3@0>2P/03PT=00h:2@0=2@H00`0>2PL09@0>2PT02@D501<?3P0=2@X030P900<0000>
2@d03PX;01LC4P0?2`X05A4@00X61@0300004`l>00D1000;1`H0<Bd/02/W9P0@30/02`T8014@3P0`
;bd05A@B01dL6P0@3`d02PT702HU8`0h=cD00@0000L6100@3`d040/?01D@500D3a<040/?014<400@
2`l00`0A31001@0@2`l03`X>00l:3P0<2P/03@/<00<03P`=00`03@/<010>3`0@3Pl030X;01HD5@0B
41404a4B01<A500@3Q403@/>00l=400A3a8700l=40H03P`A00H0108700`:3`0A3a@01P@9014?500@
3Q<Dooooo`006oooool200d;3004024O80030@804a4B014?40L03`d>01X040h?00l=3P0>30d03P`=
00l=3P0<2P/040h?00d;300<2P/03@/<00d<2P0?3P/03Pd;00d<2P0>3@/03P`=00l=3P0E4a@01P@7
018@4`0I5aX03P`A01PF6`0D4QD04@lB010>4@<04@lB00L040hA00h<3`0?3A0040hA00h<3`0=2`h0
4A4A00804a<C05P04A4A00l?3`0A4A403`l?01dM7@0Q8B404A4A00d=3@0D51D04A4C00d=3`0I6A/0
61PJ00l?4@0G5aT0410B00X:300F5QP030`>014A4`0>3`d03a0;01@E400>3`X07AhI00l?3@0@40h0
5aLH00d=3P0F5AP02@T;01@C5P0C4a804aD@01DF500F61D051LD018E500B5QD051TH03]0@@16C4`0
5Q`L01@I700I7B804QDL01LJ7`0B5QP04QHF01PL6@0C5aD05ATG01HJ6@0C5aT051LK01XN900M7S00
71db01XL;@0I6bL06A`U01XM8`0H72005a/N01TL800H6b408B@[01PK8`0E6R407R<X01HJ8P0F7B@0
7bH^01XQ:P0H8BX07BH_01hX<P0G8Bd04Q`X01@N:@0F72L06R4[01hU;`0G7BP05ahW028Y<00C6R40
5ahU0P0K8RL02@0J8BD05b4T02@]<`0I92X082/a01/V;00J9B/06B@Z01dX;P0201LR:00D01<N900N
:Bl07R/a01DS9P0K:Rd07Rd`01`[<00H9b`05bH[01TX;`0I:3006bTb01`Z<`0O;CH082lg020Z<`0O
:c808Bhf02<`>00S<CT2020^=`0901//=P0I:S@06R/e01l`>P0Q<S/06R/c01//<`0L;C@07c0g0080
834h01L08cDi02i0A00/?T8093Hj028d>00S=3X07S4h01la>`0R=3h08C=1024b@P0U=TH0;3e=020b
@00Q<cl08C<n01`_=P0L;cD06R/a01d_<`0L;S807Blc01h`=00201d_<`0T01X/<00H:Rh07Blc02Dg
>`0S=3`0830m02@d@@0R<Sh072dg01`]=P0J:c805RL^01LY;@0H:Rh06R`_01/]<00L;Bd052@Q01PX
9`0F9RL052<V01/X;P0E8BL06RD[01TT:P0H8RH04adO010J6`0D7b004ahP010K7@0I92L05b8V01hY
;@0G8RL05b8X0P0G8BX0:@0E7bP06B@[01DS9`0D8RD04b4T01@R9@0E8bH0528U010N8@0C8B@05bDX
01HT9`0E8bH062HY01<P9`0F8b/072Ta00hK8`0L:C40524Y01/X;P0H9B/06BH/01HS:@0I9R`04AhU
01/U;`0=5b805AlZ014K9`0G8B`05R0[018L:00D7RT05Al[01HP;00H8Rd05b4/01LN900I7R805Q/O
00804aPL01P051TM014F6P0F6al07B8V034f>P0G72005Q/O01`Q9@0?51P06QlS00`A5@0D6Ad03a@H
01@I7@0@5AT051TM01HK7`0C61`04QLJ01@I700C6AT05A/K01LM7@0F71`201<I6@0601DK6`0:4100
4QPH01HL700D6QX051PI0P0A5AH0100E6AX051PI014E5P0B5QL201DI6P0:01<G600@51D03Q<D014I
5P0A6QL04a`I00lH5@0<5A803QLD010I5P804AXG00`04a`I014J5`0>5Q<04aLH00lC500<41405ATJ
00`@4@0C5aP051PI00lC500A5AH201<G600701LK700@4A<06a`N030a<`0R8bD04Q<E014B5005018C
5@05014B4`0@4Q404Q@C01@F5@0C5A@00P0B51<00`0F61L02@/:01@F5@02018D4`0401@G5`0?4a<0
3A4B00hB4`8041@D00L04ADD014F4`0A5Q<041DB010E4@0@518041<>00804A8=01P04A8<00l@2P0A
4P`04A8;018C2`0D5@d051H;01<E2P0A4`P051D?014B300=3PT05ADE010@400N7R005QHH010@4P0G
5aH02@T700l@2`0E5Q404Q8@00l?3`0>3Ph2010@400C01DE5@0?3`l04a<C018B4P0;2`/03`l?01DF
5P0=3Q804aLJ00d>400H6A/03PlA018B4P0?3`l0410@018A3`0C4Q004a4>01@@3@06014@3P04010?
3@0E51804a8@014@3P8040l=01@04a<B00X9200G5Q@03`h=014?300A3@X040`901@@300D3`/04`h:
01D@300H510040h;00`;2@0B4@l04a8@00l>300D4a407QdK00/:20803Pd;01H071/I00`;2@0A40X0
4A49010@200?3PT040l:014@2`0@3`/01`H4018A3`0>3@/08R4O05=BD00Q81h02PT700h=2`0B4@l0
3Pd;014@3P0C4Q0051<A0P0@3`d0200>3@/02`X801PD4@0D40d04Ph;014=2P0B3P/04`l<1P0@30T0
6P0=30X030/9014@3P0C4Q0040l=00h=2`0F5A<061LE010?3@0?3P`040l=00h<3@0@3Q004a4D01`J
702a[k40G5YM018@4P0>30h03P`?010>4@0B41804Q0C00l=3@0=30P03`h:100@3`/02P081`<02@P4
01XI5@0J6AD04A0<010@300;30P0>S/f02@U800G61<200X;1P0300`=200?40/03Pl:00803@h902/0
40l;00h=2@0?3PX03`h:00h=2@0@3`/05A@@010?2`0?3PX01@@100`;1`0@3`/03`/8010<2@0A3@X0
3PX700l;200C3``04Ph;00l;200@30T04`l<00l;200=2@H040h>01<A4P0A40h03@`:00h=2`0=30X0
3`h<014@3@0C4Ph04Q4=014@300>3@T020L500l>300H5aD02PT7010?3@0:2@L03@`:008030/900<0
3Pd;00l>300=30X01P0>3@/01017AT@040l=01<B400G5Q@2010?3@0:00P71@0?3P`04A0>010?3@0>
3@/02`X8014@3P0?3P`010<2010?3@803`h<01<04PhA014?4P0>3Q003@h@01<G600I7Ah03Q8C00H7
2@0D5AL03`hA03<^<P0D3a<0518C014?400?3@h03@/<00l=3P0@3Pl03P`=00803@/<00@03P`=00l=
3P0@3Pl040`=0`0A3@h2010<3@0901HB4`0E4A804`l@014=3P0?2``03`/900l<1`0@3@P04@d90080
4@d:00P04@d;014=300A3@h03`/<018>3`0F4Q<05Q<@014>208040d801P04@h9014=2P0A3@/030P7
018>3`0<1`X04PdA010;3`0?2``0510?00`81`0@30/02PH602TU901?BdX06ADD00`8200D40l04Ph=
00d9200<2@P030/901<B400:2@L200/:200301/J600510<04A0?008051<A00l030/900h9300B3A40
4PdA00l:3P0@2`l03`X>00h93@0?2Ph040/?014<400B3A404`hB00h<3@0?3@h00`0@3Pl200l=3P0:
018@4@0;2@X04Q0A010>3`0B41405A<F010>4@0=2`h040hA018@4`L040hA1P0>3140100H5Q/03@/@
00h<4@0=2a0200l=4QCooooo000Kooooo`0600l=3P0B41401@<400X82@0A3a004Q0A1P0>30d300d;
300500h<3@0?3@h03@/<00`:2`0B41400P0=2``0700>30d030/900l>2`0>3@/03@`:00h=2`0>30d0
3`d>00T7200<2Pd03P`?01/I700=2a001P@901LE600A3a803`d@010>4@0?3A003@/>00l=400>30l0
40hA018@4`0=2`h02PP;00d=3@0@410200l?3`804A4A01l05ADE014A4@0:2PX03`l?014A4@0?3a00
3`hC00`;400C4QL04A0E01<B5`0M72403`hC00h=4P0@3a@05A@I030_=00D51804a@>01@E3`0_<2X0
Ce1;024Q7`0:2P/04a<E010?500J6Al0F5MM01/J800D5AH04AH@00<04AHB03h04ADD00lE4`0>5180
4QPH01PN7@084A005alQ02L^<P0A51/05a/O010D4`0@5A406AhG01LL5P0H7AL061dH01DI600H71d0
8bH/03DfBP0_;dL08B8e01HH9`0D5R805QTP01`O900I72407B0U01/N9@0[;SL06adY02X^>@0L82T0
5ahX01PO:@0I82X08b`e01@L9`0G7bX0628/01DO:@0D7RP05b4[01@K9@0G7RH06R4Y01/R:P0L8bT0
6b8X01HM8`0L92L07bLY01dU9`0L92H072HX034j?`0P:c409C0f01lZ<00M:2h07bX`02<^=08072L]
01`062<Y02<^=00R;cD07bd`020_<P0S<SD08c8g01d/<@0F9BX03ahU028a>@0>72D09cDn055OJ00`
?TL08R`e01l[<`0N:c<082de028_>00P;SL07bdf01LX<P0H:C<07Rhk024a?P0P<C/07Rlg0P0O<3L0
1P0P<CP0838f020b=P0]?d<0<TA802Xl@0808C<e01<0838f020c>@0N<3X07c4k01la?`0V=dL0;Sm?
01X[>`0I:cT07Blk01d_>P0J;C@07C0f02Lh?P0Y>cl08C<g01`^<P0J;3005RP/00807Blc02@06bda
01T[;`0K;C4072de01d^>00O<3X072dg01LX<00H:C405bP`01DV;@0G:2l06R/b01/]<@0J;3006BXY
01/[:00H:2L06BPY01TX:`0G92X06bL^01lY<P084aT05AlT02<];`0:51D04ahO01dX:P0F8BD04QdQ
03e8C00]>3h04QdS01@O9@0F82T201PR:`0801HP:00K:2h062HY01DS9P0H9RT06BLZ01PV:@0G9BP2
01HT9`0d01LU:00F92L04b4T01LT;00K:3007BXb01LT;00J9bl082dc00lL8P0E8RP04QlU00XH6`0B
82<0=D=704MAG@0L9C@051d/028[>P0g@4l09c0o01<L:`0D7B`04a`[01XS<P0Q:ST06b@a028Y;`0K
82@05Q/O02X_<`0e>Sh051TM018G6`0@5AT03Q<G014F6P0?51P03A8F01DJ7P0=4QH06b0T01XO8`0E
6Qh06AhR028W:`0C61`04QLK01PM8@0I7R805a`O018G6P8041HF01P04QPH01<I6@0B61P051XJ02@Z
:P0;4A40728R014G5`0C6AT05QXK014E5P0B5QL05a/L01HJ6`0B5QL05ATJ01HJ6`0C5aP04ADF01/O
800R:2P04APF00hG500A6QL200dF4`0401<L6@0@6AH04Q/H010I5P805AhK00T041TF00`@4@0D61T0
4ADF01dQ8P072``06AdN00`@4@0I7Ah00P0D61T0200G6a`04aLH00`=3`0I6Q`09RLY01dN800E5QP0
3a0B1@0B4aD00`0A4a<04A<B018D4`02018D4`0;014C4P0@4Q406A/J01<E500F61L02`d<01/M700J
7Al07B8U01DJ7@0?51L00P0?5AD02`0@5Q@04ALC010F4P0A614041L@00lF3`0?4`d04Q<>01DF4@0D
5A004Q<=008051D=01T04149010B1`0@4PL04Q@901@F2`0=3PP03Pl901<D3`0J6QX03Ph>01LG6@0[
:bd02@T;01dM700K6aT0414<01@E400G5aD04Q8B010@400?3`l030`<00l?3`092@T05ADE00804a<C
00X061PH02DV9P0G61`06AdP010A4`0O828051DG014A4@0@41004A4A0P0C4Q000`0C40h04Ph;014@
3P04010?3@0<014@3P0=30X030/9014@3P0<2`T040l=014@3P0C4Q0040`901<?300L61D05Q4>0P0D
3`/00`0B30P04P/501@=1`0201D>200K01DA3P0@3`d06QTG01/J600B4@l05QDC00/:200F5A<051<A
014@3P11@3h09RDQ018A2`0C4`/04A4900h=200?3PT04Q4<00X91@0:2@L03`h<00d<2P0;2PP08B0N
01@C4@0:2@L02`X800<03Pd;0P0@3`d0100<2`T040l=01DD4P0C4Q0201<?3003018>2`0A3@X040`9
00L040`901T051<A00X91`0D4a407A`J01LF500>3@/02@P6018A3`0?3P`03Pd;01HE4`0@3Q000`46
014?500`;S<0<S0e01hL8@0F51T03`dB00h<4@0@3Q<04@lD010>4`0@3Pl040l;00803`h:0P0>3@T0
400B4@d02`X600L60P0<2`L02PT500d<200A4@d05aPC01`M600C50l030d8014B3@082@@02``700l@
2`0>3`X200d>2@0401DD400D4`l040l;00`;1`803@`800<03`h:00L60P0@3`/00P0C4Ph04@0:2@H0
40`900l;200=2@H02PH300/7100>2PL040`900d91P0A3@X05A4>018>2`0@30T02PP900`:2`0;2@X0
30/9008040l=00@03@`:00l>2`0@3`/040l;0P0A40`01`0A40h03`h<01@C4@0@3`d03Pd;00D40P0>
3@/00P0=30X01@0?3P`040l=00h=2`0<2`T03@`:00803Pd;0P0@3`d02P1jNGL07ahL00l>300@3`d0
1PD3014@3P0=30P04A0<018A3@0@3`/200/:1P0I00`;1`0?3PX03`h:010?2`0=30P061LE01<?4@0C
4A@0410B00h?4@0A5AH05QXK00P<3@082@/02P/=00`;3P0B3A403@P<01DC500D4Q<040h?00/92P0<
2P/03`d>00h<3@0200d;300600h<3@0?3@h040h?00h:2`0?2``040`=0`0A3@h01P0E4A804`l@018>
3`0?2``03@T:00h:20803``700@040`8010<2@0@30T04@d;0P0A3@`04P0?2`/04@d>01DA4P0G4a00
514:018?200A3PP040d8014=2P0B3P`01`<201DA4P0@30h091lS00/62P0a;Bh03`/:00@000804@d<
01L03PX9010<2`0>2PT03`/:00d9200:1PD03PX9014?300=30P03`h:010?2`0B4@d040l;092?R`18
Ad<02`X600l>2P0A40`04Q4>00/7200@2`l04@`@00h93@02010;3`803PT=00H03`X>010;3`0@2`l0
4@`@00d;300>30d300l=3P0=00h<3@0<2P/04a4B00h<3@0A3a003P`=00d;300@3Q403P`?00d;3P0>
30l03`d@00h<3`06010>4@0300h<4@0>2a803P/B00<03P/B00H01`@;00l<4`0710/030T@01LD6`0>
2a8Dooooo`006oooool01P0:20/03P`=00`:2`0>30d02`T:00d;30H03`d>00D02@L800X82@0<2P/0
3P`=00l=3P0200d;300801<A4P0>30d03P`=010>3`0=2``03`h<00h=2`0=30X200h<3@1W00l=3P0@
3Pl061HI01@B5@0<2Pd02@L<01`J7`0H5QX040hA00d;3P0>30l03@/>00/9300>30h040hA01@B4`0E
4a@03@/<00P61`0=3Ph0418A00lA400@4Q804a@F01@E5`1VIfT0;Rla01<D5P0@4A<04A8D01<B5P0D
4aP04a8H01<B5`0>3A806QTN028Q9@0>3Q004a<E00h>400U9BD0Bd]=010@3@0@4@/04a@>010A2`0T
92804A4?01@D5@0<30h03PdB02HU:`2YZ:h081lU014A4`0D6AD04QHE014E500B5QD051PG01<H5`0H
7Q`020h>01TO7`0M8b<010d<01<G6`0A51T05QXL00lC4P0>4`l05a`G014F400C61804QLC00hB4@0B
5QL082@X01XL:`0J6bl06a`]01TK:00G6BD05QTQ01/N9@0G6Ql071lV01XM9P0/;cP06A/W01/O:P0J
7RT06b4[01LK9P0J8B/0620Z01HO:00G82T05QlY01<M9`0C7BH05R0Y01HM9@0201`S:@0V01<J800F
7B807BDX01<K7P0H82806B4S01LO8@0H828072@W02Xc>00H8RP07RT]01XS:00J92P07bX^01hW;00H
8RH06B@V01@N800K9RP06RDW01LU:00G9RT072/^01l^<`0K:Rl04R4V02Dd>@0eA4X05B@[06=bN@2f
`lH0NhR@02Hc>`0S;cL082de024^=P0R;cP2024_>00G01XX<`0J:cD0830j01h/>@0H:C<07Bhf01`]
=@0K;3@06R/c01TZ<@0I:bl072hb01d_<`0I:bl07S0b02Hh>P0U=c/08cHl01ha>00L;SP06R`g024c
@@0[?D/00P0O<Cl02`0R=4007S0k01`^>00P<cX07c0h02@e?@0N;cH06R/b01/]<@0H:Rh06B/_0080
7S0d02d06R/b01TZ<@0K;3@08C8j028c>`0N;cL06R/b01`]=@0H:C0052D/01HW;P0J:S405bP_01PW
;00E9BD07RlY01LV8@0F9B@05bDU00hL7@0B7b808B`b01DP9P0D7R@05QlT00`E6P0H8BH06B@X01lX
;@0J92T0XJb`06efN`0L9R/05R4U01DN9@0D7RD05b8X01DO9P0K9R`05B<V018P8`0E8bH05bDX01DS
9P0J:2/00P0G9BP0=@0L:Rd07B/^01TW:P0D8BL082dc01PT:P0L9bd03Q/Q02Hc=P0G8RH072X]01XV
:P0C7R802ALH01/V:`0`>T@03QLV00lG9@0@62D082Pe01XR;`0H82d05Qh[014K9`0G8Bd072Pd018M
:00<4a/05a`R00dB600D6Al082D[00H;3`0A5QX04aPL01@I7@0@5AT061dQ010E6@0<4AL0728X010G
7@0@5A/05Q`Q069ZK@0^<cL05QdP00lG6P0I7R80728V01/P8`0I7R405A/K00804ALG03804QPH010F
5P0G7Ad0<SPh01@J6P0V;2`04ALG01HL700I7al05AXJ01DK6`0L8B406QhO01HL700?51@03Q8C00`B
4P0P9BD0C51A06AZJP0B61H03aDC014G5@0=5Q@03QLF01DN7@0B6aX04AXI00`E4P0B61H051XH00lE
4`0@51D05a/L00hB4`0J7Ql00PH701XN7`0A5AH020`=00L;300Y;Bh0<cLh020T9@0E5QP04A8D00l@
4P0:2`d04Q<E010A4`D04Q<E0P0B51<2014C4P0I018D4`0C5A@04A<B01PJ6@0E5aH051HE00P:2@0M
7ah05aXK01hS9P0E6A`03A8E00`B4P0?4a@041DB00lF3`0?50h03aD?00hE3@0>4``03A4:018C3@0E
5Q4051D?018C3@0201@E3@0J014B2P0?4@H04187018D2@0F60h03@h801@E400C510020P600D51@10
@400N7Qj028R8P0d=3<0>SXh00T:1@0E5Q40410>00h>300A4@l051@D018B4P0D51@03Ph>01XJ6P0C
4a<200d=3@0?01PH60082@/0414C00P92P0B4aD01`T800d=3@0A4A404Q8B01@C4@0C4Q004A0=00l>
2P0@3`d03`h<00803Pd;01H03`h<010?3@0C4Q003`h<01<B400;2PP03Pd;00l>300?2`P04`l<00D1
000G4a00510=018?2P0I51404`h:014<200D3`/05a4<01<>2P0A3@X030/90P0G5Q@06@0;2PP03Pd;
00`;2@0@3`d06APF00d<2P0W9R@04Q4=00l?200A4@T03`l700/:1@0<2`H03`h901DD400A40h030/9
01DD4P0<2`T02@P600d<2P0D4a403@`:010?3@0F5A<00`0A40h01@0>3@/05A@B01dL6P0M71X040`9
00<04@d:01`03`/800h:1`0@30T040`900h=2@0?3@T040`900h=2@0_;R`04A0>00d<2P0D4a4040l=
00/:200F5A<03Pd;018A3`0G5Q@03@`:00h<300G5AP04Q0C014?4P040PD09bDX00T72P0>30l030X=
0P0=2`h04P0;2@`03`d<018A300@3`/03@`800`;1P0;2PH02`X500h=200J6AD08b8N00l>2@081`<0
3@d800h?2P051P40414<00l@2`8030d801403Pl:010A300?40/03a0;014B3@0:2@D03Pd9014@300B
4@d04A0<00d<200F5A402PT501DD400?3PX01PD100d<200400h:1`0K00l;200B3P/040`900h:1`0B
3P/05a<@01@@3@0B3P/03`h<014?400>30d03@`:014@3P0?3P`03@`:00`;200<2`L03Pd9018A3@0E
510020P600/;2@0C4a403Ph<00T9200G5Q@03`h<00803Pd;00<040l=014@3P0?3P`00P0@3`d200h=
2`0W00d<2P0<2`T03@`:00/:200@3`d03@`:014@3P0920H03@`:00h=2P0?3PX03@`:00/:1`0=30P0
2`X800l>2`0C4Ph03Pd:00<2000920H04PlA01@B5@0C4aD03a0B010A4`0C51H02``>00h?4@0<30h0
4a8D00P62@0D3a<05A<D01@B4`0@3Pl02PP900/92P0=2``03P`=00803@/<00H03P`=00l=3P0@3Pl0
40`=014=3P0B3Pl301@@4@0300d92P0>2P/03`/<008040`=00<04Ph<018>2`0B3P/00P0A3@X09@0A
3@`03`/:00h:2@0?2`X03PX:00d92P0>2P/04`l=01@A300B3`X040`800l;200@30T040`;01HB4@09
1@H04`lA0:2KW`0f<CD03PX:01@@3`0I5A@03PX900/71P0B3Pd04@d<018>3@0>2PT030P701@@3`0B
3Pd02`X700D4000>3@T03@`801<B3P0<2`L00P0J6AD0200:2@H02PT501DD400<2`P02`L8010;3`0A
31003`X>0P0A310600l:3P0400`:3@0=2``03P`=00h<3@803@/<00H02PP901<A4P0?3@h04@l@00h<
3@0;2@X600l=40D03@/>00d03@/@00h<4@0>31803P`A00h;4P0>31803P`A00l<4`0:1`d07adR014>
5@0R82H05A<H01Cooooo000Kooooo`09010?500;2`h05ADG00H6200<30d020P800h>3P0=3@`03Ph<
00803`l=00<02@X600`:2`0>30d00P0?3@h0200>30d030X;01@B4`0?3@h04@l@00h<3@0<2P/03`d>
0`0?3@l300l=400<00h<3`0F51L02PP;01<A500@3Q406QPL01LE6P0@3Q<04@lD010>4@0>30l040h@
0P0@3`h06@0@3`d03`h;00h=2@0=3PT03a8=01<H500A5Q@04ALI018I7P0V;c<0^/;903e3BP0A5Q`0
3a<I014D600@41H051<J01@C6`0C4QP05aHK01DE5`0A4A40410?010@3@0@4@d00P0@4@X0400A4P`0
3a0;010A300F5Q<0410>01hN700A4A0051@D01HF5`0H5aX05aHJ01DE600D5AP05QLK01<D600D5AT2
01@E600U014C5@0P8b@09BPY01@G5`0D5aH07R4P020Q900?41@0824U020Q900B4aH05aPK01TJ6`0G
61T051HF020Q8`0X:B/06ahO018E6P0B5ad05Q/Q01TN9@0I7BD05AXP01LL8`0E6R405a/T01HJ900B
5R405ATT01HI8P0I72D06QhW01HI8P0E6B806QlX01TP:00201PO9`0901LP:00I8RT072D/01<I7@0M
8RH05Q/N01dR9@0J7b<05AXM00806b0S01@05a`O01TN8@0N8bH05QdO01dU:00J8bH05b0S01XR9@0M
9RL072DU01PQ7`0J8b405AlJ01PQ7@0N:280628P024]<00K:2h0524W01h/;`806bT/00T06bT[02Pf
=`0P;Rl05R@T04iLG00e@dD06bP`01dZ<`0P;CH00`0R;cP02`0P;CH07R/d01d[=00P;CH08Rli028`
>P0N;SX0830l01l`>`0N;cP072de008072dd08008cDi028d>00U=c/093Hh01la<`0O<cH07C8f01`a
=@0M<SH07S8h01lc>@0K;cL07c<l02<g@@0L<3/05b/f01d_?00P;Sl082dn01d[>@0J:3806bXa01d/
<@0J:B`07B`a01h]=00I9c007bdg01d^=@0L;c@07c8g01la=P0L;S8072dc01TY;P0E92T05bD[01XW
;@0I9b`06BH/01LU8`0D8aT04b0G01@R6@0G91`05R<L01@P700G8R<06bHY01DP9`0@6R@051hY01dU
<@0V;SH08RTa01/S:00W<38092`^01XS900E7al07BDV01PQ8`0A6Q`07BHZ01`V;@0D7bD05B0V010K
8@0E82H06RD[01TT:P0O:S006bH/01@O9@0N:Bl05R4V01hY:`0K9RL06B<U01/U9P0J9BH05b8S01dW
:@0L9RP06B<T01LQ8`0H8b<06R@V02H_>@0Q:CD061l[01HI9@0G6RD05aXT01DI8@0D6b8051dS018P
900@8B@0428V01HO:00I7BT04ADP01LK9@0I7BL0314H01<H7P0E6Ql04AHJ018G6P0E6Qd04ALK018I
8@0Q:C804AXQ01PP:00D6b80IFic04M?E@0E7R404Q`N01TR900@6Q`092`^01DK700P9RH04QPH01XP
80804aTI0P0E6a/0<P0A5aL051XJ01`R8P0K8B405Q`O00hE5`0B6Q`04aXM010F6@0A6A/03QHH03@j
?@0F7R004QTL07AjO@1JH6005ALE00`?3P0>4Q405Q/M00TA4`0A6A/03ADH014F6@0D6QX05aTI01PI
5P0I6QP051HE00/=300g>CP0=3He01@F5@0@4Q405QPG00/=300D5QD07b4P01`N7@0@4Q404A<B01<E
500?4A004aDD00lA400C5A@04Q@C014C4P0B51<051HE0P0C5A@0900E5a@051HC010B3`0?4@h04A<@
01@F4`0K7AX05aTF01<E4P0@4Pl030h;01<E5P0B5AP04A8E010B4`0@4a804aDC020S7`0J7AP03@l9
00hB2`0@50d041<;018D2`0G6100414:01@E3@0<3@D05aP@02h_9`0E5Ph0414901<D300B4`/04A8:
01HG4P8051@B01L04Q8@00H6100];B/0De=B02@T8P0=3@/061PF00h>300O7a`0=cPc02X[9@0C50l0
3Ph;010A3@0>3P`06QXH04I6A00[:b/03`l?01@D500?3`l0410?014A4002018B4@07010@3P0?3`d0
4A4?00d=2`0B4Q003@d;018B400=014@3P0301<B400B4@l040l=008040l=00X04A0=01@B400A3P`0
514?01TF500E4Q002PP501DD4P0?3P`0@3lm0P0A40h02@0C4Q005A@B00l>300@3`d04a8@018A3`0?
3PX04Q8;018B2P02014A2@0E010?2P0?3PT03`h:01@C3`0=30P0;Rd[00H50`0C4Q005QDC024P7P0D
4a403Pd;00`;2@0C4Q005A@B02DT8P0=30X03`h<00P71P0A40h03PX700804`l<00h04@d:00h=2@0@
3`/04A0<00`<200=3PT02`/701DE4@0;30P07AdL018B4P092@T03Ph>014@3P8040l=01H040`901DA
3P0O6aP071PD014>2P0?3PX04A0<010?2`0?3PT040l;01<B3@0>3@T030/7010?2`0>3@T030/700h<
1`0?30D03``6010=1`0A3PL04@h80P0A3PL2014>2007014>1`0@3@L03Ph900h?2P0?40d061TD014B
3@0300d>2@<03Pl:03L03a0;00h;200B3P/04Ph;010<2@0C3``04Ph;014=2P0<20D03`/801DA3P0B
3P/040`901<B3P0>3@T03@`800P71@0@3`/04A0<00h=2@0=30P03Pd9010?2`0A40`03`h:010?3@0=
30X02`X800l>300B4@l03`h<00h=2`0?3P`040l=01PG5@0K6QP02`/900/=300:3@`03A0?00lA400<
3@d030d<00`<300>3Ph03`l?010>3`0?3@h03@/<00P61`0f=3D04@l@00/92P0?3@h03@/<00803P`=
0P0?3@h2014?400K00`:2`0>30`02PT8010>3`0>30`0518B00l=3P0?3@d040l>018@400>30d02`T:
00h<3@0;2@X030X;00h=3@0<2`/02@P900h=3@0<2`/030X;00l=3P0@3Pl03`d>010>3`0A3a000P41
00803P`=00<04a4B00l=3P0?3@h00P0>30d02@0=2``02PP900l;300D41402`L801PD5@0N6Q/04@d>
010<3@02014=3P08010<3@0>2P/03`/;00l;2`0A3@d03PX:014=3@0C3a0200d92P0G00h:2`0@30d0
4@d>014=3P0K61T0<2h^00h<3@0_;Bd04Q4@00h=300<2P/061HG00D3100B4140>3Hg01hL7@0;2@T0
3`h:014@300?3PX030/700h=2@0?3PX00P0>3@T0100?3PX040l;010?2`0=3@X200/;2@0F01PH5P0B
4Q003@d;014A3`092@P05ADC00h>300@40h02PX800l=3P0=2``03`d>014?400@3Pl03@/>010>4@0:
20/0;B/`018@5@0:20d0518G00l=4@D03`d@0P0>30l03`0=2`h040hA018@4`0@3Q403`d>018@4@0D
4Q<04@l@010>400<2Pd03`d@00d;3`0=2a003`dB014>5002010>4`05010>4@0=2`h02`T=010>4P0:
20/00P0?3A40100A3a8030X>01DC5P0@3Q4Dooooo`006oooool03P0<2a0020P;00/;3@0?3a405aLH
01HF5P0>3Ph05QHE0000000A4@l05ADB02`]:00=2``03`d>0P0@3Pl0200?3@h03@/<01LE5P0;2@X0
40h?00`:2`081PL0518C1P0?3A003@0>30l02@L:010>4@061@L06aTL010>4@0H5Q/040hC018@5@0A
3a8040h?01<A4P0@3Pl00P0@3`d3014@300700L80`0M7a`01PX900`C500<4aT03aHL01dT;00200<8
3P0S010B600?41D03`hE014@600@3aD030/A01DD6@0D51H03Ph>00l?3@0?40/0414<014B300A4PX0
6Q/E06AUH00D5A003`l<00`<2P0410@05aLG01<C4`0@41803`lA018B500E5AL061TL00`=4P0I6Ql0
5QLK02@U:@0A4QH04Q<F01TJ700O8B000P0G6AP0700I6aX05aTI00`=3`0T9BL0;2d_020Q8`0L7Al0
6AXL01TK6P0H6QT06adL01hP7`0G6QX051PK01@I7@0G72005a`R01DJ800B5ad061`U01HJ8`0H72D0
5a/V01@H8`0G6bH06ahW01`O:00K7RL201HI8P0;01/O:00I82P05ahV01<J8P0B6b805AhU01/T:P0L
8BD082DX01hS9P0H7B000P0J7b805P0K82<06QlR018G6P0S:2/04aPK01`Q900K8bH05alR01PP8`0K
8bD06R<S01HO7P0E7Q/0624N01PQ700J8ah072DP01HQ7@0@6ad08Rle00TF700O;C02028`<`0<01`Z
:`0M:b/06bTY01PV9P0K:BT05bDV01DR:P0K:3408Rlh02Db>`0T<CX08Bhg0`0S<3T0:00Q;SL07BXc
01/Y<P0M;3T072`i01l_?00R<cd07Bhf01TZ<P0M;SD07c4e01h`=00P<SH08C<e01h`<P0R=SL07S4e
01d`=00N<CD08C@j028e>`0O<ST07c4k024c?@0K;CT05RPd01T[>@0Q;d807R/n01h[>`0N;3L062L^
01DT:@0K:Rl06RT`02<a>@0H9Rl062Ha01//<`0J;C4201h`=00501T[;`0I:2d05bH[01HU:P0G92X0
0P0F8bT0100E8RP05b@T01PU7P0G91d201@Q6P0F01LT7@0H9Al05B4Q01<N800C7R@051hX01<M9`0E
7BP051/U01<J8P0G7R@072@W01`T9P0C6a`09Bh]01<L6`0@6AT04a/N049:D011BU409c8h01`W;@80
6B@Z03d05R4W01PS:@0K9R`07BP^01XU:`0F8BL06B@Y020Z;00M9bP06R@U01TS900G8B8051hO01LQ
8P0F82405AlP01@N7`0F8240628S01<L8`0B6b@05A`V01`N:P0M82T06QdU01`Q9`0I82H05QlT018O
9@0A82D04R8W034j@`0O8bh06QhY01@H8`0Q9Bl04ADN01DJ800;41D04aPL01@I7@0>4aL05alR00`C
6@0N9bh010dB00L@5@0D7B8051hP024[;@0D7R005AlP014K700:51D05QhP01XP8016BT/03a<D01hR
8`0A5AH02@d>008061`M02D05ATJ01HJ6`0I7Ah04QPH00TB4@0O:2L04a`K00`E500A6QT02a@C01TR
8@0740l072DT01LP7`0A6QT02Q0@01DF500G6AP03a<B00lD5`0=5AP03QHI010H6`0<4A@0318B01@F
5P0=3@/010@200lA400G6AP00@<200h@3`0D5QD03Q0?01DG5P0?4A005ALF0080418A00D051HE01hP
7`0M7ah03Q0?01<E500201@F5@0b018D4`0A4a804Q@C01<E500B51<04A<A014C400C5A804Q@A014C
400C5A804Q@A00h@3@0B514061XG00@60`0E5a@0:bd]01@E5`0B4aD0418B010B4@0A4a00418>00d?
2P0?4@`041<=00/>1`0=40T04A<<014B2P0=3PH04A8:00`=1@0B4`/08R<K018C2`0>3`L04A8:010A
2@0@4@X03Pl:01dM6`0G5aD04a<A018B400:2PP030`:00d=2`0@40h2018B400I00h>2`0B4`h0414;
00h?2P0@4@`04Q<>018B400?3`d0000001TI6@0=3@d06ATI01<C4`0A4@l04Q8@01<C4@0B4Q004A4?
010@3P0F5Q@04A4?00h>300?3`d04a<A014A3`06018A3`H04A0>04X03Pd;014@3P0C4Q004Q4?00l>
300<2`T040l=00h=2`0@3`d04Q4?014@3P0>3@/020L500X91`0=30X030/901<B400;2PP03Pd;014@
3P0=30X04Q4?01XI5`0A40`04Q4;01<C2`0D50`04a8=010?2P0?3PT03Pd900`;1`071P803@`:00/:
200H5aD04a8@00X91`0=30X040l=00P71@0B4@l0:RTW04Q7A@0T8b4030/900l>30061@<03PP8014=
300B3Pd04@d<010?3@0A40h03`h<00l?3@0<30X04Q8@00L71@0B4Q0030`<00h>3P0:2PX02`/;00d<
2P0920H03@`:01<?300?2`P03PX7018=2@0@30P03@`800l>2P804a8>00P03`h:018A3@0?3PX02PT5
010?2`0A40`03`h:00l=1`803``500l040d6014>1`0A3PL04a09018?200?30D04@h7018?200@3@H0
2@T300H70P0<3@P00`@002TZ9@0:2`H00P0;30L200`=20803@h901H04Ph;01@@3@0B3P/03PX700l;
200=2@H04@d:00l;200A3@X040`900h:1`0B3P/02PT500d<20071P8040l;00l>2P0;2PH04Q4=010?
2`0>3@T03`h:0P0@3`/050081`D03Pd;01@C4@0>3@/02PT700d<2P0?3P`040l=00h=2`0?3P`04A0>
00X:200H6QT02@`;00H:2@0C5A@05QLG00`<300;2`/030/<0P0>30d02P0=2``030X;00H41@081PL0
2`T:00h<3@0?3@h040h?00`:2`0>30d3010>3`803P`=01803`d>00`:2`0;2@X020H700H41@091`P0
7adN014?400<2P/04@l@00X82@0?3@h02`T:00X82@0<2P/03@/<00`:2`0?3@h200d;300?010>3`0A
3a0040h?00d;300C4A808AlP014?400=2``04@l@00l=3P0610D02PP900/92P0=2``0518C00803`/<
00@03@T:010<3@0A3@h030P90P0A3@h02P0B3Pl04@d>00l;300F4Q<01`<401TE5P0G4a@01P8301HB
4`0?2``2010<3@<04@d>00H06aPI02d[;00:20T061HG00`:2`0>30d300/92P0:00`:2`0100001083
01LE5@0G5Q@040l=00`;2@0;2PP020L500X91`803Pd;0`0?3P`06@0=30X03Ph<00d=2`0F5Q@04A4?
00d=2`0;2`T05QHD08n?S@0m?C/06ATG01DE4`0A3a003`d>00/92P0=2``040h?00h<3`091`X05Q@G
05IDF@0W9BX0ATA903Hc>@0?3A801@0?3A007P0H5QT03`d@00H41`040PD040hA03`j?@0O7Ah0518C
00l=3P0@3Pl030X<010>4@0<2Pd03@/?014?500C4AH04Q0F00h<4@0<2Pl03P`?00/9300A3a803P`?
01LE600=2`h03`d@01DC5P0C4A@08AlR01hL7aCooooo000Kooooo`0>00d<4@0@41<02`/=00d=3`0;
2``020P800d=3@0?3`h051@B01HF50030`8030d800h<3@0?3@h2014?400300l=3P0>30d05A<D0080
3P`=00<030X;00d;300B41401P0?3A002`0<2Pd04a4D02`Z;@0<2Pd071XM00P62@0C4AH030X?00h<
4@0>30l03P`=008040h?00<040l=014@3P0B4@d00P0C4Ph0;@0H5a@0CDe=00h@3`0@51L08BH/014H
7P0=4AX04QLM01@G7P0E5A/03`hD01HE700@3aL040lE01@C6@0?3Q<02`/=00`<300=3@/03Pl:010A
2`0A4P`04Q<;01DF401;C4L030d801HG4`0R8R001@D501PH600C4a<0410B00l?4@0A4A<051@F01PH
700<3A806AXO01<D6@1DEET0;Bhb010A500D5AL05aTH01DG5P0201HH5`0=00lA400A4a805QPH01LH
6P0Y:bX092HV01TK6P0J71/06A/J01DG5P0D5QD04QDE01/O8P0201/P900:01LL8P0D6Al04AHL01HJ
8`0E6B805a/T01HJ9@0B5R405QXU01LJ8`8061/T03005QTR01PK900M8BX05A`T01@K8`0B6B404AXQ
01<L8`0F7bD082DY01TN8@0H7B003Q<F01TN8@0J7b8051TL01XO8P0>4aH09b`_01HK7P0E6Qd05AdP
01PP8`0M9BP072@V01HO7`0G81l05QlN01HO700H8Ah06b@Q01hW8P0L9RD0;cXn08REV`0^>d4041hQ
01<Q900F92L0>4I7030n?P0I9bL06RPX01DS8`0R<3405b@/01/X<@0O;3D2024^=`0D020]=P0O;3D0
82df020]=P0Q;SL082df01l]=P0Q<3`07bll02@d@@0Z>dD08c@l01d^=P0N;cH0838f01la=@0N<3@0
72h`01T[;@0Q=CH3020c=`0K020c>@0Q=3X07C0g01d_>@0N<3X072hj01/]>@0L;S`08Rm201l/?@0M
:SX07B/g01l]=P0P;cH05bH/01l^=@0c@DT08c4j01/Y=00L;3@06Rda01d_<`0L;S805bT]01DT:@0D
8bP05B@Y00805b@Z01h0524W018O9@0B7b005B4O01PT8P0G8al05R8N01XV8P0I9B804alM018N7P0C
7R8051hW01DO:00H82/04QPT00lF800E72<04ATL010H6P0G7b00;SLf01`U900I8B<03QHI02Xa=`0d
?D@06bH/01DP9P0F8BL201@O9@0=01HQ9`0I92X07RT_01dX;P0A72806RDZ01`V:00K9BH06B<T01LQ
8P0F824051hO010J6`0200lI6P0M010J6`0B71d051hO018K800B6b805A`T01XN9`0K7RD061/R02DZ
<00R9bd06B4W010M8`0>7B803adR01LN:00J7RX051PS018F8@13Ae408bL`01DJ800F6b006b0T01LL
800B5aX0724U01dT:P0@6Ah00P0=5Q/00`0D7R004adO010J7002018L7@0g00hH6@0:51@03AHE00hD
500O8b@04ADF01hR8`0?4a@0720Q01<G600E6AX04aLH01@H6@0E6AX03Q8C00lE5@1<EE@09Rl^00dF
5@0N9bH04a`K04=<B`053Pd05b0O00dF5@0;51<04aTG00X;2P0=3`h06alN00lC5P0J8RD02Q8E00lG
6P093Q402@l?01@E5P0M7A/07QhL00d?3P0N81l04A<B01DG5P0;3@`051HE01DG5P0B51<06A/J018D
4`0>40l05QPG02PZ:@0P8R402P`;00lA400201DG5P07018D4`0A4a804Q@C01<E500B51<0418@014C
400201<E4P804Q@A02d04aDB01@F4`0D5Q<04A<@00H81@0V:2D0>S`j01@E5`0B4aD04A8C00lA400?
4@h04A<?01@F4@0H6QD05ALA00d@2@0<3`P04aD=01<D300@4@T04A8:00`=1@0=3PH05aP@010A2@0>
3`L0414900l@200?40T030d801XJ600B4Q0051@B01/K6@0I6AL05ADC01PH5P0C4a4030`:010@3P0A
4Ph03a0;014B300D5A000P0C50l01`0C4a405aLE010@3P0m?Cd05QHF00l?3`0H61P00P0B4Q00100C
4a404Q8@018B400B4Q0201DE4`0400h>300A4@l04A4?01@D4PH04Q4?1`0@3`d3018A3`03010?3@0>
3@/03`h<00803`h<00H040l=018A3`0B4@l03@`:02/Z:00<2`T2014@3P0P01DD4P0;2PP04a8@00/:
200?3P`06aXH00h=2@0@3`T04Q8:01<C2`0C4Pd040l:00l>2@0@3`/04Q4=01TH500?3P`04a8@01@C
4@0@3`d030/900/:200?3P`03Pd;01TH5P0?3Pd02@P6010?3@0>3@/04A0>01<B400A2`/3014=300:
00l>300@3`d02PT700d=2`0:2PP04Q8@0041000B4Q002`/;014A4@8030`<01@03Pd;00X91`0>3@/0
4`l<00d91P0<20D03`X6014=2@0?3PX03Pd901<B3P0E51004Q4=00d<200:2@D03@`801@C3`0A40`0
3Pd900l=2@803``500l040d6014>1`0A3PL04Pl8010=1P0<2@802PL000`90P0?30D04Q4<00h?2P0;
30L04Q<>04m@B`0I6QD00P0<3@P200d>2@803Pl:00T04Ph;01@@3@0A3@X03@T600l;200>2PL03`/8
010<2@0A3@X00P0>2PL02P0E4@h03@`801<B3P0;2PH05aHB01<B3P0@3`/06APD01DD400@3`/300d<
200D00d<2P0B4@l05QDC00l>300;2PP040l=00l>300@3`d03Pd;00d<2P0>3@/03Ph<028T8`0G6aX0
41@C00`>3@082@T04A4A00`<300=30`200h<3@803@/<00P04a4B00P61`0B41404Q0A01<A4P0?3@h0
2`T:00h<3@804@l@00d03P`=00`:2`0;2@X03`d>01<A4P0A3a00518C00l=3P0;2@X071XK018@4@0<
2P/040h?00@03@/<0`0@3Pl00`0=2``02`T:00/92P0300h<3@0B00P61`0J61T0>cTj01XH6@0<2P/0
2`T:05=ADP0E4a@030X;00l=3P0=2``040h?014=3P0?2``04Ph?014=3P0?2``04@d>0`0B3Pl02@0A
3@h040`=00`82@0=2@X02PH700P41@0I5AH0510A00/72002018>3`0A014=3P0@30d040`=00/82@0F
51D00P01014?400C4A804@l@010>3`081PL030X;010>3`0610D03P`=01TG5`0F5A<00P0<2`T00`0D
4a405aHD01<B400600h=2`0H014A3`0?3`d05QHD018B400>3P`02`/90000001>CT`06ATG00`<2P01
0@005A<D00P61`091`P040h?00/92P0A3a802`T<01<A500<2Pl03@/@092>T`0L6R003P`A1@0>30l0
4`0:20/030X=018@4`0>30l08AlR07]iO00c<C806aTJ00T720081PL01`D701HD5`0@3Q403`dA014?
500B41D04@lE00d;400;2@h00P0@3Q400`0F51L030X=01HD5`0200T72P0400`:3@081PT04a4D00h<
3aCooooo000Kooooo`0>00l>4`0H61/0410B00h>400M7Ah0:b/[07UiN@0F5QD06QXH00d=2`0A4@h0
3@h;00h<3@0?3@h2014?400800l=3P0>30d02PP9010>3`0=2``03`d>00h<3@091`P600l=400;01DC
5P0>30l0CD]>01DC5P0<2Pd0518E010>4`0=2`h040hA014?4P0>30d00P0@3Pl09P0@3`d04A0>018A
3`0B4@h04Q4=01@B400h=CH02@P9010A5@0J6b<03a<I01@F7P0I6R803`lF014>5@0L61h0;b`b01dL
8P0N7B<0;Rdb01DE600=3@l04a<C010@3P0A4@h04Q<>01<D3P0D5@l05AHA010@3P1XJ6H0A4A2018B
400F5QH051@E01<C5@0D51H05ADH0P0E51T0200E5AT0414E02<T:00B4aL0;Bhb01HG6@0E5QP05ALG
0P0C5A@06P0F61L05aTF01PJ5`0D5Q<05QPF018D4P0I6aP05QPF01DG500F61D06Q`I01TK600H6QL0
7B0N01HJ7@0G72006QlS01HK8@0D6Al05Q/Q01PL9@0F6R<06AdV01TM:00F6RD06AdX0P0G6R<05P0F
6B805APQ01HI8P0H72D05A`T01HM9@0H7bL0624X01LP9`0E7R@06QlS01<H6`0]<SD05a`O01hS9P0J
7b806b0S01PM800B5aX061dP020U:00F6ah301HN8@0[018J700K8bD0=3`m02D^;@0M9RD06B8P01XS
8@0L9B807bTX01HP900`>d4041/Q024/<00N:Bd07BP/01LR900X=3D05R8R01l[:`0N:RX08B`^020]
=@0O;3D07BXc01h[=00P;CH08Rlh01l/=@0L:C806bPa01`Y<P0P;CH08Blh01h]>00M;SP08C8l02Df
@00P<CT06R/c01//<`0N;cH08S<j028d>00201la=@0801lb=P0Q=3P08SDi028e>`0O<SP07S4g02Hi
@00S=Cl3020b?00L01h_>P0O;3`08c1001h/>P0K:C@0:3Ho03=1B@0I:2l07Rdd02Pg?`0O;CH06RPc
01PX<00E9b/05bT]01T[;`0J;3006BP]01HT:@0F8bT062D[01XV;00G8RP051lU010K800C7R805b8T
01HR90804alN01D0520N01HR800H92@05R4S01HQ9P0L9b`082Pb01HL:00D6bD06B0W014I7@0@61/0
5AhO00hG5P0>5QP0620R01HN8@0I82H072D/01@M900K92/00P0G82L03@0K92/05QlV01TR:@0L9B`0
6b@[01@M900J8bT0620S01PP8P0I8B<05QhP01DM7`0F7R000P0D71h0DP0E7Al05alQ01PP8P0I8B<0
4a/N014H700?5a/04aPM01DJ7`0F6B005QXS01DI8P0B6B404A/Q014M8`0F8BL06B0Y01LK9P0J7RT0
4QHO02HZ<`0>4Q/051TO02DZ<00N8bT05AXN01LL800C61`05alR00hF6@0E7B004ATK01DM7`0F7Ql0
4AXJ01<L6`0A6QP04Q/I01<L6@0@5aH07R<S00hB4`0J7Ql03Q8C01<G600?4a@04ADF01@H6@0C5aP0
5ATJ01LK700@51D04QPH01`R8P0G7Ad06b4Q01LM7@0>51@0:c4a01PN7P0V;2`041HF01HL700@51<0
7b0N010B4@0C5aH05a`O00XA501:DUD0=Si101TN8@0H7Qh05aTI01LG5@0P81h04aDD01PJ6@0D5QD0
5ALF00d?3P0F61L2014C4P0901LI600J71/04Q@C014C4P0D5QD05aTH00h@3`0C5A@0418A00804aDD
00`04Q@C01<E500C5A@04A<B014C4@0C5A8051HC01<E4P0@4Pl04A<@018D4@0G6AH2014C400701HH
5@0C5A805QPF01<E500B51<04A<B00lA400300lA3P0700h@2`0@4Pd051HA01<F3`0D5Q004Q<=01@E
3`0201<D3P0O01@E3`0@4@/03a0:00l@2P0A4P`03a0:014B300B4`l05QHD018B400C4a403Ph<01HF
500C4a403Ph<018B400G5aD04A4?00l@300?40/0414;014B3@0?40/03Pl:010@3P0A4@l051@B01lO
7`0C4a<03Ph>01HF5P05018B400701<C4@0;2`T05ADC00h>300F5Q@03Ph<01<C4@06018A3`H040l=
00D05A@B01<B400@3`d03`h<014@3P0201<B400B014@3P0@3`d04Q4?01@C4@0C4Q004Q4?030_;@08
1`H051<A00/:200920H03Pd;018A3`0;2PP03Pd;01HE4`0;2PH03Ph70P0?3PT08`0@3`X03`h:00l>
2P0?3PX02PT701TH5P0?3P`04@l@00/92P0I61H09RDS018A3`0=30X05QDC01lN700];2X03@`:018A
3`0@3`d02`X801<B400E3`l04Ph=014=300B3Pd03`h<00h=2`0B4@l03@d;00l?3@0<30X04A4?00`<
2P0?3`l04A4A00802`/;0P0?3P`0300A40h04@d:010<2@0D40d04Pd900l<200>3@T02PT500`;1`0?
3PX040l;014@30804Q4=00@03`h:00P70`0<2`L04@l;0P0?30L01@0@3@P04@h9014>2@0=2PH03P/6
00804a0;0P0?30L01P0A3`/00`@101`M600E5Q406Q/F00`=2@803a0;0`0@4@`02P0A4Pd040`9018>
2`0?2`P03PX7018>2`0C3``0510=01HB3`0D40d200h:1`04010<2@0<2`L02`X6018A3@803@`800D0
2PT501DD400B4@d03`h:00h=2@02010?2`0601<B400@3`d03@`:00d<2P0>3@/03`h<0P0>3@/2010?
3@08014@3P0E5A<0I6ET02<U900l?Sd0AdU8018C4`0<30`2010>3`0<00h<3@0@30d04Ph?018>3`0@
3Pl04Q0A00d;30091`P03`d>00P61`0=2``03P`=0P0@3Pl04P0>30d02`T:00/92P0=2``04a4B00X8
2@0E4a@02@L8010>3`0=2``04@l@00h<3@0=2``04@l@00d;300?3@h040h?00h<3@8030X;00H03P`=
00`:2`0<2P/03`d>010>3`0?3@h200h<3@07020N7`0:20T03@/<01DC500a;c003P`=00/92P0200d;
300:018@4@0?2``03`/<01<?400B3Pl04@d>01HB4`0C3a004Ph?014=3P<040`=00L05A8B01<?400F
4Q<04Ph?01PE5@0G4a@04`l@00804Ph?0P0@30d04`0=2P/05aDF00/92P0?3@h0518C00d;300<2P/0
2`T:01DC500=2``02PP901<A4P0:2@P04A0>01DD4P0>3@/04Q4?02LV900U92801@0>3@/01`0<2`T0
4Q8@00h>300@40h03Ph<00/;2@0>3Pd00P0?3`d0400;2`T04a<A010@3P0@3Pl061HG01<A4P0;2@X0
3`d>00`:3@0F51L020L901<A5P0;2@h061HK010>4`0>314500h<3`0>01@B5@0;2@`03@/>014?4P0<
2`d040hA01<A4P0:20T040h?01TG600@3Q004@lB01LE600B41@200h<4@0900l<4P0=2a002`T>00h<
3`0D4QD04@lB00l=40081PT040hA00803`d@00<020H9010>4@0:20/05?ooool001_ooooo00h02`T>
00l=4@091`X00@0201<A4`0H5QL0AdE600H41@0C4Q0040l=01DD4@061@4030X;00h<3@803`d>00P0
3P`=00`:2`0C4A802PP901HD5@0@3Pl02@L801<A4PH03`d@00@030X=010>4@0<2Pd04Q0C0P0<2Pd0
100?3A0040hA01HD5@0F51D2014?40<040h?01D03`h=00l>300A3@`04@/=01@?4`0?3A006APM010?
5`0C4a/051<K01<B6P060`X040`B01lH7`0R7R<04a8G01@C600J6Ah04A4C00/;3@0=3@d00P0=3@/3
00h?2P09014B3P0<30X07AdK01XJ6@0V9RH030`>014A4`0C4aD05A@I00805QDJ00X05A@I01DE6P0;
310030dA01<D5`0A4Q@02``>014B4`0@4Q403a4@0P0@4Pl06@0B51405QPD00/=200I6aH06Q`G010B
3@0G6AH06Q`I01LI5P0J71T06A/J01HH5`0K7Qh04aLJ01HK7`0I7R8051TO01<H7P0H7B<06AdV01PL
9@0K7bP06alZ01PL9`0L82/00P0G6R<301PK900d01@H8@0G7RH061lW01TP:00H8BP05b0W01HO9@0H
7B408RLZ05IKGP0G71l04aPK024V:@0O92L04QLJ03a1A00D6A`06QlR01HK7P0Q:B/05alQ01PP8P0G
7b407bLY03Hn@00V;S0072@V01/T8`0L9B@06b@S01hX:@0E7R<0=3m501dX;P0E82@05R4U01`W:`0T
;c40:SDf01DQ8@0C7al06BDU01lZ;00I9R`06BH^01PU;@0I9Rh06bP`01`Y<@0R;cL07b`d01dZ<P<0
72Ta00P072Xc01d[=00N;3D07R`e01/Y<P0I9c00938k020_=P808c8i00<09C@k02Pi@00Q<ST00`0O
<3L05P0P<CT08C8j02Hg?`0P<CT06BXb01//=00L;CD05RLa01d[>00_?DX0<3i;028`>`0E8b`04b4Z
01/Y<P0N;3D05R@^01HT;`0K:C@06b/c01/]<@0J:Bh201PW;0805R<Y01P05b@Z01PS:@0G8RP05R4W
01LR:00I92`06B<]01HP:@0E82D051lQ01<O7`0C7ah04QhL010L700@6a`04ahP01HQ8`0I8BX05adY
01DL9P0C6R803aHL00lG6P0F7R0201TQ8`0H01HN8@0J8BL051/S01HO9P0I8RT06b@[00/D6`0?61l0
3AHM01@M900I8RT0624X01<L8`0K92/05QlU01XR9@0K8bD072@V01LO8@0E7Al05alQ014I6`0B6Q`0
4a/M0`0D71h08@0G81l05AhM01HL7@0G71l061dQ01PM8`0N8R/07B4Z01XQ:@0G7R@051dR01<L8@0D
6b<041@M01hR:`0O8b`04QHO01DI8P0E6R004QLM014F700E6R0061dS018G6`0>5QT06b<U01XR900G
7b404Q/J00H?3P0?61L03aPE010I500200lH4`0h018H5P0?4a@051DG01HG6@0?41807b0R01TJ700E
5QP05aPJ01DF600G61X06Q/M018F5`0F71X04ALE01dS8@0G7A/03aDC01HL6P0C6AL051XH018H5P0?
5A<01@/900T=301?D4d092HU00lC4P0?4aH00PX=05ALG`2maLP08bP[00H<300?4A4051@B028R800@
4Q405QPG024S8P0F61L04Q@C00T;2P0C5A@06A/J01<E500L7Qd06A/J014C4P0F61L03a4@00d?3P0D
5QD061XI01lQ800D5QD3018D4`0?010B4@0A4a404Q@A018D4@0A4a00418?01<E4P0?4@h061XG01HH
5@0=3``04Q@A01DG500G6AH0418?00804A<@0P0@4Pl04`0B51405ALD01<E4P0?4@d04Q@?014C3P0@
4P`03a0:01LH4P0C50h05QLA01/L5P0?40X03Pl9014B300B4`d03a0:018C3@0?3`d00P0C4a40300I
6AL04Q8@01@D4P0N7Q`05aLE010@3P0=3@/02`/9010@3@0A4Pd04A8<010A30804A8=00T04A4?00/;
2@0I6AL0410@014A4@0410@05ADE014A3`0@40h00P0?3`d0200A4@l04a<A00h>300J6QP04A4?02/[
:@0J6QP04Q8@1P0@3`d600l>308040l=00L03`h<00h=2`0>3@/03Pd;01DD4P0@3`d03`h<00804a8@
00@03@`:00X91`0@3`d01@@20P0F5A<0200?3P`04a8@00l>300?3P`04Q4?01<B400>3@T040l:0P0=
30L01P0>3@T04A0<018A3@0D4a402@P600l>30803P`=00h0518C01LF500N7A/04A0>00d<2P0?3P`0
61LE00H5100H5aD04Q4?01DD4P071P@03Pd;01@>40803`/<01004`l@018@4@0A3a0040h?00<30`0C
4a<010@403Lg=`0=3@d03`l?00h>3P0<30`03`l?00l>300>3@/040l=0P0@30T00`0E4@h04`h:00d:
1P0200d<2P802`X800P03Pd;01DD4P0C4Q0040l=01<B400@3`d03Pd;00l=2@803``700l040d8014>
2@0A3PT05A8=01<@2`0>2`H040d801<@2`0@3@P03`d800<2000;2PH06QTG00l>2P0;2PH00P0?3PX2
010?2`804A0<01804@d:01<?300@30T03`/801@@3@0F4Pl04`l<01HB3`0C3``04@d:01@@3@0>2PL0
6APD00h=2@0c<Rh051<?01TH500A40`200/:1P0H00`;1`0@3`/04Q4=01<B3P0=30X02`X800X91`0<
2`T03Pd;00`;2@0?3P`030/9014@3P0C4Q004A0>01<C4@0>3Ph051HE00X<2`071`L03@`=00h<3@0@
3Pl040d>0P0?2``0200A3@h04Ph?00X82@0D4Q<01`D6010>3`0<2P/04Q0A0P0>30d200d;308030X;
00`01P@500`:2`0O7Ah06QPI03Pf=`0^;2d030X;00d;300<2P/03P`=00l=3P0>30d200l=3P803@/<
00<04@l@01DC500?3@h00P0=2``03@0@3Pl04@l@010>3`0=2``0518C00l=3P0C4A803@/<00l=3P0=
2``0518C01DC500>30d00P0:20T0100=2@X04Ph?010<3@0?2``3018>3`0;010<3@0>2P/03PX;00l;
300G4a@00`0001`H6@0=2@X0Og]l09jJV`0=2@X00`0@30d200l;300C00l<3@0C4A8030X;00h<3@0D
4Q<030X;01<A4P0?3@h05aDF00d;300:20T04@l@01<A4P0?3@h01P@500X82@0A3a003`d>00`:2`02
00h<3@0600d;300<2P/030X;00/:2@0E51803`h<0P0=30X0500;2PP04A0>01LF500;2PT030/900L6
100<2`T06ALH01lM7P0M6a`03`d>00`:2`0D4QD02@L:00P62@0:20d03@/@00P62`091P`03@/@1@0=
2`h0100B41<04@lB00l=400;2@`200T72P0C014?400@3Pl03P`=00h<3@0>30h03P`?014?4P0?3A40
3@/@00l=4P0?31803@/@00h<4@0:20/05A<F00T72P0U8bH02@L:00`:3@0200/9300300D31P0>30l0
20H901Cooooo000Kooooo`0>01HD6@0I5a/06QPK00D31P0B41800`4200`:2`0=30/05A@B010?3@0;
2PL03Pd900/92P0=2``200h<3@0800d;300;2@X03P`=014?4015@d@0<Bl`00H41@0?3@h600l=400<
01DC5P0<2Pd040hA028P8`0?3A004a4D00h<3P0@3Pl05aDF01PF5`0@3Pl03`d>0P0@3Pl200l=3P0G
00d;300?2``03PL901`F6P0C3Q@04a0G00d<500?3QH04A0H018?5P0710/04`hC01T@5@0D41@04Q4F
014@5@0=3A005ADG01@D500?3`l04A4A010@3P0@4@d00P0@4@`02P0:2`L05QHD01XJ600<30/04Q8B
01XJ700D51H04a<E01<B5`0D4aP201DD6@0E01<C600O82@06Q/O018C5P0A4Q@06AXL018D4`0C5A@0
4aDB01DG500C5A8051HC01LI500E5a8061XE00`>2@0B50l05aTF01TK600E5a@071hL00808R@S0100
:B`/01/O8P0M8RH07B8V01DJ800B5ad05AXP01LK900F6R<06AdV01TM:00F6RD06QhY01<F7`0D5b00
61/T0P0L7bP0100H72D05ahV01HM9@0E72@201<L8`0[01DN900O92P0314D03@i?00D6A`07R<V01<H
6`0R9bX06AhQ06Y_LP0X;C006QlR01PM800L92H04a/M01/S9@0L92H051`N01LO8@0M9BL05alQ01`T
9P0O9bT07BHV028Z;00U;S<06B@Z01LR:00P:bl072L[014L800F8B<06bHW01`X:00I9BD06bLW02@_
<@0G92X06RL_01dZ<P0N:c<07b`d01h[<`02020]=@05024^=P0P;CD07BXb01`Y<@0P;SL00P0Q;cP0
9@0N;3D07B/d01h/=@0^?4D08c8i028a>00P;cH08S4h02Xi@00R<cX07Bhe01X[<P0L;C@08C8j02<d
?00U=Sh07c0h01TZ<P0N;cL08C8j01//=00Q;cX082hk01h/=`0L:SD07bdf02<a>P0I9c00938k01TW
<@0M:cH08S0k01TY<@0F:2`05B@Y01PW;00L:c000P0L:Bl0:P0I9R`05b8X01@O9@0F8BL06B@Z020Z
=00N:3@05b4]01LQ:@0L9b/07BPZ01dY:@0E8Al03a/K014M7P0F8B<05B0R018K8`0D6RP05A/W01DL
9@0I82H06b<V018J7@0N9RP072@V01DM8@0L8bT05ahV018K8P0I8RT072D/01<L8`0Q:S407bP_01<L
8`0J8bX05QlV010I800O:2l051dS01@L7`805QhP00D03aLI00`D5P0>5QP04ATK018J700301@L7P07
01@L7@0G81d05QlL01HL6`0F6ah05AXM010E6`0201/O:01C01PO9P0F7B<051`O018J7@0:3aD05a/T
01@H8@0H72D051PQ010D7@0e>T005a`R01HK8@0O92X05a`R00lD6P0=5AP031@F00hF600C71/03AHE
01XS8P0@6AH04a`H01LP6`0C71L03aPC01TO6`0:3Pl05QLI014B500F5aT03@h@01/L7P0E5QP05QLI
01<D5P0D5AL05aPJ018C5@0;3`h051XH00`B400C6AL051XH00D;2@0D6QP03Q@B00X@3P0M8b400PP6
01LK6P0E5Q@03@l>020T8`0A5AP05QhQ01DM801<E5L03Q<F01lU9@0M7al020P601PH5P0C5A@01`T8
028T8`092`X03Q0?01DG5P0@4Q4061XI00X<2`0B51<05ALF00d?3P0@4Q404A<B01XL6`0I6aX03Q0?
01TK6P0D5QD00`0B51<00`0@4Q403a4?014C4002010B3`0;014C400F61D05aTF01<E4P0;3@X05QPE
020R7`0F61D04Q@A00lA3P0@4Pl00P0A4a003`0@4Pl03@l<00lA3P0A4a0030h:010B3@0A4`h04Q<>
014B300J6aD04Q<=01<D3P0J6aD03@h800h?2@02018C3@05010A2`0C50l04A4?01PH5P0>3P`00P0A
4@l07`0=3@/02@T7014A3`0D51803`l=010@3P0>3P/0414<00l@2P0>3`X0414<00l@2`0<30X03@d;
00h>300:2PX0820P00l?3`0=3@d0410>00l?3@0>3P`03`l=010@3P0C4a403`l=01PH5P0=3@/0<S8`
01hN700<30X0300?3P`01`0<2`T03Pd;00l>300?3P`030/900X91`0E51800P0>3@/03@0D4a404Q4?
00T81P0A40h040l=00d<2P0<2`T02PT700`;2@0E51803Pd;018A3`0F5A<00P0C4Q00900A40`03Pd8
00`;1P0>3@T04a8>01DD400A40h03@`:00l>300>30d02@L801HD5@0<2`T01`H400T81P0>3@/020L5
018A3`0?3P`040l=00D40P0<2`T00@0001TH5P0A2`d030P900h:2`0E4A805A<D01@B4`0?3@h00@41
01XJ6P0;2`/0EUIF01`L70803Ph>0180410@01DE5@0B4@l030/900h=2`0@30T03`/8018>2`0A30P0
3@X7010?3@0B4@l04A0>00h=2`0@3`d04Q4?00/:200>3@/201lN700501<B400<2PL03``700l<1`0@
3@P00P0A3PT0300T8A`08QlJ00`910091P<061D@01`I500>30T071/G00H50@0B4@d02`X600d<2P80
3Pd90P0?3PX2010?2`0701<?300E4@h04@d:010<2@0D40d05Q8?00`81@02010<2@0901@@3@0J5Q<0
510=00l>2P010000=3<_00X91@0A40`010<100802`X601P030/7010?2`0A40`03`h:00T81P0;2PP0
3Pd;00l>300>3@/03@`:010?3@0;2PP04A0>01@C4@0?3P`04A0>00/;2`0:30/03Q0?014A4@0?3Pl0
30X;00l=3P0>2``200d92P0:00l;300A3@h02`T:010>3`050`@05Q@E00L51P0G5AH03`d>00h<3@@0
30X;01<03`d>00h<3@0C4A800P0101HD5@040P<020H701@B4`091`P030X;01<A4P0;2@X03`d>00h<
3@0=2``04@l@01dK700U8b@03@/<00802`T:0`0>30d01@0@3Pl0518C0040000B41403P`=008040h?
00L02PP900L51P0>30d040h?00X82@0@30d05Q8C008040`=00h0510A014=3P0A3@h03`/<00d92P0>
2P/03`/<014=3P0?2``04Ph?00h:2`0J5QL08alP01DA4PD03`/<00<030T:00`:2`0:20T00P0?3@h0
1`020040518C00T720050`@03P`=018@4@0@3Pl00P0?3@h2010>3`0300d;300;2@X030X;00803P`=
00H03@/<00`:2`0<2P/03@`;01XI5`0C4Q02010?3@0D00l>300=30X00@0000h=2`0B4@l020L5010?
3@0<2P/01@<403<a<P0l>S/030X;00d<3P01008071XM00h<4@030@H04Q0E00h<4P0=2a0500d;3P0N
00/9300=2`h030X=00d;3P0C4A@04@lB00L51P0>30d040h?00h<3@0@3Q0030X=00/9300<2Ph03`dB
014?500@3Q@03@/@01<A5P0:20/061HI00P62@0f=3L0518E018@4`0A3a8040hA00X82`0B41<030X=
5?ooool001_ooooo00l081hS01DC5`0=2`h05aDH01/I6`091`P02PP900l=3@0?3P`03@`:018A3P0K
6QH05A<D00d;300@3Pl00P0?3@h200/92P0:00`:2`0C4A804Q0A014?400?3@h061HI01DC5P0>30l0
2`T<010>4@804Q0C00`04@lB00l=400?3A003`d@00l=3`0A3`l05Q@E01<A4P0G5AH030X;00l=3P0@
3Pl200d;300?00l=3P0@3Q004`hB01<<400A2Q403PT?01XG7P0E51`04a8J014@600A3QD040hD018<
400E31003`/>0080410B00L04A4C01HF600B4Q8061PH014A4@0A4@l0410>00804A4?01<04A4@014A
4@0A4A404a<D01<C5@0D51H0410C01PG700<2a005A@I01dL8P0@3aD04a<H01@E5`0E5QP04A8D014C
4`0E5aH04aDD008051HC01D0418>01DG4P0G6A@05ALA01LJ4`0C5A0061XE02T[9`0K7AX051HE00h@
400G61X061TL01DF6@0F61`05aXO01LL800E6Qh05a`R01`Q9`0I7R@00P0E6B806@0G6b@061`W01TM
:00J7RT05APQ01/N9`0B5Ah061/T01<F7`0H72D05QdU01DL900I82P06R<Z01LP9`0F7bD041DI01hS
9P0E6Qd0724T01PM800A5QT06b0S01TN8@0]<SD00P0K82<01`0F6ah05alQ01DM7`0E7Al0620R01TQ
8`0F7R000P0K8bH02P0J8RD06B4T01/S9@0K8bL05QlU01hW;P0P:C006b@Y01PQ9P0I8RL201XT9P0:
01hX:@0L9RL072HW02Lb=01[N7/0=T=901/X;P0N:c4072T_01XW;@8082dc00@07b`b01`Y;`0L:Bl0
7BX`0P0N;C@0100L:c806RT`01`Z<`0N;3D3024_>00;020^=`0M:c@072Xc01h_=`0J:c<072de020a
>@0N;cL06b`d01`]=@0M;SD0100N;cH0200I:3007B/e020^>00L:SD06RPc01h/=`0N;3P072Xf0P0K
:C@0B`0L:SD06BP`028a=P0E92T062H/01`Y;`0G92X062@Z01DP9P0I92X05b4W01HO9P0H8BP05Ah[
01lX>@0J8c<05b4/01/V;@0R;C80:3<e01HR8P0E8B807RTZ01DP8`0B7B405b0Y03Y0CP1oQI808BPb
01LN9@0M9BT04QXM01PP8`0L92L031<H01/R:00E72@06b8Z01HM9@0L8b/061lW028Y<@0Y<3P07bH^
014H800G7RH06b8Z01`S:`0B6B005a`P01TN8@0F6ah04aPK01HK7P0E6Qd02a0C01@I700B5aX05Q/N
01@I700F6ad05adI018H500D6QT06R8T01PP8P0C6R004APN01@K8@0E6Ql0<3@f01`Q8@0P92@05a`P
01@I7`0201HK8@0H01DJ800F6b40<cM001PL9@0I7BH082@]01DI8P0?51X04aPL01@I700C61/04AHH
010F5P0B61P09bd/010F500B61@0318>01<I5@0G71T05QPJ01DF600F5aT03a0B0P0H6A/0201/KFl0
7AhP014B500F5aT04a@F01PI6`0E61L04QHE0P0A5A@05P0C5aH051PG01HJ6@0=4A0061`K02hb<@0C
5aH03a8A014B400K7A`01`/:010E600P:2/06b<V014I700E6Qd051XJ018D500D51805QHD010B4@0B
51<2010B4@0601<E500D5QD04aDD01LI600H6QT05ALF0P0C5A@00`0A4a804Q@C01<E500201<E5007
014C4P0@4Q404Q@C01@F5@0B51<0418A010B4007014C400<010B3`0?4@h03Q0=00lA3P0A4`l04Q@?
014C3P0N81`0:R`Y01`N6`0=3``0418?0P0A4a02018D4@0>010B3P0=3PT03Pl:014B3@0C50l04A8=
018C3P0@4@`03a0;01@E400F5a804Q<>018B400=3@/3018B400C00d=2`0C4a403Ph<01LG5@0=3@/0
5QHD01@E4@0A4Pd04a@>010A300B4`h061TD01@D4P0A4@l02`/901<C4`0I6AT0410@00h>3P06014A
3`0@00l?3@0>3P`03`l=010@3P0B4Q004a<A00l>300@3`d03Pd;00d<2P0>3@/04A0>01HE4`0@3`d0
3@`:00l>30804A0>00`04Q4?01<B400A40h040l=014@3P0B4@l040l=00l>300=30X03Pd;014@3P0D
4a4200h=2`@03`h<028020L500l>300?3P`0?chl01PG5@0C4Q005aHB01<B3`0B4@d092<O01HE4`0@
3`d03`h<01DC500>30d03@/>01XH6`1_KFh051<B00h=2`0=30X03Pd;00l>300>3@/030/:01HE4`0;
2PP03Pd;018A3`0<2`T03`T;010<3@0A3@h04Ph?0P0?3@h0600:20T02`/;010@400K6a/0HV9R01DE
5@0?3`l0=CDe01XJ6P0R8R803@`:01XI5`0E518030P501@@3@0A3@X03`X6014=2P0=30X05QDC00d<
2P0;2PP05QDC010?3@804A0>00D0<c8`00L61@0E518030T8014=2P0300l;200500d91P0A3@X03@T6
00d91P0?2`P00P0<20D00`0>2`P03@`800`;1`0200/:1P0F00`;1`0?3PX03@`801PG4`0G5Q802@P4
00X91@0@30T03@T600`81@0?2`P04@d:010<2@0A3@X03`/8014=2P0B3P`03P/901TE4P0=30P03Pd9
00l>2P8030/701<04A0<00d<200D4`l030/700l>2P0@3`/030/7014@3P0B4@l040l=00d<2P0/:bT0
3`h<010?3@0H5aD02PT7014@3P0<2`T05aHD008030`<01l02`/;00`:2`0=2``03P`=014=3P0F4Q<0
>SHg00d72@0A2`d03PT;01<@4@0@3Pl020H700h<3@0<2P/0518C00T7200>30d02PP901<A4P0:20T0
518C018@4@0=2``02PP900d;300@3Pl03`d>01@B4`0?3@h0GE]L00804Q0A00P040h?00d<300Z:2T0
=38c010?3`0[:BX0=cDf00d;30803P`=00D030X;00h<3@0?3@h02PP900/92P0200d;300301HD5@0`
;Rl03P`=00803`d>00T03@/<00h<3@0?3@h02PH701<?40091@H040`=01HB4`0@30d00P0=2@X02`0?
2``05A4B00l;300B3Pl040`=00l;300@30d04@d>018>3`0@30d04@d>008040`=00<03`/<00h:2`0@
3@h00`0>30d200`:2`0d00l=3P0@3Pl02PT900X82@0R82403@/<00h<3@0610D02@L800d;300>30d0
3`d>00d;300>30d020H700X82@0@3Pl02`T:00d;2`0A40h061LE09:AS`16AD<040l=00/:200B4@l0
51<A028Q7`0E51803Pd;00h<3@0B41405aDF01XH6@091`P04a4D00`:3@0D4QD03`dB00H42@0E4aP0
30T?00T7300P7R402`T<00l=400D4QD030X=010>4@0>30l02`T<00`:3@803@/>0P0<2P/04@0>3@d0
30X;00`:300?3A004A0B00h<400>314030X?02LU:`1KFEh071XO00l=400C4A@0518E00d;3P0A3a80
518E00803`d@00<03P`?00d;3P0B41<05?ooool001_ooooo02005A0F00d83@0910P040/?01<>4@07
0`@02PH700h:2P0?2`X03PX901<?3@0I5A801`D6010>3`0R82404a4B00h<3@0;2@X04a4B02@R8`07
1@H03@/<00`:2`0?3@h0KF]^020N8@0=2`h0518E00h<3`0]:bh04@lB010>4@<03`d@020040h?01@C
400H5aD04Q4?01HE4`0:20T02`T:01<A4P0G5AP05Q@G018@4`0@3Q<04`hD01<:4P0@2A402PD<010=
5P0;2A@03P`G01@C6`0A3QD03P`A014<3`0G3Q406aLH00/;2`0L71`06ATI05]KF`1SHf<0De=C010@
40<03`l?00<0410@014A4@0B4Q800`0B4Q@02P0B4AH06APM00D42@0H5ad04Q8G01XI7`0;2Q804a<H
00l@4P0<3Pd201@F5@0701DG5P0F61D051HC01DG4P0B50l04aD@01@F4@0201<E400@01<E4P0A4a00
418?01PI6P0M7R007b0T018C5`0_<3D02``A01`N8`0G6Ql061dQ01LL800G72806AhT01@I7`8051PQ
01P05ATR01HJ9@0G6bH05a/V01dP:@0P8b`05QTR020S;00>4AX08RH_01/R:P0A6200>D180:2Y/00P
:C0072D[01<H700D6A`05a`O01TN8@0B5aX06b0S01@I700B5aX201DJ7@0301LL7`0K82<05QhP0080
620R01405alQ01PP8`0J8RD06b<V024X;@0Q:2h07B@Z01TP9P0I82P04Q/R01TR:@0K92/0624V01HO
900H8BH06bDW01PR900201XT9@0901LQ8P0H8bD0<Ca001LT:P0F8bT07R/a028_=@0U<SP07b`b0080
934g00@08Bhd01dZ<00L:Bl06bP^0P0L:Bl01@0L:C407b`d024^=P0N:c@07b/g00<082`h00L07bdh
01h/=`0V=3l09C<n01d[=P0L:S<07bdf00<07B`c0`0N;C808@0M;3807Rdd02<a>P0R<3/072Xg01/Y
=P0N;3X07R`i01d[=`0K:C@06RPc01/Y<@0B7bD04AhT02Pe>`0K:2h041/Q01`W;@0E82H0624X01<L
8`0B6b806R4Y01LP;@0G83405Ql`01@N:@0I8b`08Rdc02<^<P0F8B<05b8V01`W:`0201@O9@0J01LO
:P0I7bd0Q8ZH024W<P0d>d<02Q4G01PO900:4QD05A`R01`S:P0D6b<05QdW01/R:P0D6b<06b8Z01LN
9P0B6B403aHN010G7`0U;3@0;3<k018I8@0L8b/051/R00`A5@0A5AP201@H6`0j01LK7P0D61/03a<F
01LK7P0D61/05ATL018F6@0D61X04QHE01<H500L8R407bLY01XR9@0E728051/Q010H6`0N8bD0JF]X
03do>P0P8Q`0310C01XO8`0A5QX0314G020U:`0@5A/04aLP01dQ:P0L82T04aLR014E800I7BH04A@K
01@G700F6Qd05ATL01HJ7@0I7Ah0Oh>4028V9`0D61L061`K01HJ6@0E6AP06AXL014A4`0H61X04A4C
01<C5@0J6Q`092@V01lO8@0V9RP07QhP01DE5`0720X051HE01@F4`804aDB0P0D5Q<06@0F61D020X7
00T;200F61D051HC01`N6`0C4a4030h=00`@3`0B5aX03ADH01dU:00=5AP04AHI010F5P0A4Q<04Q8@
01@D4P0O8B003@l>018D4`0F61L04Q@C01<E500@4Q400P0C5A@00`0B51<04aDD01DG5P04014C4P04
010B4@0>40l03a4@014C4P804aDD00<04Q@C014C4@0A4a00100A4a000`0B51404A<@010B3`0200lA
3P0:010B3`0@4Ph041<<010B3@0?4@`04aD@01<E4P0?4@h03@l<00h@3`<03a4@00H03a0=00d=2`0=
3@/0410>018B400A4@l2010@3P<03`l=01T03Ph<01<C4@0;2`T05aLE00/;2@0d=3803Ph<014A3`0G
5aD03@d;01HF500E5A<08R<O01<D3`0D5@l04Q<>01<D3`0F5a8051@B020P7P0B4Q0061PH038b<P0_
;bl05aLG00H03`l=0`0>3P`01P0?3`d04A4?018B400>3@/04A0>018A3`8040l=00P04A0>00/:200A
40h04a8@010?3@0A40h05QDC00l>30804A0>0P0>3@/01`0?3P`03Pd;00h=2`0>3@/040l=01@C4@0G
5Q@01P0>3@/06P0D4a403@`:00/:200?3P`030/901XI5`0;2PH00@0001PG4`0U92803Pd;00D40P0A
3a004a4D00T72P0F51L00`44018@4@0>30`03@`:00h=2`0?3P`03Pd;00`;2@0B4@l061LE0P0@3`d0
0`0E51804a8@018<3`03014<408030X=02D09R@W00L72@0C4aD07AdO03De=`0>3Q005aLG0;Zj^P1E
EED0000001hM6`0D4a402`X8018>2`0Q7AX061@A00h91@0;1`D040h?01HD5@0B41401@<400T7200F
51D030X;00l=3P0920P02PP901PF5`091`D03`/:01@@3`0B3Pd03@T800h:2@0?2`X03PX900803@T8
00@06QHE01/G5P0C3`d04Ph;0P0A3@X0500B3P/04`l<01@@3@0?2`P04@d:018>2`0<20D03`/8014=
2P0?2`P03@T600l;200A3@X040`900<0000P71T02PH300L300060P003PX90P0@3`/0<P0?3PX030/7
00/:1P0=30P02`X601HE4@0@3`/03`h:00h=2@0@3`/03Pd;00l>300D4a402`X800l>30081`D01PD3
00h=2`0@3`d06QTG018A3`0?3P`02@T900X92@0;2@X030X;00l<3@0B3Pl02PH701/F601QFed04@/=
014;300H4Q@01@42010>3`0N71d02`T:01HD5@0100007A/L00X82@0E4a@05Q@E014?400;2@X040h?
00T7200A3a00518C0P0?3@h010040P<08R0Q0=7?d00/:R/200/92P0E00h<3@0Q7b00:2HW00X82@0B
4140518C014?400?3@h030X;00X82@0<2P/03`d>01LE5P0>30d030X;00l=3P0;2@X03`d>00d;300?
3@h03P`=00803@/<00H03`d>028N7`0=2@X02PH700`82@0C3a0200l;3004010<3@0>2P/02@D600X6
1`804Ph?01l04@d>010<3@0@30d04@d>01/G600c;c009B4R01<?400@30d02@D6018?400?3@h02`T:
00d;300@3Pl03`d>00L61P091`P08b4R01XH6@0610D00@0000l=3`0N71l061HI01TG6P0B41<00P03
00D31P0H5QT040hA00805aDH00L01@<600l<300P71/030P701TE500G4a80J6AS00805Q8A01T08QhM
059>C@0@30/05Q8A01PF5`0?3@h05aDF01<A4P0:20T04@lB00h<3`0A3a803P`A00/93P0G5AX04PlE
00@21`0H5QT03P`?01<A500B41<03`d@010>4@0?3A003@/>00803P`?01@030X=00/92P040P<0@d52
02TW:00F51H020H900h<3`050`L04Q0E00`:3`17A4X0dm7F02PV:`0E4aH0518E01LE600?3A002@L:
018@4`<03P`?00<03@/>014?4_ooool04oooool001_ooooo01d0100501HA5P0D3a<01`8600P51P0H
51D03`/<014=3@0?2`X03@T800h:200B3P/04@l@00P61`050`@02@L800L51P0B41401083018@4@0>
30d03`d>024O801NG5d0XInR00d;3P0@3Q4030X=00l=4002010>4@0T00l=400>30l03`d@00l=400@
3Pl030/801TH5P0?3P`02`X800H41@0=2``040h?01DC5P0D4QD03P`?00l=4P0E41H040T@01<>5@0<
2A002`TB00T74P0B41/051<J018?5P0A3a804`hA01D?3`0I5AD0410@01/K6`0<30`07QhN00h>3P0M
7Ad04Q8B0`0A4A400`0B4Q804a<C018B4P03018B500?018A5P0E51T020L<014@5P0H5ad06QTO01XI
8@0L72404a@F00lA400G6AP0418A01<E4P0K7AX05ALD0080418=01@04aD@014C3P0A4`h04Q@?01@F
4`0F61D02P`;01DF6@0>3a<06AXO03Xj@@1nOXH07alY01HH800C5Q/05Q/O01PM8@0H7B<06b0V01LL
8P805QXS00H05a/T01PL9`0H72L06AdX01/N9`0C5Ql201DH8@0c01TL9@0_<c`041LO00hE7@16CED0
^/?:02Tb>@0I8RP05a`P01LL7`0I7R4061dP01DJ7@0R9bX03A8E01HK7P0K82<08bP[01TN8@0E6Qd0
6R8T01dU9`0K8bD05alQ01DM7`0H82<072@W024Y;@0Q:2h07B@Z01XQ:00L8b/051dT01TR:@0L9B`0
6b@Y01XS:00L9BX06bDW01TS900J92D06bDV01PR8`0F828062<W01@Q9`0O;380934g01l/<P0M:S00
72T_008082dc00@07BX`01XW;@0J9bd07BX`0P0O;3801@0N:c<082de028_=`0P;CH08Bdi00808Rhj
0P0Q;CT01`0N;3L09S@o02Dc?P0M:cH06RPa01d[=00J:C000P0I:2l02@0I:2d06RT^01XY;P0L:c00
8C0e02/j@@0/>T@07bdj01XX=@0201TV=P0d01TW=00F92l0528]010N9P0N:c409S<i014N900Q;S@0
72L]01LR:00H8bT07bP_01TR:@0@6B0072<[01XR;`0A6R/051d/018L:00@6R<05R0Y01DP9@0D7b<0
5R4U01PS:@0A6b@04adV01dU<@0<4R80:S0n01dS;P0E72@05QdS01LN8`0I8B@02A0F01PO9P0B6B40
6R4[01/R:P0E72@072<[01dT;00F7BD04aXR00dD700X;cL0<SU100dD700D6b<05Q`S00lB5`<04QHI
0P0E6A`0800J7R404ADH00hB5@0N8RD05ATL01<G6@0K7ah06QhM01/Q8P0H82<04a/N01DL8P0I82H0
6R8U020T8`0_<R/0=SP]07moM@17Bd`08RL[02/`=00V:c407B8X01HK8@0?4a`04ADN00hB6`0C5b80
5a/V00T=600A51/051LL0P0E61d0100F6Qd06AdP04Y>D@0I7Ah200`@4@0601PL700;3a0051@F018B
500X:2X0820R0P0C4aD01`0A4A<05aLI00H62000008071`N01XJ6P0D5QD0100C5A804@0D5Q<04A<@
01DG500F61D0418?00`>2`0E5a@05QHD00L9200<40l05QXM00P@4`0D71l03QHI010E600@5QH04aDE
00805ADC00D0;2h]01@F5@0I6aX05aTH00lA400401<E500301@F5@0G6AP06A/J00<04A<B00@0418A
00h@3`0@4Q404Q@C0P0C5A@00`0@4Q403a4@00lA3`05010B3`0301<E4P0D5Q<04aDB00<04Q@A00P0
4Q@?018E3P0@4Pd03@l:00h@2`0A4a00418?00d?30803Q0?0P0?4A00200@4@l03`l=00l?3@0B4Q00
51@B01<C4@0?3`d03Ph<0P0@40h02P0A4@l04a<A00P81P0;2`T051@B0041000S8b403Ph<01@D4P0E
5A<2010@3P04014A3`0H6AD0414<010A2`<0414<00L03`l=01<C4@0<30X030`<01@D500B4Q803Ph>
00H03Ph<00@04a<A018B400@40h03Ph<0P0=3@/0100=30X04A0>018A3`0A40h200l>300@00d<2P0@
3`d03Pd;00`;2@0B4@l06QTG00/:200=30X04A0>01<B400?3P`02@P601<B400B4@l03`h<00h=2`80
3`h<0`0@3`d300l>300O01@C4@0>3@/06APF00P71@0?3P`05A@B00h=2@0I61@04A0<00d<2P0>3@/0
4Q4?018@4@0=2`h02@L:01/I700?3A003P`?00d<2`0;2PP030/9010?3@0?3P`03Pd;00L61@0920H0
2PT700d<2P0;2PP01PD3018<4002014<400c010;3`0=2`h03@/>065OHP1LG5h03@d?01dM7`071`T0
3`lA01PH600h>3P04a<C010@40081`D01`H500X91`0?2`P05a<@014=2P0?2PH03@T700d;300<2P/0
3`d>010>3`0=2``03`d>014?400=2``03P`=014?40020040514A00h:2@0C3`h04@d<00l;2P0C3`h0
3PX9010<2`0?2`X04@d<02PT8`0[9bH061@B00l;200>2PL03`/8010<2@0B3P/0510=00803@T600L0
40`900h:1`0@30T03`/800h:1`0=2@H03PX700803`/800L06aLD00d91P0E4@h02PH300l;200F4Pl0
40l;00803`h:02l03@`800`;1`0>3@T040l;01/J5P0D4`l03Pd900`;1`0>3@T02`X800h=2`0B4@l0
1@@200h=2`081`D06APF00`;2@0920H04A0>00`;2@030P002@T900T8200:20T02`T:00h;300@30d0
510A00T41P0S7Al04@/=00l82P0E3a402@D6040n?`1<BT/05Q@E00D3100B41400@0000l=3P0B4140
0@0001LE5P071@H05Q@E00d;3002018@4@0H00`:2`0D4Q<040h?01<A4P1HEUL030X;01<A4P0>30d0
3`d>0040000:20T04Q0A01DC50071@H02`T:014?400C4A8040h?00/92P0:20T03Pd=00l=3P0A3a00
518C0P0>30d01`0=2``03`d>00h<3@0<2P/03@/<00h<3@0g<c@00P0D414200l;300900X61`0A3@h0
4Ph?00P41@0?2``05Q8C00d92P0E4A80510A00<04`l@00P03@T:01`H6@0C3a002`L801<?400=2@X0
6AHG01@B4`803P`=02H040h?00h<3@0?3@h05Q@E071^K`1CDE8030X;01dK70091`T01`D800<1100>
30l00@0200P62@0c<C@040hA00<1100<2Pd0108500D31P0I5QL04@d<00P4100810<00`0003Te=00=
2@P04@d<00h:2@0Q7A`00`0001@@3`0E4a@0518C00`:2`0?3@h020H7018@4`803`d@00/03@/@00l=
4P0D4QL04@lE00/93P0C4A@02`T<01<A500B41<0518E00h<3`0200d;3P0G00h<3`0?3A0030X=01DC
500610D09bDV018@4@0<2P`05Q@G00`:3@0C4AD03`dB00H42@0K61h0AdE:01XH7@0>30l03`d@018@
4`0>30l03@/>014?4P0=2`h00P0>30l00`0<2Pd040hAooooo`0Cooooo`006oooool0200?2Q0030L<
00l:3P0A31003`/=00h:2`0=2@X03`/;0P0?2`X02P0@30X04@d:01<A4P0D4Q<04Q0A03lm?P0D4Q<0
2PP900`:2`0>30d200l=3P0701DC5015@d@0EE=F01<A500=30h05A<F00d;3P0200l=40803P`?0P0?
3A007`0@3Pl030/800l>2P0<2`L081lM01`J6`0H5QL03P`=010>4@0?3A003@/@01@B5`0I5a`06A@K
00T5300?3A@09RD]01HE7`0>3QP03a0F018A5`0D51H0518C018>300?3P/061PF00`<2P0?3`h02`/;
010@400C4a<00P0@41000`0?3a00410B010@4P03018B500W018B5@0B4AH04Q4F01@C6@061P/06APN
018A600_;SH0SXfE01lO8`0C5A@051HE01LI600?4A005QPE02HX900J71L03Q0;018E3`0H6a@051L@
01<E4@0B51405QPG01hO800C51L051DI01@D6`0M7BH092@^05=CGP0D52405QLS014D6`0E6Qh05Q/O
01@I7`0F6b404aPN00805ATR01l05QXS01HJ9@0F6RD05QXU01XM9P0C5Ql05APQ00hA6P1JGFH0B4aE
00`C6`0Q:3004APP02D^=@0F7bH051dS02@Y;@0P9BP0724T02P]<00F6ah06AhQ01XO8P0I7R404AHI
01<H6`0G71l061dP01TR8@0L92D06b<U0080620R00X06R8U01XQ9`0I82L061lW01LN9P0I82T07B@^
01LN9P0I82P072<[0P0L8bT00`0M92X06R8U01`T9`0201`T9P0401hV:00K9BH062<W01HT9`<06BLZ
00P06RP[01d[;P0M:bh06bT/01XX:`0L:Rd07R`_01/Y;0807R/a00@072T_01`Y<@0M:S807R/d0P0O
:cL02`0N:SP07BTg01`X=P0N:cT07R`i020^>`0O;CP06RPa01LU;P0K:S406BP]008062L/03@06BP[
01XY;00G9bP05RDY01`[<P0O;CL07BXi01h[>`0J9cP06bPh01/X=P0I9c@05bD`01d[<`0H9B/0934g
014M8`0R;C<06B@Z01DO9@0D7B@09c0g02L_=P0A62004aXR01DM:@0=5RH06B8a01XT;`0E7bT06B</
014L8P0E82H05R4X01HP:@0C7BP05AlZ01TQ<00O9CD08RPf01<I9@0I82P08BP_018I7`0E728061lU
0:6X[`0[<SX061lY01DI8P0F6R<04aLP0P0G6b@02`0C5b005ATR010D7@0F6R<051PQ01/O:00F6R80
9BP]02@X:`0J7R404QHI008051PK03<04aLJ02hb=@0P92L03a<F01PL7`0G6ad05a/K01HJ6P0J7b80
6B0U01@K8@0B6b406B0V01<K7@0/<2`0=SP/09:AP`3emNH0Y:NU03i3AP0V:bl06AhR01PM8P0@5A/0
4QHO01@H8P0E6B@07b<^02L[=`0G6bH04QDO01@G7`0D5ah04QDL018E6`0C5Q/03A0E01DH700H71l0
3a<F01PL7`0=4A<05aLI01HF600Y:B/08B4S01HF600D51H05aLI010@4P0I6A/00P0E5AL00`0?3`l0
4Q@B01<E4P0301<E4P03018D4@0D5Q<0418?00805aTF014051HC00d?300E5A<05aTH01<G5P0=4QD0
3ADH00H>4@0>5QT03Q<F00hD500C51D04a<A018B400F61L03Q0?01<E5002014C4P0701XL6`0?4A00
3a4@00h@3`0?4A004Q@C01DG5P04014C4P0500lA400@4Q404A<B014C4P0B51<00P0A4a800`0A4a40
418?010B3`04010B3`0300h@3@0=3``030h;008030h;00X0418<00lB2`0=40T04A<=010B3@0>40/0
3a4=010B3`0@4Q404A8C0P0A4Q@0200B4a<04A4?014A3`0D51805QHD01DE4`0A4@l03Ph<0`0?3`d0
100A4@l051@B018B400;2`T3010@3P0801@D4P0;2`T06QXH00T91`0E5A<03Ph;00h?2P0>3`T2014B
3@0500h?2P0>3P`06a/I01DE4`0?3`l00P0A4A400`0=3@d03Ph<00h>300400h>3003014A3`0@40h0
410>00<03Ph<00@030/900l>300@3`d03`h<0P0>3@/04P0@3`d04A0>014@3P0B4@l040l=00d<2P0B
4@l03Pd;00/:200>3@/04A0>010?3@0B4@l04A0>00l>300=30X030/900/:20H03Pd;01l04A0>00X9
1`0D4a401`H4010?3@0<2`T03@`:00D40`0E518040l=00l=3P0B414040h?00X82`0B41<03@/@00T7
300;2@`0518B00h=2`0=30X04Q4?01DD4P0F5A<092<Q00`;2@0=30X040l=014@3P0<2`X04@/?0080
3`X>00T040/?010>4@0@3Q40BDM:04A4AP0>3Q001PH801XJ700B4Q@00P0@4100600:2PX05QHF00D4
0P0B4@l03Pd;00l;200A3@X03`/8014<200@30X04@l@00d;30091`P04@l@010>3`0?3@h01`D601HD
5@091`P05A<D024O800?30`02PH500l;2P803PX900D05Q8A00h:2@0C3`h03`/:00/71P0201PD4`03
00l;2@0>2PL03PX700803`/801@04@d:00l;200>2PL03`/8014=2P0?2`P040`900`81@0=2@H03PX7
00d91P0>2PL040`901<?300a;BX09R8O00d9200I5A8030T600h=2@803@`801803Pd9010?2`0@3`/0
2PT501DD400>3@T030/700/:1P0=30P02@P600h=2`0A40h00`8101hM6`0?3Pd040l=00`;2@0D4a42
00h=2`0401<B400@3Pl03`d>00h<3@8040`=01P04@d>01TC5@0C3@l02`H70189300D2`h030H8014=
3P0=2``02@L801<A4P0<2P/0=C<d02TW:00n?3d030X;01LE5P091`P04Q0A01LE5P0@3Pl02`T:00T7
200:20T2018@4@0<00`;2`091`P0;B//00h<3@0;2@X040h?00`:2`0;2@X02PP900l=3P0B414030X;
0P0>30d02P0?3@h04@l@01<A4P1UHf@07A/L00h<3@0E4a@04@l@00/92P0=2``200h<3@0A00`:2`0=
2``03P`=01XF5`060P<03`/<014=3P0B3Pl03`/<00d92P0D41406aLH00h:2`0C3a003PX;00l;300>
2P/00`0=2@X02`0>2P/04`l@014=3P0@30d0510A00l;300@3@h03P`=00X82@0;2@X03P`=00803@/<
00d01@@402HT9@0M6a`02`T:014?400@3Q005aDH00d;3P0:20/01P@701XH6`0i=cX030X=00<03@/>
00H05Q@G00T6200J5QD07QXI01<?3P0=2@P201@@3`0F00P40`0C3`h01`@301HB4@0i=C@0f=OH0;^i
^P0L6Q/0518C03Dc=00Y9bX04@lB00/9300=2a005Q@I010>4`0=2Q004@lD00d;3P0;2@`03`d@00H4
1`804@lB00X03P`?00`:3@0=2`h03P`?00d;3P081PL03P`=00X82@0D4Q<02`T;0P0@3Q403@0?3A40
2`T>00d;400A3Q@030X?00X83@0;2@`030X=00X82`0<2Pd04a4D010>4@0=2`h00P0@3Q400`0>30l0
4@lBooooo`0Cooooo`006oooool07`0A2Q405@hD01TC5`0D3Q803`T<01LA4`0<1PP03@L8010:2P0B
30`050l=01<?300@3Pl030X;0040000a;c002@L800l=3P081PL030X;00L51P0@3Pl04Q0A00X82@09
1`X05aDH00`:3@0F51L03P`?01dK7P0>30l00P0=2`h02P0>30l03`d@010>3`0A40`03`h:00X91@0T
8b407ahL01@B4`0?3@l200l=400A010>4`0C41L05A8I01D@5`0>2a@081lW03He?`0D51h00PD>00d@
5P0@4AH04A8D014A400A3@X02@P500X:200B4Q000P0C4a401@071`L03`l?00h>3P0>3Q003@d?0080
3Ph@00@0410B014A4`0A4A<04Q8E0P0C4QL07`0B4AH0:RT_018A6@071`h06QTQ0450B00@41@0418A
018D4`0B51804aDB01PJ5`0N81`05QPC014C3P0H6Q@061/D01HI4P0E5a<04Q@C01<D5P0E5QX05aPL
01DF700@41P06QXT01HF8`0F5B<05QDU014A800B5A`00P0F6al00`0B5ad051TO01DJ800301@H8@<0
51PS00T05QTR00P;500E624030lH01@G800Q9Bh020lG010G7`0F7BD00P0J8bX05P0J8bT0;S<g02DZ
;@17C4l0QHZ=02db=@0L8B@06AhQ01/P8`0O92L04AHI01XO8P0B5aX05b0O01HO7`0G7b406R8T01/S
9P0J8RD08BP^01`S:P0K8RX201hU;`0D01XQ:`0G7RH05ahV01PO9`0I82H06R4W01TP9P0F7R407BDW
01PP8P0E7Al06b<U01/U9P0U<3@07R`_01DS9P0B82<05R@W01/Y;00L:Rd201h/;`807B/^00<07R`_
01PS9`0L9bd00P0L9bd00`0K9Bh072H_01/U;`0201`V<P0;01dV=@0L9C@06RHd01/W=@0J9S@06bLe
01dY=@0K:34062D^01h[<`0K:2h00P0I9R`0200K:B`072X]01/[:`0H9bX06BP]01PV<00J9cL082dm
0P0H9CH06@0H9S@06BLd01TW<P0I9bl0QY>I0;W6c00b?T@0Qi:H07V2R@0S;3<05QlV01<J8P0@5al0
2A0H01DL900L92l03QLV01/T<`0J92l051hX01XT;@0>62404adV014K9@0A6bH00P0C72/0?`0I8380
318R02H/>P0C6BD03QDM00XA6@0O9R`072<Y01TP9P1?EUd08RTc01PO:@0C5b008BD^01@H8@0F6R<0
7R8[014E7P0E6B8051PQ01dQ:P0>4Q/03a<L01DI8@0Q92T08BDX01TM800C5aX05ATL01HJ7@0M8B@0
@DE802``<`0;3a805a/N01<G6P0H71d051PI01HK7`0J8BL05QlV018K8@0G7R@07RHX030d;P0k?2h0
KFaJ0=;@_@2=ShX09R/^09JKWP22Qh/04AHK020U:`0D6240720Z01/O:P0D62@04QHR01DI9@0A4al0
4aDQ018E7P02010C700;014D6`062A002`hC00lB5`0^<CH0CE1E018F6@0E5AL04Q8D01@D5P0<30h0
0P0A4A<01`0E5AL06a/M014A4`0C4aD08R8T0000000A4a000`0C5A005@0B50l04A<>00lA300J71L0
7b4L00`>2@0E5a8051HA00h>30051`H06QhM038f>@11BD`041PK00lG6P0=4QD03Q@D01<D5@0A4@l0
3`l=01<E500201@F5@09014C4P0>40l03Q0?018D4`0C5A@04Q@C010B4@0B51<051HE00804A<B0`0B
51<01`0A4a80418A010B4@0A4a804Q@C01<E500A4a401@0?4@h2010B3`0A00lA3P0>40d03Q0=00h@
3@0@4`d03A0700hA2P0C5Pl03a8;00h@2`0A4`l0418?010B4@0A4a<04A8D018C5`0?41400P0<30X0
1P0?3`d04A4?010@3P0@40h03`l=00d=2`80410>01T03@d;00P81P071`D0410>01<C4@0;2`T03`l=
014A3`0<30X04a<A00/;2@0C4a404a<@00h?2P0>3`T051D@01DF4@0?40/04a<A010@3P0<30X03Ph>
01dM7@0S8b<06a/K00H03`l=00@03Ph<00d=2`0=3@/03Ph<0P0@40h03@0>3@/040l=00l>300=30X0
3Pd;014@3P0<2`T03`h<00h=2`0<2`T03`h<01DD4P0;2PP00P0J6AL0100>3@/020L500h=2`0<2`T2
00h=2`803`h<00X03Pd;00`;2@0=30X03Pd;010?3@0A40h04Q4?01LF500C4Q002PT70P0@3`d03P0B
4@l05aHD00d<2P0b<Bl04@l@00`:2`0I5aP03@/>00P62@0F51L030X?01DC600<2Pd03Pd<0P0:2@L0
100=30X03Pd;00h=2`0X9bD200`;2@0500@30P081`D030X;01<<4P0@2a400P0?2Q009P0>31403`dB
010>4`0<2a003@`A01DD6@061@X02@T;01@D500;2`/030`<00H61P0C4Q003`h<00/:200>2PL04Ph;
01@@3@0A30P030P600d;300<2P/0=cDf030^;`0<2P/03P`=010>3`0C4A803@/<01XH6@13@D804a0@
00/71P0L61L05A4@00`81`0I5A@03PX90P0=2@P01@0>2PT040`;010<2`0A3@/04@`900<040/800@0
4@`900l:1`0B3@X04`h;0P0>2@H09@0A30T02`L400h:1`0@30T03`/8010<2@0E4@h0:BDR01@@3@0B
3P/05A4>00<0000N6QL040l;00h=2@0<2`L03Pd9010?2`0?3PX02@P4018A3@0<2`L040l;018A3@0A
40`01`H400X91`0D4a403Pd;02@S8@0P7ad0C4]901PG5@0;2PP01PD300l>300;2PP00P0<2P/01`0;
2@X03@T:00l;300?2``030H801<;3P0J4A@00P0D2`h00`0D3Q005A4B00l=3P02010>3`0900L51P0H
5QL03P`=01@B4`0N71d02PP9018@4@0100002PP900801`D600P05A<D01dK70071@H03@/<00P61`05
0`@07Q`M00D310802`T:01/02PP900`:2`0C4A8010830040000@3Pl030X;00T7200;2@X04a4B01TG
602k^KX0>3Hg01LE5P0>30d02PP900d;300<2P/03P`=00d;300;2@X030X;00d;300=2@X03PX;00l;
300@30d00P0>2P/01`0B3Pl05A4B01PD5@0C3a0081`M00`82@0@30d00P0?2``00`0@30d04@d>01LC
500200<0000400P41@0>2P/06aLH00d:2`8020H701d02PP900`:2`0=2``02@L801DC500@3Pl02@L8
01@B4`0100003@/=00d;400B41D05Q@I01PF6`0=2a001@@800L52P0610T07Q`Q01<A5P071@X04PlA
02PR8P0R71`040X:014;2`0;1PH03@L700@00002010:2P0400l92@0X8b80W9ZK07EcM080518C00/0
0P01014?4P0C4A@02@L:018@5@0S8BH0518G014?5@0B41D02@L:00h<3`0200`:3@0404Q6B@0M6ah0
61HI00l=408030X=01D02`T<014?400?3@h01P@50040000@3Q003P`?01HD5`0?3A405A<H014?5006
10X040hC00h<4@0?3A0030X=00X82`0<2Pd03`d@01@B5@0B41<00P0F51L00`0C4A@05Q@Gooooo`0C
ooooo`006oooool07P0@2Ph03`T<01<?400B30h02`H800l;2P0@2P`03`X:010<2`0C3@d04Ph<010<
2@0@30/04@l@00h<3@0^;2d02`T:01LE600?3A004@lB00l=40091`/040hC00/9300F4AD00`0201DA
4P081@L05A0D00X82@<03@/<02403P`=010>3`0@3`d03Pd901XI5@0:2@L030X:00X82@0;2@X03P`@
00h<4@0?3A804@lE00l<4`0=2Q4040`C00T63`0921003PdE00/;4`0H62003a0F00h?4`0?3a403`h=
00l>2P0C4Pl020X701TK60051`@06ATG00<30`0G5aL00P0@41006@0@3Q404@lB014?4P0A3a<040lD
014@5@0B4AH04a8G01@C600E51T020L=00H52`0M72803`hD01HE6`0C4aD04A<B010B4@0>40h05ALD
01@F4`0A4a003a4>018D4@0I6aL00P0C5A00500D5Q@04A8D014B5P0<3A805AHK01LG800G5b40410L
01/J:00B4B406QTY01TH:00B5Ah05a`P01PL8@0F6B006QlU01lS:@0G6R405Q/Q0P0G6R<09`0F6R<0
5aXS01DH7`0H6b803a8I01TL8`0B5A`04aPN010E6`0L8bT03Q@J00`C6@0F7B<06R4W01XO8`0T:B`0
SI:F0?Olo`1BEe/05Q/O01`Q9@0H7B406QlS00@93@0J7b<04a/N01/S9P0F82805QhQ01TQ900J8BD0
5a`R028V;`0L82T07B4/01lV<00L8bd04QTS01TP:00201PO9`0C01XQ9`0K8RP06B0V01@K8@0M9BP0
5AdP010H6`0G7b806B<U018M8@0F8BD05b8V01PS9`0K9RX06RDY01/V:P0P:bl08Rda01lZ;00201dX
:P0>01LR9@0L9BX07BP/01lY;P0P:C0082Xc01XT;@0L92l07BLc01lX=@0P9cL07bTe01XU<P0J9S@2
01XV<P1401XW<00K:34072Ta01TV;P0G92X05b@[01TV;00J:2/062LW01h/;`0P;c@06BLa01@P;P0F
8c<06bPh01XU=`0J9cL072Xg01l[>@0S;ST0U9nU0<gHgP0S;C40Ae1E04eFF`0W;c@05A`R00`C6@0A
61h041LM01<J800F7BP01a0O01PO;`0L9C407RPb02/c?P0J8bh0628/01DM:00D7BX0624`01PO;`0D
6b/020hL00lE8@0N9C007B@/01PO9`0A62006B0X024X<00D6b@07bDa01@J9@0?4a`092Pa01HJ8`0G
6b@08bL`014E7P0B5Ql03A4J010D7@0B5Ql07b</018G7P0=41D2010D5`0R014E600G6ah06AdP01PL
7`0J6al04A8F01TJ7P0H6Ad05aPL02DY;00J7R404QLK01<J800D6b4051/R010H6`0H7B005ATE034c
:00P8A<0EUE705EGEP0U:Rh0@DI:02DZ<00F6b403a@J00dA6P0A5Ah051PQ014E800?4ah05ATT010C
70804aHO01L04A@K018E700C5Qd04aHM01PK800;3Q<0C4mD08^>T`0D5AT051DG01HF600E5AL03@d?
01DE5`0A4A<03`lA00d=3`0N7R005ADG00h>400E5AD0418?018D4@0201@F4`0M014C400@4Pl05aTF
00d?300F61D04A<@01@F4`051`@05QHF01PJ6@0C51H0QHZ=0<76bP0b=c/05AXN010E600A5AP05ALG
01<C4`0A4A403Q0?014C4P0@4Q404aDD010B4@092`X04A<B01<E500B51<00P0@4Q400`0A4a80418?
018D4`0301<E500401@E5P0C5A@04Q@C014C4@<0418?0`0?4@h200lA3080418=00`03a4<00h@3@0>
40d03Q0=014C3P0@4``04QD>01DG4@0>40/04A<>01@F4P0?4@h2010B4@804A8D01P04A8B014A3`0A
4@l051@B01HF500E5A<04a<A00h>300=3@/051@B01LG5@0C4a40410>01XJ600e=3804a8@00T91`0?
3`d04A0>01@D4P0:2@L03@`:00X:200E518200`=200601@E400E5Q403a0;01<C4@0@40h04A4?0P0?
3`l00`0C4a<05aLF00l?3@0500l?3@03014A3`0@40h03`l=00<03@d;0P0A40h04P0?3P`03Pd;00l>
300C4Q004Q4?01<B400<2`T02@P601`K6@0f=C<01@@202`[:@0h=cD08R4O00/:200=30X03Pd;00l>
308040l=00H03`h<00h=2`0>3Ph0410@018B4P0C4a<201HF5P0R010@400F5QH01`L701DE5@0:2PX0
3Ph>00`;2@0510805A@B00`;2`0A3a0040h?01@B5@0610L03@/>00/9300L6Ql01P@700l=3@0=30X0
3Pd;010?3@0>3@/030/902HU8`0J6AL081lM010?3@0?3P`05Q@E01@?4`0A31003`X>00h93@8030X=
02L01`H801TI6`0A4A<01@D700d=3`0B4Q@02PX:00T7200D4a@0108300d<2P0>3@/020L500P40@0=
2@H04`l<018=2P0@30X02`T:00`:2`1^K6d0I69S01DC500;2@X09B<T0040000A3a000`4200l=3P0A
3Pd040`;02XV9@0P71/03PX901hJ6@0C3`h03PX9010<2`0A3@`00P0;1`H00`0@30X040/800l:1`03
00h91P0Q014<2@0E40d04`h;00/60`0<1`@04`h;00`81@0?2`P04Ph;014=300B3Pd061@C04m;BP03
00003@T800/71P0I5A@0FeMF01<B3P0?3PX030/700h=2@0?3PX030/700T8100@3`/020L300`;1`0>
3@T02PT5010?3@0<2`T05A@B00802`X800L03`h<01LF500920H061LE00`;2@0>3@/040l=00803@/<
02L03P`=014=3P0D41405A4B02<O800>20X02@<501PB500=1`T050h@018>3`071PH04Q0A00T7200F
51D01P@500h<3@0i=cP04Q0A00L51P0A3a0040h?00`:2`0=2``0518C02h/;@0g=CH030X;00X82@0F
51D020H700<10P0H5QL020H7010>3`0=2``020H700h<3@0;2@X00P0?3@h0300@3Pl03`d>00h<3@0@
3Pl04Q0A03/i>P071@H04Q0A010>3`071@H04Q0A00`:2`803@/<00D02`T:00`:2`0=2``03PX;01DA
4P0200l;300800`82@0>2P/04@d>01<?40050@80=C4b05MCE00@30d300l;300<014=3P0B3Pl0=C4b
020L7@0F4Q<04@d>00P41@0H51D02`P900d;300?3@h03P`=0P0<2P/0BP0>30d02PP900`:2`091`P0
7A/L00d;300@3Q0020H900P62`0?3A402@L:00d;400@3Q802@L:018@5@2IUi/0LW1c00L52P0;20X0
40X:00d71`0C3@d04@/;01<=3@0A2`d0618D018<3P0G4A<02@<5014<3P0L6Q/08AlP00h<3P0G5AP0
20H900d;3P0;2@`00@0200`:3`0Q7b@040hC00d:400C4A@02@L:00d;3P0;2@`071XM08J4Q`0U8bH0
7adP01<A500<2Pd02`T<00X82`0A3a801`D601hL7P030@@05A<F00800`0A3a803@/?00X83@0;2@h0
4@lE01PF6`0@3Q403@/>00T72P0;2@`03P`?00/9300=2`h030X=0P0@3Q400`0=2`h040hAooooo`0C
ooooo`006oooool04P0>2`T03P`:00@30@0C40h051<@00/:1P0C4@l06aTF00d<200@3@X07Q`I01DC
400<20L04@d=010<300?2``04PdA010;4@8040/B01d04`dH00h8500>21D050hI014:3P0A2P/04@X:
010;2`0@2P/040/:010<2P0=30T030/800X91P0<2`H03@`800h=300?3@d030X;00X92`0>31004a4F
010=4`0?31@03@XB00/84@0>2aD04@hH010=5P0200l<4`0B00l=500@3a@04A0E010?4P0K6Q/01`H6
018A3`0>3@T0310:00XC2`0;4``03aD?00`?2`0;3@X0410>010?3@0A3`d050l@0P0F3a405`0E4AH0
3@`C01HE6`0U92X051<I00d<4@0A41@04Q8D018B4`0C4a<04Q8A018B400B4a004A<@018D4@0D5Q@0
4Q@C01/M700N82004Q@D014B5@0D5AP05AHI00804a@G01T04a@I01TJ800K6b@05aLQ01TI900H5b@0
61LU01DD900F5BD06aXZ01HE9@0S8b`06Q`Q01HH7@0G61d04aDJ01LH7@0C51T06A/P01HH7P0K7280
5aTO01PI7`0C5aX05ATK00804aLI01405a/M01HJ700I7Al061`N01HJ700C5aT05AXL01hR9@0H7B80
7R<X04I;D@2;T9L0:Bde02hc>P0E6R4061dU01TM9`0201LK9@0@01HM9P0C7bH04alX01HN:00F72L0
6a`Y01lN:`0R8Bh07Qh[01`N:`0L82`06b0/01LN:@0M92d07B@/01PO9`807B@/05d07bH^01dT;00J
8BP05ahU01HM900H7bH06R4X01/S:00L9BL082P]02@/<P0[<cX08RXa01/S:@0O9bd07RLY01/T900N
:2H08R`Z01lX:@0O9bT08b`^01lW:`0I82H07bL^01dU;@0O9S007bHa01lU<@0N93407BD`020Y=00N
:3<07RPb01lY<`0K9Bl06B<]020Z=00G8B/08R`e03Q2B`0G8BX07RPa01HQ9`0L9Rh072L`01TS;P0H
8Rd062<`045;F@0L9CD072Hf01PR<`0U;Sl06R8^02/a=`0]<cP05ahQ01LM800K8B@05ahN01PN7@0G
7A`05A/J01@J6@0F6ad0>3i7061WN00E6Rd05Q`/014H9`0C6BP05A/Z01@K:00G7B/061h/01@K:@0B
62H051`V01HO900D7B<05QlU01PQ:00F7bL04QXT01XR;00F7RX08BTe01<K:00H7bd061`W018F7`0D
62400P0c=d00200C5b006alX01@F7`0D62406QhW01HJ8`0D62005AXM0P0D6QX201DI6P0:01LH6P0E
5AL05ADG01HE5`0H51P06ADI01XH700K72406A`Q01LJ7`805QXN01l05QXO01PL8@0L7b@051PL01/M
7`0I71h08bHX0495D00k?DX04A<O01LI900B5Al04aHO01@G7P0B5A/082<Y01TL8P0D5a`051PL01HG
700C51T04Q<H018C5`0B4aP051DI01DF6P0B4aL03@hB01TJ7P0G61`06a`P00804A8D0P0B4aD08P0E
5QP05aPJ01@E5`0F5aT05AHH01@E5`0E5QP061TK010A4P0D5QH05AHG018C500A4a<04a@E00h@400M
7al020X:01@F5P0@4A804A8C018C5P0@4A@0824U05YLG`1jOH007b4U01DG6`0D5QX03PlC01<D600A
4QD02``?010A4@0A4a82018D4`1<010B4@0?4A004Q@C010B4@0L7Qd07AlN00h@3`0=3``05AHA018B
400A4A404A4B01HF6@0@3a@0410B014A4@0B4`l04Q<<018C2`0A4Pd0410A010@400@4@d04A8<018C
2`0A4PT04A8:01@E3`0E5Q804Q8B00l?400A4A003@h:01DE4P0@40d04a<A00X:200A4@l0410>014A
3`0B4Q004A4@010@3`0A4Pl03a0;00h?2P0D5A005aPC01@E400@4@`02@X500l@2`0C50l0>CXe02X[
9P0;2PP061DD028O7P0>2PT04Q0>01DB4@0C3`h040d<00l<2`0F4Q404@l=010=300T9280?clm02/[
:@0:2PT02`/9010@3P0D518030`:01TI5`8030`:00L051@B01DD4@0@3`/05A@@00L60`0l>cL0=SDa
008040l;0`0?3PX00`0=30P03`h<00`;2@0201@C4@0300h=2`0C4Q003`h<00803`h<00@03Pd;014@
3P0D4a403Pd;0P0C4Q00600A40h03`h<010?3@0;2PP03`h<010?3@0?3P`03@`:00d=3@0R8bD0:bh`
014C5P062@/02`d@01LI7017BT`0YJNY05AGF@0<3Q407R4S00T:300>3@h03P`=00d;30803P`=00/0
3`d>00d;300<2P/04a4B00`:2`0@3Q0030X;01<A4P0>30d03@/<00l=3P02010>3`0L01TG600F51D0
1P@500d<30091`P07A/L024P7`0>30`02@P7010>3P0>3@`02PT801<A4@071@D03Pd<00`:2P0E4a<0
2PT800d;2@0L61L05A8A01DA400@30/04Ph=010<2`0?2`X03PX900l;2P8040`;00D02`L600h:2@0C
3`h06aLF00/71P0200l;2P0700h:2@0?2`X040`;010<2`0=2@P05Q8?014=2P0201<?300900`81@0D
40d03PX700d91P0?2`P04@d:00l;200>2PL04@d:00<03PX701/03`/8018>2`0@30T03PX700d91P0?
2`P04`l<010=300C4Q0081lM00d;300>30d09R@V06MUI`0B418030X>00<11@0=2`l040hA00/:2@0A
40h03`h<00P71@0;2PP040l=00`;2@0=30X00P0?3P`01@0>3@/03@`:00d<2P0=30X03`h<00804Q4?
00<03Pd;00`;2@0<2`T0100<2`T0200=2``030X;00d;300>30d03`d>00d;300?3@h03P/<0P0<2@X0
1P0>2``040d>00l=400;2@`03P`?00l=40802@L:01@04a4D00`:3@071@P04Q0C00h<3`0A3a802@L8
00/92P0=2``03`d>014?40091`P03@/<00`:2`0=2``04@l@00h<3@0;2@X03@/<00h<3@803`d>00D0
3@/<00`:2`0A3a0030X;00h<3@0200l=3P0H01<A4P0?3@h04@l@010>3`0=2``030X;00d;300C4A80
4@l@00d;300;2@X030X;00h<3@0@30d01P<301TE5P0B3Pl020@5014=3P0@30d04@d>00h:2`0@30d0
4@d>0`0>2P/300l;300b010<3@0?2``040`=010<3@0>2P/03@T:00l;300>2P/03`/<01DA4P0A3@h0
3`/<018>3`0<20T02PH700h:2`0=2@X02`L800h;300;2@X030X<00X82P0B41401P@600l=3`0:20T0
5A<E06ITIP0g=CH05A<E02/X:@0I5AH03PX;014=3P0=2@X03`X=01<>4P0J5AT050lD00/62`0@2a00
3PT?01<A5P040PH0518F01DC600A3a@030X?00d;400>314200l=4P803P`A01403P`?010>4@0=2`h0
3P`?01DC5P0L6Qd030X=014?4P0?3A002`T<00l=400@3Q4040hB01LE6@0A3a<04Q0E00l=4P0201<A
5P0A00l=4P0:20d02PP=00d;400@3Q<0518E00d;3P0?3A0030X=01<A500<2Pd02@L:014?4P0>30l0
0`4400h<3`0<2Pd05?ooool001_ooooo01T04a8@00L6100E51803@`:00H50`0J6AL07A`J01lN700?
3P`02PT700l>30061@<02@D601@@4P0>2@d030L;010;400300@03PT@00h94@0C3AL03`TD00`64P0@
2a804@P;00804@P90`0?2@T0100>2PT03@`800d<200>3@T200d<200:00D40`081PL04@l@01XH6`0B
41D02@L<01<@5`0>2a@030TB00d:4`8030TD00@03P/C00h;4P0>2a803`dB0P0@3Q<0?@0<2`d03`d>
01XH6@0D4a402`X8014D4@0D7AP0?TA002db<0031`H04A<B00l?3`0@3Pl04Ph?01@>4P0E3a<05`hC
01`G7@0E51X03`hD018A5`0B4AH04A0E018A5@0C4aD04a<C01<C4P0A4@l0410>01LH5@0A4a002@/:
00H81`0M7ah0HfAV065RI00E5QP04a@H01@E6@0G61`061TM01PI7P0?3aL04A4I020P:P0O7bT04Q8L
01HF8P0D52005A@R01HE9@0D4b<05A@S04Y:DP0b<cP05aPM01PI7P0K72406AXO01@E6P0M7R<00P0I
6Ql01P0B4aP030dB014E600D61/04aLJ018F6@805ATL02H06QhQ01PL7`0G6ah06AdP01/O8P0L82<0
3A8H028V;`0?4a`05a/T01XN9`0<41T06AdX01DI900J7RT08RHa024U<00D6bD05b4[01LR;00F7RT0
51XV01XK:00Q82h07A`Z024Q;`0Q9C407b<_01TP:`0G7bX061lY01lV<01FGFL07RD_01@K9@0M92h0
72<]01/R;08061lY01006R4[01/R:P0K8RP061lT01`S:@0L8b/08RTa01DL900J8BP06R4W01/S9@0L
9BD07BHS01hW900P:BT041PK0P0M9BP0;P0K8RP061lU024X<00N9Bl07B@^01hU;`0P9S8082Pc02D^
>00O:C<07RPb01dW<@0J92h0628/01dW<@0?6B<06B<]02li@`0E7bT05R0Y01hY;P0H8bT05R4W01LR
:@0I8b`06B<]04iHH`0M9c<04a`[01@M;00L9C@05alY01LL8P0F6al061dQ01DJ7@0G71l06R0P01HL
700D6QX041HF014G5`0F71`0CUAL07=iQ`0P9SH200lE8`0F01@J:00E6bT05adY01PN:P0E6bL04QPT
01@J9P0J8RX06R<X01PQ9P0H8BL05b0W01DN9@0@6B407bPa00`D7`0E7BT04ATV018J9P0=4A`04QHO
01@H8@803Q8K01004aLP01`P:@052A808BD^00L;500>4Q/09b/c01TN8P0E6Qd04AHI018F6@0C5aX0
4a@H01PG700G5Q/05QDJ0`0F51T0100K724061/P01LJ7`0F6Ah201LJ7`0U024T:@0>4AH09BP]0495
BP0H6b005QTO01HH900E5b@06adZ00`>6P0E62805QTR01DH7`0G6R004QDJ00/>4`0H6al04QHI01TJ
7P0@4AD06AXN01LH700B4aL0:2T]01DF6P0C51P051DI00/<400@4AD04A8F01<D5P0D5AL03a0B00`=
3`0J6ad0;2d_014B5002018C5@0N014B500B4aD05AHH01@E5`0>3a403@h@018C5@0A4Q@03PlA00`=
3`0>3a405AHH01PI6`020`D07b0R01DF6`0F5a`061TN00X;400C51T0414F00D62`0A4QL08b@Y00l@
5@0L7B805aPL014B4`0@4Q403a4@0P0@4Q40600A4a803@l>00h@3`0G6AP05ALF00lA400B51<030`:
0000000;2`/04a<E01PG700>3A404A4A014A3`0B4`d04A8:010B1`0?40/03Ph@00h>3P0>3`/03a0:
010A2@804A8:00H04Q<=018C3`0A4A40410B010@40092@L200d=2`05028R800B4Q003@d;014A3`0?
3`d00`0>3P`01@0@40d03a0;00d>2@0@4@`04A8=00803Pl:02L0004001<D3`061`80004001@E400G
5Q@020L5014@3P0D4a403Pd;01DD4P0B4@l06QTG02<R800J6AL01@@201<B40020P006a/I00X:2@0D
5180<S8`01/K6@0;2`T03Ph<01<C4@0<30X061PF01<C4@0>3@T061LC00h=2@0C4Ph03`h:01@C3`0B
4@d040l;00h=2@0@3`/00P0D4`l02P0920H04Q4?010?3@0A40h04a8@00P71@0>3@/04A0>018A3`0@
3`d200h=2`0=00`;2@0?3P`040l=00l>300>3@/03`h<00`;2@0?3P`040l=00h=2`0=30X03@d=01hO
8@0202LX:P0<00X;3@0I6Q`06Q/M05]LGP2e][P07b0R07=dMP0U9RP09bPZ00h=3P0>30d03@/<0P0>
30d0200?3@h04a4B02@R8`0A3a0040h?00X82@040P<03`d>0P0<2P/06`0>30d040h?00l=3P071@H0
20H700`:2`0Z:2T04Q0A00@20`081`D03Pd;00l>300<2`T02PT700/:20071PD05A@B014@3P0<2`T0
0@0001dL6P0>2`X030P701dI600H51<040`;01@@3`0200l;2P0@010<2`0?2`X03`/:00`81`0S7ah0
3PX9010<2`0A3@`020@3014=300?2`X040`;018>3@0@30/03@T8010<2P807a/H02L06QHC01<?300C
3``061@A010<2@0?2`P040`9018>2`0@30T04@d:00d91P0?2`P03@T600`81@0B3P/03@T6014=2P0B
3P/03@T600/7100@30T030/700l>2P0G5Q<04A0>01@C4@071PH01P@500<10P0C4A@00@0200X82`0>
30l040h?00d<2P0>3@/03@`:00X91`0;2PP00P0=30X300`;2@0700d<2P0>3@/030/900d<2P0?3P`0
40l=00h=2`0600`;2@03010>3`0>30d03P`=00803`d>00@03@/<00l=3P0?3@h03@/<0P0<2P/0400;
2@X03`d@014?4P0;2@`02@L:00/9300610L00@0201DC5P0?3A000P0300X92`0<2Pd02PP901HD5@0?
3@h200`:2`0:00l=3P0=2``030X;00`:2`0=2``02`T:00T7200>30d03@/<00`:2`803@/<01l03P`=
00`:2`0=2``03`d>00`:2`0?3@h05aDF00/92P0>30d03@/<00/92P0:20T02`T:00`:2`0100003@/<
01DC500B41401@<4014=3P0D41401P8300/8200300006aLH00h:2`0@30d03@T:010<3@0B3Pl03`/<
00803PX;1@0?2``0200>2P/03@T:00`82@0=2@X020D500D10P060P<02`L80P0D4140900E4A805Q8C
01@@4@0A3@h02`L800h:2`0>2``03`d>00@20`0A3a002`T:00P61`081`L061HG00`:2`0:20T03P`=
01<A4P0D4A8030P900/7200:1PL03PX;00l:3P070PH03PT=00d83P0:1@/04@`B01<>5@081P/0D4iC
05aJG`0100@07Q`Q01TG70803@/@0`0>31400`0=2a004Q0C014?4P0200/9300@00l=400:20/030X=
00l=400>30l02PP;00`:3@0>30l00@0400P62`0=2a001@<8018@5@081P/03P`A00d;40802`T>0P0<
2Pl00`0>30l030X=01@B5@02010>4@0700P62@0C4A@02PP;01TG6P030@@030X=01@B5@0Dooooo`00
6oooool02@0;2PP08b8P0040000100004a8@00T81P0100003@`:00h=2`0200d<2P0>00D3100>2@d0
5a8G00`72`0=20h061<I00d83P0@2a803PT@014<4`0?2Q403@P?010;4@0C2P`201<:2`<04@/;01<0
40`;00l>2P0A40`04a8>014@300?3P`05A<D00/92P0P7Ql0@3i102d[<00B41D05Q<J014>5`0@3AH0
4a0I018?6P0?31D03@XA008030T@0P0>3140700?3A806aTL00P61`0B41403`h<00/:20031080624N
09:HUP1ZKfl0004001hO8@0?3a0040hA018=4@0D3Q805@lC01L>4`0I51/05QDK00l>500=314040lD
014@5@0@3a<0410B014A4@0C4a8201<C4@0P014B400?4@h05aTH01XL6`072@P02``>01PI6`0E5QP0
4a@H01@E6@0G61`06AXN01DE700A4AT06a/S01XJ900C4ad051@N01DE8@0B4Qh05A@R01HE9@0B4B40
5QDT024Q:@0O82D06AXO014B5`0@4AH061TN01dN8`0W:2d2020Q9P0G01`M8P0H6Ah04aHK01LK7P0G
6Qh051LL01LK7P0F6Qh05QTN01<G6P0B5QX05aXO01PL7`0F6Ah05a/T028V;`0J7RL05QXS024U;P0B
5Ql0720[01HJ9@0I7BP00P0Q9C00;@0E72H05AlY01@M:00D72L05adY01/N:`0L7R/05aTV01lR;P0P
9S807B<_01HO:P0E7bT04ATT01`S;P1LHfd07R@`01TP:`0K8R`06R0/01XP:`0H7bT061hZ01TO:P0J
8B/06b8X01@L800G7R@051/S020W;`0D6b<06R4Y01TP9P0K8bH07RHW01dV8`0L9B@072@V03Dm@00J
8RD07BDX01dT:P0P9bd08RTa01lV<00201hU;`0401lU<@0O9c8092dh01hX<P807BLa00D072H`01/U
;`0P:S@07RPb01HP:P02010J900E02La>P0M:2d06bHZ01dX;P0O:S006bH/01LQ:P0@6R@07BLa01PR
;@0=5b<05Al[01/R;00K82H07B8V01lT:00J7b<061dQ01HK7P0D6QX04aTI00804ALG02/05A/K01PN
9@0X;SX041HT00hD8@0631P04QPV01LM:@0F72P06Al[01DK9`0B62@05A/W01PP:00G82D05QlT01DN
900D7B@04a`S018K8`0G82T031@O024Y=@0B6RL051/W00X>6@0W:c@05ATR014E7P072a@05a/T0002
2`16BU<03Q8K01/O:00B5Ql0A4U@01dR9P0G71l041DH010D5`0A5AP03a0D00805QDJ01h05A@I01DC
600F51T05QDJ01LH7@0E61d051LL01<F6`0D5a`05APM01XM8P0L7b@04QDJ01LJ7`0E61d06QdS01PJ
9P0D5R<05aTU010B7P0B5Al06QdV01DH7`0E61h05QTN00hA5P0E61`04ADH01TJ7P0C51P201LH700C
01DF6P0O82@05QLK01<D600H6Ad02P/?01DF6P0?41@03a0B01@E5`0C51H04A8D01DF600L7Al0414C
018C5@0A4Q@0414C014B500201@E5`1c010A4`0?41804Q<E00h?4@0;30h04A8D00H72@0A4Q@03@h@
01lP8P0?41@05aPM01<D6@0:2a0061TN01XK800B4aP061TN014B5`0H6Ah03a0E01HG700S92P04Q<D
00lA400>40l03a4@014C4P0B51<03Q0?014C4P0E5aH0418A00h@3`0D5QD061PH01XJ6P0K6ad061PJ
05mNH`0<30h04A4A014A3`0A4P/0418700lA100?40/03`lA00l?3`0?3`d03a0;010A2`0A4PX04A8<
014B3@0@4@h04A4A014A4`0?3`l04Q8@01dM6`0?3`d07AdK01<C4@0A4@l04Q8@010@3P0>3P`03@d;
00h>300?40`03Pl:00d>2@0?40/0414<00h?2P0B4`h030d8010A300>3`X05aPC01PI500G5Q@03@`:
01HE4`0J6AL03Pd;00/:200C4Q006aXH08V8QP17AT@07A`J00d<2P0I6AL051@B00l?3@0G5aD02PX8
00@40`051@<02PX8018B400?3`d0410>00d=2`0510004Q4=00/:1P0D4`l04Q4=010?2`0510003@`8
01@C3`0200d<200301DD400>3@/04Q4?00803`h<00<05aHD01/J600?3P`00P0B4@l2010?3@03014@
3P0<2`T03Pd;00803`h<0P0@3`d00`0<2`T03`h<00l>300200h=2`0@00h>300820X02``>018C5@09
2P`04A8D00D6200J6ad0=cPj02X[;@1TIFL0=3Dg00000P0?3@h03P`=00d;30803P`=00P03`d>01@B
4`0A3a001@<402DS900L6Q/05Q@E00`:2`802PP901003@/<00l=3P0>30d04@l@00l=3P0J61T0KF]/
01HD5@091`P03`h<010?3@0=30X02PT700h=2`0B4@l02@P60P0>3@/05P0?3P`09bHT092?S@10?3/0
2`L601HB4@0G4a802PH500l;2P0>2PT040`;014=300@30/03PX900d9200o>cX08alN00`9200B3Pd0
40`;018>3@0@30/2014=300;00l;2P0=2@P03@T701DA3P0G4a004Ph;00d91P0?2`P04`l<010<2@0?
2`P00`0@30T0700C3``02`L400d91P0A3@X04`l<00d91P0:1P<030P5010<2@0?2`P03PX700l;200<
2`L02`X600L610030P004a8@00d<2P0<2`T04a4B00h<3@0<2Pd04Q0C00T72@0?3P`02PT700`;2@0@
3`d200/:200500h=2`0=30X030/900/:200<2`T00P0>3@/00`0<2`T02`X800d<2P0200h=2`H030/9
00P04Q0A010>3`0?3@h040h?00l=3P0<2P/02PP900`:2`@03P`=01803@/>014?4P0:20/01`D801<A
500O7B003@/>00H41`0200<09B<V00X82`0F51L04@l@018@4@0100001`D600`:2`0>30d200l=3P0A
00h<3@0?3@h03@/<00d;300?3@h030X;00/92P0<2P/03P`=00l=3P0<2P/03`d>010>3`0:20T03@/<
01DC500<2P/00P0?3@h05`0=2``030X;00d;300A3a004Q0A014?40030@804Q0A014?400F4Q<04Ph?
00L3100F4Q<05A4B010<3@0B3Pl04`l@010<3@0B3Pl04`l@010<3@0?2``03PX;00<040`=00H03`/<
00h:2`0=2@X03PX;014=3P0D414201TE5P04014=3P0=2@X0510A00h:2`801P8300T02PH701@@4@0A
3@h030P900D30`0A3a003P`=01XH6@071@H00P0;2@X06@0=2``02@L801TG600:20T03`d>018?400;
1`P03`/<00/7200A3@h04PdA00X52@0?2Ph03PT?00X52`0>2@l040/B01XH7@0<2Pl04Q0E00l=4P0T
8RL0108700`:3`0=2a000`0>3140500=2a002@L:00`:3@0<2Pd03P`?018@4`0?3A002`T<00d;3P0>
30l030X=00d;3P0@3Q404a4F00d;400@3Q<00P0501<A5P081P/030X?0`0=2a001@0<2Pl02`T>00l=
400;2@`04a4D00803P`?00L02`T<01@B5@081PT03P`?00T72P0>30l02@L:01Cooooo000Kooooo`0E
01<B400V9B<09bHT03hm>`0=30X03`h<00T81P0>3@/03`h<00h=2`0?3P`04a4B014<4P0B3A@03@P>
01D@5`0Y92X0:RD[01@?5@0>2@h03`X>00803`/>00@04Ph@01892`0B2@X04PT:0`0@2PX04`0A3@`0
3@`:00l>300C4Q0040l>00h<300>30l040hA00l=400<2Pd03`dB01<A5P0C41L04@hE018?5P0E4Q/0
514J01<@600@3A@00P0?3A804P0A3a@04Q0C018@4`17ADP08R0Q01HD5@0Y9bP0=38c014B500:4180
51XL01<G6P072`d03@hB014?500@3Q<04PdC01@>50805@hE00X040`C010?5@0E51T05QDJ00h=4P0=
3@l04A4C018B500B4Q804a<C0P0B4Q801`0C51@061XI01DG5P0?4A005aTH01LH6P0B4aH00P0C51P0
2P0B4aP04a@I01LH7@0F5ad05QHN01hN9P0M7BL05QHP01LG8@0F5R8201DE8@0L01PG900I6BH05aLT
010@600F5a`06Q/P01DF6`0F5a`06Q/P01@E6P0N7b@05AHK01@E6P0G61d061TN014D6P0G6R006A`S
01@G7`0E61h05APO01PK8`0F6Al05QTP01PK8`0I72805aXR01<G8@8061`W01<05ATT024U<00E6B@0
6alZ01PL9`0E6B@05QXU01TM:00I82X06R8]01@L9`0E7BP06b4]01/P;00C62@05Q/W01XQ;00J8bh0
5R8[00804QlX00L072@`01TO;00T:SL02Q0N01`R<00I7b`05Q`Z00805adZ01`05ad[01PN:`0H7RT0
82L^01TP9@0N9B/07RD]03<j@`0_=T006R4Y01/R:00M9BP07bPX01hW9@0M9RD07RHX06A/K`0O9bX0
82L]01HM8`0P9bd07bH^020W;`0Q:30082La01`S;@0J8b`07RLa0P0K9Bl07P0O:C<082Xd020Z=00K
9Bl07BLa020Z=00N:3805AlY01@N9`0I8RH051hP01DN8P0I8RL06b@Y01XS:@0L9B`06b@/01DN9P0H
8BX04QXS01DM900P9B/07b@Z01<H7P0I7R<07B8W01DJ7`0C61/05AXN01DJ7@804QPH00<05Q`Q01DL
9@0@5b800P0C6R@0200H7bX04QTS01<J900F7BL05ahX01DL9P0D6bD051/S0P0E72803P0E72<05A`T
01DL900I82T03A@N02<Z=01?EV0092Xe01XQ;00P92h0C51I014E7P0N8R/03A4J0P0K7bP2010D7@06
00`?600P92d0=c]301@I7P0B5a/041DI0P0B5AX02@0A51T04Q<H018C600C51T051<I01HE6`0H5ad0
5QPM01DH7@0301@G700I01HI7P0H6b0041<H0454B@1JGF807b8W01TL8P0C5Ql06A`W018D7`0[;CP0
61/T01TL9@0G6R404QDK02LZ;`0P8bP051LL01HI7P0A4QH05AHJ00l@500F5a/07b0T00h?4`02018C
5`0901@E6@0?41@06Q/O00d>4P0D5AL04Q<E014B500C51H051DG00804Q<E02@051DG01<D5P0B4aD0
4a@F01HG6@0>3a404a@F01HG6@0E5QP04a@F018C5@0@4A<05QLI00X;3@0T9BL0UIJH02HW:`0B4aT0
410H00h>5P0B4QX02PXB00l?5`0D51`07AdU014A6@10@4P03@dE018C600B4a@0418A00lA400@4Q40
4A<B018D4`0C5A@201DG5P0W00lA400@4Q404aDD014A4`0C4QH0MWEj02/Z;`0C4aD04Q8C014A3`0A
4P`04A8:00lA1@0?4@<04A8;018B500A4A404A4?010A300A4Pd04Q<=014B3@0@4@`0414?014A4@0B
4Q@04A4A01`L6P0^;R`04a<A014A3`0>3P`05ADC01@D4P0B4Q00410>00l?3@0@40h03a0<00803Pl:
01d0414<018C3P0C50l05QLB01<D3`0>3`X04Q<>01LH4`0@4@`020L501@C4@0A40h030/9010?3@0A
40h05aHD01TH5P17AT@07ahL00P71P0C4Q002`/:014A3`0:2PP03`l=014A3`0?3`d04A4?00h>3002
010@3P0400L71@0S8b40?C`h00`;1`803Pd900h03`h:014@300T8al06aXF00l>2P0@3`/04a8>00h=
2@0F5A<03@`:014@3P0>3@/05A@B03He<`804A0>00D040l=00l>300C4Q006APF010?3@0200l>3006
010?3@0A40h04A0>00h=2`0?3P`03Pd;0P0=30X0400@3`d03Ph?01<C5@092P`030d?00`<3P0@4A<0
1`P:018C5@0E5QP0EUMI01TJ700?3a403`d>00h<3@0=2``200h<3@0D00l=3P0[:BX04a4B00P61`0D
4Q<02@L8010>3`0?3@h03@/<00h<3@0A3a0040h?00l=3P0:20T0518C00`:2`0W9BH040h?01HD5@0>
3@/200/:200M00d<2P0>3@/03@`:010?3@0A40h03`h<010?3@0@3`h0BDQ602HR8P0;1`H040`;014=
300;1`H04@d<00l;2P0@30/04@d<010<2`0?2`X04`l>01TE500C3`h03`/:018>3@091@@040`;014=
300?2`X00P0>2PT0100?2`X04@d;00d91P0A3@X2018>2`0301DA3P0?2`P03PX700803`/800D03@T6
00h:1`0?2`P04@d:00l;200200`81@0F014=2P0@30T03@T600h:1`0G4a006QHC018>2`0<2`H040l:
00d<1`0;2PD04Q4<00/:1P0920@03`h;00L6100E4a<03@`;00/:2@0<2`T02`X800`;2@803Pd;0P0=
30X01P0<2`T02`X800/:200;2PP03@`:00h=2`8030/900<03Pd;00l>300?3P`01P0<2`T01@0A3a00
3`d>00l=3P0@3Pl03`d>00<03@/<01/03P`=00d;300=2``03@/<00`:3@0>30l08R0S01hL7`0C4A@0
;bd`01TG6P0:2@/06aTL06QVJ@0B41<02@L:00d;300G5AH02PT901@B4`0A3a001`D600`:2`0>30d0
3@/<00`:2`0>30d00P0?3@h01P0=2``030X;00d;300>30d03`d>00h<3@8040h?00@02@L800P61`0?
3@h02`T:0P0>30d03`0=2``030X;00h<3@0=2``02PP901LE5P22P84071XK01HD5@0=2@X081`M04U5
AP0@30d04@d>018>3`0201<?40<03`/<0P0>2P/00`0<20T03PX;010<3@0200h:2`<03`/<01<040`=
014=3P0F4Q<061@E01DA4P0>2P/02`L800l;300B3Pl04@d>01@@4@0A3@h05A4B02/W:00W92D02@P8
01HD5@0?3@h02`T:00803@/<01L03P`=00T7200V92D02PP900L51P0=2P/030P9018>3`0;1`P03`/<
00l:3P0>2@d040/?010;4@0=20h03PT?014<4`0<2Pl061HK018@5@0=2a001@<800l=4P0200`:3`80
3P`A00D03@/@00`:3`0610L03`d@01@B5@0200`:3@0400h<3`0<2Pd030X=00h<3`803`d@00T0518E
05UGG00G5AX020L;01DC60071@X04Q0E00d;400>31400`0?3A802@0>3140518E00`:3@0C4A@030X=
00h<3`0A3a803P`?02LU:00200l=400300X82`0<2Pgooooo01?ooooo000Kooooo`0700D3100^;2d0
81hO03Hd=@0E4a@0108300d;300200T7200=00P61`0>30d081hQ01XE700B31L05Q0J01TC7@0E41L0
4`hD018=4@0?2Pd0510?01DA400200l;20<04@P90`0?2@T04`0B3Pl02PP900/92P0?3@h03P`?00X8
2`050`L03@/@014?500@3Q<02`T>00P62`0?3A804@hE010=500?31<03P/B00l<4`0=2Q000P0<2Pl0
4P0=2`h03P`?00l=400K6A`030X=00<1100D4QD09bDX010@5@0C5Qd00`H=00X<4`0E5Q/05A@L01`K
8P0?3Q@040dD018>5@8050lF00@05Q8H010?500@3a@05QDI0P0;2`d0?@0E5AL04a<E01<C5@0C4aD0
4A4C010@4P0?41404aDD01DF600A4Q@04a@F01LH700E5QX04a@H01DF6`0C51T04A8G01<D6@0F5Qd0
410H018B6P0I6B<05QHP010@6P0H62806a/U01@D7P0I6B<09RH`01XJ9@0E5Ad05AHK00l@5@0>3a@0
51DJ014B5`0Z:c00=CHk02HW;00N7b@07b0U01XJ8@0?4Q/05aXS01XL9`0C5B404aHO01@F8@0E5b<0
5QTR01HH8`0C5B404aHO01HH900J7RT0720/018F8P0H72P06QhZ01`P;00E6B@00`0D62<05`0H72H0
6alZ01TO:`0H7RX05Q`X01LM:@0L8Rh082Pc01/S;P0G7bX04adW018O:00C8BX0524Z01DM:P0L8S80
7R@d01`R<P0M8c<03Q@T01DK:`0F72`05ad]008061h^01<061hZ01TP:00F7B@06R4Y01TP:P0X;cT0
8bXd01LN9`0N9B/07bLZ01`T9@0L9B@07BHU01`T:00J8BL072<Y02<Z<00J8BL06b8X00<07RD]01h0
7B@/01/R:P0I8R/0624[01PR;00K9Bl07bTc020Z=00O:C<07BLa020Z=00N:3805R0Z01hX<P0N:340
6R@U01LQ8P0E7b0051hP01TS9@0M9bT03QPJ01`U:P0E7R<06R<X00hG700F7B<05AXP018F7`0D6242
01TM9P0`01HJ8`0F6b405a`R01DJ7@0A5QT041HF00lE6P083aD06R4Y014H7`0:4AT051/S01<J8P0A
62003aHN01<J8`0F7BL051/U01<J8P0G7R@061lU01HM900D6b<05A`T01XQ:@0A62006R4Y030g?`0G
7RH07B@]00D94P0T:3404QHO02<W<00E6B804aLP01DI8P0A5Ah05QXS014E7P0?4a`02P`E00d@5`0B
5A`05QTP01<F7@0A51/04aHM0`0@4aX00`0C4a/051@L01DE7@0201@G700D01<F6`0D5a`05APM01HI
7P09314041<H02T/<@0d=c`051LL00d@5@0@4aX05aXR01HI800Y;3<09RT`01@G7P0C5Qd04QDK01lR
9`0I724201LJ7`0C01LH700H6Ad051DI01XK7`0O82@04a@H014B5P0N7b<04a@H01@E6@0C51P03@hB
01@E5`0C51H04A8D010A4`0C51H05QLI014B500201<D5P06014B500C51H05QLI01PI6`0C51H04A8D
0P0D5AL05@0B4aD05AHH00T:300?41802``>03Df>00A4QH0:b/d00P84P0N7RP06QXT00h>600C4ad0
8R8/0;Bd_P1aLG/0BTYD00l?6@0N7RH0414B010B4@02014C4P0J010B4@0?4A004Q@C01@F5@0B51<0
4A<B018D4`0A4Q@03`hC00d<4P0<2a409bH[01@D5P0>3Pd03Pl:00l@2P0@4PP0418500lA0`0@4PX0
4A<B010B4@0?4@l03Q0=00lA3P0?4@d200lA3P0;010B400A4a804A<B018C4P0410801`L500h>300P
81h04A4?00l?3@0@40h00P0A4@l2010@3P0300l@300?40/03a0;00803a0;05804Q<>010A300;30L0
4A8=01PI500=3PT051D@010@3P0O7ad03`l=00P81P0>3P`0410>00L71@0D51803@d;02DU8`0G5aD0
4Q8@010@3P0=3@/03Ph<01LG5@0<30X04Q8@00T91`0=3@/02@T7018B400>3P`0:b/Y04U8A00D4`l0
5A@@014@300?3PX04Q4=02XY9@0L6aL030/701<B3P0E510030/700/:200>3@/06APF01HE4`071P@0
0`8000h=2`0@3`d03`h<00h=2`0@3`d051<A018A3`0>3@/030/900h=2`0?3P`03@`:00h=2`0?3P`0
3@`:00`;2@0=30X04A0>010@400410@09BDU00410@0B4Q80000000T92@0@41000`<3018B4P0<30`0
3Ph>00l=3P0>30d03@/<0P0>30d09@0?3@h01@<401<A4P0G5AH02`T:00H41@030@8030X;00X82@0;
2@X030X;00/92P091`P04@l@01@B4`0F51D030X;01/I6P050`@030/900h=2`0A40h04a8@00l>300<
2`T03@`:00H50`071P@04A0>01XI5`0A40h04@d<02/W9P0K5aH04`l>00h:2@0@30/00P0?2`X02@0>
2PT03`/:00l;2P0D40l00`0004E1@00Q7A`04Ph=00`81`0200l;2P0/00h:2@0?2`X03`/:010<2`0>
2PP01P80018>2`0A3@X02PH3010<2@0:1P<03`/8014=2P0?2`P03@T600h:1`0?2`P06QHC00X60`0M
6AH09B4N00P40@0D40d040`900l;200E4@h05a<@018>2P0@40P02`/300H600071`002PX201<B3@07
1P404a8=014@300@3`/010<000`;200:2@L05A@B00l>3005108200d<2P0400X91`0;2PP030/900`;
2@802`X80P0=30X0100>3@/04A0>014@3P0>3@/600`;2@0A00h<3@0=2``03@/<00h<3@0?3@h03@/<
010>3`0>30d030X;00/92P0<2P/03@/<00T72P0C4A@0JfU/06UWJP0<2Pd00P010080300K6A`0518E
00400P0E4aH03P`?00`:2`0i=cP081hO01DC50050`@04a4B00T720<02`T:00@03P`=018@4@0=2``0
3@/<0P0>30d02`0=2``030X;00d;300;2@X03P`=00/92P081PL02`T:00X82@0=2``03P`=00803@/<
01X03P`=00T7200>30d00@0002/Y:P0100009bDV00d:2P0>2P/0=30a014=3P070`@00`0000d92P0>
2P/02`L800d92P0>2P/04@d>01<?400@30d04`l@01DA4P0B3Pl040`=014=3P8040`=01d03PX;00`8
2@0X92D09R8S010<3@0G4a@04Ph?00H20`0=2PX05a<D01<?40060`<00`0001`H6@0P7Ah00@0004I4
A@0B41404@l@018@4@0;2@X04a4B00800@071@H02PP901<A4P0A3Pl02PH700l;300200/720<03`X>
00`03`X@00h93`0=20h04@`C010>4`0=2a005A<H01`J7`0@3Q<04a4F00/93P0<2Pl200d;408030X?
00@040hA01PF6@0I5aX03`d@0P0=2`h0300?3A0030X=00l=400?3A002`T<010>4@0100@03P`A01@B
5`0H5Q/02`T>00@21`8030X?0P0=2a003P0>31403`dB00T72P0@3Q40:RP[028P8`0A3a8020H900l=
400U8bH04@lB00`:3@091`X06QPK5?ooool001_ooooo01T04a4B02HT9@040P<030X;00X82@0<2P/0
3@/<00/92P0?3@h02`T:00X82@0I5aX06aDO01D?6`0R72P09AlY01@?5P0>2@l040/?010<300I5A80
6ADA00l<1`0;20<04`/:00804`X;0`0A2`/04`0E4A802`T:00/92P0@3Q403`d@00`:3@0@3Q<03`dB
00`:3`091``03P`A01<A5P0@3Q<0514H018?5P0=2Q4030T@00h<4@0@3Q<00P0?3A804P0@3Q404@lB
018@4`0M6ah06aTL01HD5`0>30l05Q@G00d=4`000``09BPa01hO:@071`l08R4Y010?5`0?3QH040dD
018>5@8050lF00T04a4F014@5@0N7B80=SHi01hN80092@/03@d?010@4P0A4A<00`0C4aD0=P0E5QP0
3a4@00d>400E5QP04A8D00h?4`0B4aL051DI01LH7@0E5Q/04Q<H01<D6@0D51/04a<K01LG7`0F5R00
4A4K01<C7@0I6B<07alY01@D7P0I6B<0;2`f01/K900?41D061TN01XK800B4aP05AHK01TJ7`0C51T0
8B8W01PI7P0E5Q/061TN01<D6P0A51d06Q`X01`N:P0F62@05ALS01HH900G6BD06A/W01PJ9P0D5R80
4aDQ01TK:00D62@03a<O01XM:`0b=T802`lK014E8@804ADP01@051PS01PL9`0K7bT06AdV01<I9@0G
7BT05Q`X01@J9P0Q:3<0<c]6020X<`0G82X04A/U018O:00F8b`0628/01@K:`0G7Bd06Al_01HL;080
6Al_00<05Q`/01LM;@0H7Rh00P0I7bl05@0I7bd05ahV01HM900H7bL04APR01HM9`0<4ad05A`V01hU
;@0N9B/06B4T01XS8P0M9BL06b<W01dT:P1MI6X0:2le01DL8P0O9R`082L_01`S:`0201XQ:@0701/R
:P0J8bX05b0Z01PR;00K9Bl07bTc01hX<P0201`V<00601/U;`0M9c406R@^01XT;P0=5b0051hP0P0K
9BH0@@0E7b404Q`N01<M7`0H8R@06B<U01DO8@0R;2h03QPJ01HL8@0?51X04ADN02L[=00O8bh04aLR
01@H8`0H72D05a/T01<H7@0@5AP04ALG01PO8P0:4AL05ahT00`C6@0=51X061lW01DL900A62002a8J
00lF7`0G7RP05A`V01@K900H7bD06B0V01DL8`0A62004QTQ010G7`0D6b<05QdU020W;`0D6b<04QTQ
01DI8P0H72D051PQ014E7P0?4a`05a/T018F7`0I7BH0310I014E7P0H72D05ATR010C6P0F6B006ahU
01<F7@0=41L03a8I01<F7@0B5A`04A@K008041<J00<04Q@K014D6@0A51T00P0A51T08@0B5AX051LL
01dP9@0I72405aXO01dP9@0=41D051LL01HI800@4aX04A@K00d@5`0R9B`02PdD00d@5`0@4aT041<H
00X=4P0G6Ql04aHK01XK7`0D5AT04a@H018C5`0?41@04A8F01@E6@0Z:bl05aPL01PI7@0?41@0414E
00d>400201HG6@0H010A4`0=3Q003a0B014B500C51H04Q<E014B500B4aD05AHH02HW:@0E5QP02``>
018C5@0@4A<02``>01@E5`0E5QP0414C014B50082@/051DI03<c?00B4Q`06QXT0P0;2aD02@0=3AL0
61PR09jNZ00n?TP06ATS00h>600C4a/03a0A014C4P02018D4`0300lA400>40l03a4@00804A<B0P0C
5A@02P0A4Q@03`hD018A5`0B4AH0410C01dM7@0?40`03@h800h?2@0@4@P2010B1@09010B2P0@4Q40
3Q0?00d?3P0=3``03@l>00h@3P0>40d0418A00<04A<B01404A8A010@3P0L71X04Q8@00`<2P092@L0
51@B00h>300?3`d04A4?010@3P0?3`d0410=014B3@0@4@`03Pl:00d>2@0200l@2`0?01@E400@4@`0
5AHA01<D3`0=3PT01PH4018B400=3@`03`l=00h>300:2PP05ADC00H6100=3@/02@T700804A4?00X0
2@T701<C4@0>3P`04Q8@01@D4P0@40h02@T701LG5@0=3@/0410>0P092@L04@0D4`l03Pd9010?2`0>
3@T061LC00d<20071P803@`801DD400@3`/03@`800l>2P0B4@l03Pd;00L6100<2`T05A@B008030/9
00<03`h<010?3@0>3@/00P0=30X06`0B4@l03@`:00X91`0<2`T03Pd;00/:200>3@/03`h<00d<2P0<
2`T03@`:014@3P0?3`l03@d=0000000H61P0410@01LG5`061PH03Ph>01@D500;2`/03@d=00/;2`0?
3@h03P`=00d;300200h<3@0600l=3P0>30d03`d>00`:2`091`P07A/L0P0@3Pl200h<3@0900l=3P0=
2``02`T:00h<3@0;2@X01`D600d;30091`P02PP900803Pd;00l030/900X91`0;2PP03@`:00`;2@0;
2PP071/I00T81`0A40h01`H400l;2P0U8B003`/:01LC4P0E4A000P0@30/03@0>2PT03@T800h:2@0@
30/03@T801/G5P2=RHP0920O00`81`0B3Pd02`L600d9200?2`X00P0A3@`0300?2`X040`:010<2@0P
71T06QHC00h:1`0F4Pl03PX7014=2P0B3P/040`900h:1`8040`900L05A4>00<0000n>SL0GUYG01@@
3@0B3P/04@d:00803`/801803PX700d91@0F5Ph03`l5010@200D50`03@d500`;1P0920<04a8=00X9
1@0920@02PT5014@300E51809B@R01/J600:2@L201DD4P0600T81P0:2@L03@`:00d<2P0<2`T02PT7
0P0=30X0100@3`d04a8@018A3`0>3@/600`;2@0C00`:2`0;2@X030X;00h<3@0?3@h03@/<00h<3@0<
2P/02PP900/92P0?3@h04@l@00h<3`0;2@`0N7Ii085oPP0J61/02`T<01HD5`0200H41`0:01@B5@0A
3a801@<601HD5@0S8B80108301@B4`0A3a003@/<00X82@<03@/<00@04Q0A01HD5@0<2P/03P`=0P0?
3@h02`0<2P/02`T:00X82@081PL030X;00d;300:20T02`T:00d;300@3Pl04@l@008040h?03/04@l@
00/:2P0G5AH061HG00L51P0C4A801`D601@@4@0U8B8040`=00L4100H51D04`l@00/7200=2@X030P9
00l;300B3Pl04`l@010<3@0=2@X040`=01<?400@30d03@T:010<3@0B3Pl04`l@018>3`0A3@h06aLH
00h:2`0400403`/<00H20`0810D04`l@00X61`0810D040`=01<?400B3Pl04a0A01dK702>S8d0<2h_
00l=3P0>30d02`T:01LE5P0:20T040h?00/92P0=2``040d>00X61`0?2``03@T:00`82@02014<400=
010;3`0@2a403@P>00X52`0=20l02@L<010>4`0J61d030X?01dK80040PL02`T>00`:3`0200d;4080
30X?01802@L:00h<3`0?3A003@/>00l=400=2`h04@lB00d;3P0?3A003@/>00P62@0<2Pd020H;00d;
400G5AX0<S0e01DC600A3a@400/93P0>00d;400>31404Q0C00X82`0F51L03@/>00X82`0B41<04a4D
00T72P0610L02`T<00h<3`0H5QTDooooo`006oooool200/92P0500X82@0;2@X03P`=010>3`0B4140
0P0<2P/200d;300O01DC5`27PH/0:28_01LA700;1Pl03PX@00h93P0A3@l04@d<010<2@0@3@T040d7
00l<1P0K4a405@`=01P?400B30`0208401<=3`0?2Ph081hQ00h<400>31404a4F01LE6`0?31<03P/B
01TF7@0G51/03P`A014?500200h<4@<03`dB0P0?3A4200l=40803@/>02P03`d@01LE600@3Q404a4D
018@5@0@3Q<04A0I010@7@0F5R806ATU00h>6@0=2aH03`dG018A600C41L04PlF01DB600B41D04A0D
01@D5P071`T0CTi@00l?4@0H61X0410B01<C5@0G5aT04A4D01@C60051@T051@G018C5@0H6A/07QlR
018C5`0?41@09BHZ01lP9@0@4AH051@K0P0C4a/01P0H62404Q8L01@D7P0C4a/07AdU01lO9`805QHN
0P0G5al04P0F5ad05QHN01DF6`0L7B8061TN01<D6@0K7240;2db01LH7@0J6b005QLL01<D6@0G61d0
5QLM01`N:P0@4Ql07Al/00h@7@806A/X00<061XW01LI9P0F62D00P0H6RL01P0D5R<061/[01<F9P0N
8C808bHf01DH9P8061`X00T05a/V01XN:@0G6b@051PQ01hR:`0M8bl05Q`X01XP;00K8bh00P0F7RT0
9P0E7bT06R<^01DN:00C72L06B8/01PO:`0M8c806Al_01/Q<@0E6b/06Al_01HL;00G7Bd06R0`01dS
<`0Y;cl07B<c01@J:00N9Bd06B0W01/R:`0E6bH0728^01lU<@0K8Rd06R4Y01TP9P0I8B@072@U01hV
:00N9B`072<[01dT;00P9bl072<[01PO9`0N9B/05ahT0P0K8RP0200H7bD051dT01LQ:P0G8B/082Xd
01/U;`0I8bd05R0Z0P0I8bd03@0J92h06bD_01TS;@0H8R/07BDY01/S9P0E7B005alR01PP8P0B6Q`0
51`N01<K7@0E7Al00P0H82805@0F72007R<Y024U;P0g>dH0;C0n01HJ9`0J7R/05a/W01PL9P0H7B<0
5a`O01HL7@0D6Qd04QXM01HN8@0E72404APN01PO9@0E72<04aXS01@K9@0201@J9P0/01<I9P0E6RD0
5a/T01TM9P0J7bH061dS01LL8P0E6R007R<Y01DJ800G72804QLL01LL8P0D62405a/T01PL9@0k?dP0
7b</01@H8@0L82T020`E01PL9@0=4AX051PQ010D7@0D5b003Q4J01<F7`0>4AX04QDN01DH8@0H72D0
2@/D01<G800<41T05ATR00lB6`0D5ad05APM01LJ7`0F6Ah051LL014D6@0F6Ah201TL8@05014D6@0?
4QL04aHK01@G700B5AX00`0@4aP01`0>4AH02PdB014D6@082a006A`S00hA600A51T00P0E5QX0200D
5AT04a@H018C5`0@4AD061TM01HG6`0C51P04Q<G0P0C51P2014B500U00T:300G61X0414C02TZ;00H
6A/04Q<E014B500@4A<04Q<E01hO8@1LGEl03a0B01XK7@0A4Q@05AHH014B500C51H04Q<E01DF600A
4Q@05aPJ01@E6@0H6Al0410H010@5`0D51`04a<K010@5`0B4QT05ADM01@D6`0@41L03PhF00l@5@0A
4Q<0418A00h@3`02010B4@0W01<E500Q8b8092HU01LI600B51<051HE010A4`0A41D03PdB010?4`0D
4aH04Q8A01<D3`0>3`T04a@>00/<1@0F60h01`P202h_:P0f>3L02`d<014C4`0?4A4061TK00d>400E
5aL02@X<01<D500:30/04Q@C01`M6`0820L03Ph<00l?3@0E5A<04A4?01PH5P0E5A<03@d;00<03`l=
00@0414=00h?2P0>3`X03a0;0P0>3`X00`0?40/04A8=014B3@03014B3@0C00/;2@0I6AL030`:014A
3`0820H03`l=010@3P0:2PT04A4@01<C4@0D51804A4?01`L6P0D51803Ph<01@D4P0G5aD04A4?01<C
4@02018B400;010@3P0?3`d03`l=00X91P0K6QH03@`8014@300R8Ad0:bXV00h=2@0?3PX00P0@3`/0
3`0?3PX03Pd9014@3P0>3@/05aHD00l>300I61H02PT700d<2P0?3P`02PT7014@3P0?3P`03Pd;018A
3`0200h=2`0500d<2P0<2`T03@`:00`;2@0=30X00P0>3@/0700=30X030/900l?3`0?3`l0410@01@D
500?3`l04a<C00`<300?3`l03@d=00/;2`0=3@d04A4A014?400C4A8020H700d;300D4Q<03`d>00/9
2P0=2``030X;00h<3@0B41404a4B018@4@0;2@X200h<3@09028P8@0h=SL04@l@00d;300<2P/02`T:
00`:2`0=2``03Pd;00803@`:0`0>3@/200l>308030/90P0=30X08`0A3@`030P7010<2`0C3`h040`;
00h:2@0?2`X04Ph=00d92@0E4A008alN01TE500>2PT040`;00h:2@0<20L03PX9014=300@30/03`/:
00h:2@0?2`X040`;00l;2@0E4@h09R8O01`H5@0;1`@040`901/G501>BTL03`/801HB3`0810805Q8?
00803PX700@03`/8018>2`0D40d04Ph;0P0=2@H300h:1`0D00d:1P0=3@D04A4800l?1`0<30@03`l7
00`;1P0=30L04Q4<00d<200A40`02PT500l>2`0X9bD0W9^I02DT8P0:2@L02`X8014@3P0?3P`2010?
3@0600h=2`0=30X030/900d<2P0<2`T03Pd;0P0B4@l0200=30X01`H501/J600:2@L04Q4?00h=2`0?
3P`03@/<100>30d200l=3P0N00d;300@3Pl01`D600l=3P0;2@X03Pd?00d;3P0d<SD0:BLZ010>4@0C
4A@03P`?00`:3@0A3a80108500h<3`0@3Q403`d>00X82@0;2@X030X;00/92P0>30d02`T:010>3`0?
3@h03P`=02@R8`0j>3T03@/<0P0>30d01@0N71d040h?00X92@0>30d040h?00804@l@00<03`d>00h<
3@0D4Q<00P0;2@X200d;3004010>3`0<2P/04@l@010>3`<03@/<02/04`l@018>3`0>2P/030P9018>
3`0A3@h030P9010<3@0B3Pl03PX;00H20`0@30d030P900d92P0?2``040`=014=3P0@30d03PX;010<
3@0A3@h040`=00l;300C3a003@T:00l;300B3Pl04`l@01DA4P0=2@X040`=018>3`0A3@h040`=014=
3P0@3@h0@T110:n][P10?Sl03P`=00P61`0@3Pl030X;00802PP900D02`T:00d;300?30d03`/<018>
3`0200l;300=018=4@0?2Ph020@7014<4P0C3Q@04@dB018=50091``040hC08^9SP1kNGh09B<X01DC
600200h<4@0700d;400>31403P`A010>4`0F51L06QPK00l=400200h<3`0E01@B5@0E4aH040hA01<A
500H5QT0518E014?4P0B41D03P`A03@b=`0[:Bh04@lD00`:3`0E4aP02`T>010>4`0=2a0030X?014?
500@3Q404@lB00802`T<00@03`d@00`:3@081PT03P`?0P0<2Pd00`0@3Q402`T<ooooo`0Cooooo`00
6oooool0200=2`h02`T<00T72P0:20/03P`?010>4@0>30l02`T<0P0=2`h0300<2Pd040hC02DO:@0?
2AD07QPR01<=5`0@2a802PD901@@4@0C3`d04@d:010=20803P/400`050`:00h6100O5aD03@L700/5
1`0A2`d01`8602d[<00@3A@08b0W0<W6c@1VHf`2014>5`0<01XG800G51/03P/B00l<4`0;2@h03`d@
014?4P0B41<04@lB010>4@0?3@l03`d>0P0@3Pl00`0=2`h02PP;00d;3P0200h<4@0^01@B5`0F4aX0
5aDP018@7P0;2AL040hK018@7@0@3QT04@lI00/:400A41H03`hC01<C5@0N7R003`lA01TI6@0;2`/0
1`L700d=3@0K6ad05QHH00000P061@X05aHK01PG700?3Q@04a<G018C5`0N7b<08b@X018C5`0@4AH0
71dR01@E6P0?3aL04a<K00h>5P0;2aD0410J00l?6@0A4A/020P@00h>5P0C4a/051DJ01DF6`805QLL
07L05aPL01PI7P0@4AH04Q<H014B5`0:2a002@X?01`M8P0J6b006a`Q01PI7P0E5Q/05aPM01HG7@0H
6b@051HR00h@700/;SX03@lK01/M:@0D5R805QPT01PJ9P0G6BD05QPT01LI9@0D5bP05AP[01@G:@0A
52D04QDT01<F9@0A5B4061`X01HJ9@0D62406AdV01`P:@0M8Bd05Q/W01LM:@0H82/05alZ01XR;@0=
5B0061l[01/O:`0H72P07Qh/01lQ;P0F6BP07bDc01dS<@0@5R@06Al]01PN;00E6bT05ad[02<Y=`0M
8c406Al]01dS;`0M92h05A`U028Y<`0P9S8051XW020V<P0R:C@06b8Z01LN900I8BD082PZ02@/;`0K
8R/06b8/01`S;@0M92`06R4Y01LN9P0M92X051/Q024X;P0L92L07RHY01@M8P0P:C<06R@^00lI8`0A
6bD072H`01hX<P0J92h07BLa01`V<00H8R`05b4[01TS;00J8BP061lU01DL8P0J8BH072@W01TQ900G
7b804a/M01@L7P0H82806B8Q01TO8P0E6R007R8[028V<`0F6BX06A`]01PK;00E62T05a/W01TM9P02
01TN8@0701HM7P0G7b8051`O02<[;`0[<SP09Rde01lV;`0201TO:`0:01PN;00I7bd06Al_01/P;00I
72D05QTR01LJ8P0I72<05aXQ01<F70804QDJ01d05QTN01DI700R9BX082D[01PL9@0A5Ah06AdV00lC
701;CeP0ADUB018F7`0;3aP05ATR01HJ8`0<41T0418N00lA7@0B52003@lK01dO:`0[;cX01`/F01@H
8`0<4ad02a8L024X<P0N9Bh041DK018E6P0201@G700501<F6`0A51T04A@I01@G700E61d00P0A51T0
100F6Ah04aLJ01<G6@0A5AP2010D5`0800lC5P0A51T05aXO01@G700I72<03Q4H01@G700C51T201<D
6005018C5`0A4QH03a0D01@E6@0C51P0100@4AD0D00>3a40414C014B500@4A<06Q/M02TZ;00K71h0
414C00l@4P0B4aD04A8D010A4`051PP04a@F00h?4@0<3@l061TK00l@4P0B4aD0414C00h?4@0<3@l0
2P/=00P92`0H6Ad03a0E00h?4`0B4aP04a@I018C5`0F5a`05aPM01DF6P0@4AD03@hC00d>4P0>4100
6adL02PZ:@0C5A@07R0O00D71P0F61L06A/J010B4@0<3Pd03Q0?00/<3P0C4QL03PdB00d=3`0@40l0
4a@?018C3@0?40X051D?00/<1P0I6QD04A8=018D400D6AD00`L600hB4P072`h02PhA01DI7@0=4A@0
3Q8E00P;2`0;3`h082DQ0:NXYP0h>3H04Q8@00`<2`092@L07QhL01@D4P0B4Q003Ph<0P0C4a400`0B
4Q004A4>00h?2P0300l@2`L03Pl:018020X700D7100:30T02P`9018D4@0A4a001`T602X/:@0B5140
00400002000;3@X04A4?00l?3@0=3@/04A4?01<C4@0D518300h>30<03@d;00@05QDA00T8100C4Ph0
0@000P0h=c<03@0>3@T03`h:010?2`0@3`/03`h:00h=2@071P@04Q4?01XI5`0<2`T0BTU701LF500=
30X00P0;2PP02P0@3`d04A0>00h=2`0?3P`040l=01lN700K6QP02PT700l>300=30X400h=2`0;00d<
2P0>3@/02PT700P71@0A40h040l>0040000>3@/040l=00l>300=30X00P0;2PP04P0<2P/00@0001/I
6P0;2@X0518C01DC500J61T07A/L00`:2`0:20T03@/<00800@0:20T02`T:018@4@0>30d030X;01<A
4P803P`=100=2``300l>300500d<2P0;2PP02PT7018A3`0D4a400P0;2PP00`0C4Q004A0>00h:2@04
00h:2@0<00`81`0300003@T801@@3`0M6AP0:bLV01HB4@0A3@`040`;018>3@0C3`h04Ph=0`0?2`X0
1P0@30/03`/:00l;2P0?2`T02`L400l;20803PX700@0510=00`81@0J5Q<02`L40P0A3@X00`0@30T0
3PX7018>2`0200d91P04014=2P0D40d03PX700l;208040`90P0?2`P03P071P403@`7010?2P0<2`H0
3@`700h=2@0?3PX04a8>00d<2P01000030/903/j>0081`D010<10P0=30X00`0?3P`02PT700`;2@04
00d<2P8030/900<02`X800`;2@0@3`d00P0A40h00`0L6aT0BTU701DD4P0200l>300I00X91`0H5QL0
1083014?400H5QL02PP900/92P0<2P/03@/<00/92P0<2P/03`d>02/Y:P0N71l03`d@00D31P0?3A00
3P`?00H41`0100807A/N0:>QY01hMWT04a4D00P62@0200h<3@05010>3`0>30d03@/<01HD5@0A3a00
0P0C4A802`0>30d06aTJ02TW:00C4A800@0000P61`2DTY<0L6i_01`J6`0C4A803P`=008030X;01X0
3P`=010>3`0?3@h03@/<00l=3P0=2``030X;014?400<2P/04@l@00d;30071@H02`T:014?400:1`L0
5Q8C01<?400B3Pl00`00018>3`0C3a005Q8C00T51P0C3a002PH700l;30<03PX;0P0?2``02`0>2P/0
4Ph?01DA4P0>2P/02@D600d92P0^:R/09b<T01LC500F4Q<02PH700803@T:00h030P900h:2`0>2P/0
3@T:010<3@0B3a001P@501LE5P0;2@X03`d>00X82@0<2P/03`d>00h<3@8030X;00@03@/<00h;300?
2``040`=0P0?2``01`0A31003@P<00h93@0O6R000`0400L2200C3QD00P0?3A801P0d<SL09B<X0040
100:20d03P`A00d;40<030X?02403@/@00l=400C4A@02PP;00h<3`0A3a806QPK01LE600>30l02`T<
01<A500B41<03P`?00D3200=2a00<2hc00D3200D4QL04a4F00D3200@3Q<03`dB010>4`071@X02`T>
01<A500D4QD03P`?00`:3@0>30l02`T<00`:3@0?3A000P0<2Pd00`0@3Q403P`?ooooo`0Cooooo`00
6oooool01P0?3A003@/>00/9300<2Pd03`d@014?4P802`T<0P0=2`h0300<2Pd03@/@00H120060PX0
40/B00T42`0B3A804Ph?010<2`0?2`T03PX700h;1P803@X500@030@301081P0]9B<050h>0P0>20X0
3P0;1`/07a`S00L42`0N72<0cL[C04e:D`0C41T02`PA00d:4`0=2Q4030T@010=500<2Pl04@lB0P0C
4A@0700@3Q403P`=010>3`0?3@h03P`=018@4@0A3a803@/>00h<3`0C4AH03`dB01PF6`0L6B007A/V
01/I9`0B41h04Q0M01@B7@0B41/04Q4H00H52P0A41D0410B01TI6`0[:bd05ADE010@400I6AT201PH
600I014A4`1DE5H0@d=501/J7`0>3A803@`A00h=4`0D51T0414E01<D600D5AT03@hB014B5`0C51T0
2``A010@600J6R805QHN01<C7@0?3aT071`V034a>`0G5al0410H01`L900201@E6P0:01DF6P0F5a/0
5aPL01TJ7P0E5Q/06AXO03`m@P0`<CH020T>034b=`806a`Q04406AXO01LH7@0G61d05QHM01<F7`0G
6BD0:bdi0<;4d01NH6`02P`H014C7`0E5b<061XV01HH900D5R8061XV01LJ;@0J73405QT]01LJ;@0K
7Rl041<R01<G8`0N8Rd061`W01HJ8`0N8R/0720Y020T;`0K82`061hZ01PP:`0I8B`06b<^01PP:`0K
82`071/Y01`J:00Q7B`09B<a01@H900M8c006b4]018H9P0O9C806b4]018H9P0?5B8082Hb01HL:P0K
8Bh08BLc01TP:P0I82T07B@^020V<P0H7R/08BLe02L]>@0M92h06B0X01/R9`0O9bT08BT/01`S;002
01XQ:`<06R4Y00T06R4W00dD6P0K8RP07BDX02D]<00F7b@05AlX01hX<P0A6bD00P0G8B/0100C7BL0
6R@^020Z=00M9c4201HP:P0O01/T;@0H7bH05A`T01@K8@0G7R@06B0V01PP8`0D71l04ATL01<K7@0F
7R005QlN01DL7`0B5Ql05QXU01LK:@0A52L05AP[01PK;P0F6BX05aXY01TM9P0I7R8061dP01/R9@0?
5aX04ATL06=[K`2l`l/09Rde01hT;`0201/Q;`0Y01XP<00K8C406b0c01hR;`0I72D04aHO01DH800H
6b805QTP01<F700>4AH051LL01XN8@0L82<0;S4e01HK8@0I7BH06QhW018F7`0=4AX0@dM@0455CP0C
5b0020`E01dQ:P0S9c003A4J00T;5`0?4Ad05aTU00T;5`0C5B408BD`00lC7P0Q:3805ahX01hU;`0`
>D80=Ce600lD6P0A51T00`0C5Q/2018E6P0901<F6`0E61d04QDJ01<F6`0G6Qh04QHG01@H6@0C5aP0
4ADH008041@G00L04A@I018E6P0A51T0004801@G7P062@h051DJ00<051DI00@04a@H014B5P0B4aL0
4Q<G0P0@4AD200l@500900X;3@0>3a405QLI01<D5P0E5QP030d?01PI6`0C51H04A8D00804Q<E00L0
414C02<T9P0@4A<020T;01DF600@4A<04Q<E00804a@F0180414C01@E5`0A4Q@04A8D01/L7P0B4aL0
3a0B00l@4`0?41@03PlA01DF6@0E5QX04a@F010A500>3a<03@h@01<E500<3Pd200X<2`0R01<E5008
2PT02`d<010B4@0<3Pd03Q0?018D4`0A4a803`lA00d=3`0<30`03Ph;00h?2@0:2`D03a0:01PI4`0<
30T07AdK01TI6@072@L0314=018F5@0D61T02`lB00d@5@0520d01`X?00hB5@0@51D04ADD01<H5025
Qh@08b<Q00L71@804a<A00d05aLE00P81P0:2PP02@T700h>300B4Q00410>00l?300>3`X03a0;010A
300?40/03Pl:00H03a0;00`06A/H018D4@0F61D030h;01XL6@0A4a006A/H0001000L7Q/08B<P018D
4@0>40d2014A3`04010@3P0=3@/03@d;00l?3@D03@d;00T03Ph<00h=2@0I61@030/700X91@0>3@T0
5QDA00h=2@0?3PX00P0@3`/04P0?3PX03Pd901@C4@0?3P`051<A00L6100P7ad01PD300`;2@081`D0
51<A00`;2@061@<051<A00L6100C4Q00<C0^02`[:@8030/900h03@`:00h=2`0?3P`03`h<00h=2`0=
30X030/901TH5P01000040l=03He<`0A40h03@`:00l>30804Q4?01H04A0>010?3@0A3a008AlP0080
0@0=2``05Q@E0040000200402`T:01HD5@0=2``02PP901PF5`0=2``030X;014?400>30d020H700T7
200=2``03P`=0P0?3@h0100>30d03@/<00X91`0<2`T200d<2P8030/902P01PD4010?3@0=30X040l=
00X91`0100003PX9010<2`0?2`X03@T800h:2@0e<C00510?00@0000D40l03`/:01`H5`0D40l04`l>
010<2`0B3Pd04`l>010<2`0=2@P03PX9010<2`0A3@`040`;00h:2@0A3@/02`L400d91P0<20D040`9
01LC400D40d040`901<?300;1`@04`l<0P0@30T01`0B3P/03PX700d91P0@30T04Ph;00l;200@30T0
0P0A3@X2010<2@803Pd80P0;2PD0400?3PX051<?008100081`D040l=00D3100G5AH0;B//01HE4`03
0P0040l=00l>300E51803@`:00X91`0;2PP300d<2P0300`;2@0A40h03`h<00<03@`:0P0>3@/04P0N
7A/030/900`;2@0;2PT06aXH02`Z:`0<2P/02`T:01DC500?3@h02PP900D3100A3a0030X;00d;300F
51D0EUAE05ABE@803P`?00`0:BLZ00X82`0<2Pd03@/>01PF6@2OWJ00NgUl00l=400B41<03P`=010>
3`0B414200l=3P0Q01XH6@0@3Pl02@L800d;300@3Pl02@L800L51P0;2@X06aTJ010>3`0Q7b004a4B
00`:2`0A3a003@/<00/92P0<2P/03`d>014?400<2P/03`d>018@4@0=2``030X;018@4@0;2@X05A<D
00T7200Q7b009R@U00P61`0A3@h04Ph?00804@d>00L03@T:01@@4@0E4A80510A00D10P0C3a003PX;
00<040`=01T03`/<00h:2`0>2P/030P9010<3@0C3a003PX;00/7200=2@X061@E00d92P0;1`P04`l@
00h:2`0B3Pl0510A00l;300;1`P03@T:00l;300B3Pl0514B014?40091`P040h?00802`T:00<03@/<
010>3`0@3Pl00`0=2``00`0=2P/03`/<010<3@0200l;300=010;3`0300808QdQ04Y5B`0H4aT03@P>
010;4P050`P03`dB01/I7P0I5a`03@/@00l=4P0200d;400A00`:3`0;2@h02`T>00`:3`0610L03`d@
00h<3`0B41<03P`?00d;3P0C4A@04Q0C010>4@081PT01P@701DC5P0A3a@00P0<2Pl04@0Q7b@05aDJ
01DC600A3a@04a4F00L52P0>31407A/P03`j?`0@3Q404Q0C00d;3P0<2Pd03`d@00/9300A3a8040hA
00803@/>00<040hA014?4_ooool04oooool001_ooooo0`0;2@`300`:3@0@00T72P0=2`h030X=00d;
3P0>30l030X=010<4@0A31803PT>00/72`0>2@d030P900d9200>2PP03PX7010<2@804@h900/05`l<
01D=2`0Z8R004`d=00d72P0?2@d04@`B00`9400C41P040dH01HD7P02018?6P0300h;500@3AH040dF
00803P/B04P040hC018@4`0C4A@04@l@00d;300;2@X040l>014@3P0=30X04@l@01LE600D4QD04@lD
01<A5P0@3Q<05Q<J01TF7@0F4Qh06ADT01PD8P0B3a/040lH014?6@0B4AP02PT=018B5@0?41005ALE
02<U8`0D5A<03@d;018B400:2PT04Q8B00h>400Q8B@01PH:00X93P0F5AX05aHL00h=4`0E5AX04Q<G
010A5@0C51T05QLL01DF6`0F5ad051@L014A6@0A4AX04Q8L01HF800E5Al06QXT02`/=P0M7BD06QXR
01dM900E5Q/05AHJ01@E6@0E5QT05aPJ01XK7@0C51T03PlD018C600A4QL06a`Q071aMP0J6b0301TJ
7`2701LH7@0G5ad06QdU018E7P0A4a`0;c8k02LZ<`0K7RL04aHO01DH8@0H6b@05QTR01DH8@0G6RD0
6A`_01/M<`0L7c@09bXn02LZ>`0<3ah051PU01hR;@0I7BP05QXS01XN9P0H72D07B@^01dS;`0G7BT0
4a/V01DM:00F7BP07B8^01hN;00T7Rh09ah_02HJ;00S6R/09RLc01PO:P0F7BL051/V01dS;P0B6B<0
6b8]01XQ:`0L8bd051/V01dT;P0J8B/06b8Z02Xa>P0E72L0728_01/Q;`0I7bd0728^01PO:@0I82P0
7RD[01hV:@0M9BP07bD`01dT;P0K8R`06R4[01`S:`0N9Bd07RD[01hV:@0A6A`06b<V028Z;00C7Al0
6B8/01`V<0094ad07RPb01`V<00Q:cD06B<]01dW<@0K9Bl05R0Z01DO:@0I8B`0724[01XN:@0L82X0
6alX01LK8`0G72805AXP01LL800K82<06QlR01LL7`0D6Ad05a/T01<G8P0I72/06Qda01DG;@0J7380
6Qd`01XM;P0J7RP061dQ01LL7`0R:2/0:S4g024X;P0Y<3L0ADaE00dB7@0J82d06Al^01XO<@0K83@0
6Qlb01TN<P0J7Rd05aXS018E7P0C5Qh05QTP01DH7`0D5ad04QHJ01@H6`0F6Qd05ATJ028V:00I7R@0
5a/T00804ADN00/05a/T018F7`0=4AX03a<L018F7`0A5Ah05ATR00dA6P0E5R<040lM01DG9002010B
7`04010C7`0D6RH05Q`X010H8`803aLR00@04a`U014F700B5AX04aHK0`0B5AX00`0F6Ah05APM01DH
7@0201<F6`0>01@H700B5QL05QXI01HJ6@0C5aP041@F018F6@0?4QL05QTN01<F6`0^<CP03a8I01@G
700B4aP301<D6003018C5`0@4AD04Q<G00<04a@H00l04Q<G014B5P0B4aD04a@F00T:300G61X030d?
01LH6P0?41805AHH01@E5`0B4aD05AHH01PI6`0;30h00P0B4aD02`0C51H03PlA018C5@0D5AL04Q<E
00P92`0C51H030d?014B500F61P04Q@D0080418A02h04A8C014C4P0C5A@0418B00lA400@4Q80414B
00lA400@4Q406Q`K014C4P0g>CP030h=018D4`0A4a804Q@C010B4@0?4A003@l>00`>3@0>3P`04Q8?
01@E3`0A4P`03@h7010A2P082@@02@X601<C500>3Q8071/P01@F5`0:3P/05ATH00`?4@0;3A404A@J
00d@5`0C5Q`02PdA00/?400?4a80314=01LJ5`0=3@`04A4?0P0?3`d02@0:2PP05ADC014A3`0@40h0
4Q8@01@D4P0@40h03@d:00l@2`03010A300300l@2`0@4@`0414<00@0414<018010H301hP7@0:30T0
0@<101HH5@0?4@h01@L402HX9@1:C4T04A<@018D4@0;3@X04A4?018B400A4@l03@d;00`<2P0=3@/3
00l?3@80410>00T03`l=00T8100H5a<03`h:01/J5P0?3PX04Q4>00h=2@0?3PX00P0@3`/02P0?3PX0
3Pd900X9200E518020L5014@3P0<2`X05QDC00`;2@0@3`d200`;2@0902TX9P0<2`T04Q4?00d<2P0H
5aD051<A00P71@0G5Q@03Pd;00@03`h<00L03Pd;00T81P0@3`d01`H401HE4`0/:bT051<A00803`h<
014040l=018A3`0A40h03Pd;014@40081`L03`d>04Q6A`0d<S<05aDF00d;300@3Pl0<c4b01`J6`0<
2P/0<2h_01<A4P0300l=3P0300d;300=30`03P`=00<03`d>0P0>30d0100B4@l04A0>010?3@0?3P`2
00h=2`0E010?3@0A40h0?3/i02h]:`081`H04A0>010<2`0A3@`040`;00l;2P0@30/0;b/Z01PD4`0=
2@P04@d<00`81`0I5A@03P/:00d9200<20L04@d<0080510?01L040`;00l;2P0@30/04@d<010<2`0?
2`X040`:00d91P0B3P/03`/800d91P0D40d04@d:00H2000A3@X030P601@@3@0B3P/04@d:00l;200>
2PL040`9014=2P03010<2@<04@d:01D040`9018A3@0=30P030/800l>2`0=30X02PP700d;2`0@3Pl0
2@L9014?4P0B41<02`T<00X8200A40h02@P601`K6@0920H04Q4?00/:200<2`T00`0=30X03@0<2`T0
3`h<00h=2`0>3@/030/900d<2P0A40h092<Q018A3`0@3`d02`X8010?3@0<2`X00P0@3Pl03`081PL0
2`T:010>3`0>30d03`d>00d;300;2@X040h?00d;300X9RL08b4T00h<3`091`X06ALJ014?4P0200l=
400<00`:3@0F51L040hA00d;3P0<2Pd02PP900/92P0=2``02`T:00X82@0D4Q<040h?0P0=2``0300:
20T030X;018@4@0A3a002@L800l=3P0A3a005aDF00h<3@0;2@X030X;00h<3@8040h?00X04@l@00d;
300?3@h04Q0A00h<3@0<2P/040h?00h<3@030@801P@50P0X9RL01P0>30d04@d>01PD5@1`K6d0Ad=4
01<?408040`=00<02@D601<?400<20T00P0@30d0500A3@h040`=010<3@0?2``03PX;00d92P0@30d0
4@d>00l;300C3a0040`=00d92P0B3Pl06ADF014=3P0@30d0510A01dI6P0L61T03@T:0P0>2P/03P0<
20T01`@501@B4`0=2``03P`=00T7200>30d040h?01@B4`0B41403@/<010>3`0?3@h03@X;100?2``0
3P0>2@d040/?014<400@2a40=2le01@?5@0<1`h030X?018@5@0<2Pl02`T>00l=4P0:20d03@/@100<
2Pl0400>31402PP;014?4P0<2Pd03`d@00d;3P0?3A0040hA00/9300>30l04@lB00d;3P0:20/02@P<
018@5@0;2@h200d;4003018@5@0S8BH03P`A00803@/@00T05aDJ02/Y;P0:20/03P`?00`:3@0=2`h0
40hA00`:3@0@3Q400`0=2`h00`0<2Pd03`d@ooooo`0Cooooo`006oooool030071@X02`T>00h<4@0>
31402`T>00L52P0;2@h03`dB00/93P0<2Pl040hC00d;408050lC00@03PT=00l:3P0<20T04@d>0P0>
2PT05`0?2`X040`9014=2P0A3@X040P500T1000A2@L03PP800/52@0G4AD03`X@01<@5`0E4Q/02PPB
01TE8`0811802PLB00d:4`0@3AH04PlH00d:4@081@`040hC008040hA01P03`d>00d;300<2P/030/8
01LF500@3`d03@/<010>4@0<2Pd040hC00`9400>2a804@hE014>5`0C3a/061@R01XF900D4A`05A8K
01DD700B4AH04Q8D018D4`0>40d200lA300A00`=200E5Q404Q8@018B4@0H61P05aLI00T9300<2a00
61LM01LF700P7bD03`hF010@5@0@4AD04Q<G01DF6`0D5AX00P0?3aL09P0D51`05QHP01/K9@0M7BL0
6QXT01XJ9@0E5B404a<M01<C6`0L72@05aPM01PI7P0G61`05AHI01@E5`0E5QP061XJ014B5P0J6b00
5AHK01<D6@0I6Ql04a@I01HG700C51T061TN01XK800F5a`05aPM01LJ8@0520l0<cHm01PK8P0?4QT0
5aXQ01XM900I72<06QdT0P0K7RD06P0H6b@05aT^01LI<00L7S@09BLl02<V>00H6bX04aHU01LK9P0K
7bX061`U01@H800I7BH05QdW01/R;P0D72L04ATT01<J9P0B62@05aTV01hJ:@0U72d09APZ02/I;@0i
:Sd0?cm;0P0M92`06@0K8RX06R4Y01DL900A62009Rde01<J8P0B6B407B@/01TP:00N9Bl0;cE001/Q
;@0V;3X06R0^01/Q;`0P9S<072<]01hU;@0T:c808b/^020W;@0M92l092Xf02D[=`0Q:3800P0M92`0
3@0K8RP0AdmB01HN8@0Q:B/08RX/01hX:P0A6b@08bdg020Z=00f@4X04Q`V01<M9`0F82X00P0G8B/0
2`0F82X05AlY01HN:@0K82`06al[024U<00N8R`05ATR01@H8@0G728061dQ00806b0T02h05a`O01HK
7`0B5Ql06AdX01TL;@0G6Bh06add01DG;P0I6c006A`_01XN:P0I7R8061dP01<I7@0C6R805QdU01/R
:`063AL08BLc010F9@0D6B`061d`01/P=@0H7C<051T_01<G9`0D5R804aHO018E7@0C5Qd051LL01<F
6`0J7R404aLJ018F5`0<41404QHF00P=4`0?4a`07B4Z01@H8@0?4a`05QXS01XN9`0G6b@04QHO0P0H
72D04@0E6B<05QDS018A8@0S9C@05QPW018D8`14AeH04aTW00hD8P0G7b`02aDQ010J9P0=5R405AXP
01DH7@0D5a`04aHK00804QDJ01@04aHK018E6P0A51T041<H014D6@0A51P04ADD01LL6@0H71/051PG
010D500B5QL00PH900lB5P0D5a`0@DA;01dP9`031P/03a0E010A5@804A8F00@0414E00l@500@4AD0
4Q<G0P0C51P03P0B4aL04A8F01@E5`0;30h02P/=05YKG@0N7b4030d?00l@4P0C51H03a0B010A4`0H
6A/05aPJ0P0D5AL030092P`03a0B01/L7P0720X0;Rla02@U9`0?418061TK00T:300A4Q@03a4?014C
40<04Q@A02/04aDB01DG500@4Pl03a4>014C400?4@h03Q0=00d?3P0>40l0004001hP7`0<3Pd061XI
018D4`0C5A@05ALF01LI600F61L05ALF010A3@0E5Q405QLA018C2P0?4@H03@h701@E400D51804Q4E
02<R:P0n?4L05aTN0088100E6aT0:S0a01TN8P052Q00;C4j00D:400N8bL03Q@E00H<2P0:40`03A4=
00803`l=00X02`/901`L6P0:2PP02`/900l?3@0@40h04a<A01dM6`0K6aT04Q<?0P0@4@`0100A4Pd0
414<010A300?40/500h?2P0602LY9P1]LVh08BHR00/@300?51001``80P0D6AD010083@T0314=00D:
1P0A514200h>300400l?3@0@40h0410>00l?3@<04A4?0P0?3`d02@0>3P`04A0<00T8100A40`02PT5
01@C3`0<2`L03Pd900l>2P02010?2`0@00l>2P0>3@T02`X801HE4`071P@02`X800P71P061@<02`X8
014@3P0>3@/04Q4?040o?@0E51803`h<00h=2`8051<A00@03Pd;00l>300>3@/03`h<0P0@3`d02@0?
3P`03Pd;01XF4`0C3``061@A01TE4P0810402@D2018>2`0200l;200i014=2P0C3``04@d<01LF5P0B
4140:bTZ05YHF@0B41404a4B01DC500D4Q<00@0000h<3@0J61T02`T:00d;300:20T02@L800d;300F
51D06QPI018@4@0?3@h03P`=00d;300>30d03`d>01HE4`0A40h03Pd;00d<2P0>3@/03`h<010?3@05
108071/I014@3P061@<07QdK010<2`0=2@P040`;018>3@0@30/03@T800T5100@30/03PX9010<2`0I
5A@04@d<010<2`0B3Pd0510?01DA400G4a805A4@00803`/:00H03PX900l;2P0?2`X040`:00/7100@
30T200l;200801@@3@0A3@X0510=018>2`0D40d03PX700l;200>2PL200d91P03010<2@0B3P/040`9
00803`/80`0@30T02@0?2`P03@`:00`;2@0@3Ph03@/<00P61`0B418030X=02TW:P02018@5@0900@2
1`0H5QX03@/<00T81P0>3@/061LE00@30@0;2PP03Pd;00803`h<00H03Pd;00d<2P0<2`T02PT700`;
2@0>3@/200d<2P0C018A3`0;2PP03`h<00/:20061@<05aHD00X91`0O7Ah02PP901TG600d<S<0;bd^
00/92P0A3a002@L8010>3`0B41404a4B00H41@0200X82`0<01LE600=2`h01P@701@B5@0F51L01@<6
01DC5P081PT02PP;018@4`0A3a003@/<0P0>30d04@0=2``04Q0A00H41@091`P04@l@00l=3P0<2P/0
3P`=00X82@081PL02@L800d;300@3Pl00`4200X82@0<2P/03P`=00<03`d>00D040h?00`:2`0?3@h0
3`d>00/92P0200d;300A01@B4`0B41400`4200800@0B41404`l@03Pd=@3Ccm00RXJ700`82@0K5aP0
4Ph?00d92P13?d004@d>01HB4`0?2``0100@30d01@0?2``04Ph?01/G600I5AH03PX;00804Ph?00X0
2`L800D10P0:1PL02`L800`82@0D41405Q8C00d92P0810D04@d>0P0?2``03`0E4Q<04Q0A01@B4`0?
3@h03P`=00/92P0F51D08AlP01`J6`0>30d03`d>00h<3@0<2@X03`/<00d92P0200l;300=00d8300C
3Q804PdA00L2200I51X02PD;00`83P0B41D01P@900X83@0610T03@/@01<A5P0200/93P0X00`:3`0=
2a003`dB014?500>30l04Q0C00X82`0=2`h03P`?01DC5P0e<cH081hQ00`:3@0B41<05A<F00h<3`07
1@X071XO00H52@0l>Sl06ALL01dK801jN7d081hS01PF6`0:20d040hC00h<4@0:20/03`d@00d;3P0>
30l040hA00`:3@0C4A@040hA01@B5@0C4A@03`d@014?4QCooooo000Kooooo`1I010;2`0A3@h04Pl@
01<>400@2`d030T;010:3@0?2`d01`D601<>4`0A3A404@/>00/62@0?2Pd03P/>00l=4P0;2Q003PlF
00H5300B4aT030/@00l=4@0>2`d02@H701DA400<20H04Pd=018>3`0;1PL04@h@00h;3P0;2@d02PL<
01HD6P0<2@l03P/B010<4`0A2a804`lF018=500E3aH02PL;018=4P0B3A4040d@014=3`0A30l040`?
00l=400O7B006APK00d<400C4QH04@lE00h=4P0?3A<03`dD018@5P0?3A@05a@K01HB6@0E4AL04PhD
01@@5P0D41D040hA01@C500C4Q<04a8A01<C400@3`l04A4>01<C400@40h061PG010@3`0C4a804Q8C
01TI6P0G5QT05ADG02LW:@0H61/04A4D01`M800O82<08b<V01TI7P0>3Q<00P0H61d03@0B4QP040lF
01@C6P0F5A`05AHL00l@600D5A`03Q0F01PJ7P0A4aL06Q`P01@G6P0B5AL00P0E5aX01`0E61X05aTN
01DG7@0C5A/04aDJ01@F6`0F61d00P0D5QX02P0G6Ad06Q`P01XL7`0G6Qh051LL01XM8`0D5Q`0<cHl
024T:P0C5Q`201@G7@1`01DH7P0F6Al05APN01@G7P0G6RP05QTY01dQ<00L7bl08BDc02<V=00F6RD0
5a/W01/O:`0L82`06AdW01dQ:`0H7bT05AdV01DM9@0G7RT05ahX01DK900K7RX08b@`02HU<00Q72X0
;RLf03ljB00_<Cd06b4/01dT;@0K8R/06B0X01XQ:@0I82L0<SU0024X;@0G7RD0620T01PP9@0F7BD0
6B0Y01LM:00Q:3<061hY01XP:`0U:cP07bDa01dT;`0Q:3407RD^01PP:@0H8Rh07RTf020[>00[=D80
7BHb01/U;`0O:340?TM>01/V:P0M9bP06B8T01XU9P0E8BL06BD^01PT;@0S;SL041/T01DQ:P0F82X0
5AlY01@N:00G8B`05b0/01@L9`0F72L0724/01`R;00P9Bl03Q<L01PM9P0G7B<05A/P01HL8@0C6Ad0
4QPK01HL8@0B5ah06AdW01DI9@0B5BH06aha01LJ;@0D5bP06ah]01LK9@0N8bT0724V01DM800C7B40
6B4W01<L900F7bT05A`Z01TQ<00B6R/07bDf01`S<`0Z<d405Qd/00hC80804aHO06404QHM018F6`0C
5a/051TK01PL7`0B5QT061dP01LK7`0E6Ad05a/S014E7P0E62405QTQ00lC6`0B5Qh041<K010D6P0A
5A/051PN01DI7P0/<3L0BdiJ01TL:`0B5R<05APV01<H9@0a=T<05adZ01DK9P0L92h04aXU01TR;00B
6R@05AXP01PL8P0J7R<04ADK00dA5`0J7R<04QHJ014E6@0>4QH03a<G018G6@0B5QX04ADG01<G600K
7b403a<E018F600C5aT061`N014E5`0=4A@04ADH03/o@P0Q92L04A8E018C5@0C5AD04a@G01<D5P0B
51@04A8E01<D5P0D5AH051DH01<D5P0A4a<030d>018D500C5AD0@49201LH6@0D5AH0418B01<E5@0<
3Ph03Pl@01DG5`0>41002``=020R8P0F5aP04A<C00d?3`0C5AD05AHG014B4`092PX04A<C00d>3`0B
51<051DC01@E500D5A<04Q<A0080414?01D051DC010A400@4A004Q<A00l@3P0=3P/04aDA01@F500=
3`/03a4>010B400?4@d03a4>00h@3P0A4`l051HC00lA3`0<3P/0414>018C3`0A4`d00P0=3PP07`0B
50h030h:01HG5@1<C4`051@G01HF6`0=41003a@?00P<1`0D61H0Ada;038e=`19CDl08bLY02<V9P0@
51803aD@00`?2`0@4`l03Pl<01DF4P0?40d04a@A010A3@0>3`/03a0<00l@3@0@4@h04a@@010A3P0>
3`X00P0@4@`05`0A4P`0414<010A300@4@/04Q<>00l@2`0;30H030d700h?2P0>3P/0?d0l01<C400;
30P03a0<018B3`0<3@T03a0<010A3@0E5A8051@A00l@3@0<30X0414?0080414@00H03@h=00`=2`0<
3@`04a@B00l@3`0?40h200X;2P0?01<B400=30T04Q8?00l>2`0=30T03@d:014@3@0F5A805ADB00d=
2P0>3@X03`h;01<C3`0>3PX05QHB00804Q8>0100410<018B3P0=3@T05ADB00`<2@0B4Ph04A0=018A
3`0A3`d03`d;00l<2`0@3@`03P`:01<@3`0?3@/04@h=0P0E4Q40;@0@30/03PT6014=2P0>2PL03`/8
014=2P0F4Pl05A4>010=2@0?30T05Q@@01dK5`0O7a/05aLD00L7100I6AD061PD00d=2P0>3PX0<c8`
01LF5P0C4Q803Pd=00X92@0B4A403P`;00l>3@0?3P/03Pd;00`:2P0;2PL0>SPg01`K6P0=30T04A0>
00X8200@3``03`h;00d<2@0;2PL03@`900l>2`0=30T03Pd:01DD4@0200h=2P0=01<B3`0=30T040d;
00`91`0=2`P040d;00l=2P0@3@/02`T600X81@0B40d03``:00d:200200h;2@07014?300=2`P030X7
010>2`0?3@X040d;00h<2@0200`:1`1_00l<2P0B3``03@/700d;1`0?3@T04Pl<01<@3@0>30P04@l;
00X7100>2`P02`P5010>2P0A3@X03PX700`81@0C3``050l<00d91P0=20D04Pd:018>2`0>2@H03PX7
018>2`0;2PP030`:00l>3P071PH03Pd<01/J6@1dLg@0JFQY01@C500>3@l06QTJ04i=CP0<2`/02PT7
00l>300<2`T04Q4?00X:200<30X03Ph<014@3P0@40h03Ph<00d<2P0?3P/040h;014>300>2`T03@X8
00l<2`0;20L03`d<01DB4P0?30`04Q0?018A400_;Bd04a8B00@30`0>3@d030/:01<B4P0>3@`03`h=
010?3`081`L040l>00l>3@061@H061LI01@C5@0:2@X04Q4C00L61`0:2@X03`h?01<B4`061PL08B0R
034`<@0>3@d02`X:00`;2`0>3@`03Pd=010?3P1NGE`06aXJ00@30`0P7ah06QTH00T8200>3@`030/;
00h=3@0?3Ph02PT900l>3P0=30`030/;01HE500D4a<02`X900d<300A410030/<00803Pd>01D03@`<
00h=3@0?3Pl03Pd=00/:2P0];2`0<C0a00l>3P0?30d05A8C02PU9P0S7b004Ph?00l;300A30d03`X<
03@_<@0A2`d04``>00h92P0>2`/00`0=2`X05@0>2`/04Pl?01PF5@0G5A@03@/:00h<2`0A3Ph040h<
00X71@0=2PP04Pl>00l=300H5AD07A/J00d:2P0>2``03``=00P51P0>2``040h?00L51`0200h<3P0W
00/92`081PL03@/<01<A4P0A3`l01`D5010?3P0B41002PP8010?400=2`/02@H8018A4`0<2@`02`P<
00l>4P0@3A802`L>00X93P0>2a80518K01XH800B41L02`T>00d<3`0920X030/?00`;3P0>3A402@P=
010>5P0A3aL02`X?00l>4@0>3@l03@`?00X92`0?3Q003Pd@00802`X=01/03`hA00l>400>3A005QDG
00P7200?3Q0040lC01@C5P081`/06APK01HE6@1:B4d06aTN00`;400C4AH02`T>01<?500?2a004`lD
010=4@0@31403P/?00l<400@3A404PhC014=4P0>2`l05?ooool001_ooooo02X030L300d81@0=20D0
3PT600h91`0>20P02P@401@>3`0B30h06A<E00P2100C3@l04`X;018<3`0?3A803@`B00X;5P072aL0
BdmK03i2CP0:3AH01@@=01@A600I5a`040h@01<A4P0@3Pl0518C014?400?3@h04Q0A00d;300;2@X0
5A<D00X82@091`P05Q4E01@>4P0;1@T03PP<010:3P0S7B4201@>4P804`dA00@04P`@014<400<2a00
3`hD0P0D4aT02`071P`0<2le01LF70061@/04Q4G00/:400?3Q@040hB01<?400A3@h04Ph?0080510A
00@05Q8C01PD5@0G4a@05Q8C0P0E4A80100D4a<06QXH01hN700J6QP401@D4P0:01DE4`0A4@l04Q8@
018B400C4a@05aLI01DE5`0M7Al061PJ014A4`805aLI00P05QHH01DE5`0F5QP05aLI01DF6@0U:B`0
:Bd`01<G6P804ADH04X06AdP018F6@0B5QT061`O01HJ7@0C5aX05aXQ01HI800C5Qd04QDJ01<F6`0E
61d03a<F018F6@0C5aP05ATJ01XN7`0D61T08B@Y018E6P0?4QL04A@I01/N8`0H6b005QTN01LJ7`0F
6Ah04aHK01@G700I72404aPN02@X<@1:CUL0?d=<02L[=@0<41/04ADP01lS;`0B5R805QXV00dA7P0L
82`041LQ01HM9@0G7RH04aXR02/b>P1EG6@082L_01TP:00L8b/05ahV01/R:P0H7bT061hZ01TO;00I
7b/06B0Z01PO:00F7BD05QdS01lV:`0K8bH05QhQ01LO8P0H82<06R4W01TP:00J8BT072<[01lV;`0O
9S006R4[01`R;P806Al[00`06b4_01PP;@0K:SL0?dmN020`?`2O[;`0Ef=c01l[>@0H9C006R@^01TT
:P0H8bD201LS8`0<01PV:P0E8RP05B8X018O9P0D8BT072H_01LQ:`0J92h05R0Z01LQ;@0H82d051`W
0P0G7RP01`0=51h08RTa01hU;@0L8b/05QdS01DL8P0C6Ql00P0B6Qd01@0D6al05Q/Q01@H8@0C5b40
4aLR00804aHU024051PT02HZ=P0G6bD061`U01LL8P0L9BP04alO01@O8@0F8BH07bTc02@^>P0M9SD0
HFYi00TC7`0=5b405R0Y01PS:@0E7BD04aLP01<H7P0B5a`04QLJ01<H6`0C6AT041HF018G6`0H7B80
51TO01@H8@0@4a`04A@M01<F7`0E61l00P0F6B00:`0E61d051LL018F6@0A5AP04QHI01DI7@0R9S40
3aDS010F8P083QX04ALS01TP:P0E72H04aXT014H800C6R8051/S01<J8P0F6b406AhT01dR:00C61h0
3A8H01XO8`0B5aX04aPK00lD5`0=4a<04ALG018H600C5Q/04A@I01TL8@062Pd04ADH018F6@0A5AH0
4aLH014E5P0@51<04ADD018F5@0@4Q400`0A4a82018D4`0?010B4@0A4a804Q@C018D4`0A4a80418A
01LI600C5A@010H500D71P0A4a80418A01PJ6@0E5aH04aDD00804A<B00L05ALF018D4`0@4Q4010H5
02<U900A4a804aDD00H04A<B1P0C4a<0200N7Qh04a<C00h>3P0?3`l04Q8B01@D4P0B51004A<>0P0@
4Pd200h@2`0G00X<1`0<3PT04A<>01LI500F61<04aD@010B3`0B5140418?00lA3P0D5Q<04aDB01DG
500620D08bDR00@60`0E5a@04A<?00h@2`0=3`X03Q0;00lA300A4`h00`0@4Pd0100>40/03@l:010B
3@0B50l200lA30<0418=0P0A4`h01@0@4Pd03a4<00h@2`0>40/03a0;00H03a0:00/010D000<4000=
3PP06AXD00T:100@3`/04`l<01@@3@0E4@h05Q8?01@@3@0201<?300M01@@3@0E4@h0510=014?2`0;
2`/04aDD00d?3P072@P020X9014C4P0=3`h04aDD00T;2P0:30/03Q0?02LY:0092@L03`l=010@3P04
108092@R03Ti=`0@40h06ATG01LG5@0;2`T03Ph<018B400>3`X00P0?40/200h?2P0900l@2`0<3@P0
3@h9010A300>3`X03a0;01PI500=30X040`;00804@d<0`0C3`h08@0>2PT03`/:01@@3`0D40l03@T8
014<2@0B3@X04@`9010;200@30T04`l<00H2000?3PX02PT500L60P0>3`X051D?00h?200<3@D05AH>
014B300>3`T02P/5010A300:2PP020P6014A3`0@40h02PX801<B3P0=30P030/700h=2@0200l>2P07
02<R7P0<2`L0;2/W00X91@0E51003@`800l>2P0200d<20803`h:00<03Pd900d<200>3@T00P0?3PX2
00d<200600l>2P0=30P03@`800d<200?3PX03Pd90`0?3PX02`0A40`03Pd900`;1`0<2`L020L300d<
200@3`/02@P400X91@0?3PX03Pd900803@`80P0?3PX00`0=30P030/700/:1P0200X91@0300`;1`0>
3@T03Pd900<03Pd900L03@X7018=2P0?2PL03PT600d81@0L5a@050l<00803PT60P0F4@h01P0;1`@0
30/900h>300>3P`02PX8010@3P804Q8@00`04a<A00`<2P010@001PH401LG5P0F5Q@0000000L71@08
20H0000001@D4P0?3`d200h>300G00d=2`0?3`d05ADB00h=2@0?30L03`/800h:1`0?2`P040`;00<0
000;1`L02@D6010<3@0E4A800`4200L71@0820H030`:01<C4@0=3@/04a<A00/;2@0<30X00P0=3@/2
00l?3@0=00X:2P0A4A403`l?00T92@0820P02`/;010@400A4A403Ph>00d=3@0I6AT0:2PX00/;2@05
00`<2P0601/K6@0:2PP01@D300T91`0<30X0410>1P0;2`T01`0A4@l0000000@40P17AdD0>c/i00`<
2P0<30`00P0;2`/200`<300>00h>3P0<30`01`L700P8200T92@09bLW00X:2P091`P02PP900h<3@0C
3a003`/<00/7200@2P`401893003010;2`0=30X03@`:00<03@`:00T030/900d<2P0=30X03@`:00h=
2`0B4@l04A0<00l>2@0B4@d00P0>3@T02@0F5A<06QTG00P71@091`P03@/<01lM7P0o?Ch0;R`_00h<
4@0200`:3@1400d;3P0=2``02@L800d;300=30X02PT701<B400E51003`l=01dM7@0<30`02`/=00D5
1`0:2P`04Q4F01TH7@0A41D03@`B00T83P0:2A004@lJ02LU<00=31<030/@00h>400:2PX061PH02<S
8`0I61`020L=01@C6`0610l03PdB00h>400A4A<03Ph@00`<3P0F5QP0820R01DE5`0;2`d04A4C01@D
5P0:2P`05aLG010@400A4A406ATI01DE5P0@41804A4C00`;3`0Y:2d02PT>00h=4`0D4aT04a4F014<
4P0E41H04@`B010;4@0C3Q@03PT?010;4@0=20h040/A01@?5@0?2Q0Dooooo`006oooool0700=2PD0
3PX6010<2@0A3@X0510>01@@3`0;1`H02@H500D10P0d<340510A00d72@0C2Pd04@/>00`:3`0;2Q00
2P/D00T;5`0;3AT05aTT014A6@0A3aD03P`A00l:3P081`L020H700L51P0>30d200L51P0;00l=3P04
0P<03P`=01hL7@0B414030X;00X62@0H4aL020<701HA5@0300800P0C3Q83018=4@804@`@01804a8G
00X93P071P/071/P03dl@@2n_L80@T5600X93P0J6Ah030/@01dL8@0D4QH04@l@00l=3P0@3Pl04Q0A
014?400D4Q<201LE5P0401DC500C4A804Q0A01@C508061PH00<04a<C00h>3P0@41000P0C4a<01@0F
5QH05ADE00d=3@0=3@d051@E008030`>01D0410B018B500E5AL05QHH01PH6P0G5aT05QHH01LG6@0H
61X04Q<F018F6@0@4QD082@W01TM800C5aX05a/N01<G6P0E6A`06QhQ01PL7`0D61/00`0E61l0;P0D
5a`04aHK01<F6`0A5AP051PK01DI6P0G6a`06AdN01DI6P031P/05QTN01TL8@0G6Ql00@@901<F6`0J
7B806A`Q01@G700@4aP04QDJ01TL8@0H7B<0724W02L/<P0E6B8061`V01`P:`0B5R406AdY01HJ9P0[
;c/0720/01TM:@0D6bD08RTa01lV;P0F7BD0=Se5071gO`0f?DD072<[01dT;00J8BT06b8Z01PO:@0F
72P201LM:@0c01HM9`0F7BH051/S01PO9@0F7B8041PK01<K7P0J8R@05alR01PO9@0K8RP06R4W01PO
9`0J8BX07RD_01HM9`0L8Rh06Al[01PN:P0L8Rh07BDb02djA`1^O8T0>dUF0;O4d01^NXX0;CU701/W
<`0P:S@07RT_01PS9@0F82405b<S01`W:P0I92P06RDY01HQ9P0E82H06b@[01HO:00K92d05b0Y01@L
9`0E7BP051`W01XQ:`0E72H072<]02P_=`0M92`06B0X008061lU01l04QXN01TQ900J8RD05A/P01@I
7`0F6R<05a/U01HJ9@0E62L071l^01/O:`0L82`06AdW01XN9`0:3aD05QlQ018N7P0E828031LL00lI
8`0O:CD0Ae5N0;O0c`0_>DD07BLa01<M9P0:5A/03aLO01HJ8`0D6Al04aPM00804aPK00X04ALG018H
600G720061dR00lD6P0E6B804A@M018E7P0E62405QTP0P0G6R4201@G700L01@H6`0B5QT03a<F00`@
500=4A`05Q`X01PN:P0<4Qh03aDQ014H8P0F7BL04aXT00lF7P0@5ad04QTO01<J800D6Al04aPN01HK
8@0F6al04QLK01@I7@0B5aX05AXM018G6P0=4a<041HF018H60803Q4F00P06ahS00/?4P0>4QD02PhA
00lC500A5AD04QHE010D4`803A4@00L04Q@C014C4P0@4Q40418A018D4`0D5QD0418A00@04A<B01<0
418A00/=300B51<03a4@01<E500L7Qd05QPG01XL6`0?4A004aDD014C4P0<3Pd06adL01dO7P0H6QT0
6Q`K024S8P0;3@`010H500H04A<B00@0410@014A4@0B4Q8051@D0P0E5AD01`0T92@05QHF00l?3`0@
410051@D01LG5@0@4Ph01P0@4Pd01@0A4`h04Q@?01<E400A4`h0418=00805ALD00X03@l<00h@3@0A
4a002`d:01`N6`082PL01PP500L91P0O8Ah0418>1@0?4@`03`0@4Pd04Q@?01<E400A4`h03a4<010B
3@0B50l0418=00h@2`0<3PT03@l:00lA300D5Q405ALB010B3@0200d?2P0300lA300@4@`03Pl900@0
3Pl902D0414;01<D3P0Q8Q`03Pl9018C3@0>3`T04Q4=014@300C4Ph051<?018A3@0=30P04A0<010?
2`0A40`04Q4=014@300=30P01PH600/=300:30/05QPG01TK6P082PT04aDD00`>3@0@4Q405aTH00h@
3`000P403`l=04I6A00E5A<03Ph<00<30@0=3@/02PX80080410>00<020P600d=2`0B4Q001P0>3`X0
0`0<3@P03a0;010A300200/<1`0801PI500;2PP030/900h=2`0@3`d04Q4?01<B400?3P`200h=2`08
00l>300>3@/03@T8018>2`0C3``04Ph;010<2@0A3@X2018A3@0?01`K5`0E5Q40414<01@F4@0B5@h0
3@h700T:0P07200030d700X;1@0@4@/03@h:00H6100E5A<02@T70080410>01@061LC00h=2@0;2PH0
3@`8014@300B4@d02@P600H50@0f=C402@P401HE4@0920@03`h:00T8100?3PX03Pd900/:1P0@3`/0
30/700d<20803Pd90P0<2`L00`0?3PX03Pd900d<200200h=2@0900l>2P0@3`/040l;00l>2P0B4@d0
3`h:00`;1`0@3`/01`H200803Pd900D02`X601LF4P0?3PX03@`800h=2@02010?2`803Pd900D03`h:
00h=2@0=30P03`h:010?2`0500l>2P0A00h;200I5A806aLD00l;20081040;2PU020L6@0B3P/03PX7
01HB3`0A3@X02`L400/:200>3P`02PX800d=2`092@L00P0=3@/04`061P@05aLE00`<2P0D51802`/9
014A3`010@0071`J010@3P0?3`d04A4?00h>300=3@/02`/900`<2P0@40h051DA00d<200=30L00P0<
2`L0400=30P03`h<018A3`0D4Q801P@500/92P081`L08AlP01<C4@051@<04Q8@014A3`0>3P`0410>
00/;2@0<30X200d=2`803`l=00T051@D00L71`0C4a<05ADE00X:2P0C4a<030`<00/;2`0<30`00P0>
3Ph03@0:2PX03`l=00h>300<30X02`/900X:20092@L01PH400h>300F5Q@04A4?00d=2`0@40h01P0;
2`T200`<2P0400h>300A4@l02`/900h>30<02`/;00l030`<00h>3P0>3Ph02`/;00`<300?3`l03Ph>
00d=3@0:2PX04a4B01HD5@0L6Q/08alP01/G600D41400`0@2P`20189300N010;300>3@/040l=014@
3P0@3`d03Pd;00`;2@0=30X03`h<00d<2P0>3@/05A@B01HE4@0A40/04Q4=010?2`0>3@T03Pd;00l>
30081`D03P`=00X82@091`P07Q`M01hL7`0@3Q<03P`?00l=400@3Q403`d>0P0>30d200d<2P0[00h=
2`0?3PX020P600l?3`0:2PX07QhN00X:2P0?3a403PdB010?500=31404A0F018A5`0:2A002PPC01TG
8P0:2A003`hC00d=3`0=3@d00`<300d=3@0;2`h051<I01<B6P0>3AH03`hC00h>400A4A<0410B00h>
400F5QP07AdO01DE5`0;2`d03@d?00l?4@0;2`d04Q8B00d=3@0?3`l051@D018B4`02018B500300H6
2@0>3A8020L<00803`hD00H05aDJ00X83@0F51T03@/@00l=4P0:20d2014?500400h<4@0@3Q<0518G
010>4aCooooo000Kooooo`0Y010=200A3@T04@d:018>2`0C3`d04`l>00l;2P0@30`05a<D051<C@0M
6AX03@X:00h9300=20d02`T>00/:400>3QD03a4I010?600@3aL04@hC018=4@0B2`l05A0A00l<3@0B
41405A<D018@4@0>30d03`d>00h<3@0J61T03@/<01PF5`0D4Q<03P`=01<>4P0G4QH06A@H014<400E
41@01P0B3A404@0@3Q4040lD018A5P0I61d06aXO010@501FEEX09RDZ00T83@0@3a@03`hC00`;400@
3a40518C018@4@0C4A80518C00L04a4B01h04Q4B01<C500D51L04a<E010@4@0A41@05A@G01DE5P0H
61/06a/M00h>3`0=31005QHH00`<3P0I6A/05ADG010@4P0K6ad04a<E01LG6@0F5QP05ADG01HF600G
5aT05AHI01HJ7@0I7B005ATL02<W:P0B5QT201<G6P0401HJ7@0I7B0061`O01@H6`8051LN00H05QTP
01HI7P0D5a`04aHK018F6@0C5aX401DI6P0V010B5`0F6Ah06ahS014D6@0P8bP05APM01XM8P0I7240
5APM01<F6`0D5a`05aXO01HK8@0E6R007b@Z01HK8P0L8BT0720Z020T;`0S9c80<SI101@H900H72P0
6alZ01PO:@0G7RH05A`T01@K8`0H7bL072<[034h@00H7bL07bH^01/R:P0G7RH06R4Y01LN:00I7bX2
01TP:P1K01TP:00G7RH06B0V01PO900B6Qd051`O01XR9@0H82<08RT_01hU:`0J8BL06b8Y01XQ:@0G
7RL061lY01XQ;00H7RT06b4]01hT<00J8Rd05b@`02<a?@0I9c<0;3Q702TeA00I9C<07BPc02<]=`0Q
;3806B<V01HP8@0H8R805b4S01TR9P0L9RT06B4U01HN8P0I8BP06R8Z01`T;@0J8RX05alW01hU<00U
;CH05ahX01/R;00A62806R4Y02<Z<P0G7RH061lU01`S:@0D6b007bLZ028Z;@0E72404QPN01@I8P0D
6R<051XT01HJ:@0I7B`05AXV018G8`0@5Al051TR00/A5`0O:2/04A`M01PS9@0kADX0:38k014J9@0L
9C40=Ci904QAG@0B6bD06b@]010J8@0H82L05adU01HL8P0D6Ql04aTL018I6`0D6a/051`K01LN8@0H
7R<04QPN01HK900301PK900B01LJ8@0E61l051LN01@G700E61d05QXM01DI700D61/04QLJ01LK9P0B
62@04ALS028Y=00N92l061lY01<J8`0B6B404aXQ0P0E72806`0B6Al03Q<I00hC6@0@5AX04AHJ018G
6`0E6Qh04QLJ01DJ7@0C6AX03aDE014G5`0B61P05ATL00lB5P0_<SH0;S8e01XN8@0D61X041@E00lC
4`0B5QD041@C00lC4@0D6AH05ALF01<E5002014C4P0301@F5@0G6AP04Q@C00@04aDD0P0B51<04@0?
4A005QPG018D4`0>40l092HU01DG5P0G6AP051HE014C4P0B51<05aTH01TK6P0A4a803a4@018D4`0F
61L02P`;00H04A<B00@04A4A018B4P0B4Q804a<C0P0D51@2018B4P0801<C4`0E5AD04Q8B00l?3@0?
4@d03a4<010B3@0A4`h2018D3`0C014C3P0B50l04Q@?010B3@0A4`h04Q@?01<E4P0F61D0418?01<E
4P0D5Q<03Q0=01DG500?4@h05QPE00`>2`0D5Q<04A<?014C3P02018D3`03014C3P0@4Pd04A<>00<0
4A<>0`0?4@`00`0@4Pd03a4<00d?2P0200d?2P07010B3@0A4`h03a4<00d?2P0>40/03a4<014B3@06
010A2`0501DF400^;bT03a0:014B300@4@/00P0@3`/04`0C4Ph03Pd900T8100A40`05QDA018A3@0=
30P03Pd9010?2`0=3@P04Q8B01hP7`0M7ah04A<B00`>3@0I6aX0:2XY00`>3@0C5A@00P0=3`h03P0I
6aX0DU9@01lO7@0820L051@B014A3`0=3@`03Ph<00l?3@0@40h03Ph<00l?3@0B4Q003a0;0P0>3`X0
0`0@4@`04A8=00l@2`0200l@2`8051D@0P0?40/2010?3@<03`h<00D03Pd;014@3P0D4a404a8@014@
3P02010?3@0L010>2P0B3``04@h;010=2P0@40/04A<>01@D3`0;30P02@d700lB3@0A5@l02`h701DF
3`0P8AT06Q/C01LH4P061`404A8<018C3`0[:bT0Hf=Q01LG5@030`804A4?01LF4P0?3PX03@`800h=
2@803`h:0P0B4@d02`0;2PP051<?00D40@0E51003Pd900X91@0F5A404Q4=00T8100@3`/03Pd900<0
3`h:00<03Pd900d<200>3@T01@0>3@T200l>2P0<010?2`0E510051<?00/:1P0F5A403Pd900d<2009
20@061LC02l^:P0@3`/03Pd90`0?3PX400h=2@0300l>2P0B4@d04A0<00D03Pd901D03@/701TE4P0M
6AH05a<@00X60`0F4Pl0510=014=2P0D40d030P500L3000V8b0051<A014A3`0;2`T04a<A00d=2`0:
2PP03`l=00X:200;2`T00P0A4@l01`0=3@/03`l=018B40071`D05ADD01HF500<30X00P0;2`T01`0=
3@/03`l=00h>300:2PL03`h:00l>2@0>3@T00P0<2`L0300<2`T03`h<00X92@0<2P/04@l@018@4@1i
MgP0:b/Y00`<2P0B4Q0020P600X:208030`:0`0=3@/200h>300:00h>3P0;2`/05aLG01TI6@0>3Ph0
30`<00h>3P0<30`02`/;00d=3@803Ph>0P0A4@l01`0?3`d03Ph<00d=2`0<30X04A4?00h>300<30X0
0P0=3@/00`0<30X03Ph<00h>300400h>300?00d=2`0>3P`02`/900h>300=3@`02@T700h>3P0?3`l0
30`<00l?3`0B4Q803`l?00`<300>3Ph030`<00803Ph>00P02`/;00`;300:20T03@/<01@A4P0@30d0
2PH7010;308040X<01H04@X<0189300@2`/03`h<014@3P0B4@l04A0>00l>300=30X04a8@01LF500B
4@l030/9010?3@0B4@d03@`700d<200>3@T040l;00l>300=30X030/90P0>30d01`0:20T040h?01HD
5`0A3a@03P`?00l=400@3Q400P0?3@h0>00<2P/02`X800h=2`0:2@L02`X600l>2`0A4A005QHF00L7
1`0>3Ph0820R01PH6`0;2Ph04a8G01LF6`0<2a403`hD00/:4P0=31@030/@01<B5`0=3@l03Ph>00l?
3`0>3Ph02PX<02LV;0040`T03@`C00l>4`0=3@l03Ph@00d=3`092@/03Ph@00T92`0@41804A4C00P8
2P0:2P`06a/M00h>3P0<30`03`l?010@400?3a005ADG010@4P0B4QD01`H;01@C600>3A<01@@:010>
4`0>31403@/@0P0B41D01`0;2@h04Q0E00l=4P0>31403`dB010>4`0>31405?ooool001_ooooo00l0
3P/600h:1P0=2@H030P500/71@0:1PD03PX9010<300N6Q/04@d>010<3@0>2P/04`hB014=4P0>3140
0P0<2a406P0<2a000@0500X62`0C3a00614B01H<3@0?1PL0514B00h<3@0F51D0F5IG05YHF@0@3Pl0
3@/<02TW:00<2P/03@/<010>3`0B414040/?03<^<P1^JFd08QdQ01HA5@0I51P04@`@0`0B3A403`0C
3Q804@lB018A5P0<2a002`X?01LF6`0B4AH05aHK01PG700K6Ql030/@01DD6@0?3Q<05aHH01LE5P03
01DC500<01@B4`0A3a003`d>00l=3P0B41404a4B01@B4`0A41@040lD01<B5`0F5AX05A@I0P0D4aP2
01<B5`0;01LF6`0B4AH040lD01@D5`0?3a407AdO018B500?3a408R8T01PH6P0E5AL00`0D51H02@0E
5AL07b4T01LK7P0I7B00;C4d096EV00U:B`041@G01<G6P0201DI700:01LK7P0E6A`04aHM01@G7P0F
6B005APM01@G700B5AX051PK01<G6P805ATJ00P04QHG01DI6P0/;c@061/P01@G700A51T06ahS01TL
8@805QTN01h05aXO01TL8@0H6b0051LL024V;00F6b404aPN00dB600J7bH06alX01`P:`0i?DP0KW9m
02lc?`0Q9C404ADP01HM9@0L8b/07RD]020W;`0O9Rh05ahV01`S:`0F7BD082L_01TP:00F7BD061lW
01DL900G7RL301PO9`0501LN9P0D6b406R8V01HN8@0C6ah00P0E7B00800V;C<072<Y01PO9@0L8bT0
6R4X014H800M92h06R4[01PO:@0O9C407R@`01LO:P0G92h05B<^00lM:00I9C<05b<a01XV<P0G8B`0
6bD^01XU:`0F7b<051hO01LP7`0J82<05AXM01<K7@0H7b809BX^02de>00H7bD05A`R0P0E72@0:@0M
92`09bhf01XQ:`0H7bT0>3m901PO9`0G7RH03QDM01<J800G7R@04aXO01TQ900J8RD05ahS01XQ9`0J
8BT051/T00hE7`0@5R@04ALU014G8`0J82`041LP01<J8P0E72809Rhb01DO800C7Al0Ae1D02lh?`0;
51d0620[00dE800^=T4041PR00hG800J8bX04a/S01DL900D6b404aXO00804QXL00T051dL014J6@0>
5QT051/P018I7`0A62004aLP01DH8@0G6R<00`0G6R400`0G6Ql05QTN01<G6P02018F6@0E01<G6`06
3AL04ALS01<I9@0D6bD082La01PO:@0A62004QTQ01LN900I82H05ahT014H7P0E6R006AhT01DJ7P0?
51P04AHJ01DJ7@0?51L04AHI00803aDE00X04aTI010F500E6A`02`lB01PL7`0L82<04QHH01HJ6`0C
5aP03A4@0P0A5A@0100A5A<07B8N01@F5@0C5A@2018D4`0301DG5P0F61L03Q0?00@0418A00<03Q0?
01LI600:30/00P0G6AP03P0R92<0EeUH01<E500Q8b805QPG00lA400E5aH03Q0?01DG5P0F61L03a4@
01LI600I6aX02`d<1P0A4a80100C4a<04Q8B018B4P0A4A42010@400301<C4`0?3`l03`l?00804A4A
00@0410>00lA3@0?4@`0418=0`0A4`h04P0C5A00418=00lA300@4Pd04A<>018D3`0@4Pl04aDB014C
400>40d0418?014C400F61D04aDB00X<2@0>40d04A<@00h@30D03a4<00D04Q@?01<E400A4`h0418=
00lA300200d?2P<03a4<0P0>40/00`0=3`X030h900h@2`0200lA300300h@2`0@4P`04Q<=00@04Q<=
00H04A8<00D6000>3`T0414;01`M5`092P@200d<200;018A3@0@3`/03@`8020O6`0L6aL05A@@00l>
2P0B4@d05A@@018B3P0J71T00P0@4Q408`0J71/04A<B01`N7@1=Cdh01`T800T;2P0?4A0061XI01@F
501EEE<01PH401@D4P0000007alM01@D4P0@40h03@d;00l?3@0B4Q003Ph<00`<2P0A4Pd03@h900h?
2P0B4`h04a@?010A300<3@P02@X501@E400L7AP061TD010A300=30X03Pd;00803`h<00<040l=014@
3P0?3P`00P0B4@l01@0@3`d03`h<010?3@0=30P03`h:00803Pl:01D0418=01<E400D5Q4061dG00H;
1@021`40:2dW04E:@`0O8AT0824I02@U7@0L7AL02P/5010A2`0H6A@05QHD01/K6@04108061PF02LW
9@0A40`00P0?3PX0400@3`/030/700T8100:2@H03@`8010?2`0>3@T03@`801@C3`0B4@d04A0<01XI
5@0H5a<03`h:014@300?3PX3010?2`0500l>2P0>3@T03Pd900h=2@0?3PX00P0>3@T02P0?3PX04Q4=
014@300?3PX04Q4=014@300=30P04A0<00X91@0?3PX200`;1`0301TH500A40`040l;00803Pd900@0
4Q4=01LF4P0E510040l;2@0=30P0800?3@T04Ph;00`81@0B3P/03PX700X60`0A3@X03PX701<?300A
3@X03@T601PF4P0G5aD030`:00l?3@0410804A4?01@D4P0=3@/05QHD00X:200K6aT0410>01@D4P0=
3@/01@D301hN701dM7806QXH014A3`0J6QP04a<A0P0;2`T01@0=3@/03Ph;010?2`0?3PT03Pd90080
30/700X030/901<B400F51@020H700/92P081PL07A/L01@D4P0:2PP03`l=0P0<30X00`0820H03@d;
00d=2`0400d=2`0:00X:2P0B4Q802@T900D51@0=3@d02`/;00P8200?3`l04Q8B00l?3`803@d=1P0<
30X01P092@L04a<A010@3P0<30X04Q8@01HF50H030`:01T03@d;01<C4@0<30X00`<200X:20010@00
3@d=00h>3P0820P02`/;00l?3`0:2PX03`l?00h>3P020P804a<C01DE5@030`<04a<C00l=3P0>30d0
4@l@01DA4P0F4Q<03`/<00<040X<01/04PT<00l:2`0=30X03Pd;00l>300>3@/03@`:00h=2`0D4a40
6APF01DD4P0<2`T02`X800l>2P0?3PT030/700/:1P0=30P03@`:00h=2`0@3`d02PP9010>3`0<2P/0
0`4200d;3P0?3A800P0=2`h0400>30l03P`=00d;300=2``03@`:00`;2@0=30X03@`800T81@0J6QP0
?clo00d=3@0>3Ph03`lA014A4`00008200`;400`00P7300P7b@03`hD00`;4@0>3A<04A4C00h>400<
30`0000002<S8`0410H051<H00/:400@3aD030/@00T92`0<30h03`lA00d=3`0@41805QHH014A4`0<
30h03@d?014A4`0B4Q@0410@00l?3`0B4Q804a<C014A4P0F5QP03Ph@01@D5`020@H04a8G00`;400C
4QP01`D:00l=4P0W9BX04@lD00P62`0=2a004Q0E00l=4P0C4AH0518G0P0A3a@Dooooo`006oooool0
6`0?3PT03Pd900d<200<2`L02`X700X91`0G5Q@03`d=00`:2`0100003P`=00`:2`0B41<04Q0E014?
500?3A803@/@00/9300E4aH04Ph?00P20P0@1`L06Q0?01<:2`0>2``00P0100X82@02055?D00=00/9
2P091`P05aDF00h<3@0?3@h03P`=01LE5P0:20`04a4F02LU:P020@D02PP=018@5@0200l=4P06010>
4`0A3a@04@lD014?50092@/06QXL0P0@41801P0820X04Q8D01XJ700E5AL01@D700H6208051@F00T0
5QHH01@D5P0D51H051@F01<C5@0@41803`lA010@4P0A4A<00P0B4Q@0100C4QH0414F010A5P0A4QL4
018C600<010A5P0B4aP061TN01HG700D5AP04Q<E01TJ700?41804A8D01dN800F5aT05AHH0`0D5AL0
200E5QP041<E00hB5@0G6ah01@T<03Xn@@062Pd04ADH0P0F6Qd0100D61/061`O01PL7`0D5ah201DH
7`8051LL01004aHK01PL7`0F6Qd06AdN01PL7@0C5aP06AdN0:6TZ@0Y;3405aXO00001@0X:c00DEAI
01DH7@0D5a`05APM0P0I72405P0E61d04QLK014F6P0N8bL0724W01hR:P0F6R<09BTb01LK9@0S9c80
4ADP02<W<P0f>TD02Q4I01<J8P0B6B404aXR01LN9P0D6b<072<[01/R:P0Q:30201XQ:@805A`T0240
5QdT01LN900H7bD061lU01LN900F7B<06B4U01DM800C6ah05alR01HN8@0M9BP0620S01HN8@0G7R@0
5ahU01@K8`0M92`07B@^01/R;00N9Bl082La01/T;@0D82T09S<l01@Q:P0F8Rh04A/W01LQ;@0F82/0
5b0Y01LP9`0G8B@00P0I8B<0200N8R<061`M01LM7@0H71l082@W02P]<00F6al04AHJ0P0D6Al0:@0D
6b406R4Y01TP:P0I82X0C5=M02H]=@0M92`04APP01<J800F7B<05QhR01HN8@0D71l05ahS01lV;00Q
:3006b8[01@K9@0D6RP06R0^01/Q;@0/<Sh07bH_01dT;00F7B<051`P01DO8@0?6A/07BLZ00hG7P0<
5A`0:C8k01DN9`0<5Ah05QlX01lX<@0J8b`03aLP01<J8P0B6Al04QXN00804QXL00H05AhM014J6@0?
5aX04a/O014H7P0A620201<G800701DI8P0E6R005AXP01DJ800E6Qh051TM01<H6`02018G6P07018G
6`0E72@03A@N018I8`0A62809B`f02Xa>@02018I8@0D01@K8@0G7b805QhQ014I700F6al06QlS01LL
800B5aX051TL014F6@0B61P04ALG00hD500D6QP06AlM018H5P0>4QD07B4T00T=40031`P200dA4P06
01<G5P0>4Q4051TE01@I5@0@5A406QlK0`0?4a801@0@51<04ADD014E500<40l03A4@00803Q8A01@0
3A4@00`@3`0C5aH041@C014E500;3`h01@T801<G5P0>4Q405QXI01<G5P0>4Q404QHE01PL6`0i>cX0
9RPW00/=300C5A@051HE01<E50P04A<B0P0@4Q4200lA400701DG5P0?4A003@l>00lA400@4Q40418?
010B3P04010B3@0P014C3P0J71L04A<>00h@2`0?4@`03@l:00/=200B5140418?018D4@0:30T04A<@
01PJ5`0D5Q<06Q`I018D4@0G6AH04aDB00lA3@0>40/03@l:00h@2`0?4@`04A<>01TK5P0K7AP05QPC
01<E400@4Pd03@l:00h@2`0@4Pd200h@2`0300lA300A4`h04A<>00@03a4<00<03Q0;00lB300@4``0
100@4``0;`0B5@h04aH?014D3@0<3`P04QD>00/>1`0B4`h02``700l@2`0C50l03a0;01PI500G61<0
4Q<>00l@2`0F5a805aPC014B3@051`@02P`9018D4@041P<01`T607IhM@2CUI809RPU00H81@092`P0
6A/H00/=2P051@<03a0;01<D3`0<3@P03a0;00X;200=3PT02@X500l@2`0E5Q403Pl:00T:1@0@4@`0
30d800d>2@0B4`h04a@?00803a0;00d02``7018C3P0G61<05AHA01<D3`0:2PP030`:00d=2`0?3`d0
4A4?018B400=3@/03Ph<00<03`l=01@03Ph<00/<1`0>3`X03Q0;00lA300C5A005AXD04U>B01@EDl0
3aH?01LN5`2>UHh0d=O?034c;00;30@0414900h?2@0=3PP04A8<00<40@803@d;01H03`l=00d=2`0:
2PP040l;00h=2@0?3PX040l;00d<200;2PH03Pd900d<200N7AT02`X601<B3P0>3@T04A0<010?2`0A
40`04a8>014@300?3PX03Pd90`0?3PX00`0>3@T03@`800d<200300l>2P0800d<200?3PX04Q4=010?
2`0>3@T04Q4=014@300=30P200h=2@0;00l>2P0>3@T02PT500/:1P0@3`/04Q4=00l>2P0@3`/06APD
024P700H5a<00P0@3`/00`0C4Ph04A0<00h=2@0500h=2@03010?2`0B4@d030/7008040l;02403`h:
01<B3P0B4@d040l;00h=2@0=30P030/700d=2`0:2PP09RHT0000000B4Q003`l=00L71@0?3`d030`:
00l?3@0<30X03Ph<01DE4`020P002@T80451?`0410805ADC01/K6@0D51802`/900`<2P0?3`d0410=
00/<1`0;30H00P0;30L03P0<3@P03Ph<00D50`0:2PT010@400`<300G5aL02`/;00/;2@0B4Q002`/9
00l?3@0=3@/02@T71P0=3@/0200>3P`04Q8@00/;2@092@L03`l=00h>30061P@030`:0P0@40h0100?
3`d03Ph<00d=2`0=3@/200`<2P802`/900H030`:00l?3@0=3@/03Ph<00X:20020P0600d=2`0B01<C
4@00000051@B018B400E5A<04A4?00h>3P0@410020P800/;2`0>3Ph01`L700l?3`0A4A401@D5010@
400B4Q802@T90P0;2`/0100:2PX030X;018@4@0F51D300l;308040X<00<040/<00h=2`0>3@/0100>
3@/00`0@3`d04a8@018A3`0200l>300A014@300@3`X03`h:00d<200<2`L03@`:00T81P0>3@/03P`=
01hL7@0M6a`03P`=01<A500?3A803@/>00h<3`0?3A000P0>30d0@@0D4Q<04a8@00`;2@0A40h04A0<
00X:1`071`D02@T701PH5P0410803Ph>01@D5P0>3Q005QHH01`K800c<SL0E5=H010?500<2a003PdB
00`<3P0?3a402`/=02@T9P1DE5H05aLI01<B5`0@3a@03`hC00d=3`0:2P`03@d?014A4`0?3a40410B
01DE5`0?3a402@T;00`<3P0>3Q002`/=00l?3`0<30`0410@018B4P0>3Pl03`lA00h>400A41@01@@9
01@C600<2a406APN00X93P0H5a`0Ogj302/Z;`0:2@h02@P=018A5P0?3Q<05aHK01TH7@0D4aP04a8G
01Cooooo000Kooooo`0<00l>2@0=30L030/700`;1`0<2`P02`X801@C4@0j>CP061HG018@4@0=2``0
518C0P0B41D03@0A3a<040hB010=400?30h04Ph?01<>3`0A30`05Q0@01092P0=20T03@X;01<A4P0@
3Pl00P0?3@h08@0@3Pl04Q0A00l=3P0A3a003`d>00X82@0@3Q4040hC01PE6`0:20h040hD01LE6`0L
6R005aDK00h<4P0C41H040hD014?5@0K6Ah06a/M010@4P0=3@l04a<E00P82P0I6A/03@d?01HF600A
4A<04Q8D01LG6@0A4A<04a<E01LG6@02018B500401@D5P0@4180410B01<C5@80410B02D05ADG01HG
6P0E5Q/04a@I01@E6P0E5Q/05QLL01@E6P0C51T04Q<H01<D6@0I6Ql061TN01DF6P0J6ad05aPJ01HG
6@0Q8R@05AHH01<D5P0=3Q006a`N010@4P0L7Al051DG01@G6@0@51L051PK01HJ7@0B5QT061`O01@H
6`0G6ah05ATL01<G6P0G6ah06QhQ00<051LN00`04aHK01@G700G6Ql05ATL01@H6`0G6a`05QXK01<G
600E6AX07b8W05ULH@0O8RL201/N8`0E02T/<@0D5a`051LL01DH7@0H6b006A`Q01LJ7`0F6al05AXN
01PM8@0D6Ah05Q/Q01@I800G72<06QhW01TM9`0L82/08BD`03LkAP0J8BT05A`T00806R4Y00X06B0X
01<J8P0I82P06B0X01XQ:@0H7bL06R4Y01@K8`0G7R@0620T0P0I8BD201XQ9P1^01PP900I82@05QhQ
01HM8P0I8BD06B0U01DM800K8bH072@W01XR9P0J8BL06b8Y01LN9@0O9Rl07RD^01LN:00I82X06B8[
01TU;00J9bh062D^01LR;00K9C00628]01TR;@0I8B/06B4Y01/S9`0L92H07B8U01dO8@0P8B<071lP
01dO8`0C5aX06AdP01dR9P0F7B005A/O01HL8P0B6Al04ATN01HM9`0c>T@05ahX028Y<@1@Eel0@4M?
01PO9@0F7B<06B0U01/S9P0F7R404a/O01LO9@0K8bX06B4Y01@L9@0D6bP04aXX01`S;`0_=T808BTa
01TQ:00G7b@051dQ018K7@0?61/05AhQ01HO8`0E7R80620W018J8P0J8RX06b</01lW<@0C6bD06B4Y
01@L8`0B6R0051dQ014J700B6ad06B8Q01/U900D7B00624T01XR:00E7BD06AlW01TN9`0G7BD041HL
01@J800C6Al04APK01<I7@0I82806AlR01<I700A61/0@dYB02H]=`0L8bd04QTR01HM9@0F7B@04aXQ
018I7`0B6Ah201@L7`0F01<K7P0D6A`041DI01TN8P0F6ah04aPK00hD5@0F71`02a4A01@J6@0@5Q@0
:Bl/01LM6P0E6AX0:Bd_01@H6P0;3a005QXJ01<G5P0A5A@05AXF01<H50804AHA01l04AHB00hC4@0=
4Q404aPG014F500?51<03A8A00lD4P0@5A<04AHE00hC4P0A5QD0314?018G5P0A5Q@04QLE00hC4@0?
51<03A8A010E500>4a805AXH01@I600K81h0?D500<c>c@1VJ6L030h=01HH5`0@4Q404Q@C00@04aDD
00<04Q@C014C4P0C5A@00P0B51<0100A4a80418A00lA400B51<2014C4P0?018D4`0A4a80418?014C
3`0A4`h04aD@018D3`0@4Pd04Q@?01hP6`0<3PT0418=014C3P0B50l04A<>00803a4>00H051HC01<E
4P0L7Q/07b4N00d?300?4@h2014C4007010B3`0F61@020X701DG4P0@4Pd04aD@01XL5`03010B3@0C
01<E400B50l0418=018D3`0D5Q404A<>00d?2P0?4@`08R@O018D3`0C5A003@l:01@F4@0@4Pd03Q0;
00`?2@0A50d04QD>00lB2`02018E3P0300hA2P0?4P/03a4<00<04A@=00T05QLB00h?2P0>3`X051D@
018C3P0>3`X04Q<>00h?2P0?40/00P0D5A006P0?40/04Q@A00lA3P0O8Ah05ALD00d?300Q8b00=3Hc
00`>2`0B51403a4>010B3`0<3P/04A8=00h?2@0@4@`04Q<=010A300>3`X0414;00h?2P0C50h061TC
01<D3P0?40/03Pl:0P0=3PT0100@4@`04A8=010A300C50l3014B3@0300l@2`0@4@`0410>0080410>
0`0?3`d01`0=3@/05aLE01<C4@0>3P`04Q8@00`<2P0>3`X00`0?4@`0700B5Q005Q/E08bAR`1lPW/0
51/D01<J4`21RH80]Kbd02la:@082@404149014B300<3@L020T301<D3`0B4Q00410>00h>30061P@0
5aLE018A3@0D4`l03`h:00h=2@0?3PX03@`8010?300=30P2010?2`09018A3@0A40`0>cXf01<B3P0:
2@D030/7014@300;2PH03Pd900804A0<0`0>3@T0100?3PX03@`800l>2P0@3`/300l>2P0:00h=2@0=
30P040l;014@300>3@T040l;01@C3`0@3`/03Pd9018A3@803`h:00X04A0<010?2`0B4@d06APD01/J
5P0A40`030/700h=2@0B4@d040l;0P0>3@T0:P0?3PX04A0<00d<200>3@T04A0<01<B3P0<2`L040l;
01<B3P0>3@T010<1014@300?3PX02PT5018A3@0G5Q802PX8014A3`0Z:RP02`/901@D4P0<30X06a/I
00/;2@0E5A<01PH400l?3@0>3P`030`:00l?3@0>3P`0410>00/;2@0@40h051@B01DE4`0=3@/06ATG
00d=2`0=3PX030d800`=1`8030d800/03Pl:018B400=3@/03`l>00`<300>3Ph0>SXj01PH600A4@l0
5QHD00T91`0300`<2P0>00d=2`0?3`d03Ph<00d=2`0>3P`0410>00h>300:2PP05aLE00h>300?3`d0
2PX801DE4`0@40h300d=2`0300/;2@0@40h030`:0080410>00P03@d;01<C4@0:2PP05ADC010@3P0;
2`T03@d;00/;2@H03Ph<0P0G5aD0<00D51802@T8018B400=3@/04A4A01DE5@0@41003Ph>018B4P0:
2PX02@T900h>3P0=3@d02`/;00X:2P0>3Ph02P/;010A4@0=3Pd03@`<01DC500A3a003@X;00l;300A
3@h04@`=00h92`0>30/03@`:00l>300Y:2H04Q4?00d<2P0<2`T03@`:00l>300A40h040l=014@3P0A
40`040l:010?2`0?3PX03@`800d<2P0A40h05A@B00h<3@803@/<02H02PP9018@4`0?3A803P`?014?
4P081`T040h?00d;300A3a004Q4?00l>300F5A<05aHB018B3P0;2`P03Ph;04Y:B00W9bD03`l>00`<
3@0A4A8030`>014A500X9b/0=cLj00h>4@0=3A003PhA00`<3P0?3a4030`>01PH6P0X:2X030`>00X:
3@0Y:2`05aLJ00l?4@803Ph@00H03`lA00d=3`0=3@l030`>00l?4@0@418200`<3P0G018B500?3`l0
3Ph>010@400B4Q803`l@00d=3`0@41803`hB010?500D4aP04Q4G02d/<P0C4QL07QdR08>2Q`0m?440
51<H014@5@0@3a@02PT>01<B5`0B4AH00P0?3Q<Dooooo`006oooool01@0?3PT030/700/:1P0<2`L0
3@`900802`X8014061LF00`:2`071@H03P`=00l=3P0?3a403P`@00`:3@0;2@`030T:00h:2`091@H0
4@d>01@B5@0=2`h03`d@01@B5@0200h<3@<03@/<0P0<2P/03P0@3Pl030X;00h<3@0D4Q<05A<F028P
9P0D4AP02`P?00h;4P0Q7RD0B4E<01dJ8@0?31<04a0G0P0>2a806`0J61d061PJ00/;3@0C4aD0410B
00/;3@0C4aD05aLI00/;3@0@41805QHH00000P0C4aD03@d?01HF600G5aT030`>014A4`0F5QP04A4C
01@D5P0@41803`lA01@D5P0A4QH051DJ01DF6`0201HG700301DF6`0C51T04Q<H008051DJ01404a@I
01@E6P0C51L061TK01/L7P0H6A/09RLY020Q8`0I6Q`092DW05AEE`0U9RP05QLI014B500M82805a/N
01HJ7@0201@H6`0501DI700H71l061`O01LK7P0F6Qd00P0E6A`0200K7RD05APO01PK8P0P8bP06ahS
010C600C5aX051PK0`0F6Q/05`0E6AX05aXO01dP9@0F6Ah05aXO01XM8P0I72404QDJ01<F6`0F6Ah0
6A`Q01XM8P0K7R<06AhR01LL800F6al061dQ01TN8`0F6b406QlU01XO9P0J7RL06alZ0080720[00P0
:c8j01/R:P0P9bl061lW014H800@5al05ahV01PO9`806B0X00@06R4Y01/R:00H82<0620S0P0I8B@2
01XR9@0E01HN8@0H82<0620S01HM8`0G7R@061lU01@L7`0K8bH07RHY01`T9`0J8BH06R4W028Y;`0A
62003A@L01DL9P0M92h06R<Z01HR9P0F8bT04b0V00805R0Z01L04adW01TQ;00I82X06B0X01PO9P0H
82<06QlR028R9@0Y:R`0:2T[00X<400]<C@0Ri2C02X`=00E7B009bhd00lG7@0G82D06B8Y028Y<`17
CUP0:S4k02H]=@0202<Z<P0D01`S:@0F7B<05QhR020X:`0N9RT05alS01PQ9P0I8RT05b0X01@M9P0D
72T05Qh[01DM:00G7bX05QlW01<L8`0F7b@051dQ018J7@0D71l201HN8@0;01DM800C6ah04aXP01DL
8P0F7BH05QdW01LN:00@62402a@K014J7`0C7B000P0=5aP06P0:51<08R`[038l?P0W<3@03QLL018K
8P063AD031<K01/R:P0G7R@06B0V010G7@0I8B@05AdP01PP8P0I8B<04QXL00hF6@0B6B404QTS01DL
9P0C6R8082L_024X;P0D6b405A`R0P0G7b802@0E7B0051`O00/@4`0K82<051TL00P=400N8bH0318B
01@J6P0201XP7P0^00L=2@0:40`04QPD018F5`0A5AH05ATJ01HJ6`0@51<04ADD01LL600F6aL05a`H
01HK5@0A5Q003A8<01`R800>51801P`:00X@3P0L8R0051XH00lE4`0<4Q003A<A00L=2`0@5Q@03A<A
024W9@0C6AL03Q@B00`B400F71X0318@00D;2@0A5aD07B<Q014G5@0G7A/08BLU038d<`0F61L00040
01TK6P0K7A`0418A014C4P804Q@C00T04A<B010B4@0?4A005QPG018D4`0@4Q403a4@014C4P0B51<0
1@0A4a802@0A4a004A<?010B3@0D5Q404Q@?010B3@0C5A0061XE00h@2`02014C3P03018D3`092`H0
4A<@00804A<@00H0418?00lA3P0B51404aDB014C400B514201@F4`0I014C3`0=3`X01`T400T;1P0C
5A006Q`G01<E400>40/04A<>01HH4`0A4`h03Q0;00lA300B50l05aTD018D3`0J71L0;BlZ01<E400;
3@P08bDP00T;1P0A4`h03Q0;00d?2@0201XM5P09010C300C5Pl04aH?014D3@0@4``03Q4:00d@2@08
2`@02Pd60080414<00D04A8=01<D3`0D5A004Q<>00d>2@0200`=200900l@2`0@4@`04A8=018D4@0;
3@X05ALD00X<2@092`P04A<@00D03a4>00<03a4=00h?2@0>3`T00P0?40X2010A2`0=018C3@0A4P`0
3a0:00d>200>3`T03a0:00h?2P0@4@`03a0;00h?2P0?40/04Q<>00l@2`02014B3@0300h?2P0=3PT0
3@h900803@d;0`0>3P`01`0?3`d071`J00h>300;2`T03@d;00T91`0D51800P0A4Pd06`0>40/03@l:
010B3@0B5a403Q<=01hS7@083`P010/400lD3`0I81P04Q@<00@500092P803Pl901<D3P0M7QP04a@?
00P81P0;2`T0410>01HF500_;bd05QDA01dL600D4`l04A0<01DD4003014@300H018A3@0A40`03Pd9
00d<200`;b/03@`801lN6P0C4Ph03Pd901LF4P0?3PX02@P400/:1P0<2`L03`h:01@C3`040`005QDA
010?2`0<2`L06QTE01@C3`0?3PX03Pd90`0=30P900l>2P<040l;02H03`h:00h=2@0>3@T03`h:010?
2`0A40`06QTE018A3@061@403`h:01DD400A40`03@`8010?2`0:2@D04a8>01/J5P0>3@T03@`801@C
3`0>3@T06APD024P700920@03@d;014A3`0@40h03Ph<010@3P0=3@/06ATG00L71@0L71X03`l=01<C
4@0<30X01`L500`<2P802`/901@030`:03lo?@1?Cdd07alM00`<2P1ADDl0;Bd[00H70`0;30L030d7
00h?2P0?40/04A8=01PH5P0M7A/04a<B01<C4`0E5AD071`L010@40D03@d;00H03Ph<00/;2@0>3P`0
3Ph<00`<2P0=3@/2014A3`0500`<2P0B4Q003`l=020P7P0B4Q00100=3@/200h>300<00d=2`092@L0
3`l=00h>300;2`T05ADC00h>300C4a4030`:00/;2@0?3`d03Ph<1P0=3@/0200B4Q008b<Q01lO7@0;
2`T051@B02PX9P1aLG403@d=0P0:2PX0:@051@D02PX:02h^;P1FEUH010@4014A4@0;2`/0;bl_02HX
9`082PT04A<B00T92@0A3a0081hO00`:2`0=2@X04@d>018>3`0C3a004a4@010?3@0I61H06aXH00D4
0P0E518040l=00d<2P0>3@/040l=00/:200<2`T04A0<014@2`0A40`03`h:00d<200=30X03Pd;00l>
300?3@h03P`=00803`d>00T0518E00L52P0K6A`02PP;018@4`0M6a`03`d>014?400A40h00P0@3`d0
3`0@3`/02`/600l@2`0>3`X04A4?01@D4P0=3@/02`/;010@400:2P`03@d?00/;3@0:2P`03Ph>00l?
3`0200l?4@0800h>400=3@l03Ph@00h>400L71h05QHH030`<00;2`/300l?4@@03Ph@0P0?3a406`0=
3@l03Ph@018B500B4Q804A4A010@400?3`l04A4B018B500C4aD03`lB018A5P0=31401`H<01@C6@0@
3a@03PdB01dL8@0K6Ql03PdB01HE6P0?3Q<040lD01DD6@0>3A804Q4F00/:3`0Dooooo`006oooool0
3`0=3PP02P/600X;1P0<3@P03@h:00`<2P0B4Q000`<2014A4@020P803`l?01DE5@0@41803`hA00h<
3`0200l;300800l;2P0C4A804a4C018A5P0=3Q<03a8I00011P0@3a4200l=3P09010>3`0B41404a4B
018@4@0E4a@03`d>00h<3@0C4A80518E008030/A0P0?3Q@00`0;2Q006aXP01HE6`02010?5@0F00d<
4P0>3A<04Q4F00d=3P0>3Ph04a<C014A4@0=3@d03Ph>00d=3@0O7al0000000l?3`0:2PX04A8D00X;
3`0A4QH071dQ00T:3P0:2`l05aPL00l@50804Q<G00P0414E018C5`0>3a<04ADH01@H6`0C5aX041@G
018F6@804aLJ01805ATL01<G6P0A5AP051PK01@H6P0?4a@05a/L00lC500=4A806AdN00dA4P0B5QL0
=c/l01TM7P0A5AH01`/<01<G6@0E6A`301@H6`0301HJ7@0G6ah061`O00806AdP00P05a/N01DI700A
51/051LN01LJ8@0>4AH01@P=01TL8@804aLJ100F6Q/01P0G6Ql05APM01HI7P0A51T061/P01`O9080
5APM00L05QTN01PK800I724071lT01TN8@0H7B005a`O00806AhR00<05a`P01@I7`0H72@00P0K7bP0
1@0I7BH05QXS01HM9@0B6B407RD]00805ahV00<06B0X01PO9`0H7bL00`0I82P00`0I82H0620R01TQ
8P0201TQ8`806R8T00<05QhQ01TQ900H82<00P0G7R@0100I82H0620S01/S9@0L92H201/S9P0401`T
9`1=E5X09bhf01XQ:@809Rde03@06R<Z01TT9`0K9RX062<Y01TS;00J8Rd05QhY01PN:P0H7bT061lW
01TN9@0H7B4061dP01HG6`0H6Ad05QLK01dP9@0D5a`09R/_01PN90032Q006b@[00LA5`0?6R002QDK
00P@6P0S:S@09Rdg034h@00N9Bd07B@/01LN900D6b404aXO01TQ900J8RD05b0T01PQ9P0I8RT05b0X
01@M9P0D72T05Qh[00hF8@0C6bH05AhV00`E700A6Ql051`Q01@K8@0E7B005QhQ0P0E7Al06`0A6A/0
3aLJ014H7P0F7BH061lY01HL:00D72@06b@[01lX;@0I8bH051hO01<M7P0D7Qd05R0O018L7P0M9bX0
82T^018K8P0A620041LO01PO9`0A61h051/Q01<J800K8bH051`O014I6`0201HN800;01@L7P0A61h0
41LO01<J8P0?5Qh061lW01HM8`0>5QT04QXM01LO8P0D71h00P0A6A/07@0@5AP08bP[018G6P0@5QH0
5A/K01XP800220H0:Bl]00X@3@0@5Q804aTE04A:AP0D61T03Q8B014E500D61L041@C00hC3`0E6QH0
2Pl:01@I4`0G71H03Q<=01<H4P0E6aT0318@01DK6@0B61H010X800802Q0>01P02@l=014G5@0=4a40
51XH01DK6@0A5aD041HD00T?3@0630X05adK00X@3P0<4Q004aTG00dC4@0:40h041HD00T?3@0=3`h0
5ALF02@V9@0:30/05aTH00h@3`0A4a82018D4`05014C4P0@4Q403a4@01@H5`0?4a800P0<40l00`0@
51<04aLF00hB4@0400hB4@0300hC3`0>40`03a4<00804Q@?00@0418=01<E400E5a805aTD0P0D5Q40
0`0K7AP03Q0;018D4@02014C400>010B3`0?4@h04A<@010B3`0>40d03a4>010B3`0?4@h03Q0<02`^
:@0;3@P05QPC010B3@0:30L200h@2`0C010B3@0E5a80418=00h@2`0<3PT02P`701DG4P0>40/07R0K
01/M600B50l0828M075cKP0S9B004A<>01DG4P0E61807B8K01`Q6P0200lD3@0=010E3P0=4P/020d6
00/@2@0A5Pl04QL@01DJ4`0=3`X03a4<014C3P0@4Pd03a4<010B3@02018D3`0:010B3@0>40/03Q0;
00d?2P0B50l02`d800X<1`082PD061XE014C3PH03a4<0`0?40X3010A2`0=01HG4@0C50h03a0:00`=
1`0=3PP0414;00l@2`0@4@`03a0;00d>2@0>3`X0414<00l@2`02018C3P0300h?2P0<3@P03Pl:0080
30h;0P0=3``200h@3@0T00`>2`0B51403Q0=01@F4`082PL04a<A010A300B4@d03a0;00h?2P0@4Pd0
51HA00L9100:3`T0314;00hC3@052@@051TB010B2`0<3@D03Pl700l@2P0K71H0:b`V00l@2`061P@0
5aLE01@D4P0C4a407QhL014@300G5Q8040l;00h=2@0B4@d03`h:0`0B4@d05`0@3`/03@`800`;1`0;
2PP040l;028Q7@0B4@d02PT501DD400c<Rh05aHB01@C3`0:2@D010<000/:1P0A40`07A`H00l>2P0C
4Ph0<2l[01/J5P0?3PX03Pd900803@`800<03Pd9010?2`0B4@d00`0A40`2018A3@@03`h:100>3@T0
5P0?3PX040l;014@300L6aL05aHB00`;1`0B4@d05QDA010?2`0>3PX04a@?00L80`082@@030d800X;
1P0?40/04A8=00/<1`0310003a0;01TJ5@0<30X2014A3`80410>00L030`:00d=2`051@<061PF00h>
300?3`d03Ph<00806ATG00d03Ph<014A3`0@40h06QXH018B400H61H05ADC028R800<30X02PX7014C
3P0B5@h0418=00803Q0;00L04A<@010B3`0210<00@<200/=300B51<02@/:00D03`l=00`03Ph<00/;
2@0=3@/03@d;00`<2P0=3@/03`l=00H70P0@4@`020T400`=200L7AP200d>2@80414<00H03@h900`=
200@4@`03Ph<00l?3@0>3P`200`<2P0300l?3@0=3@/0410>008030`:0P0?3`d300d=2`<03Ph<02l0
3`l=01hN700J6QP020P601@D4P0Y:BL0E5AD00410@0;2`/02PX:00l?3`0S8b<06a/K00410@0820P0
61PH00X:2P2UYJD0DE=B000100092`X051HE00D51@00000061HG010>3`0?3@h03PX;00l;300D4Q40
8R4O0450?P0D4a402PT701PG5@0>3@/03@`:00h=2`0?3P`02`X800d<2P0A40`040l:010?2`0?3PX0
3Pd900h=2`0200l>308040h?00X03`d>00h<3@0@3Q400@0401HD5`0610L06QPK01PF5`0>30d03`d>
0`0?3P`0400?3PX04A4=00`=200;30L06AXE01`M600?3`d04A4?01HF500B4Q805QHF01<C4`0A4A<0
410@00l?3@0?3`l200h>400700d<4@0:2@h02@P=00L72@061PH02`/;01DE5@03010@4P0600l?4@0>
3Q003Ph@00l?4@0@41804A4C0P0?3a404`0B4Q@0410@00l?3`0=3@d030`<00l?400@41804a<E00l?
4P0A41D05A@I010?5@0510X03a0D00d>4P0?41@03PlC00d>4P0C51P00P0A4QH0100>3a<010D900h?
4`0>3a<Dooooo`006oooool09P0=3PP02``600X;1P0=3PT03Pl;00d=2`0@40h03Ph=01HF5P071`L0
3Ph>01LG5`0>3Q003`h@00h<3@0@30d03``<00d;300920X0414F00/@5P0P:34021@O00P@6@0?3a40
3`d>010>3`0E4a@06QPI01`J6`0<2P/05aDF01@B4`0A3a004Q0A018@4`0H5ad03PdD0P0?3QD0500=
31<03PdD00d<4`0A41L03`hE018A600D4aX040lD010@4@0B4Q803Ph>00l?3`0B4Q804A4A00l?3`0=
3@d04Q8B01@D500:2PX04Q<E0P0A4QH08`0L7B4051DI00X;3`0@4AD02@X>010A5@0D5AT0414E01DF
6P0@4aH04ADE01DI6`0B5QL03Q8B014E5`0C5aP051PH01DI6`0B5QL041@D01@H6P0H71d03a<D018F
5`0Y;Bh02`l@01DI6P0H71d041@E01HJ6`0?4a@06alP01<G600E6A/05ATL008051PK00<05ATL01LK
7P0E6A`00P0E6A`02@0F6Qd05a/N01TM800G6R404aHM01LJ8@0P8bP06A`Q014D6@0201@H6`0801DI
6P0F6Q/05QXK01LK700G6Ql041<H01XM8P0@4aP201LJ7`0301/N8`0I72405QTN008051LL00@05APM
01LL7`0G71l05a`O0`0G72001P0E6Ql05a`R01TN9@0J7RL06AdV01LK90806B0X00@08BP`01TP:00K
8RX07bH^0P0I82P301PO9`0801PO9@0I8R806B8P01TR800I8R806B8S01TQ8`0G7b8201TQ900<01LN
900H7bD06B4T01TQ900I8B<0620R01PP8`0K8bD06b<V01XR9P0G7RD061lV0P0K8RX0<P0F7b@06B@V
01/V:@0H8bL06B<Z01XR;00F7RP06R0[01XO:P0J7bP06QlV01XO8`0I7R807b0U01lQ9`0E61h07b<X
01HL8@0R:S404QXQ00hH800;5ah0B5EL014O9`0?72@04QXT018I8`0?5R007bH^020W;`0Y<3P05ahT
01PO9@0F7R8051`O01DM800E7R805AlT01LQ:00F82P04adV01<L:00F7b/051dX01@M9`0O:C405b4X
00hH7@0D72405A/Q0P0D6ah201@K701P01<J6`0@5aT04APK01PN9@0I7bT05AXV010H8P0C7B@04Q`Q
00hH700B7Ad04ahO018M6`0?6QP041/M01HP8`0E7b<05AlV01`T:`0@61l04QXR00lG7@0A6Ah05AdS
010I6`0?61/03aPJ014J6`0C71h05QlQ01@K8@0A62005A`T010G7P0E72804aXO00dE600C6ah06b<U
01HN800B6Q`04a/M01lU9P0:3Pl092T[07MmO@0U:b/04QLF01XP7P0oAD<04QPD014G4P0F71L05A/F
02HZ:@0F6QT03a<B018F5@0C61D05AXF01DJ5@0@5A004AH@010E3P0=4P/041D?00hD400B6QL01@/8
00dD4P0C6aP0318@01HM6`0<51405QhK00lG500<4a403A@B010H5@0=5A8051`I00`D4@0>5Q<04ATF
010H5@0?5Q<041PE018J5`0=51803aDC01/O7P1hNWT03a4@01TK6P082@P07b4P100D5QD00`0B51<0
4A<B00lC4P0300lC4P03010D4`0A5A@03a<B00@03a<B00@03a@@00h@300?4@`04A<>100B50l01P0F
61<06A/F00d?2P0@4Pd03a4<014C4080418?00D04Q@A01<E4P0D5Q<04Q@A014C4002018D4@0R010B
3`0=3`/06adH00L9100C5A003a4<03Xl=`0P8Qd03Q0;00lA300B50l03a4<00h@2`0A4`h03Q0;01@F
4@0;3@P06adH00@60P0<3PX04Q@?0412?@0F61<01`T401PJ5@0>4P`051TB01DJ4`0>4``0314:00dB
2`0>4``041D>00lD3@802@h700/04aPA00`>2@0?4@`04Q@?00h@2`0=3`X0418=00/=200@4Pd04A<>
00h@2`02010B3@0600X<1`0D5Q404aD@00L9100^<2/030h91P0>40/00`0@4@/0414:010A2P03010A
2P804A8;00L0414:00l@2@0@4@X04A8<010A300A4Pd03a0;00803@h900L03a0;010A300?40/0414<
018C3P0A4Pd03a0;00804A<@02@0418?00lA3P0>40d03Q0=03@f<`1QHf007R0M00`>2`0@4Pl02@T7
010?2`0C40d04Q0<014>2`0A4@`04a@?01<C3P0=3`X01`/500lB3@0>4P`07B0I01HG400D5@d04a@<
00d>200@4@/05aPB010A300A4@l03Ph<00l?3@0@40h03`l=00d<200A40`200d<2003010?2`0>3@T0
4A0<00804A0<00/040l;00l>2P0?3PX030/801XI5@081`D040l;01TH500?3PX07QdI00h=2@0201LF
4P0<01dL600`;b/04A0<00d<200<2`L04a8>01PG4`0<2`P03`h:00h=2@0=30P03Pd90`0?3PX00`0>
3@T03`h:010?2`02014@308040l;00L03`h:00h=2@0>3@T040l;014@300@3`/03`h:00<03Pd900l0
61LC020O6`0H5a<02`X600`;1`0?3`/04Q<>00l@2`0C50l03Pl:018C3`0@4@`03a0;018C3P0C50l0
0P0?40/06`0=3@/0410>00h>300=3@/04A4?018B400C4a40410>00`<2P0=3@/03`l=014A3`0:2PP0
4Q8@00`<2P0@40h04A4?00/;2@0>3Pd04A4?00`<2P0B4Q003Ph<018B3`0A4`h04A@=010B3@0200d?
2P0700lA3P0C5A803a0>01XL6`0620L03Q0?01<E500300l?3@803Ph<00<03@d;00/;2@0=3@/0100>
3P`0500<3@P051D@00d>2@0A4Pd03a0;010A300C50l05aPC01DF4@0>3`X030d8014B3@0@40h051@B
00l?3@0<30X03Ph<00/;2@092@L03@d;0P0B4Q001@0>3P`030`:00d=2`0=3@/03Ph<00803`l=00D0
410>00h>30071`D030`:014A3`0200l?3@0E00h>3P0B4Q804a<C00X:2P0>3Ph02`/;00h>3P0C4a<0
3`l?00/;2`0?3`l06ATI01hP7`0J7A`041<B00T;2P0F5QH0410@01DD500?3@h040h?00803``=00L0
40h>01`K6@0h=cD03`h<01LF500@3`d04A0>008040l=00D04Q4?00l>300A40h04a8>00l>2@0300l>
2P04010?3@0>3@/030/900l=3P<04@l@00P03Pd?02<Q9P0>30l040hA00h<3`0<2P/040h?00d;3080
3Pd;00h03`h<00l>2P0B4Pd03Pl9018C3P092PL01@H300h?2`0;2`T04Q8@00h>3P0C4a<0410@00`<
3@80414=00/03`l>00h>400?3a403`hC01lN8`0R8BH03Ph@00h>3P0<30X04A4>010@4002010@4P80
3`lA00@03Ph@00d=3`0?3a40410B0P0?3a400`0A4A<0410@014A4@0201<C4`0:018B4`0@41804Q8D
014A500<2a0051<H01lN900C4QP03PlC00l@50802@X>00P03a0D00h?4`0>3a<051DI02l`=00S92P0
3a0D00`=4ACooooo000Kooooo`0J00h?2@0<3@L02``700d>2@0>3`/03@d;00/;2@0<30/00P82018B
4P0C4a<010@400d=3`0>3@h040h?018>3@0@3@d03@d?00D62P0J7bH0DU]T0:Jd`@1<GFd03adZ00l?
4P0?3@h200h<3@0@00l=3P0@3Pl0518C020N7`0L6Q/04a4B010>3`0?3A002PT@00d<500D4a/04A0H
010?5`0510`04Q4I01<B6P804A0H00H040lG00d<4P0D51D0410@00/;2`0=3@d2018B4P0H01XJ6P1?
Cdl030`<00d=3@0U9BD030`?01PI7@0A4QH05QLK01`M8@0E5QX07b0T014B5P0B4aL04a@H00`=4@0B
4aL04ADF01@H5`0G6aX05ATH01<G5P0D61L05ATH0P0B5QD201<G5P0901@H5`0C5aL04ADF014E5P0m
@D804aLH018F5`0<41404QHG008041@E01@04ADF00dA4P0J7R007b<V01`P8`0H71l05QXM01DI700J
7R4061`O01<G6P0A5AP04QHI01HJ7@0G6R404aHM014D6`0V:Bh0=cXo01/N8`805QXM00@05ATJ01@H
6@0E6AX05QXK0P0G6Ql0100K7R<051LL01HI7P0B5AX301<F6`0A01@G700E61d05QTN01DJ7@0F6ah0
5a`O01DJ7@0E6Qh05a`P01/P900J7b@061dS01TM9P0K7bP07B4Z01LN9P0@5al00P0D6b<00`0]=3`0
>d9:01LN9P0301LN9P0;01PO9`0H7bD06R<R01XS800I8Ql06B8Q01TQ8P0H82805alR01XR9@0I8B@0
0P0H7bD0200J8RD0620R01HN800E7Al05alQ01TQ900H82<06b<V0P0R:Bl03@0@5al04aXR01LP9@0I
92D06RDW01LR900I8RP06B8[01DN9`0J8B/06alZ01/O:00J7bD00P0J7b<0A00D5ah08RD/028W;@0B
61l0DEYQ0<3;d@0P;3@06RL_01XY<01aPXX02Q/S02Le?P0T;3D09Rdg01LN:00F7BD04aXR01LN9P0J
8BL06B0V01TP9@0C6ah04QXM01@M8@0F8BD06B@Z01TT:`0F82T05Al[01<M:@0I8bd07RPb024[<`0H
8bT041/O014I7P0C61h04aPL018G6P0C6AT051XH01DK6P0F71`05a`O01TN9@0I7BP05QXV01<K9@0B
7B<04ahR01PS9P0C7al041`L01@P7P0:5Q@02QDG01<N8@0H8bL092le0419D00S;3<05AhU01<L8@0A
6Ql051dR00dG6@0C7Al051hO0P0<5QL06P0@6Q/06B0V018I8@0E72@04APN01@K8@0C6ah051`O01PP
8`0K8bD05AdO014I6`0?5aT08bTY01DK6`0A5aL0<SPh01`R8P0I7ad051XH010F500A5a<020l800T@
2@0:4@X0720O0P0E6AP0:00F6QT041@B00`A3@0:3`T041D?014F400B5a004aPA00XA2P083PX041TF
014J5`0B6aP02Q<@04=<B@0]=S<02a@A00hG500=5Q<04a`I020Y9P10BDH03AHC010I5P0B6aP02a@A
00XC401BFeP0?4E2051IEP0E7Q/05b0M01lU8`0>4Q40?Cln00H81`0S9B@05ALF01@F5@0A4a82018D
4`05014C4P0@4Q403a4@00`@3`0?4a800P0A5A@00`0>4Q40310?010D4`04010D4`0>010E4@0?4@d0
4A<>010B3@0B50l04aD@010B3@0J71L092HQ03Dg<P0N81/04A<>01DG4P0@4Pl200lA3P05014C400E
5a@05ALD01<E4P0B51400P0D5Q<0200B51405ALC00X<1`0E5a805aTD01/M601LGUT0:bdX0P0>40/0
400@4Pd03Q0;00h@2`0A4`h0418=00d?2P0A4`h05QPC00D70P0F61<04Q@?00L9100C5A003a4<01`N
6@0=4@/200/@2@0>00`A2P0=4P/03A8;00`A2P0?50d03A8;00lD3@0Q9Ql0@TM000lA300@4Pd04A<>
010B3@0>40/200lA308061XE00T0418=018D3`0@4Pd05ALB00L9100<3PT03@l:00L9100A4`h01@0=
3`X0100=40X04A8:014B2P0A4PX3010A2@0300`=1@0=3PH04A8:00804a@<00X04Q<;00l@2`0@4@`0
3a0;00d>2@0>3`X0414<00d>2@0<3@P03@h90P0@4@`03P0=3PT02P`900/=2P0<3P/03@l<00lA3P0@
4Pl02P`901`N6`000@001PP501@F4`0F5Q@040`90P0C3``05@0B3P/04`l<01<B3P0920@05QDA00l@
2`0E5Q404A<>00H90P0>3`P03a08014B2P0B4`d03a0:00d>200>3`X05QHD00@40P0F5Q@03@d;00h>
3003010?2`<04A0<01<040l;00l>2P0?3PX040l;014@300B4@d051<?00`;1`071P8051<?014@300?
3PX05A@@010?2`0D4`l02@P500P70`0F5A4040l;00804A0<00@020L300X91@0C4Ph03Pd90P0=30P0
1@0>3@T03`h:00l>2P0?3PX040l;00@04Q4=00<04A0<010?2`0@3`/00P0@3`/0?00?3PX03Pd900h=
2@0?3PX040l;014@300B4@d04a8>018A3@0<2`L03`h:018A3@0C4`h04Q<>00`=200:2`H01`P302<T
7`0?40/05QLB02PY901GF5<0@D8m01`M600B4Q004a<A00l?3@0=3@/051@B01PH5P0B4Q006ATG00L7
1@0D5180410>00P81P0E5A<06ATG00/;2@0=3@/03Ph<00d=2`030`403@d;01DE4`092@L02PX800T:
1P0=3`X03a8;010B3@0=3`X030h900h@3@0?4@h04aDC00H81`0F61L05ALF00L920803`l=00@03Ph<
00d=2`0<30X030`:0P0=3@/04@0?3`d04A4?010@3P0<30X05QLB00@50P061`803@h9010A300D5A00
2``700l@2`0@4@`03@h900h?2P0B4`h03Ph<0080410>00D03@d;00/;2@0<30X030`:010@3P0201XJ
6003010@3P0=3@/03@d;00803Ph<0`0@40h02`0;2`T03@d;014A3`0=3@/02`/900l?3@0?3`l02@T9
010@400<30`04a<C00805ADE00d05QHF00L71`0@41002`/;00h@3`0C5QD01@T800X>3@0B51<03`l?
0000000;2`/030X;008040h?00l03@/<00l=3@0>3@/030/900L6100D4a402`X8018A3`0=30X03Pd;
014@3P0=30X040l=018A3@0?3PT00`0?3PX0;@0?3P`03@`:00/:200=2``040h?014?400B41408R0S
08B2Q`0f=3L05A<F00T72P0?3@h02@L800l=3P0?3P`03Pd;00d<2P0=30P030`701<D3P0<3@P01PL2
03@e<00[;2L07AdK024Q7`0J6QX06a/K01HF5P0A4A003a0;00l@2P0>3P/03Ph>010@4P0C4QL0TI2E
07YiOP0U9BH0000000h?2P0@4@`03`l?00l?4@0200h>40803@d?01802`/=00d=3`0?3a403Ph@00d=
3`0?3a40410@014A4@0E5AD05QHF01<C500@41802`/=018B5@0?3Q<040lD01<B600<2a4200l@500:
00`=4@0>3a<0414E00/<400C51P03a0D02`]<@0R8bL030dA010A5ACooooo000Kooooo`0[010A2`0=
3PP02``700d>2@0>3P/030`:00h>300<30/01PH601DE5@0C4a<01`L7014?400C4A8051<A01HB4@0D
4A40410B00`=4@0I82L0Lh290?7oo`2dbM`0<dEC010A500@3Pl03`d>00h<3@0<2P/02`T:01/I6P0T
8R<07A/L014?400@3Pl04@lB01PG7P0@3aL03@`D00X94@0R8BT08B0X01<B6P02010?5`0M00h=5@0=
31@040lE01<C500@410051@D01HF5P0C4a<04A4A02<S8`21PH4030`<01HF5P18B4P04Q<F01HI7P0=
41D04aHK01DH7@0M82D0>Se201LJ7`0?4QL04QDJ00lB5`0B5AX04ADF014G4`0B61@00`0C6AD05P0D
6QH04QPD010F4P0D6QH061hJ01DK5`0@5QD04QPH00hD500T:RX0318B02<Y:@0<4Q8051XJ00L=3@0G
7Ad07bDU01HL700J7b007B4T01XN8@0G6ah201HJ7@0301TM800H71l05QXM008051PK00X05ATL024T
:`0A51/071lV06EXK@26RHh04aHK01PL7`0G6ah05ATJ0P0C5aP00`0D61T061/P01hQ9P0301HI7P05
01@G700B5AX04aHK01DH7@0F6Ah00P0G6Ql00`0E6Qd05adM01TN8@0201HK7P0301PM8@0K82@06b0U
00806QlU00X0724W01dR:00T:c<06R4Y01LN9P0A62006b8Z01TP:00E72@05QdU0P0G7RH0100I82P0
6B0V01XS8P0J8al201TR7`0501PQ7`0H8B00620R01XR900J8RD00P0H7bD01P0J8RD0620R01HO7`0G
7b406B4S01XR9@805alR00`051/Q01HM8`0K8RP092/a02@^<00K9RH07RPY01/U9`0K92X072<]01TP
:P0H7bT201XN9`0[01TN900H7B4061dQ02@W;`0T9c0061`U01PN9`0H8BX0=3i701LR;00?7BH04B8Z
041AF`0:72H05bP`01`T;P0L8bd06R4[020W;`0K8RX07bH^01/R:00C6R0051`P014I700C6ah05AlR
01HQ9@0J9B/06RD/01LQ:P0F82`04adY01DO:@0^>4806B<[00XE6`0I92P03aLL01<H7P0B5a/04aPK
01@J6P0201HL6P0/01LM7@0I7R406QhV01TM:00J7RX05alY00hI7`0?6Qh04A`O00@@400;5aL0520N
00dI5`0L9bT02aHI00093@0g@TP0GfQ_03<l@`0E7RD04AXO010I7P0F7b@04A/M01@N800A6a`03ALH
018L7@0B71h06R4W014H7P0C6R003A@J00hE6`0>5QT041PK014I700B6Q`04ATK00lG6@0>5aH00082
018H600N92@2010F500;00dC4@0K8Ad04QPD014G4`032P<041L@01LN5`0?4a803Q8A018F5@0B5a<0
0P0<4@d00`0W;2H041D?00`A2`0201<H4@0>018I4P0F71P01Pl<018K600D7AX06B8O09nXY@1AFUL0
7bPU01DN6`0>5a@01@h;00TB3`0`>CH200XC400@00dF4`0<5A80214>04M@C@0Y<Rl0:c@a00081@0;
51402a4?020T8`082PT0;2h]00d?3P0L7Qd020X9014C4P804Q@C00@04A<B010B4@0?4A003Q<A0`0>
518200`B40D03Q@B01<03a@@014C3`0C5A00418=018D3`0C5A003a4<00`>2@0F61<07b4L014C3P0=
3`X02`d801@F4`0A4a00418?014C400C5A804A<@00803Q0=0P0A4a006`0?4@h03@l;00X<1`0B50l0
3@l:00/=200H6QD0418=00h@2`0=3`X03a4<00d?2P0>40/03a4<014C3P092`H06Q`G018D3`0=3`X0
3Q0;00/=200L7QT051HA00T;1P0:30L04aH@018I4@0200/B2P0900hE3@0?5Ph03aH>010G3`063@D0
0`X200`C2`0G7QH041D?00803a@>00l041D?00lD3P0<4@/04aPB01hS7@0K81X03Q<=00lD3P0;40X0
6A`E0085000I71D092LP00D80@0E61401P0=40T3018C2`03014B2P0@4@T0414900<0414900X04A8:
018C2`0C50`03Pl:010A300?40/03Pl:00l@2`0B4`h03@h90P0C50l01`0>3`X03@h9014B3@0:30T0
2@h:00X?2`0;40`00P0>4`l05@0<4@d03Q<?01@I5@0G71P0314=00/;2@0?2`P04`h;01@?300C3P/0
4`l<01@@3@0;1`@04A0<00/:1P0B4@d04Q<>018C3@0>3`P04A8:018C2`0201<D3P09018C3@0=3PT0
4A4?01HF500b<S004A4?01PH5P0?3PX03Pd900803`h:0P0>3@T0300B4@d040l;00l>2P0?3PX040l;
014@300E51003Pd9010?2`0A40`02`X600T810803Pd900X04A0<00l>2P0>3@T04Q4=00P7100<2`L0
5A@B004000071P804a8>0`0=30P02@0>3@T03`h:00l>2P0@3`/04a8>01LF4P0F5A4051<?018A3@03
014@30804Q4=01d040l;00h=2@0>3@T03`h:010?2`0A40`04a8>014@300;2PH020L301<B3P0D4`l0
3`l;00`=200720<04A8=02<T7`1MGUT06AXE014B3@10@C`0j>WT0<c=b00[;2T04Q8@01@D4P0?3`d0
3@d;014A3`0201<C4@0M028R80092@L05ADC00h>300=3@/02`/900P81P051@@06a/I01`L6P0>3P`0
0P8001@D4P0@40h020P602PX9P0@40d04Q@?014F3`0@5@l0314;00T>20083@T01P/704Y>C00M8B00
10P700T=300D5QD00P0A4@l0100?3`d03Ph<00d=2`0<30X200h>300H010@3P0C4a404Q8@00`<2P0:
2`H05AHB01hO6@082@<030d700l@2P0:2`D030d700d>200>3`T0414;010A300@40h03Ph<01DE4`0C
4a4030`:01<C4@0@40h03`l=0P0H61H00`0?3`d03Ph<00d=2`0200h>300?010@3P0A4@l04A4?00T9
1`0>3P`0410>00T91`0<30X05QHD01<C4`0<30`05QHF00T92@051@D03@d=00802PX:01d04Q8B02TY
:@020P802P`;00@71P0=4A0051PG00L9200A4a806adL014A4@0>3Ph0410@00d;30091`P03`d=01@C
4@0A40h05aHD00l>300B4@l02PT700`;2@0?3P`04Q4?00h=2`0@3`d04Q4=00l>2@0300l>2P<03`h<
0P0>30d0100?3@h040h?00T82P0c<CH200X82`0S00h<3`0H5QL03`d>014?400@3`d03`h<00d<2P0<
2`L04A4<00/<1P092P@05aPC04M8@`0a<Rd04A4?01DE4`0=3@/03`l?00`<300:2PT03Pl:00d>200=
3PX03`l?014A4`0E51X08b8X02DT:@0?3a001PH401@E400A4P`03Ph>00h>400=3@l00`0<30h01P0;
2`d03Ph@014A4`0@41803`lA010@4P803`l?0P0>3Ph0100?3a003`lA00/;3@0A41@201<B5`0901<B
600B4AL04Q<G00/?4P0=4A@03Q8E00`@4`0:3Q405ATL00802PhA00<010P;00`@4`0@51L05?ooool0
01_ooooo01T03a0:00d=2@0<30T03Ph;00l?3@0<30/03`l>00h>3P0@414030`=00/;300<30d03`dA
018A4`0=3@`03@`=014@4@0>3Pl05QHI010C5`0[<CH0H6Y`05aXL00D7B804Q8A00804Q4>01L04A0>
00l>3P0?3Ph03@`=00d<3P0C4aH03PdA01dN8@0?41<03@`B01@C6P0F5A/040lE01@C600>3A<051<I
01HF6P0C4QH03`hB014@500C4QH04A8C01<D5@0201`L7@0Y014B4@0C51<03a0@01LH5P0B4a403Pl=
018C4@0>40l04A@E00h?4@0E5QX051HK01hP9P0c=3d05aPQ00hA6@0B5A/051LL01@H700?4a@04QLG
01@F5`0@51<04QLE010E4`0E6QP051XG01PN6P0F7AT06B4L01<K5@0C5aD05aTK01TK7@0A5aL0;C<c
09VPX00Y<C405QhM00hD500B61P00P0E5aT07P0G6ad04ALJ02P^<@0O92D0<STj01@J6`0F6ad041PF
01LM700I7Qd04aXI01XO7`0H7Ad06b0Q01TN7`0Q9RL0;S<d01<H600G71`05a`K01HK6P0C61P061dK
01HK6P0J7R406b8U01@J7@0H72005adP01@H70805ATM00`061`O01XM8@0H71h061`O01DJ7@0H7B40
6QlS01HM800E71l05adQ01TP8`0J8RD201`T:00;01XR9P0K92P05b0V01TS:00K9BX06B<X01/U:`0F
7R806R8X01PQ9@0H82@00P0G7R<03`0J8RD06R<R01XS8@0K92807RHW01`T9@0F7al05alQ01/S9@0I
8B@0620S01/R9P0H82<06B4S01XR900201/S9@0501TQ900G7b807bL[018I7`0F7B<00P0J8BP0FP0E
7R<0524R01HS8`0G8bD05R0S01HP9@0I8bT0620V01<K8P0@6Ad05AdQ01/R9@0D71l06R4U028Z;P0F
7R805AhS01@O900K9R/0520W01@R:@0B82L05bH^01l_=P0F92`09Bhg01TQ:P0G8BX0624Y014I800C
7B<07RL]01`T:P0H8BD05B0R01HO8P0J9BP04ahS01DP9P0G8BP04adU01DO:00F7bT0624[02lg?`0D
72D02A4H01HN900P:Bh041TK00lH6P0A6Q`04AXK01HO800C71d05QlS01TR:00G7RL05QhX01dT<00O
:3804QdS014L800C7B003APH028];00]>CL03aXI00lI6@0B6ad04ATM01`T:00g?d<07BHZ01HN8P0K
8bP051`R014I7`0F7R<04AXM00lH6P0D7Ad05b0N01`V900F7Ad041LG01@K700D6Qd051/N01LN8@80
3A@G00L03aHH01<J6`0E71/05A`J01DJ6P0>51403a@B008041DB00P051TF01<I5@0D6QH051XF00lE
3`0J81/0318=014E50804aLF02P03Q8@014F4`0B5a<0>Slj01XO6P0@5@l04aPA00lD3@0C61802@l;
00lE4P0<4a005Q/H00lF4`0J8Qh07R<P00lF4P0>5Q8051TF01<I5P0D71P03Q@A010G500C6QL03A<@
01<I5P0>5A805Q/H00`C3`0<51005adJ01PN6`0?5A803Q<@018F4`0;3P`03Q8?014E4P0C5Q@041@A
0P0D5aD02@0B5Q<04ADB014F4`0@5Q@0318@00T?3@0=4a40318@01DK6@0500hD4P0400dC4@0A5A40
4aHB010D3`804AD@00T03a8>010C3`0C5a804QDA010D3`0F6AD04aHB01DH500^<Rd00P0<40/00`0B
5A403a8>010C3`02014D400j018F4@0A51003A0;01PL5P0@4`d06ahH02DY8`0;3PP04QH@00lC3@0=
4@/03Q4;00d@2P0>4P`041@>01@H4P0?4P`071lI018E3`0C5Q0041@>00H91@0D5a402@d701@H4P0@
50h0=CXc02hd;00X;RH03Q@<018H4@0A5`l04AL@00hD3@0<4P/041H?018H40093`P041@>018F400:
3PL05ATC014E3P0>4P/0310:018F400B5Pl020`6010D3@0G6aD05AL@00/=1P0e=c00B4Y401XL5@0A
4``03@l800h@2@<0418;00h03a4:00h?200@4@X04Q<<010A2P0?40T04A8;01<D3@0B4``03a0900d>
1`0@4@X04a@>00h@2@80418<00/03Q0:00lA2`0B50h04Q@>020R700E5a4030h8014C3@0B50h061XF
014D400200lB3P0800hA3@0?4Ph030l;00hB3@0A5A003Q4=00d@300?4@d2014?3@0>01@B400A3``0
3Pd:018B3`0<30T04Q8?018C3`0E5A80:B/W010B3@0@4@/04A8=010A2`0>3`T200l@2P07018C3P0:
2`L05aLD02l_;00Q8Qh0;BhY014A3002010@2`803@d800P0410;00l?2P0@40/04A4<00l?2P0=3@P0
3`l:014A2`804Q8=01804A4<018B3@0<30L03@d:018B3`0>3P/07alL00/;200=3@X03Ph:01PH4`0_
;b/05aLB01HF4@0:2PL04Q8=00h>2P0A4@`2010@300300l?2P0>3PT0410;00804A4=00P0410;00l?
2`0?3`/0410;010@300?3`X0410;014A30<03`l:01P03Ph900d=200A4@`0410;00T91`0D50l03Ph9
01`L5`0<3@P04Q<=01@E3`0B4`d030d8024R7@0;30H04A8=02d^:@2>ShX0OGii02//9`0=3P/03Pl<
00d>2P0;30P200`=2P0D01PI5@0P8Ad03a0<01HG4`0D5A806Q/G010A3P0A4Q003a0=00h?3@092PP0
30d;00d>2`0?40d04Q<@00L81P0<3@/04A8@00d?2P0=40X200lA300P00hA300@4`l051DA010C3`0?
4`h030d;00`?2`0<3PX09bLT034b;P0>3P/04A8>00`=2@0@4@d03Pl;00h>2`0?40`04A4>010A3@0=
3PT030d8059CCP0f=c403a0:00h?2P0A4Pd030d800h?2@0=3PP03Pl:010A300>3`X2010A3`0=01TJ
600F5a@03Pl=01PI5`0?40h030d;010A3P0A4Q003a0=010A3P0=3P/02``800l@300200l@3@0>00h?
300<3@T01`P5010A3@0=3PX05AHB00l@3@0C4a802`/:00`<2`0B4Q403@d<00`<2`0>3Pd2010@3`0K
00h>3@0E5A@02PX9010B400?40h030d<00/<2`0A4Q000P<100h>3@0?3`h03Ph=010?3P0@3`l03`h=
00h>300<2`T03`l=00X:200G5Q@02PX800d=2`0<2`T061LE00/;2@0<2`T08b<P00803Ph901h03Ph:
00d=200A4@h03@d:014A3@0@40`0410=00l?300>3@`03Pd=00l>3`0@3a407QdN01<B4@0>3@d040l>
010?3`0?3P`04A0>00d=2`0=30T04A0;00/9100C4@/030X400h>2@0B4@`03@`9010?300>3P/2018B
4@0=01<C4@0@40d03`l<00d>2`0>3Pd0410A01@D5P0?3a404a8E018B4P0;2`T030`9010@3@0200l?
3P0600h>3@0>3Pl03@d>00d=3P0>3Pl0410A0P0B4Q@06P0@4180410C018B4P0?3`l0410@00h>3P0@
41404a<E018B500A41@03`hC00h=4P0?3Q@051<I018B5`0<3Q403A0C014A5@0>3a<03A0C00/;3`0?
41@03a8E00h>4`0C51P020/>5?ooool001_ooooo00h030d800`=2@0;2`T03@d;00l?3P0>3Ph03@d=
00P82@0A4A<03Ph@018A5@0>3A806aXO01dM80804a<E00T05QHG00P8200;2`/02`/:00l?3@0E5A<0
4a@?010A300B3`X00P0?3PT0IP0?3PX03@d;00d=2`0>3Q003a0D00X;3`0?41D0000500lB5`0A41H0
40lD00l>4`0@3a@0410B014A4`0G5aT07alO01DE5@0@410051@D014A4@0O82@0>S/m018C5@0E5QP0
10H501XL6`0>40l04A<@00lA3P0C5A805ALB018D3`0?40/03Ph>01<C5P0H5ad061PR01DE800B4Q`0
41<L010C6@0@4aP04AHI014E5`0O82@071dO018C5@0F5aT04QHE018G5@0Q9bD0?TA001hU8@0?61<0
41XB01TL6P0=3@l071dO018F5`0C71/0I6e/01`V9@0C7A`051XJ01@G600F5aT061PJ018D5`0V;S00
4a/M00H>400K92<04Q/J01LP7`0@6AH05QlK018K5P0@6A@0624L00hD400@5Q804QPD01DK5`0G7AT0
6AlK018H500@5Q802a4=00hD400G7AT06R0M00P@4P0=5AP051`O01@L7P0E7Al03ADG01PM800E6Qd0
61hN01XN7`805QXK0P0H7B40300F6al041PK01DM800L92L0628T01DO8@0H8R@062<U01HQ8`0I92H0
6RP[01@R9@8062HY00/062DW02D`<P0I8bD05R0R01PR8`0H8280620Q01lX9`0K8bD06B4S01/S9@02
01lW:@0801PP8P0F7R006B4S01DM7`0F7R0072@V01XR900H828201/S9@0601TQ8`0G7b405alR01dT
:P0K8RP08bX`0P0J8BT04`0I8RL052<U01LU9P0H9RL04b4R01LR900M:2X062<U00/E5`0`>S`04Q`N
010J700E7b403a/K018N7P0S;bl07BTY00XE5`0<5aT00`0B7B401P0D7bD05b8X01TT:P0I8b`0628[
01LQ:P<05b8X03/062<W01dX;00G8RD062<U01LR900O:Rh07BP^01PS:@0J92/06R<Z01TR:@0E7BD0
3QDM018I8@0C6B405ATR02/_>01MIFT07b/[01HR8P0G8b@051lQ01PS9`0A724041XS00lI8`0?6B@0
41XV018L:00B72H02QDK00hI7`0N:2X051hO00PB4@0A6aT05QlL018K6P0D6a`05Q/N01lT:00b>S`0
7bLY014I700C6R003aHL010G7`0i@4H09Rha01LP8@0D7A`041TF01DN6@0F71P04aTE01DK6@0F6ah0
4QLJ018G6`0200lD600I014F600A5aL04QPF01<I5@0H7AT05Q/G014F4P0;40`02Pl;00lD400F6aL0
2a0<018G4`0A5Q8041DA018G4`0?4a804aLF01@H5`0<40l05AXG014F4P0@5A404AHA014F4002018G
4@03018G400@5A4041DA00@041DA01H07B8N00dB3P0B5a<05a`H010E4@0?51004QLC014F4P0@5A40
2Pl;01@I5@0?51004QLC00lD400A5Q803Q<?00P=2@0;40`04AHB018G4`0=4Ph03Q<?1P0A5Q80200>
4`l0314=00dC4@0J81h05Q`J018H5P0F71X020h<0P0>518200lE4`0400hD4P0=4a4041DA010E4@80
3a@@0`0>4`l300lD40803Q<?01@020d801XO6@0:3`T0724K01@I4`0>4`d04QLA01<H4P0@5@l04QLA
014F400?50h06AhG00X?200H7AH082DN00T>1`0>4``03a@=00hC30803A8;00<03Q<<010E3P0@5@h0
100@5@h06P0>4``0314:00`A2P0;40T0314:00dB2`0?50d02Pl803Hk=00H7AH00@H000D:0`0B5a00
3Q<<00lD3@0C614041D>00dB2`0<3`P05QTB018E3P0L7aP051L@00lB2`0E61404QD>0`0A50d02@0K
7QL04A8<01PI4`0D5@l06AXD00`=1`0B4`d03a0:00h?2@0200l@2P06010A2`0A4P`03a0:010A2`0B
4`d0414;0P0?40X00`0=3PP03Pl900h?2@0200/<1P0B00d>200;3PL03A0900d@2@0;3PL030l800d@
2@0?4P/06A`E00`?200930D04aH?00`?200D5Q403@l:00lA300B50l0418=0P0A4`h04@0B50l03a4<
00d?2P0?4@`04Q@?00@60`092`P02`d:018D4@0=3`d02`d:01HH5@0D5Q<01`T600/=2P0b=3402P`9
00803a0;0P0@4@`00`0?40/03Pl:010A3005014B3@<0414;01X04A8<01@E3`0G6180414;01<D3P0G
61804Q<=00d>200@4@/04A8:00h?1`0A4PX0414;00d>200@4@/03a0;00L71@0H61H0Ti>A01PH5P0@
40h04a@?00L80`0H6A@04a@?00T:1@803Pl:00H01`P300X;1P0@4@`02@X500h?2P0@4@`300l@2`0F
010A300A4Pd0414<00l@2`0A4Pd0414<00l@2`0?40X03@h800h?2@0?40X0414;014B300;30H030d7
02TZ9025QX006Q/E00@5000<3@P04Q<=01PI4`805QLA00@04Q<=00`=1`0>3`T03@h80P0N7aT02P0B
4`d03@l:00d?2P0<3PT03@l:00h@2`0?4@`04Q@?010B3@0>40/2010B3@0400d?2P0?4@h03Q0=00d?
308030h;0`0=3``01@0>40d02`d:00/=2P0>40d03a0;00803Pl:01003@h900h?2P0?40/04A8=00h?
2P0?40/03Pl:00`=200?40/02P/602LX8`051P404A8=00d>2@0@4@`03Pl:0P0=3PT02`0>3`X0414<
014B3@092PD0?Chi014B3@0>3`X05QLB00<4000:2`H03Pl:008030d800P04A8=00h?2P0<3P/03Q0=
01@F4`0@4Pl02`d:018D4@803Q0=00H03@l<00h@3@0?4@h03a4>00d?2P0:30L2018D3`0L00d?2P0:
30L05ALB00H80`0?4@`02P`701LI50092`H04Q8@014A3`0;2`T03@d;00X:200<30X04a<A00d=2`07
1`D06QXH00/;2@0410803Ph<01DE4`0D518030`:00H6100J6QP0410>018B40<03Ph<01<03`l=014A
3`0@40h0410>00l?3@0=3@/030`:014A3`04108010@300<30@0U9B<0Ngah02DV8@000@0051D@00D6
0@0=3PT04a@?00803@h900D0414<018C3P0A4Pd0414=00l?3@0200d=2`0>00l?3@0B4Q004a<A00d=
2`0<30X0410>00/;2@0:2PP040h:01<>200D3`T04Pl8014>1`0A3PT200l>2P04018A3@0B4Q004Q8@
018B40<03Ph<00T03`l=010@3P0A4@l03`l=014A3`0B4Q003Ph<00d=2`0>3P`00P0A4Pd0100A4@l0
410>00l?3@0?3`l200h>3P80410B00l03`lA00h=4@0F5QP03Ph>014A4@0=3@d04A4B01@D5P0:2P`0
410C01@C600C4QL03`hC00`;4@0B4AH00P0A41D01@0C4QL051<H018A5P0A41D040lD00804a8G00<0
3`hC010?5?ooool04oooool001_ooooo01H030d800d=2P0<30X02`/900`<2`0?3`l04A4A00P82@0B
4Q@03@d?00`;3`0:2@h020L<00d<400>3Q005aLI01lO800B4Q802PX:00d=300>3P`03@d;0P0=3PT0
100A3PT03`h900l>2@0>3@T200d=2`1A00P82P0?41@01`P<01TJ7`0110T07B0U014@5P0@3a@03`hC
010?500@41804A4C01DE5`0L71`051@D014A4@0D51@04a<C071aM@31`/@0;2d_01@E5`0;3@`04Q@C
010B4@0B51403a4>010B3`0@4Pd03a0;00h?2P0>3Ph04Q4E01HE6`0F5R0051@N018B700?4Q/03a8H
010C600@5AP05APK02@U:@0O828051DG01LH6P0E6AP061dL05AJF02DVYH0F5mK028[9P0H8QX06QhL
00/;3@0N7b405ATJ00XC4P0@6AP05AlN01<M700D6QX051PI01HG6@0H61X05aXM01HN8@0C6ah07BDW
00/C5@0I8B804a`K014J6@0E7Q`02a@A014J5`0B6aP061hL01DK6@0D6QP02Q0>008041HD01D04QPF
01@J600B61H06R0N01HL6P0B61L09Rh`01XR9@0F7R40=cm104M?D@0K8bD05AXM01<H6`0F6ah05adM
01<I6@0B61P0;34e02X_<`0T:Bd00P0J8RD0100N9RT072HX01<M7`0E7b4201LR900>01TT9P0J:2/0
3a`R01PU:`0H9RT04alR02D`<P0G8B<05AlQ01PR8`0H82806B4S020X:P0K8bD201PP8P0301`T9P0O
9bT072@V00805alQ01@04QXL01<K7@0K8bD072@V01LO8@0I8B<0620R01HN800G7b806B4T01`S:@0N
9B/09bhd01hU;@0K8RX05b0U01TV:00M:b`062HW01HT9@806RDW00d02A@F01@N800jA4H06B4T01DM
800G8B<07BTY010L700C7al05B4Q00`G6@0R;Bl04ahR00804QdQ00H051lU01DP9P0F8BL05b4Z01DO
:00D7RL201@O9@0@01DP9P0B7B405B0T01DP8`0I92H07BPZ01HQ9@0I92X041/Q014K8@0F7bH03aPO
01LO9P0F7BD03aHN00lD7@802`lH02T0<c/o018N7P074a<031LH00lJ700A720041/P010K8@0=5b00
4Q`U01HP:P0A6bL0;SQ202lj@00B7B<04adO01/U9P0H8R406R<Q01PQ7P0C71/05A`M01HK7P0M8RH0
=Cdo020X:P0?5aX04aXP018I7`0A6200<STo01lW:P0@6AX04a`K014J5`0@6A@051XF014G4`0D6QP0
5AXM014F6@03014F6P0@014G600A5aL04ALE014G4`0F6aL05AXF014F4P0?510051TE01lT800G71P0
3Q<?01@I5@0C61@04QLC01<H50804ADD00P04QHE00`@3`0F6QP051TE010E4@0A5Q404AH@018G4@80
4aPA00`04aPD018G4`0A5Q803a@@00hC3`0=4Ph05Q/G00D:1P0A5Q804QLC01<H500A5Q8200`A3@0>
01@I5@0F6aL0;34]034f<P0=4Ph04QLC01LL600D6AD04QLC01TN6P0B5a<05Q/G01<H500?5102010E
4@0<01<H500>4`l03a@@01<H500?51002Pl;018H5P032@L0>3hl00X>30093`d06b4O0P0>518200lE
4`0300hD4P0=4a4041DA00<03a@@0P0>4`l00`0?51003Q<?00dB3P0200hC3`0700lD400B5a404AH@
010E3`19CTP0Ada601@I4`02018G4@0;010E3`0A5Q0041D?018G400I7QL02@h700dB2`0C61401P/4
00dB2`0>4``00P0=4P/00`0>4``03a@=010E3P03010E3P803a@=00`03Q<<00lD3@0A5Pl03a@=00/@
2@0<4@X051TB00/@2@0B5a0041D>01@I4P0H7AH2010E3P0N01<H4@0D6A803Q<<00`A2P072P<03a8;
01@G400B5@h04A@=00lB2`0D5a003a8;00/>1`0B5@h02`h7018E3P082@<061TC00/<1P061`403Pl9
00l@2P0A4P`0414;00h?2@0=3PP03a0:018C3@0D5@l04Q<=0`0@4@/02P0?40X03Pl9014B300D5@l0
4Q<=00l@2P0>3`T03A09010C300?4P/200hA2P0O010C300=40T03a8;00`?200>4@X04A@=00d@2@0<
3PT02@/600lA300B50l0418=014C3P0<3PT04A<>018D3`0>40/03a4<01HH4`0>40d051HC00X<2@0L
7Q/0;c4^03<e<P0C5A801@L400d?300H6QL04A<@0043000200l@2`80414<00<03a0;00h?2P0A4Pd0
0`0B4`h0600?40/03Pl:00l@2P0;30H02P/500`=1`0=3PP030d701<D3P0E5Q0061TC018C3@0=3PP0
3a0:00l@200;30@03@h600h?2@0@4@/051D?010A300>3P`030`:03@d<P8030`:00d01`P300d>2@0=
3PT01PL201lP6`0C50l01PL201LH4`0>3`X05AHA00/<1`0C50l03a0;00<03Pl:00<03a0;010A300@
4@`00`0?40/06@0>3`X03@h900d>200=3PP03a0:01<D3P0E5Q005QLA010A2`0B4`d0Ce1:00d>2007
20804a@>01XK5@0F5a402``600h?2@0?40X03Pl901@E3`0<3@L03@h800`=1`0A4P`00P0>40/01P0=
3`X03Q0;00h@2`0@4Pd04A<>00lA30<03@l:00D02P`700lA3P0>40d03Q0=00`>2`0200d?300700`>
2`0=3``03@l<00/=2P0:30T03@l<00l@2`0200h?2P0500d>2@0>3`X03a0;014B3@0=3PT00P0?40/0
5P0<3@P0414<0001000A4Pd02P/6014B3@0=3PT02``700l@2`0>3`X030d800d>2@0B4`h05AHA00X;
1P0G61<02@X500`=200@4@`02``700d>2@0@4@`200d>2@0:010A300=3PT03Q0=00d?300@4Pl03a4>
00`>2`0>40d0418?00lA3P@03@l<00`03Q0;00`>2@0F61<04aD@00d?2P0;3@P02@/6018D3`0G6A@0
10H300h@2`0:30L2014A3`0C00h>300=3@/04a<A00d=2`051@<06ATG01/K6@1@D4h0410>014A3`0:
2PP0000000@40P0M7A/00P80010@3P0?3`d0410>00d=2`0200h>300F00`<2P0:2PP030`:018B400=
3@/03Ph<018B400G5aD04a<A01XJ600?3`d020P602DU8P051P4010D001HG4P0=3PT03a0;00d>2@0?
40/030d800/<1`8030d801D03Ph;00h>300<30X030`:00h>300A4@l05ADC014A3`0?3`d04Q8@00l?
3@0=3@/04@l:01D@2P0F4@/05A8=01@A300B3`X03`h:010?2`0@4@`00P0@40h0100?3`d02`/900`<
2P0?3`d2018B4007014A3`0=3@/03`l=014A3`0?3`d03Ph<00l?3@02014B3@06014A3`0@40h0410>
00l?3`0=3@d03Ph>0`0?3a406@0>3Q406QXL00h>3P0<30`02PX:014A4P0C4aD03@d?00l?4P0B4AH0
4a8G010?5@0;2Q0040lD00h=4P0?3Q<04A0E018A5P0?3Q<05A@I014@5@0B4AH04A0E00h=4P0A41D0
5?ooool001_ooooo01H0414<00h>2`0>3P`030`:00X:2@0@41003`l?00d=3P0E5AL03@d?00d<400?
3Q<04Q4F014@500:2P`02`/=01<C500D51@03`l?00d=300=3@/03`l=0P0>3`X0100C40/04A0;010?
2P0@3`/200l?3@0@014A4`0B4aL051DI00X;4010@dP0BTeB014@5P0@3a@03`hC010?500@41804A4C
01@D5P0H61P04a<C010@408051@D00@0>S/o0821P`0C51H03PlA0P0C5A@0FP0A4a804A<@00h@3@0D
5Q<06adH01HG4`0A4@l04A4A01<B5P0E51X05AHL01DE7P0B4Q/03Q4H00lB600A51T041DH01@G6`0Q
8RH06a`N01<D5P0G61X05a/J03Dj>02W[J/0noom0:jf/@13C4L08B/S01DJ5`0F5aT061TK00dB4`0J
82004a`K018K6P0?61L04ALG018G600E5aT05aPJ01HJ7P0C6Ql04QTN01/R9`0=5AP0620R01<K7@0F
7al07RLW014J6P0K92804QXJ01TO800<4Q404AHG01@I6`0E6aX051XJ01@J6`0B61L04ALG01TN800B
61L05a`N010E600A61/03aHI01hT9`0^=CL04QTK014F6@0@5AP05Q/O01TN8P0F71d05Q/N01LL800H
7B806QlT01LO8`0D72004ATM01lY;00G8B@06R@W01hY;00M:2/06RDY01HS:@806BH/00l05bDY01LT
9`0I92L072HX01XT9P0J92D05alQ01@L7P0H82805QhP01DM800H82806R8U01/S9P0I8B<00P0H82<2
01HN8@805alR0P0I8B<01`0G7b405QhP01XR900O9bX06B0V01/R:00Q:2h00P0J8BT0F@0E7R<062DW
01`Z:`0D8R<05B8S01PS9@0B7Al05b8T02H_<P0=5QT05AdP01/S9P0H82<03aXK01PS900F8B80<cho
01LQ8`0D7R00628V01HP900F82D0628Y01LQ9`0E7bD0628[01XT;@0L9Bh06R@[01LQ:00E7bH04Q`P
01@N8P0F8B@05b4S01/U9`0?6Qd06RDZ01TT:@0H8RP072D[01HO9@0C6b407bH]01/R:@0B61l06AhU
01DI8@0K8bH072LV01DP8@0F8B8051lQ01<M8P0F82D04adT014J8`0D7RL0624/01LP:`0f?dT0>dI<
01hY;`0@6Q`04adN01HP7`0I8R004a`I010I600B6AX041DH01DJ7P0I8B<04a/M01@L7`0H7bD05A`R
014H800B6Al03ADH00lG600E7Qd04a`I014J5@0D6QH04ALC01@J600F6ah04QLJ00<04aPL00@04QLI
014G5`0@5Q@041HB0`0A5Q804P0B5a<05a`H020U8@0H7AT04AHB01DJ5P0@5A404AHB00lD400D61L0
4ADD01DI600>4Q404QLD00hC3`0E6QH051TD018G4@804AH@00D04QL@018G4`0A5Q804AHB010E4@02
00lD4004014F4P0B5a<04aPD00/@30804AHB01405Q/G010E4@0@5A402Pl;010E4@0?51008RLS01XO
6`0?51002a0<00hC3`0C61@05a`H00lD400H7AT04QLC00X?2`0300lD4008010E4@0A5Q804QLC018G
4`0A5aD09B/Y08jDTP0h?S`400hD4P803aDC00<03Q@B00dC4@0?51001@0?5100300@5A403A8>00`A
3@0=4Ph03a@@010E4@0B5a402a0:00`A2`0Z;bT0:BhX00hC3@803a@>0P0>4`d01`0=4P`03A8;014F
3`0>4``04AH?018G400;40T01@0>4``0100?50d041D>010E3P0@5@h300lD3@0500hC300C61405a`E
01<H4@0=4P/00P0?50d0400@5@h0314:010E3P0G71D08BHO010E3P0<4@X03Q<<00dB2`0:3`P03a@=
00d@2@0<3`P03a8;00T<1@0?4P/2010C300;01@G400<3`P041<<010C300B5@h04a@>00h?2@0@4@/0
4Q<=00d>200@4@/00`0B4`d3014B300J01@E3`0?40X030d700l@2P0A4P`03a0:00h?2@0A4P`05QLA
01@E3`0@4@/03Pl900d@2@0@4``03a8;00d@2@0>4@X03a8;01<F3`0=40T04A@=01DH4@0A50d03a8;
00lA300;3@P300h@2`0;01@F4@0@4Pd030h9014C3P0B50l03Q0;00d?2P0>40d0418?00/=2P0=3``0
0P0S9B801P0A4a002@/803<e<P19BdP03Q0=014C40803a0;0P0@4@`0;@0?40/03Pl:010A300B4`h0
4a@?014B3@0>3`X030d8014B300>3`T030d701DF400H6A<051D?00l@2P0A4P`04a@>00l@2P0<3@L0
3a0:00h?1`0?40P03Pl700d>200?40X04A8<014B3P0=3@/05QHD00d=300E5A<03`l=014B3@0B4`h0
3a0;00d>2@0^;bX05aPC01@E4@11@Sd061TD01LH4`082@H03a0;010A300300l@2`09010A300B4`h0
6Q/F01/L5`0B4`h03@h900l@2`0@4@/03a0:00803Pl900<04A8<01<D3P0H6A<00P0?40X03`0H6A<0
30d701`M5`0@4@/02P/701`M5`0V9b404A8<00l@2P0>3`T05QLA014B300B4`d03Pl9014B300200h@
2`0;00d?2P0<3PT03@l:00h@2`0:30L02`d800`>2@0>40/03a4<010B3@0?4@h00P0>40d0100=3``0
3Q0=00lA3P0>40d200lA3P8030h;00P03a4>00l@2`0>3`X03Pl:00d>2@0>3`X03a0;01@E4080414<
00/03Pl:00X;1P0=3PT05QLB00`=200A4Pd03@h900l@2`0>3`X04Q<>00l@2`0200/<1`0400h?2P0B
4`h030d8014B3@804a@?00T01`P3014B3@0@4@`04Q<>00h?2P0=3PT0414<00`=200A4a000P0=3``0
100?4@h0418?00/=2P0>40d300d?30803Q0=00`03Q0;00T;1P0C5A003@l:00X<1`0>40/03a4<00/=
200<3PX02P`701@F4@0@4Pd2010@3P0?018B400=3@/06a/I00d=2`0>3P`0410>00P81`0P81h01@D3
00l?3@0K6aT03@d;014A3`0820H02`/900@030`:00/03`l=018B400A4@l03@d;01<C4@0J6QP03`l=
00h>300A4@l04Q8@00l?3@02010@3P0D00`<2P0?3`d04A8=01TJ5@0;30P03@h901TJ5@0A4Pd03@h9
00/<1`0>3`X05AHA01XK5P0E5A803Ph<010@3P0A4@l03Ph<00/;2@0=3@/200h>3009018B400D5180
4A4?014?2P0D40X05Q8<01DB3@0C40/04@l:008040l;00D03a0<00l?3@0>3P`030d<014A3`04010@
3P07014A3`0?3`d03`l=00h>300<30X03Ph<01<C4@0200l@2`<03`l=0`0?3`l01@0@41804A4C014A
4`0B4AD06ATK00<03@d=00T0410A00h>400F5QP03`hB00`;400?3Q<04Q4G014@5P0@3a@00P0?3Q<0
2@0A41D04Q4F010?500A41D040lD01@C600E51T040lD014@5@0Dooooo`006oooool06@0H6A@03@h:
00l?3@0?3`d02`/:010@400:2PX03@d>00`<3P051@L03PdA00@320071P/02`/>00/;3@0<30h07alP
03@d=00>3Ph02`/:00d=2`0C4a40414<00`=200?30L00P0=30L0RP0>3@T03@d;00d=2`0@418010D9
00d>4P0E5Q/01@P=00P;400A41H040lD00l>4`0@3a@0410B014A4`0D51H04a<C014A4@0@41004Q8B
01@D500@4AD06Q/M00h?4@0@4A<03a4@00X<2`0@4Q40418?00d?300D5Q<07AlJ01PI5P0C4a4051@D
01<C500C4QL051DJ01LH7@0D51`03a8I014D6P0C5Q/041DH010C5P0I6Qh05AHH018C5@0D5AL051PG
02<X9`1PIV@0X:JR06M^JP0W<2/06R@L01dR7`0C51H01PX;01HK6`0<4Q806b4Q00XC4P0@6AP04aTI
01DJ6`0G6a`06AXL01<H700941P061lV01LN900K8RP03QHJ00lG6P0A6A`07BDX01DM7`0G7b404ATK
01DJ7@0G71l03a@G01HK7P0>4aH02@hA01<H6`0?51L08BHY01XO8P0E6Qd04AHI00P=400G71l06b0S
00lD5`0D6A`05Q/N01XO8`0I7R807R<W020U:@0K82@06AhR01hS:@0K82H05a`R01PO9@0N9B/082L]
01XS:00F7b@072DZ01hY;@0I92P05R4U010M8`0P;C<05R<Y01@Q9`0L:2d03aXN01XT9P0H8R@06B<U
01PP8P0C6ad05alQ01<K7P0F7R40620S01TQ900G7b805AdP01TQ900H82<06b<V01XR9@805AdP0P0J
8R@0100H82805alQ01/S9@0O9bX201XQ9`1M01`S:@0G7RH07B@/01PQ9P0C8280528S018P8@0C7R00
4A`N00dH6P0=5aT03ADH02/c=P0J8RD03aLJ01dU:00A6a`04Q`M02Pb<`0A6a`02A<E01`V:00J8bP0
5b0U01TR9`0L9B`06B8Y01HO9P0H8BX072D^01hW<00M9Rd0624X01DN9@0F7b@0624V01PQ9@0B71h0
5b4S01LQ900<5a/04QdQ01@N8`0@6Ah05QlT01PP9P0H7bD03QDK01PN900731803a@J00lG6@0F81l0
5AlP01<M7P0=5aP02A<E01DN900H8BP0624Z01<K9@0@62<04a/V018K9@0E82H07RT_01`W:@0?6AX0
218A00hG5@0B6aP041TH018I6P0@5AP04aPL010H6P0B6Q`04a/N00lF700>5A/04QTQ01DL8P0C6ah0
4ATJ00hG5P0?61D051dH01<I5@0A5a<051XH01HK7P0C61/051TM00804QLK00h04QLI014G5`0@5Q@0
41HB018G4`0D6AD05AXF014F4P0@5A404QLC01DJ5P0A5Q805AXF018G4`806AhJ00X05ATH00dA400D
61L041@C01<G5@0@5A405a`H01DJ5@0A5Q0041D?0P0A5Pl0:P0>4`l03a@@010E4@0@5A404AHB018G
4`0C61@02@h:00dB3P0J7a/03A8>01LL600;40`02Pl;01LL600D6AD06AhJ01PM6@12Ad<0;c@`01LL
600C61@05AXF018G4`0>4`l02a0<01<H500@5A402a0<010E4@0B5a<051TE018G4`0<4@d03Q<?018G
4`0F71X051XH02/a;`083P`061hL00dC4@803Q@B0P0?5A<00`0>51803A<A00hC3`0300lD40<041DA
00h03a@@00hC3`0?51003a@@010E4@0C61806QlI018G4@072`H03A8<018G4@0@5@l03a@>014F4080
3Q<=00<04AH@00hC300<4@X00P0;40T00`0=4P/03Q<<00lD3@0200lD3@0400hC300=4P/03Q<<010E
3P803a@=0`0=4P/04@0?50d04AH?00lD3@0;40T0314:014F3`0=4P/041D>00H;100H7AH07B8K00dB
2`0<4@X02Pl800`A2P0=4P/051TB00803a8;01804A@=018E3P0>4@X03Q4:01PK500<3`P04QD>01@G
400H6a@03a8;01DF400A4P`0414;00P90`0C50h03a0:010A2`0A4P`201@E3`05018C3@0?40X04A8<
010A2`0>3`T00`0?40X02@0@4@/04Q<=01<D3P0@4@/03a0:010A2`0<3`P03a8;00hA2P0200d@2@05
00lB2`0B5@h03Q4:00lB2`0@4``00P0=40T0600?4@`02`d800`>2@0=3`X0418=01/M600[;BP04A<>
00P:1@0<3PT02P`700d?2P0K7AX03a4>01<E4P0A4a002P`9018D4@072@H03a4>00D7100G6AH03a4>
00P:1`803a0;0P0@4@`0100?40/03Pl:00l@2`0@4@`2014B3@0W00h?2P0=3PT04a@>014B300:2`D0
3Pl9014B300:2`D03Pl900l@2P0C50h0414;00l@2P0C50h0414901@E3@0@4@T030d700d>200<3@L0
5AHC00d=2`00000010@2018B400E5A<02P/600d>2@0F5a801PL2010A300:2`L04a@?02HW8P092PD0
6a`G00/<1`082@H0414<00<03a0;00X0414<014B3@0L7AP07b0K014B3@0=3PT0414<014B300@4@/0
3Pl90P0=3PP03@0>3`T0414;010A2`051P002``900/<1P0<3@L05aPB0001000K71H0=3D_01DF400?
40X00P0A4P`0100720803a0:014B300A4P`200d?2P0300`>2@0;3@P02`d8008030h900H03@l:00lA
300>40/03Q0;010B3@0?4@h300h@3@0500lA3P0@4Pl03a4>010B3`0A4a000P0>40d0200A4a003a0;
00h?2P0>3`X03@h900h?2P0?40/05AHA0P0@4@`03P0>3`X02@X500/<1`0?40/020T601<D3`0@4@`0
3a0;00h?2P0B4`h03a0;00/<1`0:2`H02``70P0<3@P01`0@4@`00@800001000B4`h01@H100h?2P0A
4Pd00P0=3PT0200?40/02``700lA3P0>40d02`d:00h@3@0C5A803@l<0P0<3P/0400;3@X03@l<00h@
3@0?4@h03@l:00P:1@0C5A002P`700H80`0>40/02P`7028T7`0L7QT020X500D70P0<3PT200/;2@0A
00`<2P0?3`d04a<A00T91`0E5A<03@d;00T91`092@P0;Bd[03`l>P2OWid020P600l?3@071`D06a/I
00h>300C4a400`0=3@/200h>300400`<2P0A4@l05ADC01<C4@804Q8@01<04a<A01DE4`0C4a403`l=
00T91`051P<000400083000G61<04a@?00d>2@0@4@`030d800/<1`0>3`X04a@?01HG4P0C51003Ph<
008030`:00<03Ph<014A3`0A4@l00P0>3P`01P0E5A<071`J01PH5P0B4@`04Pl8018?2P804@h900`0
3Pd9010?2`0?40/03`l=00h>300=3@/02`d<01LG5@0D5180410>00d=2`0>3P`3010@3P0400d=2`0;
2`T03@d;01@D4P803Pl:0`0?3`d00`0@41004A4A014A4@02014A4`07018B500E51P05aLI00l?3`0D
51@04a<C018B4`0200d=3`06010@4`0E51T05QDJ018A5P0;2Q004A0E0P0?3Q<01@0A41D04Q4F010?
500@3a@04A0E00806QTN00<05A@I01@C6?ooool04oooool001_ooooo01`07QlJ00d=2P0?3`d04a<A
00d=300?3`l03Ph>00h>3`071`T02`/=01hN8@0100D04Q4F014@500>3Q002`/=00l?400G5aL03Ph>
014A400C4a4051@B014B3@0?40/03P/600`;1P0=30L03Pd90P0=3@/0:`0];Bl0:2T]028S9`1<CE80
6QdR01<F6`0A41H040lD00l>4`0@3a@0410B014A4`0D51H04Q8B010@400?3`l0410@01<C4`0:2`l0
824S00l@4P0=3Q005QPG01<E500A4a804A<@00d?300>40d03a4<00l@300B4Q0051@D018B4`0@4180
4Q<G01LH700E5Q/03a8G018E6P0E61d04AHI00hA5@0F5a/00P0D5AL04P0B4aD03a<B014F5@0G7A/0
>3hj02D/:00B6aH04adE01/P7@0B5QL03a<D01XN7`0@5QH05adM01<I6@0D6QX05ATJ01HJ6`805ATJ
01D08BD[00XA6`0mA4d0ADaD03Y1B@0R:C003aHL00XB5@0E7B004QXM00dE600B6Qd00@H:02L/<00B
5a/05AXN01PM8@0I7R805AXN00lD600`=CT00P0L8BD01`0A5QX06AdP01<G6P0A5AP06AhQ020U:00A
5QX00P0G7b807`0L8bT07RD[01PO9@0F7B<08RL]01dR:00E6R004APN01<J800B6Al0624V01HO900I
8RL06B@X01HQ9@0H8bL03Q/Q01LT;00A7RH041dS01HR9`0C7R80624V01LP900I8bD0620S01@L7`0G
7b80620S01TQ900H82<00`0G7b805P0I8B@05QhQ01XR9@0J8RD0620S01`T9`0I8B<06R8T01PP8P0G
7b406B4T01`T9`0I82H06R4W01`S:@0H7bL07RD]01LP9@0D7b804ahP01LR900E8282014K7@0B01/U
9`0H82<0@TY=01TN8P17C500?TI901lY:P0i@d@0FF=T01dW:00B71h072HX01TR9`0F7b@0624V01dV
;@0J8bX05AhU0`0D7BH00`0D7B@04Q/R018K8P0201PQ9P0W01DN8P0A6ad06bDW03I1A00F8BD062<W
01`V:`0E7R<08R/`01`T:@0A61h010/A02H/<P0H7B<07B8X00dE600F81l04adL01HP800H8R<04adO
01/T:00I8RL06R<Z01PQ:@0E7RL05QhY01LP:P0G8RP05R4W014L7P0C7Ah06R@S01XS8@0@6AH041TH
01<J6`0A5QT051TM00804a/M01P041PK00lF700@5ad04QTQ018I7`0@61/03QLH014J6@0D7AX04a`G
018H500?5A404QPF01DJ7@0B5aX04aPL018G6`0A5QX04ALH014G5`0A5aD04ALC010E4@0B5a<301@I
5@0<01LL600F6aL04QLC01DJ5P0A5Q80724M01hS7`0N8R4041@C018F5@0?4a804aPE0P0E6QH01@0C
61<04AH@014F400C61805AXC00803a@@0P0@5A42014F4P0A00X?2`0X;BT02@h:01HK5`0B5a<061dI
01<H500;40`04QLC00X?2`062`L00`P401TN6P0F6aL02a0<00T>2P0?51000P0<4@d03P0T:BD04aPD
00`A3@0C61@03A8>01<H500A5Q803a@@00hC3`0?510041DA010F500=4a405Q`J0P0:40h00`0@5Q@0
3Q@B00hD4P0200lE4`0500hD4P0=4a403Q<?00hC3`0?5100100@5A43014F4P8041DA01802@h801LL
5P083@L020d701XO6@0?50h041D?00hC3@0A5Q003A8<00hC3@0C61803A8;00`A2P0:3`P02a0900lD
3@0>4``3010E3P0400dB2`0;40T03A8;010E3P803a@=00<03A8;00`A2P0<4@X00P0<4@X02@0;40T0
314:00dB2`083@H05a`E04mDC@0N8a`02Pl800/@2@0200dB2`0F00/@2@0?50d041D>018G400<3`P0
4A@=00d@2@0D5a002Pd6020S701<CdP04A@=010C300B5@h04A@=00/>1`0B4`d051D?01TJ500?40X0
7AhH00`=1`<04A8<00T0414;00l@2P0?40X04aH?01@G400C5Pl03a8;00d@2@0<3`P00P0D5a001@0A
50d03Q4:010C300D5a003a8;00804A@=00`03a8;010C300A50d03Q4:010C300<3`P02`h700d@2@0>
4@X03Q0;00d?2P0?4@`200h@2`0C01LI500V:2<03a4<00/=200=3`X02P`7014C3P0E5a802@/601XL
5`0f>3<01PP501<E400E5a806A/F0084000<3PT05ALB00lA300200l@2`80414<00<03a0;00h?2P0?
40/00P0?40/3010A300302<T7P0R8ad05QLA00804Q<=00/030d7014B300A4P`051D?010A2`0>3`T0
4a@>018C2`0E5Ph03Pl700/<1P02010A2`0@00d>2@0?3`d06QXH03`l>P2?Shd071`J018C3P0N7aX0
:R/V00/<1`0O81/04A8=00`=20082@@02``701LH4`80414<00H03a0;00h?2P0>3`X03Pl:00l@2`0=
3PT201<D3`0400/<1`0@4@`0414<00d>2@803a0:0P0>3`T01P0=3PP030d701@E3`0?40X02``601hO
6@803a0:0P0A4P`00`0F5a403@h800`=1`0201<D3P0700T:100C50h051D?018C3@0?4@`03Q0;00d?
2P0300`>2@0600d?2P0?4@`0418=00d?2P0<3PT03Q0;100>40d00`0?4@h04A<@00lA3P02010B3`04
00h@3@0=3``0418?00l@2`803Pl:00T03@h900h?2P0?40/04Q<>00h?2P0?40/03Pl:00/<1`0>3`X0
0P0?40/0200A4Pd0414<00`=200=3PT0414<00l@2`0=3PT030d80P0=3PT0200@4@`030d803Hg<P09
2PD04a@?00`=200=3PT0414<0P0<3@P02P0?40/02``700/=2P0=3``02@/800/=2P0B51403a4>00h@
3@0=3``200/=2P8030h;01l03Q0;00d?2P0L7QT03a4<00L9100>40/03a4<04A6@@0m?cX05aTD00X<
1`0G6A@03@d;00/;2@0:2PP051@B00h>300;2`T04A4?01DE4`0I6AL02PX800h>300C4a40=SHd00X:
200Q8Al03Ph<010@3P0=3@/05QHD00803Ph<01`030`:00h>300@40h0410>00l?3@0<30X05QHD01PH
5P0G5aD02@T7000000071`D05QHD01PH5P0C4a007AhI01HG4P092PD02``700`=200@4@`03Pl:00d>
2@0<3@P02``700P9100<30T03`l=0P0=3@/00`0?3`d04Q8@018B4002010@3P0<01DE4`0N7Q`06ATG
018A300C40/040d800d<200>3@T040l;00h>300?3`d03a0>0P0>40l0100=3`h051@B01<C4@0A4@l2
00l?3@04014A3`0>3P`03`l=010@3P803Ph<00<0410>010A300@4@`00P0A4@l05@0B4Q004Q8B010@
400@41003`lA010@4P0B4Q@05A@H01DE5`0?3`l05ADE014A4@0@41403Ph@00T92`0B4AD061LL01LF
6`0A41D02`X@00h=4P0200d<4@0500l>4`0@3a@03PdB018A5P0A41D00P0F5AX00`0B4AH04a8Goooo
o`0Cooooo`006oooool05P1[K6L051DA00X:200D51802`/:00l?3`0=3@d030`=00`<3P0H61X0:BT/
01@C60081``0410C00h>400G5aT030`=00l?3`0820P04a<B018B400>3P`200l@2`0D014>2@0@3`X0
40l:00l>2P0?3`d04A4?05EEE`1?D5@07QlS01DF6`0>4AH030lD018A5`0F5AX03PdB01LF6`0N7R00
3Ph@01@D5P0@410200l?3`0K010@400B4Q80414E00l@4P0@4A<05QLI010B4@0E5aH03a4@014C400@
4Pl04Q@A01<E400A4Ph04A4@010@400@41404A4B018C500F5aX05aPK018F600C5QX061`P01@I700@
4aL051DI00804a@F02<04Q<E00hB4@0H7A`04ALE01TO6`0J8Qd03AHA018L500=51404aPI01DI6P0>
4Q<04QHG00lD5@0F6a/05AXK01DI6P0D61T04aLH018G600C6Al072<]018I8`0E72@07B@/01LN9P0G
7R@031<I018J7@0H82<04QXM01LO8P0Q9RX0GV=W02H[;`0201DJ7P0i014F6P0E6Qh02PlC01/P900:
3a<06AhR020U:@0D61/05APK01LK7P0G6al05QXN01@I7@0E7B405QhR01XR:@0I8BP05QhU01LN9@0O
8b/0ADYA03e2B@0D6b8082L^01HM900G82H05QlU01LP9P0H8bP06B@Y01`W;@0D8BT04b0X014N9P0D
8BP05R8X024/<@0I8RP05b0U01/T:00I8B@05QhQ01hV:@0J8RH072@X01@K800I82D07B@Y01XR9P0J
8BH05QhR01PP900I8BD06R4V01`T9`0I8B<06R8T00805QhP01806R8T01PP8`0D6b405ahT01/R:00I
82P06R4Y01DN8`0D7R805R4S01hY:`0C7R005QlR010I700B6ad05Q`P01`S9P0S:2`209RMX@0<01DM
7`0C71h07RLY01HO8@0K92L041TL01TQ9`0?5a`0620U01XR:@0I8BP05AdU0P0E7BH0>@0D72H051`T
01<K8`0C6b<05QhS01HN900C6b004Q/N01XS9P0`>cd062<V01<N8@0E7b804adP01PQ9@0A6Qh041LL
034i?@0C6Ah02PlD01@I7P0E71h05R0N018K6@0B71/05AhN014J700D72004QXO01<K8P0H82P06B4[
01LO:@0C72H051lU01<N900@6ad04adN018L6`0A6QP03QLD00dF5@0D6a`05a`O01DJ7P0C6ad03QHH
00lG6P0;4QP051/Q01LN9P0A61h051`O01<L7@0G81l04AXG014J5@02014G4`0301<I5`0E6Qd04QLJ
00804AHJ00L04QLK00dB4`0I7al05A/I01<I5@0D6AD04AHB008041DA01@04QLC020U8@0D6AD04QLC
014F4P0=4Ph04QLC01<H500M8B004aLF018F5@0?4a804QHD01<H500B5a<03a@?01HK5@0?50h0;34[
028W80<041DA01404AHB018G4`0B5a<03A8>03m4@00=4Ph0314=01HK5`0>4`l03a@@00dB3P0F6aL0
3Q<?010E4@0E6QH02@h:01DJ5P0200hC3`08010E4@0=4Ph03a@@02L/:00C61@03A8>01@I5@0;40`2
010E4@803a@@00/03Q<?00lD400<4Q003Q@B00X@3P0?5A<02Q0>00dC4@0D6QP0318@00hD4P0200lE
4`03014G5@0>4`l041DA008041DA00<051TE01PM6@0@5A400`0A5Q801@0@5A403a@@010E3`0:3`T0
4aPB00<04AH@00T041D?00lD3P0@5@l03A8<00`A2`0?50d02Pl800`A2P0?50d00P0A5Pl200lD3@05
018G400@5@h020d600/@2@0>4``00`0?50d200dB2`0<010E3P0>4``01``500hC300;40T04AH?010E
3P083@H07R<L00`@2`0B5a004AH?0P0?50d07@0>4``041D>00hC300<4@X04A@=01@G400>4@X04QD>
00d@2@0V:B80CE19024T7@0_<R/05APA00hA2P0?4P/05QLA018C3@0E5Q003Pl9018C3@0@4@/04Q<=
014B300@4@/03a0:014B300C50h04aH?008051L@00@041<<00`?200;3PL04QD>0P0@4``03`0930D0
41<<00hA2P0<3`P03a8;00d@2@0<3`P03a8;00hA2P0<3`P04QD>00hA2P0;3PL03a8;018E3P02010B
3@0G014C3P0?4@`03@l:00lA300B50l02`d800lA300D5Q402`d8018D3`0<3PP04aD?02X/9P14Ad40
3Q0:00P:100B5@l03A0:020R700Q8ad02`d700lA2`0B4`h00P0C50l01@0A4Pd03@h900/<1`0@4@`0
2P/600<0414<01h03Pl:00h?2@0B4`d02``600/<1`0;30H030d7014B300;30H0414;00l@2P0>3`T0
4Q<=01<D300A4PX03Pl700d>200@4@/04Q<=010A300>3P`04a<A038b<021PGl0:RXX018C3P051P<0
5aPC00`=20092PD200l@2`0500/<1`0B4`h020T400T:1@0@4@`00`0=3PT02@0>3`X03a0;00l@2`0@
4@`03a0;00d>2@0C50l04Q<>00`=200200h?2@0S00l@2P0>3`T03@h800l@2P0<3@L05QLA014B300=
3PP03a0:00`=1`0D5@l03Pl9014B300G61803a0:014B300C50h0414;01DF400C50h03Pl901@F4@0>
40/03a4<010B3@0;3@P03a4<00`>2@0C5A002P`8014C3P092`H03Q0<010B3`0>40d00P0?4@h02@0>
40d03a4>00lA3P0<3P/0<S@a010B3`0;3@X04A<@010A300200l@2`<03Pl:00L03a0;00/<1`0@4@`0
51D@00d>2P0j>cH05aPC00803@h901X03Pl:00d>2@0@4@`030d800l@2`0A4Pd0414<00h?2P0=3PT0
2``701@E401hNG@0@d@o010A3@0D5A003@h900l@2`0<3@P02``700d>2@0<3@P02@/800d?300<3P/0
2P`900d?3080418?02H03a4>00`>2`072@H02`d:010B3`0<3PT04A<>01XL5`0@4Pd03a4<00/=200?
4@`051HA014C3P0?4@`02P`700/=200?3`d030`:00d=2`0E5A<030`:00h>300<30X02PX800`<2P0B
4Q0030`:018B400C4a403Ph<00`<2P0?3`d0410>00X:200B4Q002`/900h>30803@d;00L05aLE01PH
5P0L71X04A4?018B400?3`d0=3@b00805QHD01403Ph<018B400;2`T04a<@01LH4`0:2`H04a@@00/<
1`0=3PT02``700l@2`0n?cX0414=01dN6@0>3`X03a0<010@3P02018B40804A4?01D0410>00d=2`0<
30X04A4?01HF500A4@l03@d:018@300A3`/03`h:010?2`0A4@h02PX800l@3@0:30X06A`L00d@400>
41003@d;00h>300A4@l00P0C4a400`0B4Q003@d;00h>3002014A3`0V010@3P0?3`d05AHA01@E400C
4a404Q8@014A3`0B4Q804A4A00d=3@0>3Q00410B00h>400C4QH051@F00l?3`0@41003@d=00d=3P0<
30h03`lA010@4`0E51T051<H00`;400D4aT030/@01PG701<Be0051<H010?500>3A804A0E010?500A
41D040lD00h=4P0@3a@Dooooo`006oooool0200b<bh0004001<C4@0A4@l09bLV018B4P0:2PX03@d>
0P0=3@l08@0B4AD061LL01TH7@0/;2l0410B01HF60092@X01`L701<C4`0A4A004A4?00l?3@0<3@P0
3@h9010=200?3PT03Pd800d<200>3P`04A4?010@4P0=3Q805AHJ01dN8`0@4aP010L<00l>500:2@h0
30/@024P9@0_;c4071`N018B500200d=3@0Z00l?3`0A4A404A4A00l@500<3@l03a0B01HG6@0F61L0
4aDD00lA400?4@h03Q0=010B3`0B50l06AXG01TI6@0D51@04Q8B01<C4`0C5A@05QPG01XK7@0E6AX0
4QHH01HJ7@0C61`04A@H01<D600A4Q@04Q<E01<D5P0A5A@03A8A010F500F71P04QXE018K5P0Q:b<0
2a8?010F5P0A5AH051PI0P0A5AH201DI6P804aLH01404aTI01@J6P0A5a`000LA01XQ:P0^=Cd0_<?;
01hU;00;4QP04ATL01@L7`0@61/04QXM01DM80093Q80;34e00dB5P0201@I7@0701LL800D6Ad01``@
01PM8@0O92P0PXN;01TM8@0201PI7@0801LJ7@0F6Ah05QTN01DJ7P0F7B<05A`R01@M900E7RD201LP
:@0K01HM9@10A4d0=3Q100hE7@0T:c<05ahV020Y<00O:2l07BH]01`W;@0K9R`06RD[028_=`0N:c<0
3a`T00XG7`0H92/07RT_01HO9P0F7bD0624V01LO8P0F7R4072@W01@K8@0L8bT092/a008051/Q0240
8BP^01/R:00I82H061lU01TP9P0H7bD05AdP01PP8`0I8B<051`N01HN800K8bH05alR01TP9P0L8bT0
61lU01TP:00J8BT05ahT01/U:0064A<02QDG010J700H82<07RHY014I700C61`04QLK00dB5P0O92P0
8RL[018J700F7R000P0I8B<0800G7b805AdP010G7@0L8bT031<I01XQ:@0C6R803aHN018I8`0E72H0
5ahX01LN9P0E72@051/S01DL8P0G7R@06R4V01PP8`0F7R4051hP01@O8@0;5QP041/M01dW:@0F8280
214C05=KGP2V[[405Q`P01LL800N8bL02a8C0P0?61D01`0?61H041TH014I6`0A6A/04QTO01@K8`0E
72D00P0E72H0600D7BH05R4W01DP9P0?6Q`04adN018L6`0?61H03aPE00lH5`0A61T04QLJ018G6`0=
5AL02a<E01PP8`0?5Q`05QdS01DL900I82H03aLJ01@L7@0I8R40624N00`E40804ALC00X04QPF01<H
6`0D6A`05AXN01/P900:3a<05adN01TO7`0<4Q0041HB0P0@5A40100F6aL04aPD00`A3@0@5A4201@I
5@0501<H500B5a<04AHB014F4P0A5A@00`0B5QD02`0B5a@04AHB01HK5`0@5A005Q/E00H;1@0P9Ah0
20d601<H500B5a<03a@@00<03Q<?01<02Pl;01@I5@0@5A404AHB00lD400N8al0<SLc01hS7`0E6QH0
2@h:00dB3P0@5A405AXF01hS7`0>4`l041DA00lD400<4@d03Q<?008041DA00D03a@@00`A3@0;40`0
3a@@010E4@0200hC3`0D01LL600N8al0728P01@J600C6AL03aDC00/A3`0=4a404aTG00P>300?5A<0
41HD00`B400@5Q@041DA018G4`0@5A403A8>014F4P0F6aL600hC3`0300lD3P0=4P`03A8<008041D?
100A5Q007`0?50h03Q<=00dB300<4@X02a0900dB2`0?50d03Q<<00L<1P083@H02Pl800T>1`0D6A80
5a`E01<H4@0;40T02Pl800`A2P0:3`P02a0900L;1P093PL07b@M00d@3017C4D0008000hC300;40T0
3A8;01@I4P0A5Pl00P0<4@X00`0=4P/03Q<<00`A2P0200`A2P8041<<0`0?4P/200hA2P0600P;100P
8a`02`h701@G400>4@X04A8<0`0@4@/02`0A4P`0414;00d>200@4@/05aPB01PI4`0E5Q003a0:00`?
200=40T03a8;00<041<<00/03Q4:01@G400>4@X05aXC00T<1P0D5a0030l800lB2`0;3PL030l8014D
3@0200hA2P8041<<0P0?4P/00`0@4``03a4<00lA300200h@2`803a4<01H06A/F020R7@0A4`h03Q0;
00X<1`0C5A0051L@01DH4@0A50d03A0900hA2P0C5Pl03Q4:01@G400J7AH0;S4Z03Hi<P0D5a002P/6
00/<1`0=3PT0414<0P0B4`h05@0A4Ph0824L01LH4`0?40/02``700P9100A4P`03Pl900`=1`0B4`d0
2``600l@2P0@4@/04a@>01@E3`0;30H02@X400d>200@4@T02P/300`=1@0200d>200=010A2`0?40/0
2`/900l?3@0C4a405aLE00d=2`0>3`X020T4010A300;30L02P/6010A3002014B3@0600h?2P0;30L0
3@h900l@2`0>3`X03@h90P0>3`X600l@2`0300h?2P0@4@/04A8<00@0414;00@03Pl900X;1@0:2`D0
3@h80`0@4@/06`0?40X03@h8010A2`0B4`d0414;01HG4@0C50h0414;00l@2P0@4@/03a0:00/=2007
2@@0>S`g00@60@0H6QD02`d800P:1@0E5a803@l:014C3P0K7AP020X500d?300Q8b007R0M00T;2002
00lA3P0600<50P0A4a007R0M00@60`0?4@h01@L40P0?40/04@0>3`X03@h900d>2@0=3PT020T4018C
3P0<3@P03@h90411?03Mg]T0:b`W01<D3`0H6A@05QLB01<D3`0<3@P051D@008061TD00X05AHA010A
300>3`X0414<00/<1`0N7aX03a0;00T:1@0H6A@03a0;0P0B4`h02@0?40/03@h900d>2@0;3@X03@l<
018D4@0@4Pl02`d:00lA3P0200h@3@05014C400H6QL0;S0]03m1?P0J71L00P0=3`X01P0I6aH03Q0;
00h@2`0?4@`03@l:00/=20<02P`700`04a<A00l?3@0C4a4051@B010@3P0C4a404A4?00`<2P0=3@/0
410>00l?3@0=3@/200l?3@803Ph<0P0=3@/01`092@L02PX800X:200>3P`04A4?01<C4@071`D00P0A
4@l08@0E5A<05aLE07inO01>CT`04A4?01@D4P071`D0410>01PI5@0@4@`07QlJ05MHD`0M7QT02``7
00d>2@0/;BP0QXN2020Q70092PD00040010@3@0>3P`04A4?018B400@40h04A4?018B400>3P`03@d;
014A3`0D5180410>00`;200200d<200<00h=2@0=3PT03@d;01HH5@092`P04aDD00hB4`0J7Ql02Ph>
00`<300=3@/03`l=0P0A4@l4018B4006010@3P0?3`d03`l=018C3P0A4Pd03`l=0P0>3P`0700?3`l0
4Q8B01<C4`0B4Q@04A4C01<C5@0D4aL04Q8D014A4@0@41004A4A00l?400;2`d04a<E01@C5`0510T0
61LL01@C6@0@3aD040lD01TH7@18Ad`04A0E01@C600?3Q<03PdB014@5@0B4AH2010?5003014@5Ooo
oooooooo01;ooooo000Kooooo`0D00l@2`0>3P/071`J00d=2`0T92<030`<00/;2`0@41403Ph@00X:
300@41<07A`Q018A5P0X:2/020P:00`<3P0>3Pl02`/;00`<300:2PT2010@3P0N00d>2@0?40/04Pl:
00l>2@0>3@P03@`8010@3P0C4a4051@F00831`0720`01@H;00d@5@0R9BX0;2/a00l>4`0B4AH04a8G
010@4P0820X04A4C00d=3@0<30`03`l?010@400?3`l03@hB00d>400>3a40414C0P0A4a80=@0>40l0
3Q0=00h@3@0@4Pl04A<>01TJ5`0J6QX04a<C00l?3P0@40h0418?01DG500K7A`061`K018F600A5AP0
4AHJ01<F6P0D5AT04Q<E01<D5P0E5QP04aLF018G5P0G7A/05Q`H018J5@0F7aX0:S@/01<L600A6QT0
4aTI01HK6`0A5AH04Q<E01DF600D5AL04ADF014F5`0B61P051XJ01PP900I82P051/R00893`16CE<0
5A`Q00XB5@0F7R4051`N00TA4`0?5aT041PJ00<03a@G00`05Q/N01@I700B5aX04QLJ00hC5P0D6A`0
7B8U07IkOP0F6Qd061TM01PI6`0H6Ad201HI7P0;01DJ800D6b<041LO00hG800D7RL06B<]01TR;00D
6b<06alX01PL9@0E72@00P0N9Bd06P0C72<05AhU01@M900B7B<051lU01HQ9`0C82P04b0Y01HS;00?
72@08B`e01@N9`0E7RD06B8X01HO900F7B<05ahT01<J800X;cD09bhd02/b>00C6R00:2le00T@5P0M
92X06R4W0P0I82H0:P0H7bD05AdP01LO8P0G7b4051`N01HN800K8bH0620S01PO9@0M92X051/Q01@K
8`0J8BT05ahT01<M800J92H09c4c03m9B`0J8RD051`O01XO8`0I7R80724U01HI7P0E61d02PlC01DM
7`0G7b406B4S01PP8P0E7B0051`O01@K8@1FGF<072<Y01HM9@0@5al06b8Z018I8`0C6R@05A`V01LN
9P8061lW0P0E7280@00I8BD0620S018J7@0;5AL04A`N01DP8P0A71h03QPJ00dG6@0B6ad04a/N02`d
=`0J8B@05AXN010E6@0@5aL041TD010I5P0@6AL04AXI018J700A6A`051`O01LN900E72<04APP01<J
900D7BH051lU018M8`0>6A/04A/L018L6`0=5aD03aPE01<L6`0@5aP0314D018G6`0=5AL02Q8D00hF
6@05318031<I014H800`=cd06B4T018K70084A004Q/H01@M600C6AD04QPD014G5@0@5AP04aPK01HK
7`0731006QlS014F600=4a<02Q0>01DK5`0B5a<2014F4P0300lD400=4Ph05a`H00H04aPD100A5A@0
300A5Q<04AHB010E4@0A5Q405a`F00hC3@0B5a401P/401<H500A5Q803a@@00dB3P80314=00D03A8>
018G4`0C61@041DA00lD400203Ll>00;01TN6P0?51002Pl;00lD400<4@d061dI01lT800@5A404QLC
014F4P0@5A400P0A5Q804P0@5A403Q<?00/@300:3`/03A8>00lD400>4`l04AHB01/P700Q9R80728P
014G5@0>5180318@00/A3`0>51803A<A00P>308041HD00P02Q0>00`B400>4`l04AHB00lD400<4@d0
3A8>010E4@H03Q<?00<03a@>00dB300=4P`01`0@5@l08`0?50h03Q<=00dB2`0<4@X03Q<<00lD3@0>
4``05AXC00dB2`0320406QlH00`A2P0?50d09BXS00`A2P093PL03A8;00`A2P0:3`P05a`E00@90P03
2040724J0:>XX@0V:b@03a@=00`A2P0=4P/051TB010E3P0<4@X03A8;00hC300=4P/03a@=008041D>
0P0>4@X300lB2`0F010C300E614020/400d@2@082`@05APA00hA2P0C50h03a0:00d>200B4`d051D?
00l@2P0B4`d05AH@01XK5@0I6Q@051D?00`=1`0=40T0314:00hC30<03a@=00P03Q<<010E3P0F6a@0
=CXc00P=1`0<4@X03A0900lB2`8030l800<041<<00hA2P0A50d00P0@4``2014D3@0300lB2`0?4@`0
3Q0;008030h902D03Q0;00lA300210004aD@00L9100=3`X05ALB01HH4`0A50d04QD>00hA2P0:3@H0
2`h7010C300:3@H04QD>00P;100R9Ah0@4<l01<F3`0D5A00414<00d>2@0>3`X0414<018C3P0>3`X0
3a0;00H70P0<3@P0414<01LH4`0D5@l03@h800X;1@0B4`d03@h80080414;01@02P/5014B300R8ad0
6Q/E00/<1P0>3`L02``4010A2@0A4P`03@h800h?2@0>3`X03@d;00l?3@0;2`T03@d;00D50`0>3`X0
20T400l@2`802``700<04a@?01DF4@0A4Pd00P0<3@P00`0A4Pd04Q<>00l@2`0300h?2P803@h90P0>
3`X200l@2`07010A300B4`d04Q<=014B300@4@/04A8<018C3@0201HG4@06018C3@0?40X03@h800`=
1`0>3`T0414;0P0=3PP200l@2P0401DF400B4`d03Pl900d>20803a0:00D030h900T;1P0d=S400040
01PJ5@0200d?2P0A010B3@0<3PT0008001DG4P0;3@P071hK02T[:00M7a`020X700h@3@0?4@h020X7
01DG50072@H01PP503Dg=00M7a`00P0>3`X200d>2@8030d802/01PL201@E400B4`h04A8=01lP6`1d
MG00:2TT010A300D5A004a@?018C3P0<3@P04a@?01DF4@0D5A004A8=00h?2P0=3PT01`P300X;1P0;
30L010D000h?2P0=3PT02P/600l@2`0A4Pd03a0;00d>2@0;30L03Q0=00/=2P0@4Pl04A<@00d?300<
3P/04aDB00lA3P092`P01@L400h@3@0I6aP030d:0080004000D051HA00H80`0G6A@03@l:00/=2002
00X<1`802`d800`0410>00d=2`0@40h0410>00h>300?3`d04a<A00l?3@0>3P`03`l=00h>300=3@/2
010@3P803`l=0P0>3P`0;`0D51805aLE00h>300;2`T03Ph<00d=2`0:2PP051@B00l?3@0>3P`01PH4
024Q7`21PGl06QXH0000000N7Q`0PH5o00X;1`0=3PT03a0;02//9`0<3@P02``7018C3P061`808b@O
00`=200L7AP04Q<>00X;1`0>3P`04Q8@01@D4P0A4@l0410>014A3`0>3P`030`:00l?3@0A4@l03`l=
00h=2P0?3PX03@h900h>300?3`d0414>00801PP700D061`M000310072``02`l?00h>3P0300h>3003
00l?3@0@40h051@B00805QHD00<03`l=00`<2P0>3P`00P0<3@P08P0<30X03@d;00h>300@41003`l?
01PH600D51H03`lA01PH6P0B4QD03`lA018B4P0D51@04Q8B00l?400=3@l030`>00X93@0K6Ql06QTN
00l>4`0100H04a8G01/J7`0B4AH03PdB01@C600C4QL03PdB014@5@0B4AH040lD00l>4`0@3a@Doooo
o`006oooool01@0:2`H03Pl;00L71@0=3@/03@d<00803`l?01l0410A00h>400<30h03@d@010?500=
3140410C00P82P0@41804A4B014A4@092@T09bLV01lO7@0@40h04Q<>00l@2`0F4`h04A0;00l>2@0A
40`051@B01HF500A4A<0414E018C5`0?41D04A@I01TL8@0J6Al030/@00803`hC00D051@F014A4`0@
41803@d=00h>3P02010@400A00l?3`0>3a<04A8D010A4`0=3Q003a4@018D4`0A4a803a4>010B3`0C
5A804aD@01<D4P0B4Q<0410@014A400C50l00P0C5A00600G6AH061`K01@H6@0>4QD04AHJ01HI7@0E
5QX051DG01HG6@0G61X04aLF01<H5P0C6AL03aDA01@K5`0:4`h06B<K018L600?61L041HF01<H600B
5AH05ADG01LG6@804Q<E03@041DF018H600B6aX05QlQ00hE6P0@61`092/`010E5`0G7b8051`N01<K
700D7Ad04a/L00lH5P0D7A`07B8T00L=300F71`04ALH01`R8@0B61P04aPJ01dS8P0J7b00D5IG00dC
4P0I7Al05aPJ01PH6P0H6Ad061TN01LJ7`0F6b406B0X01PO9`0E7bP05AlZ01DP:`0I8bh061lY01XN
:00N8R`05QdV01@K900Q:3406b@/01dV;P0L9Bd06R@/01dW;`0P:S<0E65Z0P0N:c@04P0H9Bd08blh
018L9@0G82P07BH]01@M8`0E728072<Y01HM8`0J8BP072<Z01hU;00h?dH0W:>Z02`c>P0N9B`06b8Y
01PO9P806B0W01405ahT01LO8P0F7R005QhP01TQ8`0J8R@0620S01LN900J8BL07B@Z01PO9`0G7RH0
7B@Z01<L800A6ad04adO02H_<P0201HM800701DJ7P0C5a/05ATM01DH7@0M82D061/P01LM800201LN
800701HL7`0C6Ad04ALK018H7P15Be406R0V01LL9@0201XP:00b01LL9`0E6RD051XT01HK900H7BH0
6AlW01XP9P0G7B<05A/P01@K7P0E71l05QlR014M7P0D824041/L00lI6P0G8B<04Q/M01LO8@0A6A`0
5A/N00hC5`0C61`041LF014H500A61D04QTG01<K6@0D6a`05A`O01DK7`0E6b4051XQ01@I8P0D6B<0
4a/T014L8P0@6b403aTK010J6`0B71/041TG010I5P0B6aX04QTJ018G6P0H7B403aLI018J700E7B02
014H7P0701DL900B6Al06b<V03]3A00Q:RT03aPE010I500201DK5`0:01@J600B5aX04AHI010E6@0P
9BT0MGYn020V9`0E6a/051XH00lE4@8041DA0P0A5Q801@0D6AD06QlK014F4P0A5Q804QLC00804aPD
00<051TE014E500@51<00P0?4a80300@5A804AHB00dB3P0B5a805AXD01XO6@0A5Pl05a`E018G4`0A
5Q8041DA00lD408041DA01804AHB018G4`0<4@d041DA01@I5@0[<2`082DQ010E4@0D6AD04aPD01@I
5@0;40`0314=01<H500;40`041DA014F4P0E6QH3010E4@803a@@00l03Q<?00dB3P0B5a<04aPD014F
4P0>4`l03A8>014G5@083P`02@l=00dC4@0D6QP06AlM00dC4@0:40h00P0?5A<0200<4Q003A<A00`A
3@0@5A404AHB00lD400=4Ph03Q<?1P0@5A400`0?50h03A8<00dB3002010E3`0300lD3P0>4`d03a@>
008041D?00D03a@>00hC3@0<4@X02a0900lD3@02014F3`0900`A2P0E6Q<0314:00`@2P0>4``0<SL`
04Q=AP0A5Pl0314:00804QL@0P0>4``04`0B5a002a09014F3`093@P04AH?00hC300=4P/03Q<<018G
400=4P/02a0900hC300=4P/02a0900`A2P0=4P/0314:00d@2@0>4@X00P0?4P/0200@4``04A@=00P;
1@0>4@X03a8;00`?200>4@X041<<1P0@4@/02`0R8ad07b0J01HG4@0@4@/04A8<01@F3`0A50d03a@=
010E3P0?50d03A8;0080314:00D02a09030e;P1FFe@061dF00/@2@0200lB2`803Q4:0P0?4P/0200C
5Pl03a8;00hA2P0A50d041<<00`?200?4@`03@l:0P0;3@P03`0=3`X03a4<014C3P0=3`X02@/6018D
3`0=3`X04Q@?01LJ4`0@4`/03A08010C2`0?4PX020/300hA2@0200d@200;010C2`0B5@d03a8;01DF
4@0A4Pd03a0;00d>2@0<3@P03@h906=TG`0O81/00P0C50l07@092PD04Q<>01<D3P0?40X02``6014B
300=3PP04a@>00`=1`0=3PP03Pl901`M5`0K71H03a0:00d>1P0@4@T061TA01PI4`0@4@/03Pl900`=
200A4@l04a<A00d=2`0A4@l02`/9014B3@0<3@P0414<00803a0;00D04Q<>010A300>3`X03@h9010A
300201<D3`<03a0;00<03Pl:00`=200>3`X00P0?40/200h?2P0300d>2@0>3`X03Pl9008030d700D0
3Pl9010A2`0G618061TC01<D3P02010A2`0600l@2P0@4@/04A8<014B300B4`d0414;0P0>3`T07@0=
3PP03Pl9010A2`0B4`d04A8<014C3P0<3PT03a4<02PZ9@0E5a803Q0;018D3`0D5Q403a4<01@F4@0@
4Pd051HA02`^:`0E5a@020X700lA3P0=3``03a4>01HH5@082PL05ALD00D7100e=c@0828P00H03@h9
02<0414<00`=20061`803@h900/<1`0E5Q405aPC00d>2@0A4Pd02``7014B3@0C50l030d800h?2P0=
3PT030d800d>2@0@4@`030d800h?2P0=3PT0414<018C3P082@@02``700d>2@0?40/0414<01<D3`0H
6A@06A/H00`>2`0:30T03Q0=00`>2`0200X<2@0500h@3@0D5Q<03a4>00d?300B51400P0I6aH0100>
40/02P`801LI50082PL200`>2@0>00h@2`0@4Pd04aD@01DG4P0>3P`02`/900`<2P0>3P`03@d;00`<
2P0A4@l0410>00l?3@0@40h2014A3`<03`l=01P03Ph<00d=2`0=3@/061PF01lO7@0A4@l03@d;018B
400>3P`04A4?01DE4`0;2`T05QHD02<S8@0K6aT02@T700l?3@0B4Q005QHD01LG5@0C510030d8014B
3@0D5A0200P9100800h?2P0A4Pd03@h901@E40082@D03Pl:00h>2`0?3`d2018B4006010@3P0A4@l0
4Q8@010@3P0=3@/03`l=0P0@40h0600?3``03Ph;00d>2P0=3@/03Ph<00lA3`0A51<03a8A00lC500>
4aD01``>05YNH00?4A003`l=00d=2`0<30X03@d;00l?3@0@40h051@B01DE4`0=3@/02PX800h>3080
3Pl:0`0>3P`0600?3`l0410@014A4@0B4Q@04A4C010@4P0>3A404Q8D01@D500E5AD0410@010@4@0D
51H05QHH00l?4P1=C54092<X01@D6@0E51X03PdB01`K800C4QL04Q4F00`;40803`hC0P0B4AH00`0@
3a@03`hC010?500Dooooo`006oooool06@0;30L04A4>00l?3@020P003`l>00D51@0<30`02PX;00`<
3P0?3a403PhA00/:3`0H5a`02`X>01<C5@0E5AL02PX;00/;2`0:2PX0=3@c02DU8`0>3P`04Q<>00l@
2`0C40/00P0<2`H0400?3PX0410>014A3`0>3Q0071dQ00`=4@0720d030lD00H93P0C4QP061LL010?
500920d0410B00H6200A4A<200l?3`04018B4P0@41003`l?010A5@804a@F07X0414C014C4P0D5QD0
4aDD010B3`0B51405QPE01<E400A4Q00410B010@400C4a004Q<=00lB2`0=40X04A<>01DJ5P0G6a/0
41@G010E6`0E61d051DI01@E5`0F5aT05aPJ01<G5P0@5A@06b4O014G4`0<4`l03AHA01`V7P0B71P0
31HE00hD500B5QL04a@F01LG6@0H61X051@F018C5@0A5AH03aPG014J6@0@6AX03aLJ01PP8P000P@0
6B4S00lH600;51<03QLF028[:@0I8Ql0214>02/d<@0G7A/03Q@B018H5P0;4@l05adK014G5@0C6AL0
51XH01PN700f?3X04QPF01LL6`0F5aT05aLI01TI6`0H6Ah05aXO01PL8P0H7bL06b@]01/T;`0B7RX0
3a/W01@O;00K8Bd07R8]01/O:P0E72H05ahX01<J900E7RL04a`U01@M9P0H8R/07bTb028/=@1NJg@0
7R/d01HS;00E8R/06RH_01DO:00D7BH06b@/01LP9`0D6b4061lU01TP9P0A620061lW01@K8`0A6200
ADaD00hE7@0L8b/061lW01HM9@0G7RH061lW01PO9@0H82<05AdO01PP8P0I8B<05QhQ01DM80805ahT
01007RD[01XQ:@0B6B405QdS01HO8`0K9BL0BE=E02H^<@0G720051TM01/P900M82D071lT01<F6`0I
72405aXO0P0F6ah03P0E6Qd04aPK010E6@0@5AT04QLM01DJ800>4aT05ATR01dQ:P0A5Ah06QhY01LK
9P0F6RD05QXS0P0G6b@03`0G72804QLM018G700E6Qh061dQ010I6`0F8R80?4Q802hi>@0641403QPI
010I6P0:4Q@00@T;01HL7`0201<H6`0=014G5P0A5a<04ALC01<I5P0E6aT05Q`L01PM7`0D6Ad041DK
01@H800H72D05QXS01<K8`02010K8@0W01<M7`0@6Q/03aTH01<M6`0A6QL03AHE00lF5`0B5aX041DI
00L?4@0?5aT03ADH010G7@0<4aT051/S01hU:`0B6Qd06B8S00XC4P0@6AH0624L00lE4@0@5Q804aTG
01@I700B5aX041DI00H;3`0L8BD051TK00`B4P0630X051XF010E4@0A5Q803a@@00dB3P0A5Q804QLC
00803a@@00H041DA014F4P0A5Q804QLC01DI600D61L2018F5@0P01@H5P0E6QH05Q/G01<H4`0=4P`0
4AH@00`A2`0B5a005Q/G01@I5@0A5Q8041DA00lD400>4`l02a0<018G4`0>4`l05Q/G010E4@052PH0
7B8N010E4@0A5Q802a0<00lD400>4`l02Pl;010E4@0<4@d041DA00dB3P0A5Q8200lD400300hC3`0@
5A404AHB00804QLC00H03a@@00hC3`0?51004AHB018G4`0G7A/200dC4@0400hD4P0?5A<04aTG010F
50<03A<A00<03Q@B010F500B5a<00P0B5a<00`0?51002a0<00T>2P06014F4P0300lD3P0=4P`03A8<
008041D?00<03a@>00hC3@0?50h00P0?50h08`0>4`d03A8<00`A2P0;40T03a@=018G400A5Pl03A8;
01lT7@0I7QL020d600L<1@0;40T05a`E00hC300<4@X04AH?00lD3@0<4@X01P/500T>1`0;40T02@h7
00hC300C61404QL@00dB2`0?50d04AH?00X?20093PL03a@=014F3`0B5a003Q<<0080314:0P0>4@X3
00lB2`04010C300K7QL08B@M00X=1P804aH?010051L@00d>200A4P`04a@>00h?2@0<3@L04A8<01LH
4P0E5Q004a@>010A2`0?40X03a4:00/@2@0<4@X03Q<<0`0?50d200P=1P0<010E3P0M8Q/04AH?01<H
4@0A50d03Q4:00lB2`0>4@X030l800lB2`0A50d03a8;0P0>4@X00`0=40T02`h700d?2P0400h@2`0=
00d?2P092`H02@/6010B3@0?4@`04aD@04U<A@0^<BX05aXA00T<0`0=40L04A@;00`?1P02010C2P0<
00/>1@0?4PT04aH=00L:0@0;30L03Pl:00l@2`0@4@`03a0;00h?2P0K71L061TD0`0;30L02`0@4@`0
3a0:00l@2P0?40X05QLA00l@2P0B4`d03a0:01<D3P0>3`T02``6008030d701@04A8:00T:0P0;30@0
3@h800l@2P0C50h03Pl:014A3`0C4a4030`:010@3P0;2`T03Pl:00/<1`0<3@P03Pl:00d>2@0?40/0
414<00h?2P803a0;01D03@h900`=200>3`X03a0;010A300>3`X03@h900l@2`0@4@`03a0;00h?2P0<
3@P02``700d>200>3`T03@h800h?2@0?40X04A8<018C3@0?40X00P0=3PP200l@2P0T00h?2@0A4P`0
51D?01DF400A4P`03a0:00h?2@0=3PP03Pl9014B300C50h04A8<01<E40072@@07AlJ010B3@0?4@`0
3Q0;00T;1P0>40/010H300`>2@0H6QD0418=00L91P0A4a004Q@A00d?300A4a00418?00@60`0F61D0
2@/800/=2P0=3``01`T60P0=3PT200h?2P803a0;00l020T4014B3@0D5A00414<00`=20061`80414<
00l@2`0A4Pd01`P300`=200>3`X0414<014B3@0?40/00P0<3@P01@0>3`X05AHA00`=200:2`H04a@?
00802``70P0>3`X01`0=3PT03Pl:01HG4P0N7aX07b4N010B3`0;3@X00`0=3``03@0D5Q<03a4>00`>
2`051`@00`D200L91P0=3`X030h901HH4`0U9b80DE=>01`N6@0?4@`00P0>40/01P0?4@`0418=010B
3@0@40h03`l=00d=2`80410>00<030`:00h>300?3`d00P0?3`d00`0A4@l051@B00h>300300d=2`80
30`:00D02`/9014A3`0;2`T03@d;01@D4P03018B400=00d=2`0J6QP0>c/i01`L6P0M7A/0000001HF
500000007alM00`=2@082@@04A8=00<4000200l@2`07010A300D5A00004001<D3`0G61<03Pl:00L8
1@0200`<2P802PX800<030`:010@3P0@40h0100@40h00`0>3P`03@d;010@3P02010@3P0900h@3`03
1`H0310?07UmOP0U:Rd00PL:01/O8@0?4A003`l=00<03Ph<02T03`l=00d=2`0@40h04A4?00d=2`0<
30X03`l=014B3@0B4`h04Q8@010@3P0?3`d03@d=01DE5@0=3@d04Q8D01HF600<30h0410C01HF600D
51@04A4A00d=3@0A4A805aLI018B500L71l07QdR01LF6`0Q82D081lU01@C60061@X06APM014@5@0@
3a@02PT>010?500C4QL04Q4F010?500200h=4QCooooo000Kooooo`0V01HG4P0:2`L06a/I01<C4@0=
3@`02`/;00d=3@0=3@h030`>00/;3@0=3A003`hC00d<4@0;2`h04A4C00/;3@0;2``03@d=00T92@0G
5aH05ADC00`<2P0?40/04a@?014>2@0;2PD030/6010?2`0?3`d03Ph<014A4`14ADT0>3Tm01LH7@0;
3Q<020/@00T83P0?3Q<2010?500901PH6P0@41804Q8D010@400A4A404a<C014A4@0@41004A8F00<0
4Q<E01H04aDD01@F5@0C5A@03a4>018D4@0F61D04Q@?010A400A4A<03`l?00l@300?40X030l800`?
1`0@4Pd051TE01TM7@0@51L03A8H01<F6P0D5AT051DG0P0F5aT08@0B5QD03A8@00hD4P0D6QH0<cXf
014J5@0=5`l04A/G00dG5P0B61P061/L01DF600E5AL061HI01HF600D5AL04ADF00lH5`0A6QT041TJ
01<K7@0C6A/072@V01`U900>5aH02a@C010I5P0N9b<05AhI00`E400W<2/06R0L01`R7P0201DK5`1;
00hD400?5A405A/G00dC3`0B61@000H200hD400B5aD05aLI01PF6@0I6A/061TN01LJ7`0H72805QdU
01LP:@0I8Rd05R8^01DQ;`0C82d06b4]01dQ;00K7bX05A`V01XQ:`0N9Bl07bPa01PQ:P0J8b`08B/d
02Tc?00X<S/06RL`01PU;`0H9Bh05b@]01TU;P0F82T051dV01dV;P0Q:S406R4Y01<J8P0I82P06R4Y
01/R:P0L8b/04aXR01TP:00M92`06B0X01HM9@0D6b<05A`T01TP:00H7bD06R8U01DM7`0I8B<06R8T
01@L7P0D71l05A`R01LN900C6R007B@/01lV;P0C6R0061lT00dE600e?D0051`O03Hk?`0N8bL04QLK
008051LL00L03A0E01DF6`0?4QL05a`O01HK7P0E6Qd051TL00804AHJ00L07b@Z02T^=00I7R@04aLP
01@H8@0H72D05a/V00805QXU01805a/T01PL9@0H72D04aPN00hC6@0K82D08RL[01/P900@6A/0:3@d
05aXJ016DE402aDF01HP8@0I8R<07BDW024Y:`0=51H201PM800K010F5@0B61@04QPD01@J5`0F71X0
61hN01LL7P0C61`04QLM01<H7P0E6R005QXS01DM9P0A72804QdS01HQ8`0@6Q/03ALF018L6P0A6QL0
3AHE00dD5@0@5AP041DI01TQ8`0N9RP041PK008051/Q00L0:c8j00dD6P063Q403aLH01@M700C71T0
214<00804ALC00X04QPF018G6P0A5QT04AHJ01TN8P0<4AD06b0R01HL700630X03aDA0P0B5a<0100:
3`/02@h:018G4`0H7AT200hC3`@03a@@00l05ATH018F5@0@51<041@C018G500E6QH061dI01<H4`0=
4P`041D?01HK5@0D6A804aPD018G4`0@5A40100?5102014F4P0A01DJ5P0?51007R<O01XO6`0:3`/0
3A8>00/@300B5a<04aPD00/@300B5a<03a@@01<H500;40`03Q<?018G4`0A5Q800P0?51000`0@5A40
4AHB010E4@0200hC3`09018G4`0D6AD05AXF01<I5`0<4Q003A<A00/A3`083P`02Q0>008041HD00X0
3A<A00`B400=4a403A<A018G4`0A5Q8041DA00lD400<4@d02Pl;1P0?51000`0?50h03A8<00dB3003
010E3`<03a@>01h03Q<=00`A2`0>4`d03a@=00hC300?50d041D>00lD3@0<4@X00@H000@90P0I7QL0
3Q<<00D:0`0<4@X02a0900`A2P0@5@h0314:00X?200<4@X051TB01TN5`0:3`P061dF00D:0`0;40T0
3A8;00lD3@0@5@h200T>1`0600dB2`0D6A806AhG01<H4@0>4``04AH?0P0@4``300lB2`0?00hA2P0Y
;2D0<SD^010C300H6a@04A@=018E3P0?40X0414;014B300@4@/03a0:014B300=3PP03Pl900804A8<
00D0414;00d?2@0:3`P02Q4900`C2`0300dD300800hE3@0R:B401`h60007000;4PX03A8;018E3P0=
40T200lB2`0600/>1`0@4``041<<014D3@0@4``03Q4:0P0=40T03P0<3PT03a4<014C3P0A4`h03a4<
00`>2@0B50l051HA010B3@0:30L01@L402P[900R9Ah05AP?0P0;3PD02@0=40L030l600`?1P0?4PT0
20/200`?1P0D5`h02@`3014B3@02018C3P06014B3@0>3`X03@h900/<2@0I6QD04Q<>0P0=3PT06P0;
30L03a0:00`=1`0B4`d08B8L01<D3P0>3`T04A8<00L80P0>3`T05QLA014B300=3PP04A8:00T:0P0;
30@030d700d>200A4P`03a0;00h>300@40h02`/9010@3P0:2PP03Pl:0P0<3@P200h?2P0;00l@2`0@
4@`03@h900h?2P0?40/03@h900/<1`0=3PT03a0;010A300?40/0100>3`X03P0=3PT030d800`=200=
3PT03Pl900l@2P0@4@/04A8<018C3@0D5@l04a@>014B300@4@/03Pl90P0<3@L01`0@4@/04Q<=018C
3@0?40X04A8<01LH4P0C50h00P0>3`T01`0?40X04A8<014C3P0B50l05aTD0001000:30L00P0@4Pd0
4@041P40;c4/00H80`0>40/030h900D7100@4Pl051HC00h@3@0@4Pl04A<@00D7100L7Q/04aDB01HH
5@0@4Pl05ALD00803Pl:01<03a0;010A300@4@`04A8=01/L5`0=3PT02P/600/<1`0F5a805AHA010A
300<3@P0414<00/<1`0@4@`02@X500h?2P0@4@`03a0;008030d80P0=3PT01`0A4Pd03a0;01/L5`0@
4@`020T400/<1`0<3@P00P0;30L00`0?40/05AHA01HH5@0200d?300500h@3@0<3P/030h;00h@3@0;
3@X00P0>40d02P0A4a005QPE014C3P051`80418=01@F4@0V:2<01`T400lA300>40/200d?2P0?00h@
2`0?4@`03@d;00d=2`092@L03@d;00h>30092@L03Ph<010@3P0?3`d03@d;00l?3@0B4Q003`l=00<0
3Ph<0P0=3@/01@0?3`d03Ph<00d=2`0=3@/03Ph<00803`l=01X0410>01@D4P0?3`d092@R00L71@0E
5A<08b<Q00X:200<30X00`<100P81P0=3PT08R<N00d>2@0S91l051D@014B3@0g>3<06Q/F00h?2P0<
3@P02``700l@300<30X03@d;00`<2P802`/900@03@d;00h>300@40h0410>0`0>3P`03@0@40h051@B
01DG5P0C5A@04A<B00lC500/<340]KVj0497BP0F6ah01`X<00d?3P0?3`d0100@40h3014A3`<03`l=
00h0414<014B3@0A4@l04A4?00l?3@0=3@d04a<C014A4@0A4A<04Q8D014A4`0C4aH05ADG018B4P80
3`l?01804a<D01<C5@071`T04A4D00@3200F5AX051<I00d<4P0?3Q<020L<01@C600?3Q<04A0E00h=
4P0@3a@04a8G018A5P0@3a@200h=4QCooooo000Kooooo`0I09>AU@0Z:B`0:RX[03`m?0093@T03Q4=
00`@2`0@51003@h=00L7200>3@l03`dA00h=4P0W9RX05ADH00811@0>3Q003@d>00l?400<30d04Q8A
00`<2`0>3Pd03Ph;014@300200h=2P0I010@3@0?3`d03Ph<00d=3@0H6AX061PI01HG6@0?418051@F
01@C5`0@3a<04A4B010@4P0B4Q@0410B018B500?3a404A4B01DD600C4QH0410C014B5P0A4Q@04Q<E
01<D5@0201<E500f010B400>40d03Q0=01<E4@0C5A0041<A014D4`0?4Q404A8@018C3`0C4`l051@A
00l@3@0D5A@07b8R01<G6@0<4A<03a@F010C5P0G6Ad061XM018E5P0A5AH04AHF01HK6@1>De40a<S6
038j=P0A5Q<04QXG010H5`0G71`06QhO01@G600B4aD05ADG01PH6P0G6A/05ATJ01<H6@0C6QX05QdN
01DL7@0F7Ah06b<R01<K6P0D6a/05QdL018J600B6AL051/J01@K600F7A/041DC0P0H7A/0E@0L8Ah0
3Q<@010E4P0K81l04QLF010E5@0N8b<05AXJ01LL7P0J7B<05aXP01HI7P0H6al06AdQ01PL7`0H7B40
4APN01HO:00R;S`08bln01LT=@0I8Bh072<^01hV<@0F7BX0620Z02Pb>`0T;CH072D^01HP:@0F8BP0
5b4Y01DO:00H8b`0:3<l01dY<P0F8BX0624Y01/U;@0I8BX072@[024Y<00S:C0051XP01LM8P0N92T0
6AhS01HL8@0K7bD05Q/Q01XP9@0G6b005a`R01TO900L82H0724V01XP9@0J82<05adP01`R9@0K8R@0
5Q`O01PN8P0G7B<082H/01@J800X;CH0A4YB01/Q9`0G7B8041LJ01PO8P0C6Qd0>d1301hS9P0O92H0
6AdQ01LL7@0C61T05Q/L01<H6P0H7B005AXM01@I700C6Qd00P0D6Ql0B`0j@DL07bD/010H7P0F7RD0
5alW00lG7`0F6b<05ATS01DI8@0G72806b0W01hS:00J7b<05Q/O02<X;00W;2h07b@W01HN7P0;5a@0
72DU01<L7P0:4aD04a`P01PP90053A805QdS01hU:P0R:2d051XO018I6`0A61P041LF00lF500@61D0
51/I01@K6P0A61P04QTJ018H700B61h04aTQ01<J8@0B6Ql051dQ01HP8@0@6AL03QHD00lF4`0>5Q80
3aLE014G6@0@5AP04QLK00TA5@0=5AT04QTN01PO9@0>5A/05QdS01<J800G7b802A4C00`D5@0E7Q`0
4a`J03To?P0?5A@061dN00dB5@0730l04AHJ00hC5`0B5aX03Q8E01LL7P02018H5`0D00`A3P0>4a00
4ADC014F4`0@5A80314>00lC4@0?514041@B00lC4@0>4Q0041@B014F4`0?4a403A8?00lC4@0@5A80
3a@@01<H500A5Q4200lD3`0401@I500>4`h03a@@00lD408041DA00<04AHB018G4`0D6AD00`0?5100
4P0A5Q80;C8^01LL600@5A404QLC01<H500F6aL03a@@00L<200?4`l04QLC01<H500A5Q802@h:00dB
3P0A5Q803A8>010E4@<03Q<?01T03a@@014F4P0I7QX05a`H010E4`0E7Ah03QDF00lH5P0:4@d041P@
00/F2`0?6@h031@=00TC300=5Q003ADB00TA3P0@5A803Q8@00`A3P0A5A<03Q<?00lD400>4`l03a@?
008041D@00X03Q<>00hC3@0>4`d03A8<01PM5`0=4P`04QLA00hC3@0A5Q004aPB0P0>4`d0200A5Q00
41D?018G400@5@h03a@=00hC300=4P/03Q<<0P0B5a00100:3`P03a@=01<H4@0>4``200`A2P1300lD
3@0=4P/02a0900hC300=4P/01@X3010E3P0=4P/04QL@00`@2@0@50d04aL@00lC300;3`P03A4:00`@
2@0=4@X04QH?00lC300=4@X041@=00`?200>4@X04A@=00lB2`0>4@X04A@=00d@2@0I71D03A09014D
3@0:3@H03Q4:018D3@0>40T0418<01DG400?4@X04Q@>00h@2P0?4@X03a4;010B2`0@4P`04A<<00dA
2P0<4P/03Q<;00hB2`0;4@X02a0901@H4@0`=Rh061dF014E3P0>4`/03109018E3P0?4P/04QD>00lB
2`0;3PL04A@=01DH4@0F6A8051L@010C300200`?200I00hA2`0?4@`04aH@01@G4@0?4@/02`d700P;
1@0<3`T03A0:01<E3`0?4@/030l800lC301PI5d07B4I018F3`0<40T03a8:010C3@0>40T03Q0800h@
2P0>40T04Q@>00h?2@0200d>200500h?2P0@4@/04A8<018C3@082@@00P0B4`h0:P0F5a404a@>018C
3@0;30H051D?01hO6@0C50h02@X400`=1`0>3`T051D?00d>200:2`D04Q<=00h?200B4``061TB010A
2`0<3@L02@X400h?2P0<3@P03Pl:010@300C51003a0;010B3@0<3PT0414<01DG4P0C5A004A8=010B
3@0:2`H03Pl:010A300;3@P02``700h?2P0B4`h0414<00h?2P80414;01<03Pl900d>2@0=3PP03@h9
00l@2P0@4@`02`d700/<1`0?4@/051H@00/<1`0A4`d03Q0:00d?2@0?40/0418<010A300?4@X0418;
00804Q@<0280418;014C300M7aT061TD018D3P0;30P030d8010A3@0;3@P06A/F00d>2P0B50l04A<>
00h@2`0D5Q402`d8055CCP0V:2<04A<>00/=200H6QH03@l;02<U8@0=3`/030h:018D400@4Ph030h:
01TK5`0<3PX03a4=01@F4P0B4`l04A8>0`0?4@d08`0>40`020T500d?2`0?40`02@X600`>2P0=3`/0
4A<>00d?2P0=3PT061TD02LX8`0B4`h03a0;00lA300H6QD04A8=010A3@0a<Rd0824L01<D3`082@D0
4Q<>00l@2`0;30L04A8=010A300>3`X030d800h?2P0@4@`03Q0<00X<200<3PX02P`800802`d900d0
3Q0<01<E4@0B51003a4=00D71@0<3PX03Q0<00T;1`0B51003@h;00h@300A4`l03Q0<00803@l;0100
3a4=010B3P0@4Ph051DA020P7@0E5A804A4>018B3`0:2PL0410=01<D400B4Pl03@d:00H71@0>3`/0
3Ph<0`0?3`d200d=2`0]00/;2@0>3P`051@B00l?3@0>3P`05ADB00/<200:2`L04A4>014B3P0Q8Qh0
4A4>00d=2P0720@0414=00d=2P0:2`L04a<?00D60`0<3@P0414<00`=20061`<0414<024R7@0H6A@0
3a0;014B3@0<3@P03Ph;00h>3@0@40l04A4@00l?3P0>3Pd030`;014A400C4a80410?00d=300;2`X0
3Ph=00`=2P0C51804A<A00803a4?03402Pd;00d@3P0V:BT02`h>00X?3P0@4a<03Q0?00l@3P0@4A00
4Q<A014B4@0>3`h04Q<A014B4@0@4A003a0?010A3`0A4Q0051DE00l@4@0;2`d03a0B01@E5`0=3Pl0
30d@01dM800=3A003PlA018B500@41<05QHH00l?400@41403@d>010A4P0D5AL04Q<E00h>400@41@0
4Q8F010@4`0;2`l02PX>01@D6@0A4AH03`lD014A5P0D51T03`lD00804A4F00<02`/@00d=4P0>3Q<0
5?ooool001_ooooo01T0E55L00H42`041@T06AXL00L=20083`L04QTA01HL5@0=4P`01@D500X92P0I
5aX01PD:00l>4`0920d03PdB01HF6@061PP03`lA00H6200E5AL04a<C00d=3@0>3Ph04A4?00803`l=
0P0>3P`0500?3`d03Ph<01HF500N7Q`09bLU010@3P0B4Q005QHF01<C4`0B4Q804a<C01@D5P0E5AL0
3@d?00h=4P0A41D05aHK01TH7P0I61d04A8E0P0A4Q@3014C4P0O00lA3P0>40d03@l<010B3@0B50l0
3Q<?00dC4@0>4Q40418A014A4@0C4A805A<D00l=3P0@41007AlN01DI600=4a405Q/L00lB5`0;3a80
310C014E600G6a`04QHG01dQ8P0/<2l0OX:101TM700@51<05ATI00lC5002010D5@0600hB4`0?4a@0
4ADF01<G600D61T04QHG0P0?4a@01`0D6AX05A/K01HL700F71`04ALG01DK6`0I7al00P0E6a/0=`0D
6QX041HF018H600@51<04ADD01DI600D61L04QHE00dA4P0A5AH03Q8C01XN8@0B5QT07b<V018F6`0L
8bd05AhW014H800F6al061dP01HJ6P0G7Ad07BDW01TQ:@0I8S409C1201@Q=@0N9cH06bDa01TS;`0F
82`05AlZ01hX<P0Q:c@06bD^01LQ:P0I92X06RD[01LR:00D7RL05AlX01XT;@0J8bX05QlV01TR:@0I
82H05ahT014H7P0Q9RX0724U01PM8@0I7B0061`O01LK7P0H71l00P0I7B006@0F6Qd06AdP01`P8`0M
8B@07R8U01dQ900H7B005a`O01`Q900J7b805AXN01XO8`0G7280724W01/P9P0H72D0<3@m00hB6`0E
6Ql04aPL01HK7`0G71l05AXM01LL7`0E6Q`00P0A5aL00`0G7A`06AlM01TO7`0201<H6`1;01@I700F
7R406b8X01dT:P1FGf@08BXa01hW;P0A72806RD[00PA600D6R004AHL01<H7P0J7b<0724U01/P900E
6Qd03Q@D014G5`0F71`04aTI00hE4`0>5a805AhM018J6`0?5aX051/S00D<5@0>5Al072<]00P?600=
51`0>D16020X;00@61/03QHH014J6@0F7a`051dH014J5@0>5a@03AHE018J700D6b404aXT014G7P0B
5a/04aPK01@J6P0B61H041HB014G4`0@5Q803Q@B00lD5@0>4aH061dQ014H800=51`04QTQ01DL8P0B
6Al06R4W01HN8@0D71l02a<E01PP8P022P`03ADG01PM800I7R40314D01DJ7@0O92L04AHI00803Q<F
0P0?51L01`0@5AP041HG010D5@0=4A003a<B014E500?4a800P0A5A@200hB4@<04ADD00<041DA00lD
400@5A400P0A5Q800`0>4`l03a@@00hC3`0200dB3P0300lD400@5A404AHB00D04AHB01P041DA00lD
400>4`l03Q<?00lD400@5A402Pl;010E4@0>4`l03a@@01TN6P0N8al02Pl;018G4`0K81`02Pl;00dB
3P0H7AT03Q<?01XO6`0C61@02a0<010E4@0C61@200lD400900`A3@0C61@05a`H018H5P1[M7H0P8Z;
018M6@0A71804Qh@008031P:00l031P<010K4`0A6aT02Q@E00L?4@0@5A@03a<B00X>3@0>4Q404AHB
00T>2P0@5A4041D?00lD3P0@5@l00P0@5@h03@0I7QP04AH@00H;1@0>4`d06QlI00`A2`0E6Q@05Q/E
018G4@0?50h02Pl9010E3P0?50d00P0=4P/00`0?50d041D>00lD3@02010E3P0F00`A2P0?50d03a@=
00dB2`0<4@X02a0900dB2`0>4``0314:00X?200<4@X04QL@01<H4@0:3`P02a0901hR6`0W:R<0:2/T
01TL5@0B5@h04aH?010C30803Q4:00@03a8;010C300B5@h04QD>0P0C5Pl04@0D5a0071lH02ha:P0=
40T030l800d@2@0?4P/041<<00hA2P0B5@h05aXC01@G400<3`P02@`500/>1`0>4@X03a8;008041<<
0P0?4P/0100=40T03Q4:00lB2`0?4P/200hA2P803A0900X03Q4:014D3@0?4P/02Pd600`?20072P<0
2@`500lB2`0B5@h030l8100?4P/02`0>4@X03A090002000B5@h071lH00D80@0B5@h051L@00/>1`0=
40T03Q4:00803a8;01003A8;020U7`2V[:H0:BhX018G4@0A50l03Q0;00d?2P0>3`X071dH02PY900S
91l04A8=010A2`0?40X03Pl90P0?40X03`0@4@/04Q<=000100051P00@T<m0;jo^@0/;BL02@X401<D
3P0310002``600h?2@0@4@/03Pl900l@2P0201@E3`0;018C3@0G6180414;00H70@051P0020T500h?
2@0A4P`03Pl900d>200>3`T00P0A4P`0400@4@/030h900P:1@0=3`X04Q@?010B3@0?4@`02@/601@F
4@0>40/03a4<01XL5`0;3@L0414;014B300=3PP300h?2@0B010A2`0>3`T03@h800d>200>3`T02``7
00h@2`0N81/02P`700h@2`0?4@`04aD@00h@2`0=3`X03a4<010B3@0>40/03a8;0P0@4`X02`0@4`/0
3a8;00hA2P0?4@`03@l:00/=2P0A4a004Q@A00lA3P0=3`X03Q0;00803a4<00@03@l:00`>2@0=3`X0
3@l:0P0A4`h03P0=3`X03Q0;00H80`010`0071hI014C3P092`H03Q0;01@F4@0@4Pd03a4<00`>2@0F
61<04A<>0`0;3@X300X<2@803Q0=014030h;00h@3@0@4Pl02`d:00T;1P0;3@P010H100d?2P0K7AP0
2`d800X<1`0@4Pd05aTD00d?2P0<3PT0:2XU024R7@0200/<1`0^014B3@0=3PT03@h900h?2P0=3PT0
2``700`=200@4@`04Q<>00lA300@4Pd05aTD014C3P0C5A0030h900lA300:30P01@L200/<2@0@4Pd0
3@l:00X<2@0J71T0:B/X07eoO00:30T0004000lA3P0;3@X03Q0=01@F4`0A4a0030h;014B3@0O81/0
4A8=00X;1P0A4Pd0414<00X;1P0<3@P01@H1014B3@0L7AP03@h9010@3P@03`l=00d0410>00d=2`0?
3`d04Q8@00X:200D5180=3Da01dN6@0;30L0414<014B3@0?40/02``700H03@h900H02``700d>2@0A
4Pd03@h900/<1`0>3`X200d>2@0400`=200=3PT03@h900h>30803@d=00H03Ph>00l?3`0?3`l03Ph>
010@400;2`/200d=3@0E00P8200A4Q004Q@A01@F4`0620D01`T600lA3P082PL02`d:00d?300?4@h0
5ALD01LI5P0E5aH03Q0?00T;2P0?4A004Q@C00`>3@0?4A003Q0?00803@l>01403Q0?010A4P041@T0
2@X?01/L8@0?41D04A8G014B5P0D5AT0FeaP01PI7@0@4A<04a@F00d>400720X01PL901<D5P0201@E
5`0C018C5@0@4A<03@h@014B500<3@l04A8D00/<3P0?41@051DJ00l@5@0;314030dB00/<4@0C51T0
2P/@01DF6`0I6Ql07AhS01/L8@0Dooooo`006oooool04P0;21403@/B018C5`0H6A/03aD@00/B2`07
3PH03aD>010E3`0B4Q802@P:01LE600B4AH040lD00l>4`0=31402@T<00T92`803Ph@00H03`lA014A
4`092@T030`<014A3`0@40h300l?3@07010@3P0=3@/04Q8@01@D4P0M7A/030`:00l?3@02018B4P0;
01<C4`0D51@05ADG01DE5`0B4Q@051<H01<B5`0B4AH04a8H01@C600A4QD00`0A4Q@2014C4P0:018D
4`0@4Pl04A<@014C3P0@4Pd03a@@00`B400>4Q40418B018B4P80518C01/04Q0A014A4@0H6QT06QhM
014G5@0>4a@03A0E01TM800U:B`061`O00hB4`062P/07R8S00`@3`0U:BP05QXI00T=300G6a/06AdN
01<G600@51D04QHG01@H6@0F6Q/05a/L01PL7@0F6Q/00P0B5QL01@0E6Q/05adM01DK6`0@5QH03Q@D
00806AlO00L05A/K01@J6P0D6QX041HF018H600E6AP04aLF008041@C01d04ADD014E5P0;3a003a<D
01LK7P0J7R406AdP01@H7@0J8B/051dV014H800D6Ad05Q/N01@H6@0<4A@04QXM010I8P0>5bH062<e
01<P<`0S;3/07BLc01LQ;@0C7BT05AlZ01lY<`0S;CH06B</01HP:@0201/V;00?01@O9@0D7RL05AlX
01XT;@0K92/06B8Y01lX;`0E72806B0V00`C6@0I7R806QlS01HK7`0I7B0061`O00@05QXM0P0G6ah0
100H71l06AdP01`P8`0M8B@201XO8P0C01`Q900I7R405AXN01PM8@0J7bD06b0V020U:`0B5Ql05QXS
01<G800>4aT04AHL01XO8`0K82@041DI00`A500F6ah041DH010F5P0201@J6P0f01<I6@0@5AP04AHI
01<H6`0G7b807BDX01lW:P0J8bP00``A00dF6`0?6R007RT_018K8P0B61h041DK01DJ800N8bL06QlS
01@I7@0F6ah03A<C018H600S:BT07B<S01<K600F7aX01Pl>02/c=00H82<05ahV01@K900J8B/05A`V
00dD7@0R:C40K7=i03Y1AP0@61/03QHH01TR8@0P:BH0624L010I5@0@6AH041TH018J7@0D6b404QTS
018H7`0A5QX03a@G018H600C6AL041HB0P0A5a<02P0@5Q@04ALG018G6P0L8BD03QDM010G7`0E72@0
51/Q00dD6P063A<200/C5P0:02H^<017Ce403ADG01<K7@0:3a801P/>01XO8P000@@06b0S00X?4P80
3Q<F0`0?51L01@0@5QL03a<D00dA400A5A@051PG00<041@C00H03A4@00/?3P0A5A@04aLF00lC4P0>
4`l2014F4P05010E4@0?510041DA018G4`0?51000P0;40`00`0>4`l04AHB014F4P05014F4P0G00hC
3`0?510041DA010E4@0?51003Q<?00dB3P0D6AD03a@@00dB3P0J7a/09R/W01dR7P041`@0314=00lD
400D6AD05AXF01<H500G71P05Q/G00`A3@0A5Q800P0=4Ph04P0@5A40314=00dB3P0B5a<04QPF065[
JP1SKVX01Q4;01DQ60033`<03QX@00TE300;5Q804A/L00dE7P0841d03Q@P00P<3@807B4P01D041@C
01XO6`0>4`l04QLC00lD3P0=4P`03Q<=014F3`0B5a002Pl901DJ50011P0061dG00dB30042@@05AXD
00X?2@0=4P`04QLA00D:100A5Pl00`0<4@X00`0>4``041D>00hC300200hC300400dB2`0@5@h041D>
00dB2`802a0901403A8;00hC300=4P/02a0900T>1`052P<00PL102T^9`062`@020`601HI4P0H6a@0
3a8;00X=1P0;3PL03Q4:00lB2`0200hA2P0D00lB2`0@4``041<<00hA2P0930D01PT200`?200L7aP0
3Q4:00d@2@0>4@X041<<014D3@0>4@X000<001<F3`0H6a@05APA01dP6@0E614600lB2`0400d@2@0>
4@X03a8;00lB2`803Q4:00`020/400T<1@0=40T04A@=010C300;3PL05QTB01LJ4`0>4@X03a8;018E
3P072P<200/>1`0:00`?200=40T041<<014D3@0J7AH01`X401<F3`0V:B80Bdi700T<1@803a8;0P0>
4@X03`0?4P/03A8;0046000Z<2X00`P2010E3`062@@030h900T;1P0;3@P071dH02X[9P0S91l030d8
00h?2@0300l@2P803Pl901804Q<=00d>200D5@l0?3dg0;Ff/00P8A/04a@>020Q6`03100051D?01<D
3P0@4@/03Pl900d>200A4P`04Q<=010A2`0A4P`200`=1`0:00h?2@0P8A/03@h800h?2@0?40X03@h8
00h?2@0A4P`0414;00h?2@802P`701002`d800`>2@0<3PT03Q0;00X<1`0H6QD03Q0;06EWHP1cMG00
3a0;014B300>3`T03a0:01@E3`0A4P`03@h80`0?40X02@0>3`T03@h8018D3P072@@04A<>00X<2@0F
61<03a4<00L81@0200`>2@0G00h@2`0?4@`03@l:00hA2P0?4PT03A0700`?1`0<3`P03Q4:00@60@0>
40/04A<@02X/:@0T9R<02`d:00X<1`0<3PT03a4<010B3@0=3`X02@/600`>2@0:30L00P0;3@P0;009
2`H03a4<00`>2@0O8A`01@L200H80`0E5a80418=00d?2P0<3PT0418=00/=200C5A003@l:00d?300?
4@h04A<@00h@3@0<3P/0418?018D4@0:30T03a4>01HH5@0C5A802P`900`>2@0?4@`02P`700T;1P0=
3`X02`d800P:1@0@4Pd02P`700P:1@0?4@`02@/601<D3`092PD03@h9014B3@0>3`X0414<100=3PT0
=@0@4@`04A8=00/=200A4`h07R0K01TK5P0F61<02`d800T;1P0I6aH03Q0;00/=20092`H030h901<E
4P051`@04aDB03i0?@072@H061XG00h@3@0:30T0418?01XL6@0C5A802`d:00h?2P0H6A@04Q<>00/<
1`0B4`h05QLB01@E40010P002P/600P91@0A4Pd00@80014A3`0>3P`03@d;00h>300@40h04Q8@014A
3`0>3P`03`l=00/;2@0F5Q@0<c@`01DF4@020`004A8=0080414<1`0?40/01P0<3@P03Pl:018C3P0>
3`X030d800h?2P803@h900D030d800d>2@0=3PT03Ph<00d=3@0300h>3P0a00l?3`0A4A403Ph>00T9
2@0I6AT061PH00/;2`0:2`X03Q0=01LI5P0;3@X0418?01@F4`092`P03@l<00lA3P0C5A806Q`I01dO
700S9B@06A/J014C4P0I6aX07R0O01LI600@4Q403@l>00/=300=3`h03a4@00`>3P0J6al01`P=014B
5`061``04a@I01@E6@010PH01PL;04E6BP0=3Q804Q<G00h?4`0D5AL04A8D00/<3P082@/02``>00D6
200200d>400401<D5P0=3Q004A8D00l@4P803a0D00@04A8F01TJ7P0L7B404A8F0P0>3a<0100G61`0
4a@H00T:3P0<3A4Dooooo`006oooool01@091Ph03`dC00P92`0>3a403Q<@00802a8;01D02a4:00<7
0P0?3`d04A0A00h<3P0<30l03PhA00h=4@0<30l03@d@010@4P092@/0;2`^00l?4@0=3@l0410A00h>
3P0?3`d03Ph<00d=2`0>3P`00P0?3`d0200A4@l03Ph<00<30@0?3`d03@d;018B400?3`l04A4A0P0B
4Q802@0@41803Ph@010@4P0C4QL04Q4F00h=4P0?3Q@04Q4G010A5@02010A5006010A4`0@4Q80418B
018D4`0A4a0051HC0P0A4`l0700B5Q@03A<A00hB4@0A4a804a<C01@B4`0E4a@05aDF01@D500E5aH0
7b<R01XP7P0=4Q@02`hC01LK7P0H71l0310C01LK700S9bP061`M018F5@0<40l06QhM018F5@0J7Qh0
720Q01HJ6`0C5aP201@H6@0c01DI6P0G6a`06AdN01TM7P0F6Q/05a/L01PM7@0E6a/051XJ01<I6@0E
6a/061hN01@J6P0A5aL04QPH01@J6P0B61P05A/K01DI600F6QT051PG00lC4P0>4Q4051PI01LK700@
51D07b<V05YNH@0Z;S40?d=901<J8`0A6R<041LN01@I7@0E6Qd05QXK01`Q900@5a`051dV01dV=@0H
8cD0524d02@]?00L9S8051hZ018L:00G8B`08R`f01dW<00J92d05b4Z00805b8X01005B0V01HP:@0H
8R/07BL`01dV;@0I8RT07BH]01HM8`0Z<CL061lU01PM8@0G72005AXN01/O8P0J7R4061`O0`0G6ah0
0`0D61/05QXM01PL7`0201TM800401PL7`0E6Qd06AhQ01XO8P806AhQ01<06QlS01TN900H7B<061dS
01LK900>4Q/061`U01LK8`0N8R`0:Rlf02X_=@0J7b@051TN01DJ7P0G72005AXM014G6@0C61/05Q/N
00<04aPK00X04a/M01@L7`0E7B005AlR00lH7@0F7b@04A`Q01DP9P0@6B005adS0P0J7bD0?P0J7b<0
5a`P01HK7`0F6ah05Q`L01DK6`0W;Bd09B/[00lG5@0L9B8072DT08RATP11BD`04QTQ01LN9P0>5Ah0
2a8K02L^=P0i@4H061lU01HN8P0=5AP03ADG01@L7@0H8Al04a`J018K6@0E7Qd05AdO01@K800A6200
3aHP018H7`0@5AT03A8E014G5`0E6aT04QPD00lE4@0>51003aDC01<H6@0>4aH04AHJ018I8@0C6R80
4QTQ010G7@0A61h05A`R01PP8`0;4aH031@F00XB500X<3808RX/00hC5P0L8B@03A8E018G6P0:3A00
5AXM1@0?51L0400?5AH03a<D00hB4@0C5aH05ATH014E500@51<03a<B01@H5`0C5aH03Q8A00lC4P0>
4Q402a0<010E4@0A5Q8200dB3P04010E4@0B5a<04AHB00lD40<03Q<?1P0@5A405@0=4Ph03a@@014F
4P0A5Q803a@@00dB3P0G71P061dI00lD400<4@d041DA014F4P0E6QH03a@@01<H500B5a<092TU020U
8@0E6QH0314=014F4P0201<H500300T>2P0>4`l041DA00804AHB01D03a@@00dC3`0>5a802Q@=014L
4`0640L03AP?00LA300>5aP02Q8J00`C8@093RD05QXg02T]@`0b=cX010P700hB4@0@51<06QlK00L;
200?51000`0?50h200lD3@803a@>00X061dG00T>200=4P`04QLA00X?2@0A5Q003a@>00X?2P0>4`d0
314;0P0>4``0100<4@X02a0900dB2`0?50d300hC300900dB2`0<4@X0314:00`A2P0=4P/03Q<<00lD
3@0>4``0314;00803a@=00`0314;05iSG00[<2T04QH?010C300B5@h04A@=00lB2`0B5@h04aH?010C
300?4P/200hA2P0500lB2`0=40T041<<018E3P0@4``00P0?4P/00`0@4``03a8;00lB2`02014D3@03
00hA2P0B5@h04A@=00803A0900<03a8;00/>200@4``0100?4P/00`0@4``03A0900hA2P0200lB2`80
3Q4:02`02@`500/>1`0@4``04QD>010C300<3`P03a8;02<V7`0F6A802@`500hA2P0?4P/04QD>010C
300>4@X03A0900lB2`0@4``02Pd600hA2P0<3`P051L@020S7@0;3PL04aH?014D3@0>4@X03A0900lB
2`0>4``0314;00T?2@0;40X03a<?00d@2`0>40/0418=00`>2@0=3PT0414<018C3P0>3`X03Pl900l@
2P80414;00/03Pl900d>200A4P`051D?014B300A4Pd04A8?018C3@0?40X02``600X;1@0201<D3P06
00L81@0@4@/03Pl900l@2P0A4P`03a0:0P0=3PP0100D5@l04Q<=02LX8P092P@2010A2`803Pl90180
414;00l@2P0=3PP03@l:010B3@0=3`X02P`700`>2@0@4Pd03@l:00`>2@0@4@d0F5YE05MIE00;30L0
30d700h?2@0=3PP2010A2`8030d701403a0:018C3@0B4`d04A8<00h@2P0=3`X061XE00`>2@0B50l0
2`d800lA3@0<3PT02@/600X<1`0=3`X03Q0;00hA2P0200hA200:00lB2P0?4P/03Q4:01HH4`0Q8ah0
3a4>020R7`0J71T0418?00`>2@<03@l:00@030h900/=200@4Pd03Q0;0P0A4`h09P0<3PT03a4<018D
4@0?4@`030h9018D3`0A4`h0;S0[02PZ9@0B50l04A<>00lA30082PD02`d8010B3`0D5Q<05ALD00h@
3@0;3@X03a4>00d?300;3@X04aDB01LI5P0A4a0030h;010B3@0>40/0418=00h@2`0;3@P04A<>00lA
300=3`X01`T400/=200A4`h030h90P0>3`X0100B4`h04A8=00/<1`0>3`X2010A30803Pl:02H03@h9
00`=200:30L02`d801@F4@0?4@`04Q@?00`>2@0@4Pd020X600h@2`1KGEP09bTT00`>2@0?4@h02P`9
00d?300A4a003Q0=00L91P0?4@h03@l<00h@3@0@4Pl03Q0=00`>2`0?40/05aPC01XK5P0A4Pd02``7
010A300<3@P03a0<014B3@0B4`h020T5014B3PH03@d;00L030`:010@3P0C4a403Ph<00/;2@0A4@h0
2P/60080414<00<02``7014B3@0@4@`01@0>3`X01`0?40/030d800d>2@0A4Pd03@h900`=200@4@`0
0P0?40/0100>3`X03a0;00l@2`0?40d500h>3P1200l?3`0<30`030`<024Q8@0H61P02`/;02PY9`1K
GEX0Gf5N01LI5P0720H03a4>00`>2`0?4@h03Q0=00d?300B51404aDB014C4P0=3`h02`d<00h@3`0@
4Q403Q0?01<E500?4A0030h=010B4@0A4a8030d>00`=4@0D5AT0A4E:01HG700;31003a0D01DF6P0K
7200C4eA01hO8`1lOH406Q/O00h?4@0C51H02@X<010A4`0C51H04Q<E014B500=3Q005AHH00l@4P0A
4Q@04a@F01TJ7P0;2`l02``@01hO8`0U9RX03a0D01<D600@4AD02@X>01DF6P0D5AT0414E5?ooool0
01_ooooo00d05A8I00l=4`0D5AT06a`N010E500?5A402Q0<00hD3P0?50h010@200h=3@0<2P/04Q8D
00809BDW00X05QHH00/;3@0=3@l051@F014A4`0?3a404A4C00X:300>3Q0030`;0P0;2`T0400<30X0
3@d;00h>300?3`d05QHD00T91`0D51803`l=00d=2`0A4A404Q8B01<C4`0B4Q803`lA00h>400A4A<2
018A5P03014@5@0B4AL04a8H00<03a0D0`0?41802P0@4Q4051HE00lA3P0=3``0418?010D4P0?5A<0
41@C018D4`0B4Q8201<A4P0J01@B4`0B4Q804A<B01TM700H7Q`07b@U01DH7@0@51L061`O01<G6P0E
6AX07R8S00<7200A5A@05a/J00dA400E6AP04aLG010D5@0?4a@04QHG01<G600B5QL041@E014E5P0D
61T201DI6P0601HJ6`0E6Q/04aTI018H600G7Ad0728R0P0F71`2018H600401<I6@0@5QH04QPH010D
4`804aLF0P0?4a80<`0F6Q/0<3@e00lC500N8RD041@G01@H6`0=41H041LO00lH7`0B6Al051TM01DJ
7@0G6ah06b0T02@[<@0L92d08R/j03M3D`0J9cP08BXi01TS;`0C7BT05Al[01TS;P0Q:cD06bD^01hX
<@0L9Rl062<Y01LR:00I92X04Q`U01hX<@0^>440;3Dl01/T:`0A6R403aHL02H]<`0K8RP06b0T01DJ
7P0H7B405QXM01LK7P0I7B006alR01hR9@0P92L04QHI01DI700201PL7`0301LK7P0E6A`0314D00<0
4aPK0P0G72004P0Q9R`06AhT00lD6P0E6B804ADN00lC700L82/06QhY01`P:`0K7bT06QhW01hS:@0A
5Q`06AhT01PM8@0D6Ad05a`P01dR9P<05AXM02D051`N01@L7`0D71l0218D00`E6P0>5a`041/O01@O
9@0F7bH06AlU01lT:P0K82H04aPL01DJ7P0J7b<05AXM01TO7`0A5aL051XJ01<I6@0B6AP05b0M00L@
3`0Q:BX02a<F01DL8P0A62003QDM01PO9`20Qhd0inob04I>D@0E7B004ATL01<K7@0A6QX03aPG0080
4AXI02<041PJ018J7@0C6R404APP018I8`0C6B004AHJ010E600C6AT05A/I01<I5@0G7AT061hJ01<I
5`0@5AH03Q<F01PM8@0=51`03QDM01DL900?5Q`01@`B00hE6`0;4aH051`O02Xb=00V;S00PHV;05aT
IP0?51L00`P;01HK7P0A5QT08bP[05QMH002010E60<03a@G00D03Q@E00lC500=4A004ADD01@H5`02
010D4`03014E500M8B007R8Q008041@C00@04aLF00`A3@0>4`l03a@@0`0=4Ph01P0?510041DA014F
4P0A5Q803a@@00dB3PH03a@@04803Q<?00lD400@5A4041DA00lD400>4`l03A8>00hC3`0<4@d03a@@
014F4P0:3`/03a@@028W8`0J7a/03Q<?02DZ9P0L8Ad03Q<?010E4@083@T02a0<00T>2P0H7AT0314=
00/@300@5A404QLC00`A3@093`/031D=01XT700?6A003QP?01DN6@043@X02A0E00lE8@0=4RD02@dX
01DH>@0O8c`0<C@h00040`0=4A002Ph=00/@300:3`/03A8>00lD3P0A5Q0041D?00dB2`0<4@X01@X5
01lT7P1BEe406b0J00X?2@0>4`d07R<M05IKE@14BD<04AH@024V800@5@h2014F3`0;00`A2P093PL0
314:010E3P0>4``03A8;00hC30093PL020d600/@2@0=4P/00P0?50d02@0=4P/03Q<<01<H4@0>4``0
4aPA010E3P0D6A80008000lC300200`?200500d@2@082`@02@`500hA2P0?4P/00P0>4@X02@0?4P/0
41<<00P;10082`@02@`500X=1P0;3PL03A09010C300200lB2`8041<<0P0=40T03@072P<04aH?01PK
500930D03a8;014D3@0@4``03Q4:00d@2@0>4@X04A@=00d@2@0>4@X00P0?4P/300hA2P0;010C300B
5@h041<<00hA2P0=40T02`h700hA2P0:3@H03A0901@G400<3`P00P0?4P/400d@2@0I01PK500=40T0
1PT201dP6@0<3`P03A09014D3@0@4``03Q4:00d@2@0>4@X0314:00L<1P0>50d05AXD00D:100F6A@0
5ALB00/=200A4Pd0414<00`=200>3`X05AHA00d>200300h?2@803@h80280824K01@E3`16Ad404Q<=
01<D3P0B4`d05AH@00d>200F5a4020T4010A2`0H6A<030d7014B300?40X0414;01<D3P0B4`d03a0:
00`=1`041@003@h800H70@0C50h03a0:00d>200>3`T04A8<010A2`0>3`T030h900lA300=3`X02@/6
0P0;3@P02P0F61<03a4<00`>2@021000004000l@2`0F5a406a`F010A2`092P@200`=1`0300/<1P0>
3`T04Q<=00804a@>00P0418<014C3P02100061XE079dK`1?DD`06A/F00`>2@8020X501403@l:00lA
300?4P/03Q48014D2`0C5Ph04QD>00hA2P0?4@`06Q`G00lA3P0A4a0030h;00h@3@0?4@`03Q0;00`>
2@0200/=200300d?2P0B50l03@l:00802`d801d030h901LI500c=C002`d800d?2P0;3@P03@l:06U[
IP1ZK6L0;BlZ00X<1`0D5Q40418=00/=20082PL02`d:00d?300;3@X02P`900lA3P0>40d06A/H01PJ
5`0A4a003Q0=00/=2P0>40/02P`700d?2P0200lA300:014C3P0?4@`030h901DG4P0D5Q4020X500X<
1`0720<030d800d>2@802``700<03Pl:00d>2@0=3PT00P0=3PT01P0@4@`04A8=010B3@0:30L02`d8
00H80`803a4<01<02P`7024S7P0O8A`06adH01@F4@0C5A0030h;00<50P0a<c001PP601HH5@0E5a@0
3Q0=010B3`0<3P/01PP500P:1`0=3``0414<00803Pl:00h030d800h?2P0C50l09BHQ09^LU`0P8A`0
20T6014B3@0T9B003Ph<010@3P0B4Q004A4?00h>30<03@d;00@03Ph<00l?3@0@40h04Q8?0P0B4`h0
10061`<03a0;01@E400:2`H500d>2@0400h?2P0<3@P030d800l@2`8030d800@03a0;00d>2@0=3PT0
30d80P0=3PT00`0?3`d03`l?00h>3P0200h>3P0A00d=3@0?3`l03`l?00T92@0=3@d02`/;00`<300E
5QD08R@Q02la;P0>40d020X701<E4P0;3@X03Q0=00d?300<3P/00P0@4Pl0<00=3`h0418A01@F5@0B
51<0418A018D4`0A4a803a4@00h@3`0A4a804Q@C00h@3`0I6Q`03@hB02@U:@0A4QH0414E01HG6`00
00@061TM02PY;@010PH0ATM;01LH700>3a405aPJ00T:300@4A<030d?028S9@0K71h03@h@01@E5`0?
4180414C018C5@0@4AD04a@H00`=4@092Ph03@hB00l@50041@T04a@H014B5P0B4aL01PL;02PY;ACo
oooo000Kooooo`0?00l=4P0A3a@0414E010A4`0/<Bl0GVAP03<i=@0@5A407b@P00/;2@0>3@/02PT7
00410@0K6a/0:b/[00806ATK00P0AdM9018B50061PT04A0E00h=4P0:2@h030`>00`<2`8030`:00/0
3@d;00h>300?3`d02`/901HF500820H04a<A00l?3@0:2PP03`l?010@4002014A4@804A4C00H05ADG
018A5P0A41D04A0E00h=4`0<2a4400l@50803a0B00X061TJ01hP7`0A4a803a4>01@F4`0?514041HD
014E500B51<04Q8B0P0B4140200C4A804Q8B014C4P0D61L05adK038g>00U:2d03a<F0P0=4A@02@0G
6a`05ATJ00X>3`0@51<0720O00dA400?4a8041@D018F5`0201@H6@<04aLH00`051PI01HJ6`0G6a`0
5ATJ01HJ6`0D6AT051XJ01<I6@0E6a/06R0P01PN7P0E6a/2018H600501<I6@0@5QH04QPH01lS8P0J
7Qd00P0C5aH0;00E6AP05ATJ01`P8@0?4a@04aLJ00<72P0O8bH07B4V01<J8P0C72<051/Q01DJ7P0C
61/051PK01lT:00a>3h09blh02`f@P1=FFT0;S]<020Y>00I8bl05Al[01PR;P0I8bh072H`01dW<00L
9Rl06bD^01XU:`0H8bT05R4W01HP:@0N:340:C<l02Pa>00J8bX05AhU014H7P0G7R@04QTO01/P900E
6Qh061dQ0P0G71l0100H7B006AhQ01`Q900N8bH201@I70805AXM0P0F6ah04`0=4QD05AXM01<H6`0C
61/05a`O01DJ7P0R9bd06AhT01DJ800G6b@07B4Z01lS;00G6bL06QhZ01/O:P0D62<04aLR01PL9@0H
7B@00P0G72801`0F6b404aPN018G6`0E6Q`05A/K01HL700D71h00P0C6ad0;`0G8B<0628T01DO8@0D
7b<041/O018K800E6b406AhT01PM8`0C61`051TM01LL800G71l061hN01HL700B61P04ALG014I5`0D
7AX06B8Q018K700@61/06B0V018I800F7BD01PdC05AKH02_]kT0=Cdo01@L7P0E7Al05alQ01DM7`0B
6Q`04a/M010H6P0>5QT04ATL018I800@5al04QTQ018H7`0A5QX04aPK01HL700E6aT04aTE00806AlK
01@05A/I018H600A5QT0724U024X<00C6R803A@L00`C6@0B6Al0B4mE01XR9@0I8B@04QXL00H>400/
=3H0:C4c00dB5@0X;C001PX=00hC5P803a@G0`0@5AP03`0?51L03Q<F00hD5@0@51D03A4@00lC4P0A
5A@03a<B014E500=4A006AdL01XN7@0@51<04aLF018F5@0300lD4004014F4P0@5A403A8>010E4@80
3a@@00<041DA014F4P0A5Q801P0?51001`0@5A403a@@00hC3`0>4`l03a@@010E4@093PX00`0>4`l0
100B5a<03a@@01/P700B5a<200`A3@08020U8@0@5A4020d9010E4@0<4@d08RLS00L<200G71P200dB
3P0H014F4P0?51003Q<?01<I5@0?5a400P`400<=1@0@6Q801a0;00XC400;51D05A`T00`B7P073200
310Y00/@8`0?4aH061`K01`P7`0=4A002Pl;01@I5@0>4`l03Q<=0P0?50h200hC300B00lD3P0C6180
7b@N00hC3@0@5@l0314;00lD3P0i?SP0;34[00870@0>4`d02a0:010E3P0A5Pl03A8;00X?200>4``0
4QL@0P0;40T0500>4``02@h700T>1`0=4P/03Q<<014F3`0?50d0314:00dB2`0>4``00`P10087000C
614051TB00lD3@0G6a@041<<014D3@0E61404A@=0P0B5@h200hA2P0600lB2`0@4``04QD>01DH4@0C
5Pl041<<0P0?4P/0100@4``03a8;00hA2P0>4@X200lB2`0?00/>1`0<3`P03Q4:01<F3`082`@00080
020S700A50d041<<00hA2P0=40T03Q4:014D3@0=40T03Q4:00803a8;0`0>4@X2010C308030l800@0
3a8;01DH4@0>4@X03A090P0B5@h00`0:3@H041<<010C300200lB2`0300d@2@0<3`P01@P1008020/4
00@04A@=00T<1@0G6Q<03A090`0>4@X02`0=40T02Pl801dR6`052P@061dF00hC30072`D01PT200L:
0`0>40T04A8<00803a0:00@0414;00h?2@0=3PP030d70P0=3PP01P0>3`T07AhH024R701EEU003@h8
00`=1`802P/500T03@h800X;1@0H6A@00`@000T:100>3`T05QLA014B300<3@L00P0?40X0100=3PP0
3a0:018C3@0@4@/200`=1`0300h?2@0=3PP03Pl900804A8<01D0414;00/=200<3PT030h900/=200<
3PT02@/601TK5P0@4Pd02`d801TK5P0@4Pd04A<=01/L5P0P8A/04a@>00/<1P0>3`T03a0:00h?2@0?
40X00P0B4`d02`0A4P`03@l901@F4@0J71L020X5024S7P0B50l020X500/=200:30L030h900803a4<
00P03Q4:00hA200@4`X04A@<014D3@0@4``010H100d?2P805QPE00<0418?00X<2@0>40/00`0>40/0
0`0=3`X030h900lA300300`>2@0400/=200D5Q40008000T;1P8051HA00/0418=02DW8P1?DD`0:2XU
00d?2P0?4@`04aD@00h@2`0<3P/03@l<00h@3@0200lA3P0;014C400:30T06adJ01<E4P0=3``04Q@A
00T;200>40/04A<>00h@2`0=3`X00P0A4`h0100@4Pd03@l:014C3P0A4`h200X<1`0Q00X;1P0<3@P0
2P/600T:1@0=3PT0414<00h?2P0=3PT02``700`=200@4@`04Q<>00lA300;3@P03Q0;00P:1@0>40/0
30h900L910072@D020X500lA300D5Q403a4<01/M6P0Q8b00Ngej018D4@082PL00P@100h@3@0?4@h0
3Q0=00802`d:00D030h;014B3@0?40/030d800h?2P0201<D3`0300`=200n?cX0004000805QLB00<0
004000l?3@0?3`d00P0@40h200l?3@0<010@3P0<30X02`/9010@3P0B4Q004A8>00X;1P092PD01`P3
00l@2`0D5A003Pl:1@0?40/0100@4@`03@h900d>2@0@4@`200d>2@04010A300=3PT03@h900`=2080
3@h900@03`l=00l?3`0?3`l03Ph>0P0=3@d0400@410051@D00`<300:2PX03Ph>010@400F5aH02P`9
018D4@0E5a@05aTF00`>2`0>40d0418?00lA3P0>40d2018D4@8020X90P092`X07@0:30/02`d<00`>
3@0=3`h03a4@010B4@0?4A003Q0?00<41P0720X05AHH00831`0C51P0FeaP02LX;00;3100EUML01<D
6@010PL051DJ00l@4P0G61X02``>01`M7`0X:B/0HfAV02DV:00>3a404A8D00803a0B00d0414C00T:
300A4Q@03PlA00/<3P0?41804Q<E01HG6@0A4Q@06a`N01lP8P0J6ad0P86301Cooooo000Kooooo`0I
014?4`0E51P04Q<F01LH6P21QXH0l_Of08jDTP0I7a/05a`H00X;1`0>3P/04A0=010@3`0:2PT03`l>
00h>3`0C4aD0;Bd_00l?4P0D4aL051<H00d<4@0B4AH03PdA014A400200/;2@0=00l?3@0@40h03@d;
00l?3@0D518020P6014A3`0B4Q003@d;00`<300>3Ph03`l?010@4002010@4P0600l?4@0:2@h03PdB
01DD6@0A41H05A@J0P0@4AH0:@0?41D0414E014B5@0B4aH07b0R01lQ8@0M7ah04A<A01@F500@5180
3aDC010D4`0B51@04A4A014?400D4Q<05Q@E01HF5P0G6AP061`K01/Q7`0L8B<03a8G014E600J7R40
5ATL01DI6P0B5QL07B4R01<G5P0A5A@03Q8A010D4`0B5QH05QXK01<G600D61T03Q8C01@H6@0A5AH0
4aLH00<05ATJ02L051PI018G600E6a/04ALG01PN7P0D6QX092XZ01/Q8@0;4A404aTI01PN7P093@d0
61hN034e=00W:bX05a/J01@H5`0F6QT04aLH01/O800B5QL04aLJ01TM80093A005ATN01lV;00L9B/0
82L]01DJ7P0C61`05QTN01DJ800J8BT06R8/01LQ;@0N:SP05R<c01lX=`0M9c<00P0I8bl05`0K9C00
7BLa01/U;P0O:C8051hW01PS:@0K9R`04QdS01PR:`0I8b`051hW010I800C72<06R<Z01XQ9`0F7B<0
31<I01XO8`0G7200<cPl030g>@0L8bD05ahP00805A/N04T051XM01DL7P0C6Q`04QTK010G6@0B61X0
41LI01DJ7@0G71l051TL01DJ7@0I7R405Q/O01DJ800@5A/05Q/Q01/O:00W:c@0;C4j028V<P0[;c/0
;30l01`P:`0G6bH07R8]01LK900C61h05AXP01PM8`0C61h03Q<G01LL7@0I7al05adM018J6`0@61X0
3aLI01DO800>61X07bT[03Q3AP0;5QT05b0T014G7@0D6Al05Q/Q01LL800D6Ad04aPL01@I700B61P0
5A/K01TO7`0L8R804ATG00lH5@0E7Qd03aLJ01@L7`0C6R0041LN01LN900B6Qh06B4S02</:`0N9bD0
8b`[01dU9`0P:2X04a/M00lG6@0B6Qd03A@I00804APO02T041LN010G7`0A620041HL018G6`0F6ah0
5Q`L018H5P0A5a<04QPD010F4P0@5Q@04aPI00hC5P0E6Qh04APP00lF7P0K8RX06b8X00hE6`0J8BL0
1`lB00lG6P0@61X072@V00T?4@0@61X03a@G00T>4@0A5QT041DH01TN8@0B5aX03A8E01@I700A5QT0
<CHi01LL7`0=4Q@03A4B00hB4@02010D4`0400hB4@0A5A@03Q8A00lC4P8041@C00@04ADD00dA400B
5a<04AHB0`0@5A40200?51003A8>010E4@0;40`03a@@014F4P0@5A404aPD0P0>4`l00`0?51004aPD
00T>2P0200hC3`803A8>00L041DA018G4`0@5A405AXF014F4P0<4@d03A8>00804AHB00/04QLC00hC
3`093PX04AHB01/P700=4Ph03a@@01DJ5P0`=C404AHB00hC3`02018G4`08014F4P0?51004aPD01XN
700M92804ATF014I5@0:4P/200hF3`0I01DM600F7Q/04a/I00`B50073A402PlC014E5@0<40l02@d<
018F5@0@5A40314=010E4@0=4P`0314;00dB300=4P/03Q<<00dB300A5Q0020/700lD3P0>4`d03a@>
00hC3@0200lD3P0300`A2`0?50h041D?00803a@=00@03A8;00`A2P0?50d041D>0P0;40T04`0=4P/0
2a0900/@2@0<4@X04AH?00hC300A5Pl02@h700hC300@5@h04aPA00lD3@0:3`P02a09018G400D6140
4aH?00hA2P0?4P/00P0<3`P01P0?4P/041<<00hA2P0>4@X051L@01<F3`803A0900L03Q4:014D3@0C
5Pl04QD>010C300?4P/03Q4:008030l800T03A0901DH4@0D5a003a8<00`?2@0M81T0NGae018E3P0?
4P/00`0>4@X01`0?4P/02Pd600d@2@0>4@X020/600d@2@0>4@X00`0?4P/02`0=40T03Q4:010C300=
40T030l800hA2P0?4P/03A09010C300D5a004QD>00803A0900<041<<00lB2`0A50d00P0>4@X03P0?
4P/041<<00hA2P0?4P/04QD>00`?200=40T04QD?00D:10083@D03aD<01<H400:40L04AD=0P0>4@T0
1@0?4@T0414:010A2P0@4@X03Pl800803Pl901<030d700l@2P0<3@L03@h800h?2@0A4P`04Q<=014B
3@0B4`d03a0:00`=2@0G61803a0:03`m=`0L7AL04A8<01DF400I6Q@051D?00<03a0:00L04A8<00h?
2@0A4P`03a0:014B300=3PP03a0:00803@h800H03a0:014B300@4@/03Q0;00/=200=3`X200lA300=
00h@2`0=3`X02P`700lA300=3`X02P`700h?2P0C50h051D?00l@2P0<3@L03@h800h?2@0200l@2P08
014B300B4`d04A8<00h@2P0<3P/03@l:014C3P092`H200d?2P0M00X<1`0=3`X03a4<014C3P0@4Pd0
3Q4:00T<100@4`X03a8:010C300?4P/03a4<00h@2`0];b`00`D2010B3`0A4a003Q0;00`>2@0=3`X0
418=00h@2`0<3PT02`d8010B3@0D5Q403a4<00`>2@0@4Pd00P0A4`h03@0=3`X05QPC00`>2@0@4Pd0
3Q0;01`N6@0P8Qd02`d800`>2@0@4Pd04Q@A010B3`0>40d00P0=3``00`0?4@h020X701DG500200/=
2P0601<E4P0D5Q<03a4<014C3P0<3PT02P`70P0<3PT0?00A4`h03a4<00X<1`0:30L0418=018D3`0?
40/03Pl:00d>2@0;30L03@h9014B3@0F5a803Pl:00X;1P0A4Pd0414<00h?2P082PD0418=00/=200G
6A@03a4<00T;1P0<3PT03Q0;00`>2@0D5Q404Q@?01LI501EEe@03@l<00`>2`0@4Pl051HC00`>2`0=
3``03Q0=010B3`0A4a003a4>00d?300>3`X02P/701<D3`0>3`X04A8=00T:1@0=3PT0414<00l@2`0=
3PT02``700l@2`0@40h03`l=00d=2`0<30X03Ph<014A3`<03`l=00h0410>00h>300@40d06AXE01@E
400@4@`030d800/<1`0E5Q402P/6010A300C50l04A8=00l@2`80414<0P0?40/02P0@4@`04A8=014B
3@0?40/03Pl:00d>2@0>3`X03a0;00l?3@0>3Ph200l?3`0400h>3P0=3@d03@d=018B4P803`l?00D0
4Q8B00h>3P0>3`h02@/800`>2`0200X<2@0g00h@3@0=3``05ALD00/=2P0:30T030h;00h@3@0C5A@0
4Q@C00d?3P0>40l02`d<010B4@0>40l030h=02@V9@0@4Q402P`;00lA400@4A803a0A018C500A4QD0
414D00l@500:2a005QLL01@E6P0B4aT05AHL00l@5P0<3A404a@F00h?4@0B4aD03a0B02PY:`0O8280
414C01HG6@0<3@l0414C00X;3@0@4A<03PlA00d>400A4Q@04Q<E00X;3@0B4aD03a0B03Df>010@D<0
4Q<E020Q8`0Dooooo`006oooool04P0?3A003@`?014B500:2`d0B4e=08bBTP1?EED05Q/J00X?2`02
0`004a<?00l>2P0<30X03`l=00/;2@0<30`04a<D014A4`8040lD00H03PdB00d<4P0<2a402`X?02l_
;P0G5aD200h>300<018B400?3`d03`l=01DE4`0A4@l0410>01@D4P0C4a403Ph>00l?3`0@41004A4A
0P0?3a40FP0D51H04Q4F014@5@0C4QL03@`B01LF700A4QL04Q<H010A5P0>3a<03@hB00`=4@0S92H0
?d1205AEE`0F61L03@l>01TM700<4Q003Q8A01<E500A4A404@l@01@B4`0E4a@051@D01DG5P0E6AP0
5Q`J01HK700A51T03a<F01@H6`0H71l05ATJ018F5`0?4a@03Q8A010D4`0A5A@041@C01DI6@0F6Q/0
4aLH00lC500:3Pl05a/L01@H6@0B5QL04aLH01DI6P0F6Q/05ATJ01DJ6P0I7al03Q@D01@J6P042PX0
82HV00X@400D6QX06b4Q01@J6P0S:BT0728R024U900M8B005ATH014E500D61L06alP00X>3`0K7b00
5QXM01<G6P0S9bX06QhS01PO9@0B6b007B@Z01dR9P0P9BT09bXa01DI8P0F7BL06B4/01PR;P0F8S00
62Hd01HP;08051hZ01d05R0/01`V<@0S;CL072H_024[=00E7bP06RD[01TT:P0E82H04A/T01LQ:P0A
6b@03AHM010I800B6b8072<Y01LN900?5Q`06b0T01DJ7P0X;C408b/]00dE5`0D71h05AdO01HN800D
71h04QXL01@L7P0301LO8@0;014I6`0B5aX051TL01@I700C61/051TM01LL800F6b405AXP01HK8@0H
72D00P0J7RL0@00N8Rh06AdY028V<@0W:cH06alZ01DI8P0G72<05Q/Q01LL8P0H7B<04aPN010E6@0C
6AP061hN01HL700D7A`05AdO01<K7@0@6Q/051hP01DO8@0nBD/08bh`01XT9P0D6R005AXP01HK8@0E
6Qh04QLK014F6P0B5aX041HF01<I6@0B61P051XJ00lF5@0D7A`05alQ014I6`0>5QT041LM018I7`0C
6ah051`N014J6@0>5a@04AXE00`E4P0`>3X0IVi`0459B`022@l01PdC01dT;00;4QX04APP01`S:`0>
5Ad02A0H00lE6P0B5a/05AXM01DK6`0E6aT201DK5`0A014G4`0@5Q@04QLH00lD5`0G72008RTa01XQ
:@0C6R803QDK00/B600A61h0;CDh008:3@0J8R@01@d?008:300C6Q`00P0>4aH03@0?51L041DH010E
600@5AP02@hA00@9300B5aX0Q8V<06M/K`0D6Q/03A4B00hB4@0@51<00P0?4a80200@51<04QHE00hB
4@0@51<051PG010D4`0?4a803Q<?0P0A5Q802P0?510041DA01<H500=4Ph04QLC010E4@0G71P04QLC
014F4P0B5a<2010E4@0500D:1P0<4@d04QLC018G4`0A5Q800P0?5102010E4@0:00hC3`0A5Q804aPD
018G4`0A5Q804QLC00dB3P0@5A40314=01@I5@804AHB00L0314=00lD400A5Q804AHB00lD400>4`l0
4AHB00803a@@01`041DA018G4`0C5aH05Q/M018G6P0@5QH03aHA00lF3P0>5P/05alA00`D1@0A6@X0
4AX900PA000@60/03a<@02<W9P10A4<0720O00H;1`0V:bL05AXF00dB300>4`d04QLA010E3P0;40T0
3A8<0P0@5@l00`0<4@/02Pl900dB300500hC3@8041D>00<03Q<<00dB2`0=4P/00P0>4``300dB2`80
314:01003A8;01<H4@0;40T03A8;00D:0`0?50d03A8;014F3`0?50d0314:00/@2@0?50d05ATB014D
3@0>4@X041<<0P0=40T01`0>4@X04QD>010C300C5Pl07b8K01hQ6P0A50d00P0?4P/00`0A50d04QD>
018E3P02010C300;00lB2`0<3`P030l800lB2`0930D04A@=00/>1`000P004A@=01XM5P0B5@h00P0=
40T05`0@4``03Q4:00lB2`0L7aP010L001@G400U:24051L@00`?200o@S/0<C@]01TL5@0?4P/04A@=
010C300B5@h03A0900hA2P0B5@h04aH?00hA2P0:3@H03a8;00804A@=010030l800D80@0=40T03A09
014D3@0D5a004QD>00`?200;3PL0H6=L05QKE00I71D020X601PM5P0:40H02a880P0=4`T0100=4@P0
30l600d@1`0?4@P2010A2@0500l@200>3`L0:b`V01/L5P0<3@L00P0=3PP03@0C50h01PL4014B3001
0P003@h800L80P0>3`T02``601@E3`0:2`D05QLA00/<1P0720801P0>3`T04P0C50h04Q<=014B300A
4P`0414;00l@2P0A4P`03Pl900`=1`0=3PP03a0:010A2`0Y:bH01`T400lA300:30L03a4<018D3`D0
3Q0;00<03a0;00l@2P0?40X00`0@4@/0400?40X03@h800d>200?40X0414;00l@2P0C50l00040018D
3`0D5Q4071hI00h@2`0<3PT03a4<00h@2`0;3@P200h@2`0H01@G40072P4041<:010C2`0F6A8041<<
00X<1`0F61<0>S`i00X<2@0B514020X700h@2`0<3PT03a4<00h@2`0:30L030h900lA300>40/030h9
00/=200<3PT03a4<0`0=3`X01P0>40/03a4<014C3P092`H051HA01LI50802@/600<03a4<018D4@0=
3``00P0?4@h02@082PL03@l<00L91P0>40d02P`900lA3P0D5Q<08bDR010B3@0200lA3003010B3@0?
4@`02`d800803a4<00@03Q0;00`>2@0=3`X0418=0P0?40/03@0C50l04A8=00d>2@0A4Pd03Pl:00d>
2@041@002``7018C3P0G61<0828M00@60`0X:RD00`051`80300D5Q403a4<00d?2P0A4`h0418=00`>
2@0<3P/03@l<010B3`0E5a@051HC00X<2@803@l<00L03Q0=00lA3P0?4@h03a4>010A30051P404a@?
00802``700<03a0;01<D3`0B4`h00P0A4Pd200l@2`06010@3P0A4@l0410>00d=2`0>3P`0410>0`0>
3P`200l?3@0900l?300N7aX0414<00X;1P0?40/01`P3010A300I6QD061TD008030d800L01`P300l@
2`0@4@`0414<00`=200A4Pd04Q<>00803a0;00/03Pl:00d>2@0>3`X03a0;00l?3@0>3Ph03`l?010@
400?3`l03Ph>00l?3`03010@40803`l?00<03@h=00/=2P0;3@X00P0<3P/08@0=3``04aDB0001000?
4@h00`D2028T8@0@4Pl030h=00L9200<3Pd051HE014C4P0>40l03@l>01HH5`1;CD`0:R`[01`N7@0A
4a8071hM00lA400:30/04a@F00D6200F5a/03a0E014B5`0D5AX04a<K014A6@0@4AL04A8F01<D5P02
00l@4P0701@E5`0?41803a0B00h?4@0D5AL04A8D01LH6P03010A4`804A8D0P0B4aD01P0;30h03a0B
010A4`0?41803@h@00h?4ACooooo000Kooooo`0B00h<3@0=30h04A8D00D62P0@51L08bTY00dC4`0:
3`h02a0<00X;1P0E5A0020L200`=200?3``030`:00d=2`0B4Q<0410B0P0?3Q<04P0=31803@`D00/:
4P0;2Q00;2`[01DE4`0=3@/03Ph<01@D4P0C4a4051@B01/K6@0D51803@d;00l?3@0A4@l03Ph>00l?
3`80410@00T0410B00l?4@0B4Q@05aHK00l>4`0=31402`X@018A5`0B4QX00P0C51T09@0A4QL03@hB
00`=4@0@4AD07QlQ03ho@@0D5AL01@L601<G5P0=4a403A4@018D4`0@41004Q0A01DC500D4Q<04a<C
014C4P0?4a803aDC01<H6@0B5AX03a<F018F6@0E6A`051PI01<G600@51D03A4@01HJ6@0L81l05a/J
01<G5`0830d0720Q01/O800@51D00P0A5AH04@0B5QL04aLH01DI6P0F6Q/05ATJ01<H6@0I7al05adM
020V9P0G7Ad0>3hn018H600P9RH061hN01@J6P0C6AT02a4A00805ATH03L04aLF014E500E6AP082@U
01DI6P0F6Q/04QHI01`P8`0<41<05ATN01LO8P0=5aT04QXM01TN900J7bD07R4Z01HJ9@0B6B<051`W
01/U<@0M:CD06BLd01dW<`0D7RX04adY01HP;00C7BP06B<]01LQ:P0F82T051hW01XU:`0A728051lU
00lI8P0C7BH041XS010I800B6b803QLN01LN900F7B<05A`R01TN8P0F6al04QLK020X:P0A6A/06B4S
01LO8@0F7R005AdO00hF600A6A/03ADG00803aLI00@01@d?00lD5`0H7B0061dP0P0C61/0=00I7R80
4QLM01HK8@0H7B<061`U01TM9P0J7RL061`W010D7`0L82/0;30j01lS;00D6Al06AhT01LL8P0G7200
61dQ01HK7`0D6A`04QPG01<I5`0B61H05AhK01HO7P0A6QT051hO02@^;`0A6a`06bHX02D`<P0=5aT0
5adS01HK8@0D6Al04aPL018G6`0A5QX0314D00lE5@0F71`04QPH00lE5@0D71/04a`K01HN800D71h0
2a<F00dD6P0A61d03aLJ00lG6@0@6AL2010I500W01DN6`0?61L09bla02L_<P0I82H000H>00`C7@0=
51h05QdW02L^=`0?5Qh02A0F01<I7P0@5AT03a@G014G5`0C6AL051XF018H500?5A403aDC014G5`0@
5AP05Q/O01dT;00F7BD03QDM00`C6@0=51X05QdS0418B`053A0041PJ01XR90063Q003QHH00`A500>
4aH03a@G00803Q<F00P041DH018G6P0G71l04QLJ02L/;`0I7R403a@F010D5@803a<B0P0@51<00`0>
4Q404ADD010D4`02018F5@0300hB4@0@51<03a@@00804AHB00@041DA014F4P0C61@03a@@0P0@5A40
300B5a<020d901DJ5P0<4@d02a0<01HK5`0;40`02@h:010E4@0D6AD041DA00hC3`804AHB01@03Q<?
00/@300?510051TE01LL600F6aL04AHB00lD400@5A403A8>01HK5`0B5a<04AHB00/@300B5a<04aPD
00hC3`0=4Ph041DA00lD40803Q<?00<03a@@010E4@0A5A@00P0@51L05`0?4a@03a@@00lD3@0@5P`0
5A`=00`C0@0;4`004AT400/C000<4`401PT500X>3@0T:2L04aLF038g<`1fNgL05Q/G00`A2`0=4P`0
5AXD014F3`0;40T0314;00803a@>00<0314;00X?2@0<4@/01@0>4`d2010E3P0500lD3@0>4``03Q<<
00hC300?50d00`0>4``200dB2`0700hC300?50d02a0900X?200;40T06b0I00X?200200lD3@0B00`A
2P0;40T03A8;00lC300>4@X04A@=01@G400=40T030l800lB2`0C5Pl041<<00lB2`0F6A804aH?018E
3P0@4``03a8;0P0@4``0200<3`P03a8;010C300A50d03Q4:00d@2@0?4P/04QD>0P0E6140100<3`P0
9BPQ00T<1`0A50d200d@2@0=014D3@0@4``04A@=01<F3`000`008B@M03m2>`0R9Ah03a8;03m2>`0^
<BX04QD>00d@2@02018E3P0301<F3`0?4P/041<<008051L@01D04A@=00lB2`0=40T030l800d@2@0A
50d051L@00`?200;3PL04QD>01TL5@0F6A802@`501PK500U:24061/D010C300C5Pl03A8;00/A1`0;
4PL00P0;4@L0100<4@L03A0700`?1P0?4@P2014B2P0D00l@200=3PH0<34[01/L5P0720802@X400d>
200E5Q0051D?028S7@0A4P`0414;00@500092P@03@h801HG4@0?40X03@h800H70@0<3@L600h?2@@0
3a0:0P0>3`T0300B4`d0414;00h?2@0>3`T03a0:010A2`0P8Qd01@L2018D3`0A4`h01`T400d?2PD0
3Q0;00L03Q0:00h?2@0?40X0414;014B300B4`d0414;00803@h802D03a0:00h?2@0;30H02@X501XL
5`0?4@`020X7010B3@010`0030h901XL5`0C5A003@l:00h@2`0:30L08RDN01TL4`0J7A@051L?01PK
500=40T02P`701TK5P0@4Pl07R0M00H81@0>40d02`d800d?2P0A4`h03Q0;00T;1P0>40/05aTD00/=
200:30L04aD@00804Q@?0P0>40/200d?2P0A00h@2`0?4@`03@l:00X<1`0;3@P030h900/=200A4`h0
30h;00T;200>40d03a4>00L91P0:30T03a4>01@F4`0;3@X00P0>40d01`0H6QL03Q0;00lA300A4`h0
4Q@?010B3@0:30L00P0@4Pd0100>40/030h900`>2@0>40/2010A300?01@E400B4`h03Pl:018C3P0>
3`X06AXE01HG4P0A4Pd03@h900X;1P0?4@`07R0K020R7@000@007b4L00803Q0;00<03@l:00h@2`0>
40/00P0;3@P01`0I6aP04Q@A00@60`0<3P/02P`901TK600=3``00`0>40d200lA3P07014B3@0;30L0
3a0;00h?2P051P4061TD010A300200l@2`0400h?2P0<3@P030d800l?3@804A4?0`0>3P`300d=2`80
3Ph<00L03@d:01HG4P0;30L02P/7010A30082@@04A8=00804Q<>00@02``700T:1@0>3`X030d80P0?
40/01@0=3PT0414<010A300?40/0414<00<03a0;00<0414<00l@3@0?3`l00`0@41002@0?3`l0410@
010@400?3`l03Ph>00l?3`0A4A403a0?00`>2`0300d?300C00h@3@000@006Q`I010B3`0>40d0>3Xg
02`^:`0B51<02@/:01PJ6@0G6AP04Q@C00@61@082PT02P`;02HX9`0>40l02`d<00X<2`0201@F4`0<
00d?3P0C51H03PlA01<D600?41D04A8G01<C6`0A4A/03`lI00h>5`0C51P04Q<E0P0=3Q00200C51H0
414C00X;3@0?41804Q<E028S9@0K71h05AHH0`0@4Q43014C4P0400/=300?4A00418A00lA40803@l>
5?ooool001_ooooo01803`d=00/:2P0=3Q003a0D00/?4P0<4A@03a@G00T>3@0=4Ph03`l=00/;1P0=
3@H03@h900h?2P0>3P/03`l=00l?3P0?3a4200h=4P0<00d<4P0=31@030/D00`;4@0C4a803Ph<00l?
3@0B4Q004A4?00`<2P0?3`d03Ph<0P0=3@/00`0>3P`03`l=00h>3P0200l?3`0R010@400@4180410B
01TI6`0L6b004A0E01@C600C4QP051<I01<C6`0=3A@03PlE010A5P0@4AD04a@H01DF6P0:2Pd061TL
010A4`0C51D04QHF00dC4@0=4A004Q@C010@400B41405aDF01HD5@0D51@04Q@C014E500@5Q@04aPJ
01@G70804ADH00`04QHI018F5`0B5QL041@E014E500F6QT061`K01@H5`0E6AT02`l@024U9P0P92D3
01@H6@0:018F5`0C5aP05ATJ01HJ6`0E6AX05AXJ01LM7@0C6AT051XJ00`B4P805Q`L00H05A/K010E
5@0G7Ad02a4A01TO7`0D61L201LK6P8041@C02`06AdN018F5`0D61T061`O02<W:P0=4A@0FUiR01hV
:00D7Ql041PK01HK8@0?51X06A`V01LK9P0E6bH05QhZ01XT<00I9C4062Hb01hX=00E7b/05R0/01TS
;`0B72L05R0Z018L9@0T;SL0628[01HQ9`0C7R@05B0V01HP:@0D7RL041XS01@M900I8RT051dT010G
7@0F7B<061lU01@I7@0N8bL06b0T02@/;P805b0R00X041TK01@M7`0G82404Q/L01XS9@0C71d06R<T
02D^<00M9BL05AXM0P0K82<01`0G71l051TM01HK7`0F6b406QlU01/P9P0I7BH00P0H72D0EP0I7BD0
61`V01DI8@0D6Al06QlT020U:P0H7B4051TM01@I700F71h05a`P01LM7P0D6QP04QPF010F500C71T0
4a`K00dF5@0=5aL04A/L01DO800?6a`02aLH01@N800F728051TO018G7@0B5a/051TM01HK7`0M8RD0
8bTY01@J6P0G7Ad041HF01PO7`0@6AP031@F01<K7P0@61/041LL01DM800A6A/03QLF00lH500@6Q80
4A/C01<L5`0@6AP03QHH00`C600C6R808RTc00`C7P0B62<05A/V01LN9`0@5al04APN01LM8P0D6Ad0
4QLJ01@J6P0D6QP03aDA00/A3@0>51004QPF01@I6P0B5aX04QLK01<J8P0@5al04QTQ01@K8@0A61h0
51/Q018J7@0@5aX0HVY/06=[K@0C6ad02a8D00`A500>4aH041DH0P0?51L0200@5AP03Q<F018G6P0@
5AP02PlB010E600;4A804QHG0P0?4a82014E500700`@3`0=4A0041@C01<G5P0>4Q40310?00lC4P03
014F4P03010E4@0=4Ph0314=0080314=00H04AHB018G4`0B5a<0?44m03i3?`0C61@300hC3`0:00`A
3@0A5Q802a0<00X?2`0@5A404QLC00dB3P0>4`l03A8>010E4@8051TE00L03a@@014F4P0@5A403Q<?
01DJ5P0>4`l04QLC008041DA00<04AHB010E4@0>4`l00`0=4Ph05`0>4`l03a@@00lD400?4a403Q8C
014E5`0A5AD03a@@00hC300?50`03aD:01@K3@0<4`<04AP600dD0`0<4PD041@A010D4`0?4a803A4@
00lD400B5a<041DA00803A8<00D03Q<=00hC300=4P/041D?00hC3@0200dB30803a@>1@0>4`d00`0>
4``03A8;00dB2`0300dB2`0300hC300?50d03a@=00803Q<<0P0=4P/020083@H02Pl800X?200E6Q<0
;C8[00/@2@0:3`P0314:0P0=4P/01`0>4``03Q8;00d@2@0A50d04aH?00`?200=40T00P0?4P/00`0>
4@X03A09010C300200lB2`0L00hA2P0?4P/041<<00lB2`0;3PL030l800hA2P0@4``03Q4:00d@2@0?
4P/05aXC00P;100?4P/02@`5014D3@0F61<04A@=00`?200>4@X04QD>014D3@0C5Pl030l801PK500B
5@l04QD>01@G40803a8;0P0=40T200lB2`0600d@2@0?4P/03Q4:00hA2P0@4``04A@=0P0?4P/02P0>
4@X03a8;00d@2@0:3@H03a8;00`?200>4@X04A@=01@G400A50d200`?200701@G400?4P/03a8;014D
3P0?4`h03A<900`C200200/A1P0400hB200?4PP030l500lA1`804Q<:00h03a4700d>1P0D5@l04A8<
00X;1@0@4@/03@h8014B300G61<02``601<D3P0<3@L071dG00/<1P803@h800@0414;00h?2@0=3PP0
4Q<=1P0=3PP300l@2P<0414;00<04a@>014B300@4@/00`0?40X01P0?4@`02`d800`>2@0O8A`02P`7
010B3@D03Q0;00<03Q0:00h?2@0>3`T0100>3`T200d>2080414;02D03Pl901HG4P2DUY40<38]01HH
4`0:30L01PP3018D3`0X:RD06adH014C3P0@4Pd01`T401hQ6P0A50/06QdD01<F3P0B5@h030l800`>
2@072@H0418?00@50`0W:BH0E5IC01<E400>40/03@l:00h@2`0=3`X04aD@028T7`0C5A003a4<018D
3`092`H02`d800803a4<00P03Q0;00d?2P0=3`X03Q0;01@F4@0=3`X05QPC01/M60803a4<00l03@l<
01LI5P0@4Pl01`T600lA3P0<3P/0418?01@F4`0<3P/03a4>00/=2P0B51405ALB014C3P0?4@`00P0>
40/0100;3@P03@l:00lA300?4@`200h@2`0D00lA300?40/03@h900d>2@0>3`X0414<01TJ5@0l?CP0
30d900`=200@4@`04A8=01HG4P0O8A`0EEMB00`>2@0E5a803Q0<00/=200>40/200d?2P0900T;1P0=
3`X051HA01hP7@051`@04aDB018D4@0<3P/02P`900H03Q0=00L0414<018C3P0?40/04Q<>00L80`0F
5a80414<00803a0;00@03Pl:00d>2@0=3PT03`l=0`0A4@l0100>3P`03@d;00`<2P0<30X200d=2`0>
00h>300@40d04a@?00`=200?40/04Q<>00/<1`0E5Q403a0=00P9100C50l03a0;01TJ5@092PD200h?
2P0500l@2`0>3`X03Pl:00h?2P0@4@`00`0A4Pd00`0@4@`03`l=00h>3P0400h>3P0900l?3`0>3Ph0
30`<00`<300>3Ph04A4A010A3`0=3``03Q0=00<03a4>02<04Q@A08^=RP0K7AX04aDB00T;200<3P`0
3a4@01<E500a<S4051HE00/=300A4a806A/J00H81`0>40l05QPG00/=300A4a801`T601DG4`0:30X0
51HF014B4`0=3Q403a0E010A5P0B4QX03`lI00d=5`0>3QP03PlC00d>400>3a40414C00l@4P0200`=
3`804Q<E00<09RLY018C5@0?41801P0@4Q40100?4A004Q@C01<E500A4a8200lA41Cooooo000Koooo
o`0C00l>300?3Pd02@/:010A5@052Pd02PlC0001100830h03A8>00D60@0?40T030`400h?2@0<3@P0
414<010@3P0=3@`03Ph>00h=4P0200h=4`0@00h=5@0>31L03PdC010@400=3@/03Ph<010@3P0C4a40
4A4?01DE4`0:2PP030`:010@3P0;2`T02@T700l?3`803Ph>01X03`l?010@4P0A4A<07AdO01LF6`0>
3A804Q4F00l>500D4aT07QhV00h>5P0?3aL03a0E010A5P0F5a`03a0D01LH700E5QX02``>010A4`0;
3`l0318@00hB4@0D5QD04A4A014?4080518C05D04Q8B014C4P0@51<041HD01<H6P0D5a`04aLJ018F
6@0A5AP04QHG010D5@0B5QL05QXI01<G5P0=4A003Q8A00dA4@0C5aP02@d>01<G600>4Q<06QhO01DI
6P0B5QL04aLH01DI6P0F6Q/05ATJ01DJ6P0A5aL051XJ01XP800K8B406AlO01HL700630`05Q`L01<I
6@0O9BD03aDE018F5@0E6AP05a/J01<G5P0B5QD05ATJ00hB4`0N8R<051PK00dA50072`h06AdQ01@L
7P0@6Q/041PK020U:`0B5ad0828^01HJ9P0I7b/072@a01HP;00B7RX05R@_01HP;00G8Bd06B<_01DO
:`0C7BP04adW01LQ:P0c?DH06B</010K8@0C7R@041/Q01TS;00E7bP03QPQ018K8P0I8RT05b0W01LN
900C6R004QTO00806QlS01@051`O014I6`0?6AX05b4R01<M7P0F824041XK02D_<00`>S/06R@U01@N
7`0J92D0218C01HK7P0H7B005a`O01HK7P0E6Qd051TM01TN90805Q/Q00H05a/T01DI8P0D62405AXP
01HK8@0D6Ad201LL801K01<H6`0D6A`04AHI014G5`0D6QX05Q`L01HL6P0B61@04ALE00lE4`0C71T0
5AhM018K6P0/=SD06B<T00lI6P0C7al01Q8B018L7@0D6R004QLM014F700C61`05Q/O01PM8@0Q9RT0
9bd]00lE5@0F71`04aTI01TP800H8B003QHH010H6`0A6A`03QHI00dE600?61L03QLF00dF4@0>6100
3aT@010I500>5aH00PX<014I7@0>5Al04QPT00T?6`0A5b<051XV00hE7`0E72@04aXP00`B5`0@5AT0
4aPK01LM7@0E6aT04ALC00`B3P0A5a<05A/I01@I6P0C61/04AHJ01@K8`0@5al03QDM00`C6@0941H0
2a8H00L?4P0D71l0<c/m04A<CP022P`05QhP00dB5@0>4aH04QLJ01DJ7@0D6A`03a@G018G6P0J7b80
4AHI000110062`h03a@F010D5@0200lC4P8041@C00L03Q8A00P<2`0=4A004ADD018F5@0F6QT061`K
0080314=00/03Q<?010E4@0?51002a0<00lD400<4@d03Q<?00lD400<4@d0;c@`02@Y9@02010E4@06
00/@300=4Ph041DA01HK5`0A5Q803Q<?0P0@5A401@0<4@d04QLC00hC3`0;40`0314=00<03a@@00d0
41DA00lD400B5a<0314=01dR7P0C61@03Q<?00dB3P0B5a<03a@@00/@300=4Ph03Q<?00803a@@0P0>
4`l06P0B5a<051TE018G4`0<4@d03A4@00lC4P0>4Q0041DA00@91@0;40/03A8<01<H4P0C5aH0310?
00/?3P093@`02a0<014F4P0?51004QLA010E3`0<4@/03Q<<01<H4@0H7AL041D?100=4P`500hC3@03
00`A2P0:3`P02a0900<0314:00@03A8;00hC300>4``03Q<<0P0=4P/03@0>4``03a@=00/@2@0:3`P0
2a0901/P6@093PL03A8;00hC300=4P/02Pl800/@2@0=4@X00P0=40T00`0?4P/030l800d@2@0200lB
2`05014D3@0@4``041<<014D3@0>4@X00P0=40T2010C300400hA2P0;3PL030l800hA2P8030l800P0
3Q4:00D80@0G6Q<04aH?00hA2P0K7QL0?T4j014D3@803A0901004A@=010C300A50d041<<01@G400:
3@H092LP024T7@0;3PL02Pd600lB2`0C5Pl03a8;00hA2P0B5@h03Q4:0P0?4P/3010C300D00hA2P0<
3`P04aH?014D3@0?4P/06ahG00hA2P0@4``03Q4:00/>1`0<3`P041<<018E3P0620@0008000/>1`0F
6A806b4G00hD2P0>5@P200hD200400lD200@4`P03A0500lA1P80418701003a4600h@1@0@4@/03a0:
00T:100?40X02``600d>201HFE<0@d@n010A2`0A4Pd02P/500T:100?40X01PL10P0=3PP00`0A4P`0
20T300h?2@0500h?2@80414;1P0?40X4010A2`0600lA300:30L04A<>0084000620<03@l:1@0>40/0
2P0?40/03a0:00l@2P0>3`T030d700/<1P0>3`T03a0:00h?2@0@4@/2018C3@0E00d?2@0E5a801`T4
00h@2`0T9R404aD@01@F4@0O8A`05aTD00h@2`0=3`X01`T400lB2`0520005QT@014D300@4``04A@=
018D3`0A4`h03a4>0080004000T071dK01lQ700D5Q402`d800`>2@0;3@P03@l:014C3P0<3PT00P0>
40/0100;3@P061XE00h@2`0>40/200d?2P0F00h@2`0?4@`02@/600P:1@0G6A@06Q`G00`>2@0:30L0
6adJ02X/:@0I6aP01PP501@F4`0<3P/01`T600`>2`0:30T04Q@A010B3`0D5Q<07AlJ01DG4P803Q0;
00@0418=014C3P0:30L03Q0;0`0?4@`02`0@4Pd04A8=00`=200<3@P03@h901<D3`0O81/0LgA_01hO
6P0E5Q404Q<>00803Pl:01<03Q0;01DG4P0>40/06adH00/<2@0J71L04Q@?00/=200=3`X02`d8018D
3`0N81/0GV1M00h@3@0B51400`D201LI5P0@4Pl03a4>00<03Q0=0P0=3``2010A300400l@2`0=3PT0
7QlJ00D60@803@h90P0>3`X200l@2`06010@3P0?3`d03`l=010@3P0>3P`030`:0`0=3@/200h>3004
00h?2`092PD02P/600l@2`80414<00h04a@?05UJE@0N7aX03a0=014B3@020`00414<00h?2P0?40/0
4Q<>00h?2P0<3@P03a0;010A30<03a0;00<0414<00l@3@0=3@d00`0<30`00`0=3@d03Ph>00d=3@02
00`<300400d=3@0>3Ph03Pl>00d?30803Q0=0P0?4@h06`0A4a005aTF00lA3P0;3@X051HC00P:1`0>
40l02@/:01PJ6@0A4a80418A01DG5P0>40l00@<2018D4`0[;B`030h=00d?3@0F61D00P@0020R7`1O
HF000`D401<D5P0>3a@03a0E010@600200h>600=010@6`0@4AD03PlA01<D5P0H6A/04A8D00d>400?
41802``>014B500<3@l02``>01<D5P03010B4@<03a4@00@03@l>010B4@0A4a803Q0?0P0<3PdDoooo
o`006oooool05@0>3@/04a<B00X<2`0?41@01@X=01HK7`0/<CD01`/=00hC3`092PD04a<<00H6000>
3`T030d7010A300@40h030`;00h>3P0?3Q<03`hD00l>5P0200l=6008010?5@0;2`/02@T700X:200?
3`d051@B01<C4@0K6aT200l?3@0A00`<2P061P@01`L500l?3`0>3Ph03@d=00l?3`0@41804A4C01<C
5@0@3a@02`X?00`;400>3A<07QdS01lO9`0?3aL00P0B4QX05@0A4QL05QLL024R9P0B4aL051DI01PI
6`0I6Q`03A4A00/A3`0?4a805ALF018B4P0@3Pl0518C01DC500C4a<04Q@C010D4`0?5A<04QLH01@G
700201DI700G01<G6P0C5aP04QHG01DI6P0H71/051PG00lC4P0B5QD041@D030d=@0;3a006QhO00hB
4`0K7b003a<D018F5`0C5aP05ATJ01HJ6`0E6AX06AhO01PN7P0F71`00P0=4a<01@0;4A403A<C03a2
@P0B61P07B<S0080728R00<04QHE01<G5P0F6QT00P0F6QT0700E6AX04QHG00`@4@0C5aX07b<V01TM
800@51T04a/M00lI6P0A6A`0:Rle01@I7`0D5R805a/W01TO:`0K8c005R0/01<O:`0F92l05R0/028/
>00P:SH04adY01@N:@0@6R@05AlX02@^=`0B72D3010K8@805b4Z01d04A/T01<L8`0H8BP05QlV01HM
8`0J8BL04APN01PM8@0F6al0=Ce001dU9`0G8B806B<T018L7@0C7Ah0218C008<3@0K9BH041XK00hH
6@0O:BX04A/L01<H6`0I7R406QlR01HK7P0I7R4082DY01`Q9`02014F700C01PL9@0I7BH05a/T01HK
800K82@06AhR01/P8`0F6ah03a@G018H6@0@5QH04ALG01DK6P0F71X05A/I01<I5@0E6aL04ALC010I
5P0201@M6P0D03M1@00V<34051hO010L700:5QH02A<D01DK8@0D6Al04aPN01<H700D6Ad05AXN014F
6@0H7Qh05Q`L01DK6`0I7al0620O01`U900G7b42014I700j00dE6008418031DD014J6@0C71L04A/C
018L4`0A6a@051dL00hF600H82@0ADaF00/A7@0K8Bl051XX01<I9@0D6bD05ahV014H7P0;4AH041DI
018G6P0B61P03aDC00lE4@0@5Q805Q`H01HL6P0?5AD04QLJ01@I7@0:4AT02A0H00hE7@0A61h03A@J
00`C6@0430l05QhQ014I6`1EGEl0;3@f00`D5P0?51L03Q<F01<H6`0K82<06QlR00hC5P093Q404AHI
00hC5P0J7b807b@W014G600=4A803Q8A010D4`803a<B01d041@C00X>3@0>4Q4041@C01<G5P0I7A`0
5a/J00dB3P0<4@d03a@@014F4P0@5A402a0<014F4P0<4@d041DA01TN6P0:3`/0314=000300083@T0
5a`H014F4P0@5A402a0<01@I5@0B5a<041DA00lD400200hC3`8041DA00d03A8>00`A3@0?51004QLC
00`A3@0@5A404AHB018G4`0@5A40:c0/010E4@0?51003Q<?00<041DA01l03A8>00lD400@5A4041DA
00lD400>4`d04AH?01<H4@0@5@l02`l=00dA4P0A5AP030lC00`?500931<05QTP00/>5@0=41D03A4A
010D4`0I7A`041@C00T>2P0B5a<041DA014F400@5@l03Q<=010E3P0B5a004QLA00803a@>00<041D?
00dB300<4@/01@0>4`d00`0<4@X02Pl800`A2P0200dB2`0300`A2P0=4P/03A8;00803A8;0P0<4@X0
1`0=4P/04aPA00/@2@0=4P/01@X300lD3@0;40T00P0>4``05P0<4@X02a0900`A2P0?4``03A0900`?
200@4``03Q4:00`?200>4@X041<<018E3P0>4@X02Pd600/>1`0A50d03a8;00d@2@0?4P/041<<00lB
2`0=40T200hA2P8030l800P04A@=00X=1P0S9Ql02Pd6010C300L7aP0=CPa018E3P803A0900P041<<
00hA2P0?4P/010L000/>1`0@4``0>3/d02`_:0803a8;0P0@4``02`0>4@X041<<01<F3`0>4@X03a8;
010C300?4P/041<<014D3@0D5a002`h700803A0900H061/D034d;@0@4``03Q4:00d@2@0>4@X2010C
300800`?200>4@X05APA01XM5P0:3@H010X000hD2P0?5PX2014G2`04014E2P0@4`P03a8700lA1P80
3Q0501003a46010B1`0B4`d03Pl900L80P0>3`T02``600h?2@0e=S00;RlY00L80P0?40X04A8<01@E
3`0B4`d030d70P0?40X00`0G61801`P200h?2@0500h?2@0400l@2P0>3`T03@h800d>20802``600<0
3@h800h?2@0?40X00`0@4@/01P072@@02P`701@F4@000@00<38]00P:1PD03Q0;00<03a4;010A2`0?
40X00`0?40X2018C3@803a0:0P0A4P`02P0E5a40004000h@2`0?4@`05QPC00D70P082PD04A<>010B
3@0=3`X200lA300H018E3P0:3@@05QT@010C2`0@4``03a8;00D70P0C5A0020T702/]:P041P<05aTF
01PJ5@0B50l03Q0;00d?2P0:30L030h900T;1P0:30L030h9010B3@0G6A@092HQ0`0=3`X01`0>40/0
3a4<014C3P0<3PT02P`700lA300A4`h00P0;3@P01@0H6QL07R0M01HH5@0<3P/03a4>008030h;00l0
3a4>00/=2P0A4a002`d:00`>2`0F61<04A<>00h@2`0?4@`04A<>010B3@0;3@P03a4<010B3@0?4@`0
0P0>40/06`0@4@`03@h900l@2`0>3`X0414<01PI500N7aX01@H301@E400:2`H03a0;00T:1@0:30L0
4A<>00lA300620<03Q0;0043000@4Pd02@/600h@2`0?4@`051HA01lQ700L7Q/01`T6018D4@0200d?
300300L91P0?4@h03a4>00803Q0=0P0=3``02P0@4@`02P/6010A300@4@`0@d@o00X;1P082@@02@X5
00X;1P0=3PT200h?2P06014A3`0=3@/03@d;010@3P0?3`d03@d;0`0>3P`200l?3@0N00l@30082@@0
30d800l@2`0;30L04A8=02`]:01TIF0061TD00d>2`082@@01PL2018C3P0?40/0414<01DF4@0?40/0
3@h9010A300?40/03Pl:00d>2@0>3`X03a0;010@3P0>3Ph03@d=00`<300=3@d03Ph>0`0@410300l?
3`0300h?3@0=3``03@l<00<03Q0=00T05ALD0001000?4@h02@/801XL6@092`P05QPG00/=30082PT0
0P0?4A0040092`X04aDD01<E500?4A006adL010B4@0e=cD03Q0=00L9100S9B80Gf5P00`>3@0@4A<0
3@hC00l@5@0@41T200l?6`0=018B7@0C51P03a0B01<D5P0H6A/04Q<E014B500>3a403@h@02TZ;008
2@/03@h@00l@4P02010B4@803a4@0P0>40l01P0=3`h0418A014C4P0>40l030h=00/=31Cooooo000K
ooooo`0V00X:1`0C51402@/:00h?4@0<3Q<08bL[07YlP@0D5aX02P`=00/<300<3@X06QXF00l@2P0=
3PL03a0;010A2`0=3@X03@d<01DE5@0@41<02`X>010?5@0?3QD04Q4G00h>4@0>3a404A8D00d>400>
3Q002P/=010@4P0?4180410B00l?4@0720X05ADG014A4P0?3a0200/;300400h?4@0?3a40410B014A
50804Q8F02l04Q8E01dO900@51h03A4K00P;5@0E6B801`XB01TK8@1GFEh05aPL00`=4@0B4QH05ADH
018D5P0?4A80418E01@F5`0A4Q<04A4D01DD5`0B4a@05QHI01LH6P0C5AH051HI014E600D5a`05QXN
01DI7@0D61/05AXM01DJ700A61T04AHH00lF5@0>5Q@03aLE02@Z:P1<D5808RHX01TM7`0@51H06alQ
018F600D61X05ATK01HJ700201DI6`1G01DJ700?51P04aPK00/A4@0I7al051XH01hT8`2DVYT07R@T
01@I6`0E6Qh051XM01<G600C5aH06QhM01<G5`0D61P051PJ01LK7@0;3Q8061/P00T<4P0I728061/Q
010G6`0E6b0051TO02T]=@0J7BL05ATT01HI9`0F72/06B0`01PP<00E82l05b4a014I;P0X;dH092]1
024Y?P0I8SD062@c01PS<@0E7b`051hY01DN:00I8bX06bD[01HN9@0J8bT06B4X01PP9P0I8RL06R8V
01@K800S:Rl072@X01LN8@0P9bX0FF5T02@];@0C71X03aTG010G600B6QX041XJ01HL7`0T;2h08BX/
01lV:@0R:Rd05alS01<K8@0P9Rl082L`01TO9P0K8RP0:30f028Y;`0G7B805QlS01HN8P0C6Qh051/O
01TN8@0R9RX07R8V008051TL05405QXM01<H6P0B5aT051TK01DJ6P0F6a`05a`L01HK6@0H7A/05AXG
014G5P0C61P04QTJ01DK7@0B61/05QdP018J7P0H7b<051XP01HI8P0D61l051PM01@I6`0B61L04APD
010H500@61<05alM01@M7@0@5aX05AhR018K800G82D04QXO00lG6`0;4QL03QHH01<J6P0H7al061lL
018K4`0A5a004QPC018J6@0@51L07b@X05mUJ`0G6R<05a`V01@I900B5B004QHQ014G800@4ah04QHK
01DJ7@0F6ah04aPH010E4@0@5Q4051XE01PM6@0F6aT03Q<D00hB5P0C5ah04ADJ01@J7`0N8bP092P[
01DL7@0A5aL05a`K00XA400>5A@04aLI01LN7`0<41<041@G00hC5P0A5AL00P0F6Q`09P0>4a@03A8D
01DJ6@0@5A@03a@C00dB4@0>4a403A8@00lD4P0A5Q<041DC00lD4`0A5QD02@h=01HK7@0@51H03Q8E
014F600>4a@04QHE00hC3`0D6AD05AXF00hC3`0<4@d04AHB010E4@0J7a/09b`X01`Q7@0>4`l04aPD
010E4@0>4`l02a0<018G4`0A5Q803a@@0P0@5A401P0?51003Q<?00lD400=4Ph03a@@010E4@803a@@
00P041DA00dB3P0>4`l02Pl;01PM6@0A5Q809b`X00dB3P<03Q<?02H041DA014F4P0<4@d03A8>00lD
400@5A403Q<?010E400@5@h041D?00hC3P0;40d03a<C01<G600>4Q<04ADI01TM8@0P92P03Q4F00X>
4@0>4a002a0>00dC3P0>4a002a4<00T?2P0>50h02a4;00dC300?5@l03A<<00/A2P0<4@X02Pl800hC
3@0I7QL051TC00dB2`D03Q<<01803A4;00d@2P0?4P`041<=00lC3@0@50h03a8<01@G4@062@D030l9
00/?2@0@4`d02`l9014F3`0;40T03Q<=010E3`0B5a4300dB2`0;00`A2`0>4``03a@>010D3P0;3`P0
310901<G400>4P/02Ph700/?200<40T00`0?4``0200B5Pl03a8;00lB2`0>4@X03a8;010C300=40T0
3Q4:100?4P/0200A50d09RTR02ha:P0<3`T04A@=00L:0`0A50d041<<0`0?4P/01@0=40T03Q4:00`?
200D5a002Pd700804A@=00L041<<01<F3`0B5@h041<<00lB2`0>4@X030l800803Q4:0P0=40T04@0>
4@X041<<00lB2`0>4@X041<<00lB2`0<3`P051L@010C3@0>40/030h801<E3`0C5Pl03Q4:01@G3`0A
50`03a8800804A@:01P06R0E00dE2P0=5P/05AhB00lF3@0>5@/041L;00T@1`0J81H06QlD00hC2`0:
3`D03Q8:00`>200?40`03Q0:01@F4@0D5Q805QPB02X/9`0;3@T061TD00/<200/;BT300d?2@0_00h@
2P0>40T051H?00X<1@0>40X03@l900h@2@0A4``03Q0:00/=1P0E5`d02P`601@F300=3`L03a4:00h@
200<3PP01PP400T:1@0B50h03a0<01DG4P0D5Q4041<=00d@2P0G6Q@0C4i801HH4P0>40X03A0:00lA
2`0?4P`03a4;00h@2P0C5@l071hG01<E3P0C5@l04A<<01@F400A4``03@l800h@2P0A4`d0418<00`>
200D5Q400P0@4Pd0100;3@P04A<>00d?2P0:30L200h@2`1A010B3@0C5A00418=00P;1P0:30H030l9
00lB300<3`T04aD@00h@2`0A4`l01`T500T;1`0A4`l03`l;00l?2P0@40`03a0;00`>2@0?4@`03Q4<
00lB3@0<4@X030l:00hD3@0@5Pl02`l900h@2P0?4@/03@l900`?2@0?4@/04QD?01TK5@0;3@T02`d7
014C3@0<3`T03@l;00/=2@0=3`/03a4=00`>2P0>40`03a4=014C3`0=3`/0418>00/=2@0:30P03a0=
00d>2`0>3``03a0<00h?2`0?40d03Pl;010A3P0A4Ph03a0=00d>2`0;30T02`d900`>2P0?40`03Q0<
00d>2P0?40`03Q0<01@E4@0H6QH01`T501<D400@4Ph030h900lA3@0F61<05ALB01LI50092`H04Q@?
00803Q0;00D03a4<00P:1@0D5Q405ALC01<E4@02014C3`0M00`>2P0C5A403a4=014C3`0<3PX03Q0<
010B3P0<3PX0414=00H70`0E5A80410=03`m>@0E5Q803@d:00d>2P0>3P/03a0<010@3@0@4@d04A4>
00`=2@0=3PX04A8>010@3@0>3P/03@h:00h?2`0?3``00P0?40`0300A4@h03@d:010@3@0?40`020P5
00h?2`0g=c@0:b`X00P91`0@40d01@H401TI5P80418=02L0414<018D3`0?4@`03Q0;00lA300=3PT0
3Pl:00l@2`0;30L03Q0;01HG500;30/05AHE01HG5@0:2`T04A8@00h?3P0<3@`07QlM00h?3@0E5Q@0
30d<00l@3P072@H030h;00h@3@0?4@h030h;00/=2P0F61D03@l<00/=2P0=3``030h;00l@400A4Q40
2``<01dN7@0>3`l00P0?4100700G61L03a0@00d>3P0A4Q80;c0`00X<2P0E5aD02@/:01<D5@0D5AP0
30d@00`=4P0>3a@04A4J00h>5`0?3aP0820Y01/L7`0F5aP04A<C010A4P0@4Q805AHG00l@4@0B4a@0
;Bh_01<D5@0A4Q<200`>3@0601<E4`0E5aD07AlM00h@3P0?4@l04aDC0P0D5Q@00`0B51803a4?00h@
3P0Dooooo`006oooool03`0:30L02`d900<50P0<3@l01`L;00/<4@0K72401`P=00H7300;310030d@
01HH5`0>3`T03@h700`=1`0200d>200700`=200K6aT0000000d=3@0G5aT02@P=01LF6`02014B5`80
30dB0240414F018C60030`P051DJ00T:3`0A4QL03@hC00@52@0;30h03a0B00h?4@0?41803PlA00T:
300<3@l0414C00l@4P0B4aD05AHH02X]<P0J8Bd02Q0L01HL:00W;SP03a<L00dA6P0N8BP04a@I018C
600920h040lD01HF6P0E5QX00P0A4QH02P0C51P03a0D00/<400<3A403a0D01@E6@0>3a<03@hB00lA
5P0@4aP3014D6@05018G6P0C6Q`041PJ00hF600?61P00P0A6aX02P0D6a`06AdP01DI700?4aH051PK
01LK7P0E6A`051PK01DI700F6Qd201DI700b01<G700@5A/06b0T00`A50052`/041HC00T?2`0R:2H0
5A/K014F6P083A405a`S01<G600>4Q403a<B00lC500P92D02`lB00`?500A51T010L>05mRJ`1iO8D0
4aHO018E7P0G6R<04QDN028T<00L7RX041@P01HL:P0H7Rh06R0a01PO<@0H7c806b8f01lR@@1>DG80
7R=2018I=@0L9Sl04Aha024^@@0^>DX082Xf02@/>@0G7RT05A`T01/R:00J8RD201TQ900]01PP8`0F
7R405AdP01DM800H82<05QhQ01TQ900Y<C<0:c4_01<I5P0=4a403Q@B00/A400?5AD05AXM01LL800P
9BT08BH/01`Q9`0I82P06R0^01XQ<@0F7R/04QXU018K9@0F7bH05b0U014K7@0F82404A/K00dG5P0E
7Qd061dP01PL7`0D61/03Q8E00lC5P0A5AP03A4D00`@4`0A5AP04aLJ01@H6`0G6a`05ATI00805a/J
04X051PI01<G6P0D61/041<H010C6P0D5ah03A0G00hA6P0B5Ah04aDQ014D6`0A51T04aPF014H4@0@
5`l04A/A02H`:00<5A801a4C00@=500>5b002Q8M01<L9@0A6B4051/S00dD6P0E6ah04ALG01<G600D
61H051TE01@I4`0C61D04aLH01DI700F6Qd05ATL01<F6`0A51X05APO01DH8@0B51l051HR01<E8@0?
4QT041@G014E5P0B5QD04aPD01@I4`0B5a004QLC01@H5`0A5AL03Q4F01@G7`0:3A804aLJ01DI6@0B
5QD01@X600dB300A5Q003a@>00dB3P0?4a@041@E00dA500?4aH03Q8E00hB4`0=4A803Q8C00lC4P80
41@C00@04AHB018G4`0B5a<04QLA0`0?5A401P0?5A<041HD010F5P0F6ah09BX]01<H70803A8H00d0
5Q/P00hB4@0?51007b@P020U8@0>4`l01``800lD400>4`l03a@@014F4P0?51002@h:00804AHB00D0
41DA00lD400C61@061dI010E4@03014F4P03010E4@0>4`l03Q<?00@03a@@00P03Q<?00870`0U:RH0
00D100L<20093PX02a0<00lD40803A8>018041DA00lD400>4`l03a@@00`A3@0?51003Q<?00dB3P0@
5A403a@@00hC3`0<4@d02a0<00hC3`0A5Q804QLC010E4@0?510200L<200B00lD400>5@h02Q4:00dD
3@0>5@h031<<00hE3P0=50d031<<00dD3@0?5Pl031<<00XA2P0>4``0314:00dB2`0D6A804QL@1P0<
4@X00`0<40X03Q0;010B3@02010B3@0F018D3`0?4@`0418=010B3@0C5A0010H1010B3@0A50l03Q<=
018G4@0H7AL05Q/E01<H4P0?50h02a0:00`A2`0>4`d04AH@018G4@0@5@h03Q<<00lD3@8041D>00<0
3Q<<00/@2@0;40T00P0;40T200`A2P0701HI4P0930D06A`E00d@2@0;3PL04A@=010C3002014D3@0@
010C300>4@X030l800hA2P072P<06QdF014D3@0I71D030l800hA2P0@4``04A@=00lB2`0=40T03Q4:
00lB2`803Q4:00<03A0900hA2P0?4P/00P0>4@X0100=40T02`h700d@2@0?4P/600hA2P0I00d@2@0<
3`P02`h700/>1`0:3@H02@`500H81@1NH5d06adJ00T;1P0520805QTB00lB2@0=40H02`h300`@0P0>
4P@03aD903e5>P0P:R405b4H01PR6@0S;B@02aD<004;0P0201DO5P0500/E30094`X03A@<01LJ5`06
20D00P0;3@X02@082PL03Q0=01PJ5`092`P02P`900h@3@0?4@h071hI00h@2P0300lB2`0400hA2P0=
40T04aH?00lB2`802`h702P030l800`?1P0;3`<000<000lC1@0;3P<04QD<010C2P0A50d05ALB01XL
5`0G6AH02@/800lA300?4@/020/400/>1`0A50d041<<00hA2P0=40T030l800hA2P0@4``03a8;00`?
200@4``071lH00d@2@0E61403a8;01<F3`0?4P/030l800d@2@0>4@X030l800X=1`0<3PT03@l:0`0>
40/0600=3`X04aD@01@F4@0?4@`04aD@018D3`0=3`X04Q@?00h@2`0:30L03a4<01DG4P0>40/030h9
00lA300@4Pd03@l:010A300B4@d04Ph;00h=2@0>3`X03a0;00d?2P803A8<0P0<4``01@0;4P/02149
00X?200<3`P03A0900803Q4:00P03A0900X=1P0<3`P04QD>00lB2`0L7aP02`h700`>2@@03@l:01<0
2`d8018D3`0A4`h03a4<00d?2P0;3@P02P`7014A3`0?3`d04A4?00l?3@0<30X04A4?00l?3@0A4@l0
3`l=00`<2P0;2`T030`:00803Q0=100=3``0900;3@X04A<@00h@3@010`002P`9010B3`0>40/02`d8
014C3P0I6aH05ALB00P:1@0A4`h04aD@00/=200B50l05QPC02d_:P2WZJ@08R@O00P:1@0B50l030h9
00/=200D5Q405aTD010B3@0D5Q405aTD010B3@0>3P`00P8000`<2P0B4Q005ADC00/;2@804A4?0P0@
40h200l?3@803Pl:00H03a0;014B3@0@4@`03Pl:00d>2@0>3`X300l@2`0300/;20071`D02`/90080
410>00D05aLE01dM6`0@40h04a<A01DE4`0200h>300>00`=2@0;3@P02P`700d?2P0@4Pd04A<>010B
3@0:30L030h9014C3P092`H03@l:01/M6@0D5Q<2018D4@0>00X<2@0?4@h04A<@01@F4`1OHEh07AlL
0001000<3P/03@l<00T;200G6AH04A<@00`>2`0B514200h@3@803a4>00X03Q0=00d?300@41006ATI
03<c<`1IFET06ATI00h>3P0<30`03@d=0`0@41008P0?3`l04Q<E00/<3P0<3@l04Q<G00h?4`0A4QH0
3a0E00d>4`0=3AD02PXB00P8400E5A`051DG01@F5@0E5aH04aDD010B4@0=3`h02`d<00h@3`0?4A00
3@l>00lA400A4a805aTF00X<2@031@807AlL00lA3P0=3``0418?00h@3@0?4@h2014C400300lA3_oo
oooooooo01;ooooo000Kooooo`0500`>2@0:30P01PP500l@4P0@4A@00P0<3A80=@0E5Q/02``A00H7
2`0<3A002@/:014B3@0A4P`03a0:00d>2@0;30L02P/600/;2P0D51<04a<C014A4`071`T0410B00h?
4`092Ph01`P<01DF6P0=3Q807QlS01TI7@0B4aL06AXN00h?4`0=3Q8030dA00d>400<3@l03@h@01DF
600G61X04A8D00l@4P0B4aD02``>010A4`0H6A/0D5=G07MnR00@5R803QDP00`C7@0B5Ql02PhG00hA
600K7240824V014@5P0H5a`030`A0080414E01T051DI024R9P0K7200414E01DF6P0@4AD04a@H014B
5P0?41@05aTN018E6P0@4aP04QDJ01<F6`0A5QT041HI00hF600=5AL041TK01<M7P0D7Ql04QPK01<G
6P0D61/05ATL00805a/N03T05QXM01@H6`0A5AP05QXM01PL7`0E6A`04QHL00X?5@0R9b/06QlR00dC
4`0E6aX07B<Q00@:200F71d0314E01dR9P1LHFP03a<D01TM700N8R<0310A01TM7P0B5QT01@P=020S
:00@4aX0A4M>061SJP0F6B4051LN01@G7@0D5ah07b8Z01lR:`0Y;CP06R4/01XP;@0G7B/051`Z01LN
;`0N9CP0;S5?05=FMP0T:DP082M301HQ>@0B7c80AE9T04iIJ@0M9c<072@`018J900L8b/06R4W01HN
8@0G7b800P0J8RD08@0F7R406b<V01DM800G7b806R8U01TQ900E7Al0=3Xj020V900H7Q`061hN01DK
700H7B005Q/O01DJ7P0H7B4061dS01DJ800G72D08bTf01PO;@0C6bL05AdX01HN9`0A6R405b0U010J
700B71h03aTI00lI600F7ah04QLJ01@H6`0201DI701<014E600?4aH05a/N010D5`0D61/05QXM014E
600A5AL05ATI01LK6P0F6QT051PI01<G6P0D61/04aHK01/N9@0@4aX05QTP01DH8@0B5Ah05QTQ01<F
700C5aT05AXG01@K4`0C6Q804adD01TS700C71/041PK00lH800D7BH041TR01PQ:P0=5Ad061lV00`D
600?5AP04QPH018F5P0B5a@04aPD01@I5@0C61H04QHG01<G6P0D61/04QHI014D6@0B5A/05APO01HI
8P0D5b005APQ01@F8P0D5ah04aLJ014E5P0@51@04AHB014F4@0B5a804aLE01@H600A5AP03a8G01<F
7P0=41D03A4D010D500W:bX09R/W00`A2`0C61804QLA014F4P804ADF0P0@51L01`0?4aH03Q8C00hB
4`0>4Q<041@C00dA400>4Q400`0@5A40500@5@l0318>00`B3P0>51003Q@B00lE4`0@5QH02@hA01XO
8P0<4AD02a0D00lD600F6b003Q8A00hC3`0J7a/07B8N01@I5@0B5a<03a@@100>4`l0200;40`03A8>
00lD400>4`l03A8>00lD400C61@041DA0`0A5Q80100@5A403a@@014F4P0@5A4200lD4006010E4@0A
5Q803Q<?028W8`0=4Ph04QLC0P0?5100300A5Q803a@@00lD400@5A403a@@00dB3P0?51003A8>010E
4@0=4Ph02a0<00dB3P803Q<?00D03A8>00/@300>4`l041DA00lD400200hC3`0600dB3P0M8Qh0;34]
018I4P0;4P/03A@=0P0?5Pl03@0B6A803aH?00hE3P0?5Pl041L@00lF3`0=50d03A8;014F3`0=4P/0
2a0900lD3@0>4``01@0=4P/05P0=4@/03Q0;010B3@0@4Pd03a4<014C3P0D5Q406A/F03m1?00G6A@0
3@l:01HH4`0A5100314;00dB300G71H0314;00X?2@0C61803Q<=00X?2@0;40X200dB300800dB2`0;
40T02a0900hC300@5@h03A8;00/@2@0=4P/200lD3@0:00dB2`0;40T071lH05IIDP0G6Q<03a8<01DH
4@0A50d03A0900hA2P@041<<00d05APA018E3P0=40X0OH1i09VLU@0G6Q@03Q4:010C300A50d03a8;
00d@2@0>4@X03a8;00803Q4:00/03A0900hA2P0?4P/03a8;018E3P0C5Pl03Q4:00d@2@0@4``03A09
00hA2P02010C300@00hA2P0=40T041<<00lB2`0=40T030l800/>1`0:3@H04Q@@04M9AP0J71P03@l:
00h@2P092`L03a8900hA1`803A0501/041<700lE2@0A6@h04Q`C020Z8@1NJ5l0Qi6801lY800>60l0
2aD<00LA20094`X03QP?00hE3@0U:2D01`T600d?300@4Pl02P`9010B3`0;3@X04A<@00d?300?4@h0
414?014C3P0?4@/00`0@4``05P0?4P/03Q4:00`?200=40T03a8;00hA2P0=40T03a89018E2@082`<0
41<800lB1`0@4`X02Pd400hA2P0J71L07R0K00d?300C5A804A<>010C300>4@X2010C308030l800@0
3A0900`?200>4@X041<<0`0?4P/0100H6a@02`h701DH4@0<3`P200lB2`07010C300?4P/041<<018E
3P0?4P`02`d800`>2@0200d?2P8030h90P0>40/04P0:30L02`d800lA300A4`h030h900d?2P0@4Pd0
3@l:00X<1`0@4Pd03@l:00h@2`0@4Pd03@l:00d>2@0B4Ph04A0<00l>2P803a0;01L03@l:00hC3@0>
4`d03Q<=00/B2`0:4@X02A09010D3@0>4@X030l8010C300A50d03Q4:01DH4@0@4``03Q4:00`?2@0?
4P/041<=014C3P0@4Pd04A<>010B3@0200h@2`803a4<0`0>40/0200=3`X0410>00l?3@0A4@l03`l=
00`<2P0@40h03`l=0P0@40h01@0?3`d04A4?01@D4P0C5A80418?00803@l<01003Q0=00lA3P0:30T0
3Q0=010B3`0A4a00BD]807=eLP0>40/03@l:00lA300@4Pd03a4<00/=20092`H03a4<0P0;3@P04`0@
4Pd07R0K05]MF00B50l03a4<014C3P092`H04A<>00lA300A4`h030h900lA300A4`h030h900/;2@0P
81h030`:00l?3@0<30X00`0@40h200l?3@803Ph<00<03@h9014B3@0A4Pd00P0?40/00`0A4Pd03Pl:
00l@2`03010A300@00l?300?3`d04Q8@014A3`0<30X03@d;018B400D51802`/9010@3P0A4@l030`:
01<D4@0=3`X02`d800`>2@803Q0;00@03a4<00T;1P092`H03a4<0P0<3PT0500B51007AlL010B3`0@
4Pl04Q@A00P:1`0@4Pl030h;01`N6`092`P05aTF00d?300>40d030h<01/M6`0H6QL03@l<014B400=
3``03Q0=100@4Pl0200D51@06a/K020P800X:2P020P800l?3`0=3@d03Ph>100?3`l0900>3a402@X<
014B500F5a/020T=01@E6@0G61d04a@I014B5`0C4a/04A4I00d>500<3@l03Q0?014C4P0B51<0418A
00h@3`0B51<07b4P01@F5@0<3Pd04A<B00lA400<3P/0418?00d?300K7AX0418?00d?300C5A80418?
00d?300?4@h04Q@A00d?31Cooooo000Kooooo`0=00P:1@0?4@d02P`900@51`0?41@05AHK010A5P0=
3Q<02``A00/<400=3Q403a4@00/<1`0200d>2@1:00/<1`0;2`P03@d;00`<2P0G5aH030`<00X:2P07
1`L02PX<01<D600B4aL03a0D00/<400W:2`0M7Ei08:3Q`0:2`l04Q<G014B5P0:2`l04A8F014B500<
3@l02``>01DF600G61X04A8D01<D5P0D5AL030d?00l@4P061`T0=CTl04U?F00941X000<=00/?6@0@
51d0720Y00/>5@0D5AX05QLL00X;400G61d04a@H01HG6`0G61`051DI01PI7@0E5QX03@hB014B5P0@
4AD03a0D00`=4@0B4aL06ahQ01@H6`0B5QT05ATL01HJ7@0A5QT03aDH00lG6@0>5QP03aPJ010J6`0?
6AX04QPK01DI700D61/04aLJ010D5`0?4aH201<G6P0e010D5`0E6A`061`O01@H6`0B5Q/082D[055F
FP0?51L03aDE018H600=4a<03Q@D01XO8P0>4aL082DY030e>P0L82404aLF01dQ8P0F6Q/061`M01LK
7P0V:Rd04aLJ01HI7P0520d04QDJ01hQ:00K7b804ADH01TM8@0Q92T07R4X020T;00J8BT061lY01DK
9P0A6B@05AdZ01dT=01=DF`0NGfJ03DjE`0L8cd0<CaB01l/?`0G93D08Rdm024[=`0=5B007RD`01LN
9P0C6R000P0G7b802P0F7R405alR01XR9@0H82<05AdP01<K7P0E7B00620S01LO8@0F71`2010F5P06
014F6@0?51L03Q<F01@I7@0@5AT04aPL0P0D6Al0200J7RL04QPT018H900C6BD051XV01<J8`0?5Qh0
5ahT0P0A6A`03@0@61X04AXI01DN7@0L8B@06AdP01PL7`0E6A`03a<F00`@4`0C5aX02`lB00lC5P0D
61/00P0B5QT0100B5QL051PI01@H6@0B5QL2014E600N01/N8`11A4T041<H01<F7@0J7B@03a8I014E
6@0?4a@03a<B014F4@0@5`l03aH>01DO5`0D7AX04Q/M01hW;P0?5b804a`V00hG7P0D7B@04QXR02he
>`0P:2/051/N01<I6@0B5QD04AHC018G4`0C61@051PH0`0C5aX06P0B5QT04A@I01@G700D5a`04QDL
014D6`0B5A`05APQ01PK800D61T041@E00lC4`0@5A403a@@014F4`0D61L051PI018E6@0@4aP04QDM
01@G700>4QD04ADE03Hj>@0j?c/04AH@0P0C6180100C61@04QHG014E5P0B5QT2010D5`0=00lC500>
4Q<03a<D010D4`0<40l03a<B014F4P0@5A403a@@014F400;4@d0318>00`B400200dC4@0@00hD500?
5AD0;38b01<H6`0730l051TL00/@4`0A5A@02a0<00dB3P0A5Q805Q/G01/P700@5A404AHB010E4@@0
3a@@0P0A5Q801@0?510041DA01<H500?510041DA00<04AHB00<03a@@010E4@0?51000P0=4Ph09`0?
510041DA01/P700:3`/04QLC024V8P0C61@05AXF010E4@0>4`l03A8>00hC3`0<4@d02a0<00X?2`0?
51005AXF01<H500<4@d03A8>00lD400@5A403a@@00dB3P0?510041DA00lD400;40`03A8>00`A3@0>
4`l051TE00T@2@073PL02a8;00`C30083`P02A0900hE3P0200`C300300lF3`0>5@h03A@=00803Q<<
00@0314:00lD3@0B5a0041D>1@0?50d0500>4P`03Q0;010B3@0?4@`03Q0;00lA300D5Q401PP3028T
7`0620<04Q@?00d?2P0930T03A8<00X?2@0G71H08RLQ01TN600J7aT06AhH0P0?50h200dB300B014F
400730D02@h701/P6@0B5a003A8;014F3`0@5@h04aPA018G400@5@h03A8;00/>1`1ZKFH02P`800T<
1@0C5Pl01PT40P0<3`P04@0>4@X03a8;014D3@0C5Pl020/40085000A50d041<<02T/9@0L7aP03Q4:
010C300A50d03a8;00d@2@0>4@X03a8;00803Q4:00P03A0900hA2P0?4P/02@`500hA2P0D5a004QD>
010C30803a8;01403Q4:00d@2@0=40T03Q4:00lB2`0A50d041<<00lB2`0>4@X03A0900`?200B50l0
1@L301dO6P0A4`h04aH?01TL5@03010C2P0<014D2@0B5@X041H:00dE2P0L8a/0TIR@0?Kmm@3=e<`0
?D@l01TP600A610031<;0P0;4PX0100:4@T0310<00X<2@082PL200lA3P0800T;200>40h02`d:01<E
4P0A4a00=SPe010B3@0=3`T300hA2P0F00d@2@0<3`P05QTB00X=1P0?4P/04aH?00lB2`0=40L020/1
00lB1`09304041<:014D2`0=40L03A0900hA2P0?4P/03@l:02HX8`0T9R403Q4:00`?20803A0900X0
30l800d@2@0>4@X03A0900hA2P0?4P/03Q4:014D3@0F6A8092LP0P0H6a@0200?4P/041<<00`?200>
4@X04A@=01@G400H6a@051LA0P0>40/07@0?4@`03Q0;00d?2P0@4Pd020X500/=200B50l00`D001@F
4@15Ad807R0K0084000<3PT02@/601<E400A4`h03@l:014C3P0E5a804A<>00d?2P0B4`h0414<00h?
2P0?40/0414<00h@2`0=3`X03Q0;00803A8<00/0314;00/B2`0>4@X041<<018E3P0?4P/041<<01DH
4@1?DT/0UiZC02d`:@0201PK500700hA2P0A4`h03Q0;010B3@0?4@`030h901<E400200d?2P803Q0;
0P0?4@`02@0@40h03`l=01<C4@0A4@l030`:010@3P0B4Q003@d;00l?3@0201DE4`0=00h>300@4Pl0
3Q0=00`>2`0=3``0418?01<E4P092`P03Q0=01<E4P0;3@X06adJ01dO700200lA300M00h@2`0=3`X0
3Q0;00lA300:30L030h9014C3P0?4@`030h900H80`0:30L03a4<018D3`0C5A0030h900H80`0@4Pd0
4A<>00h@2`0@4Pd04A<>00h@2`0C4a40?3`j01/K6@0<30X02@T701/K6@0?3`d00`0>3P`200d=2`08
00d>2@0A4Pd04A8=00h?2P0?40/04Q<>00`=200=3PT300h?2P0400`<2@0<30X03`l=010@3P803`l=
00<030`:018B400@40h00P0W9bD02P0?3`d04a@@01@F4@0@4Pd03@l:00`>2@0;3@P030h900X<1`08
2PD300`>2@0D00lA3@0H6QL05aTF00X<2@072@H030h;00d?300620D09BLT014C40092`P04aDB00`>
2`0?4@h061XG01XL6@0?4@h02@/800/=2P0<3P/200h@3@0500lA3P0>40d03@d=018B4P0@41000P0=
3@d03`0<30`051@D01<C4`0A4A403`l?00d=3@0<30`020X9018D4`0N7b405QLI01<D5P0<3A403PlC
00l@500200l@5@04010A5P0B4aT03a0B00h@3`803@l>01@04A<B01@F5@0F61L09BLV01LI600=3`h0
4Q@C00h@3`0N81d08B<P00d?30092`P03a4>01LI5P0D5Q<05QPE00lA3P0>40d04A<@00/=2QCooooo
000Kooooo`0o00`>2@0D5Q803a4>00@51`0A4QH04a@I00l@5@061``03a0E018C5`092Pd02P`;00@5
000:2`D02``700X;1P0<3@T04A4?00h>301SHf8071`L00P8200Q8B403@d=018C5P061`/0414E00l@
500E5QX0ADI:02X[;`020`L03a0D01DF6P0;31002P/?00h?4@0A4Q@04Q<E01HG6@0A4Q@020T;014B
500B4aD02``>00l@4P0000805ATL018H7`0E72H04APP01PL9@0000T000<<014D6`0?41D05aPM01PI
7P0=3Q<0414F018C5`0C51P04Q<G00804A8F00L0414E00d>4P0K72005QLK00X;3`0G61`05aTM0080
4QHI04d051PK01<G6P0?51L03aDH010H6P0?5aT03aPJ00hH6@0<5QL041HI01<G6P0B5QT04aLJ010D
5`0A5AP051PK01<G6P0A5AP05ATL01HJ7@0D61/051TL02<X;01<DED04QLJ01lT9`0D6QX04ALG01HL
700L8B@0724U01HK7`0?51T07B4R01@H5`0P92D04ADF010D5@0W:bh05ATL00X>4@0:3A80:B`a018E
6P0P8bP0C51A02@X:@0A5AL06AdP01`O900F6b006B0V01TP:00G7RL05AhW01LO:P0M93807B4j03Pl
E`0D6SD01`lV01<N<P0=6R/0:CI6028^>P0/=T802Q8M01dT;`0@5al05A`R01TQ900H82<04a/N018J
7@0G7b8072@W01/S9P0201@L7`806R8U050061dP01LM7P0I7R406QlR01LL7`0B5aX05AXN018G6`0E
6Qh05Q/Q01LL8P0L82T02Q4K00lE8@0D6bD04aXT014H800@5ad04aXP010H6`0>5QT03QHH010I600B
6aX06AdP018F6@0?4aH04ADH01TM800M8B@07R8U01<G6P0B5QT04ADH00lC5P0A5AP04QHG01DI6P0D
61T04QHG014E600B5QT0:B`a06MZK`0R9BX05APO01lR:@0P8bP051PJ01<G5P0D6AD05Q/E01<J4P0A
61005AlH00H?3P0J8RH0GVM`03<kAP0>5R003QLN018K8P0A6Ah0;3@g01dU:00C6Q/04aTI01<G5P0B
5a@04QLC01<H500D61P05ATL01@H6`0C5aX04QHI018E6P0C5Q/041<H00hA60803a8I00D04A@K01DH
7@0?4a@0310A00lC4`0201<G5P0;014E500A5AH04ADH018E6@0D5a`05QTP00lB5`0?4aH0310@01XN
7@0H7AT00P0?50h01@0@5@l04AHB00hB4`0=4A803a<F008041@G0`0?4a@01`0@51<03Q8A018F5@0E
6QH04QLC014F4P0D6A<00P0=4`l300dC4@0<00dC4`0F71`0<3Hf014F6@062`h05a`O01<I6P0?4a80
3Q<?014F4P0B5a<04AHB0P0>4`l01P0@5A404AHB00lD400=4Ph03Q<?00dB3P8041DA00D03Q<?00lD
400@5A403Q<?010E4@03014F4P03010E4@0?51003a@@00803Q<?0P0?51005@0<4@d051TE00T>2P0:
3`/04QLC00T>2P0?51003A8>00`A3@0>4`l03A8>00/@300=4Ph04QLC01TN6P0H7AT04AHB010E4@0?
51004AHB010E4@0200lD4007010E4@0>4`l02a0<00hC3`0;40`01P/700L<200200`C3007018I4P0A
61402a8;00XA2P0=50d02Q4:00/B2`0200dD3@0600`C300?50d03A8;00`A2P0C614051TB1P0?50d0
800>4P`03Q0;010B3@0?4@`03@l:00h@2`0B50l02@/601@F4@0B50l02@/600/=200F6Q@03A8<00/@
2P0A5Q0061dG00hC3@0?50h041D?00T>200@5@l03Q<=00`A2`0?50d01@X300H;100H7AH04QL@00dB
2`0?50d03A8;0P0?50d02`0>4``0314:0085000L7aP03A0:00hA2P0D5a005APA014D3@0@4``03a8;
00803Q4:00@03a8;014D3@0?4P/04aH?0P0E614020092`L03Q4:010C300A50d03a8;00d@2@0>4@X0
3a8;0P0>4@X02`0=40T03Q4:00lB2`072P<02@`500hA2P0@4``04A@=00lB2`0@4``03Q4:008030l8
00<03Q4:010C300=40T00P0=40T300`?200700/=200?4@`01PP300hA2P0:30P03a8;00hA200200lB
2@0M00lB1`0@4`P03Q@:02L/9@0O9Qh0H6MO0=;Id@32al405A`D014H400>5@d03A@<00/B2P083`L0
3QD=00h@300H6QL04Q@A01DG500G6AH03@l<00h@3@0<3P/020X700lA3P0H6QL051HA00`?200=40T0
0P0>4@X200`?200C02X]9P0=40T02`h700lB2`0<3`P03A0900`?1@0N8AH030l4014D2`0>4@P03A07
00`?200;3PL030l8014C3P0M7aX061XE00hA2P0200`?200?00d@2@0>4@X041<<00hA2P0=40T03Q4:
00lB2`0>4@X02`h700`?200L7aP051L@01<F3`0;3PL04A@=008030l800@03Q4:010C300A50d04A<=
0`0@4Pd03P0?4@`03Q0;014C3P092`H03@l:01@F4@031@005ALB04mAC00V:2<02P`7010B3@031@00
20X50P0:30L0300E5a807R0K01PJ5@0>40/04a@?014B3@0>3`X03a0;010A300>40/030h900d?2P<0
3A8<00l0318<00X=1P0>4@X04A@=00lB2`0A50d06QdF09^NU`3en?40?3lh0085000I71D061/D00h@
2`0:30L00P0>40/010092`H04Q@?00d?2P0=3`X200h@2`803a4<00T0410>014A3`0E5A<04a<A00h>
300A4@l051@B00d=2`0<30X00P0A4@l00`0:2PP03Q0=00d?300200d?300<010B3`0B51405QPE00`>
2`051`@0008001HH5@0K7AX0418=00lA300>40/03a4<0P0@4Pd02`0B50l02`d800d?2P0A4`h06A/F
00h@2`0I6aH06adH00d?2P0<3PT051HA00L0418=00H03`l=028R800C4a403Ph<00/;2@0?3`d2014A
3`80410>0P0?3`d00`0=3PT0414<010A300200l@2`0:010A300<3@P03@h900d>2@0>3`X03@h900`<
2@0>3P`0410>014A3`8051@B00T03`l=00`<2P0;2`T07AdK01lO7@0@40h0414>018D3`0?4@`00`0>
40/00`0=3`X030h900`>2@0200/=200500`>2@082PH02`d:024S800M7a`00P092`P040082PL051HC
01lQ7P0?4@h01@L400d?300;3@X07b4N03<e<P0E5a@01PP501XL6@0;3@X030h;00d?300>40d200d?
3006010@400:2PX051@D01hN7P0<30`03@d=0P0B4Q802@0A4A403`l?00l?3`0@41002`d<01LI600Q
8R@05QLI01PI6`0200`=4@0M014B5P0?41D02P/@00d>4`0A4QP030d?00h@3`0A4a804Q@C014C4P0>
40l030h=01LI600?4A002P`;00lA400>40l010H300`>2`041P<01PP501@F4`0A4a0030h;01HH5@0@
4Pl030h;010B3`0=3``05?ooool001_ooooo01403@l:00T;200?4@h051DG02@U:00:2a00414F00h?
500<3A802``@00/<3`0<3Pd05ADC01TJ5@0F5a803`l=00d=2`03010@3P0B00h>300@40h020P600d=
300=3Pl02P/=00h?4@0;30h030d?00d>400>3a404A8D00X;3@0?41802P/=01@E5`0>3a404Q<E0P0@
4A<0=@0?41802``>00h?4@0D5AL03PlA01DF600@4A<03Q0D00/?5@093QD02PlE00dB600?4QT04aHM
010C6P0:3A803Q4F01@G700?4QL0<C<h01@E6@0<3A405AHJ014B5P0@4AD05QLK00l@500e=SX0;Bhb
00d>4P0M7R803a4D010D5@0D61T04aLI010D5`0?51L04ALJ014I6`0A6A`04Q/M010J700>61X041HI
014E600C5aX06AdP01DI700D61/05ATL01<G6P0D61/05ATL00804aLJ00H041@H010E6@0D6A`051TL
01DJ7@0@5AP201LL7`0701HK7P0E6Qd06AhQ01LL800>41405ATJ02T];P0301LK700O01LK7P0C5aX0
61`O04mCEP0F6Q`07b<V03/o?`0H71/04QHF014E5P0B5QP06QlR01<K7P0D720061lV01HO9P0E7RH0
5b0Z01HK<00J7cH07bDm01/S>@0L:3X082hl01/X=`0A7BT072Ha018J9@0D6bH05A`T01LN900201DM
80805QhQ00L051`O01TQ900G7b804a/N01PP8`0O9bX05QhQ00805a`P0P0E6Qh04@0D6Ad04AHJ01DJ
7P0B5a/04aPL01<H7P0B5ad05AXQ010G800?5Ql04APP01<J8P0D6b804QTO01<K7`0C6ah04ATL0080
4QXL01804QTK01<G6P0G6ah05a/N01DI700I7B007R8U01lS9P0F6Qd04aLJ014E600F6Qd07B4T01DI
700H71l05a/N01DI700D61/201DI700H0413B00=41D051LL00lB5`0B5QT04QLE01@I500F6aD061dG
014H4@0>50l04AXF01`T9P0@61h05AhW00lG8P0@6B802aDH018L7`0<5AL0620R00lG6@0B6AX04aTI
0P0E6AP01P0C5aH04QLC01@H600E6A`051PK01<G6P804ADH02/04QDI010C600B5AX061/P01<F6P0B
5AX04aPK00dC4`0;4A4041HF01@J6P0A5aL041HG014F6@0@5AT04QLK01<H700D6Al04A@I010D5`0<
41004aLF00/@300B5a403a@>014F400B5a<03Q8C00dA4P0?4aH04ADH010D5`0@51D03a<D010D5@0A
5A@02`l>00lC4P0C61@03a@@00dB3P0B5a4041HC008041HD0P0=4a4200`B400601HL6P0;4A004ALG
010F5@0B61P03a@A0P0A5Q801`0B5a<04AHB00/@300<4@d04QLC01@I5@0A5Q800P0>4`l01@0<4@d0
3a@@00lD400>4`l03A8>00803Q<?00<041DA014F4P0A5Q800P0A5Q801@0?51004AHB018G4`0B5a<0
4AHB00803a@@01807b@P00dB3P0=4Ph0:BhZ01@I5@0?51003A8>00hC3`0A5Q8041DA00hC3`0A5Q80
41DA01<H500A5Q803Q<?010E4@0=4Ph2010E4@0;00hC3`0=4Ph03Q<?00dB3P0?510041DA00`A3@0?
510061dI010G400?5Pl00P0D6a@03@0?5Pl03QD>00lF3`0;4P/02Q4:00dD3@0>5@h03A@=00lD3@0C
614041D>014F3`0?50d01`0<4@X03@0=4P`03Q<=00`A2`0;40X0314;00lD3P0k@3X06QlJ00dB300@
5@l02@h8010E3`0<4@/00P0=4P`0400;40X092TS02/`:P093PP02a0:01`Q6`0E6Q@0314;00/@2P0C
61403a@=00X?200N8a`07B8K00dB2`0;40T300`A2P0J00dB2`0E61402`h700lB300>4@X041<<00`?
200B5@h04A@=00lB2`0=40T03Q4:010C300?4P/051L@00`?2@0G6Q<03Q4:00d?2P0>4@X041<<014D
3@0?4P/03A0900hA2P0?4P/200hA2P0:00d@2@0>4@X03a8;028U7P0I71D03A0900`?200>4@X02Pd6
00d@2@@03a8;0`0=40T03@0>4@X03a8;00lB2`0@4``04aH?03Lj<`072P<06QdF018E3`0930D03A09
00lB2P0?4PT00P0@4`X02@0>4`T010T303Y1>@0Y<2P0;SD]03Hm=@0F7AD03aH>00XA2@0300`C2`07
01DK500<3PT02`d800d?2P0;3@P02P`700`>2@0200h@2`0600T;1P0?4@`01`T501<E400>4@X03a8;
0P0@4``200hA2P0E01PK500930D03A0900hA2P0;3PL041<<014D2`0_<RT041<:014D2`0<3`P03Q4:
01<F3`0D5a0030l801<F3`0;3PL03Q4:014D3@0B5@h041<<00803a8;01@041<<00lB2`0=40T03Q4:
00lB2`0=40T03a8;00X=1P0B5@h03Q4:018E3P082`@04A@=010C300<3`P03Q4:014D3@0>4@X03A0:
010B3@804A<>00<03a4<00h@2`0>40/00P0@4Pd04P0;3@P02P`7010B3@0F61<00`D100d?2P0>40`0
2P`7018D3`0L7QT051HA014C3P0D5Q404Q@?00h@2`0B50l0418=00h@2`D03a4<00h0418=00dB300<
4@/02Pl901<F3`0@4``03A0900lB2`0@4``04QD>02X]9P1<CdP06ahG010C30803a8;00H03Q0;00d?
2P0H6QD05aTD00`>2@0?4@`400h@2`803a4<00D04A<@01<E4P0G6AH05ALD010B3`02014C4005010B
3`0<3P/02P`901<E4P0O8Ah00`0>40d200d?300E00`>2`092`P03a4>014C400:30T03Q0=00P:1`0?
4@`030h900d?2P0@4Pd04Q@?00lA300=3`X02`d800h@2`0;3@P07R0K01<E400;3@P030h900803@l:
00h03a4<018D3`0>40/03@l:00lA300>40/03@l:00lA300>40d020X701DG500=3``04A<@00/=2P80
3a4>0P0>40d200d?300500l@2`0=3PT03a0;018C3P0@4@`00`0>3`X0100?40/0414<00l@2`0>3`/2
010@3P0=00h>300C4a404Q8@010@3P071`D02`/900d=2`0;2`T04a<A014B3P0?4@`030h900d?2P02
00h@2`0;00d?2P0?4@`04A<>00`>2@0:30L03@l:00lA3@0=3``07AlL02HX9@0A4a000P0=3``00`0C
5A802``:00h@3P0200lA3P0600d?30092`P04A<@010B3`0E5a@02P`90P0?4@h07@0@4Pl03a4>00h@
3@0=3``03Q0?00`>3@0@4Q402P`;010B4@0B51<0418A00lA400=3`h030h=00d?3P0?4A00418A00d?
3P0@4Q404A8D00T:300@4A<030dA014B5P0?41@03@hC010A5P0=3Q<0414C0080418A00<03a4@00h@
3`0<3Pd00P0=3`h200lA400;00h@3`0@4Q405aTF010B3`0?4@h0828O034c<00>40d030h;020R7`0I
6aP00P0=3``00`0<3P_oooooooooo`0Booooo`006oooool0300=3`X02@/700H81@0J6ad0@D9600d>
4`082@h030dB00d>4`041@T03a0C00h@3`804a<A00D04Q8@010@3P0<30X020P600d=2`0200`<2P0:
00d>2@0>3`X03`l=00T;2`041@L04a@F00P92`0Z:bd0HfAV00l@4P803@h@00l03a0B00h?4@0=3Q00
3@h@00/<3P0?4180414C00d>400?41804A8D01TJ700P8B<08b@V03Hg>@0I6Qh01P0?4QL02P0@4aP0
2PlC00hC5`0;41H07B8X02`^<`0I6Qh05AHJ01<D600B4aL2014B5P0301<D600E5QX04a@H0080414E
00l04A<F018F5@0C5aH04QHF01<G600D6A`04APK00/C5P0@61/0620T00hG70094QL041HI01DI700D
61/00P0E6A`0200C5aX04ADH018F6@0D61/05QXM01@H6`0B5QT051TL0P0E6Qd01`0C61/04AHI01LL
800T:Bd05AXN010E600G71l00P0C61/01P0D61T04aLH018F5`0A5AH04QHG01DI6P<041@E00D04QHG
01DI600I7Ad05a/J01@I5@02018F5@0I01<G600C61/06R8U01XR9@0?5Q`05AhU00083`0J8R/07R<f
01/P=00L8SL07BDh01l[>`0X=T<062Hc01TU<@0J92h06b<^01`T;@0M92`072<Y01HN8@0J8RD08BT/
01dU:00200hF6@0>01DM800D71l03aLJ018J7@0M9BP07B8X01HK8@0>4aT06AhT00lD6P0T:Bl07b@Z
014F6`0J7b<201@I7@0E01PM8`0F6b405Q/Q00lD6P0>4aT04AHL00lD600H7B403A8E01<H6`0>4aH0
6b0S014F6@0F6Qd09RX]02<W:P0>4QD05ATL01TM800E6A`051PK00804aLJ0P0B5QT01`0E61d05aXO
01XM8P0F6Ah01`/>01lS9P0S9bX00P0D61/07P0J7R405ATL00dA4P0A5Q409R/U07UnN00K81X03A<?
02/a;@0=5Q@05AdO01@L8`0F7bP08b/f00hG7P0B71d041XK014J700A6QT041TH00lF5P0?5AD04ADD
01<G5P0E6AP05QXI01HJ6P0E6A`051PK01<G6P8051PK02L04QHI01DI700L82<03Q8E01HJ6`0>4QD0
5Q/K00/D4@0:4a8031DE00P@4P0;4aD03aLJ01LO8P0941H03QDK00dD6P0=4aP041<H00lC5P0?4a<0
4ADD018G4`0A5Q004aPB00lD3P0=4Ph051PI00/?400G6ah04QHI01XN8@072``05ATJ00`@4@0D61L0
4QHE014E500@5A400P0>4`l01P0=4P`03Q@B00dC4@0=4a403aDC010F50803Q@B01403A<A00dC400=
4a403Q@@010F4`0A5Q803a@@00X?2`0>4`l02Ph:00hC3`0A5Q805AXF028W8`0M8Qh03a@@01DJ5P06
00lD40804AHB0P0@5A4200lD400=00L<200A5Q804AHB014F4P0<4@d00`P400hC3`19CTX04AHB00/@
300A5Q805AXF010E4@0500lD400600hC3`0@5A404AHB00lD400;40`02@h:0P0@5A4200lD40@03Q<?
01@03a@@010E4@0@5A4041DA01/R6`0H7aP041L@014H4@0H7aP09bhW00hE3P0:4@X02a8;00hE3P0<
4``02A0900`A2P0C61405Q/D01<H4@803Q<<0P0?50d09`0>4``03A8;00dB2`0<4P/03aH?014H4@0>
5@h01@`501HM5P0@5a00U9^D05=JD`0C6Q<01@`501PO600=4`d04AH@00lD3P0<4@/02Pl902T^:00c
>38000D002P]9`0Y;RP02@h801LL5P0<4@/08BHO00/@2@0@5@h0IfaU051ECP0=4P/01``500/@2@0D
6A803a@=00L<1@03010C300300lB2`0>4@X03Q4:00H03A0900H04A@=010C300>4@X03A0900hA2P0A
50d3010C30803A0901<041<<018E3P0A50d03Q4:01PK500m@3T061/D02HY8P0J7AH030l800lB2`0B
5@h03Q4:00/>1`0@4``03a8;00T<1@0:3@H041<<00803A090P0<3`P200hA2P803A070P0>4@P01P0?
4PX03a8;01PK500:3@H04A@=00P;10802`h70P0>4``0200@5@h03a@=01DJ4`0U:R<07b@M00X?200=
4P/04aPA0P0=4P/06@0j?CH04QD>00P;100@4``02Pd600lB2`0;3PL04aH?018E3P0=40T03a8;01<F
3`0=40T03a8;01DH4@0<3`P03Q4:00/>1`0@4``03A0900`?200=40T03a8;010C300:3@H00P0C5Pl0
3`0=40T030l800hA2P0`<b`0?D0g01<F3@0A50/03A07018E300a=2d03A0900/>1`0?4P/03A09010C
300200d@2@0G01LJ4`0C5Pl03Q4:00`?200B5@h05QTB014D3@0@4``03a8;014D3@0D5a005APA00`?
200930D03Q4:00lA2`0A4`h03a4<00T;1P0?4@`051HA018D3`0?4@`00P0>40/04`0?4@`04A<>010B
3@0B50l030h9018D3`082PD0418=01/M600<3PT0418=014C3P031@0051HA00L<1P0:3`T01P/601<E
400I6aH00`0@4Pd01@0?4@`0418=018D3`0E5a803Q4:00803A0900H041<<018E3P0A50d04A@=010C
300>4@X300/>1`80418=00H03a4<00h@2`0=3`X030h900lA300<3PT200X<1`0?00h@2`0A4`h051HC
00T;200E5a@02`d:00`>2`0G6AH030h;00d?300?4@h03Q0=01DG500V:2D03a4>008030h;00<0418?
00lA3P051`@00P0@4Pl200h@3@0=00d?300<3P/0418=010B3@0?4@`03Q0;00`>2@0:30L0418=00lA
300<3PT02P`700`>2@0200h@2`<030h90P0>40/0100=3`X02`d800/=200=3`X200h@2`0<00h@3@0;
3@X04Q@A00d?300>40d030h;018D4@0G6AH03a4>00d?30031@803@l<0`0>3`X03@0@4@`04A8=014B
3@0A4Pd051D@010A300>3`X0414<00`=2@0=3@/03`l=010@3P0>3P`00P0=3@/0600A4@l04Q8@00/;
2@0;2`T03@d;00l@3@0?4@`030h900X<1`0;3@P03a4<014C3P0D5Q4061XE00P:1@0=3`X01PP3014C
3`0=3``03a4>014C400@4Pl03a4>01@F4`802P`901L03Q0=00L91P0=3``051HC00T;200C5A802P`9
014C400>40d030h;014C400?4@h03@l<010B3`0<3P/03a4@00P:2@0;3@`0418A00D71P0A4a8030h=
00h@3`0200lA400:010B4@0D5QD06adJ018D4@0C5A8051HE00`>3@0@4A<03PlA01DF60803a0D00@0
3@hB01HG6`0E5QP04Q@C0P0=3`h0100E5aH071hM00d?3P0A4a8200lA4008010B4@0;3@`01`T601<E
4P0=3``02@/8010B3`0?4@h2018D4@04010B3`0>40d03@l<00`>2aCooooo000Kooooo`0=014C3P0:
30P03a4>00X;3@0F5aX03a0E01hO90061``05AHK01DF6P0>3a802@X<00l?3`02010@3P803`l=00D0
3@d;00/;2@0;2`T02`/900`=200200d>2@0700d?3`0B4aD03PlA00H72@0B4aD08B8T00l@4P0200d>
400300l@4P0>3a403@h@00803a0B00/051DG01DF600@4A<0414C00`=3`0E5QP05aPJ014B500Q8R@0
2P/=00hB5@0500hA5P0600lB5`07310051TM01@I7`0=4QP0310E0P0;3100100@4AD04a@H01<D600B
4aL2014B5P0D01<D600D5AT05AHJ01<E5P0A5A@04QHE018F5P0C5aP051TL01DK7P0B6Qd05alR01hV
:P0F7b@04Q/P01<I7P0A5AP03Q8E00lC5P0C5aX201@H6`0401DI700G6ah06AdP01LK7P805ATL01L0
4aPK01@I700B5aX03a@G01DJ7P0V:bl06b0T01TN8P0N8bH05a`O01HK7P0E6AX051PI01<G600A5AH0
4QHG01<G600B5QL04ADF010D500A5A@04QHE01DI600200hC3`0`010D4`0B5QD04QHG010E600A6A`0
4a/N014H7P0H8BP00``C028Z<`0I7bl04AHY01/R=@0P:CX04Ad[01`Z=@0B82/05B4[01LQ:`0G82T0
5AdV018I8@0J8BL0620S01/S9P0N9RT06R8U010H6`0E7B00620S01TQ900H82<06b<V01lW:P0l@DL0
5QXR02@Y;`0R9bd0724W09:GW@15BU005a`Q010E6@0N8bL04AHJ01TN8P0A5Q`05AXP0P0B5ad04@0E
6Ql04AHJ00dB5P0>4aH06AhQ010E600F6ah020d@01DI700B5QT06AdP01dQ900F6Qd02@d@00lC5P0@
51L04ADH00804aLJ00H051PK01DH7@0;3Q<06QdR0454B@0W:bh201TM800J01@H6`0C5aX051PK018F
6@0@51D05a`G028W8@1GG5H05a`F00`B3P0H7Q`04AXI00041`14C58010dF018K900D7B803QPG00hH
6@0A6QT04a`K014J6@0@5aL041HF018F5@0C5aH201@H5`0301DI6`0C5aX04aLJ00804aLJ0P0D61/0
5P0@51L04ADH018F5`0T:2T051PI010F5@0:4a002a@C00hF5`0B6Q`041PK00`D5`0Q:2h02Q4G01@K
8@083aD061lT01@H6`0B5QT04ADE018F5@0B5a<200lD3P04018G4@0=4Ph05a/L01@H6@80310C00/0
9b/^01HJ6`0=4A8020`=00L9200A5A@041@C010E4@0?51003Q<?00hC3P0200`B400300lE4`0B61H0
4ALE00803A<A0P0=4`l200hD4007010F4P0C61@0314=01@I5@0A5Q803A8>01dR7P0200dB3P0401HK
5`0B5a<020d9014F4PH03a@@0P0@5A4200lD40803Q<?00l04AHB00@91@0O920041DA00hC3`0C61@0
3Q<?03Ll>00N8al06QlK00hC3`093PX02Pl;00/@300<4@d00P0=4Ph00`0>4`l03a@@00lD400200lD
40803Q<?00<041DA00lD400?51000P0>4`l0100=4Ph03Q<?00hC3`0?5103010E4@07010G400?5Pl0
2A0900/B2`0<4``05ahG00hE3P0200/B2`0:00dD3@0<4``02A0900dB2`0C614051TB018G400=4P/0
3Q<<00lD3@803Q<<0P0=4P/00`083PL02a8;01DL5@02010G400O00dD3@052`D0<CPa00/B2`0940T0
00@0010G400F71D010T30002000J7aT04QLA00P=1`0@5@l00PL101TN600N8ad02a0:01HK5@0@5@h0
3A8;0087000;40T05Q/D010E3P0=4P/04aPA018G40052P<00@H0010E3P03010C300300lB2`0>4@X0
3Q4:00H03a8;01/06A`E01LJ4`0B5@h03Q4:00d@2@0>4@X030l800lB2`0A50d03a8;00hA2P0@4``0
2@`500`?200>4@X020/401hQ6P041`404A@=00hA2P0B5@h06ahG01HI4P082`@03A09010C300>4@X0
0P0;3PL0100?4P/041<<00lB2`0=40T200`?200300d@2@0=40L03A0700803Q4800P03a8:00lB2`01
100061/D00`?200D5a005APA010C30803a@=0100314:00X?200@5@h05Q/D01DJ4`0:3`P041D>01<H
4@0<4@X03a@=02lb:`0@4``03a8;018E3P0?4P/041<<0P0=40T200`?200?00hA2P0?4P/04A@=00lB
2`0930D03a8;01HI4P041`0041<<00d@2@0<3`P03A0900lB2`0@4``03A0900804aH?00H03a8;00hA
2P0?4P/05APA01/N5@0;3PD2010C2P0601TL4`0h>c@06A`E01@G400B5@h03Q4:0P0=40T01`0@4``0
5APA00hA2P0<3`P03Q4:018E3P0E61400P0B5@h03`0C5Pl030l800<6000Q91d07B0I00`?200F6A80
20X400lA300C5A004Q@?00`>2@0;3@P030h900d?2P0200`>2@0D00d?2P0>40/03a4<00H80`0:30L0
30h9010B3@0;3@P01`T400lA300>40/02`d801TK5P0^<2/00@H0028W8@062PD02P`701@F4@0?4@d2
00h@2`803a4<00P04A<>01<E400>4@X03A0900hA2P0@4``04A@=010C30803Q4:100=40T2010B3@05
00lA300=3`X03@l:00`>2@0;3@P00P0<3PT0200=3`X03a4<010B3@000P004aDB00L91P0H6QL0418?
0P0B5140300?4@h03Q0=00`>2`0=3``05aTF010B3`0=3``02`d:00h@3@0?4@h02P`900d?30D03Q0=
1P0=3`X0200;3@P03@l:00h@2`0>40/02`d800X<1`0<3PT03Q0;0P0?4@`01@0<3PT02`d8018D3`0=
3`X030h900803a4<00h03@l:014C400:30T010H300h@3@0D5Q<0418?00lA3`0?4@h061XG00lA3P0H
6QL0;S0]00l@2`803Pl:00D03a0;010A300@4@`0414<01<D3`0200l@2`05014B3@0?3``0410>014A
3`0?3`d00P0=3@/200h>300C01@D4P0J6QP0410>018B400F5a@05QPC01TK5P0C5A0030h900d?2P0>
40/01`T400/=200F61<0:B/V00d?2P092`L03Q0=00lA3P04010B3`0?00`>2`0E5a@06A/H01<E4P0@
4Pl02P`902HX9@0A4a00004000`>2`0A4a003a4>018D4@0?4@h02`d:00803a4>00T020X901lQ800L
7Qd00P@300L9200C5A@03a4@010B4@0A4a800P0?4A005@0B51<0=CLd01lQ7P082PL02@/:01DG5P0j
>cd08b@V03Lh>P0Q8RH03@hB018C5`082@`04Q<E010B4@0?4A003Q0?014C4P0C5A@03@l>018D4`02
010B4@08018D4`0=3`h04A<@00`>2`0?4@h04aDB014C400?4@h2010B3`0400lA3P0>40d03Q0=00d?
31Cooooo000Kooooo`0<00D70`0;3@T0418?00X;3@0;30l02P/@01/L8@0>3a@01PL<00H62P0F5aX0
51DG0`0<30`0400?3`l04Q8A01@D4P0;2`T030`900`=200=3PT03@h800d>2@0<3P`03@l>00lA400C
5A@03a4@00/=300?4A0200d?3P0300lA400>40l03@l>00803PlA0P0E5QP200l@4P0700h?4@0D5AL0
4Q<E00T:300F5aT02P/=00l@4P0200l@4`0900l@500=4A@03A4D01@I7@0@5AT04AHJ00XA5`0=51X0
4ADJ008051DI00L05QLK01DF6P0A4QH04A8F01<D600D5AT04a@H00804Q<G02@04Q@E010E4@0@51<0
4QHF01DI6P0E6Qd04aXM010H6`0B6Al05AdT01<L8`0B6b805A/P01<G6P0@51L04aLJ01TM800L82<0
6AdP01@H6`0F6Qd05a/N01HJ7@0D61/051TJ018H600D6A`04QLK00hC5`0B5ad05a`R01<H7@0E6Qh0
51TL00hD5@0A5aL201@H6`0701<G6P0C5aP04aLH01<G600F6QT05ATH018G5002010E4@04014F4P0C
5aH04aLF01<G5P804aLH02004aPL01TQ900A61d04aXQ020Y<00D7BD07bPb028X=`0I7bh0;3=303Ho
C@0P;3P0:CM101HT;P0I9Bh06bD^01/T;@0F7RP04aXR01@K8@0I8B@06b<V01PP8`0D71l04a/N00hF
6@0?5aX04ATL018J7@0C6ah04aXP010D7@805a/U00X061`V01XN9`0b=Sl0;34g01<H7@0I7R80D5EI
02<X;00G72003a8G0P0E61d0400F6Ah06A`Q01DH7@0E6A`0310C01<G6P0K7b80ATY=04]?DP0L82<0
61`O01<G6P0B5QT051PK01PL7`0B5QT301<G6P09018F6@0A5AT04aHL01`O9P0H6b8082<X01DH7@0A
51T04ADH00805QXK01H04ADF018F5`0E6AT041@A018G4`0K81`05Q/H01@J600C6AP041TI01TQ902;
U9L09S0d00hG700B6ad04A`H014K6@0C7AX04a`I010I5P0@61D04QPF0P0C5aH2018F5@0W018F600A
51T04A@I018E6@0C5aX051PK01@H6@0>4Q<04aLH02DY:@0i?C`06AdL00hE4`0B6aP05AhM00lH6@09
41@02a8H03HmA01>EEd05QdU014H7`0>5A/03aLJ01DI700D61/04QHF018F5@0A5Q803Q<=00dB300G
71H03a@@00/?400<41404ADH01DI700C5aX0310A00803a<D00<051PG00lC4P0?4a800`0?51002P0@
5A00318@00dC4`0A5aD051XH01<I5`0>51003A<?00dD3P0>5@l300lF3`0<00T<2@0D6AD02@h:00hC
3`13B4@05AXF01<H500@5A404QLC00lD400<4@d05AXF2@0?510200hC3`0800dB3P0G71P05Q/G00/@
300A5Q803A8>00lD400B5a<200dB3P802a0<00D03a@@00hC3`0?51003a@@014F4P02018G4`04010E
4@0?51003a@@010E4@804QLC00<03a@@00hC3`0>4`l00P0=4Ph0100<4@d03Q<?00hC3`0>4`l300lD
400700lF3`0=50d02a8;014H4@0940T031<<00hE3P0200`C300800dD3@0;4P/02a8;010E3P0B5a00
4AH?00hC300=4P/400hC30803A8;01X03A<<0005000I81T02A09018I4P042`@041L@00D<1@0940T0
4QTB00`C300G7QL0AD]4034f<00=4P`04AH@00/@2P0A5Q0041D?00X?2@093PP03a@>00dB300>4`d0
3A8<00hC30805a`E00@02Pl800T>1`0>4``04AH?0P0=4P/00`0A5Pl0314:010C3002010C300300lB
2`0>4@X03Q4:00H03Q4:00P061/D01LJ4`0C5Pl041<<00lB2`0@4``02Pd600d@2@804A@=010041<<
014D3@0:3@H02@`501LJ4`0@4``05QTB018E3P0930D02Pd6014D3@0H6a@04aH?00T<1@0A50d041<<
0P0>4@X0300?4P/03Q4:018E3P0A50d03a8;00hA2P0=40T03A0800d@1P0=40D03Q4600hA20803a89
00@03A0906IYHP0K7QL04A<>0P0=3`X04`0=40T04A@=00P;100;3PL051L@00X=1P0>4@X030l801<F
3`0B5@h03A09014D3@0D5a001`X301<F3`0<3`P041<<00X=1P0C5Pl00P0>4@X300lB2`0K014D3@0B
5@h01`X3020S700c=Rl05APA010C300>4@X03A0900hA2P0?4P/041<<00lA300>40/03a4<00lB2`0>
4@X03A0900lB2@082`8041<:00hA1P0=40D04A@:01<F3P0:3@H030l800803Q4:00@03A0900hA2P0B
5@h04aH?0P0=40T200hA2P0A010C300>4@X04QD>01@G400A50d02@`702d`:@0V:B803a8<01`O600A
4`d03Q0;00`>2@0B50l02@/600X<1`0@4Pd00P0=3`X0600>40/03a4<00lA300@4Pd02P`7034c;P0<
3PX03a4<00d?2P0:30L03@l:00lA30072@@03Q0;01/N600K81X07B@M01@I4`083@L04QLA010B3@0<
3PT03@l:010A30<04A8=00H041<<00hA2P0>4@X03a8;010C300>4@X200`?20<03a8;00D03Q4:010B
3@0?4@`03a4<00d?2P0200`>2@0300/=200>40/03a4<00803a4<00h03Q0;018G4`0<4@d03Q<?00`A
3@1HGET0EEYF01DJ5P0?51003Q<?00dB3P0:3`/0314=00lA3P803@l<00@030h;00h@3@0B514030h;
0P0=3``0:`0>40d03a4>00lA3P0F61<04aD@00lA300>40/03a4<010B3@0Q8ah05QPC00h@2`0?4@`0
418=00h@2`0:30L03a4<018D3`0A4`h02`d800T;1P0>40/03a4<010B3@0?4@`03@l:00`>2@0?5100
2@h:01<H500;40`07R<O06Y_J`1HGET05AXF01<H500<4@d03a@@02lc;`0A4Pd0414<00l@2`0>3`X0
0`0?40/03P0C50l03a0;010A300C50l04a<@01@D4P0C4a40410>00d=2`0>3P`0410>00l?3@0H61H0
7alM0P0=3@/03P0B4a004Q@?01PJ5@0E5a803Q0;010B3@0A4`h03a4<01@F4@0M7aX0;BlZ01@F4@0?
4@d03a4>0P0>40d01`0?4@h04A<@018D4@092`P03Q0=014C400<3P/00P0@4Pl0500=3``03a0>01dO
700V:2D030h;018D4@0C5A803a4>00`>2`0?4@h04Q@A03i2@@2KWih07B4P00`@3`0B5QD09BPW00lC
4P0@51<03a<B0P0<40l05@0>4Q403Q0=00/=2P0?4@h04Q@A00d?300?4A0030d?01PI6`0A4Q@03PlC
00l@500?41<03@l?00h@3`0@4Q403a4@00d?3P0;3@`03Q0?014C4P0200h@3`09010B4@0<3Pd0418?
00h@3@0D5Q<04Q@A00/=2P0B51403@l<00<03Q0=0P0?4@hDooooo`006oooool030092`H02`d900P:
1`0?41804Q<G00X;40020`P03PlD00`=4P0:2`l07b0S01<D5P8030`>00d02`/=00d=3@0@40l04a<A
00`=200>3`X03a0;00l@2P0>3`T03Pl:010B400;3@`02P`;00<03@l>00d03a4@00d?3P0=3`h03a4@
00h@3`0=3`h03PlA00T:300=3Q003PlA00d>400?41803PlA00803@h@00<03a0B01<D5P0=3Q000`0B
4Q802@0A4Q@03a<F00lC5P0A5QX03QHI00082`042@l00P/@00/A5@0200d>4P07014B5P0H6Ad06Q/O
01LH700K72008R<W01dN8P0201<D600=01@G5P0?50h03Q<?014F4`0E6AP051XJ01<I700B6Qd04aXP
018J8@0E7RD05QlX01@J8002010D5`0E01@H6`0G6ah05a/N01<G6P0@51L04ADH018F6@0A5AP041@G
018G600C6AL05a`N01HK7`0A5QX04QLN01HJ8`0F6b405a`P01@I700C6AT07B<S008041@G02T04aLJ
01@H6@0E6AX05ATH01HJ6@0E6QH04aPD018G4@0C61805AXE01`P7`0I7Ah04ADF00dA500B5QT07R<W
014H7P0G7RH08BPa018K900=5B006B4/01HL:00J82`07RHb01lY<`0O;3D082hg01<Q:P0C82P04Q`U
01<L9@0E7BH05ahV00hE6`0F7R405alR018J7@0@61/04a/N010H6`0201LO8P0A014I700B6Qd06B0V
00hB7@0D62@08RHa01lS;P0J7RP06AdV014F700H7B800`P<038g>`0G72005AXM01<G6P0E6A/00P0@
51L02@0E6A`051PK01lS9P0I7B00720S00d@5@0M82D061/P01TM800201HJ7@0Q01hR9@0=4A@03A4D
00/?4P0<41<03Q8E014E600E6A`05QTN01PK8`0C5Qd05APO01<F7@0A51T06A`Q01DI700E6AX05QXK
01HJ6@0C5aH04ADD01@H5`0A5A@02`l>01@H6@0;4A404QLJ00`D5P0H828082TZ01XT9@094a@04adK
00803aXD00X04A/F014J5@0>5a@041LE018H5P0C5aH04QHE014E500@51D041@F0P0@4aP0800@51P0
4ADH018F5`0@51D03A4@01DI600J7Qd07b@P00X?2`0?5a<031LC010J6@0A6a`03QLL03M0A`13C5D0
6R</02lh?`0E7R@04a`Q00dF6@0?51L03a<F00hB4P0@51<04AHB00lD3P0E6Q@0314;00dB3P0M8B80
3Q8C0P0:3Q401`0A5AP06AdN00@82@0@51D03a<B00hB4@0?4a800`0?51002@0@5A0041HD00hD500=
4a<03aDC014G5@0@5Q8031<<00dD3@0300lF3P0400hE3@0R9b401P/701lT80806AhJ00H01``8010E
4@0?51004AHB00lD400<4@d700lD40804AHB010041DA00lD400?51003a@@028W8`0;3``03A8>00lD
400D6AD01P/700lD400@5A405Q/G00/@300>4`l00PL30P0?51002`0>4`l03A8>00`A3@0<4@d03A8>
010E4@0B5a<04aPD014F4P0@5A403Q<?00<03A8>0P0<4@d500hC3`0700dB3P0@5a002Q4:00T@2@0A
61402A0900/B2`0200dD3@8031<<0P0;4P/00`0?50d041D>00hC300200`A2P803Q<<0P0=4P/200`A
2P0Q00/A2P0i@c/0P8Z2014K4`0>61004A/C00<;10074@T03aTA004;0`0;5@d01@l701/Q6`0F6aD0
8BHP01@I4`042@<051TC00`A2`0A5Q003A8<010E3`0<4@/01@X401LL5P0;40T061dF02ld;@0E6Q<0
41D>00X=2@083@H04AH?00802a0900D03a@=010C300@4``041<<00lB2`0200hA2PH03A0900H03Q4:
00d@2@0>4@X03Q4:00lB2`0@4``300hA2P0D00`?200>4@X051L@01lR6`0:3@H030l800lB2`0<3`P0
20/501<F3`0@4``02`h700X=1P0=40T03a8;018E3P0?4P/03Q4:00lB2`0@4``400hA2P0500lB2`0A
50d04A@;00d@1@0=4@@00P0>4@H04@0?4PP03a8903<f;`3;c/P0MgUd024S80061`D051HA010C300F
6A804QD>01/N5`0Y;2D06ahG01@G400<3`P02`h700<03Q4:00D041<:00`?1P0E60l030l601DH3`02
00hA200;01@G3P0C5Pd030l600X=100<3`H041<<018E3P0@4``04aH?01XM5P0;3PL01P0>4@X0400B
51003a4>00lA300A4`h03a8;00hA2P0>4@P041<8018E2P0@4`P05a/=018E2P0B5@d05APA01<F3`0A
50d4010C300H018E3P0D5a004A@=00d@2@0?4P/03Q4:00`?200@4``04A@=00`?200?4P/03A09014D
3@0>4@X04A@=02X]9`0K7AP02P`700d?2P072@@010H100`>2@0>40/03a4<0`0@4Pd0400A4`h0418=
04=5@00@4Pd03@l:014C3P0H6QD03@l:01<E400@4Pd03Q0;014E3`052P@082LP00XA2P042@<200dB
300300d?2P0>40/04Q<>00804a8>00L0410<010C300>4@X03A0900hA2P0?4P/03A0900@03a8;00D0
3Q4:00d@2@0?4@`03a4<00h@2`0200`>2@0500/=200D5Q404A<>00d?2P0;3@P00P0=3`X02P0;40`0
51TE0002000>4`l041DA01DJ5P0A5Q803A8>00lD400A5Q8200dB3P8030h;00@04Q@A014C400=3``0
4A<@0P0>40d200d?308030h;00`06A/F01HH4`0A4`h03a4<010B3@0A4`h0:2XU01LI50092`H030h9
00lA300>40/200d?2P803Q0;00<03@l:00`>2@0B50l00P0Q8ah04P0D5Q403a4<014C3P0F6aL04QLC
00@91@0D6AD02Pl;01DJ5P0@5A4051TE00X?2`0@5A40314=04iCC`0A4Pd0414<00l@2`@03Pl:00D0
4Q<>00l@2`0@4@`04a@?018B3`02018B400R010@3P0?3`d04Q8@01@D4P0O7ad08R8P01DE4`0B4Q00
4a<A01HG4`0G6A@04A<>00d?2P0?4@`04A<>00lA300E5a807AlJ00T;1P0:30L01@L201@F4P0?4@h0
3Q0=00d?300?4@h04A<@018D4@0620D06A/H038d<@0E5a@03@l<00T;2@805aTF00D0BD]80=3Bc`0T
9R<0418?00lA3P02014C4080418?00T041@C03Tm?00=4A001PX900lC4P0C5aH03A4@00hB4@0?4a80
0P0=4A003@0@51<06A/H01@F4@0?4@`03a4>010B3`0I6aX06Q`K01PJ6@0A4Q@04a@F00T:300=3Q00
100>40l0400?4A00418A01@F5@0E5aH03a4@00d?3P0>40l02@/:00L91P0B51403@l<010B3`0J71T0
3Q0=00`>2`0=3``200h@3@80418?5?ooool001_ooooo00L04A<>00T;1`0<3P/04a@F018C5`0`<CH0
>CXo00803PlD00<03a0D00`=400<3@l00`0=3@l0400=3@d03`l>00l?3@0<3@P03Pl:010A300A4P`0
3a0:00h?2P0?4@l06A/J00P:2@0<3Pd04Q@C00840`0?4A0200d?3P0:00lA400>40l03@l>010A4`0:
2`d030d?00h?4@0?41804Q<E014B50803PlA00<04Q<E00l@4P0=3Q000`0B4Q80:00A4Q@03a<F00lC
5P0;41@04QXM00P@4`0U;3804AXO01DK7`0D5AT04a@H01TJ7P0Q8RH092DY01TJ7P0D5AT071dQ01TJ
7P0@4AD04Q<G01DH5`0@5@l03A8>014F4`0E6AP04aTI00hE5P0=5AP03A@J00XB6@0=5Qd03aPQ010F
700A5AP04QHI01DI700G6ah05QXM01<G6P0A5AP3018F6@0e014E600B5aL04aTG01PN7P0I7R8051TM
01DI8P0D624051TO01<H700@5AP04QPH01`R800?4a@041@G01<G6P0D61T05ATJ01DI600F6aL05AXF
01@I500C61805AXD01LL5`0N8R40720Q01HJ6`0B5QT06AdP02T^<`0R:C406B0X01TP:P0N9S40<SY5
01`T;`0L8Rh08RPd01hV<@0G8B/07BXc01XX<@0B8BP041dU00hH8@0?62404a/T01LN900?5Q`04a/N
01DM800D71l00P0C6ah0=`0>5QT05QhQ01DM800?5aX04QXM01dT:P0W:cH04QHR00lC7`0@51l061`V
00D94P0A5Q`08RL/00D:3P0K82@04QLJ01DJ7@0E6AX05QXK00lC500>4QD04aLJ018F6@0:3Q403Q8E
01TM800?4QL06A`Q00lB5`0I7B005ATL00/?4P0A5AP04QHI02L[;P0L82<05a/N01@H6`0B5QT04aLJ
01@G700C5Qh03A0G01PK8P0I72<04aHK01LJ7`0F6Qd04ADF018F5`0F6QT04ADD00`@3`0C5aL00P0B
5QL0400D61T03A8E01PM800@61X072@V00P>3@0H8R403QPG01LR7@0>6A<031LA00hH4`0@6A@03aPE
010H5@0B61H2018F5@03014E500@51D04ADH00804A@I01X041@H014E600A5AH04aLG018F5@0E6AP0
2Pl;00dB3P093PX06b<O00XE4@0640l02Q@E01lX;@1LIFh0F65Z00`E7P0/=Ch03QLM018K80094QD0
3A8E00dA500=4A403a<B010E4@803a@>00/03A8<01<H500C5aP01PX;038f>@1DF5/04QHI00lC500F
6Q/04QHG014E500200lC4P<03a@@01T03a@?014G5@0>51@02a4A00`B400?5A<041HB00/B2`0<4``0
3aH>010G3`0?5Ph03QD<00870@0B5a<05a`H00P=2@0G71P04AHB00hC3`0@5A404AHB010E4@0>4`l0
314=00H03a@@0P0A5Q83010E4@0=00lD40052PH03a@@01hS7`0730P0LgQd02@Y9@093PX03a@@00hC
3`062`L06AhJ01DJ5P02018G4`0;010E4@0>4`l03A8>00`A3@0=4Ph041DA01<H500B5a<03a@@00dB
3P0?51000P0>4`l200dB3P0400`A3@0>4`l03Q<?00hC3`<03A8>00T04APA00/B2`0940T04APA00/B
2`0>5@h03A@=00hE3P0=50d00P0;4P/01`0<4``0314:00hC300>4``0314:00dB2`0>4``00`0=4P/2
00`A2P0D00P?20074@T0<cde00D<1P033@D05AlG01<M5@0>610010h600/E3@0@6Q800@/300XA2`07
30H07B8L01HK5@0<4@/04AH@00H;1@0A5Q02018G4@0>00`A2`062`D02a0:00D:0`0B5a003a@=00L<
1@0B5a004AH?00lD3@0@5@h04aPA00lD3@093PL3010C300300lB2`0>4@X03Q4:00H03a8;0`0>4@X0
0`0=40T030l800`?2002010C300;00d@2@0:3@H03A0901@G400]<2T04aH?014D3@0I71D05QTB010C
300<3`P00P0=40T00`0;3PL03A09010C3002010C300400hA2P0=40T03Q4:00hA2P8030l800H03A09
00hA2P0A50d04QD<00d@1@0=4@@200hA1P0900lB200?4PT0=STb06i`JP0n@3/05QPE01TK60041P40
3@l:00804A@=01006QdF02HY8P0N8AX05QTB00d@2@0930D03A0900lB2`0=40T03a89018E300?4PT0
30l601<F3@0=40L04A@;0P0K7QD02@0A50/03Q48014D2`0;3PL03Q4:01@G400;3PL03A0900X=1P06
00hA2P<05ALD02<051HA018E3P0A50d03Q4801<F2`0;3P<03Q46018F200=40D03A08010C300<3`P0
2Pd600T<1@0<3`P04A@=00lB2`0A50d05QTB01<F3`0>4@X04A@=010C300?4P/051L@01<F3`0?4P/0
61/D00L:0`0?4P/03A090044000N8A/051HA00T;1P02010B3@802`d801L030h900d?2P0>40/03Q0;
00d?2P0@4Pd020X502@V8@0>40/051HA00h@2`0?4@`03Q0;00d?2P031@003Q0;010D3P0B6A80LGQa
020W800@5@l0314;00T=2@0200lA3005014B3@0B4@d04Q4=018A3@0?40X00P0=40T01P0>4@X03a8;
00hA2P0A50d041<<00lB2`803A0900D03Q4:00h@2`0>40/03Q0;00`>2@0200/=200>01HH4`0A4`h0
30h900/=200<3PT03Q0;00870`0>4`l041DA01HK5`0>4`l04AHB00hC3`0<4@d200hC3`0400X?2`0=
4Ph03Q0=00/=2P8051HC00P030h;00lA3P0?4@h03Q0=00d?300<3P/02`d:00X<2@803a4<00<03@l:
00h@2`0@4Pd00P0A4`h07`0<3PT02P`700`>2@0:30L020X500lA300<3PT02`d800`>2@0>40/03a4<
01DG4P0S9B008B<N014C3P0:30L03@l:01@I5@0=4Ph000D100lD400=4Ph04aPD00dB3P0H7AT01P/7
00`A3@001000<3Da010A300?40/00P0>3`X300l@2`0M01<D3`0?40/03a0;018C3P0@40d04A4?018B
400A4@l0410>018B400A4@l06a/I01`L6P0;2`T04a<A01DE4`0M7Q/08bDP01HH4`0>40/03a4<00h@
2`0A4`h06Q`G020R7@0C5A0061XE00h@2`0E5a<00P0>40d200lA3P0A010B3`0B51401@L401DG500Z
;2T03Q0=00X<2@0<3P/09bTV00L81P031@80>C/h00`>2`0>40d03@l<010B3`0C5A800P0?4@h02@00
0@003Q8A014E500J7Qd041@C00T=300<40l03A4@00hB4@0200dA400?010E4P082PL02P`7014C3P0C
5A803a4>00/=300620L05ALF00`=3`0?41806AXL01LH6P0@4Q403a4@00803Q0?00P0418A018D4`0H
6QT06A/J018D4`0?4A004A<B00d?3P803@l<00@01PP501XL6@0/;R/02@/80P0>40d200lA3P03010B
3`0A4a3ooooo01?ooooo000Kooooo`0O00`=2@0?40h01@H5018E5`0I6b007b8W02ha=`0;3Q803a4E
00h?4P0;30d04A4A00/;3P0=30l03Ph@00l?3`0>3Pd03@d;00/;200=3PT0414;010A300>3`P03@h8
00/=2`0@4Q403@l>00lA400@4Q403@l>00lA400200d?3`0?00lA4@0>41003@l?00h?4@0;30h03a0B
010A4`0>3a40414C00d>400B4aD04A8D010A4`0;30h04a@F00<04A4A00T0418A00hB4`0>4Q<03Q<F
00lF6@0?4aL0DEML018J7P0=4AD00P0>3a<00`0B4aL04a@H018C5`0201<D6080414E00`04A8F00l@
500C5A@04AHA00dB3P0@5A<051TH014F600?5QP051`P01@K8P0@620201<L9007018H7P0A5AT03a<G
018E6@0F6Qh06A`P01HI7@03018E6@0G018F6@0B5AT04AHF014G5@0I7al06QlS01HK7`0F6b8051TP
01DJ800D6Ad04aPK01@J6P0E6aT051PI01@H6`0E6A`051PI01<G600A5A@05Q/H01DJ5`0D6A@00P0B
5a40800E6Q@04aLH01LK7P0J7R4051PL018E6P0F6b0061lW01DL9@0A5b805QdY0418E00N9S405ahZ
01DL:00K92h06bD^014N9`0C8RT0528Y01@P:00C7BD04a`S01<K8@0C6R005QhR014I700C6ah06b<V
01`T9`0E7B004a/N0P0D71l03@0F7R4082P[02T`=P1<D5/05a/W01XN:P0B5R404aLQ024U;@0B5ad0
61dQ01`Q900I7R800P0F6ah03`0C5aT05a/M01@H6@0D61X05QXM018F6@0G6ah03a<F01HJ7@0?4QH0
720T018F6P0Q9BL07R8T014E5`0201PL7`0@03Di?00V:Rd0720S01DI700B5QT051LK01HI7P0D5al0
5APO018E700E61l06A`Q00lB5P0G6ad04QHG018F5P8051PG04T04QHE01<H6P0B5QT05ATL018G6P0F
6ah04QPK010H6P0@6AP04Q/J010K5`0K9R806bHP01lZ8`0I91h04ahH014J500?6A803aLC014G500A
5Q<04AHD014E5@0A5AH04aLJ01DH7@0C5Q/04QDI010D5`0@51D04QHF00lC4P0C61@03Q<?01@I4`0@
5@l06R8K010K5P0A6QP03aPJ01LP9@0J8RX05QhX018K900;4a`03QHL01/U:00a>C/04QLI014E5`0?
4a<041DB010E4@0>4`d03A8=010E400>4a003a<D00`@4@0]<C@0CU9F018F6P0B5QP03a<D01dQ8@0F
6aT04QHD014E4`0@5A403a@@00hC3`0>4`h03A<B00802a4A00`03Q@C00hD4P0=4`l02a8<00`C300?
5Pl04AP?010H3@0>5@`051TD01DJ5P0>4`l200/@300301DJ5P0A5Q804AHB00803a@@00<04AHB00hC
3`0?51001@0?5102010E4@803a@@0P0>4`l0300G71P03A8>01@I5@0:3`/07B8N00L;200D6AD03a@@
00dB3P0A5Q808BHR02hc;`804AHB0P0@5Q800`0@5A403aDA00lE4@0200hD400300hC3`0=4Ph03A<?
008041DA0P0?510400hC3`803A8>0P0<4@d03`0=5@d03QD>00`E3@0B6Q<031<<00lG400<50`03aH?
00dE3P0:4PX02a8;00dD3@093PL03A8;00hC300200dB2`0300hC300=4P/03A8;0080314:01`02a09
01lV7P0M9al02Q8;00hG3`084PX0210900dF3`0<5Ph0210900`F3P0640P03QL?00/B2`0>4`d0314;
00hC3@0;40X0314;010E3`0<4@/03Q<=00dB300>4`d04AH@00lD3@0:3`P05a`E0P0>4``01`0M8Q/0
;c@]02`a:P0E6Q<06AhG010E3P0>4``00`0@4``00`0?4P/03Q4:00hA2P0600hA2P@04A@=00<041<<
00hA2P0@4``00P0@4``200d@2@0X014D3@0?4``01@T200lC300C5a003a<<014E3P093@H0310900lC
300;3`P03109010D3@0<3`P041<<00lB2`0:3@H02`h7010C300>4@X03A0900`?200=40T03Q4:00lB
2@0=40D03A4300hB100>4@H03a8800lB2@0>4@X04A@=01TK5P041P<0418>018E3`0A4`d030l800d@
2@803a8;014041<<00/>1`0@4``03a8;00hA2P0@4``04QD>00d@200I71@01`X1018E3@0?4PX02Pd4
01<F3@0D5`l051L>01<F3@02010C2`0600lB2`0@4``04A@=00d@2@0D5a0041<<0P0>4@X200lB2`0A
00hA2P0=40T04A<?01PJ5`0G6AD0418=00hA2P0@4``04QD<00`?1@072P005AT<00H:000?4PL03Q49
014D3@0>4@X00P0B5@h03@0>4@X04QD>01<F3`0>4@/04A@=018D3P0=40T03Q4:00lA2`0B5@h061/D
01HH4P0C5Pl00P0=40X02@0E61403A0900/>200@4Pd03a4<00d?2P0<3PT03a4<010B3@0200d?2P0F
00h@2`0@4Pd03a4<00h@2`0>4@d03A0=00/>2`0?4`h0310:00hA300>4@/02Ph802HY8`0L7QT02`d8
014D3`083`P0:c@/01`S700C6Q<01@`500dA30803a4<00`03Pl:00h>2P0?3`X04@l<00d?2@0;3PL0
30l800hA2P0@4``03a8;014D3@0?4P/200`?200800lB2`0D5a003Q0;00h@2`0=3`X030h900/=200:
30L400lA300D010B3@0?4Pd04aTE01TN6`0G7AT01PX700`B3P083PX02Q0<00`B3P0?5A403Q<?00hD
400H7AT05aXG00/=2P0@4Pl051HC00d?300@4Pl400`>2`0400d?300=3`/030h900d?2P803Q0;0P0?
4@`0100<3PT03Q0;00h@2`0?4@`2010B3@0400h@2`0=3`X030h900d?2P803Q0;0P0A4`h04@0@4Pd0
3a4<00h@2`0=4@/02Pl;00hD400?5A402@l;014G4`0K8Ad061hJ00/A3@0<4Ph02a0<01<I5@0?5100
3a0;00803Pl:00h0414<014B3@0A4Pd04A8=01@E400@4@`03a0;014B3@0@40d04Q8@01<C4@0B4Q00
3`l=00h>3080410>0P0>3P`2010@3P05010A3@0B50l0418=00h@2`0=3`X00P0>40/02@0?4@`051HA
00`>2@0F61<02P`7010B3P0>40d03a4>014C4003010B3`09018D4@0K7AX05QPE010B3`0C5A80418?
00/=2P0@4Pl06A/H00803a4>00`04A<@00`>2`0=3``03a4>00`>2`0@4a003Q8A00X@3P0B61H02Q0>
00lE4`12B4H300lE4`0400/A3`0:40h03A8?010D3`804Q@?00@04A<@018D4@0A4a003Q0?0P0D5QD0
0`0K71h05AHH00d>400300lB4@0500hA400=40l030l>014D4`0C5QD00P0=40l0200A51<03Q4@01<E
4P0B51404A<@01PJ5`0J71T02P`91P0A4a0Dooooo`006oooool09P0E4aP030/@00<63@0010l0GVMa
04aFH00G8BX02aHI00L=3@0:3`/0414900h>1P0=3@/03a4@020R8@031@@03Q0?00X<2`0>40l03@h?
00l@4P0A4Q@030d?010A4`092`X0418A00d?3P0:2`d030d?00/<3P0<3@l03PlC00d>4P0A4QH02``@
010A5@0?41803@h@0P0>3a402@0:2`d020T;00d>400G61X05AHH01<D5P0>3a401`P:014B5002018C
5@0>014B500>3a403@h@01@G600E6AX03Q8E00T=400F6Qd0;C0d00hA5P0=41D061/P00lB5`0;3Q<2
01hQ9P0N010C600<3a@04A@I018E6P0F61T071hM00/?400C5a/05AdP00dD6P0<5A/04a`S014J8@0=
5A`04QTO00lF700A5Qd04QHQ01LK9P0@51l0720[00lC700?4a/04AHL010E6`0A5Q`04AHJ014F700B
5aX04QPH0P0C61/0=@0D6A`051TM010E6@0J7b<09R/^01TN8@0=4QD051XJ01@I700J7b804aPK00hC
5P0E6Qd03a@F014G5`0B61P05A/K01@J6P0B61P03Q@D018H600I7al04QPH01<I6@0L8B@051TL010E
6@0L8BL0314G01DI8P0F7BD04aPR01LP<@0I93H05b8c01DQ;`0L:3D07R/d01/U;P0F8BP04a`Q018L
7P0C7Ah05AdO014I700C61`041DI01<H700J7b<061dQ01LL800H7B405AXN008051TM00<04AHJ014E
7P0F6R<00P0G72803P0E6R003a@H01DJ7P0C61/06AlO01XO8P0E6a/051TL014D6@0B5AX04QHI01@G
700Q9BP0;S8e0P0E6AX0300B5QD05ATH01@I5@0?5100318@01HL6P0630X06R0O01<I6@0F71`05AXM
00X?4`8041DI03l04AHL01XO9@0D5ah051LN01DH7@0G6Ql06A`Q01XN8@0D61X05a/L014E500?4a40
6QlK010F4P0?61D06b@S01`U900C71/031DD00/E500>61L051hO018L7@0C7A`06R@S05QSH@0jAd00
62DN01LT6P0?6a402QH:010L4@0>60l03aTA00`C400:410041DH014F6P0>4aL04AHI01@I700B61P0
3aDE018H5`0D6QH04QPD00dD3P0=50d04AP@00lF3P0?6A004APA00hF4`0U;Bl041DK010F7P0=51`0
2@dF00T?500B6Q`041DF00lD400?50h00P0?510200hC3`803Q8A01H03Q8B010D5@0B5QT051LL01DJ
800>4aT041DI01DK6`0;4@l04aTD014H4@0=50d02Q4:00hD400A5a<04ALD00P=400;41<03aDF00lE
5@042PX04QPG0P0:40`05P0:40/02a8;00dD300@5`l04ALC010F500E6aT04aTG00dC4@0A5aD03Q@B
00/A3`0<4Q003A<A00`B400?5A<0318@00X@3P0L8R00?TA201XP7P0B61H200lE4`0;00hD4P0=4a40
41HD01<I5`0I7ad03Q@B014G5@0X;R`0;C<a00H<2P0<4Q000P0@5Q@0400=4a40318@00dC4@0C71L0
3AHA00<<1`0>5a8031D@014J5@0@6A@01a0;00/D3`0=5Q404AXE00TB3@0?5@l200hC3@03010E3`0?
50h03Q<=008041D?0P0?50h03P0>4`d03A@=00hI4@0>61002aH>00LA2@0;5@d02aH>00HA2@0@6Q80
5b8J00TC2`0640P01@l70P0>5@h200dD3@0700`C300=50d04QTB01@K500?5Pl03A@=00/B2`0200XA
2P0;00dB300?5@h02A0900/@2P0>50h051/D00D:100@5Pl02a8;00/@2P0@5@h00`0=4P/02P0?50d0
41D>018G400E6Q<03Q<<00H;100E6Q<04aPA00H;0`093`<300/A1`0a00hD2P0@5@d03Q<<00`A2`0;
40X03Q<=018G4@0;40T020d6010E3P0:3`P03A8;010E3P062`@04AH?00lD3@0<4@X02@h700X?200?
4P/04QD>014D3@0>4@X04A@=010C300A50d03Q4:00lB2`0@4``03A0900lC30001`008BPQ00XA2P0?
5Pl04APA03Pm>00]=2d04APA00L>1`0B6A8020l800hE3P0D6A805QTB00T<1@0G6Q<05APA00/>1`02
00lB2`803Q4:010041<<010C2P0:4080318300dC1@0=4`L03A8:00`A2P0?50d04AH?00X@1P042P00
4aT=00T?0`0A50/041<<0P0?4P/06@0>4@X03A0900hA2P0<3`P04QD>010C300<3`P04A@=00d@2@0?
4@`02@`500T;1@0>40/041<<00T;1@0@4Pd06QdF00d@2P072@@051L@014F3P0>50X03A<900`B200=
4`T00`0>50X0@00@5P`04aT?018H3P0A5Pl03Q4:00h@2`0A50d03A0900hA2P0F6A803Q4:014D3@0A
50/03a8900hA200?4PT0318800/A1`0B60l041D>00dB2`0?50h05Q/E00870@0I7QT061dG00460P0I
7QT00080028W8`093@T04aPB010E4@0;40/02Pl900P=2@0>4`h03a@>00hC3`0=4Ph02@h:01<H500?
51000080020U8@0g?3P061dI00/@300@5A402@h:014F4P0E6Q/06b8X05EMH00>51<04a`G00`C2`0<
50T02a<801dT6P0L8AX02Pl801dR700=4P`3010E3`08018G4@083@L05Q/E010E3`0?4Pd03@l:00@6
0@0C5A0200X?200700`A2P0=4P/03a@=014F3`0>4``03A8;00`A2P0300/@2@`0314;05D03A@=00TB
2P084PX031<<00XA2P001P004QLA014F400<4@/0418=01<F4@0;40X04QLA00dB300A5Q0041D?00/@
2P0@5@l01@X4010E3`0730H02a0:00hC3@0C61802a0:00hC300G71D041D>00P=1P000`004QL@00@9
0P0:3`P05AXC00H;100L8AX02Pl:00lD3P0<4@/02a0:01<H4P0@5@l0314;00/@2P0>4`d0314;00dB
300B5a403Q<=010B3@0=4P`0310:00lA300>4`d04AD?00d?2P0;40X03a8=00h@2`0<3PT0:R`W00L9
100E5a8030h901XL5`0C5A0030h900T;1P0<3PT05aTD01<E400<3PT06A/F00`>2@082PD02`d801hP
6`0d=S406A/F03Tk=P0/;RT01PP301@F4@0@4Pd03a4<00803Q0;0P0=3`X03@0C5A002@/600h@2`0;
3@P03@l:00`>2@0A4`h06Q`G00`>2@0D5Q401@L201<E400>40/00P0?4@`0100A4`h04Q@?010B3@0=
4@/500`A2`0=01DJ50062`D00@H001`Q6`042@<04aPB010E4@0>4`l0314=00/@300<4@d03Q<?00P=
2@0200lD400=01@I5@0?5100314=018G4@0=4P/02Pl900`A2`0;40X03a@@00hC3`0<4@d041@C00L;
2P0200hB4@@03aDC00D03A<A00`B400>51804ALE00/A3`02010F500=00P>2P093PP03A8<00lD3P0;
40X02a0;01<H500=4Ph03Q8@00hB4@0=4A00310?00X>3@0Dooooo`006oooool03@0>2A005A<K00L:
4`0O9C40[;O20;;0b`0A7bP02QHJ00H?3P0<4@/04A8800l?1@0=3PT00P0>40l0600I6aX05AHG014B
500C51H030d@014B5P0720`03PlD00/<400<3Ph020X9010B4@0@4A<030d?01HG6@0D5AT05AHJ01PI
7@0=3Q<010D:01HG700B4aH03@h@00`=3`803@h@00@030d?00d>400C51H04A8D0P0@4A<00`0=3Q00
414C014B5002014B50803a0B00H02P/=00/<3P0C51H05QLI00l@4P0I6ah2010C600501TL8@0D5a`0
4QDJ01@G700C5Q/00P0B5AX0600@4aP030lD00/>400B4aD04QHI01<I7P0H8BP03QLN01DO:00B72D0
4a`S00lG7P0B6Al05Q/O02DZ<P0T:3@03Q8N00dA7@0>4Qd051PS01TM9P0B5Ql04ADN018G7@804aPN
0P0C61/0>`0E6Qd061dP01TN8@0K82<03a@G018G6P0K82<061dP014F6@0C61/05a`O01DJ7@0J7b80
5Q/N00X?4P0B5aX051TL01<H6`0B5aX04aPK01@I700G71l06AlO00`B4P0G7Ad08RPX01@J6P0F6ah0
5Q/O01lT:00B5a/061dS01LL8P0D6R804ah`01PU>00J9CP062@d020Z>@0T;SP04adW01@N900C7Al0
4A/M010J6P0B6Q`04QLK01DJ7P0D6Ad05Q/O01/P900F6al05AXN01<H700B5a/051TM01HK7`0D6Ad0
5AXP008051TO00/05a`P01HK7`0@5AT04QLJ01<I6P0nA4@0A4Y:02<Y:@0T:B`051LL01@G7@0201<F
6`0H01`P900W:bh05QXK01TM700G6aX05a`H01HK5@0C61804QPD038h=00K8Al03Q@B00D;2`0?5AD0
5Q/N00hC5`0C61`03a@J00X?5@0?51X06QdT01LJ7`0F6Ah051LL0P0C5aX02P0C5aP05QXI01HJ6@0C
61@06AhH010F4P0>61D05R4M01LR7P0B71/200`F5@0b00hH5`0=5aP04A/L01HP8@0H8R<0:3<b014N
5`0>6a@05R<I01HT5`074`L03AT<00XF30053`L04Q/G01hW9P0E6Qh020dA00dB5P0@5AP04QPI010F
5P0<4Q803Q@B014G4`0@5Q803A@>00dD3@0A61005QhD00H>0`0940T041HC01HK7P062`l02@dE00<8
3P0G7280724T00dB5@0C6AP041D?010E3P0A5Q004QLC014F4P0A5Q<04ADD014E5P0@51D2010D5`07
00lB5`0O8b`0HfM`00P=4@083Ph03Q@@014G4P0200hE3@0;00lF3P0@5Q803aDA00`B4@0W;2l00086
02<X:`0/<S804ALG00lE500>51800P0=4`l03@0=50d03aH?014H400?5A403Q@B018H5P0@5Q@0318@
014G5@0@5Q@05A/I00hD4P0:40h01@0<4Q001@0O9B<05A/I018H5P0;4@l0318@00802a4?00L03A<A
00hD4P0<4Q004aTG010F500C6AL06AlM00803A<A01803aDC01<I5`0E6aT05A/I00lH5@063`X03aXD
010K5@0C7QP01Q4;00LB300;50h0?DQ203a7@@0=61800Pd700L@2`0>50d2010E3`0400lD3P0A5Q00
4QLA00lD3P<03Q<=00<03A8<00`C300B71@00`0:5@d0500A71@00Pd500hI4@0=610021<;00XE3@0M
:20062<K00lF3`0>5@h031<<00XA2P083`P02Q4:010G400A61403QD>00`C30083`P01`d70P093PP0
2P0;40X02@h800hC3@0<4@/01P/500lD3P0730H04AH@018G4@083@L300`A2P0400dB2`0>4``0314:
00D:0`803a@=00X00PL000/@2@0D6Q0051X>014G2`0=4`P02a4700`B200>50/03Q<<0`0@5@l03`0?
50h03Q<<00X?200=4P/01@X300X?200C614051TB00lD3@062PD061dF01@I4P0<4@X03A09010C3002
00lB2`804QD>01P04A@=00hA2P0?4P/041<<00d@2@0>4P/072<L05QRFP0?6A401@l700`F3P0X<RX0
8B/S00dG3`053`L03QP@00PB2P0>5@h000D008B7P00e>3401`X300@60P0A50d200lB2`803A090100
3Q4:00hA200;4@<02a8300/A1@0;4@L02a4800/@2@0@5@h04QL?018H3P093`<03Q@500H<000@4`X0
41<<0`0?4P/03@0>4@X03A0900`?200@4``03a8;00/>1`0@4``0:2XU01DG4P0@4Pd06A/F018D3`0;
3@P00P0?4@`01`0D5Q403a4<00/=200A50d04aP@010F300>50X00P0=4`T03P0>50X03aD;00hD2P0@
5P`04aT?018H3P0@5P`02`h700d@2@0A50d03a8;00`?200@4``03Q4:0P0A50d0<P0?4P/03Q4:00lB
2`0;4@L02@l500lE300<4@X020d600T>200>4`d02Pl;014F4P052PH08bPT08^@S00O9200008000lD
400E6QH020d901@I5@0<4@d02Pl;00hC3`0=4Ph02a0<00dB3P0C61@09b`X02db;P0@5A406AhJ024V
8P0H7AT041DA00X?2`0?51006QlK01LM803Rjo80W:FZ02@^;P0010000``400TC200540804QX>01DJ
4`0:3`P04aPB0P052P@020062`D02a0:00hC3@0C61801``6018G4@093PP04AH@0P0;40X01`0>4``0
3A8;00dB2`0<4@X03A8;00hC300?50d0100>4``00`0@5@h0314;00`A2`0900`A2`0]00/B2`0530D0
2Q@<008<100;4P/031<<01PO600>4`d03Q8<00/=200=3`X04A<>00/=200=4P`02@h800dB300<4@/0
20d700/@2P042@<03A8<01<H4P0U:R@082DO00lD3P011P0041D>00T>1`052P<04QL@01<H4@083@H0
5Q/D00@90P0;40T0008000T>1`0=4@d041D?01DJ500930P02Pl900dB30093PP02Pl900802@h800D0
314;00dB300C5A004aD@014C3P0200h@2`0400lA300>40/030h900d?2P804A<>00P0418=04mAC00[
;BP04aD@00/=200K7AP020X5014C3P803a4<00l061XE01DG4P0;3@P02@/601DG4P0F61<020X501<E
400J71L0418=01XL5`0>40/03@l:01PJ5@0<3PT00`0?4@`200h@2`0=010B3@0E5a804aD@01HH4`0C
5A00418=00X<1`0>40/04Q@?014C3P0:30L03Q0;014C3P0200lA3004014C3P0B50l0418=00dA2`D0
314;01l02@h801HK5@0B5a4061dG00dB300>4`d02@h:00`A3@0>4`l0314=00/@300@5A406AhJ014F
4P0>4`l041DA01DJ5P0A5Q404aPB010E3P0B5a404aPB00lD3P0=4Ph05AXF00T>2P0J7Qd04QHE00P<
2`0>4a803Q@B00@03AHC01<031DB00D>2`0A6QL05b0M03i7A00L9B808R/V01LL5P0I7QP020d700H;
1@0F6aH06AhJ01HK5`0E6AL04aLF014E500@51<03a<B01Cooooo000Kooooo`0D00l:3`0@3a@00PD=
018F800lADl0>TMA00PE7@064AD020h>00/@300?40T03@d600h>300;3@`02P`;04M9B00];Rl03a0B
00d>400>3Q4200d>4P0K00d>4`0@4AH03a0C00X;3P082@`03a0D00X;3`0;310030dB00X;400?3aH0
30`D01PH8@0l?D<05aPK010A4`0=3Q00414C01<D5P0D5AL03PlA00l@4P0<3@l03@h@014B500B4aD0
414C00803a0B00h0414C018C5@0B4aD0414C01HG6@0N7b404Q<E01@E5`0@4QD03Q4F00lB5`0@4aP0
4aHK018E6P803Q4F01T04QDJ01<F6`0@4aP041<H01<G700<4QL06b8W01HN9P0T<3T03APQ01DR:`0=
6B804Q/S010H7`0:4QH051TM01@H7`0K7bT03A4L03<g@@0?51/051PQ014F7@0?51T041DJ00804AHJ
00@04QLK018G6P0B5aX04QLJ0P0C61/01P0D6A`061dP01<H6`0C61/05a`O01@I70804AHI00L03Q<F
01TN8@0I7R403A8E01<H6`0A5QT04QLJ008051TL02<04aPK018G6P0H7Qh07B<S01LM7@0?5AD09B/[
02P]<00E6Qh05Q/O01<H700F6b404aPN01PN9P0S;3d0:3=602PcA@0N:SX07bXh024[=@0B72D05b4W
01LP900D71l04ATK01<K7@0D6Ad05a`P01DJ7P0F6al05a`P00lD600F6al04QLK01@I7@0201LL800=
01DJ7P0F6b404QLM01<H7P0G72005AXN018G6`0G71l04ALH01XP800L8R804QPH01<H6P0201HI7P07
01@G700D61/05QXM01TM800B5QL06QhM01LK6P0201<H500A018F500C61L05adL01DK6`0>4aD07R<V
00`A500@5AT04AHL01/P9P0N8bT0720Y01hS:P0I72805QTN01DH7@0D61/00P0C5aX0>00D61T03a<B
01LK6P0D6AD04aPD00dC3`0?6AD03aTH010J6@0A6aX03aTH00hH5`0nB4L072HW00dG600@6Q/04Q`M
00lJ600E8Q/072TQ01@Q5`0K:1d021@900dH3@0A6a<041XC00dD4@0F71`06b0T01HK7`0D6A`05AXM
01DJ700B61P041HD00lE4`0@5Q@041HB00lF400>5@h03aH?018I40083`L06B0I014G500>51D03a@G
01DJ7`0E6R005Q/P02<X:`0E6Qd03Q@C00lD400A5Q004aPB0P0E6QH06@0D61L03Q8A00lC4P0B5QL0
4QHI014E600@4aL0=CU106aaN00F6al05A/K01DK600@5A004AP@01DL500J8AX05Q`H018H500>5180
20/>00`A501ZKg808bTY01HL700<4Q000P0?5A<03P0>51003A@=00dD3@0>5@h041HC00lE4`0@5Q@0
3aDC00hD4P0C6AL02Q0>014G5@0<4Q002@l=0P0>51802`093`d03aDC00/A3`073@/041HD00`B400>
51803aDC010F500A5aD041HD00803Q@B00H04ALE00T?3@093`d03aDC00/A3`0@5Q@200hD4P0B010F
500>518020l=00TB3@0<5a40218<00`G4@0950h041/E00`E3`14CdT0>dI000lI4`084`d03QLB010F
400B5a4041D?0P0>4`d04`0?50h03Q<=00hC3@0>4`d03A8<00`A2`0;4P/031L?00PC2`0=61006B@L
038m=@0;5Ph031L?00lJ4P0950`03QTA01HQ6@033PH0100>5@h0500?5Pl031<<00XA2P0;4P/041L@
01PO600F7AH041H@00dB300;40X03A8<00lD3P0F6aD05AXD01PM5`1>Ddd03A8<00P=1`0A5Q003A8;
100<4@X0800=4P/041D>00D:0`0@5@h04QL@00X?200A5Pl02Q0600X@10093`<0318700hD2P0<4PP0
318900lD3@0C618051TC014F400<4@/03Q<<00X?200@5@h0314:01LL5@0]<R/02a0:010E3P0:3`P0
2a0900`A2P0=4P/030l80`0?4P/0100C5Pl04QD>014D3@0?4P/2014D3@0:00d@2@0<40T03A@=02Pb
:P0?6A4010h601PR6P094P/03QP@00/E3@80218:01P02aD=00dD3@0>4``08RDO00/>1`0A50d041<<
00hA2P0A50d041<<00hA2P0=40T030l800`?1P0<4P@02a4300T?0`0:40H0318900lD3@0@5@h01P/4
014G3@0<4PH200X@0P0700hA200?4P/03a8;00lB2`0@4``04A@=010C3002014D3@0<010C300>4@X0
4QD>01TK5P0K7AP051HA00P:1@0;3@P05aTD01@F4@0@4Pd03@l:0P0A4`h00`0>4@/03aD<00dC2@02
00`B20803Q@:00H03A<900`B200=4`T03aD;00dC2@0;4@L200d@2@05018E3P0C5Pl03Q4:00`?200>
4@X00P0A50d200lB2`0[010C300@5P`03Q@:01<H400?50d02a0900dB2`0:3`T0314=00dB3P0L8Ad0
>Chj059GD`0F6aL04AHB00X?2`0A5Q803A8>010E4@0?5100314=00hC3`0:3`/02@h:00`A3@0=4Ph0
41DA00lD40093PX02Pl;014F4P0<4@d02Ph;01@I5@0:3P/05Q/G018I6P1^Mgd0BE9F00P@40063`X0
2Q@<00`D2P0200XB1`803a@=01402Pl901DJ500:3`T02`l:00lD3P0:3`T03A8<00lD3P0;40X0314<
014F400@5@l03Q<=014F3`0@5@h03Q<<00`A2P0200/@2@80314:0P0;40T00`0=4P/03Q<<00dB3005
00dB30D0314;00D02a8;01LN5`0?6A4031H>00hE3P0200dD3@0700/@2P0?4`d03@l:00h@2`0B50l0
3@l:00hC3@0300dB300S00/@2P0<4@/03A8<010E3`093PP03a@>00`A2`0;40X02Pl800`A2`0<4@X0
51TB00T>1`083@H04AH?00hC300:3`P02a09028W801nPg`0;S<]059GD@17C4H041D?01<H4P0730H0
5Q/E01TN600?50h03Q<=014F400;40X051HA01<E400A4`h00P0>40/03@0?4@`0418=00lA300?4@`0
418=00lA300>40/0418=00/=200B50l04A<>00H8100F61<00P0@4Pd0400=3`X03a4<014C3P0D5Q40
1PP500/=200=3`/06Q`G03`n>@0/;RT02@/600d?2P0H6QD03a4<00X<1`0=3`X2014C3P80418=00h0
3a4<00h@300/;RT02`d800lA300:30L04aD@00`>2@0>40/02`d8014C3P0E5a804Q@?00d?2P803a4<
00@04A<>018D3`0@4Pd03Q4<1@0=4P`07`0;40X0314;00`A2`0H7AL05Q/E00dB30093PX03A8>010E
4@0=4Ph02a0<00hC3`0=4Ph0314=02`a;@0E6QH05Q/G00dB3@0A5Q003Q<<00hC3@0?50h0314;014F
4P0=4Ph03Q<?00X>3@0B5QD04aLF00/@3P0?5A<01@0<5A804P094Pl02Q<@059KF03:dm00HfaY00D:
1P0E6Q@02a0:028W8@0U:R@0314<00hC3`0B5a<04ADC010D4`0A5A@051PG01HJ6ACooooo000Koooo
o`0U010<3@0:2@X02@X>01@I7`053aL03aTR00@>5`053a@02@hA00d?3P0?3``03Pd900h>300@4Q40
1@L600L9200310D030d?00/<3P0>3a80414E04e>DP0A4QL0414F00h?4`0>3a@05AHK014B5`0F5a`0
4A4I01@D700L72@05ADO00h>60030`l01@D=00h?4P0200/<3P803@h@00@02``>00l@4P0@4A<0414C
0P0<3@l03@0>3a40414C00h?4@0>3a40414C018C5@0C51H05aPJ03Hg>@0o@4808B8T01dN800C5AT0
0P0C5Q/01@0@4aP04aHK01<F6`0D5a`04aHK008041<H0P0D5a`01@0>5A`02aDN028_>00K:C<08c4l
00805B<^01403a`U01<M9P0D72<04QLK01HI7P0I7B80>Ci402X^=`0j?dD04QLK01`Q9`0@5AT04AHI
01<H6`0C6AX04ALG018G6P0201DJ7@0O01@I700B5aX04AHI014F6@0K82<05a`O01HK7P0E6Qd04QLJ
01@I7013B4/07b@W01@I700J7b805Q/N01@I700E6Qd05Q/N01PM800G71l05AXM01<H6`0F71`03A<C
01DK6`0F71`0:Bl_02@Y;00J7b<05AXN01LL800201HK8@0E01`R:P0=5RD051la01XU=P0J8c@082Xg
02@^>00L9Bh072@[01LN900B6Qd04ATL01DM7`0C61`051TM014F6P0D6Ad06b0T01PM8@0K82@06AhR
00807B8V0P0E6Qh03P0B5ad04aPN01PM8`0F6al03a@H018G6`0@5AP05adN018H600D6QX0728R018H
600C5Q/04aLK0P0D61/01@0D61X04QHG01LK700P92<0720O00<05a/J00P02PlB010E600730l0CU=G
02L/<00:3aD06b0V01HJ8`805a/T00<051PS01@H8@0B5A/00P0B5QT04@0D61/05QXK01HJ6`0N8R<0
4ADD01PL6`0E6AP05QXI01<I5`0?61L03AHE00hG5P0A6QT04Q/J014J6@063`h03QLF00805b0O00`0
3aPG00XE4P0=6Q<02aP?00D?1`0>6Q000Ph4018M500=5`l041HB010F500@5QH200/@4`0e014F6@0@
5QH03aDE00dC4`0<4Q003aDC01<I5`0D6QH04QPD00hD400>5@h04APA01HM5P083`P04ALD05YPH00f
>ch02PlB01<H70042@d041DH02H[;P0D6QT03A8>00lD3P0B5a<04aPD01@I5@0C5aH0310?00hB4@0A
5AH04aLH018F5`0@51L0724U00462P0H7B4041HF00X@3P0=50h02A0900dD3@0@5a003A<?00/A3@0<
4Q0092T/00T>4@073@d00`T900T?3`0>51800P0?5A<0500>51003A<?00`B3P0;4P/03Q@B00lE4`0=
4a402a4?00hD4P0A5aD06b4O00lE4`0B61H04ALE00L=2`0<4Q003A<A00T?3@0C6AL03Q@B0P0=4a40
2`0<4Q002a4?00dC4@0?5A<03Q@B00T?3@0B61H0318@00X@3P0A5aD051XH008020h<01P03Q@B010F
500@5Q@06R0N02H/:P0=5Q401@d800060@0=5Q4031D@010I500D7AP0=Slj02Xc;P0;50l02A8=00PA
300>50h02a0:00`A2`0@5@l03A8<00X?2@0@5@l200lD3P803Q<=00<03A@=01@N5P0E7aL00P0E7aL0
800b?3@02A<;00TC2`053`L02Q@<00/E3@0D7QH04A/C00`C300=50d03aH?014H4@0B6A806B0I01XQ
6P0C6Q<03aH?01DL5@0B6A80318;00X?2@0;40X03A8<00X?2@0=4P`04QLA00870@0U:R@01``701HK
5@093PP03Q<=0P0>4``200dB2`1A00hC300D6A804QL@01HK500>4``02@h7018G400<4PP03Q@8018H
300G7A8051X@00hD2P0<4@T03Q<<00lD3P0>4`d03A8<00/@2P0@5@h0314:010E3P062`@02a0901PM
5P000P007B8K01LL5@0730D03Q<<00lD3@0?4P/04QD>010C300=40T03a8;00hA2P0A50d03Q4:010C
300A50d03A0900dA2P0J8AX00`X300lF3`0530D05A`E00hE3P083`P03QD>00dD3@073PL02a8;00T@
2@0;40T05aXC01dP6@0?4P/02Pd600lB2`0C5Pl04QD>010C300?4P/03Q4:00hA200;4@D02a4400/A
1@0=4`T04QLA01HK5@0k@3X05AXC018H3P0>50P020h100H<000=40L03Q4:00803a8;00`041<<014D
3@0A50d04QD>00lB2`0=40T03Q4:010C300;3@P0418=014C3P0D5Q42018D3`0C00lA300C5A003a4<
00lA300A4`h03a4<00/@2@0:3`P02a0900hC300B5a0051TB00dB2`0;40T0314:00hC300<4@X02Pl8
010C300200`?2009010C300?4P/030l800lB2`0@4``03a8;00hA2P0?4P/04A@=00802Q06010041H=
00hC300;40T01``5010E3`0X;BT05a`H01<H500H7AT02@d900050@0>4`l03a@@00`A3@0>4`l041DA
0P0<4@d09`0>4`l02a0<00`A3@0;40`03A8>014F4P0>4`l04QLC010E4@0<4@d04aPD00H;1`0B5Q<0
1``801<H500>5AH04Q/P00062@0@6AT03AHA018I4@0<4`/04AP@00lE2`0;40T03Q<<00`A2P1PIEl0
?44k01HK5@0@5@l02a0:00lD3P0>4`d00@H001XO6@011P0051TC00X?2@0200hC300700dB2`0<4@X0
314:00dB2`0D6A804aPA014F3`0300lD3@H03A8<1@0<4@/02@0;4P/07bHO00XD300J91`00`X300lF
3`083`P02a0:014D3`02010B3@0A018D3`0>40/02Pl900X?2@093PP020d700T>20083@L0008000`A
2`0A5Q004aPB00dB300F6aD03A8;00/@2@083@H00P0;40T06P0B5a003Q<<01`Q6P0730D02Pl800lD
3@0j?cP08RLQ0;Jk]@2PYIl03Q<=004600042@<04AH@01HK5@0:3`T02a0:010E3`0730H03Q0;00lA
300>40/03@l:00lA300A4`h0418=0P0A4`h06`0?4@`03@l:00`>2@0D5Q406adH00<5000@4Pd04A<>
01<E400D5Q405QPC014C3P0?4@`04Q@?00`>2@0B50l0418=01LI500D5Q402@/6014C3P0G6A@0418=
00D70P0C5A005ALB010B3@02014C3P80418=00h03a4<01lQ701=CdX06adH01DG4P0;3@P05aTD00X<
1`0P8Qd03Q0;018D3`000@006adH010B3@803a4<00@04A<>018D3`0@4Pd03Q4<1@0=4P`02P0:3`T0
3A8<01<H4P0>4`d04QLA00X?2@0?51003A8>00`A3@0?5102014F4P0Z010E4@0>4`l0=S/g01`Q7@0M
8Qh03a@?014F400?50d041D?00hC3@0<4@/04QLC01/P700i?SX06alN00lC4P062PT03Q8A010F500?
5A<03A<A00/A3`0:40h02a4?018H5P0A5aD051XH02le<`0J81h06b4M01LL5P0=4P`0@4Do04I;A@0D
6A@04QLC014F4P0@518041@C018F5@0G6aX06alN5?ooool001_ooooo03401`<0018A400310H02@hB
00L?5@002a40214H00TA600<4AD0414C018A400C4Q005QHF00X<2`0G6AP06A/J01DG5`0000801`P:
00D5200G61`0NW]o01dN8`020`P03@hC00421`0J6b0020P=00h>5P092A404Q8K00`<5P0000T02PXF
01@D800G5b403PlC00h?4@0@4A<04Q<E00h?4@0<3@l03a0B014B500C51H03PlA00X;3@0=3Q00414C
00803a0B00T0414C014B500A4Q@03@h@01HG6@0K71h04Q<E00l@4P0=3a<00P0A51T00`0@4aP03Q4F
010C600201<F6`0M018E6P0E61d051LL010C600A62002aTT018P;@10D5d0GVik04ADH@0B8Bh06BLb
01<P:@0A6B005AXN018F6@0F6ah0;C8f01dR:00D6Ad00PL:00lD600=4QD05A/K01PN7P0G7Ad04aTG
01@J6P0C6AX01@0A5QT02@0B5aX04AHI01<H6`0B5aX03a@G01LL7`1[L7<082DX00L<3`0201`Q900S
00/@4`0E6Qd04aPK010E600?51L04QLJ01LL7`0O9BD06b4Q010F5P0C6AT0DeUI059GFP0L8BD05Q/O
01LL800@5A/061dS01LM9@0H8C006RHf01PT<`0D7B`05AlZ01<M9`0L9Bh0620V018I7`0@61/041PJ
014I6`0A5QX04aPL018G6`0H7B400P0S:2`0;00K82@06QlS01lT:00K82@05AXN01hS9`0H7B<051TO
01TN900G72003a@H01<H700>4aH020d?014G5`0D6QX03aDE01<I6@0B5QT04ADI01<G6P0E6A`05ATK
018F5`0G6a`0720O01PL6`0F6QT05a/J01HJ6`0E6Qh061dS01@I7@2k`<H0AdaB01hS:@0P9B/061`U
01DI8P0D62404QHQ014E7P0D5ad04aLJ0P0B5QT02@0B5QL04aLH01XN7`0@51<04QHE010D4`0F6QT0
4aTG014I6002010I600G014J6@0B6aX04a`K01XS8P0F7ah041TH00hG5P0@6AP04A/G00PE3P0?71<0
4alG01LR6P084`/04QdE00dG3`0?5A403aDD00hD500M8RD08RLZ018H600A5aL00P0?5AD01@0?5A<0
41HD01<I5`0D6QH04QPD00803aDA00h031<<01PN6P0<4Ph05adL06meM@1;D5<05Q/N01<H700G7200
4aPK028W:P0G7A`03a@@00lD3P8041DA01404AHB018F5@0A5A@04QHE018F5`0A5AH03a<D00dA5009
3Q400PL:01@I6`083P`051XH02D[9`093`/02Q4:00`C300200`B3P0A00lE4`011`L06b4Q01@J6P08
3Ph06R0P00`B400@5Q@04ALE014G4`0@5Q803aDA00hD400<4Q003aDC00/A3`093`d00P0<4Q003@0B
61H02Q0>00lE4`0?5A<02@l=00lE4`0D6QP02Q0>00`B400?5A<0318@01@J600@5Q@00P0=4a401P0@
5Q@03aDC00X@3P083P`03aDC014G5@803aDC00l041HD00X@3P0B61H04aTG00lE4`0H7Q`0:2h/075j
M@11BTD02Q<>00PA300740/03QLB00T?2`0@6A@00P0A6QD01@0H8A`04AXE00X?2@093PP02a0:0080
4AH@0`0@5@l200lD3P0>00hC3@0=50d041PA01@N5P0B71@031H>02@^9P0;5@d01a4900dG3`0F81P0
218:00LA2@094`/200dD3@<031<<00X04aXC01PO600A614031<<010G400?5Pl0318;00/@2P0=4P`0
41D?0P0:3`T0200>4`d000@000hC3@083@L04aPB00P=1`0C61803a@=0P0>4``0300=4P/03Q<<01@I
4P0E6Q<03A8;00lD3@0@5@h02Pl800L=0`083P803A<700lE2P803aD;00<03aD<00dB2`0<4@/00P0;
40X0500=4P`0314:00L<1@0<4@X01@X300P=1P0=4P/0:2dV075fK`1TJF805Q/D0002000A5Pl041<<
018E3P0@4``030l800hA2P0<3`P04A@=0P0>4@X03@0@4``03A0900lC300=4P`05A`E00hE3P0<4``0
1`h7018I4P0940T03QD>00dD3@073PL00P0940T0200B5@h030l:0002000G6Q<04aH?00`?200C5Pl0
4QD>0`0@4``03P0@4`X02a4500`B1@0=4`T03a@=01@I4P0G71H0?44k01@I4`0>4``02a4700/A1008
3P803Q480`0?4P/2010C300900hA2P0A50d02`h700T<1@0<3`P03A0900`>2@0O8A`05ALB00803@l:
01T02`d8010B3@0B50l04A<>00d?2P0>40/04A<>00`A2P0=4P/03Q<<018G400F6a@05a`E00lD3@0>
4``03a@=014F3`0@5@h03Q<<00lB2`0=40T02@`500`?200>4@X02`h7008041<<00@03a8;00d@2@0?
4P/04A@=0P0;4@L0>@0B60l041D>00hC300>4``02Pl901dR7P0I7QX01P/700hC3`0J7a/04QLC00T>
2P0=4Ph03Q<?00lD400=4Ph02Pl;00/@300>4`l02a0<00hC3`0<4@d03A8>014F4P0<4@d03Q<?00dB
3P093PX010T501dR7P1/LFd07R<O0004000<4a<07bT[05ALGP042`T03QLD00P>2@0:4@X03QD=00lE
300:3`P02a0900dB2`0N8ad02Pl900450@0>4`d04QLA010E3`0D6A<03A8<00hC3@000P004QLA01<H
4P0400`A2P0600hC300?50d051TB01<H4@0@5@h03A8;0P0<4@X600hC3@D0314;00l02a8;00hE3P07
4@T05b4I00<:0`022@800@P100X?2@0A5@l0418=00h@2`0?4@`030h900/@2P0=4P`00P0:3`T08@0<
4@/02@h801PM5`0>4`d010T300/@2P052P@020d70002000C61403Q<<0003000=4P/010T2014F3`0;
40T01P/401HK50083@H01``500lD3P0Q9R0092TS00X?2@0F6aD051TC00P=1`0<4@/01``600/@2P0A
5Q003A8<00`>2@0300d?2P0500lA300A4`h030h9010B3@0A4`h00`0@4Pd0600;3@P04aD@00D70P0=
3`X0418=00h@2`0A4`h051HA010B3@0?4@`0418=014C3P0O8A`02`d800L91P082PD0008001DG4P08
2PD03Q0;024S7P0?4@`02`d8018D3`<0418=0P0?4@`03@0@4Pd0:2XU00d?2P0?4@`02P`7010B3@0<
3PT06Q`G00H80`0?4@`03@l:01/M600;3@P00P0?4@`0100A4`h04Q@?010B3@0>4P`500hC3@0600L<
1P0=4P`02a0:01XO6@14BD<03Q<=0P0;40`0700>4`l04QLC01@I5@0E6QH061dI00D:1P0=40d01@X6
014F4P083@P02@h800/@2@0B5a403a@>00P=1`093PX051TE018G4`093@`05QXI00X>3@0@51<041HD
00lE4`0<4Q002Q0>00/A3`0<4Q0200hD4P0<00lE4`0@5Q@04QPF00D;1`0;40X02a0901HK5@0K81X0
4QLB00T>2P0B5a<041DB0P0>4Q42010D4aCooooo000Kooooo`0]00l>2P0>3PP02P`800T<30083@l0
1a0D00X@5P0;41H030hC00d=4P0?3Q804Q4B00d=3@0?4A001PP700P:2@0=3Pl06Q/M00l@4P0A4QD0
3a0D01@E6@082@h0414F00l?5`071`h04Q8J01LG7`1BDU`06QXT010@6`0@41`03`lK014@7P0:2AL0
4A4L00l@500>3a<03a0D014B5P0?41@03@hB010A5@0?41@04a@H00803a0D03<051DI014B500B4aD0
4Q<E014B500?41803PlA01DF600@4A<02@X<018C5@0C51H05aTM00/>4`0=41D04aHK00`?500?4QL0
5aXO01HI7P0I72405APM00lB5`0A51T03aTS01PZ=`0W>TP0Zkc70>Cdn`3Ahnh0DF9_04YHH`0]>T<0
4a/R01XO8`0<3Q805QXM01HK7P0E6Qh04aPJ01PN7P0D6A/04QPG01DK6@0I7ad05Q`I00lE4@0?5A80
51XI01DJ7@0D6A`00P0B5aX0300A5QT051TL014F6@0A5QT04QLJ010E600C61/07R<V018G6P0E6Qd0
51TL03Pm@0804QLJ01X05AXM01/P8`0L8B@06AhQ01@I700Q9bL0:Bl_024W9`0oADD0/;Jf0:jc]@0M
8RH06AhR01XO8`0F6b40;34g02H/<`0J8C00624a01<M:`0F82d07BHa01PQ:`0F7bL041PO010G7@80
5Q/O01X03a@G018G6`0E6Qh05AXN01LL800L8BD05Q/O01DJ7P0D6Ad061dQ01<H700I7R80=CXn02hc
>@0E6R0051TO01/P900F6al05AXN01DJ7@0G71h03aDE014G5`0J820051XJ01@H6`804QHI0P0E6AX0
300B5QL05QXK01DI6P0@51D04aLH01DI6P0C5aX04AHL01PL9@0H72@0@TI?01PL9@805QXS00P04aLR
014E800D62<05QXU01@H8@0E61`04aLJ018F6@804ADF0P0B5QL0>P0E6AX04QHG01<G600O8b@05a`M
018I6`0E7Al051`N010H6P0B6aX05AhM00XC4P0=5QD041TG014J5`0?61D03aTD00HA2`0E81X02aH@
018M5`0?61<041LC00X@3@0=4a406QlN00hB4`0L82<09b`]01@J6@0B61L04ALE018H5P0D6QP04ALE
00hD4P0?5A<041HD010F4`0B61D04aTF00hD4P0G7A`03A<C01dS8`0D6A`02a0C01TN8@0<4A@03A8D
014G5`0@5QH051PF018G500?4a803Q8A010D4`0C5aH2018F5@0=014E500@51<03a<B00lC4`0<4Q80
5adL00dB4P0;4@l06AlM01lU8P0=4a00318>00hD4@02018H5P0400lE4`0>51<041HE00lD4`80318@
0P0>51807@0?5A<041HD014G5@0@5Q<03Q@A00lE500F71`04ALG00hD500@5QH02a4A00dC4`0U:b/0
4QPH00H<300B61P03Q@D00dC4@0M8b4020h<018H5P0?5A<04aTG01@J600>5180318@00lE4`0@5Q@0
318@00803aDC00D041HD00lE4`0>51804ALE00hD4P02014G5@0E00hD4P0=4a403aDC01LP6`0@6A@0
1Pl:00hG4P0740/02Q<>00/D3`0<5A003QLB00TB3@0>5a8031@?00lD3P0H7AL051TC00/@2P0>4`d0
5Q/E00803a@>0P0>4`d03P0=4P`0318<00hG3`0=5`l031H>00TC2`0A6a<03AL?018L500Y<b/08B/S
00XD300>61002A<;0P0<4``200dD3@8031<<01@03aH?014H4@0>5@h041L@00lF3`0=4`d03A8<00hC
3@0@5@l0314;00dB300@5@l03Q<=010E3`0=4P`020d7010E3`0>4`d03a@=00dB2`<0314:02L04QL@
0866O`2@UHh0:BhW01PM5P0D6A8041H<014G2`0@5PX03A<801TO5@0]<bT09BXR00`A2P0>4`d03a@>
00hC3@0?50h03a@=00P=1P0<4@X02a09010E3P0>4``02a09020U7P0M8Q`051TB00P=1P0@5@h03A09
010C300?4P/03A09010C300>4@X04QD>00d@2@0<3`P00P0>4@X00`0D5a0061dF00hE3@0200`C2`0;
00XA2@0<4``03A@<00XA2@0<4`/02a8:00T@200?5@h04QD>014D3P0?4P/00P0>4@X00`0:3@P041<<
010C300200lB2`06010C300A50/03A<700hD200?5@/03a@=0P0@5@l0200G71H02Pl900dB2`093`D0
3Q@800`B1P0A50/041<<0`0?4P/01@0>4@X04QD>01DH4@0>4@X02`h7008041<<00d05QPC03@f<@0J
71L03Q0;01PJ5@0B50l071hI00`>2@0@4Pd03Q0;00/=200A4`h03Q<<0080314:00l03A8;010E3P0A
5Pl0314:00/@2@0=4P/04AH?00lD3@0>4``04A@=01LJ4`0B5@h04A@=018E3P0>4@X00P0@4``03P0>
4@X03A0900lB2`0B5@h041H<00hD2P0D6A4041D>00dB2`0?50d03Q<=00hC3`0:3`/02a0<0P0@5A40
300B5a<03A8>00lD400:3`/03Q<?00`A3@0;40`03A8>00hC3`0:3`/03A8>018G4`8041DA0P0A5Q80
500@5A40314=018G4`0?51004aPD00`A3@0E6QH03A<C01lX:02IXJ80:2l^00hD4P0>5A003A8=00T>
1`0;40T041<<00d@2@0A50d03A8<0P0<4@/02P0A5Q004QLA00/@2P0>4`d020d701PM5`1bMg405Q/E
00`A2`0>4``200dB2`0600`A2P0=4P/03a@=00hC300=4P/0314:0P0:3`P00`0;40T03Q<=00hC3@04
00hC3@D0314;03402a8;01DL5@0;50`01`h804A;A00L8a`03aH?00hC3@0G6QD05ALB014C3P0@4Pd0
30h900dB300@5@l0314;00/@2P0?50h02a0:02<X8P0G71H01``600T>200<4@/08bPR061UGP0A5A00
61dF00T>1`0B5a003Q<<010E3P0K81T05AXC01@I4`0Q9Ql03Q<<00lD3P0;40X0314;00X?2@0?50h0
3Q<=00T>200:3`T0314;00/@2P0=4P`04AH@0080418=02803a4<00d?2P0>40/0418=00d?2P0B50l0
4aD@00lA300>40/03a4<01@F4@0H6QD0418=01DG4P0T9R404aD@00lA300A4`h0418=018D3`0@4Pd0
3@l:00h@2`0D5Q404aD@014C3P0F61<04aD@03Xl=`1VJ6<0@T@o010B3@0D5Q403Q0;0`0?4@`200h@
2`0=00lA300;3@P03a4<018D3`0C5A003a4<010B3@0A4`h0>C/f018D3`0L7QT01PP501<E400200lA
3004014C3P0B50l0418=00hB30D03Q<=01D03a@>00dB300<4@/061dG04I;A@0B5a401P/701<H500N
8al05AXF00dB3P0A5Q803a@@010E4@0>4`l03a@@00hC3`0@5A0041D?00hC300?50h00P0=4P`04`0L
8Ad09BXV020U8@15BDP04QHE00hB4@0=4A003aDA00hD400=4`l03Q@@018H500E6aL03A<?00lE4@0;
4@d03aDA00dC3`0A61800P0@5@l01P0<4@/03Q<=014F4@0;40`03a@@010D4P803Q8A00<0310?00/?
3_ooool04oooool001_ooooo00d07AdE014B2`0C50l0004000`@4@052Pd030lD00/>4`0W:2d03PdC
00T73P0A41D03`lA00<03Q0?02<03Q0@00h?4@0=3Q0061TL00L8300;3100414F00L83@0A4AT02PXB
02PX<00c<c/0aLG?02d]=`0A4Ad01`LC01DE8@0A41h02PTG00P8500?3aH00P<8018C600<3A805QLL
02LX;@0C51T00`@900h?500X:Bh061TN00d>4P0?4180414C00h?4@02018C5@0T00h?4@0=3Q003@h@
00L82P0F5aT02``>00h@50062@h04aHK03Tl@@0M82D02`hC01@G700;3Q<02PdB01LJ7`0F6Ah05APM
01LR:`0@8S00=4MF09ja`03`ool0dN?a041AG`0C8B`04AhW01HN900E6Qd061TM014E5`0C61/05A/K
01LM7@0E6a/04aTG0P0B61H0300D6QH04QPD00`B3P0A614061hL01<H6`0G71l05Q/N00lD5`0@5AP0
6AhQ01HK7P804AHI00@051TL01LL7`0E6Qd05AXM0P0D6A`0>P0E6Qd05a`O01dR9@0/<C@06QlR02P]
<00N8bH04QLJ01dS8`0C6AT06R0P01HL700e>c/0>Sm201PM8@0F6al061dQ020U:`0Q9R`041HM01HN
:@0D7RX04Q`X01<K:00F7BT06B0Z014H800B61l05AXP01LL800H7B405AXN028W:`0T:Bd04aPL01@I
7@0G720041DI01<H700F6al051TM014F6P0B5a/05Q/O01HK8@0H7B<04AHL02<X;00:3a<06AhR024V
:@0:3Q004ALG00L=3@0E6a/04aTI01DI6P0D61T201<G600E01LK700J7Ql05ATJ01/O800A5AH04ADH
01TM800G6Ql05ATS01dQ;00C5b80310K00L;500D624041@M01TM9P0@51d0<3@m00/?600H7B<04aLI
00804ADF00d04aLH018F5`0A5AH04QHG01PL7@0J7Ql05ATL01TM800B5QT051TM01lT:00P9BT05Q/N
008041DH00h05adM00lE4`0?5A<05Q`H00hD400D7QP02A@<00lH4`0:4`l04a`I00lE4`0>51<041HF
018F5`804aLH02T04QHG01@I6@0E6aT03aDC010F500N92808BLU01XP7P0G7A/0318@00dC4@0M8b40
10X801@J6P0B61P04AHI00/A4@0D6QX04aTI00hD50052`/02Q0@018H60093`l02a4A00T=3P0@51<0
1`/:00`@3`0C5aH041@C00lC4P0@51<04ADD00hB4@0=4A003a<A00lE4`0?5A403aDC00hD4P0200dC
4@0501LM6`0=4a4041HE014G5@052`T00P083P`08`0B61H03aDC00`B40073@/061hL00H<2P0H7Q`0
2@l=01TO7@0=4a403Q@C01TO7`062PX02Q0@00/A4@0=4a<041HF00X@400E6a/0318B00@:2P0?5AD0
3Q@D01LM6`1SJFL041HD01lU8`0630X07B<Q020V900?5A<04ALE00D;2@0:40h04ALE00803aDC0P0>
518200dC4@0600H<2P0F71X03A<A00T?3@0@5Q@02@l=0P0>510200dC3`80318>00X04ALC00lE4@0>
51002@l;01LM6@0Y;b/051TC010E3`0=4P`0314;0P0=4P`0900<4@/092TS0003000;40X03Q<=00T>
200@5a003QD>00XA2P0>5@h04QTB00lF3`0H7aP0<CPa010G400>5@h041L@00/B2`0@5a004QTB00hE
3P093`T05A`E00dD3@0@5a003aH?00dD3@0<4``03A@=00lE3P0=4P`0314;014F400B5a403A8<00X?
2@80314;01/03A8<00hC3@0>4`d041D>00hC300:3`P01``5014F3`0Q9Ql0>d0i0<gBb`3[l>T0=S/d
00dB2`0320404AL=010F2P0=4`L03aD:014G3@0?5@/03aD<00X?200@5@l03Q<=014F400>4`d00P0<
4@X200dB2`<03Q<<0P0=4P/05@0<4@X03A8;00hC300;3PL03a8;018E3P0>4@X030l8010C300F6A80
30l800/>1`0F6A801`X30495?P2TZZ007R@J00P>10052`405adC00/A1`0600hD2P18014D3@0@4``0
3A0900d@2@0?4P/041<<00d@2@0B5@h041<<00/>1`0B5@h04A@;00T?0`0A5``02a47018G400;40/0
0PL301hS7`0b=c4041D>00/A1`093`@041H:01DH3`0?4P/04QD>014D3@0=40T04A@=01@G400;3PL0
30l801DH4@0>4@X05aXC01/M600:30L03@l:010B3@0=3`X04A<>02h`:`0A4`h030h900d?2P0<3PT0
3@l:00/@2P0=4P`03Q<=00lD3P0=4P`0314;00X?2@0E6Q@01P/501DJ500D6A<02@h800lB2`0C5Pl0
3Q4:00d@2@0>4@X02Pd6018E3P0H6a@051L@00`?200C5Pl030l80P0B60h04P0:3`L02a0900`A2P0<
4@X02Pl900P=2@0<4@d041DA00hC3`0;40`03A8>00/@30083@T0314=018G4`0>4`l020d900X?2`80
3A8>00@02a0<00`A3@0=4Ph03a@@0`0@5A401`0?510020d901XO6`0;40`0314=00/@300=4Pl00P0=
4a4200`B400400dB3`083@T02Pl;010B3P804A<>00d04Q@>00hC3@0=4P`02a0:00dB300?50h02Pl9
018G4@0<4@/06b0J02T^:00L8A/02@h800802@h700<03Q<<00D:0`0;40T00P0@5@h00`0G71D03Q<<
00hC3002010E3P0D00P=1`0;40X03Q<=00X?2@0;40X04aPB00dB300<4@/04aPB00hC3@0@5@l01`h7
00T@2@094`/05AlG01`S700E71D03aH?00/@2P0<3`X200d?2P0P010B3@0A4`h03Q<=00H;1@0N8ad0
3A8<00`A2`0320803A8<01@I4`0C61803Q<=00lD3P0G71H0?d@m018G400<4@X041D>00D:0`0<4@X0
20d601PM5P0@5@h0314:00lD3@0<4@X041D?00dB30052P@03a@>00H;1@0=4P`200X?2@0G00dB300A
5Q003a@>00hC3@0E5a802P`700T;1P0>40/03@l:00X<1`0>40/03a4<010B3@0?4@`030h900/=200M
7aX0CU1;01DG4P0K7AP0OGmj01<E400A4`h00P0H6QD00`0@4Pd020X500X<1`0200`>2@05010B3@0C
5A004A<>018D3`0C5A000`0A4`h200lA3003010B3@0?4@`0418=00804A<>00@0418=00lA300?4@`0
3Q0;0P0?4@`3018D3`0c014C3P0@4Pd0418=010B3@0B50l051HA00h@2`072@@030h900lB3@0=4P`0
3a@>00`A2`0;40X03Q<=00dB300@5@l04AH@00X?2@0730H02a0:018G4`0320@0314=00hC3`001@40
41DA018G4`083@T03a@@00`A3@0@5A404AHA018G4@0>4``02a0:01TN60000P008RLS01DJ5P0H7AT0
7B4P00X>3@0F6QT03Q8A01<H500>4`l02Pl;00`A3@0@5A404AHB00802a0<00`04AHB01LL600E6QH0
3A8<00`A2`0;40T06b0J00hC3@0?50l08RLS00lD400>4Q0200lC4P803A4@5?ooool001_ooooo00d0
1@D000X;100J6aH030h;01LH6@0A5AP0310C01HH7@0l?D809bH/01HD6`0>3A803PlA00<03Q0?02<0
3Q0@00h?4@0:2`d03@hA00h?4`082@d0414F01lP9@0C4a/0000700/;4`0=3AD0@T9<00412`0>3QT0
5aLS01HF8P071Q@02@PF01PH900B4aT051DJ014B5`0D5AX061TN024R9`0>3Q<0:BX_06m`M@1YJVl0
30dB01DF6P0?41<03a0B00h?4@02018C5@0=00d>400?41803PlA00`=3`0F5aT04a@F01<E600>4AH0
7R4V0413B00W:Rl04aHK01@G700200lB5`804QDJ020061/P01TS;@086RH04bDc03U;F@1cQI<0J7Z8
024b?`0?7BP031TR00hF7@0@5AT05QXM018G6@0C61/05A/K01LM7@0E6a/04aTG01HL6P0N928082HR
01TO6`0B61@04aXC01HL6P0C61/05AXM01@I700@5AP051TL01<H6`804AHI00<04QLJ01<H6`0B5aX0
100C61/02@0D6A`05Q/N018G6P0O92L04QLJ024V:@0J7b8041DH01hT900201PN7P0G010F5P0P9RH0
7B8U01<H700A5QX041DI01@I7`0F6b4041HM01DM:00C7BL04Q`W01@L9`0H82T06b8Z01<J8P0C6B00
51TO01HK7`0G72005AXN014F6P0S:2`00`0E6Qh0100<4AD05Q/O01PM8@0G720201DJ7P0C01TN8P0E
6R004aPN01hS:@0731006AhR00P=4@0>4aH0FEmP02H/;00A5aL08bTY00X@400?4a@03Q8C00dA4P0>
4Q<04ADF01@H6@0300lC500@024U:00U:B`06A`Q018F800G6bH04QHQ01@H8P0<41T04QHO028V;`0J
7RL05AXP03m3B`0J7RL06b0V01<G6@804ADF00@04aLH018F5`0A5AH04QHG0P0C5aP05P0>4QD051PK
00hB5@0@5AT051TM01DJ7P0C61`03a@G00hC5P0C6AT02Q0>01@J5`0A5a<02@l;00`D3P084`/01@h9
00XC3`0C71T05A/K010F5P0A5aL201<G600B018F5`0A5AH03a@A00lE4@0?5A<04ALE01PN700E6aT0
318@01`R800G7A/061hL0006100K8B405a`O00lD5`0@5AP04QPI0P0A5aL04P0C6AL04QPF010F5P0>
51@03A<C00X@400F6Q/05a/L01XN7P0A5A@02`l>018F5@0?4a8041@C014E500>4Q403A8>00lD4080
3aDA00`03Q@@00hD4P0=4a403A<A018H600;4A401P`<00lE5@0B61H0318@00lE4@0;4@d200`B4080
20h<01h05Q`J01<I5`0>5180318@01PN700;4A406AlO01XP800H7Qh05Q`L00/A4@083Ph041HF00T>
3P0B61P041HF014G5`0?5AD03aDC01@J600I7ad051XH01<I5`042PP02Q0>01@J600>5180318@01@J
60093`d200lE4`803Q@B0P0=4a401P0<4Q00728P00P>300U:bT0C59@00dC4@803Q@@0P0=4`l200`B
3P0U00lE4@0B61@04aTE00`B3P0>510061hJ010E3`0>4`d03A8<00hC3@0A5Q004aPB00hC3@052P@0
2@h801HK5@0L8A/04QLA00hE3P083`P00`X300T@2@0<4``020l800T@2@0P9b002A0900dD3@0?5Pl0
3QD>00P?200120403A@=00L>1`0D6a@03A@=00`C300200/B2`0:00`C300=50d04ALA01DJ500D6A<0
314;00T>200A5Q004QLA00`A2`<03A8<01L03Q<=014F3`0F6a@061dF01DJ4`0B5a0051TB014F3`12
Ad00Jg1Y01dQ700@5@h04AH?00dC2@0<4PH02@l300X@1@0<4PP02a4700P=1@0730D02@h800L<1P02
01PM5`80314:0P0=4P/300hC30803A8;00<0314:00dB2`0>4``00P0=40T0400>4@X03a8;010C300?
4P/030l801/N5`0;3@T03a8;01`O600F6A80?D<i0003000B60h020h401@J40073@<600hD2P803a8;
0P0>4@X2010C300D00H90P0A50d03Q4:00P;100930D06A`E00X@1P0E6a00008002H[9@0Y;RT051TE
00P=2@0E6QD02a0:00hC300A5`d03Q@:014D3@0>4@X2018E3P0600hA2P0B5@h02`h701<F3`062@80
30l80P0?4P/03`0C5A002P`700lA300E5a803Q0;00X<1`0B50l020X500h@2`0C5A003a4<00h@2`05
2P@01``600`A2`02014F400H00lD3P0@5@l03a@>01XO6@1RIf40<3D_00T>200A50d03a8;00X=1P0>
4@X04aH?010C300:3@H03Q4:01@G400B5@h05aXC014D3@0D6Q005A/A00hC2`0?50d041D>0P0;40X0
0`0?51004aPD00lD400200/@3006010E4@0B5a<04AHB00hC3`0=4Ph03Q<?0P0=4Ph300hC3`@03A8>
0P0>4`l02@0E6QH0<CHb04mDD00K81`01``800hC3`0@5Q802Q0<00P>2P0200L=2`0800X>3@0P92<0
3a@@00`>2`0E5a803a4<00`>200;3@P200T>200F00dB300?50h03A8<018G4@0;40X04AH@01PM5`0@
5@l03Q<=024V7`0=4P/02a09018G400A5Pl020d600dB2`062`@041D>018G40083@H03a@=014F4080
4aPB00<0314;00X?2@0@5@l00P0@5@l03@0H7AL03A8<00H;1@0120404aXC00lI4@0C7AD04aXC00T@
2@042`@03Q<=00hA300=3`X00`0<3PT06`0<4@/02Pl900lD3P001@0041D?00lD3P0;40X03Q<=00dB
30093PP02Pl900lD3P0G71D01P/400hC300C61402a09010E3P093PL05a`E010E3P0<4@X03a@=00`A
2P0>4`d03A8<00L<1P0200hC3@03014F400B5a403A8<0080314;00<02a0:00X?2@0A4`h00P0>40/0
0`0@4Pd04Q@?018D3`0300lA300B00h@2`0=3`X030h900`>2@0I6aH071hI01HG500[;BP030h900lA
300E5a805QPC010B3@0<3PT03@l:00`>2@0:30L03@l:0`0@4Pd01@0?4@`03Q0;010B3@0B50l04A<>
0080418=00D03a4<00d?2P0;3@P02@/600`>2@02010B3@0400lA300@4Pd0418=014C3P80418=0`0?
4@`2014C3P0^010B3@0?4@`03Q0;00lA300@4`h03a@>010E3`0=4P`0314;00lD3P0A5Q0051TC01HK
5@0@5@l03Q<=018G4@0C61@02@h:01HK5`0G71P02a0<010E4@0E6QH04aPD010E4@0;40`08bPT00D:
1@093PP0314:00X?2@0=4P`06AhH06ebKP0H7AT06b0L020T8`0<40l04aLF00T=300B5a<03a@@00dB
3P0>4`l0314=00T>2P8041DA00d05AXF01/P700I7QX04AH@014F3`0H7AH020d701TN6015BTD03a@@
010E4@0=4Pl0310?00803A4@00<03Q8Aooooooooool04_ooool001_ooooo00d04Q<=00/<200>3`X0
3Ph<00d>3@082@X06AXK00X:3@0F5AX02`X?00d<4@0B4AH03PlA00<03Q0?02<03Q0@00h?4@092P`0
3PlB02TZ;P0A4QH02``A02X[<00J6al04a@I00L83@0C51T00P8901LG7`0I6B405ADN00@43@0?3aX0
2PXF018B700?41H05AHK00001@0B4aP03PlD01@E6P0A4QL01@H;01HG700J6b004A8G010A5@0>3a80
3a0B00d>4002014B500:00`=3`0B4aD03PlA01<D5P0>3a405AHH018D5`0:3A8030lD01@G70804A@I
02T041<H01PK800N8BH05aXO01@G700E61d04aXQ00XF800?72L03QdX01l^>P0V=D404B0/00TF800B
7BH05alV018G6`0D5a/04ADH01<H6`0E6Qd05Q/N01DK6`0C6AT03aDE01/Q7`0O9B<051XG01DK5`0G
7AT04ALF00lD5`0@5AP04QLJ01<H6`0L8B@03a@G010E600D6A`05a`O01HK7P05018G6P0U01<H6`0D
6A`02PlB01DJ7@0?51L06QlR01LL7`0A5QT051XJ01PN7P0G7Ad06AlO01PN7P0D6A`0724U01PM8@0E
6Qh051TO01<H7P0D6R406B4Y01LP:@0F7RP051dV01HN9`0H7bL06QlV01HK8@0C61h05APM01HI7P0E
61d03Q<G02`a=@0D6Ad041DI01PM8@0301LL80805Q/O00/05a`P01TN8P0G72805AXP01@I7`0m@TH0
51TM018G6`0B5aX0;C8d01hT900201@J6P0J014G5`0C5aH04QHE014E500B5QD05ATI01HJ6`0A5AH0
51PK014E600F6Qd05QTN00hA600?4ad04aLP00`@6@0B5Qh03Q<J01@I7`0C61d061dR00`A5@0F6al0
20dB01DJ7P0C5aH2014E501d01<G5P0B5QL04ADF010D5@0E6A`0720S01HJ7@0F6Ah03a8G010C6P0?
4QT041<I01@G700C5aX04QHI01@H6@0@5A80314=01HK5P0D6A<06B4J03]5?@0C71L04APE00hD500I
7R404ADI01<F6P0C5a/051LJ01@E6@0C51H04aPE01@K500A5a<041HB01<I5@0B61H03aDC01HL6P08
3Ph07R@T079hN00Z;c8041DI00dB5`0@5AX051TL00X@400<4Q00<cTf05=IE@0Z<2h01P/:01HL700>
51@020`?01LK7@0D61T04aLH04U=CP0e>CP03a<B010D4`0A5Q803Q<?00dB3P0?50h03aH>00hE3P0>
5@l03A<@00dC4@0=4a<020d@00`A500>51H03aDE014G5`0=4a40;C<_00dD3@0@5Q803aDA01LM6@0@
5Q@04QPF00881P0E6a/04QPH03i4A00c>3/010T<018G6P093Q4051TL00dB5@0>4aH02a0C010E600F
6ah03a@G01HJ7@0=4a<03A<B018H5P0C6AL05Q`J00/A3`0B61H010X8018G5@0K8Al020h<01@J6009
3`d200lE4`803Q@B0P0=4a401P0:40h0:Bl]01TO7@0I7ad0;38`00dC4@803a@@100>4`l00`0?5100
3A8>00hC3`0200hC3`0O014F4P0@5@l03a@>00lD3P0@5@l04QLA01@I4`0C61803A8<01TN600@50l0
4AH@018G4@0G71H051TC00lD3P0@5@l04AH@00hC3@0=4P`051TC00`A2`0?50h02@h800`A2`0>5@h0
20l801/R6`0<4``04APA00P?200200T@2@0600XA2P0;4P/031<<00`B300<4@/03Q<=0P0?50h2010E
3`803Q<=0P0=4P`06@0<4@/03a@>00lD3@0;40T02@h700dB2`0B5a005AXC00`A2P0F6a@03A4;018G
400A5Pl03A<900hD200=4`L03A<800hD2P0=4`T03149010E3P0>4`d020d701dR700P9Al01@0=4P/0
0`0>4``03A8;00dB2`0300`A2P0:00dB2`0H6a@05APA014D3@0C5Pl04QD>00hA2P0E61402Pd600d@
2@803Q4:00L0Gf9K01DH3`0<3`P051L>00H90@0B5@`03A0700H041<:00<030l800hA2P0@4``00P0A
50d0>@0@4``03a8;00hA2P0C5Pl09BPQ010C300B5@h03A<900lE300K81T0UY^E09fRW@0j?c/08BHR
00`A300>4`d0314:010F300630803A0900hA2P0B5@h04aH?014D3@0@4``04QD?02/^9`0A50d030l8
01DH4@0A50d030h9018D3`0=3`X030h9010B3@0>40/030h900/=200=3`X030h900/=200<3PT08RLS
010E4@093PX03Q<?010E4@0>4`l041DA00T>2P0=4Ph05ATE014F4P0=4@`03A09010C300300hA2P0?
00`?200`<b`04QD>01<F3`0=40T041<<00lB2`0>50X03aD;00`A2@0<4@X03A8;00lD3@0?50h03Q<?
00802a0<00<03A8>00lD400?51000P0@5A4200`A3@0600lD400=4Ph0314=00hC3`0?51003Q<?0P0=
4Ph00`0;40`02Pl;00X?2`0200/@300D01/P700d>CD03a@@00hC3`0@5A403Q<=00lF3`0>5@h03Q@?
00hB4@0?4a@0C4e?02X[;00A4A0051@A00h?2P0C5@h0418=00`A2`0=4P`300lD3P07014F400<4@/0
314;00dB30093PP03Q<=00@90`0200lD3@0:00P=1P0<4@X04QL@06Y_J00U:R<02a0900`A2P093PL0
3Q<<018G4@8051TC00P041D?00hC3@0B5a40<cPb00`A2`0@5@l04aPB010E3`802Q4:00L02A<;00dG
3`0>5@h03A@=01@K500=4P`03A4;00803@l:00X03Q0;00lA30083@L041D?00`A2`0730H03a@>00/@
2P0A5Q003Q<=0P0<4@/00`0=4P`02a0:00T>1`0200`A2P0C00X?20093PL0314:00P=1P0B5a003A8;
00T>1`0<4@X02Pl800/@2P0<4@/02a0:00P=1`0B5a402@h801<H4P0<4@/02Pl900/@2P0200`A2`08
00lA300A4`h04A<>00lA300>40/03a4<014C3P0>40/200d?2P0;00h@2`0?4@`051HA00`>2@0=3`X0
7AlJ00lA300;3@P03Q0;010B3@0A4`h00P0@4Pd02@0B50l04A<>00h@2`0>40/0418=014C3P0B50l0
3a4<00h@2`0200lA300500h@2`0=3`X03a4<010B3@0A4`h00P0@4Pd2014C3P<0418=00D04A<>010B
3@0=3`X03@l:00h@2`0300lA300800h@2`0=3`X03@l:014C3P0@4Pd03Q8<00lD3P0@5@l200hC3@0;
010E3`0;40X03Q<=00lD3P0=4P`02a0:00lD3P0A5Q80314=010E4@0>4`l00P0?51006`0;40`03Q<?
00hC3`0F6aL0?44m01LL5`0E6Q@02a0900hC3@0K81X0=CXd01XO6`0@5A405Q/G01XN7@0?4a804ADD
00/?3@0A4a004A<>01@F4@0E5a804Q@?00d?2P0>40/03@l:010B3@0201@F4@0=00h@2`0=4P/0314;
01LL5P0=4P`041DA00lD400@5A403Q<@00dA400?4a804QHE00lC4P0Dooooo`006oooool020000000
3`l=00X:20092@L00`<201`L6P0I61H02@T90P0@41800`0?3a403@d?00d?3P0300d?3P0K00d?3`0=
3Q001PL900l@4`0P8BD03a0D00<42@0;31403PlB01HG6`0:2`l0414E00h?4`0I6Ql0>3Tn03`m@P0H
620051@L00h>600K6b<02PXB01TI8@0F5Qh0<30h00X:4P0;2a<03`lG00802@TA00H03PhE00l?5`0I
6Ql03PlB00l@4P0=3Q02014B500f00d>400A4Q@04a@F01TJ700>3a405QLI00`>4P0<3a@051LL01HI
7P0E61d051LL00/>4`0F6Ah06QdR01@G700F6Ah04QDJ014F6`0A61h03aPO00`E7@0>6b@05b@]018O
:0095Ql05b4Z01dU:`0B6Qd04QLK00hC5`0B5a/04aPL01@I7@0C61/04QLJ01HL700V;2`09B/[014G
5@0@5Q@04QPF00dC4P0?51L04AHI010E600B5aX05AXM018G6P0A5QT04QLJ01@I700E6Qd051TL100C
61/09`0D6A`05AXM01@I700H7B005AXM01HK7P0E6Qd051TL01DK6`0H7Qh04aTI01DK6`0B61P041DH
01<H700?51P051TM01/P9P0H7B<05Q`R01HM9@0E7RD051dT01DL900G7BD06AhT01`Q9`0G6b404aHM
01@G7P0E61h051LL02T^<P0oA4P0724U018G6`0D6Ad04aPL01HK7`0201DJ7P0@01HK7`0H7B4061dQ
00/@5P0M8RP09BX`07EjOP0D6Ad041DI01@I700E6a`03A<C00T?3`0?5AD05adM014E50804AHB01H0
4ADD018F5P0C5aP04QHI01LK7P0C5aX04QDJ01PK800K7RD04QHO02``>@0N8bT041DK00`A5`0G7200
7R<W01DJ7@0A5aL06AlP01DK6`0B61H04aLE0P0A5Q80A00C5aH04QHG014E5P0C5aX04QHI01XN8@0D
5a`04QDJ00d@5@0A51`061/R01LJ8@0B5AX04aLJ01DI700>4Q804AHB01HK5P0C618041D?018I4@0h
@SX03Q@@010F500;4A406QhQ018E6`0@4aP051DJ01DF6`0E5QX05AHH01@H5P0@5a0031<<00`C3@0=
4`l03Q@B00/A3`000P009R`/01DK701JGf808BHY014F700F6R<061dS00`A5@0;4A403A<A010F4P12
BD80?48n01<I5P0A5aD04aTI00dA50000@@05ATL00dA4P0E6AX0;c<b00lC4P0@51<04AHB00hC3@0=
4P`03a@=0P0>5P/0;P0=50d03A<?00`B400<4Q<061dQ00P=4@093Q4041HF00L=3@0@5Q<09bdY00T@
2@0?5Pl01`d9018H500>518041HD00dC4@0?5AD020d@018G6P0=4QD082DX018G6P093Q406AhQ010E
600=4QD07R<V00P=400]<SD0004401LL7`073@d05A/K00D;2@0:40h010X801LM6`0>518092XX00T=
2`29Shd0BU1>00@:200I7ad200lE4`803Q@B0P0=4a42018H5P0401HL6P0A5aD020h<00`B40H03Q<?
00H03a@@00/@300;40`03a@@014F4P0?510300lD3P0<010E3`0A5Q004AH@00<70P0Z;bT00@H000hC
3@042@<00`P2010E3`0K81X05AXD0P0;40X03@0=4P`02Pl900H;1@093PP041D?00/@2P0B5a404QTB
01PO600@5a001Pd601XQ6P0>5@h00`0<4``00`0;4P/02Q4:00`B300200hC3@803A8<00D03a@>014F
400>4`d03Q<=00dB300200`A2`0=00/@2P0;40T03A8;018G400C61403a@=00P=1P0>4``02a09024V
7`0A5Pl01@X3014G3@0200dC1`0900`B1`0;4@L02a4700hC2`062`@0314;00P=1`0730H0314;00L0
3A8;01@0314:00/@2@0;40T02a0900dB2`0F6A805aXC01HI4P0@4``03a8;018E3P0930D01`X301XM
5P0F6A803A0901HI4P0C5Pd03a8700/>0`805QT>00<02Pd300lB1`0?4PL00`0?4PL0100?4PT02`h7
00d@2@0@4``2014D3@0E010C300M81T03a8;01<F3`0`<b`051L@00/>1`0>50X051TA00`A2P0G71H0
:Rl/02HZ:@0P92<01P/700hC3@052P<02a4800`B200=40T041<<00804A@=00@03a8;00/>1`011000
5aXC0P0C5Pl0GP0H6a@09bXS018D3`051`801PP301hP6`0K7AP01`T400lA300=3`X02P`700`>2@0D
5Q406A/F01`Q7@093PX01@X600hC3`0C61@04QLC00H:1`0=4Ph01``801DJ5P000`00314;00/>200C
5Pl04QD>00/>1`0?4P/05aXC02/^9`0520401PT200D80@0=40T041<<00`B200=4`T03Q<;00/@2@0=
4P/03A8<00P=1`0730P041DA01@I5@0=4Ph02Pl;00/@300<4@d03Q<?00T>2P0;40`03Q<?00T>2P0:
3`/041DA01<H500?51003Q<?00lD400<4@d02Pl;00/@300<4@d02Pl;00P=2@0Q9R802Pl;00050@07
30P03a@>00`B200@5@h04QLB00hB4@0<3@l0000400P92`0@40l0410>010A300>3PP03a4<00T>200:
3`T02a0:00P=1`0<4@/07b@N01DJ500?50h201<H4P0?010E3`0A5Pl00`P100H:1@0H7AH010T200`@
2`0U:R<02a0901@I4P03204010T201<H4@093PP02a0:00<03Q<=00l04AH@04I;A@0B5a403A8<00hC
3@0:3`T01`h700XA2P094`/02aD=00/B2`0<4``05QdF00dB300>4@`00P0?4@`02`0B50l04aD@01HK
5@062`H00`P201<H4P052P@03Q<=014F400;40X020d700802a0:00<01P/500`A2P0=4P/00P052P<0
;00?50d03Q<<00T>1`0>4``02a0900T>1`0;40T0314:00X?2@0A5Q0051TC00`A2`0E6Q@01``600dB
300;40X03A8<00lD3P0>4`d0314;00lA300<3PT03Q0;018D3`0<3PT01`T4014C3P0>40/030h900d?
2P0>40/03a4<010B3@010`003@l:00T;1P0;3@P05aTD014C3P0>40/03@l:00h@2`0?4@`0418=0`0B
50l0100A4`h0418=01<E400B50l2010B3@0800lA300=3`X03@l:010B3@0A4`h03@l:00X<1`0;3@P3
00h@2`0700d?2P0>40/03Q0;00lA300>40/03a4<010B3@02014C3P0700lA300C5A005ALB00d?2P0<
3PT03Q0;00hA300200dB30803Q<=00l03A8<00`A2`0=4P`03a@>00hC3@0?50h04AH@00dB3P0:3`/0
3Q<?00P=2@0B5a<04AHB01TN6P0:3`/00P0=4Ph040052PH01P/6014F400<4@X02@h80005000R9b40
2a0<00P=2@0>4`l03A4@00/?3P0<40l04QHD00d?300>40/400lA3003010B3@0?4@`0418=00804A<>
00d0418=00T>1`0D6A805a`F00/@2P0E6QD03a@@00dB3P0A5A<04ADD01HJ6@0H71/03A4@01Cooooo
000Kooooo`0<01HF5P0=3@/00`<101dM6`0:2PP03@`:00h=2`0510@02@T900h>400820X00P84100<
3Pd03P0<3Ph030d?00`=3`0?41<02``@00`=4@0=3Q<020T=00/<3P092P`04a@F00@4200:2`l02``@
0P0D5AX03@0000D02@TA00L73`051@d03@dE00`<500A4AT09BD]00`<500C4a/02PXB01DE7@0@41P0
0P0B4QX010082@h03a0C010A4`0>3a42018C5@0N00h?4@0<3@l04A8D014B500=3Q004a@F00/=4009
314041<H00d@5@0<3a@03a8G00`?500>4AH03a8G00`?500A51T04aHK01<G6`0I7R80724U014I7`0:
51d03QPQ018O:00<5Ql03aPO014I800>5A/051TM0P0B5a/301<H700;018G6`0F6ah08BLW024W9`0A
5aL041HD01<I5`0B61T05AXM01<H6`0?51L00P0@5AP0100C61/04AHI00hC5P0?51L2014F6@@04aPK
00P051TL01DJ7@0I7R4061dP01HK7P0B5aX04aPK01PM80805A/K0P0B61P06`0I7al061dP01`Q9@0G
72006QlS01XO9@0B5ad04aPN00lF7P0?61l04AXQ01DL900I7bH06b0V01XO9@0F6R4051LN01DH7`0E
61h051LL01<H700W;3005a`P01HK7`0C61`03Q<G01PM8@0201HK7`0?01PM8@0J7b<06AhR018G7@0C
61h08BH/02@Y;@0M8RH020dA00lD5`0H7Al02@l?02P^;P0>51@01`d;00804AHB01L04QLC018F5@0B
5QH04QHG01DI700:3Q40310C01PK800I724051LN01DI8@0k@4H0;c@j01/P9@0>4aL05AXM01DJ700C
6AT04QPH00dC4P0C6AL03Q@@01<H5002014F4P1Z01<G5P0B5QL04ADF028V:@0B5QT051PK00hA5P0C
5Q/04aHM014D7@0I72<061/R018E6`0C5aX05a/L010D500E6QH0=3Td01<H4P0:3`P02a4:01XT6`09
3`/051XI00dB5@0D5a`041<I014D6`0D51`05AHK01DF600D5AL04QDA00dD3@0A61405A`F014G4`0=
4a407bDS01TO7@052`/051XK01DJ7@0?51L03Q<I01XN:@0K7bP03A8E010F500A5aD01`d801XQ6P0F
71P041HC01`R800B61P041@G00lC5P0B5QT000@500dA4P0G6aX03a<B010D4`0A5Q803Q<=00dB300?
50d03AD:00dE200=5@`0318>00`B400<4A@0Ada@01`Q9@062`h05A/K00`B4P0=4a0020l80006000=
50d02Q0<01<I5@0B61H02@l=014G5@0?5AD051TL00hC5P0C61/020d@00X?4P021`X05AXM00lD5`0;
41<00`P;03@i?02UZZd08bP[00dB5@0730l04aTI00`B40804QPF00P02@l=014G5@093`d09B/Y061V
I00S:BL07R@R00L=2`803aDC0P0>518300dC4@06014G5@0<4Q003A<A01<I5`0@5Q@03A8>0`0>4`l2
00lD400:00hC3`0B5a<04QLC018G4`0<4@d01@X600/@2P0<4@/03Q<=014F40804aPB01P07b@N07Ai
L`0U:R@03a@>00P=1`0Q9R004QLA020U7`0K81X04AH@01<H4P0E6Q@06AhH00lD3P0=4P`041D?00/@
2P0A5Q000@L100hE3P073PL072<L04mFC`0]=2d300hE3P0:00`C300;4P/04ALA01@I4`093PP00@D1
02<X8P1GG5H0Ada600hC3@<03A8<00h0314;014F3`0?50d02Pl800`A2P0@5@h03Q<<010E3P0A5Pl0
6b0I04Y?B00F6a@00`P100hD2P803aD900T03A<800`B200=4`T04QL?00P=1P0E6Q@04QLA00T>200?
50h00P0>4``300dB2`<0314:0`0;40T0100<4@X030l800lB2`0A50d200d@2@805APA0P0>4@X0100=
40T071lH01@G3`0?4PT200d@1@0301<F2`0;3P<03a8700H03Q4600<03A0900hA2P0?4P/00`0@4``0
5@0F6A804QD>00`?200E61402@`501DH4@0D6Q001``501TN5`0D6AD04ADC0001000<40l020d:01<H
4P0=4P`02a0800hD2P0>4@X04QD>00lB2`0200hA2P0<00T<1@0D5a005aXC01DH4@0B5@h010L101<F
3`092`H03Q0;00lA300C5A004Q@?0P0=3`X06@0@4Pd03@l:00lA300B50l04A<>00lD400;40`03Q<?
01DJ5P0B5a<03Q<?014F4P0J7a/07B8N00hB3P083@T03a@>010C3@0@4``03A0900X=1P0H6a@09bXS
01dP6@0>4@X00P0D5a004`0G6Q<05APA00X@1P0;4@L03Q<;00T>1`0:3`P08RLQ02L/9P0D6AD03A8>
014F4P0>4`l02a0<00`A3@0B5a<06AhJ00`A3@0730P00P0=4Ph0100<4@d04aPD01LL600B5a<200lD
400X00dB3P0<4@d03A8>00hC3`0B5a<0008000P=2@0?51006AhJ01DJ5P0D6A<051X@01PM5P0K81/0
5a/J01@E5`0D5AT07b0T01HF5`051@<030d801DE400?4@`020d700`A2`0@5@l0314;01DJ500V:bD0
6AhH00`A2`0?50h05AXD01@I4`03204082DN00hC30093PL041D>00/@2@800PL000@051TB00T>1`0<
4@X03Q<<0P0:3`T200`A2`802a0:00l03a@>00D:100A5Q002a0:00`A2`0H7aP02A0900H@20094`/0
2a8;00XA2P0@5a0041D?010D3P0?4@`00P0>40/02P0?4@`041D?00T>200F6aD0=3Tc00hC3@0=4P`0
4AH@00dB300;40X200dB300D00X?2@093PL02Pl800T>1`0<4@X03A8;00D:0`0>4``041D>00hC300=
4P/03Q<<010E3P0730H03A8<00hC3@0=4P`04AH@00T>200?50h200hC3@0:00lD3P0:3`T020d700h@
2`0:30L03Q0;01HH4`0C5A003@l:010B3@803Q0;0P0=3`X02P0>40/04A<>014C3P0J71L02`d8010B
3@0F61<04Q@?00d?2P0<3PT200h@2`0400`>2@0>40/0418=010B3@803Q0;0P0?4@`0100>40/0418=
018D3`0A4`h200d?2P0;00lA300>40/0418=01HH4`0E5a803Q0;00d?2P0<3PT03@l:00h@2`0@4Pd0
0`0A4`h2018D3`09010B3@0G6A@06adH010B3@0>40/0418=00lB3@0=4P`0314;00803Q<=0P0=4P`0
0`0>4`d03a@>00lD3P02010E3`0D00<810042@D05AXF00lD400A5Q802Pl;00hC3`000`003a@@01LL
60062`L082DP000200093PL05a`F00hC3@0I7QP04QLC00X?2`0@5A4200X>3@0700H:2@0A5A<05QPC
01HH4`0D5Q403a4<010B3@03018D3`80418=0P0A4`h030021`00314;00T>200320805AXE00@91@0=
4Ph04ADC010D4`0F6QT06alN00dA41Cooooo000Kooooo`0<00H72@0<3@d04A4A03`k>@0F5A@03Pd;
014@3P0<2`T02`X8014A4@0<3@d02@/:100<3Ph0700<3Pl030d@00l@4`0>3a<01@H:00d>4`0B4aP0
2``A00/<3P0A4Q<02``=00d>40082@/03a0B00l@4`0:2`h02@X=01hO900Q8RL030dA00/;4P0<3A<0
414G010@5`0?41H03PlE010@5`0@41P200d=5@08018B6P0C51T04A8E018C5@0A4Q@051DH01DF6@0@
4A@201hO8P0900X;3P0A4Q@0414C00lA500>4A@04ADH00lC5P0:3A4041<G008041@H01406QhR01`O
8`0=41D030lD01<E600F5aX03Q8E01@I7P0P:2l05alV018K90084Q/0210H00hE700B61h061dR01@I
7P03018G7@0@018G700B5a/04AHI018G6P0F6al05AXL00lD5P0B5aT05AXL01HK7P0B5aX03Q<F01HK
7P0K82<05AXM01<H6`<04AHI00<03a@G018G6P0A5QT00P0A5QT0500B5aX051TL01PM800C61/051TL
00lD5`0F6ah092T/018G6@0=4a<061dN01@J6`0[<C809b`_01<H700E6Qh06QlS018G7@0@5A/0<3Dk
0P0B6B4201<J800`01@J800D6Al05a`R01HJ8@0F6B005aXQ01LI800C5Qd051TM018G6`0@5AT06QlS
01TN8@0E6Qh05Q/O01<H700C61/05Q/O01TN8@0G72004aPM018G700D6Ah05APL018G6`0C61/06b0S
01DK700A5aL0;C<c01<I6@0C6AP05AXG01HK5`0F6aP05QXJ01DI6P0E6A/05ATL01<F6`0D5a`05APM
018E700A51/04QLL020U:P0C61d05Q/N0P0B5aX01`0B61P05A/J01/Q7`0=4a006b4N00lE4@0C6A80
0P0A5Q806P0C61L04QHG014E5`0L82<041<I01LK800C5Q`051LO01<F7P0E62004aHN01<F7@0F6Al0
720S01hR8`0D61P06b0L024V8P0F6aD05AXC010F3P0;4P/041HB01DK6P0?51L041<H0P0F6B00F00G
61h05QHK01<C5@0A4Q@04ADA010G3`0A5a8051XF00dC3`0;4@h03a@B00X@400E6a/07B<S010E5`0B
5a/04ADM00lC7@0>4aX04QLK00lE4`0>51805A/F00`C30083PP03aDB018H5P0=4a<03Q8E00hB5P0?
4aD04QHG010D5@0@51@03a<B010E4@0A5Q803Q<>00dB300?50d03QD900dE2@0=50`03A8>00`B400<
41<0:Bda01HK7`0=4QD04AHG00dC4`0>4a003aH?01HM5@0<4P`02Q0<018H500J81d04ALE00/A4@0=
4a<02a4B00dB5@0;41<06QlS04mDF00?51P04AHJ00dB5P0D6Ad03Q<G02DZ;`0S:2d03A8G01<H7@0D
6A`04ALG00X@3P0D6QP03A<A03<i=`0;4@l03Q@B018H5P0A6AH03aLD014H5P0mAD4200lE4P803Q@A
0P0=4a00100A5a@051XG00hD4P0;4@l200dC4@803A8>00h03Q<?00lD400?51003a@@00`A3@0A5Q80
3A8>00hC3`0@5A403A8>00`A2`0=4P`03Q<=00lD3P803Q<=01h02@h801lT7P0;40X041D?00L<1P0<
4@/03Q<=00lD3P0<4@/03a@>01<H4P0B5a40:c0Z01/P6P0@5@l03A8<00/@2P0=4P`04QTA00T@2@0?
5Pl03QD>020W800>5@h031<;00dD3@0>5@h03QD=00dD3@0@5Pl2014F400501<H4P0B5a403a@>00dB
300<4@/00P0=4P`200hC3@0401lT7P0Q9Ql04AH?00/@2@803a@=01802a0900lD3@0=4P/08bPQ00X?
200C61403Q@;00lE2@0@5P/03A<800X@1P0<4PP0318900P=1P0?50h01P/500P=1`0;40X300hC3004
00dB2`0<4@X0314:00`A2P802a0900D02Pl800/@2@0<4@X04aH?010C300200d@2@0>00hA2P0?4P/0
3A0900D80@0B5@h02`h7018E3P0<3`P04QD<018E2`0@4`T03Q4700d@1`0A50X600hA1`8041<<0P0>
4@X2010C300G00lB2`0B5@h04A@=00lB2`0A50h041<=00T?1P0>4`/0314:018G4P0=4Ph041DB00X>
300C61D03A8<014F400:3`L041H<00`?200@4``02`h700`?200A50d0100=40T08P0E61403Q4:018E
3P0];bX04A<>00h@2`0@4Pd03@l:00lA300D5Q404A<>00`>2@0>40/03a4<00/=200=4Ph0314=00dB
3P0?51003Q<?00dB3P0@5A403A4>00P=2@0=4@d04aPD00X?2P0B50h02`h700hA2`0@4P`03a8<01@F
400>40X2018E3P0J00/>1`0?4P/020/300`B200>50X04AH>00X?20093PL06QlI01`Q6`0@5A002a0;
00dB3@0>4`l0314=00P=2@0=4Ph05a`H00`A3@093PX05Q/G01<H500;40`03A8>018G4`0@5A4200`A
3@0X00dB3P0>4`l03Q<?00hC3`0=4Ph02a0<01hS7`0:3`/02`l<00/@300=4P/03Q@:00dB2`0=4Pd0
310?00h?4P0=3Q402@T=00l?400G5Q@05QDB010A2`0A4`h02Pl800dB300?50h02Pl901DJ500?50h0
3Q<<00`A2`0=4P`041D>00lD3P0=4P/0>Chg01dR6`0<4@X04aPA00`A2P803a@=00@0314:010E3P0?
50d02a090P0<4@/04P0=4P`03Q<=00hC3@0:3`T03A8<00P=1`0?50h0314;010E3`0:40X02Q4:00L@
200>5Pl04QTB00hE3P0<4``0314;00d@2`8030h90P0>40/01@0<4@/04aPA00dA3@0/<B/03A8<0080
3Q<=00<03A8<00`A2`0=4P`00P0>4`d0200<4@/02Pl800hC300>4``02Pl800`A2P0>4``03A8;0P0<
4@X02P0=4P/041D>01XO6@0D6A<02Pl900lD3P093PP03Q<=01<H4P0=4P`200`A2`0300/@2P093PP0
3Q0;00803a4<0`0@4Pd200lA3003010B3@0?4@`03@l:008030h900H06A/F00D70P0B50l03@l:00lA
300@4Pd200`>2@05010B3@0?4@`03@l:00h@2`0?4@`00P0=3`X0300A4`h04Q@?00h@2`0=3`X03Q0;
00lA300=3`X03a4<01<E400B50l03Q0;010B3@8061XE0P0?4@`01@0>40/03a4<00lA300B50l04aD@
00804Q@?0P0A4`h0100>40/04Q@?01<E400=3`X2018D3`0600dA2`0>4`d03Q<=010E3`0A5Q003Q<=
0P0=4P`07`0<4@/03Q<=00hC3@0=4P`04AHB00lD400T:BD061dI018G4`0@5A404AHB010E4@0F6AH0
41@@01<G4`0>4@d04aPB01HK500?50h051TC00870P0@5A402Pl;01<H500<40l04ADD00H:2@0@5180
4Q@?01@F400E5a400P0A4`d04`0D5Q004aD?014D3P0?4@/03@l900hA2`0A4`d04aPA00`A2`0E6QD0
3A8=010E4@0B5Q@03a<A00hC4@072`X03a<C01/O7P0@51<05?ooool001_ooooo00<030`<00d=3@0>
3Ph00P0>3Ph00`0=3@d02`/;00d=3@0200l?3`0G00d=3@0;2`d051DI00@52P0K72403@hC00/<4@0B
4aP03a0E014B5`0@4AH02@TA00l?5`061``030dB018C5`0?41@03PlC00l@4P0=3Q002P`<00L9200:
30/00`0>40d0@`082PT03a0B01@E5`0>3a402P/?00h?4`0@4AH020T>00L83@0<31@0=cLo0083200D
5AP02@X>018C5`0>3a@05aLO00d=5@0K6b<02``A00h?500G61`00`@600d?3@051`8010H101LI500=
3``02@/8010B400=3`h0414C01HG6@0D5AT05QLK02DV:`0<3aH010L>02HY<@2]/KX092Pa014E7P0B
5Ql04ADN01@H8@0F6B805APQ01DH7`0D5ah041<J014D6`0D5ah05APO00lB6@0H6b005APO01TL8@0C
5Q/02@`A01HJ7P0D61/04QHI010D5`0G6ah0>3`o01hR9@0F6Qd00P0G6ah00`0?4aH04QHI018F5`04
018F5`0K01<G600=4A803Q8C014E5P0C5aP051PI01DI6`0F6ah0:2d`028W:P0B5a/0724U01LL800?
51P05a`P01`Q9@1BEe/0Zk2d04aAE@0G72803a@J018G7@0K82H05Q/Q01<H7P0E6R005Q/Q00805AXP
05`04aPN014F6P0A5QT05Q`M01DK6`0H7B007B8T01HL700D6A`05AXL01LM7@0H7B005Q/M014G5`0G
6a`03a<B01@H5`0F6QT04ADE01DI6P0H71d051PI01XN7`0G6ah041@G01XN8@0;3a8051LL01HI7P0@
4aP07B0U00L:3`0A51X05QTP014D6`0>4AP03A0G01/N8`0H71l020`?00hB5@0A5AL03Q8C01TM7P0B
5QL020`=01`P8@0=4A40=CTj01DK6@0C6aD051XF01@M600D6aX041DH00hF6@0D6R404ADP01@K9@0B
5b@030lN00lC7P0H6b4020/@01TM800?4aH02`l@014E5P0e>CP061`K010D4`0B5a<051TE00lG4`0@
6AH051dJ014G5`0E6AX061TM01<D600I6Qh082@W01TN800<4Q802Q<B00lE5@0I7Ah02@d>00lC5007
2`X04ADF018F5@<041@C00H04ADD01<G5P0D61X03a<F00H:3@0N8R@201HJ6@803A8>02003Q<?00lD
400@5A404AHB018F5@0A5AH020`<010D4`0F6QT0310?01/O7P0;3`h0310?00D9200D6AD04aPD00X?
2`0<4@d03A0=014C4P0C5aH03Q4A018C5@0J7Ql03a8C01TK6P0C5aH03a8A00dC3`0?5A4041HC00dC
4@802Q0>100>51801`0=4a<02a4A02<X:`0d>C`0314D01DJ7P0@5AX00P0;41H08@0]<CX000@=02@X
<`1YKGP04QHO00hF600740h02Q<@00`B400V:bT061`K00T?2`0D6aL000H000lL5@0A6a@03AXA00dD
3@0C61801``600hC3@0>50h02Q4:02D/9@0G7aT01@h901HO6P0<5A002a4=00hC3`0A5Q804QLC00lD
400400dB3P07010E4@0>4`l02@h:00/@300>4`d03A8<00`A2`0200dB300R00hC3@0@5@l03Q<=00hC
3@0A5Q005a`F00`A2`0J7a/01P/700@91@0A5Q80QHZ6055FDP0>4`l06b0L0004000@5A402Pl;00/@
2P093`H04aPA00/A1`1@EDd092TR00hD2`06308020d6010F3@0F71804aPA00lD3@0A5Q8041DA00lD
40803Q<?01H04AHB00/@300;40`02Pl;00`A3@0A5Q80314;00dB300?50h041D?00lD3P0=4P`0314;
00dB300>4`d03a@>00dB300<4@/03Q<<01DK4@0D6A803A8;0P0>4``300T>1`0I018G40093PL0314:
014F40011P004AH@00X?2@0E6Q@041D?00X?2@0L8A/02Pd900X?2@0A5Q003A8<014F40062`D03Q<=
00X?2@0<4@/02@h800/@2P0=4P`041D?00hC3@0200`A2`0P00dB2`0@5@h01P/400/@2@0=4P/0314:
00P=1P093PL0314:014F3`0G71D06QlH00lA300=40X01PT2010C2P0>4@P02Pd4010C2P0G6Q802Pd6
06AVH@0>40h030h;00h@2`0>4@X03a8;014D3@0?4@`020X500`>2@0=3`X200hA2P0900d@2@0<3`P0
4A<>00T;1P000@006A/F00P:1P0L7QT061XE00802P`700<05ALB00d?300E5a800P0A4`h0300@4Pd0
3a4<00`>2@0;3@P03Q0;01DG4P082PD04aD@00@60@0A4`h02a0<00lD40803A8>0280314=00L<200@
5A4020d900`A3@0=4Ph0314=014F4P0=3`X00`D000lA3P0@4Pl0@D=201DG5P0;3@X03@l:0044000>
4@T061/B00d@1`0A5Ph06QlH01<H4@083@H02a0900dB2`0;40T03a@=018G400?50d02a0:00hC3P0?
4a803Q8A0P0=4A00200>4Q40310?00hB4@0:3Pd041@C00lC4P0:3Pd03Q<?0P0<4@/02P0=4P`03Q<=
00hC3@0<4@/02@h8010E3`0:3PT010T301XO6@052@D200X?2@0M00/@300=4Ph041@C00lC4P0:3Pd0
5QPF00P:1`0@4Pl03@l;00dB2`0>50X03A<:00hC300B60h03aD<00`A2P0<4PP02a4800/@2@0<4PP0
3A8:010F300F718051X@00T?1@0;4@L051X@00/A1`0=4`T00P0@5P`02`0?5@/03A8:00lD3P000P00
3a@>00hC3@0:3`T03A8<00P=1`0C618041D?00802Pl900L02a0:00<80P0C6A803Q<=000400083@L0
2a0:00803a@>01003A8<00`A2`0<4@/03A8<02ld;@13BD003A8;01dR6`0@4`l0314:024V800;40/0
41DA00/@30062`L04AH@100=4P`00`0;40X02@h800/@2P0500/@2P0900lD3P0;40X01@X400X?2@0>
4`d051TC010E3`0;40X02Pl900802a0:01<02Pl9014F4P000`00314=00dB3P0A4a003@l<00h@3@0?
3`d04A4?01@D4P0?3`d02`/900d?2P0A4`h051HA01<E400>40/030h900804A<>00P03a4<00d?2P0?
4@`04A@?018G4@0A5Q002a0:00lD3P804A<>00<04Q@?010A300@4@`00P0A4Pd07@0@4Pd01``601PM
5`0=4P`05AXD01@I4`093PP0314;014F400=4P`041D?00dB300<4@`051TE010E4@0B5a<02a0<01<H
500=4Ph020d900870`0L8Ad03A8>01TN6P052PH02a0<00dB3P0>4`l03A8>0080314=01L01P/700`A
3@0?51001@X600P=2@0:3`T04QLA00/@2P0=4P`03Q<=00h@3@0E5a@06adJ01PH600?3`l04A4A010@
400:30T03A8>018G4`0<4@d04aPD00X?2`0200dB3P0<010E4@0C61@02a0<018G4`0<4@d03A8>010E
4@0A5Q8041DA00lD40083@T0314=0P0@5A403P0>4`l02`l>014E500A5AH03Q8C00`@4@0=4A804ADF
00dA4P0?4a@01PX;00dA500=4A<03Q8C5?ooool001_ooooo00<02`/;00`<300<30`00`0<30`00`0;
2`/030`<00`<300200`<300@00/;3@082@h030`D01DE7@0;2a<03`lG01DE7@0C4a/030`D00d=5@0:
2Q804A4I00h>5P0@4AH04a@I00l@5@802``@00P02@X<018D500?4A003a4>00h@300<3PT03@l:018D
4@803Q0?02P02`d<00`=3`0B4aD0414E01LH7@0A4QL0:2P`065QJ@0Y:Rl03a0C00T:3P0I6Ql04Q8J
01DE7`0D51h02@TC00h>600[:c<05aPM00421P0L7Q/06ahG01`O600930D051HA01dO6P0F61D04Q@A
01@F5@0G61T04Q<E01<D600@4QL03a8K01XM9P0N8BX0A4M@00lB6`0E62404QDN0P0A51d01P0B5Ah0
4aHO01DH800B5A`03a8I010C6P804aHM00d04QDL01`O9P0F6B005QTP018E700;3QD04QDJ00dA500C
5aX04QHI00lC5P0L82<05QXM00<04aLJ00@041@G018F6@0A5AH04QHG0P0E6AX06`0D61T04QHG010D
5@0A5AH04aLH01@H6@0E6AX05QXK01XO8`0S:2`07B8V01<H700J7b<05AXN010E6@062`l07R<W0825
R@35b/h0:Rlc01@I7`0E6R0092T_02db>00M8RP04AHL01<H7P0301@I7`0E01<H7P0B5a/04AHI01LL
7P0D6QX051TL01TO800F71`05a`O01HL7@0F71`05a`O01<I6P0>51@04ADD01/P700H7AT04QLC014E
500C5aH04aLH008051PI03`051PK01<G6P0C5Q/05QTP01XM900B5A`061/R00hA600;3QD04QDL01<F
7@0G6R408bH]010C6P072Pl05ATK02hb<`0H71d04ADF00hB4`0;3a0051PI00dA4P0R9RL06AdN03m3
A00R:2H01`h:00D>2@094Pl041PI01<K7P0B6Qd03A@K01/R;00A5b<0318P01@J:P0J82`07R4U00dA
500E6A`01`/<03/o@00D61T07B4P014E500D61L04aLF014E500>5A@03aTH00lH5`0;41403a<D01<D
5P0A4Q@05AHH01PI6`0D6AX200dF5@04014H6@0D61/03a<F014E60<03A4B00<041@C014E500B5a<0
0P0B5a<04P0?4a<05QXK01TM7P0`=3@092PW01/O7P0<40h03a@@010E4@0A5Q404QLA01<H4P0830/0
4QHE01PL6`0<40l02`l>00lC4P801PX900`0720O00T=30093@`0310?010B4@0A4a80418A014C4P0D
5QD03Q0?01TK6P082PT201<E5009014C4P0D5aH03A4@00lE4`0B61H041HD00lE4`0@5Q@03A<A00<0
3Q@B02L03A<A00`B400630`05Q/N00H;3P0A5QX05AXO01@I7`052A8020`F01lS;P0B5R40SY:N01DL
900@61X04Q/I00dF4`093`d041DC0045100=4`l00@X501LT7@085@h03alF00/K4@0;4P/04aPA00`A
2P0B5a0041H?01@K500?5Pl02a<<02@^9P14CDP09c0[010I500>4`l00P0A5Q80300>4`l03A8>00hC
3`0?51005Q/G01TN6P0A5Q803A8>014F4P0>4`d03A8<00`A2`803A8<01l03Q<=010E3`0B5a403a@>
00P=1`052P@020d700860`0=4Ph04AHB00L;200n@cl0:2dY00lD400>4`l01``802H[9`0730P02@h8
03To=P011`001`d301HL4P000`004AL=00P>100L8QP03Q8<0003000B60h03a@=00803Q<?100?5100
1P083@T0314=00dB3P0?51004aPD00dB3@803Q<=00H03A8<00hC3@0>4`d03A8<00/@2P0<4@/300hC
3@0300/@2P0?50d04AH?0080314:0P0=4P/02P0M8Q/05AXC00dB2`0<4@X02a0901HK5@0730H04aPB
00T>200A5Q0200/@2P0>00L<1P0?50h0<cPb04M<AP0:3`T00@H0020U7`0=4P`02@h800dB300>4`d0
2a0:00T>200:3`T200dB300;00X?2@0;40X041D?00X?2@0>4`d03A8<00`A2`0=4P`03Q<=00lD3P0@
5@l00P0A5Q004@0<3PT03a8<00X=1P0B5@`04QD;01@G300C5P/03Q4800d@2@1LGUT051HD00P:1`0:
30L03A0900P;100930D041<<00803A09100?4P/03@0=40T04A<>01DG4P0N81/02@/605]MF00<3PT0
2`d800`>2@0?4@`06A/F00h@2`092`H00P0=3`X200h@2`<03@l:00D04A<>00X<1`0B50l04Q@?014C
3P0200hC3`0400/@300<4@d03A8>00X?2`803A8>01L04AHB00hC3`083@T02Pl;00lA30072@H05QPE
018D4`0g>3X0414C010B4@0?4@h03Q0;014D300@4`P01`X1010E3P0D6A803Q<<00P=1P0;40T03Q<<
00dB2`0200hC300?00dB2`0<4@X020d800H:2@0>4Q4051PG014E500<40l02Ph=01<G5P0=4A00310?
014E500=4A0041@B00<041D?0P0A5Q001`0D6A<041D?0005000U:R@03a@>00L<1P0B5a800P0;40`0
100<4@d03A8>00lD400?510200D:1P0;00X?2`0B5a<02a0;00X?200<4PP02Q0600/A1`0?5@/03188
00hD2P0=4`T00P0<4PP01`0>50X04AL=00dC2@0B60h041H<00T?1@0;4@L00P0@5P`06@0A5`d04aT?
018H3P0A5`d03Q@:01XO6@0?50h01@T501hS7@0G71H03Q<=010E3`0;40X03a@>00dB300;40X061dG
01LL5P042@<01``6024V800E6Q@02a0:00dB300<4@/00`0:3`T03@0:3`P02@h701hT6P042P005a`E
00dB2`0;40T01``600dB3@0@5A404QLC01DJ5P001000100>4`d800dB300>00H;1@0D6A<05a`F01LL
5P021`404aPB010E3`0;40X02Pl900`A2`0;40X02Pl900lE4@0E6QH200dB3P0M018D4@0@4Pl03a4>
00l?3@0@40h04a<A010@3P0=3@/03Q0;01HH4`0J71L061XE010B3@0<3PT02`d800`>2@0620<04Q@?
01XL5`0<4@/03A@=00lD3P0<4@/03a@>014C3P0>40/03@l:00d>2@0?40/00P0B4`h07P0C5A001@X4
0005000A5Q00008000hC3@0?50h010T3018G4@0=4P`04AH@00D:100B5a802@h:00hC3`0;40`01``8
00X?2`083@T04aPD02ld<013B4@02a0<00T>2P0?51002a0<00dB3P0>4`l03A8>00`A3@803A8>02@0
5a`H01@I5@093PX03A8>00L<200@5A40314=014F4P0C61@04Q@A010@3P0F5Q@051@D00l=3P0A3a00
4A0A01`N6`0@5A404QLC01dR7P0?51003Q<?00dB3P0;40`0314=00/@30062`L0314=00`@3`0=4A00
41@C014E500@51<03a<B00/?3P0?4a82018F5@0;00lC4P0<40l041@E00hB5@0?4aH04QHI01<G6P0@
51L05ATL020T9`0=4A@00P0@51L00`062Pgoooooooooo`0Booooo`006oooool300`<300300/;2`0<
30`030`<008030`<0P0:2PX02`0<30`030`>00d>4`0;2a<07AdU010@600J6R80ShnG02`/=00D51`0
5ADM00<03@dE00X04Q8J01@D6`0?41D03PlD00l@5@0=3Q402``>00d>3`0:30/02P/;0P0=3`d0100=
3`h030h=014C4P0B4aD200d>4P0T010A5P0>3a@04Q<H00/;4`0Q8BT020P>018C5`0:2a0051DK00h>
600@41`051@P00l?6`0>3QT06a/T00h?5@0F5a/0:2X[00h@3@0=3``04A<@00d?3@0<3P`04A<C010A
4P0A4Q@051DG00l@4P0A4Q@04Q@I01HI800:2a80<SDl02T/<`0E61l041<J0P0D5ah01@0B5A`041<J
018E700D5ah04QDL008041<J00@04A@K018E700B5A`05QTP0P0B5A`0100G6R406A`S01PK800A5AP2
01HJ7@0>018F6@0@51L02`lB010D5`0?4aH03Q8E01<G6P0B5QT04ADF01<G600G6a`061`M01HJ6`0A
5AH301@H6@805ATJ00d05QXK01LL800F6al05AXN01HK7`0G720061dQ01LL800F6al051TM018G6`0_
=3P04AHJ00804aPL0P0D6Ad01@0A5QX04QLK010E6@0B5a/04aPL008051TM00L04aPL014F6P0G71l0
4aPL010E6@0E6Qh06b0S00804AHJ00H04aPL01DJ7P0D6Ad04AHJ014E5@0F6QX2014E5@0801@H6@0:
3Q0051PK01PL7`0F6Qh051LL01DH7@0B5A/201@G7P0700d@5`0L7bH04A@K01/N9@0A51/05aXQ00hA
6002010C6P0R01DH7@0D61X04ADF00hB4`0G6a`02Ph?01XN7`0D61T03Q8C01PL7@0<41407b<T00P=
3P0T:bX051dK00lG600@61T04QXM00`D5`0A61h04APQ00H=5`0A62<05A/W00P>5`0C5QP05a/L01dQ
8P0C5aP0J6a]024U9P0B5QL03a<D01@H6P804QHH02`061lO01TP800C6AT041@E01HF600H61X05A@G
018B500A4A<03a<D00lF5P0@5aL04QLJ00P;400B5AX02`lC01<G6P0A5AP03a<E010D5@0B5QL051PH
01<G5P0B5QH03a<D014E5P0;3a005a/L00dA4P0D61L041@C00hB4@0?510041D@014F400A5Q4041@C
00P<2`0G6aX02@d<01@H5`0C5aH0:Bd/00`@3`803Q8A01@051PG00dA400A4a8051HE018D4`0A4a80
4aDD00lA400D5QD01PP701HH5`0620L05ALF00d@3`0>4Q403aDC014G5@0@5Q@03aDC014G5@803A<A
0P0>51808`0=4a40318@00/A4@0;4A403A<C00`B4`0>4aH02PlC010E6P0D6Al0HfQ_01/P9`0_=3d0
3A@K00L=3`0A6QP01a0=00lE4`0@5A@051PG00T?3@0A6QH04b0I00TF3`0<6Q<01A0900`D3P0?5@l0
3A<>014H4P0;4Pd05A/G00lE4P0=4a001@h:00803aPE01001Pl<00hC3`0A5Q804AHB00lD400>4`l0
3a@@00hC3`0H7AT06b0L010E4@0=4Ph04aPD00hC3`0=4Ph0314=0P0=4Ph0300>4`l02a0<00hC3`0;
40`03Q<?018G4`0g?3P09R/W00T>2P0@5A403a@@00T>2P803Q<?01<03A8>018G4`0@5A402Pl;018G
4@0Q9ah04QP>00T?1@0?5@`05adC00`B200=4`T0=3X`02X`9`0<4PX06R0F00T>200:3`/0314=0080
3a@@0P0>4`l04P093PX03A8>00hC3`0=4Ph03a@@00`A300?50h03A8<00`A2`0=4P`03a@>00hC3@0<
4@/02a0:00dB300?50h041D?00lD3P803a@=00d03A8;00hC300?50d03Q<<02L/9@0G71D01``5014F
3`0>4``03Q<=00H;1@0>4`d020d700804AH@00d051TC00<80P0A5Q00<cPb04aAB`0@5@l061dG05AI
D`0R9b4041D?00lD3P0:3PT041D?0080314;00P04aPB01DJ500@5@l02Pl9010E3`0<4@/041D?00/@
2P80314;01P03A8<00lD3P0?50h03A8<00X?2@0=3``04Q@?00lB2`0E60l03a8701<G2@0A5@L041@7
01hQ5`0j?CD04Q@>00lB300:3@H06QdF014D3@0<3`P04QD>00/>1`0>4@X4010C300A00hA2P072@@0
3a4<00P:1P0F61<08R@P01DG4P0?4@`0418=05]MF01TIV40418=00h@2`0C5A004Q@?014C3P0?4@`0
0P0>40/01P0@4Pd03Q0;018D3`0;3@P09BLR00P:1@8041DA00<02a0<00`A3@0?51000P0=4Ph00`0C
61@05a`H014F4P0200X?2`0C00`>2@051`@05ALD00`>3@0L7Al01PL900lA400B5140418=00hA2P0>
4@L03a8900hC300<4@/02Pl900/@2P0<4@/03Q<=00dB300200`A2`0700dB300>4`d03a<?00dA400?
4a803A4@00X>3@0200T=300600hB4@0:3Pd041@C00lC4P0830/03a<A0`0@5A402P0?51003Q<?00dA
3P0?510041DA03Xo>`0F6aL02@`9010E4@0?510200hC3`0>00dB3P0>4`l02@h:01@I5@0>4`l03A8>
00T<2@0F6aH02a0900dC2@0;4@L03188010F300=4`T200X@1P0900T?1@0:40H02a4700hD2P0:40H0
318800/A1`0<4PP03aD;00803A<90P0>50X05`0=4`T0318800T?1P0<4@/04AH@014E401NHed0C55;
00`@2`0=4P`01``600lD3P0@5@l04AH@02L/9P0oA3h05Q/E028W8@0B5a402@h900`A2`0>4`d03A8<
00802a0:00h0314;00dB2`0>4``0318800X@1P0A5Pl03a@=00/@2@0<4@/03a<?00hC3`0;40`03a@@
00X?2`802a0:00<02Pl900/@2P0=4P`01`0>4`d01`0?50h02Pl900T>200A5Q0020d701HK5@0?50h0
0P0;40X02P0<4@/02a0:00X?2@0=4`l0=3Te02@Y9@0B5Q<04Q@A00T;2@0@4Pl200l?3@03014A3`0@
40h0410>00803a4<0P0@4Pd06@0?4@`03Q0;014C3P0A4`h02P`701XL5`0S9B004AH@010G400C6180
51TC01DJ500F61<04Q@?00h@2`0>3`X03a0;010A300?40/03@l:00dB300B5a40BDi800/?2`0?50h0
0P0=4P`04@0>4`h03a@>00dB3@0>4`d03Q<>014F4P083@T041DA00lD400>4`l0314=00T>2P0>4`l0
41DA01/P70042@D03Q<?00@03A8>0240314=00lD400B5a<06b0L01HK5`0;40`03a@A02HZ:P0Y;Bh0
5ATJ00lC500?4a<04A<C00h@3`0A4a804Q8B014A4@0C4a<051<D00X<2@0E6QH02a0<00lD400730P0
4QLC00lD400A5Q806AhJ01LL600B5a<02Pl;00hB4@0?4a800`0@51<00`0?4a8041@C018F5@0201<G
5P05010D4`0>4Q403Q8C00/?400@51D00P0G6a`01`0@51D02Ph?00dA4P0@51D05a/L00dA4P0D61T0
5?ooool001_ooooo00D0410@00l?3`0=3@d030`<00d=3@0200h>3P0L00d=3@0;2`/02`/;00d=3@0>
3Q0030dA01@E6P051P/03@hC01TJ7`0^;c@06AXO00D62`0A4QL03@hC00`=4P0=3AD0410H00d=5@09
2A402`/B00h?500;31403a0E014B5P0;30h02``?00d>40802``>02l04A8D01/L7P0M7R804Q<G00d>
4P061``01@H;01/L8@0=3AD02PXB00d=5@0?41D04A4I00d=5@0E5B005A@R014@7P0:2QL05ADQ00d=
5`0@41L04a@I00X;3`0K72006Q/O00`=4@0G61`04A8F00P82`0=3Q003PlA010A4`0>3a40414C01PJ
7`0H6b006ahS010C60062@h041<H01PK800D5a`05aXO01HI7P0B5AX03a8G014D6@0201<F6`804QDJ
0P0C5Q/2018E6P0?00d@5@0A51T04aHK010D600C5aX04ADH01<G6P0D61/04ADH00/?4P0C5aX04ADH
00hB5@0E6A`04ADH00<04aLH0P0B5QL02@0A5AH051PI01@H6@0C5aP04QHG01<G600E6AX04QLK010E
6@0201DJ7P0E014F6P0H7B407B8V018G6`0A5QX03Q<G01XO8`0I7R804AHI01HK7P0J7b8061dP01@I
700@5AP03Q<F010E600B5aX04aPK01@I700D6Ad04AHJ008051TO00l04AHL01HK8@0R9bd06AhT01HK
8@0C61h04QLM00hC6@093Q805QXM00`@4P0C5aX05ATL01<G6P0R9BX00P0G6Ql0500N8BP06A`S00lB
6@0G6R406A`S01<F6`0G6Ql01`X?020S:00>4AH05QTN01<F6`0A51T05aXO00P;40031P/01`/=01`P
8@0;3a0041@E0P0=4A8201<G600[01LK700D61T0720Q014E5P0P9BP041DH00`A5@0@5AT05Q/O00lD
600M8RH000D;01XO9@0oA4X0<cPn018G6`0320H03A4@01<G5P0=4A004aLH00P<3@0@51L02`lB00`?
500;3Q<03Q4F01@H700A5AH03Q8C018C5@0E5AL0518E01@@500F51L061PJ01<D5P0=4A803Q8C014E
6P0C5Qd06QdT00lB6@02014D6@0?010C600@51L04QHI01<G6P0B5QL03a<F00/?4P0=4A@06alR0455
A`0H71d03A4B00dA4@0=4A003A8>00<03Q<?01002`l>01TM701:CTd06alN01HJ6@0;3`h061`K00H:
2@0E6AP041@C014E500;3`h03@l>010B4@0?4A003@l>0P0A4a802P0:30/04A<B014C4P0G6AP071hM
00hA400F6QT05A/I01<I5`0=4a4200X@3P80318@0`0>5180;P0=4a405Q`J00X@3P0@5Q@03A<A010F
5P0@5AP02@hA00hC5P021`/0314E00hC600=5AP051dL01LQ7@084@h051XH00dB400>4Q403aDC00D>
2`0>6QH04alK00PH4P0>7AP041/G00dF4`0:4a004a`I00dF500?61D01Pl>00D>300:4a801a0?00XC
4P0E7Q/03Q<?010E4@0?51003Q<?00lD400A5Q803A8>00/@300=4Ph200/@3004010E4@0>4`l03A8>
00`A3@803A8>02<03Q<?01<H50093PX01``800dB3P083@T0;34]01<H500730P06b0L00/@300<4@d0
5Q/G010E4@0<4@d010T500/@300A5Q806QlI00`A2P0=4P/02a0900`A2P0:3`P02a0900hC300<4@X0
5AXC01HK500;40T02Pl800/@300=4Ph03Q<?00dB3P0200/@300]00L<200;40`04AHB01TN6P0Q9R80
51TD00`A2`0=4P`03Q<=00dB300<4@/03A8<00hC3@0<4@/02a0:00`A2`0>4`d06AhG01HK500;40T0
3A8;018G400?50d0314:018G40093PL03A8;014F3`0?50d04QLA010E3`0>4`d010T300L<1P093PP0
20d7010E3`042@<00@H00005000:3`T000<000hC3@093PP01P/500803a@>0P0:3`T200`A2`0O00dB
300@5@l03A8<00hC3@093PP03Q<=00T>200=4P`01``600T>200=4P`03Q<=00dB300;40X020X700/=
2@0C5Pl08B@K01`O4`0P91D03a<401@H2@0F6P/04QH800/?0P0?4PL03Q4:020S700E614030l8010C
300200`?20@03Q4:014030l8014C3P0A4`h03a4<00@60@0?4@`0418=00L9100@4Pd07R0K02DW8P0>
40/02@/601HH4`0C5A004A<>00lA300200h@2`803@l:01X06adH01LI500l?ST06adH00hC3`0A5Q80
3Q<?00lD400>4`l02Pl;00P=2@093PX020d900T>2P0=4Ph03Q<?010B3`092`X051HE00l@4P0D5AL0
414C00lA4@0P8Ql03@l:00`>2@8041<:00H0314:00/@2P0>4`d03a@>00dB300;40X200`A2`0@00dB
300>4`d03Q<=00`A3@072`X01PX900P:2@0<40l061`K01HJ6@072`X03A4@02/_;P0E6AP01`/:01<H
5@803A8>00d0314=00/@300;40`020d900L<200=4Ph02a0<0004000B5a<02@d9010E4@0?51003Q<?
00803A8>00/000D1018G4`093PX03a@@028W8`1bMg80314:00dB2`0;40T0314:010E3P0200hC300:
00lD3@0B5a004QL@010E3P0>4``0314:00dB2`0<4@X04AH?01@I4P<03A8;0P0?50d2010E3P09014F
400;40X041D?018G4@0730H02a0:00X?2@0N8ad05Q/E00802@h800T02a0:00L<1P0K81X0?D8l00hC
3@0@5@l04AH@00hC3@0=4P`00P0<4@/03P0>4`d03Q<<01@I4P0630804QP>010E3P0C61403Q<<0005
000A5Q4041DA000200000`004AHB10093PP00`0;40X0314;00`A2`0500`A2`0D00X?2@042@<08RLQ
020U7`0;40X00`P200dB300;40X0314;00dB300<4@/02Pl900X@300B5a<07B8N00D:1P0];b`0:2XW
00lA3P0@40h200l?3@03010@3P0A4@l04A<>00<0418=0P0A4`h0200=3`X02P`700d?2P0;3@P03@l:
014F400@5a003Q<=0P0=4P`00`0@4Pd051HA018D3`02014B3@0K010A300>3`X03a4<00hC3@0=4P`0
41D?018G4@0;40X01``600hC3@0I7QP0PhR201LL5P0?50h0;C8]08J;Q`0]<Rh05Q/G00460P083@T0
41DA014F4P0?5100=3Te071eL@0^<bl0314=00803Q<?01403A8>00`A3@0<4@d051TE010E4@0>4`l0
3a@@00dB3P0=4Pl04aPL01LL8P083A4020/@00/>4`0>4Q@04Q<E014B5003018B4P0>014A3`0?4@h0
7B8N00dB3P062`L04QLC00hC3`0;40`0314=01PM6@0F6aL04aPD00/@300@51<500lC4P06010D4`0A
5A@04ADD010D4`0?4a803A4@100>4Q<0100A5AH051PI01<G600D61T200X>3`0300861`072`cooooo
01?ooooo000Kooooo`06018B4P0@41003@d=00d=3@0>3Ph03`l?0P0>3Ph200d=3@0;00h>3P0>3Q00
20T=00l@5@092Pl030dB00/;400000D04A8G00H7300@4AH00P0<3A803`092Pl06ATS018B6P0<31@0
3@dE00l?5`0;31401`P=00T:3`0720`04A8G01LH7@0B4aL03a0C00d>4P02014B5P0E00h?4`0?41@0
4Q<H01LH7@0I6Ql051@L00d=5@071`l030dB01PH800?3aT03@dI00H54`081aD061LU01LG8`0?3a/0
20PA01PH800D51/0410H00804a<K00<04Q<H01@E6P0F5a/00P0B4aL0500B4aD03PlA014B500H6ad0
004401PK800D5a/06QhQ01DH7@092`l04QHI018E6P0D5a/04ADH00`?500=41D04aHK01DH7@0D5a`0
4QDJ0P0C5Q/0200@4aP05APM01<F6`0L7b@08B@Y01<G6`0E6A`05QXM0P0E6A`03`0=4A@041@G01@H
6`0D61/04aLJ01@H6`0A5AP05ATJ01@H6@0B5QL04ADF010D5@0A5AH051PI01<G6002018F5`0G01<G
600F6Q`05AXN01@I7@0G72005Q/O01<H700D6Ad05AXN018G6`0D6Ad000<700H;3`0M8RH03a@G014F
6@0>4aH0314D010E600>4aH03a@G014F6@0C61/00`0D6A`02@0D6Al04aPN01@I7`0C61h05Q/Q020U
:`0C61h04QLM014F700201<H7P0;014F700D5a`051PK020T9`0E6A`041<G03Tl@@0E61d04aHM01XM
900K7RD00P0F6B803@0E61l04A@I028U:P0<3a@0>Se2028U:P0<3a@02`hC00hA5P0A51T051LL02LZ
;`0I7Al00P0;3a00100A5AH04aLH01@H6@0830d200/?400?00lC500A5AH03a<F010E6@083A<020dA
00lD600E6Qh04AHJ00H93@0320`051TL01XO8`0F6ah0318B00805AXF02P05Q/G01LK6P000@805a/L
00hB5@0=41D05APO01<F7@0@4a`03a8G00/?400>3a4051@F018@4`0B3A405A0D01/F6P0L6Qd05ADG
00d>400>3a402`hC01dP:@0@4a`04A@K00hA600D5ah041<H00lB5`0@4aP04ADH00lC5P0>4QD04ADH
00X>4@0420/0720R00861`0:3Pl04aLG0P0?4a83010E4@0=00X>3@0B5QD0<CDd00lC4P0B5QD03A4@
00hB4@021PD03Q8A00T=300B5QD03A4@00/=300200lA400700`>3@0@4Q404Q@C01LI600C5A@03@l>
01XL6`0200P:2@8061hL00<051XH00dC4@0:40h00P0;4@l03P0<4Q003Q@B00hD4P0>51803A<A010F
50093`d020h<00hD4P0@5Q@04QPH038h>00E6a/00PP80P0E6Qd0:0063Q0031DD00dG500<5A805A/I
00lD4`0;3`h04ALE010I5P0F8Qh000P40310?0034Pl02Q@C00hF60053@l03ADG00dE5P0;51<0EemQ
010I600?61L041TH01/T8`1:D5003Q8A010E4@0?51003Q<?010E4@0B5a<03a@@00T>2P0:3`/0314=
00hC3`0B5a<03Q<?00dB3P0<4@d200dB3P0b00hC3`0D6AD03A8>00dB3P0@5A4000D100hC3`0@5A40
0@H201DJ5P0;40`041DA00`A3@0<3``0;c@`08^@S00:3`/051TE01@I4`0E6Q@04AH?00lD3@0A5Pl0
1P/400hC300D6A801P/400T>200<4@X00@H000lD3`0<4@d03A8>00hC3`0<4@d02a0<00lD400:3`/0
314=00dB3P0A5Q8061dI00lD3`0;40X03A8<00lD3P0=4P`02a0:00dB300>4`d200dB3080314;01@0
61dG01@I4P0730D02Pl800hC300;40T03A8;00`A2P0730D04aPA00hC300=4P/03A8<014F400<4@/0
1P/500T>200@5@l0314;01XO6@804AH@00L00`P200lD3P0E6Q@01P/5018G4@093PP03Q<=00802Pl9
00T0314;00hC3@0;40X02a0:010E3`0?50h03A8<00T>200C61800P0<4@/02`0;40X0314;00dB300=
4P`02a0:00T>200=3``030h:010C300I71<051P:00807b<B00d08bLF00/?000A5@@06al@01PL3P0>
4@P051L@00`?20062@8030l801<F3`0<3`P03A0900803Q4:01`03A0900`?200B50l01PL401HH4`03
1@0061XE0001000B50l03@l:004300072@@02P`701HH4`0?4@`03@l:00`>2@0>40/0418=014C3P0?
4@`0418=01PJ5@0D5Q409BLR01<E400=4Ph04AHB0P0?51005P0=4Ph020d900`A3@093PX01``800lD
400E6QH04aPD00lA3P0<3Pd03Q0?00l@4P0@4A<051DG00X:300C5A@02P`900lA300B5@`03Q4:00`A
2`0=4P`2010E3`0D00dB300;40X02a0:00`A2`0=4P`03Q<=00lD3P0C5aD051PG01<G5P0?4a804aLF
01lS8P0K7ah01PX900/?3P0Z;Rd04aLF00H:2@0C61D200hC3`<03A8>01l04AHB01DJ5P083@T04aPD
00dB3P0D6AD04AHB00lD400>4`l03A8>00`A3@0=4Ph082DQ01hS7`093PX00@H200D:1P0R9b802@h8
00/@2@093PL02Pl800hC300;40T03A8;00hC300A5Pl04QL@010E3P0>4``03A8;00803Q<<00<041D>
01<H4@0=4P/00P0;40T05P0=4P/03Q<<010E3P0A5Pl051TC000200011P002a0:018G4@0>4`d00@H0
01dR700D6A<020d700/@2P062`D07b@N028W8@0B5a401P/500X=2@062`D200/@2P802Pl90100314;
00dB2`0=4P/02Q0601HL4P0C614041D>00H;10093PP05AXE00lD400Q9R80=3Te00X?2`0;40X03A8<
0P0>4`d00`0=4P`0314;00/@2P0500/@2P0C014F400[<2X0>Sli02H[9@093PP03A8<00`A2`0;40X0
314;00hC3@0<4@/02Pl900X@300C61@0;c@`01PM6@0W:BH05aTF00lA3P02014A3`0b00l?3@0@40h0
4A4?00/=200@4Pd051HA018D3`0<3PT02@/6018D3`0?4@`05QPC010B3@0?4@`061dG014H4@0>4`d0
3A8<00/@2P0@4Pd04aD@010B3@0@4@`04Q<>01<D3`0A4Pd03@l:014F400B5a4010P401`Q6`093PP0
0`P201TN60021`40?T<m0005000J7aT010T40415@@021`<020`900@91@0E6QH03a@@00H;1`093PX0
6QlK01dR7P083@T2010E4@0O00hC3`0<4@d0314=00dB3P0F6aL041DA00X?2`0=4Ph041DA00lD4P09
3Q@04aLP018F7`0I72D061/R01<F6P0B4aL03PlA00l?400@41003Ph>00`=2`0@4Pl010T500X>2`0?
51005AXF00X?2`0@5A403A8>00hC3`0200`A3@05014F4P0A5A@041@C00lC4P0>4Q400P0?4a804P0>
4Q403a<B00lC4P0?4a803Q8A00dA400?4a@041@E00dA4P0;3a003Q8C01@H6@0X;2d0?D5201TM7P0E
6AX07b<T00lC51Cooooo000Kooooo`0801<C5@0@418030`>00/;3@0=3@l03Ph@00/;3@0<30h200d=
3`0800`<3P0;2`d03PlC00/<4@0C51T01@D:00d>4`0D5AX200`=4P0A00h?500:2a00414F00X;400I
6B80410J00X:500>3QL0410H00d=5@0>3QH030`D00X:4@0K6b807alW01@E6`0?41D00P0=3Q<02P0<
3A804A8G01TJ7`0>3a@020T>00d>4`0?3aL01`L?00l?5`0<31@201HF800?00X:5P0J6BL0D4mO01PG
9@0B4Qh03PhJ010@6@0L72@04Q8L00X95P0:2QD03`lJ00/;5P0S8b`0;Bhd00803a0E01l04Q<F010A
4`0D5AL05QTJ00/?400E6A/05a/L00dA4P0F6Q`07b<T01DI6P0>4Q@03a<E01<G600?4aD03A4D018E
6P0E61d04aHK010C600A51T051LL00lB5`0E61d041<H01XM8P0S9R/04QDI01LK7P0E6A`041@G0080
51PK00@04QHI010D5`0E6A`061`O0P0C5aX05P0D61/05ATL01HJ7@0E6A`04aLJ010D5`0E6A`051PK
01<G6P0D61/05QXM01XN8@0F6al04QLK014F6P0O92P09BX^01DJ7P0>4aL0314E01@I7@0?51P201`Q
9@0801LL7`0G7Ad051XJ01LM7@0L8R804aTI018H600D6QX301DK6`0301@I700J7bD04QHO008051PQ
00<04QHO01HJ8`0E6B800P0B5Ql0B00C5b0051PQ018G7@0F6Al051LL01DH7@0A51T04A@J01lR:@0A
51`05QTR00`?600Q92h0>3Y6010C700J7B@041<H01DH7@0;3Q<05aXO014D6@0C5Q/041<H01HI7P0?
4QL07b8W04]>D`17Bdh0310C01PL7`0?4aH051PK00dA500B5QT051PK00`@4`0C5aX03Q8E018F6P0A
5Q`041@M014F7@0B5ad041DI00lD600C61X061hO00/A4@0N92@06b4P00H<2@0A5Q004QLA00dB300A
5A<04QHG010D5P0D5a/03Q4H01LJ8`0G6B@04A<O010B600@4A<04a<E01LE600A31004`dA01dG6`0K
5QX05A0D014@4P804A8D00T0:bdd06=UL@0D5R8041<M00D84@0E62403a8I00lB600>4AH00`0=41D0
2P0=41@04aLJ00T=400>4QD02PhA01<G600<41403Q8B00hB4@0>4a4200hC3`0300X>3@0?4a803A4@
00803a<B01H03A4@00`@3`0H71/0:Rh]00hB4@0C5aH041@C00dA4P0B5QL041@E00X>3`0=4A8041@E
014E5P0@51D03Q8C00@7200M8B80<CDf00lE4`0@5Q@03aDC0P0<4Q000`0?5A<02a4?00`B400400hD
4P0V00`B3P0C6AD01P`801TO6`0B61@04ALD00/A3`0<4@l03A<A01LM700=4a804a`J01@M6P0<5Q<0
3aPE00T?3@0K81l09b//00/?3`0<5A@06bLV00`F5@0/>cX06bTZ014L7`0V<3@03aPL00PB5@0;51H0
2A4D02/c=P0>5QP041PJ00L<3`0?51L04QPH00hB4@0?510200hC3`0;014F4P0C61@03Q<?010E4@0A
5Q80314=00lD400G71P03Q8A00dA400<40l00P0=4A007`0>4Q403a<B00/?3P0:3Pd03A4@010D4`0;
3`h061dI00P=2@0<4@d03Q<?00H;1`0@5A404ADB034f<P1lPGd06AhJ00hC3`093PT02a0:00hC3008
3@H03Q<<00dB2`0:3`P03A8;00lD3@0A5Pl03a@=00dB2`0;40/00P0;40`02`0=4Ph03a@@010E4@0B
5a<0314=00lD400>4`l03A8>00lD400;40/03A8<00<0314;00@03A8<00`A2`0;40X03A8<0P0?50h0
1`0>4`d03a@>00/@2@0:3`P03Q<<00/@2@0<4@X00P0=4P/01P0;40T041D>00/@2@0;40T01``6014F
4080314;01X04QLA01hS7@0?50h01``600dB300;40X03Q<=00/@2P0:3`T02`l:018G4@0730H0314;
00hC3@0A5Q003A8<00X?2@0=4P`03a@>00dB300A5Q003A8<00lD3P0P9Al05AXD00X?2@803Q<=01P0
3A8<00/@2P0<4@/02a0:018D4P0B51403a8;00hA200C5`T0>3`[09JKR02UZID0?T<^024V4P0A5PD0
4QH600lB2@0B5@h071lH01LJ4`0<3`P041<<00hA2P0?4P/2010C300J00lB2`0>4@X051HA01@E4@0?
4@`030h;00d?2`0E5a803a4<018D3`0=3`X04Q@?00h@2`0D5Q403a4<00d?2P0<3PT03Q0;014C3P0B
50l03Q0;014C3P0@4Pd04aD@00<50@0?4@`200hC3`0S00X?2`0<4@d03A8>00/@300>4`l03A8>00hC
3`0I7QX05AXF00X?2`0=4Ph04ADD00T=300?4a@02PhA00lC5P17Bdd020`;018G4`0=4P`03A8:00dB
2`0>4`h03Q<?00`A3@0;40`0314=00lD400=4Ph02Pl;00T>2P0=4Ph04AHB014F4`0F6QT00P0Q9B@0
2@0D61L03Q8A00dA400@51<02Ph=00hB4@0=4A0020`;00hB4@0200dA40803Q8A00T03a<B00X>3@0F
6QT020`;00X>3@093@`03Q8A00hB400=4Ph00`0<4@d00`0=4Ph03a@@00H;1`0200dB3P0D01DJ5P0<
4@`02Pl900/@2@0:3`P02a0900lD3@0<4@X02a0900X?20093PL0314:00lD3@0E6Q<02Pl800dB2`0;
40T02@h700`A2P093PL400hC300@00lD3@0@5@h051TC00870@0C61803Q<=00T>200=4P`02a0:00dB
300:3`T02@h800`A2`0=4P`01@X400lD3P803Q<=00<0314;00T>2@0<4@/00P0;40X05@0<4@/03Q<=
00hC30093PL03aD;00P>1P0;40T03a@=010E3P0B5a402`l;01HK5`12Ad<0DEEB00hB3P0;40X03Q<=
014F400@5@l03A8<00P=1`0600/@2P0[038g<@2[/:X0:RlY014F400:3`T03Q<=00`A2`0;40X03A8<
00hC3@0<4@/02Pl900/A3@0@5A402@h:01PM6@0C5A8030h;00d?300C4a4051@B010@3P0?3`d0410>
00lA300<3PT02`d800`>2@0>40/03a4<018D3`0<3PT02P`700d?2P0<3PT03A8<00hE3P0>4`d04QLA
00lD3P0B50l051HA010B3@03014B3@0L00h?2P0;3@P07R<M00/>2P0E6Q@03Q4=010E3`0=4P`04QLA
00hC3@0?50h0314;01<H4P0C61<02Ph;01PM6@0@5A403Q<?01TN6P0Y;RX092TU00/@300@5A401``8
014F4P0<4@d04AHB00hC3`80314=0P0=4Ph05P0>4`l03A8>00dB3P0?51004AHD00/?6@0D62D03a<O
018F8@0A5Ah03Q4G014D600:3Q003@h?018D4`0?4@h03Pl=01DI5@0X;BT0?D8n014F4P0=4Ph300hC
3`804AHB00H02@h:00hC3`0B5QD04ADD00lC4P0=4A0200lC4P0400dA400>4Q403a<B00lC4P<041@C
00/03Q8A010D4`0C5aH051PG00lC4P0:3Pd04aLF00lC4P0@51<02Ph=014E500Dooooo`006oooool0
100D51H01`L901PH6P0;2`d200T92`0I00h>400@418010@600/;3@0?3a4051@F010A5@0720`0QhR<
03Pi?@082@d03PlC01<D600;310020T=00X;3`061`/05QLL00h>5P061Ph04A4I010@600>3QH02@TA
00l?5`0200d=5`0d00h>600<31H02PXB01<C6`0>3QH04A4I00d=5@1:BU80W9bT00h>5P0K724051DJ
00`=4P0I6Ql010D:00`=4P092A4020PB00/;5`0d<d40ZjZh02TX=P0D520071`X00h>5`0J6R803`lI
01<B800B4Al03PhK018B7P0C4ad04Q8J01<D6@0D5AX05AHJ018C5`0?41@03Q4C00H:2`0F6Q/09b//
01<G600?4a@051PI010D5@0E6AX0310A01<G600@51D0310B014E60804aLJ0P0E6A`01`0B5QT041@G
00hB5@0D61/05a/N01<G6P0?4aH00P0E6A`05`0=4A@0310C01@H6`0>4QD03A4D01<G6P0F6Qd04QHI
014E600D5a`07B0U00lB5`0J7B803a8G01@G700?4QL041<H01DH7@0I724061/P01@G700H7B406AhR
00806QlS00D061dQ01HK7`0E6Qh04QLK01LL800202DZ;P0W01LL800M8RD03Q<F01@I700;41<04QLJ
01@I700A5QT02a0C01XO8P0H7B005a`O01PM8@0>4aT061`U00hB6`0@51d03a<L01HJ8`0J7RL04aLP
010D7@0C5b0051PQ00lD6P0@4aX04aHK018E6P0?4QL041<I01@G7P0@4a`051LP014D7@0B52005QPT
01<F7`0=41D04ADH00803A4D00<051PK010D5`0A5AP01@0A5AP01@0B5AX051LL01<F6`0A51T04QDJ
00804aHK0P0@4aP07`0A51T051LL01HI7P0G6R806QdV01LJ8`0B5A`04aHK01DH7@0?4aD04ADF00/?
3P0>4Q004AHB00`A2`0A5Q003A8>018G4`0C5aH041@E014E600`<cP03a8I010C7@0:31P00@<@01@F
7@0C51H051@F01HC5P0G4QH00P0I4aL03`0G4AD05Q4E01<A500?3a404a@F01/M8`0I6bL04Q@P00P:
5@0?4Q/04aHO00d@600L7bH000<801@G700200P;400H01@G700@4aP03Q4F00dA5@0>4QD041@G010D
5P0=4A802`l@00/?3P0<40l041@C00T=300830/04ADD00X>3@0J7Qd01`/:00`@3`0@51<02`l>00lC
4P052@P06alN0P0:4100300;4A403A<C00hD500A5aL010X:01/Q8@0220P07bDU01<I6@0>51@020h<
00X@3P<03A<A05D03aDC00`B400=4a403Q@B010F500A5aD04QPF010F4P0:40`05adI01dS7`0C6AD0
3Q@@018H500?5A40318>00/A3@0:4@/0214<00/D3`0<5Q803QLD00dC4@0I7Qd0=CTj00D:3@0?5aT0
3APJ00@?4@0:6AT06RT/02Hd=`1`O8804A`R018M8`0<5Q/01a0E01XR9@0>5AL000L901LL7`0@5AL0
20h>00P<2`0C61@01``800hC3`0E6QH00@H200lD400@5A40314=00dB3P0?51003Q<?00dA400830/0
2@d<00lC4P0@51<03a<B00X=300A5A@06AdL00dA400830/03A4@00X?2`0=4Ph041DA00P=2@0B5a<0
5AXF00lD400<4@d02a0<00`A3@0>4`l03a@@00`A2`1;D4X00PL101`Q6`000P003A8<00<02a0:00`0
314;00hC3@0<4@`03A8>00lD400=4Ph02a0<014F4P0I7QX03Q<?00L<200=4Ph200`A3@0700`A300S
:2801``600P=1`0B5a403a@>010E3`03014F400500hC3@0=4P`0314;00`A2P0;40T00P093PL0200;
40T0314:00/@2@0@5@h03A8;00hC30042@80314;0P0;40X01P0>4`d04AH@01<H4P0@5@l03A8<00/@
2P80314;0P0;40X01@093PP03A8<014F400>4`d02a0:0080314;02@02Pl9014F400:3`T041D?00H;
1@083@L041D?00L<1P0>4`d02@h800/@2P0=4P`03a@>00/@2P0=4P`04aPB00P:2@0A4a004QD>01LJ
4@0^<R<0PhMf0?7fhP3ZkMX0B4dg02hc7`0A5PD051P700H9000m@3T0RHb501lR6`0=40T05APA00X=
1P0<3`P200lB2`0300d@2@0;3PL030h900804aD@0P0>40/00`0C5A00418=00lA300400d?2P0]00`>
2@0=3`X0418=00d?2P0>40/051HA00/=200A4`h06Q`G01LI500@4Pd04aD@010E4@0A5Q80314=0046
0P0E6QH04AHB00`A3@0:3`/02a0<010E4@0?5100314=00D;2@0>51@02Q0@00hC5P0@5AT01``?01<H
6P0?5A<0318>014G4P0010004AP@00X?2P0=4Ph03a@@00dB3P0<4@d02@h:00dB3P093PX02Pl;0080
4AHB02L03a<A00lC4P0@51<02@d<00`@3`0>4Q403A4@00/?3P0A5A@05a/J00T=300830/02`l>00dA
400D61L020`;00dA400D61L03a<B00P<2`0I7A`01PT801PL6`000@003Q8@01HK5`0C61@04AHB0002
000H7AT02Pl;00/@300<4@d051TE01TN6P0@5A4051TC00dB30093PP00P0=4P`0800>4`d020d7010E
3`0?50h0314;00T>200C61803Q<=00/@2P0:3`T0314;00X?2@0C61803A8<00T>200;40X0314;00T>
200>4`d0IFYT030e;`042@<020d700lD3P0:3`T020d700lD3P0730H03Q<=00dB30093PP03Q<=0P0;
40X04@0>4`d03a@>00`A2`083@L02@h800`A2`0>4`d04AH@018G40062`@02`l901HL4P0=4P/03a@=
00/@2@0=4P`03a@?00803a@@00`03A8>00D:1P0=4P`02@h800X?2@0?50h03Q<=00H;1@0@5@l03a@>
00hC3@0=4P`200hC3@0Y01DJ500N8ad0724K00X?2@0@5@l01``600hC3@0M8Q`000<0010E3`042@<0
4aPB00L;200Q9R8010T500lD400B514061XG01LI5P0@40h03`l=01dM6`0;2`T03`l=00/=200>40/0
2P`700`>2@092`H03a4<01/M600C5A004Q@?00T;1P0;3@P04AH@00T@2@0<4@/020d701@I4`0@4Pd0
0P0B50l03P0?40/03Pl:010A300>3`X04A<>00lD3P0320803a@>00@90`0V:bD04AH@02db;00W;2H0
2a0:0P0?50h04P093PT04AHB00hC3`0;40`05Q/G01dR7P0I7QX03Q<?00X?2`0=4Ph02Pl;00T>2P0=
4Ph04QLC01DJ5P0?5100314=00hC3`803A8>0`0@5A404P0@5A<02`lJ00lE8`0A5b<03A4L00T=5P0D
61l020/@00T=400;3`l03Q0?010B3`0A4a0041DA01XO6`0K81`03A8>00X?2`803a@@00T04QLC01LL
600=4Ph02Pl;010E4@0;3`h0310?00dA400>4Q400P0@51<01`0B5QD0310?00`@3`0B5QD05ATH010D
4`0<40l00P0?4a801@0E6AP082@S01lS8P0?4a803Q8A00803A4@00<03Q8A00lC4_ooool04oooool0
01_ooooo00P04Q8D00@41P0410H00P8401<C5@061PP020P:018B50803Ph@01802PX<00`<3P010PH0
5AHJ07enPP13A4P051DI00011@0:2`l020T=01<D600I6Qh01`P<00X;3`0=3Q<01PH>00d>4`0e=Cd2
00l?5`0g00d=5@0<31H02`/E00h>600C4ad05QHP00/;500A4A/02PXB00h>5P0J6R805QHN00d=5@0E
5Q/02``A00<42@0B4aP0414F00d>4`061``03@dE00l?6P0L72P0IfMc01`L:@0@41`06QXT00h>5@0G
61d03PlG01<C7`0B4Al03PhJ018B700C4ad03`lH00h>5P0A4QL04a@I01<D600A4QH04A<G00L;300>
4QD051PJ00/?400?4aH03a<E00/?400>4QD03Q8D01DI6P0D61/041@G00lC5P02014E60805ATL0P0D
61/01@0B5QT051PK01@H6`0A5AP041@G008051PK0P0>4QD03@0C5aX05ATL018F6@0D61/05ATL018F
6@0C5aX00005024T:@0?4QL05APM01dP9@0=3a@00P0B5AX01P0E61d061/P01PK800E61d04aPL01@I
7@805a`P02405Q/O01@I7@0?51P03a@H01DJ7P0L8BD06b0T01<H700<4A@020d@01@I700P9BP0724T
00L<3`0H7B005a`O01HK7P0>4aH05AXM014F6P0G72806alX00lC700B5Ql041@M018F7`0R9Rl06AdV
01<G800D62404ADN00/@5P0?4QL00P0B5AX01@0@4aP04QDK01HI800@4aX04aHO008041<L00@051HR
014D7@0@4aP04aLJ0P0>4QD01P0D61/04QHI00lC5P0?4aH041@G014E60804QHI00<04A@I01<F6`0B
5AX00P0A51T0100C5Q/041<H010C600A51T2018E6P0;014D6@0C5Qh04aHO018E700?4QP03a8G010D
5`0=4A804QHE014E500A5Q800P0C6180900@5A002a0<014E500C5aL03A4D00`@4`0<3aD041<L01@G
8@0F62@03a4N01XL8P0D5AL051@F01@C5P0J5AT07APL02XT:00R7B404`hB01<B5@0F5aT04Q<E00X<
4P0:31P04Q@P01/N9`0I72D04A@M00lB6@0;3Q<07B0U04Y=DP0K7R<05aXO00`?50803a8G01D03a<G
00lC5P0?4aH05a/M01`P8@0H71d041@D00/?3P0:3Pd061`K00L;2P0>4Q403a<B01@H5`0B5QD01PX9
00/?3P0>4Q404aLF00L;2P0B5QD00P0>51@300dC4`0900lE5@032@T03aDE01@J6P000P800`T900dB
4P0:40h02a4?0080318@00@03A<A00hD4P0=4a403A<A100>5180500G7A/0318?00@:1P0;4@d04QPD
00X@300>51003A<?00`B3P0>5@h051/D01LQ6@0:4`h02A<?00`E4P0<4Q005Q/K02``<@0D6A`02A4D
0P084aD060075AP0;C`o071mP`1BGfD03Q/Q02Td>P0@6R00628T08N?TP1BFU`04QXL01<H6`0>51@0
4QPF01<H500=4Ph02Pl;00H;1`052PH03A8>00hC3`0B5a<03Q<?00/@30803A8>00<03a<B00`@3`0<
40l00P0?4a802@0>4Q404ADD00lC4P0=4A003a<B00/?3P0<40l0314=00D:1P0200`A3@0300dB3P06
2`L03Q<?00<0314=0P0>4`l0400<4@/020d70002000B5a408BHP014F400=4P`0314;00dB300>4`d0
3a@>00`A300<4@d03a@@00`A3@0:3`/200hC3`0<00T>2P0730P02@h:00lD400;40`020d80005000A
5Q003A8<018G4@0D6A<03Q<=0P0:3`T05`0;40X02Pl900T>20093PP0314:00dB2`0<4@X02Pl800/@
2@0?50d04aPA010E3P0010003A8;01<H4@0?50h03A8<00/@2P0:3`T02a0:00`A2`0@5@l03Q<=0080
314;00D03A8<00`A2`0:3`T0314;00dB300300X?2@0>00L<1P0>4`d020d700X?2@0=4P`010T300lD
3P0N8ad0;S<]01LL5P042@<04aPB00P=1`0:3`T200lD3P0E00dB300<4@/030h;018D400@4``05QT@
01lS501CEdH0/[JU0;BiY@0h?BT03A8001DI200>4P<02`h501/N5`1FFE8061/D010C30072P<03a8;
008041<<00H03a8;00hA2P0<3`P03Q0;00d?2P0>40/2010B3@0300d?2P0@4Pd03a4<00<03@l:01H0
3Q0;00lA300?4@`0418=00`>2@0=3`X04Q@?00h@2`0@4Pd05QPC018D3`0=3`X0418=01DJ5P021`<0
82DQ01<H500=4Ph00`P400`A3@093PX02Pl;0P0=4Ph03P0;40`05adK00@:2P0@5QH03Q<F00T>4P0E
6Qh04AHI03To?`0d>SP04QTC01dT700;4P/0314=0P0>4`l03@0<4@d02Pl;01@I5@0:3`/03Q<?018G
4`0E6QH092TU01<H5@0>4Q403a<B00T=300<40l00P0=4A006@0:3Pd03A4@01@H5`0:3Pd020`;00`@
3`000`802`l>01<G5P0;3`h0310?00D81`0F6QT00040014E500010<06QhM00lD4@0<4@d051TE00T>
2P0E6QH02Pl;00P=2@0;40`00P0:3`/0400>4`l0314=00X?2@062`D02@h800hC3@0;40X02@h800L<
1P0:3`T010T3014F40001@004QLA00lD3P0<4@/200/@2P0M00L<1P0>4`d06b0J00/@2P0:3`T041D?
00@90`0;40X06AhH00T>200@5@l04QLA00hC3@0<4@/02Pl9010E3`083@L03a@>00hC3@0;40X03A8<
00`A2`0=4P`041D?018G4@0?50h03Q<=00dB300;40X00P0:3`T04`0:3`P010T201HL4P0010003A8;
00/@2@0@5@h0724K01<H4`1CF5@0DUMC00dB3P0?51003a@>00X?2@083@L02a0:00dB300:3`T0100;
40X200X?2@0700@9100=4P`0314;00X?2@0D6A<02a0:00L<1P02010E3`0:00hC3@062`D010T300P>
2P093PX03A8>01HK5`0Z;2T04Q@A01@F4`804A4?01P05aLE00l?3@0?3`d04A<>01<E400?4@`04Q@?
01HH4`0>40/0418=00H80`0D5Q406adH01<E400=4P`01@`501<H4P0=4P`04aPB00h@2`0C5A006Q`G
01<D3`0A4Pd201DF4@0>01@F4@0=4P`01@X401PM5`0T:B<0FEiH02ld;P0O91h0724K00/@2P0?50h0
4AH@00P=200;40`200dB3P804QLC00<03Q<?00lD400@5A400P0@5A401`0A5Q803a@@010E4@0C61@0
3A8>00/@300>4`l00P0<4@d0500>4`l03a@@00lD400>4a405A`T0088500=51l000<>00D94P073140
51PK01<G600B5QH04A<B010B3`0?4@h03Q<?01@I5@0C61@0314=0P0=4Ph01P0<4@d041DA01DJ5P0G
71P03A8>00hC3`80310?00X03Q8A00lC4P0@51<041@C00hB4@0@51<03Q8A00`@3`093@`020`;0P0A
5A@01P0:3Pd02`l>01XN7@0R9RD03A4@00`@3`802`l>00<0310?00dA4?ooool04oooool001_ooooo
020020L<014@5@0920d01`H;01TH7@0<2a0061LL00`;400:2@h030/@00h=4P0@3a@030d?00l@4P0C
51H01@H800X;3@0;30h03PlA00X;3@0D5AL08b@V00h?4@0<3A002``?018C5P0L7B00?3e100X;3`0;
31403a0E00l?5`8030`D01d05QHP01dM9`0D51l03`lK010@6`0=3AL071`V00/;5@0>3QH02@X?00`=
4P0F5a`02@X?00h?500<3A0051DI01@D6`0=3AD0<30i05eMIP0<31H03@dF01LG7P0=3A<04Q<F00h?
500B4Q/04Q8L00h>5`02018B6`0C010@600?3aL04A8G018C600A4QL0414F018D6@0C5a/05aXO018E
6P0B5QX05aXO00lC5`0G6Qh041<H01@H700?4aL03a8G01<G6`0201<G6005010D5@0B5QL04ADF00hB
4`0@51D0100A5AH0100D61X051PK014E600A5AP2018F6@0?01HJ7@0C5aX04QHI01<G6P0?4aH04QHI
01DH7@0G6Ql041<H01dP9@0<3a@05aXO01HI7P0D5a`04aHK00<05APM00P04aPL01@I7@0F6al05Q/O
01DJ7P0C61`041DI014F6P8051TM0P0B5a/03`0B5a`06QlT01DJ7`0F6b00314F028W;00B5a`051TN
01<H7@0@5AX0724V01<H7@0D6Al05a`R00`A5`02018G7@0:01<H7P0E6R004QLM018G7@0D6Al05Q/Q
01<H7@0C5a/051PJ018F6@8041@G0P0A51T02@0C5Q`03a8I00lB6@0B5Ad03Q4H01@H6`0C5aP03Q8C
00lC500201@H6@07014E5P0B5QL04QHG01@H6@0E6AX05ATL010C6002014D6@0500lB5`0@4aP04A@I
00lB5`0A51T00P0B5AX0:@0@4aP03a8G01<D6P0@41P0414G018C6@0@4AH03PlC00l@4P0>40l04aDD
018D4@0@4Pl04aDC00lC4P0>4Q804QHH014E5`0?4QH04QDJ00hA600G6R<03A0I00`?60082QD04aLL
010D5@0?4A<04A4C01DD5`0J5aX091lS01lK7`0D4aD0414C010C500E61T0:bhc02HY<@0E62004A@K
00802@`B00`04QDJ00/>4P0E6Ad09BT/00hB500B5QT030lD00hA600@4aP04A@I010C600>4QD2010D
5`0<00lC500=4A80310A00`@3`0:3Pd0310?010D4`0?4a8061`K00hB4@0?4a80310?0P0@51<01P0;
3`h041@C01<H6P0B5aX041DH00hC5P803A8E00P02PlB01LL7`093Q4051TL00P=400<4A<03Q@C00dC
4@80318@00@03A<A00hD4P0>51803Q@B100=4a40<`0:40l04QPH00`B4@0>4Q4041HD00X@3P0=4a00
2a4=00X@300=50d05A`E01TS6`0@6A@02aD?00XC3P0=4a403a@D01@H6P093Q403ADI018M8@0@6b00
8S0e08fLX@3ao_l0/L3402@c>00H9B/07RX^00TE5P0C7Ah03ADE00H>300C6AP03A8@00D:1`0E6QH0
4AHB00hC3`0W;2P05a`H014F4P0=4Ph04QLC00lD400@5A403a@@00/@300>4Q<041@E00lC500200dA
4P803a<D00P0310A00<61`0C5aP041@E00lC4P0C61@06AhJ01dR7P803a@@00<03A8>00hC3`0=4Ph0
0`0=4Ph02@0>4`l0314=01HK5`0D6AD02a0<00P=2@0=4Ph03Q<?00dB3P0200hC3`0F00lD400=4Ph0
3A8>010E4@0>4`l02Pl;00/@300<4@d03a@@00dB3P0;40`051TE01<H500A5Q400`L301`Q6`0>4`d0
2@h800lD3P0<4@/03A8<00hC3@<03a@>00@0314;00dB2`0?50d03a@=0P0<4@X01P0?50d00@H001/P
6@0730D02a0:00lD3@803A8<0P0<4@/01P0=4P`041D?00lD3P0=4P`02a0:00`A2`803A8<00@01``6
00lD3P0=4P`02@h80P0?50h0300A5Q002@h800X?2@0>4`d03A8<00`A2`0730H07B8L02H[9@0:3`T0
3a@>00dB30803a@>01P03A8<00/@2P0A5Q0061dG00d?300A4`l03a8;01@G3P0C5`T05a/;01lS4`0d
>2P08RHF00dA1`0>4PH03A4401@G3`0;3PL071lH018E3P0@4``030l800lB2`0>4@X200d@2@0:010C
300A50d04aD@00`>2@0=3`X05ALB01HH4`0<3PT0418=00lA30803@l:00L03Q0;00lA300B50l0418=
014C3P0>40/03@l:00804Q@?100=3`X02P0?4@`0@DI204=8A00420@04AHB00460P0E6QH03Q<?00X?
2`093PX300/@300:01XP7P0A5aL04QPI07f2QP1[L7@04AHJ00hC5P0=4Q@04QPF00hD40803QD>02l0
3Q8@00lC4P0>4Q402`l>00X>3@0830/020X9014E500K7ah04QHE00dA40093@`0310?00dA400:3Pd0
2`l>00`@3`0?4a802`l>00T=300?4a80310?00X>3@0<41004aLH00/?400>4A804ADF00X>3`0>4Q<0
41@E01dQ8P0=4A803a<D00/?400A51800PL300dB3P0?5100DUMC01<H500=4Ph04AHB00lD40093PX0
314=00dB3P0200`A3@0R01@I5@0H7AT04QLC00dB3P0>4`l03a@@00dB3P0=40d03a@@00`A3@0:3`/0
2a0<00`A3@0>4`l03A8>01<H50082`P0724M00`A3@0;40`0;C8^030d<@0=4P`01@X500dB30093PP0
1P/500lD3P083@L03A8<00P=1`0?50h0314;00/@2P803A8<00L03Q<=010E3`0B5a404QLA01<H4P0@
5@l03A8<0080314;0P0=4P/03@0A5Ph05Q`B010E3P0;40X02`h:01<H4P0?50l04AHB018G4`0?5100
314=00hC3@0<4@/00P093PP0100<4@/03a@>00/@2P0>4`d2010E3`0W00hC3@0=4P`03a@>010E3`07
30H03Q<=00X?2@0520@03Q8=00T>200G71H01``700`A2`0A5Q002Q0<00lD40093PX02a0<01@F4`0A
4a003Q0=018B400D51803@d;01DE4`0?3`d030h900h@2`1>D4/0;c4/00/=200@4Pd03@l;01DG4P08
2PD04A<>00h@2`0_=2h06R4J00803Q<=00h01``600H80`0?4@`03Q0;00d>2@0A4Pd0414<00X;1P0=
3`X03Q<=00/@2P0?50h010T301lT7P<041D?00@03Q<=00`A2`0<4@/03Q<>0P0@5A402P0>4`l03a@@
00lD40093PX04aPD01PM6@0?510041DA00lD400;40`200lD40802a0<00<041DA00`A3@0=4Ph00`0>
4`l0300=4Q0020`A00XC6@0=4aP05QhS00hE6P0<4A<05A/L01@J6P0C5aL041@C00hB4@803A8>00@0
41DA00lD400?51004AHB0P0>4`l01`0?510020d9020U8@0=4Ph04AHB00dA400>4Q400P0?4a82010D
4`0800hB4@0C5aH041@C00dA400H71/0:Rh]00`A3@0?510200/@3004018G4`0F6aL03a@@00hC3`80
3A8>00<03Q<?00lD4?ooool04oooool001_ooooo03`05aHK00L62`0510T03`hC00/:3`0510T010<8
00`;400K6Ql02PT>00/:3`0N7B8020T;010A4`0720X051DG00/<3P0720X03@h@00P92`051PP03PlA
00T:300>3a405ALF00T;2P0C5A@01`L901LH6P0@4AD02``@010A5P0>3a@02``A014A6@0F5R001`LD
00/:60071a<0=SI2061PJP0Z:S@03PhF00h?500J6b008b@Y00P93@0?41@051HE00X<2`0<3@l0414E
01TJ7`0@4AH03@dD00l@5@0B4aL030h>00lA400?4A82014B5`0400l@5@0A4QL04A8G014B5`804a@I
01L04a<J014A6@0@41P03a0H01<F7@0K7RD04aHM01DH7`0G6R402`hE01PK8P0;3QD041<J00L:4@0@
4aX02PdA00dA4P0?4a@04ADF01TM7P0L82405ATJ010D5@03018F5`0A01@H6@0F6Q`04aLJ00lC5P0B
5QT051PK014E600?4aH03A4D018F6@0E6A`04ADH010D5`0H6b0061/R02T/<`0T9bh00P0C5Qd01P0F
6B004aHM010C6P0A51/04QDL01<F7@<05Q/O010051TM018G6`0?51P05a`P01@I7@0A5QX051TM01HK
7`0B5a`08bL`01PL9@0@51d06alX00lC701@E5d0=SY30`0E6B802P0B5Ql041@M00hC6@0H7B404AHJ
01DJ7P0F6al0724U01HK7`0D6Ad2018G6`04010E6@0=4QH04ADF010D50803Q8C00@03a<D00lC5P0B
5QT051PK0P0@4aP01`0B5AX03Q4F01<G6P0@51D03a<D00hB4`0@51D01@0C5aP01@0B5QL04QHI00hA
5`0@4aX03a8I00803Q4H010041<J01<F7@0A51/041<J014D6`0B5A`04aHK01@E6@0@4AH04A8F01DF
6P0B4aL03a0B01DF600;3@`03Q0?0P0C5A@03@0D5QD03a<F01HJ7@0E61d030lD01LJ7`0V:Bh092L^
00X=500@4aX061/R01TL8`0N8RL00P0<4Q807`0?4A<0410B00l?4@0<2`d03`lA01HF600@4a@020h>
01DK6`2<T9@0TIBI02/^<`082a0041@G014E600@51L06QhO014E5P093@h04QHE00L;300?4aH03A0G
014D6`0C5Q`04A@I00d@5@0>4QH041@G00lC5P0>4Q@00P0=4A80;00<40l051PG00P<2`0420L03Q8A
00dA400A5A@01`/:010D4`0830/02@d<00X>3@0@5AP03QHH00dE5`0<51H03ADG00hF600G7b400@T;
00dE5`0@61X0210B01DM7P0@5QH03Q@B00`B400>51803aDC00dC4@0<4Q003A<A00hD4P0?5A<041HD
014G5P0C61/010T<00lD5`0G71l04QPH01@J600=4a403A<@0P0<4Ph0>00;4P`02A<;014J5@0;5A00
2Q<>00lE4`0@5A@02@d@00hC5`063Q801Q4G01<M9P0R<3L0D5mV0;C6bP1]Oh<062X^018Q900=71h0
00`<010J6`0740h010d800/A3@0F71H06AhJ00X?2`0A5Q802Pl;02T^:P0G71P020d900hC3`0;40`0
3A8>01XO6`0F6aL02a0<00/?400>4Q<03A4B00/?400=4A8041@E00/?400D61T05ATJ018F5`093@h0
3Q8A00`A3P0L8Ad07R<O00T>2P0<4@d041DA1P0=4Ph01@0;40`000D1010E4@021P<09BXV00803A8>
100<4@d04`0=4Ph03a@@010E4@0@5A40314=00/@300?51002@h:00X?2`0E6QH02a0<00P=2@093PT0
<CH`00@90`021`400@H000/@2P0=4P`00`0>4`d00`0;40X02Pl900/@2P0200hC300C00`A2P0;40T0
3A8;00T>1`0H7AH0I6UR02/`:@0H7AH01P/500L<1P093PP0314;00dB300?50h05Q/E00`A2`0:3`T0
20d700X?2@0200/@2P0500T>200=4P`02a0:00hC3@0D6A<00P0=4P`08P062`D041D?00/@2P0>4`d0
3a@>00/@2P0:3`T0314;00<80P0I7QP020d700X?2@0@5@l04aPB010E3`0P9Al0>3dg00`>2`0>40`0
3A0900`?1P0D60/03Q8401/O4@0@50P020/000@7000B5@d010L000X=1P0B5@h02@`5018E3P0930D2
01<F3`08014D3@0=40T03A09010C300B5@h04A<>00lA300@4Pd201<E4003010B3@0?4@`03Q0;0080
3@l:0P0?4@`00`0@4Pd03@l:010B3@02010B3@0401<E400M7aX04A<>00/=20802P`701`02@/600L;
200B5a<04AHB00X?2`0L8Ad03A8>00lD400=4Ph0314=00/@300<4@d03A8>00TA3`0:4Q@00`/=0459
C00_=S`02Q4G010H6`0;4aD051dJ00T?300230@02Q4:00`@3P0<40l03A4@0P0<40l0200=4A006QhM
01<G5P072`X03a<B010D4`0>4Q402Ph=0P0;3`h06@0:3Pd0310?014E500<40l02@d<00hB4@0?4a80
3Q8A00X>3P0=4A802@d>018F5`0;3a000@D601LK700B5QL00042014E5P000@803a<D010D4`0;40`0
51TE00T>2P0>4`l00P0:3`/200/@300500lD400B5a<02Pl;00hC3`0=4Ph00P0@5A402`0:3`/02@h:
00L<20052PH041DA00D:1P1JGe/05AXF00`A3@0?51002a0<00801``801802Pl;01TN6P0E6QH02Pl;
00<810000P003a8?010E3`0730H03Q<=010E3`0A5Q00314;00T>200;40X02@h8014F400<4@/200dB
30803Q<=0`0=4P`200lD3P803Q<=01404AH@018G400?50d06QlH01@J40083@H061dF01<H4@0@5@l0
2Pl:01HK5`0G71P0314=00lD400:3`T03A8<00hC3@0200`A2`0600dB30083@L02a0:00hC3@0=4P`0
2Pl90P093PP0=@0=4P`00PL1014F400320804AH@00dB30011P0000<001dR700;40X05a`F00/A3@0C
61@0314=01@I5@082PL04A<@00/=2P0B4Q005ADC00P81P0E5A<03`l=01@F4@0=3`X06adH01@F4@0Q
8ah01`T4014C3P0F61<020X501@F4@031@0082DO00T@2@0D6A<02a0:01HK5@0E5a80418=01DG4P0:
2`H03@h9014B3@0B4`h061XE00lD3P083@L03Q<=00lD3P0M8Q`05Q/E0080314;00D04AH@00X?2@08
3@L03A8=00dB3P0300`A3@0@00dB3P0<4@d06QlK020U8@0D6AD05AXF01<H500=4Ph03a@@00hC3`0<
4@d03A8>014F4P0>4`l03a@@010E4@803a@@00L03Q<@01`U900B71d05b4R00H>40084A0051dK00<0
3Q@B0`0>4Q403@0<4@d04QLC01<H500<4@d03A8>00hC3`0730P03A8>01LL600m@Sh0724M00dB3P0>
4Q400`0?4a82010D4`0<01@H5`0A5A@0310?00X>3@0B5QD06alN00T>2P0;40`0314=010E4@0C61@0
2a0<0P0@5A4200lD408041DA5?ooool001_ooooo03H040lD01@C600I61d04a8G00L62`0a<3D0=3<h
00T83@0@3a@030/@01PG700O7R<051DG00X;3@00008010D700H72@0C51H02P/=00l@4P0;30h03@h@
00L82P0>40l01PL500H81@0L7Qd03@l>01LH6P0000801`P<00d>4`0>3a@03@hC010@600B4Q`03PhK
00l>70081aD03PhJ01TI8`0000T03PhF01XK800L7B804A8G00/<400K71h03Q0>01DG5P0C5A@01`P;
00`=4P092Pl2010A5@0400l@4P0>40h03Q0=00lA40804A8D00@03a0B014B5P0A4QH03a0E0P0A4QL0
400C4aX04a<K01@D700C5A`04QDL01HI800>4AP04A@K01LJ8@0C5Qd07b8Y010C6P0B5A`03Q4H02<V
;@0<41@201@H6@07018F5`0F6Q/05a/L01PL7@0I7Ah05a/L01HJ6`0201@H6@0I01HJ700C5aX03a<F
018F6@0C5aX04ADH00lC5P0>4QD05ATL01PL7`0D61/04aLJ00L:4@082a80FUeT06IYL00]<3L01PP?
01DH7`0B5A`041<J018E700C5Qd051LN01<H700201@I7@0L018G6`0@5AT03A8F01LL800C61`041DI
01@I7@0F6al04QLL00P<5@093AP051PS00X>6@0[;cX0]KW404I:E@0E6B@04aLR018F8@0@51l06AdV
00`A5@0E6Qh03a@G01DJ7P0D6Ad051TL01@I7@805AXM00L051TM01<H6`0A5QT03A4@00`@3`0=4A00
41@C00804aLH00`04ADH01@H6`0@51L041<H01<F6`0?4aH04QHG00lC500A5AH041@E00hB4`0A5AH5
010D5@13010D5`0?4QP041<J010C6P0>4AP03a8I010C6P0E61l04QDL010C6P0A51/04aHM01@G700A
4QD03a0D010A5@0A4QH0414C00l@4P0@4A<03Q0?00X<2`0>40l051HE018C5@0@4aP061/R01HI7P0;
3Q@061/P02T/<@0c=Sd041<J01DH7`0?4QT01@P?018H6`0<5A@03aDE010E5P0@4A<03`lA010@4P0?
41804A8D018G5`0=5QD041TH03@k?00Z;C802PdB010D5`0A5AP02@d@018F5`052@X02@d>010D4`0?
4a800`L600/?4P0>4AP041<J018E6`0@4aP03Q4F00hB5P02010D5`0L00lC5@0>4Q<03Q8C00hB4@09
3@`05ATH028V9@0830/01@T8010D4`0830/07b<R018F5@0A5A@02Pl?00hC5P0<51H02a<E00`D5P0=
5AL03aLI014I6`0X<3804a/M00`D5P022P`01Ph@00hD5080318@00<041HD014G5@0=4a400P0<4Q00
300>518041HD014G5@0B61L0OX>602T^<P052Ph02PlC00D:3@0;4A40318B00hD4P803aDA03P03A@>
00TC2`0:4`h02A<>00XC3P0B61H05Q/L00hB5@0=4QH041LN01DP9P0@6R<03adU00`M900W>Cd08C<g
01<U9`0=71l000d=01<Q8@0=5aH03QPC01@N5P0B6A803aD>00H;1@0C61@04QLC00lD400=4Ph00`P4
014F4P0?51002@h:00`A3@0J7a/061dI00dA400>4Q<03A4B00`@4@0;3a003Q8C010D5@0<41402@d>
01DI6P0=4A802@d>01DI6P0>4Q00314=01<H500?51003Q<?00P=2@803A8>0P0>4`l0100=4Ph0314=
00lD400B5a<200lD400401TN6P0<4@d03A8>00`A3@<02a0<01<03Q<?00lD400?51003a@@00hC3`0=
4Ph04AHB00dB3P0E6QH0:2dY018G4`0:3`/07B8M06mdKP0P9Al061dG00dB300B5a403a@>00803Q<=
00H03A8<00X?2@083@L02a0900hC300=4P/200X?200A00dB2`0;40T03Q<<01XO60000P004AH?00`A
2P083@L02a0:00`A2`093PP02Pl9014F400;40X02Pl900T>200:3`T00P0<4@/00`0=4P`0314;00/@
2P0200dB300S00X?2@001@001P/501<H4P0<4@/08RLQ01TN600E6Q@020d7010E3`0?50h02@h800/@
2P0730H03a@>01HK5@0>4`d041D?01`Q6`0?4@h03A0:00d@2@0520004A@:014E1`0G6`d04aH;01@G
3P0>4@X0CU1;01/M600930D04A@=00@7000K7QL00P0@4``01`0K7QL05aXC014D3@0?4P/03Q4:00lB
2`0<3PT00P0?4@`00`0>40/03@l:00h@2`0200h@2`803@l:01403a4<010B3@0?4@`02`d800lA300A
4`h0418=01<E400A4`h02`d800T;1P0B50l05aTD01DG4P0G71P010T501PM6@0200hC3`0C00P=2@0>
4`l03a@@00hC3`0=4Ph0314=00dC3`0<51<04QXL00`D5P0@61/010/A014H7P0;4A@01@d?01/T8@0@
6AD0D5YB00`F3P0200/?3P0600`@3`0=4A003A4@00/?3P0420L051PG0P0@51<02`0E6AP01PP700X>
3@0;3`h03A4@00X>3@0<40l041@C00dA400;3`h03A4@00803a<B01805ATI00041@0B5QL0?D5201`P
8@0<41401`T:01TM7P0P92D04ADF02HZ:`0F6Q/07b<S01@I5@062`L04aPD014F4P0>4`l300/@3004
01<H500G71P0314=00lD4080314=00l02Pl;00H;1`0:3`/082DQ00T>2P0;40`05Q/G07^0O00D6AD0
2Pl;00hC3`0;40`0314=014F4P0H7AT00`0=4Ph01P0<4@d020d901PM6@083@L01P/5010E3`8020d7
00d03Q<=00`A2`0<4@/0314;01DJ500>4`d04AH@00hC3@0?50h03Q<=00`A2`0;40X0314;00<03A8<
0P0<4@/02@0<4@X0J6eV07QnM00?5@/0314:00T>20001@008RLQ00/@2`0200`A3@0400L;1`0G71P0
2a0:00dB30803Q<=00<03A8<00/@2P0<4@/00`0>4`d0400;40X02Pl9018G4@0E6Q@01P/500X?2@00
0P0092TS00dB300D6A<082DO05MLEP0?50h0008004aBCP0320@200P=2@0301@F4`041P<03Q0=0080
4a<A00T030`:014A3`0@40h04A<>00D70P0L7QT03a4<00h@2`0<3PT00P0@4Pd01P0:30L01@H301<E
4024RH<09B`U00D:108041D?0P0@4Pd07P0=3`X030d801XK5P0D5A002P/6018D3`0?50h02Pl900dB
30093PP01P/500/@2P0<4@/02a0:010E3`0>4`d0314;00`A300;40`041DA01HK5`0A5Q80314=00/@
300C61@061dI018G4`0D6AD04aPD010E4@803a@@0P0>4`l200lD40<041DA00T03a@@00hC3`002@H0
3aXF09bWX`0j@d006B8O004:1`0A5aD00P0@5Q@01P0?4a803Q8A00dA40093PX041DA014F4P802Pl;
00L0314=00lD400<4@d03A8>02P]:@0B5a<041DA00803a<B100@51<0300;3`h03A4@00lC4P0?4a80
2Ph=00D9200@5A403Q<?00T>2P0<4@d04aPD014F4P803Q<?0P0=4Ph200hC3aCooooo000Kooooo`0O
00`;4@0;2Q001`H<00/;400@3aD0BTU?04I5B`0=3A804A0F00L62`0<2a002`X?00P9300>3a405aPJ
00d>4@0?41801`P:00X;3P0A4Q@030d?010A500:2`h03@l?00lA3P041@<02@/800`>300B51<03a4@
00l@4P0200d>4@0E00d>4P0<3A402`/B00`<6@0;2QH03PhJ00d=5`082140418J010@600E5Q/05QLL
00d>4`0D5AT03PlB010A40082PX02P/<018C5P0?41@0414E00803@hB00X02``>014C4@0;3@X030h;
010B400A4a403a4@014C4`0@4A<03a0C0P0A4QL0<@0@4AL04A4H014A6P0B4a`03A0H014D700@4a/0
3Q4I01DH800@4a/04aHN00`?5`0@4a/08RD]04]>EP0D5ad061/N01HI700@51L04QHH01<G6@0G6ad0
6AdO01@H6P0D61T05QXK01@H6@0C5aT051PJ018F600A5AP04ADG01<G6@0E6A`04ADG01<G6@0D61/0
41@F018F6@0B5Q/07B0V01LJ80082a408RD[01PK8@0E61h051LM01@G700G6Ql00P0H6b002@0A5QT0
4QLK01@I7@0E6Qh051TM01<H700B5a/051TM01HK7`0201<H701E01HK800O8bd03a<O01XN:@0B5R40
3Q8N024U<00L82/041@N01DI8`0@51l04QHQ018G7P0?51P03aDE010F5@0S:BX08RPX01<I600A5aP0
4aTI01@J6@0C6AX04QLH010F5@0F6QT04QLC014F4P0C61@051PF014E500=4A804ADF00hB4`0?4aD0
4QHI00lC5@0C5aP04ADF01HJ6`0E6AX03a<D010D5P0?4aD04ADG01<G6@0F6Q`061`N01TL800@4aP0
4A@K014D6P0?4QT041<J014D6P0A51/04QDL018E6`0A51/03a8I00lB5`0@4Q804a@E018C500@4A<0
4A8D01<D5`0H6A`0;Bha01/L7`0;30l04Q<F00lA5P0>4AX04QDO01@G7`0>4AT041<J01PK8@0A51X0
4ADI018E6@0F6Ad04aLK01PO800200`E500700lD500@51D04Q<E01<D5P0@4A<03A0A014F5P0200dF
5@0F014H6@0>4QD03a<F014E5`0:3Pl03Q8C01`P8@0;3`h05a/J01<H5@0U:RL05a`I00hB500>4AL0
41<I014D6P0@4aT03Q4F00`@500<41<03A4D00dA4`803A4B00d04aLF010D4`0K7ah0:bl^00dA400@
51<04QHE00X>3@0U:BP041@C01<G5P0@5AD03Q<F00802a<F00`0318F00/C5P0=51L02Q4D07=kOP0f
?D001`dA00XB5@0<4QD02a4A00X@3P0=4a4201@J600300dC4@0>51803Q@B00<03Q@B00@03Q@C01lT
:00=4QL02a0D0P0@5AP07`0A5aL03Q@D00dC4P0=4a403A<?00lE4@0?5Q802Q<=00`F400:4`l041HD
01HK6`0>4QD03a@H00`A5`0M9b`00`/C00`I800<6b802a/O00`M7`0141404b4S00/G5`074A001Q4>
00L@300@61402Q4:018G400@5@l00P0B5a<07P0<4@d04AHB01<H500;40`03a@@010E4@0=4Ph03a@@
014F4P0>4Q006QhO010D5`0<41803A4D00hB5@0>4Q@0DEEG00lC5P0C5aT02PhA00/?4P0F6Q/04aPE
00lD400B5a<0314=010E4@0=4Ph0314=00hC3`803a@@0P0<4@d0200N8al03a@@00`A3@0_<c00314=
00dB3P0?51003Q<?0`0=4Ph0100>4`l03A8>00`A3@0<4@d200dB3P0=00`A3@093PX0314=014F4P0;
40`02Pl;00T>2P0T:B<04QLA00dB30021`4041D?00dB300200hC3@0B00lD3P0>4`d03A8<00`A2P0;
40T03A8;00`A2P0:3`P02a0900hC30093PL03A8;01<H4@0F6a@04aPA00`A2`0>4`d03a@>0P093PP0
1@0@5@l03Q<=00`A2`0;40X03A8<00803a@>00d03Q<=00X?2@0?50h03A8<00L<1P0M8Q`0@DI000hC
3@0;40X02Pl:00X?2@0?50h03Q<=00803A8<00<02Pl9024V800:3`T00`0<4@/08P0;40X02Pl900P=
1`0E5a802`d701@G400930@04A@:00lB200<3`D03a8:018E3`0;3@P092HT00h@3@092`H051L@0085
000F6A8041<<014D3@0B5@h04A@=00hA2P0=40T03Q4:00lB2`0@4P`03a8<00hA2`0>40/030h900X<
1`0>40/300d?2P0E00lA3@0@4Pd041<>00X=200=4@/03Q8<00d?2P0>40/04A<>00d?2P0;3@P051HA
01HH4`0?4@`03Q<?00D:1P0;3P/03a@@00T>2P0C61@020d900803a@@0180314=00/@300<4@h02A4@
00L>3`0;4aD031<F00hD6@0941D02A0C00lF5`0<5A80>40l09bTWP0K8ad03a<B00dA4@0<410200/?
3`0;010D4`031PD04ADD02<W9P0=4A002`l>00dA400:3Pd0310?010D4`0<40l00P0>4Q40600<40l0
3Q8A00`@3`0;3`h03A4@014E5P0K7b402@`?02T];`0l@4805ATL00lC5P0830h02`lB01DI6`1oPhD0
92P[00d@400?51005Q/G00dB3P0>4`l03A8>00X?2`803A8>0140314=010E4@0?51003A8?00`@3P0=
4Pl0310>00X?2`0B5a<01P/700`A3@0@5A402Ph:01LL600=4Ph02a0<010E4@0200/@300E01@I5@0N
8al02a0<00`A3@093PX02Pl;00hC3`093@T04AH@00/@2@0<4@/020d700dB300?50h02Pl900P=1`0;
40X04aPB00/@2`0A5Q403A8<008041D?00D03A8<00hC3@0A5Q002@h800`A2`0200lD3P0H00dB300:
3`T09b`U034g;P0>50`01P/400lD3@093PP04AH@01@I500=4Ph03Q<?010E4@062`L04AH@00/@2P0:
3`T03A8<010E3`0<4@/04QLA014F400>4`d0314;0P0;40X04@0730H04AH@00D:100=4P`04QLA06M/
IP0f>cD03Q<=00`?2`0D6A<03a@>01DJ500k@Cd02a0<00hC3`0;40`03Q0=00804aDB01H04a@A010A
3`0D5A<02PX8010A3`0G6A@03a4<00/=20092`H02`d8014C3P0>40/04aD@00L91@0D5Q406adJ08:7
P@0O9Ah01@T500hC3@083@L03@l:0P0@4Pd01P0A4Pd08R<N01/L5`0=3PT0418=00hC3@<041D?0140
3A8<01HK5@0?50h03A8<00`A2`0A5Q0041D?00dB3@0=4Ph041DA01HK5`0?5100314=00lD400=4Ph0
314=00dB3P0200`A3@@03Q<?00<03A8>00X?2`0?51000`0?5100200=4Ph0314=00hG4@0C7QL0?dY3
01HP6@0950d03aPC0P0=5Q401@0?5A<03a<B00hB4@0=4A40314=00803Q<?00X041DA01@I5@0@5A40
4aPD00L<200:3`/04AHB00L<200?510041DB1@0@51<04P0=4A003a<B014E500@51<03a<B00hB4@0=
4Pl06b0K01LL5`0>4`h03a@?01<H4`0@5A003a@?00hC3@0>4`h03a@?010E3aCooooo000Kooooo`0C
010?5`0:2A002`X@010?5@0<2a003PdB00L62`0;2`d020P:014A4@0<30/01`L701lN8`0:2@h061LL
00811`0>3A801@@900H52`0200l>4`0300/:400=31803`hC00<03PdB0`0>3Q0200`<300J00d=3@0>
3P`03Ph<00l?3`0A4A@020L<01<D600=41<00`H;014F6P0>4AH02`hE00l?5`0>3QH030/C00h=5@0<
31H0410H014A6@0@41P03@dE00`=4P0;314030dA00l@4P0C51D2014C4P804aDD00L04Q@C01@F5@0C
5A@03@l>01LH6P0>3a40414C00803@h@0100418F014D6@0H6b002@`A01<F6`0>4AH051LL00d@5@0;
3Q<061/P01DH7@0@4aP04QDM00h@70092aL03@lJ0P0F6B800`0B5A`05APM01TL8@0200lC5P0K00/?
4P0C5aP041@C00lC4`0@51D04QHE01DI6@0@51D041@C014E5@0A5AH04QHE018F5P0=4a404ALE00hD
500C61/06AhQ018G6P0H7Qh000<301PN6`0J8AX04AP@01HM5P0A5aL04QLJ00805AXM00<051TL018G
6P0E6Qd00P0F6ah0800E6Qd04aPK014F6P052Q005QXS00lD6P0E6Qh041DI010E600E6Qd03a@F01/Q
8@0T:RP06R0N00hD4P0A5A@06AhK01LL600830/03a@A01@I5@0M8B005a`I02@Y9@0Q9B@03a@A01HJ
6@0@51<08BDT02<W9P0B5QD04ADD0P0;3`h0CP0J7Qd0310?024U9011ADD051PI01PL7@0G6a`051PI
018F6@0@51L03Q4F00`?500B5A`04aHM010C700=41T030lH01<F6P0520d03A4D01<F6P0?4QL02@d@
01DI7@0>4AH04ADH01<G6`0@4aP04ADH010D5@0<41403A4B01<G6P0=4A@05APM03e0A@2GVZ407R4X
014D7@0F6B801PPD01DJ:00111<05ATT00lD6`0B5aX051XJ00`@400A4a80418B00h?4@0K71h07B4R
00/A4@0D6QX010P901TM7P0F6Q/03a<D00861`0E6AX04aLH00hD500C6AT061dO00lC5P0A5AP04aLJ
00X>4@0<41<06QhQ01TM7P093@h03Q8C00/?400D61T03Q8D010D5`803a<F00<03Q8E00`@4`0D61T0
0P0:3Pl02P0R9RL00PH7014E5P093@h041@E00`@4@0?4a@0310A00dA4P0I7Ah200X>3`0@01@H6@29
SHh09b//01<G600A5aL03a@F00hB5@0=4a<03a@F00hB5@0F71`0314B00hB5@000P804aHH00hB4`80
3a<D0P0=4A806`0>4Q<02Ph?00L;300830d04ADF01<G600>4Q<04QPH01<I6@052`/00PP8010F5P0D
6QP04QPF00X@3P0D6QP02@l=010F50052`T05adK00P>300J8200318B00dC4`0;4A403a@G00dB5@02
00XB500@00dE5`0@61X03aTJ00lI600>61L03QLF00dF5@0=5Q<03aPE00/A3`0A5a<05A/G00@:1P0A
5a<03A<?014H4@802Q4:00<03aH?00hE3P0@5a00100@5a005`0@5Q807B<Q00lE5@0:40h03A<B010F
5P0@5Q@03aDD00lE5@0>51803Q@C00dC4`0=4a4051XH00881P0L8R0051XH018H5P0=4a403aDC00L=
2`0220H03aDC00803Q@B00H02Ph=01LK6P0E6AP02Ph=00hB4@0;3`h201<G5P0<00P<2`072`X0=SXi
010D4`093@`04ADD00/?3P0A5A@020`;00hB4@0830/01`/:0P0@51<00`0;3`h03A8>00lD400200lD
40803A8>00L041DA00hC3`093PX02a0<00dB3P0F6aL02@h800803A<900<02Q0700dB2`0=4P/00P0?
50h0:P0@5@l041DA00lD3P0<4@`01`T400`>2@0B50l02@/601HH4`0@4Pd03a4<00h@2`0<3PT02`d8
00`>2@0?4@`03Q<<01HK500E6Q@01P/500T>200X;BT0JVm[028W8`093PX02`l>00050@0<40h06QlK
00<8100?51008RLS06icK`0@5A400PL301dR7P0320@02a0<00`A3@001@402`d800`>2@803@l:0P0<
3`P0200C5Pl04A<>00X<1`0:30L030h:00D70P0:30L03@l:0P0:30L0200>40/02`d800h@2`0<3PT0
3@l:010B3@0>40/02@`50`0?4PT300lB2`07010B3@0D5Q802`d:00P:1`0?40l000@0010F4P0200`B
3P1S00/A3@0>4`l02Pl;01lT800E5a@04A<@010B3`0?4@h03@l<00dA40052@P0310?01dQ800420L0
5ATH00dA400D61L02@d<00P<2`0F6QT02Ph=00hC4@052@P04QPH00H;300=4A803aDE00lD500<40l0
1P`:00P=300E6AP02Ph=00d@500830l0310C00X>4@093A003A4B00hB4`0=4A003A8?00hC3`0?5100
3Q8@018F5`072``041@E00lC50031`P02Ph?010D5@093@h03Q8C00041@0=4A804QHG00`@3`0830d0
4QHF07YnO@0P92D020`<04U=C01>DU<02@`<00lC4P0D61T02Pl<01LL600N8al04AHB00dB3P0;40`0
2@h:01TN6P0>4`l000D100dB3P0@5A80310A00hB4`0<41408BDV09jRX@0W:b/02Ph=00/?3P0>4Q40
3Q<?00dB3P0:3`/0314;014F400;40X03Q<=00T>200;40X01``600803Q<=01D02Pl901DJ50083@L0
318800/A1`0>50X03A<900T>1`0<4@X01@X400X?2P0>4`l02a0<00T=300C5aH04AHB00X?2@0>4`d0
3A8<00/@2P093PP0100:3`T02@0<4@/03A8<00/@2P0?50d0314;00dB300A5Q003Q<=00`A2`0200dB
300<00T>200=4P`0724K04=8A00@5A403a@@014F4P0<4@d010T500lD400=4Ph02a0<0`093PX01`0@
4Pd04Q@?00h@2`0@4Pd04Q@?00h@2`0?4@`00P0:30L200h@2`0500X?2@093PX02Pl;00/@300>4`l0
0`0?51001`0=4Ph0314=00`?300<3P/02Pl;00hC3`0<4@d00P0:3`/0100=4Ph03a@@00P=2@0=4Ph3
00lD4004018G4P0A4`h03Q0;014C3P803a4<00l0418=00X<1`082PD02`d800lA300>40/0418=00P:
1@092`H03a4<01LI500H6QD0418=00lA300=3`X00P0>40/07@0=3`X02@`800hC3`0A5Q8041DA00/@
300F6aL0<3Da00lD400S:2@02@h:01@I5@0=4Ph02Pl;014F4P0;40`041DA00H;1`0C61@05AXF00/@
300730P051TE02L/:00=4Ph03Q@@00XC3P0A61@06AlK008061hJ00P08RPT018H500630P03aDA014G
4`0;4@d03A8>00`A3@<02a0<00@03A8>00/@300<4@d03A8>0P0?51006@0A5Q802a0<00T>2P0>4`l0
6AhJ01DJ5`0830/03Q8A00dA4@0;3a00310A00lC500B5QT0724T02@Z:`0V;2`03aDE00hD4`0A5aD0
4aTG00H<2P0:40`04ALE05AJE`0=4`l05?ooool001_ooooo01P02@P@01HF70061@/05aHL00l>4`00
00@01PH800h>3`071`L02PX800X;1`0D5180000400`;4@0920h0000500/:400G5Q`051<I00d<4P08
1`d03PdC014@5P0?3Q@300h=4`0400h=4P0>3Q003Ph@00X:2P802PX804402``800/<1`0;2`T04@l@
00L71`0B51<0418D00L<3`0F6ah0>Sm300D83`082a805QDM00d:5@0:21<040lL00d=6@0?3aT04a<M
018B6P0?3aL03PlD00h?4`0?41@04A8E00l@4P0>3a403a4@00h@3`0?4A005ALF01<E500<3Pd03Q0?
014C4P0B51<03Q0?01LI600A51H02@d@01HJ7@0<41<051PK00`@4`0D61/04ADH00hB5@0@51L0310C
00T=400<3QL05QPU01/M:P0A4b001@LC00P:5P0=41P03a8I01HI7P0I72404aLJ018F6@0K7b404aLF
014E500200lC4P03010D4`0A5A@04ADD00804QHE0P0C5aH03P0?5A<05A/G01@J600E6a/06AlO01@J
6P0F71`05A/I01XP6`0E7A804AT<01DM4@0D6QP051TL100C61/00`0H7B005a`O01DJ7@0201<H6`0U
01@I700N8bL0<SLk01@I7@0J7b804ALH00hD500C6AL0318@01@J5P0K8Ad05A`F010F4P0T:BD06QlK
018G4`0<4@d061dI01DJ5P0D6AD041DA01LL600E6QH03A8>01@I5@0;3`h09b/Z02X^;@0>4Q403a<B
01/O7P093@`03a<B00X>3@0E6AP092PW00dA4002010D5@8041@G010041@H010C600@4aX030lH00hA
6P0C5B403a4M00/>5`0>4AD0310C00hB5@0?4aH0720S01HJ7@0@51L03A4D0P0@51L0:P0=4A@03a<F
00hB4`0<41403Q8C01<G6P0=41D05APM00d@5`0O8R/02@`E018D80000Ph07b<_03DiB@001Q@03aHP
01DJ7`0:41000080018G4`0B51404aDC00h@3`0C51H05QTJ00L;300E6AX04ADF01@H6@0=4A804ADF
00lC500<414010L800hB4`052@X05ATK010D5`0<41<04ADH018F6@8041@G00H07B4T00L;3P0E6A`0
2`lB00D9300>4Q@200`@4@0F00dA4P0<41402`l@01/O800T:2T0:2`]03/o@00D61T02@`=01<G600I
7Ah04QHG014E5P0<41402`l@00P<3@0A5AH0;C4b01`P8@0j?Sl04QHG010D5@803a<D0P0>4Q<0200?
4a@01PX;00hB4`0D61T082@U01XN7`0A5AH03Q8C0P0?4a@07@0=4A80310A00dA4P0<41402Ph?00`@
4@0A5AH04QHG00hB4`0<4Q002@l=00`B400>51802Q0>00T?3@0?5A<02Q0>01@J600;4@l04QPF00X@
3P073@d03Q@D00020P0@5QH0318B014G5`0<4Q803A<C00@03Q@D0P0@5Q@0400?5A<03Q@B00dC4@0<
4Q002Q0>00dC4@0;4@l04aTG00`B400=4a402a4=00`C300>5@h03A@=00XA2P083`P500hE3P0800hD
400B61H0318@00X@3P0;4@l0318@00dC4@0>518300dC4@80318@00L041HD014G5@052`T02a4?00L=
2`000P001@T700806AlM01P01`d;00H<2P0<4Q002`l>00T=30052@P03a<B02hb<@0a=C@01`/:00/?
3P0G6aX041@C02@X9`0R9RD020`;010D4`072`X0310?00H:2@0G6aX051PG00`@3`0=4A0200hB4@0=
00hC400<4@d0314=00`A3@0;40`02Pl;00`A3@0?51004QLC00hC3`0;40`04aPD00`A2P02010F300@
00dC2P0@5@h041D>00P=1`0A5Q004aPD00dB3P093PX01``800lA300C5A006Q`G018D3`0K7AP03a4<
00h@2`803@l:01L030h900d?2P0>40/04AH?01<H4@0@5@l020d700T>200G71P082DQ00P=2@0<40l0
61`K00lC4P093@`03Q<?00P=2@0=4Ph00@H2038g<`093PX05AXF00P=2@02014F4P0300T>2P0A5Q80
30h900@03Q0;00/03@l:00/=200<3PT02P`700T;1P0?4@`06Q`G00T;1P0?4@`030h900X<1`0200h@
2`0300X<1`0;3@P03@l:0080418=00<03Q4:00hA200>4@L00P0>4@P02@0>4@T03Q4:00`>2@000P00
418?01<E500=3`h04ADD00H>2@0200@=200600`B3P0=4`l03aDA018G4`0>40d030h;0P0>40d0;@0<
3P/03Q8A00P<2`0:3Pd04aLF00D9200B5QD020`;00lC4P0B5QD04aLF028V9@0Q9B@0720O018F5@0E
6AP03A4@00P<2`062PT0310?00lC4P0K7ah06AdL00`@3`0A5AH041<I00X=4P0<3a@02@`A00P<3`0<
41803Q8C00hB4@0=4Pl03A8>00hC3@0;3`d03a<D00hB4`0F6Q/04aLH00L;300>4Q<05a/L06mcM002
014E5P0R00T=3P093@d01`/:01hR8@0830/0:Bd/00D9200B5QD0>cln03i2@@0F6QT04aLF010D4`0<
4@h082DQ02db;P0D6AD01@X6014F4P0:3`/041DA00/@300730P0314=00dB3`0>4Q<02`lB00`@4`0C
5aP0HfMX01LK700830/02Ph=00dA40803Q<?00l0314=00T>200?50h0314;010E3`0<4@/03A8<01XO
6@0?50h01@X400P=1`0@5@l05AXD00hD2P0>50P00P0B60h03P0>50X03a@=01DJ500@5A003A8>00dA
400D61L092PW01lT800<4@/02Pl9010E3`0=4P`000@0100:3`T0100;40X0314;00/@2P0>4`d200`A
2`0A010E3`0=4P`02Pl900L<1P0:3`T02a0:00`A2`0B5a40:Rl[00D:1P0010001``800lD400I7QX0
41DA00lD400=4Ph00`0<4@d0400?4@`04A<>00d?2P0?4@`04A<>00d?2P0>40/030h900d?2P0?4@`0
3@l:00X<1`0:3`/02a0<00`A3@0=4Ph200hC3`03010E4@0>4`l03A8>00<0314=01403a@@018G4`0?
51002Pl;00lD400E6QH03A8>00hC3`0=4Ph0314=00dB3P0C5Q80418=00d?2P0?4@`030h900/=2002
010B3@0400d?2P0>40/03a4<00d?2P802`d80P0I6aH04`0:30L03Q0;010B3@0@4Pd03Q0;00lA300@
4Pd03a4<00/>2P0<4@d02Pl;00`A3@083@T02a0<01HK5`0D6AD06AhJ01PM6@000`000P0=4Ph03`0B
5a<0314=014F4P083@T0314=018G4`0[<2`07R<O01`Q7@1KH5`03a@@00lE4@0:40`02a4=00lE4@02
00dC3`04010F4P0?5A404QPD00lE4@802@l;0P0=4Ph300`A3@0300dB3P0<4@d03A8>00803Q<?00X0
3a@@010E4@0:3`T02a0:00lD400B5a<03a@A00T=300>4Q403a<C0P0?4a@03P0>4Q@03A4D00T>4P1Z
Kg<06b0S00021@0>4aD01@/;00/A4@0A5aH06b4O00471@0I7ad03A<A5?ooool001_ooooo00l04A0F
040oA@0K6R0030/@00X:3P0A4AD030`>00/;300820P0410>00/;2@0<30`030`>010?500510T00P0@
3a@0100?3Q<02`X?00`;400>3A8200/:3`0500h=4P0>3A<03PdC00h=4`0>3A800P0>3Q00100A4A80
4A4A010@3`0?3`h200l?3@0C014?40092@T03a4@018D5P0;41<05a`O05MLH00=41L01`T@00`;4`0;
21<04a4L018A6`0;2a@030`E014A6P0A4AT03@dE010A5P0200l@5@0^010A5P0>3a@030d@00h?4@0>
3a803PlA018C5@0B4aH04A8D00<41P0E5QT04a@G00l@4P0R8bH07R4T00dA500D61/0310C01<G6P09
3A00310C00lC5P0@51L03A4D01@H6`0G6ah061/R018E7`0:3AL0418M01HI8P0E62404A@L010C6P0A
51/071lV010C6@0F6Al06QhQ018F5`0A5AH041@F010D5@0A5AL04QHH018F5`804aLI040051PI01@I
6@0>5A@04Q/I010I600>5QP041PK01@L7P0G7b003QLE02H`:P2<UXh0KGM]01dW7@0H7Qd05a`O01@I
700B5aX04aPK01DJ7@0H7B005Q/N01<H6`0A5QT04QLJ01DJ7@0Q9RT0A4U;014F6@0L8B@04ALH00lE
5@0B61P041HE014G5@0C6AP04aTG01DK6P0A5AD04QHF01DI600@51@05a/J00hB4@0?4a<04QHF00hB
4@0=4A404aLG01DI6@0A5AH041@E018F5`0=4A<04QHH00`@4@0C5aT03Q8D01@H6@0D61X041@F01HJ
700A5AP04QDI0P0B5AX201<F6`0C01XM900L7bH05QTP00hA6@0D5al06ahV014D600H71l03a<F01DI
7019CE00@DE800dA500A5AP05ATL014E600?4aH04aLJ01@H6@02010D5@0^010D5`072Pl03a8G018E
700?4Q/03Q4J01<F7`0;3AT09BTd06aaO00F7BH02a8I00/@4P0F71/051XH01<H500B51404aDC010B
4@0?41804A@E00/?400A5AH03A4B01<G60093@h03Q8C018F5`0C5aP03Q8C01XN7`093@h05a/M00lC
5P0;3a803Q8E01PL7`0C5aX03A4D00lC5P0>4QD02Pd@01PL7`0b=ST04ADG00lC50@041@E0P0B5QL0
1P0;3a004QHG00X>3`0?4a@04ADF01PL7@804ADF00/03A4B00`@4@0A5AH041@E00lB4`0=4A802Ph?
014E5P0;3a00310A00hB4`0200lC500700hB4`0E6AX03Q8C014E5P0=4A8051PI010C500200hB4`04
00lC500B5QL051PI01@H6@803a<D01@041@E00lC500>4Q<03A4B00lE4`0@5Q@05Q`J010F50073@/0
41HD00T?3@0<4Q004QPF00dC4@0A5aD041HD00T?3`0R:2P0GVAT01DK6`8041HF01H02Q0@00`B4P0>
51@03Q@D00dC4`0;4A402@l=00X@3P0;4@l0318@00hD4P0?5A<03A<A01@J60093`d03Q@B00lE4`0@
5Q@04ALC00`B3P0I7a/05adI0P0:40`600`B3P0300X@3P0>51803Q@B0080318@00D03Q@B00dC4@0=
4a403A<A00`B400200/A3`0T01@J600g?C/06R0N00P>300A5aD0:c4_02dc<@083P`03Q@B00`B400C
6AL02Ph<00`@3`0=4A002`l>00T=300;3`h04ADD00H:2@0?4a8030l>01<G5P0Y:bX0Bdm>01HJ6@0O
8b804ADD00lC4P0830/05a/J018F5@0>4Q4041@C00lC4P0>4Q403Q8@0`0<4@d200/@300700dB3P08
3@T03Q<?00T>2P0?510041DA00/@2@0200hD2P0A00/A200>4``03Q<<014F400=4P`07b@P00X?2`0=
4Ph03a@@00lA300@4Pd06Q`G01TK5P0P8Qd03Q0;00`>2@0=3`X00P0?4@`02`0>40/03@l:018G400=
4P/02Pl900lD3P0@5@l02a0<00P=2@0G71P03Q8A00803a<B00H03A4@00/@300@5A403a@@00L:1`08
3@T200`A3@0600dB3P0<4@d02Pd:00hC3`0;40`03Q0;100?4@`03P0>40/03a4<00d?2P0A4`h03@l:
010B3@0[;BP04A<>01PJ5@0C5A002`d800h@2`0A4`h02`d80P0?4@`200d?2P0300lB2`0>4@P03Q47
00803Q4801@03Q4900hA2P072@@0CDm;01TK6@0?4A00418A00L;2P0<4Ph02a@?00PA300<4Ph020h:
00dC3`0:3`/03Q0=00lA3P0@4Pl03@l<00X<2@<03A4@01h02Ph=00`@3`0;3`h03Q8A00`@3`0@51<0
2@d<00lC4P0@51<08bLV014E50051`H041@C014E500>4Q4041@C01dQ800?4a8061`K00lC4P0O8b@0
5QXN010C600A5AT03A4D00/?4P0?4aD041@E00lC4P0=4@l200`A3@0500dB400<41403a<D00/?400<
41400P0>4Q<02`0H71d0E5QI00lC500:3Pl01@T:00lC4`062PT04aLF010D4`072`X041@C00803A4@
01T03a<B01DI600>4Q401PX900dB3`0A5Q8041DA00`A3@0A5Q80314=014F4P0730P0314=018G4`09
3PX0314>00`@4@0:3Q40310C00X>3`0A5AH03A4@00P<2`0:3Pd03A8>00<03Q<?00h01P/5010E3`0>
4`d04aPB014F400@5@l03Q<=00dB300F6aD0GfAN08:7P@0k@3X02a0:00X@1`803a@=00<02Pl800`A
2`0C61800P0;40X02@0;40/03A8=018G4P0<4@/02Pl900T>200=4P`051TC00dB300300`A2`802a0:
0P0:3`T02@0=4P`02Pl900/@2P0>4`d02a0:00hC3@0;40X03a@>014F4002010E3`0800dB3P0>4`l0
2a0<018G4`0;40`0314=00lD400>4`l300`A3@0900dB3P0>40/03a4<00d?2P0>40/03a4<00d?2P0>
40/03a4<0080418=00@030h900X<1`0=4Ph03A8>100<4@d00`0@5A403Q<?00dB3P0400dB3P0D018G
4`0?51002@h:00dB3P0C61@04AHB00lD400=4Ph02Pl;00/@300A5A003a4<00`>2@0@4Pd03Q0;00d?
2P0A4`h04Q@?014C3P0B50l201<E400:01XL5`0<3PT030h901<E40092`H03@l:018D3`0?4@`03Q0;
00lA30804Q@?02D041@?010E4@093PX03Q<?00lD400:3`/0314=04eBCP13B4@04QLC00lD400I7QX0
2@h:014F4P0?51004QLC00lD400>4`l05Q/G01@I5@0B5a<04AHB00`A3@0H7AT061hJ014G4`0=4`l0
3Q@@00/A3@0>510051XF00dC3`0:40`03Q@@00lE4@0C6AD041DA00803a@@00@03Q<?00lD400@5A40
3a@@1@0>4`l0600=4P`03a@>010E4@0<4@d0310>00hB4@0?4a8041@D014E5P0@51D03Q8D00/?4P0E
6Qh05ATM01@I701MHVD0=C/l018H600?5AD03aDD00lE4`0B61H061hL00/A3aCooooo000Kooooo`0H
00L6300C4QP03PdB00401@0A4A@05aLI010@4P0=3@h02`/;01<C4`0>3Ph05QHF030`<P071P/04Q4F
00D42@0=31404a8G00T83@0510T02`X?00d<4@0<2a0040lD0`0=318200d<4@0500d=3`0?3a403`lA
00h>3P0=3@d00P0<30`0=00D4QD03@d?00/<3P0@4a@01P/>00/@4`0A5QX04QDJ014D6@0B4AT04PlH
014@600@41H051DJ018C600<3A802@X?00X;400?41D03@dE00h>5P0A4AT0410H00d>4`0E5QX06a`Q
014B5`0<3A40414F010A5@0M7R80GUmT03hoA00720`020T>01HH7@072Pl030lD00lB5`0L7b@04A@I
00hA5P0B5AX051LL00hA5P0D5a`05APM00X=4`082a804QDL01TL8`0?4QT200d@5`0O01HI800;3QL0
4aHO00/>5`0E624041<I014E600A5AT04QDJ018F6@0B5QX041<H010D5`0A5AT04QDJ018F6@0B5QX0
3aLI018L7@0B71h03QPJ00`E6P0B6b0051dR00`F601GHF40n?oo0<;=a`0Y<bd05AXM01HK7`0201LL
800501DJ7P0D6Ad04AHJ014F6P0B5a/00P0A5QX02`0@5AT00`T902L]:`0;4A405adM00dC4`0A5aL0
41DH01DJ7@0E6a/04aPK008051TL01T07b<V00dA4`0<41404QHI01hR900>4Q<03A4D01LK7@0?4a@0
3A4D01@H6P0>4QD0310C010D600C5aX01PT>00d@500G6ah05QTN018E6@0>4QD03a8G010C5`0@4aP0
5APM00<05APO04/05APN01DH7@0S9R/082<X01PK800>4AH04aHK01/N8`0@4aP04aHK00@730051P/0
:bhc01DH7@0?4QL051LL01PK800C5Q/04A@I01HJ7@0:3Q402`lB00hB5@0D5a`04QDJ01hQ9P0?4QT0
2`hE01TL8`0B5Ah01`XC00/?600F72802A4D01LO8@0>51<0318@00P>2P0?51004aDD00l@4@0>3a40
4Q<G00lB50093@h04aLH010D5@0?4a@09BTZ05QLG@0>4Q<02@d>00dA4P0<41403A4B00P<3P0=4A@0
4aLJ010D5`0?4aH04ADH010D5`031`X02PhA00`?4P0?4aH092P[00L:300?4a@03Q8C00/?400830d0
2Ph?00/?400?4a@00P0D61T0;@0A5AH04QHG00T=3P0@51D0310A010D5@0=4A803a<D00X>3`0A5AH0
4aLH00X>3`0A5AH03Q8C00/?400<41403a<D014E5P0@51D03a<D00hB4`093@h05QXK00451P000P<0
92PY00lC500=4A803Q8C018F5`0D61T04aLH00lC500@51D03a<D00`@4@0;3a003A4B00hD4P0?5A<0
1P`:00dC4@0J81h03A<A00P>300200dC4@0;00lE4`0<4Q003A<A010F5P0N92@0Q8Z:00`B4P0=4a<0
20h>00hD500<4Q800P0:41002`0<4Q803A<C00X@3P0;4@l0318@00dC4@0>51803aDC00P>300;4@l0
3Q@B00803aDC00<0<3Hd018H50052`L00P0A5a<00`052`L020h:00`B3P0500`B3P0700hD4P0@5Q@0
3Q@B00/A3`0=4a4041HD00lE4`0200hD4P<03A<A01003Q@B00L=2`0=4a4041HD028X9P0O9B<03aDC
00D;2@0F71X0318@01TO7@0A5aD0310?00/?3P0<40l03Q8A0P0@51<03`0J7Qd01`/:00hB4@0I7A`0
2`l>01HJ6@0@51<07b<R01<G5P0=4A0010P700/?3P072`X020`;00hB4@0200`@3`0300dA3`0<4@d0
314=00<0314=00L01``800@91@0M8Qh02@h:00@91@000P001P/40080318800/02@l600`A2P0<4@X0
4AH?01lT7P2`]K40DUMC01dR7P0@5A403Q0;00X<1`02014C3P0401TK5P0<3PT02`d800`>2@803a4<
01/03Q0;00`>2@0=4P/02a0900X?2@0>4`d04AH@00lD40011P803a@@00/?3P0D61L03A4@00P<2`0:
3`/0314=00P=2@0D6AD0314=00hC3`0320@0CU=?01HK5`0B5a<01P/701/P700>40/00P0?4@`05@0>
40/03@l:00/=200C5A002@/600lA300=3`X01`T401LI500?4@`05aTD010B3@092`H030h9018D3`0>
40/04Q@?010B3@0<3PT02`d800lB2`0300d@1`<03A0902H00`D004a>BP2ATi008B<P00d?300@5A40
1Ph900PA300740/01P`800/A3@052`L0314=01<E4P0F61D05ALD010B3`0>40d02Ph=00`@3`0?4a80
2@d<00/?3P0420L03A4@010D4`0;3`h03Q8A01/O7P0?4a805ATH00X>3@0830/04ADD01<G5P0@51<0
51PG02hb<@803a<B00/020`;01TM7P0C5QX03Q8E018F6@0@51L03a<D018F5`0@51D03a<B00`@3`02
00X>3@0C00lC4`093@h02`l@00L;30052@X03Q8C00/?400A5AH00042010D5@052@X04ADF00/?3`0>
4Q40310?014E500830/061`K01<G5P0300lC4P0D00dA400<40l01``900dB3P0A5Q802a0<00X?2`0C
61@05AXF00H;1`0?51003Q<?00L<200=4@l02@d>00hB4`0<41404ADF00@82@0?4a8300dB3P0G00`A
2`0;40X02a0:00T>200E6Q@04AH@018G4@0A5Q00314;01`Q6`0>4`d04AH@09JKU@3Sj>80PHJ0010E
3`0=4P`03A8=00/@2P093PP03a@>00hC3@0<4@X00P0@5@h02@093PP01P/500T>200B5a403A8<010E
3`0E6Q@020d700hC3@0300lD3P0400dB300;40X02@h800`A2`802@h800h0314;00T>200;40X0314;
00dB30093PP020d7018G4@093PX020d900870`062`L02Pl;014F4P80314=00H02a0<00`A3@0=4Ph0
3A8>00d?2P0<3PT200d?2P0400`>2@0=3`X04A<>00h@2`8030h900@03Q0;010B3@0>4`l03A8>0P0<
4@d200X?2`0400dB3P0;40`02Pl;00X?2`<02a0<0P093PX0100;40`02Pl;00X?2`0<4@d200lD400H
00dB3P0<4@d06QdI024S7P0L7QT06Q`G010B3@0;3@P03@l:00lA300@4Pd04A<>01<E400E5a80<S@_
024S7P082PD03@l:00`>2@0>40/03a4<00d?2P0<3PT03Q0;0P0@4Pd06`0@50l05AXF00hC3`0;40`0
314=00X?2`0A5Q808RLS01dR7P0<4@d04QLC00050@0B5a<03a@@010E4@093PX03a@@014F4P083@T0
6b0L00/@30093PX07R<O00X?2`0@5Q802Q0<00P>2P0200`B3P07010F4P0c>CD08RPT00hD400=4`l0
3aDA018H5002010E4@<03a@@00<041DA00lD400>4`l0100>4`l0200?50h03A8<00`A3@0>4`l03a@A
00hB4@0?4a803a<C0P0>4Q<03P0@51H04QHI00/@500G72002PlB03Ll?`0Z;S004QPH00hD500H7Qd0
2@l=014G5@0D6QP05Q`J5?ooool001_ooooo00D02`X@00P7300H5a`03@`@010@4`0200/;3@0A014A
4`0>3Pl02`/<00/;300/;2h0EeMI00/:3P0A4A@04A0D01<C5P0<30l0B4M;01XI7@071PX03`lB00d<
400<2`l00`0<2a4300`;408040lC0P0@4182010@4@04010>4P0@41<02@X=01@G6@<020d@00`01`X?
00H93P0>3A@040dE00X93`0A4Q@05aPK01DF6@0>3a8030dA00h?4`0@4AH200d=5@80410I02X03PhG
01HG7@0J6R404Q8I00d=500@4AL04Q<I00d=500/;3<051@K01HG7@092Q004Q@J00/>4`0D5a`04A@I
01<F6`0:3A804QDJ00`?500:3A802`hC00lB5`0@4aP08BDY01dQ8`0=41@041<G014D6P0@4aT03Q4G
01TL8`0A51d0>Se701lQ;00K7BP04aHN01LJ800F6Al051LM018E6`0@4aT2014D6P<04QDK01<04aLL
00TB500@6Q`04QdQ00lI7`0O:C40GVM_02hh@00L9Rd08B`_04iHF@0nBDL05B0O018J7@0E6Qh061dQ
01TN8P0H7B405a`P00804AHJ0`0B5a/07@0B5aX0728Q014G500C6AH04QPG00dC4`0A5aL03A8E018G
6`0A5QX04AHK018G700=4QL02`hD030d>@0j?T8071lU014D6@0C5a/05APN01/O900I7B405aXP01LJ
7`0B5A/06ahT00d@5P0@4aT03A0F00804A@J02405aXP01@G7@0>4AL03Q4G00lB600:3A@03a8J010C
6`0A51`04QDL01@G7@0E61d07B4T00`@4`0<41805QXK014E5`093@l0310D018E6P0D5a`04aHK01`O
900931403a8G00hA5P0A51T041<H00d@5@0@4aP051PL014E6@0?4QH00P0@4aP06P0N8BH03A0F01lR
:@0M82L03A0H01XM9@0D6Ah02a8C00D>300B6aT03A8?018H500>510041@B01DG5`0@4A<04A8D018C
5`0C5QP02Ph?00/?400>4Q<051PI05IJF`2a]KH0:Rh_0P0=4A803`0A5AH051PI018F600C5aX041@G
01<G6P0<41<03A4D00lC5P0K7b804ADH03Hj?@0K7b802PhA01XN800201@H6@0700lC500<41403a<D
020T9@0=4A804ADF00lC5002010D5@0400hB4`0E6AX041@E018F5`@03Q8C00<02`h?018F5`0;3a00
1`0>4Q<02@0<41403Q8C00lC500>4Q<04aLH04I:B`0B5QL03a<D00`@4@0200lC500500X>3`0@51D0
3Q8C00`@4@0>4Q<00P0@51D0500D6QT02a4@00P>3@0Q9bH0;cDd00P>3@0;4A003A<B00X@3`0F71/0
41HE00lE50083Ph041HF00X@400A5QH03A<C00hD500@5QH03Q@D0P0<4Q80200=4a<03Q@D014G5@0@
5Q@03Q@B00`B400;4@l02Q0>0`0@5Q@01@0>51801@/901lU8`0B61D02a4>00803A<@00<02a4>00dC
400=4a001@0=4a001P0?5A<0318@00X@3P0;4@l0318@00dC4@803aDC0P0>518200dC4@0=00hD4P0=
4a4020h<00`B400O9B<03aDC00`B400=4a404QPF00X?3@0<4Q002Q0>00dA400200hB4@0500`@3`0;
3`h02Ph=00T=300F6QT00P0@51<040072`X02@d<00D9200D61L03Q8A010D4`0830/04ADD00dA400;
3`h0310?00X>3@0<40l03Q8@00X?2`0;40`300`A3@0700/@300E6QH0@TM3020U8@0>4`l01PT600lD
3P0200hD2P0?00/A200>4``03Q<<00hC30042@<0F5eI024V8P083@T03A8>01DG4P0>40/04aD@00d?
2P0B50l02`d800H03@l:01D02Pl800`A2P0>4`d02a0:00X?2@0<4@d03A8>00X?2`0;3`h03Q8A00dA
400;3`h0314=01@I5@0=4Ph010P4014F4P0@5A407b@P08B9Q@0k@3`00P0;40`02`0:3@X03a4<010B
3@0@4Pd03a4<00d?2P0<3PT051HA00h@2`0@4Pd04aD@00804A<>00H02P`7010B3@0:30L020X500lA
300C5A0200lA30803Q0;00<0418=014C3P0>4@X00P0>4@T04P0>4@X03Q4;00hA2`0D5Q4030h903Xl
>00K7AT030h:00D:1@0<4`l02A8=00lH4`0;4@d0>3hj01`R7P0:3`/04A<@01<E4P804Q@A00<04aDB
00`@3`0830/00P0;3`h07@0A5A@0;30_00hB4@0@51<0310?018F5@0O8b804QHE00lC4P0E6AP0FEeL
02<W9P041`H04ADD00`@3`0?4a803Q8A018F5@0Q9B@0@4A500d@50093A003Q8E00hB500>4Q<04ADF
010D5@0>4Q80310@00802Ph>00l0310A00/?400H71d0;30a01HJ6`093@h0310A00X>3`0E6AX03Q8C
014E5P0?4a@0310@00hB4@0=4A000P0<40l06@0>4Q402`l>00X>3@0?4a802`l>01PL6`0R9RD04aLE
00`A3@093PX0314=010E4@0<4@d03a@@00H;1`0@5A402Pl;01lT800<4@d0310A014E5P0?4a@03a<C
01<G5P0;3`d00P0?51002P0>4`h02a0:00/@2P0:3`T0314;01TN600A5Q003Q<=00lD3P0:3`T200/@
2P0<00lD3P0L8A/092TS01/P6`0<4@h02`l=00`A3P0<4@d02@h900dB300@5@l0314:0P0<4@T02P0@
5@`06b0H00hC300C61802@h801@I4`0P9Al02@h800`A2`0>4`d2010E3`0400hC3@0<4@/02a0:00hC
3@802Pl900h0314;00T>200?50h041D?014F400<4@/02Pl901<H4P0<4@d041DA02L/:00C61@0314=
00T>2P<03Q<?00/041DA014F4P0B5a<03Q0;00`>2@0?4@`03Q0;00`>2@0?4@`0418=00lA300200`>
2@04014C3P0E5a803A8>00dB3P<0314=00@02a0<00`A3@0:3`/02Pl;0P0;40`01P0<4@d03Q<?00/@
300<4@d041DA00hC3`802a0<0P0?51000`0>4`l03A8>010C3`0200d?2P04014C3P0?4@`030h900h@
2`804A<>00d0418=00lA300@4Pd06A`G00hA300;3PT03A0;00T<1`0?4Pd041@>00dA2`0<3`X03A0;
00803Q8<00<04AHA01hS7`0H7AT00P0?51001`0<4@d03A8>01XO6`0?4Pl041DA01TN6P0?51000P0>
4`l05`0B5a<03Q<?01XO6`0>4`l03a@@00T=2@0D6AD0>3di00X?2`0=4Ph03A<?00X@300>51004aTE
014G4`0B61@0318>00dC3`0@5Q802Q0<00D;1`0@5Q8041DA00803a@@00@03Q<?00lD400@5A403A8>
0`0>4`l200lD400H00`A2`0>4`d041DA014F4P0?5140310?010D4`0?4a<03Q8C00lC500A5AL04aLJ
00lD600>4aL05a`O03@i?00=4Q@082HV01LM7@0=4a8041HD018H5P0;4@l061hL5?ooool001_ooooo
01P03`hC00h=4P081``02@T;00P82P0000803@d?00H6200=3@l05aLI00P82P092@/03Ph@00/;3@0@
41807QhP00`<3P0A4A<051@F00`<3P0C4aD03@d?00P82P0@418600`;400400/:3`0<2a0030/@00h=
4@803PdB00d020H;00l>4`0:2`l06ahQ010E600>4aH01P/>00H93P0@4aP03@`B00X73P0D4aP03a0@
008030h=00T03PlA00l@500@4AD051DJ00l?5`0=3AD03PhH00d=6@0=3AH00P0>3QH04@0=3AD04Q8J
010@600=3AD071`T03Ph@00?3aL06ATQ00H63P0C5A/020/@01@G70082a003A0E01hQ9P0g>Sl07B0U
00803a8G010030lD00d@5@0C5QT02`l@00`@4@0F6Q`04ADH010C600G6R0051LN00L:4`1?DU`06Q`X
014C800D5R405APO0P0G6R40100F6B0051LN018E700B5A`201<F7@0n01@G7P0D61h03aTK01HQ8`0@
6b0051hW04mIHP3Wl?D0J79l024[=@0E82L082/_01HQ8`0@6Q`051`O01DJ7P0D6Ad05Q/O01PM8@0L
8BD05a`P01DJ7P0B5a/04AHJ01<H700G71l0Ade;00T?2`0G7AT03A<A014G5P0B5aX041DI018G700=
4QP03Q<I01<H7`0<41T08RD^028U;00M82L041<J018E700;3QD051LN01DH7`0F6B005APO018E700E
61l061/R01HI800I72<02PdD00/>5@0G6R404A@K00hA600F6B0051LN00d@5`0H6b8201<F7`0D014D
7@0A51/041<I00lB5`0@51H04aLH018F5@0?4a8041@C01<G600D5a/03A0E018E6P0A51T05APM01LJ
7`0A51T02PdB00d@5@0?4QL200`?500o010C600>4AH03A0E018E6P0I7240:Rdb02HY;P0:3A@03A0G
01<F7@0N8BP02PlC00hF4P0Z<bh0=d0k01HL600=4`l02a4?00`@3`0@4A<051DG01`M7`0F5a/01PT;
01DI6P0I7Ah03a<D018F5`072``0:2`]00/?400<41404QHG01<G60093@h0:Rh`01`P8`0420/04aLJ
018F6@0;3a805a/N028V:@0N8RD0310C00862@0M8B@04QHH01<G600D61T041@E00hB4`0C5aP0=CTj
00dA4P093@h0310A01DI6P0?4a@0310A01<G600?4a@04ADF00803Q8C00D02`l@034e=P0?4a@05ATJ
00<7200200lC500I00hB4`0<41402Ph?00X>3`0<41403A4B01LK70093@h05a/L01PL7@0<3a0041@E
00dA4P0<41404aLH01HJ6`0B5QL04ADF00`@4@0:3Pl04QHG01HJ6`0D61T041HF00dC4`0200`B4P0F
00lE5@0A5aL0318B00dC4`083Ph07R@T01HL700C6AT04QPH00P>3P0H7Qh00`T900L=3@0A5aL03A<C
00lE5@0A5aL041HF00dC4`0;4A402Q0>00/A3`80318@0P0>518020032@L03A<A00L=2`0>51803A<A
00T?3@0:40h03Q@B0P093`d00`0<4Q002Q0>00`B400500`B400600dC4@0:40h0318@010F500>5180
2a4?0P0=4a4200`B40802a4?00`03A8@00X@3P0=4a4051XH0006100C6AL03aDC010F500:40h03Q@B
00D;2@032@L2010D4`0F00dA400;3`h04ADD01<G5P0A5A@0FUiM00`?3P0@51<01PX9010D4`0830/0
3a<B00P<2`0=4A001PX900/?3P0:3Pd03a<B01DI600>4Q402Ph=00`A3P803A8>0`0?51001`0B5a<0
00D101TN6P0730P06b0L00T>2P0<4@/00P0;4@L05`083PD02a0900/@2@083@L04aPB00/>2`0A5Q80
3A8>00/@300=3`X02P`701@F4@0>40/0418=00d?2P0?4@`03Q0;00`>2@0;3@P030h900lA300730D0
2a09008041D?01003Q<=00dB3P083@T01``8018F5@062PT03a<B00X=300;40`04QLC00lD40011P80
9R/W00T>2P0?51001``80P093PX04P0D6AD01``8018D3`0B50l04A<>010B3@0?4@`03@l:00h@2`0?
4@`020X500T;1P0?4@`030h901LI500F61<03Q0;00d?2P804A<>00<05QPC010B3@0=3`X00P0>40/0
0`0;3@P03a8;00lB2`0200lB2`0A00lB300?4@`01@L201LI500:30L03@l:00l@3@0H7AL08RXU014J
5@0C71L01@/7051FDP0Q9b<04AHB01@F4`0A4a000P0=3``0300@4Pl03A4@00H:2@0830/04ADD02X^
;@1^LW4041@C00T=300?4a802`l>00hB4@80310?00h04ADD06EYJ00H71/03Q8A024U900>4Q403A4@
00X>3@0?4a8061`K00`@3`0?4aD02`lB010D5P803a<D00@04ADF00hB4`0=4A80310A0P0;3a00:P0>
4Q<01PX;00D92P0Q8b@01`/<00010P0D61T04ADF00H:2`0@51D0310A010D5@0?4a<0008101DI600>
4Q402Ph=018F5@0I7A`01@T800/?3P0830/04QHE01/O7P072`T02@h:00lD400>4`l02@h:014F4P0<
4@d020d9018G4`0C61@0@DI2014F4P0<40l0310A018F5P0830/061`K00dB3P80314=0P0;40X0>00<
4@/03A8<00`A2`0I7QP03Q<=00/@2P0?50h02a0:00L<1P0=4P`02a0:00P=1`0F6aD03Q<>00`@3`0=
4A805ATH01HK5`0?51003Q<=00hC300>4`/03Q@:00/A1@0>50P06b4G00L<1@0S:2802a0:0003000<
4@/04AH@00L<1P0:3`T03A8<00hC3@0<4@/02Pl900`A2`0?50h02a0:00X?2@0=4P`02@h800hC3@0;
40X041D?014F400:3`T01``6010E4@0A5Q80>Chj00dB3P093PX041DA0P0;40`0400<4@d03Q<?010E
4@0A5Q803Q0;00`>2@0@4Pd03Q0;00`>2@0@4Pd030h9010B3@0?4@`03Q0;014C3P0D5Q4700`A3@80
2a0<00@0314=00dB3P0=4Ph03A8>0P0@5A4200dB3P0;00lD400>4`l03Q<?00`A3@0;40`03A8>018E
4@0?4@`03Q0;018D3`0>40/00P0;3@P03P0=3`X03a4<00lA300@4Pd04aD@01HJ500<4@/03A8<00lD
3P0A5Q003a@>00/@2P0?50h03A8<0P0>4`d09P0=4P`02a0;01<H500?51003Q<?01<H500<4@d041DA
00L<200;40`03a@@018G4`0730P061dI00dB3P0G71P08BHR03@i=@0F6aL02a0<01LL600C61@08bPT
00lD400E6QH041HB00hD400D6QH061hJ01<I5@0=4`l051XF00dC3`0<4Ph04QPD014G4`0?5A403a@@
0P0>4`l01P0=4Ph03Q<?00lD400;40`0314=00dB3P803a@@01804AHB00hC3@0G71H07b@P01PM6@0@
5A804ADD010D4`0B5QH04aLH018F5`0?4aD0310C00462P0E6Qd04QLJ00dB5@093Q0200P>3P0501@J
6@0:40h00`T701<I5`0630X05?ooool001_ooooo01/020P:00/;3@0>3Q003Ph@00/;3@0820X02PX<
00h>400A4A<010<8018A5P0<2a002PX<00d=3`0E5AL06QXL01HF600<30h02PX<00l?4@0<30h03Ph@
00l?4@0;2`d02PT>00`;400=31400`0?3Q<03@0:2@l04Q4G00d<4P081`d051<I00h=4`0=2Q402PT?
01HG700>41D041DH00462@0;41<00P0?4aH05`0@3a@040hC010@4P0>3`d04aDB00<50P0B51<02``>
01HG6`0I6Ql0410H00d=5@0<31@030`F00`<5@0=3AD03PhF010@600B4QX04a<K014A6@0?3aL0410H
00804Q8J00l04a<K010A6@0E61l01@P?01<F7@0G6R404QDL06EXK`0S9Rd02PdD00lB6@0:3A@02`hE
018F6@0>4Q400P0>4Q<01P0?4a@041@G010C6@0?4QT03a8K00lB70803a4M00H03a4L01<F7@0A51/0
41<J01DH7`0D5ah2018E70804A@K02/04QDL01@H7`084Q@02aHH01<N8`0M9c00@4YC09^U/00^>4@0
6B<]014K9@0@6R<04QdS014K8@0E72805a`R01PM8`0D6Al09R/a04A9C`0K82H05Q/Q01DJ800_=3X0
3a@J014F6`0M8b<01P`:01@J60032@T061hO00/@4`0Q9RX02PlD02X_=@0<41T051PR01dQ:P0P8b`0
>ci7014D7@1cMWl06ahW00<04QDN00`041<L00lB6`0C5Ql05aXS00/>5@0G6R404aHM00`?5P0@4aX0
4A@K010C6P0A51/2018E708051LN01<06A`U010C700B5A`03a8I00`?5@0K7R<04ADG014E5P0A5A@0
4AHC014F4P0A5A@041<I01HI800I72<051LN01<F7@0J7B@041<J00803Q4H0P0A51/06@0@4aX04A<J
00`?5P0C5Qd04QDL00X=4P0<3a@071lT01<F6`031P/0A4M<00d@5@0N8bH04QXF0419A012BdH04aTG
018H5P0G7Ad04ADF00/<400C51P04Q<G00l@4P0A4aD00P0A5AH04P0?4a@03Q8C014E5P0B5QL01@T:
01@H6@21QHH06AdN020T9@0>4Q@04aLJ01@H6`0B5QT041@G014E600L82<07R8U01DI70803a<F00`0
41@G00dA4`0=4A8051PI00X>3`0<41404aLH00hB4`0H71d0<CDf024U9P062P/200hB4`0A00/?400>
4Q<02Ph?00@82@0:3Pl02`l@018F5`0=4A801PX;00dA4P0@51D03A4B018F5`0?4a@02@d>00`@4@0:
3Pl00P0<414200dA4P803Q8C0`0=4A80600<41402`l@00/?400@51D04ADF01@H6@0=4A8061`M00X>
3`0630`03A<C00hD500C6AT02@h>01DK6`0630`041HF00T?3`0630`020`<01HL700B61P0318B00X@
4080318B00L020h>00lE5@0<4Q801`d=00P>3P093@d05Q`L00804aTG00H041HD00T?3@0D6QP04QPF
00hD4P0<4Q0200X@3P0300`B400>518041HD00803aDC00l02@l=00lE4`073@/03Q@B00lE4`0=4a40
2a4?00X@3P0;4@l03aDC01<I5`0B61H02a4?00X@3P0=4a400`0>51801P0=4a402a4?00X@3P093`d0
3A<A010F5080318@02D04aTG00hD4P0=4a4041HD00dC4@0B61H02Q0>00lC4P000@002Ph=01<G5P07
2`X02Ph=00L;2P0@51<04ADD00@81`093@`03Q8A00lC4P0:3Pd041@C01DI600=4A002`l>00hB4@0@
51<03Q8A00X>3@0<40l04ADC00P=2@0A5Q805AXF00`A3@001@402Pl;0080314=00@03A8>00/@3009
3PX020d70P093`D02P0:40L02a0900/@2@093PP04QLA01LL600A5Q801P/700X?2`0?4@`2010B3@03
00h@2`0=3`X030h900802`d80P0=3`X200`>2@0J00/@2@0D6A805Q/E00T>200730H0314=00T>2P0:
3`/020`;018F5@000`80@4A300/@300=4Ph02a0<01DJ5P0320@020d900H;1`0A5Q802@h:01TN6P0C
61@02@h:018D3`0A4`h200lA3080418=02P03Q0;00lA300=3`X02P`700/=200@4Pd02P`700d?300E
5a80418=01HH5@0_<B`0;S0[010B3@0>40/04A<>00T;1P0@4Pd01`T401TK5P0620<06Q`G00X<1`0>
40/04Q@?014C3@0<3`P02@`500/>1`0=4P`0:C0/08bET0084@`03A<?0002000C6AD03Q<?00lA3P0>
40d030h;0P0:30T02`0=4A001PX900P<2`0?4a801PX900`@3`0>4Q403A4@00`@3`0;3`h03A4@0080
3a<B00D03A4@00hB4@0E6AP06alN01dQ800600hB4@0<010D5@0=4A802@d>00P<3@0>4Q<02`l@00hB
4`0;3a0041@F00`@4`062Pd041@F0P0=4A80600C5aP02`l@00X>3`0;3a002Ph?00P<3@0?4a@03Q8C
00T=3P0=4A401`/:00/?3P0D61L03a<B00hB4@0@51<03A4@00`@3`0;3`h03A4@00hB4@0>4Q002Pl;
00/@30803a@@03T02@h:00P=2@0@5A403Q<?00P=2@0<4@d020d901<G5P072`X02`l>00L;2P0730P0
5Q/G00hC3@0;40X03A8<00lD3@0<4@X03Q<<00/@2P1AEU00>3dg0004000<4@/03A8<00lD3P0=4P`0
5Q/E00X?2@052P@03Q<>00/?3P0?4a@0CE5@07YoN`0730P03A8<01XO60052`804AL=01<I3@0=4`L0
10X000`A2P0?50h01``6018G4@0A5Q001``600X?2@083@L041D?00H;1@0D6A<0314;010E3`0<4@/0
0P0730H00`0;40X03Q<=00dB300200dB300800`A2`0;40X02Pl900lD400@5A403Q<?00X?2`083@T2
00T>2P0300hC3`0?5100314=00802Pl;00H03Q0;00@60@0R91l02``901<E400<3PT2010B3@0N00/=
200<3PT0418=010B3@0D6AD0008001/P70093PX09BXV00@91@0<4@d04aPD01/P700>4`l041DA028W
8`0=4Ph02Pl;00T>2P0:3`/02a0<00dB3P0:3`/02a0<00`A3@0;40`020d901LJ5P0E5a804Q@?0P0>
40/2010B3@0N018D3`0D5Q403@l:00L9100:30L03Q8<00hE3P0;4P/04QTB014H4@001`005A`E00P?
200:4@X03QD>00L>1`0=50d0318<01HK5`062`L041DA01hS7`083@T02@h:014F4P0>4`l07B8N05YO
F`0C61@03Q<?0P0@5A400`0C61@04QLC00dB3P0201<H500D010E4@0L8Ad05AXF00P=2@0i?c/0:Bl[
00P>2P0M8al03Q@@00lE4@0=4`l051XF014G4`073@T020h:00X@300=4Ph041DA00hC3`0=4Ph2014F
4P0N00/@300<4@d03Q<?00lD400>4`l03A8>01TN600:3`T041DA00D:1P0D61H02@d<00X>3@0H71`0
1PX;01LK700=4A<05ATL00@93@0@5AP03a@G00dB5@0E6a`02a4A00L=3@0A5aH02Q0>02dc<@0S:BL0
1@/95?ooool001_ooooo00d03Ph?00d=3P0<30d030`=00d=3P0>3Q0030`>02PW:P1KFUh06QTN00d<
4@0<2a002`/=00803Ph?00/02`/<00X:2`0<30d03Ph?010@4@0;2``03@d>00h>3`0;2`d030/@00d<
4@0300h=4P0I00d<4P0<2a402@P?00l>5@0@3aH03PdD00/:4@0B3aL010<:01LG7P0=3a@0DeQL01XO
8P0;41<0310B00/?4@0<30l040hB018B500>3`h03a4?01dO7@1MGUl0LgAf01TJ700200h?4`0500d>
4P0=3A@03`lF014B600A4AP00P0@4AL400l@5P0;010A5`0A4QP04Q<I01<C6P0C51/03A0G00lB6@0=
41L07B0W00/>5@0@4aX00P0<3aH01P0E61l03A0G00/>5@0>4QD03a<C010D5@804ADG00@04ADH014D
600A51X04A@J0P0A51`0>P0A4ah041<K018E6`0A51X03a8H018E6`0A51X04aHL014D6P0?4QP04A@J
01<F700B5Q/04a`N018L7P0C7B803aPQ00lI8P0Q:SL07RLd010I9@0?62<031HO00dG800@6B404APN
01`Q9`0H7B<0;34g07f2R03Oi>L0LWMm02`a=`0N8bT0B4eC01lT:P0I7R<051XK00dC4P0E6Q`04AHH
00lD5`0?51P020dA020U:P1RIfd06QlV00hC6P0N8RX04aHN010C6`0?4QX07R4Y01<F7P0A51`04QDM
01@G7`0B5Ad2014D708051LN00D051LM01DH7P0B5A/03Q4G018E6`02014D6P@041<I03D02`hD01dP
9P0H720041<I014D600A5AP04ADF014E5@0A5A@04AHD014F4`0A5AD04A@J00lB6@0A51/041<J00lB
6@0C5Qd03Q4H018E700C5Qd041<J00hA600=41L08bH^018E7@0C5Qh04A@K018E6`0C5Q`051LL01dP
9@0E61d0HVIZ00lC5`083A004a/I030i=`0S;2X03a@F00`A500>4aH041@H00`=4P0C51P04a@F018C
5@0A51D03a<D00hB4`0?4a@041@E00lC5002010D5@0K00P<3@0a=CH02@d>010D5@0>4Q@03a<F010D
5`0>4QD0310C00dA500@51L03a<F00dA500?4aH04ADH010D5`0A5AL01PX;00P<3@0?4a@02`l@014E
5P0@51D0310A01PL7@0C5aP02Ph?00803a<D00L02Ph?00lC500J7Ql061`M010D5@0;3a00310A0080
3a<D00P03Q8C00`@4@0A5AH03a<D00dA4P0C5aP06AdN00lC5080310A0P0=4A8200hB4`803a<D01P0
3Q8C00dA4P0=4A803A4B014E5P0:3Pl0310A01PL7@0Y;Bh051PI010F5`083Pl03Q<E00/@4P0B5aT0
2@l@01@I6`0?4aD03aDF00X@4@0L8B<01@/<00lE5@0>51@400`B4P0>01<I6@0;4A405A/K00H:2P0A
5QH04aLG00lE4`0:40h04aTG00lE4`0>51802@l=010F500>518200`B400600hD4P0@5Q@03Q@C00/A
400B61L02@l>0P0?5A@01`0<4Q403Q@C00H<2`0>51<041HE00/A400<4Q000P0=4a400`0<4Q003A<A
00lE4`0200hD4P803aDC01D03Q@B00dC4@0>51802a4?00`B400=4a404ALE01PN702:T8h07R@R01DK
6@0A5Q@04ALE00L<2P0=40l02`l>010D4`0<40l06AdL00dA400:3Pd00P0;3`h02@0<40l03a<B00dA
400=4A002@d<00lC4P0B5QD02`l>00`@3`0200dA4080310?00P03A4@010D4P0F6aL02Pl;00`@3@09
3PX05AXF00dB3P80314=0P0=4Ph03@0<4@d02a0900/A1`0;4@L0314900`A2P0=4P/02a0:00lD3P0<
4@d02Pl;014F4P0>4`l00P0A4`h03@0@4Pd03Q0;00`>2@0;3@P03Q0;00lA300@4Pd03a4<00h@2`0;
3@P02@h7010E3P0B5a400P0;40X04`0;40`03a@@00dB3P0;3`h0310?034e=01KGeh03A8>00hC3`0K
7a`041DA014F4P083@T04aPD00H91P0U:RH0DUMC00hB3`0@5A400`0>40/01P0@4Pd04Q@?01@F4@0@
4Pd04A<>00lA30803@l:01d0418=01LI500<3PT06adH00D60`0o@C`05QPC01hP6`0=3`X020X500d?
2P0A4`h051HA01DG4`0<3PX03a4=00T;1`0?4@`04Q@?01LI4`0C5Q004QD>018E3@0@4`/02a0900dE
3`0B6aH02a@?00/A3@0200P>2P0300`A3@0>40d03a4>00<0418?00D05ATH00`@3`031`H0310?00/?
3P0200hB4@0600dA400<40l03A4@00dA400?4a803Q8A0P0<40l00`0>4Q4041@C010D4`0600dA400<
00`@400A5AD051PH01<G5`0E6AX03A4B00X>3`0=4A<02@d@014E600D5a/02Ph@0P0=4A803P0>4Q<0
310A00/?40093@h02`l@00X>3`0=4A801`/<00/?400H71`041@C018F5@0F6QT04ADD0P0>4Q4200`@
3`<03A4@01h03Q8@00`A3@0;40`03A8>00hC3`0;40`04AHB00dB3P0:3`/03A8>00lD400@5A403Q8A
00`@3`0>4Q0020d9014F4P0?4`l04AH@00dB300<4@/03A8;00X?200>4``051TC010D3`0?4`h04AH@
010E3`0;40X200dB300J00X?2@0I7QP05AXD00dB300=4@l03Q<@03Di=P1>Ddl03a@?00hC3@0d>C80
5AXC00dB2P073@@02a47010F3@0730H03Q<=00H;1@0;40X0314;00lD3P0C61802@h800hC3@0B5a48
00dB300300`A2`0=4P`03A8<00803A8<00H0314;00dB3P0?51003A8>00/@300:3`/200/@30803Q<?
00H03A8>00hC3`0?51003a4<01DG4P0B50l200`>2@0:00h@2`0@4Pd03Q0;018D3`0>40/03@l:01DG
4P0F6aL04AHB00P=2@@0314=00H04AHB01<H500:3`/02Pl;010E4@0;40`200`A3@0900dB3P0<4@d0
314=01DJ5P0@5A40724M01@I5@0>4`l03a8>00<03a4<00D0418=014C3P0A4`h0418=00lA3002010B
3@0L00lA300:3`T02a8;00lF3`0=50d03QD>00dD3@0<4``01`h700XA2P0;4P/031<<014H4@0=4`d0
3Q<?01DJ5P0<4@d02@h:01<H500?51003A8>014F4P0?51009R/W00<7100C61@03a@@00hC3`803a@@
01/03A8>00hC3`0L8Ad03a@@00/@300@5A40314=01HL600C6AD051XF04I<B00j@3`0318>014G4`0F
71P04aTE00/A3@0=4`l041HB014F4P0C61@041DA00dB3P0?51003Q<?00dB3P0>4`l00`0?51004P0>
4`l02a0:00hC3@0@5A402@h:02T]:`0I7A`051PG00`?3`0C5aP0310A010D5P0;3a804aPL00lD5`0B
5aX03a@G00dC50803aDE00D02a4@01<I5`0P9R@04aTG00lE4`0Dooooo`006oooool04P0?3`l03@d=
00/;2`0;2`/03@d>00l?4@0K6ad03@d@028Q9P0000@020L<01<B5`0B4Q@04a<C00l?3`0;2`/030`<
010@40804A4A00D02@T900X:2P0=3@d02`/;00h=4@0300h=4P0E00`;4@0;2Q002@P>00h=5@0510`0
2PTA00`:5@0:21<04PlI00/:4P0C4a/02P`A03a1A@0731002a0C00`@4@0;3a003@d?00l=400@4180
4Q<D00804a@F00/0NW]m09RIV`0;30h0414E00h?4`0?41804A8F00d>4P0<3A403@hB00h?5002010A
5@09014B5`0@4AH03a0D00l@5@0@4AH04A8F014B5`0E5ad02@`C008041<J00D04aHM01PK8P0>4AP0
41<J01@G7P02010C6P0801<F7@0A51T03a<D018F6@0D61/04aLJ014E600A51P6014D6@0[018F6@0A
5AT041<H010D5`0?4QH04QDJ00hB5@0=41@04QDJ01@H6`0?4aL04a/M010J6`0@6Qd04Q/R014J8`0;
4al04QXW00`D8@0A6BD02a@M00`E7P0@628041@M01/P9P0R9bd0=3To07AiO`35b]00CU=I028W;@0D
6Al061dS010E6`0B5ad03Q<G01HK7`0?51P06QlS018G6`0H7B406QlS00@93P0200lD6P0;01@I7`0A
5Q`030lF01PK8P0D5ah05APO00X=500J7B@03a8I018E700D5ah00P0B5A`04`0C5Q/02@`A00/?4`09
3A003Q4F01DI7@0@51L03a8G00lC5`0?4aH041<H010D600@51L02PhA01HJ7@0>4Q<020`?00hB5@0B
5QT00`0@51D02`0A5AD04ADF014E5P0I72803Q4H00lB6@0B5A`041<J014D6`0B5A`04A@K00803A0G
00<06QdT02<V;@0H6b@00P0=41T0900<3aH051LN010C6P0R9BX0Wj:W01lS9P0>4QD01@T<01LL7`05
30h051`O00lG6P0G728010PA00L;500B5Ad03`lG014B5`0B4aD04Q@C010C4`0<41402Ph?00lC500B
5QL03A4B00P<3@093@h03A4B00T=3P0?4a@0310A00lC5@0A5AP04QHI010D5`803Q8E0P0?4aH01P0@
51L04ADH010D5`0>4QD02`lA00`@4@8061`M01X041@E00hB4`093@h02`l@00dA4P0<41403A4B010D
5@0G6a`04ADF018F5`0M8B80720Q00`@4@0@51D02Ph?014E5P0H71d041@E00`@4@0?4a@0310A00hB
4`0H71d0720Q01@H6@H03A4B1P0?4a@2010D5@0T01DI6P0;3a004QHG00`@4@0<4A@051TL01<H6`0=
4QD04AHI00`A50000@@051TL010E600A5QT0B4e@00lD5`0;4A403Q@D00dC4`0;4A40318B010F5P0=
4a<04ALG00/A4@0?5AD0318B0826QP0h?S`04QPF00X@3P042PP01`d;018H5P0?5A<03Q@B0P0=4a40
4@0>51803aDC00/A4@0<4Q802Q0@00dC4`0H7Qh02a4A00dC4`0D6QX01@/;00hD500B61P03A<C01HL
6P0C6AL03Q@B00803A<A00D02Q0>00dC4@0>51803aDC010F500200lE4`0300`B400?5A<04ALE0080
2a4?00D04QPF0498AP073@/051XH00lE4`0201@J60804ADD00@06QhM02/_;P0j?Sd05QXI0P0>4Q40
3@0=4A004ADD00dA400;3`h0310?00@81`093@`03A4@00T=300@51<03A4@00T=300;3`h00P0>4Q40
100C5aD08RLS01`Q7@1;D4`2010E4@0300L<200<4@d0314=00<03Q<?00@03Q<<00dC2@0=4`T03A<:
0P0=4P/01P0>4`d05AXD00dB3P042@D05AXF00`A3@803Q0;0P0?4@`02P0>40/03@l:00`>2@0>40/0
4A<>010B3@0>40/02P`700L<1@0;40T200dB300H00lD3P093PX00080018G4`0:3Pd041@C00hB4@0<
40l041DA00@91@0F6aL041DA00<8100=4Ph00PL300lD400320@03A8>00X?2`0320@04A<>010B3@0?
4@`03Q0;0P0?4@`2010B3@0_00lA300>40/03Q0;00h@2`000@00DeE@000100082PD061XE010B3@0E
5a804aD@00P:1@092`H0418=00T;1P051`@02P`900`>2`092`P04aDA00d?2P0/;bP06A`E00T<1@0:
3@@03Q4800`A2P094@/0@DY501LP6`0C6AD00@L300`B3P0:3`/03@l<00h@3@0@4Pl04A<@018D4@0Y
;B`07b<R00X>3@0=4A002Ph=00L;2P0>4Q400P0<40l0100>4Q403A4@00dA400>4Q42010D4`0300hB
4@0<40l0310?00H0310?00`020`;00lC4P0C5aH04QHE01@H6@0@51D061`M01/O8P0A5AP0D5AG05II
GP0A5AP201<G600:00dA4P0C5aP04QHG010D5@0E6AX041@E018F5`0830d0310A01TM7@8041@C00H0
4ADD00`@3`0:3Pd02Ph=00`@3`0>4Q4200lC4P0300hB4@0=4Pl0314=00802a0<0P0<4@d0100:3`/0
1P/700lD400E6QH200dB3P0b00@81`072`X04AHB00H;1`052PH00`H201dR700F6aD041D>00`A2P08
3@H02Q0600hC3@083@L041D?00H;1@0>4`d03A8<00H;1@0A5Q0041D?03<h<P0W;2H01``600@90`0@
5@l02@d:0004000D6A<02a0:00T>200730D05AXC00lD3@0;40T010T300L<1P0>4`d02Pl900lD3P0;
40X03A8<00@90`0;40X01``601DJ500:3`T0314;00/@2P0=4P`300hC3@0400`A2`0:3`T02a0:00`A
2`<03A8<00H02a0<00hC3`0>4`l0314=00dB3P0>4`l200dB3P0@00`A3@0=4Ph04AHB01@I5@0;3@P0
1@L200X<1`0<3PT020X501LI500A4`h03@l:00X<1`092`H0418=01DG4P806b0L00L010T500<71006
2`L01@X600/@300@5A403Q<?00803a@@00D02a0<00X?2`0;40`0314=00hC3`0200lD400806EZIP0C
61@03Q<?00T>2P0G71P030l;00`>2@0=3`X2010B3@0F00lA300A4`h0418=00d?2P0<3PT03Q0;00lA
300B614082LP00/B2`0G7QL02A0900890P0D6a@03aH?018I4P0940T051/D028Y8P0I7aT00PL300lD
40804QLC00@06QlK00P=2@062`L05AXF0P0>4`l00`052PH04aPD00lD400200dB3P0J00hC3`0?5100
1``801`Q7@0J7a/04AHB010E4@0C61@04aTE01DK5`073@T04aTE01LM6@0?5A402@l;00dC3`0@5Q80
3A<?00`B3P0;4@d02@h:00dB3P0?51004QLC01PM6@0K81`3010E4@803a@@01T03Q<?010E3`0D6A<0
3a@@00L<200D6AH00`L600H:2@0>4Q807R8S01XN7`0;3a404aLJ04eBEP1RIfX03a@G00H;3P0?51H0
:c4a09:HV00Z<2l0318@014G5@0?5A<05Q`J01Cooooo000Kooooo`802`/900/030`:00`<300;2``0
2`/=00h=4P0<2a0040lD01HE6`0G5Q`02PT>00d=3`0200X:2P8030`<00P02@T9014A4@0A4A402@T9
00X:2P0=3@d02`/;00h>40803PdB03l03@`A00/:400:2@l03PdE00T74P0=2aH04@lJ00h<6@0S8B`0
3``G00h=5@071`l02P`C00462P000`L02PlB00lC500@51D0410@00l=3P0>3Q002PX<00l@500=3Q80
824U01TJ70061`T04A8D00d>400C5A@07QlQ01/L7P0A4Q@03@h@00h?4`0?41<0414C010A5@0@4A@0
3a0B00l@500@4A@0414C010A5@0?4AL05QTR014D7@0D5b003Q4J00`?600A51d04QDN00hA6P082a@0
3Q4J010C700>4AL03a<F018E6P0D5a`04aHK014E600@51L01@0?4aH0>00B5QT04aLH018F600B5QT0
41@E014E5`0@51L03Q8C00hB500B5QT04aLH010E5P0@6AP03aLI00`D5P0:4AT02a8L00dC7`0@5R@0
3A<Q01@J9P0<4ad03A@N010G8@0L82T05ATR01<G800G6b@0;c<l05QLI@0T:3406QhW01LK900:3QL0
51PQ01PL9@0;41H051TO00X?5@0@5A/05AXP01@I7`0B5a/05Q/O00`A5@0>4aL05a`P00dB5P0I7240
3A0E014D6@031P/041<H01PK800=41D04A@I0`0C5Q/05`0E61d0310C01XN800B5QL0720S03@h>P0V
:R/04aLJ018F600A5AH041@G00lC5@0>4Q<03a<D00X>3`0>4Q403a<D00`@4@0C5aP03a<D00lC5P0@
51L04ADG00804ADH00@071lW00lB6`0@4a`04aHO0P0A51d0;@0B5Ah04A@M00d@6@0>4AX06ahW02@W
<0092aL03Q4J018E7P0<3aP04aHM00P;4P031P/06QhQ0001100A5AL051PI00H;3P0A5a`01PdE0089
4@0F6RD041@O01dQ;00=41X03PhF010A5@0F5aT061XI01@G5`0;3a002@d>00lC500A5AH03A4B00X>
3`011@H05QXK018F5`0E6AX041@E00lC5@0B5QT04aLJ014E600200lC5P04010D5`0>4QD03Q8E00dA
50802`lB00@04ADG00020`000@803A4B0P0?4a@02@0=4A804QHG014E5P0>4Q<02Ph?00dA4P0A5AH0
3a<D00dA4P02010D5@0=00P<3@0B5QL02`l@00lC500D61T03A4B00hB4`0A5AH041@E014E5P0?4a@0
2`l@00T=3P0600dA4P@03a<D0P0@51D08P093@h02Ph?01<G60093@h041@E00lC500;41<041DH00X?
4P0>4aH041DH01<H6`0D6A`020d@00T>4@052Pd03Q<F01PM800;4A403aDE00hD500;4A40318B014G
5`001PH02a4A00020P083Ph02Q0@02/a<@0M8b4020h<018H5P0?5A<200X@3P803A<A0P0<4Q0200dC
4@0E00/A4@0B61P01`d=01`R8P0]<c<04ALG00/A4@0D6QX02Q0@00/A4@0=4a<0318B00`B400>5180
2Q0>00`B400@5Q@03A<A00`B400=4a403Q@B00<03aDC01d02a4?01TO7@0L8R003A<A00H<2P0<4Q00
5adK00dC4@0C6AL01@X800X@3P0>518041<B00T=30000P4061`K00/?3P0:3Pd04ADD00`@3`0:3Pd0
310?00L;2P0830/02@d<00L;2P0A5A@03Q8A00D9200200`@3`0;00P<2`0;3`h03Q8A00dA400=4@l0
4aPD00P=2@0g?3P020d9018G4`0=4Ph00P0<4@d0100=4Ph03Q<?00lD400?50d200hD2P0<00dC2P0=
4P/03A8;00`A2P0B5a403a@@00@91@0@5A402Pl;00/=200<3PT03Q0;0`0?4@`07P092`H02P`700d?
2P0?4@`03Q0;00d?2P083@H02Pl800/@2P0=4P`03a@>00T>2P0P9B403a@@00hB4@031`H051PG00/>
3@0=4Ph020d900T>2P052PH000D100lD40062`L04AHB00dB3P0E6QH020d900lD4080418=0`0>40/0
0`0?4@`03Q0;00h@2`0200h@2`0Q00d?2P0<3PT04A<>018D3`0>40/0418=00X;200C5A002`d801@F
4@0>40/0418=01TK5P0B50l03@l<02<U90041PD04A<@018D400;3@P0:B`U01LJ4P072P4020/200`?
1@0;4@L031@>02L`:`012PD0=cdi00`B3P0@5Q802a0<00803@l<0`0>40d201@H5`0;00D9200=4A00
3Q8A00/?3P0=4A002`l>00`@3`0?4a803A4@00/?3P0=4A000P0A5A@00`0>4Q403A4@00hB4@0600`@
3`0<00/@300=4Ph03a<A00hB4@0A5AH03Q8D00hB5@0A5AP01PX>030c>00e>3d020`?0P0D61T00`0?
4a@05ATJ01@H6@0200dA4P0900P<3@0=4A802`l@00T=3P0A5AD03A4@00hB4@0=4A00310?00802Ph=
00H03A4@00lC4P0A5A@041@C00lC4P0=4Pl200`A3@802a0<00<03A8>00`A3@0:3`/00P0C61@0:@0:
3`/041DA02@Y9@0;40`0314=018G4@0@5@l04AH@00hC300:3`P020d600T?1@083P@03Q@:00X?2@0A
5Q0061dG0046000=4P`03a@>00`A2`0C61800`P201/P6P0E6Q@02Pl9010E3`0320404aPB01PM5P0D
6A802Pl901<H4P0=4P`04AH@00T>200<4@`02a0:01<H4P0:3`T000D000802@h800L03Q<=00<80P0G
71H02@h8014F400;40X01``60080314;0P0:3`T01@0<4@/03A8<00X?2@0;40X0314;00<03A8<00<0
2a0<00hC3`0>4`l00P0=4Ph00`0?51003A8>00dB3P0200`A3@04014F4P0E6QH07b4L00`>2@803Q0;
01405aTD00lA300@4Pd05ALB00`>2@0>40/051HA00h@2`1_M700P8F101DJ5P0G71P01P/701HK5`0<
4@d041DA00hC3`02014F4P0X00`A3@0>4`l02a0<00X?2`0=4Ph04AHB01<H500A5Q8041DA01lT8006
2`L03a@@00d@300>40/03a4<010B3@0>40/030h9010B3@0E5a804aD@00h@2`0?4@`061XE010F3`0D
7QH02Q@<00@>1P0c?CD0BeE=018L500C7AD07BLO00lI4@0A6a<07bTQ01XP6P0;40`03A8>01<H5080
5AXF00D0314=00T>2P0B5a<03A8>01<H500200lD4007010E4@0?51003Q<?00lD400B5a<03Q<?014F
4P0200dB3P0E00`A3@0/<Bd03Q@@01HL600?5A402Q0<00/A3@0<4Ph02a4=00lE4@0G7AT061hJ01<I
5@0=4`l04AHB01<H500@5A403Q<?014F4P0@5A404AHB008041DA00<03a@@00hC3`0>4`l00P093PP0
0`0<4@d041DA00`@3P0200H:2@0A010D500=4A801`/<01PL7P031`X0?T=705]PH`0?51L02@hA01@J
6`0b>3P0aL_;03Pn?@093`d05Q`J014G5@093`d05?ooool001_ooooo00l030`900/<2@0;2`T02`/;
00/;300<30h01`L;00h=4P071P`030/A00`<4P0@3aD02`/=00X:2P0<30`00P0?3`l0200:2PX03Ph>
010@400;2`/03@d=00h>3P0;2`/03Ph@0`0>3A8200`;4@0L00`;4`0?3AP06QPS00l=6@10?T/0ZZRe
01PE800@3aL02`/C01<E70000`L04aPL00T>4@0@51D04ADF018B4P0?3@h03Ph@00X:3`0@4AH020T>
014B5P041@L07b0R01@F5@0?4A00418@01<E4P803Q0>00H04A<C010B4P0?4A403@h?00`=3P0>3a03
00lA4@80414B00H03Q0E01XM9P051a003Q4J010C700?4Q/300hA6P0:010C700B5Ah03a8K00hA6@0?
4QP041<I014D6P0A51T04ADH010D5`8041@E05/041@D010D4P0@51@04QHF010D500B5QH04aLG014E
5@0B5QH03A4A010D500C5aL04QHF010D500B5QH04ALF01HN700F7Ah03aDK010E7P0@5R003a@Q00hC
800C62@03Q<N01<I8`0D6B<051PQ00dA6P0E6B806AdV01XN9`0G6b@061`U018F7`0@51d05QXS01PL
9@0B5Ql051PR01LK9@0_<c`04QHO01LL8`0D6Al02PlC014F6P0C61/02@hB01TN800E6a`04A@H01XN
8P0>4QH0=cXn01HI7@0E61`04QDI01<G6`0B5QX041@H018E6@0D61/041@E01DI6@093@d02`l?01DI
6@0;3`l05ATI01@H600A5AD03a<C00dA4@0;3`h04AHC00dB3P0F6QP05a`I00lC4P0@51@03Q8C00hB
5@0?4aH041@H014E6@0A51X06A`T00lB6`0@4a`04A@M00803a8K04003Q4J01<F7`0D5b004QDN010C
700A51d03a4M00lB700=41X06A`U05AGGP1MH6L04aHK014E600F6Qd020`=00dA4P083A00314J00hE
800<4Ql07b8b01dP<00>4B006Q`Y01PH8P0?41@03a4@010B3`0?4Q003A4B00`@4@0>4Q<03a<D00hB
4`0@51D02`l@00lC500E6AX041@E00hB4`0>4Q@03a<F010D5`0>4QD0310C00dA500>4QD03a<F010D
5`0?4aH03Q8E014E600n@T@09b//00L92P0C5aP0310A00T=3P0>4Q<05a/L014E5P0=4A802`l@0P0=
4A800`0?4a@03Q8C00hB4`0201<G600<00/?400>4Q<03a<D00/?400:3Pl03a<D00`@4@0>4Q<051PI
010D5@0=4A806AdN0`0>4Q<200dA4P0300`@4@0>4Q<03Q8C00803a<D0P0@51D0500E6AX02`l@00lC
500?4a@05ATJ00dA4P0A5QT04AHJ03Ll@00;41@051TM00hC5`0E6Qd0:2d`00/@500?51P03Q<F00hA
500@5QH03aDE0`0=4a<03P0>51@041HF00hD500D6QX03Q@D010F5P0:3Ph04QPF00X@3P0A5aD03A<A
00hD4P0;4@l0318@100=4a405`0<4Q0020h>00dB50062`d05adN02T_<00C61X02a4B00T?400E6a`0
4QPI00/A4P0<4Q804QPF01/Q7`0B61H0318@00dC4@0:40h0318@00dC4@0>51803A<A0080318@00D0
3A<A01PN700L8R0041HD00P>300200`B400Y014E4`0T:RP06R0N00hD4P083P`03Q4@00`@3`0B5QD0
CE5@01@H5`0:3Pd04QHE00L;2P0H71/05a/J00D9200=4A003a<B01<G5P0T:2L06AdL00T=300<40l0
2`l>00`@3`0=4A00310?00/?3P093@/04AHB00/@300A5Q80314=018G4`0;40`03A8>00`A3@0;40`0
314=00dB3P0>4``00P0>50X02`0=4`X03A8;00`A2P0<4@/02a0:00/@300:3`/02a0<00hC3`0<3PT0
3@l:00@03a4<01h02P`700/=200<3PT03@l:00h@2`0?4@`02Pl800dB2`0;40X02Pl900dB300<4@d0
1PX702L/:00@51<03A4@00/?3P0<40l01P/701@I5@083@T05Q/G010E4@0<4@d00PD2014F4P0:3P/0
41@@00/@300:3`/200`>2@0500d?2P0>40/04A<>018D3`0?4@`00P0>40/08P0?4@`03Q0;00X<1`0B
50l03Q0<018D3`0=3`X04aD@014C3P0>40/04Q@?00d?2P0;3@P04A<>01@F4@0U9bH0;Bl^00X<2`0D
5Q<03Q0<010B3@0A50d03a8:00hA200?4PT03a8800X@1P094@/03aDA03Ho>P1DFUH04ALC00L=2@0=
4Ph200h@3@0E00d?300<3P/030h;00dA400@51<02Ph=00hB4@0;3`h03a<B00hB4@0;3`h0310?014E
500=4A002Ph=00/?3P0@51<03a<B00/?3P0<40l03Q8A00H03A4@0P0>4`l01@0=4Pl03A4@014E5P0@
51H03A4D00804QHJ00D020/@00hA5`0>4QH03A4B00hB4`0200lC500400hB4`0D61T092PY01hR8`80
4ADF00D02`l@00/?3`0?4a8041@C00`@3`0200hB4@0400`@3`0=4A003A4@00hB4@803a<B00L03A4?
00`A3@0>4`l03A8>00/@300=4Ph02a0<00802Pl;03D03A8>00lD400?5100C55=01hS7`0:3PX04AH@
010E3`0:3`T051TB00lD3@0>50/0318800T?1@0;4@L03A8<00T>200<4@/04AH@00hC3@0?50h02Pl9
00dB300;40X04aPB00dB30093PP041D=00lE2P0=4`X02a0800hC2`0=4P`03Q<=00/@2`0A5Q403A4?
018G500=4@l02Pl:00lD3P0G71H08BHP014F400:3`T04aPB00`A2`093PP02a0:00hC3@0?50h03Q<=
00dB300200/@2P802Pl900<0314;00dB300=4P`00P0=4P`0100<4@/03A8>010E4@0?510200dB3P03
00lD400=4Ph03A8>0080314=01<03a@@018G4`0X:RD06adH00X<1`0?4@`05aTD00X;200>40/03a4<
010B3@0>40/03@l:00lA300f>cL0>Chj018G4`0:3`/04aPD00803a@@01403A8>00hC3`0<4@d02a0<
010E4@0A5Q80314=00X?2`0=4Ph04QLC01@I5@0H7AT02@d:00/@300=4Ph04QLC00lB3P02014C3P0:
010B3@0=3`X02`d800`>2@0>40/03a4<00`>2@0?4@`061XE01LM5`802aD=01P051hF09nYX@3?fM40
6B<K00lI4@0M9al0628J00/E3@0>61002a<=018G4`0>4`l041DA00/@300730P051TE018G4`0@5A40
51TE014F4P0?51003A8>00lD400A5Q8200lD400=018G4`0>4`l03a@@010E4@0D6AD02Pl;01HK5`0A
5a<02a4=00`B3P0>51004ALC00lE4@0200dC3`0=01DK5`0H7QX04ALC00/A3@0=4Ph041DA00dB3P0:
3`/03A8>00`A3@0A5Q8041DA00lD400200dB3P0E00hC3`0=4P`041D?00lD400I7QX03Q8@00hB4@0@
51<04ADE05YNG`0L82402`h@01TM800=4AD041DI01LL7`0@5AP03A8C00lE5@0P9RH04aTH00803Q@B
00<03A<A03@j>?ooool04oooool001_ooooo01X04Q8@00d=300820P020P800d=3`0B4Q@03@`A00<2
200K6R000`8800P73@0D4aT030`>00l?400>3Ph02PX<00/;300A4A402PX<00l?400<30`03Ph?00l?
4@0;2`d03@d?00d<4@803PdB03003@`B00`;4@092@l02PTA00<22P081Q4030XE03Hd?`0B4AP01PD;
01LH7@0520d05APM00462P0;3a80310C00h?4`0=3@l03`d@00l>4`0=3A@020T>01TJ7`0@4AH01@H:
01TJ7P0A4Q@05ALF01<E500<3P`03Q0?010B4@0>40l03PlA00h@400>40l03PlA00l@4@0?4A003a0B
00lA4@0?4A003a0B014C5P082a805aXQ04E8C`0<3aH2014D6`803Q4H00X04A@K00/>5@0<3aH04A@L
00hA6P0>4AP03Q4G00lB5`0@4aP04ADI0P0A5AP4014E5P0E00`@4@0@51D04aLH00lC4P0B5QD02`l>
018F5@0G71P04AHB00hC3`0D6AD04ALE01LM6`0E6a/041DH01<H700C5al04QHO010D7@0F6R<051PQ
00807R<Y00`04AHL01<H7P0>4QX020`E01HK8@0B5ah03a<L024V;00?4a/04QHO01XO9@0A5Ah201PL
9@0/05YNIP0H7B<02a0E00dB5P0J7b804AHI00X@400L8R8010T901LK700D61/01`P<01HJ7@0_<c@0
;S8c01TM7P0H71d05QXK014E5P0>4QD0414E01<D600C5aP01`/;014E500B5QL0310@01XN7@0;3a00
310@00dA400?4a@041@D014E500D61L06b0L00`@3`062PT041@F014E600=41D03Q4F00hA600@4aX2
014D6`1Q01LJ8P0C4ad04QDN014D7@0?4Q/04A@M010C700>4AX03a<N01@G8P0E6B@051PQ00`?5`0N
8BP06QdT00d@5`0a=3/0;S4f00d@5@072Pl051PK010D5`0830l03Q4F00H;5@0K7bX020`H020T<@0h
>dX02@dI01@G8P0F5Qh03PlC018D4`0E5a@04QDD00lC500?4aH03A4C00`@4@0?4aH02`lA01PL7@01
1@P041@F010D5@0:3Q403Q8E00lC5P0@51L03Q8E00`@4`0=4A@02`lB00`@4`0?4aH03A4D00X>4@0;
3a803Q8D01HJ6`0I7Ah02@d>018F5`0F6Q/02`l@01PL7@0<41403A4B01@H6@0F6Q/020`?00/?4P09
3A003A4D01@H6@0?4a@01`/<01DI6P0G6a`02`l@00hB4@0C5aL04QHG010D4`0@51@02`l@00H:2@0A
5AD03Q8C00hB4@0>4Q803A4B00`@3`0<4100310A00dA4P0200hB4`803a<F01D020`?00T=400D61X0
20`=00X>3`0A5QL03A8E03<k?@2PZ:X03ADH00lG6@032`d010T=00lD60001@P061dQ010E6@093Q40
51XJ00hD500<4Q800P0>51@03`0:410061hN04mEE@052`/06R0P010F5P0=4a<02Q0>00dC4@0?5A<0
20h<014G5@0<4Q003A<A00hD4P0200lE4`0C00hD4P0=4a4051XJ00`B4`0@5QH01``>00hC5P0@5QH0
4AHH0005200S:BT09BX/01DJ7@0B61P02@l=01`R800C6AL02a4?00dC4@0400`B400700XA3`093`d0
1Pl<00`B40052`T02@l=00dC400200`A3@0601@I5@000P006QhM00/@3`093`d04aTG0P0>4Q402@07
2`X010P700/?3P0@51<03a<B00dA4010A4<0=c/j00P<2`0200`@3`0600D9200A51<02`l>00D9200<
40l02Ph=0P0?4a803`0:3Pd02@d<00dA3`0320@02a0<00lD400:3`/00PL300hC3`0=4Ph02a0<00X?
2`093PX02Pl;00`B2P0200dC2@0900`B2@0;40T02a0901HK5@0A5Q802@h:01<H500;40`041D@00<0
418=02<03Q0;00d?2P0;3@P04A<>00lA300=3`X02`d800d?2P0@4Pd03A8;010E3P0<4@/01``600X?
2@0=4Ph051TE00T>2P0:3`/041@C0002000?514020d900/@300E6QH0EU]G00hC3`0<4@d02a0<00lD
40052@D05a`H014F4P0<4@d0418=00lA300200d?2P803Q0;00T04A<>00lA300?4@`04Q@?010B3@0:
30L04Q@?00h@2`0@4Pd00P0A4`h00`0B50l04aD@010B3@0200h@2`0801/M600];bX03a4>00@50`0K
7AX051D@00`>2@0>40/200lB2`0;00/>1@0:3@H03A07010F300=5@l05A/G00P>2P093`/020h:00`B
3P0=4Ph01@0?4@h04@0@51<03Q8A00hB4@0>4Q402Ph=01HJ6@0>4Q402Ph=00`@3`0A5A@03A4@00P<
2`0>4Q404QHE010D4`093@`02`l>00L03Q8A00l02@h:00`A3@0=4Pl0310?010D5@0:3Pl05ATL00dA
500830l06QhQ00lB5`072`h020`=00T=3P0A5AH00P0;3a001`0:3Pl0720Q01XN7`031`P03A4B00lC
500<41000P0@51<02`0:3Pd03A4@00`@3`093@`02`l>00X>3@093@`02`l>00`@3`0;3`d02a0<0080
3a@@0P0;40`03P083@T0314=01@I5@0U:RH0:c0/014F4P0>4`l03A8>01DJ5P083@L01``600dB300@
5@l0314:0P0>4``0;00;40T0314:00X?2@0K81X041D?018G4@0?50h02a0:01HK5@0:3`T02a0:00L<
1P0:3`T051TC00lD3@0=4`T041H<01LL5@001@002a09018G4@093PP020d900D:1P0?51402@d<00/A
3@083PX01@`500/B2`0<4``07RDM051GD00B6A8061lH018I4P093`/041HB00dB3P0@5A004QLA010E
4@0:3`T01@X40`0=4P`01P0<4@/02a0:00X?2@0>4`d041D?00lD3P803A8>02403Q<?00`A3@0=4Ph0
314=00X?300;3`h03A8>010B3P0=3`X04A<>01HH4`021000<S@_02DW8P082PD04aD@00`>2@0E5a80
=SPc018G4`0?5100314=00dB3P093PX03Q<?00`A30093PP041D?00`A2`0>4`d07B8L014F4P0?5100
0P0>4`l08P0?510041DA010E4@0A5Q802Pl;014F4P0;40`03A0<014C3P0@4Pd03a4<00h@2`0=3`X0
418=014C3P0?4@`0418=014C3P0?4@`020h701<M5@042`@04Q/C00LA2@0Z<BX0624I00H@200;4P/0
4ATB00TC2`0?5Pl03aH@00hC3`0A5Q8202`a;@0A01PM6@0=4Ph03a@@01LL600_=3003A8>00H;1`0?
51003A8>014F4P0?51003A8>00lD400:3`/04QLC00/@300@5A400P0B5a<0400A5a<0318>01LM6@0=
4`l01P`800hD400@5Q80318>00lE4@0A5a<02a4=00T?2`0?51004AHB00lD400=4Ph2010E4@03014F
4P0@5A403A8>00802a0<01T0314=00/@2P0K81X02Pl;010E4@0A5Q<0310?018F5@0>4Q808RHW00D9
2P0E6A/01@T<00@93@0D6Ad04AHI00/@4`0J7b406b4Q00/A4@0A5aH01@/901XP7P0<51404AXG01Co
oooo000Kooooo`0J00L72@0:2P`030`>00h>400510T05QDJ00T83@071P/0000400T83@0B4AH00P46
018A5P0<2`l03`lA00d<4@081`/04Q8D018A5P0:2Pd03Ph@00`<3`0:2@h040lD00d<4@0?3Q<4010?
508040lE01403PdC00/:400;2Q002``@00T;3@0>4Q<02`l@00T=400;3a800@D800d>4`0;314030/A
00l>5P0@3aL03`hF00`<500200h>5P1C00l?5P0<3A802``A01HG700:2a003PlD00l@500;31404A8F
01<D5P082@d030d@02DV:00H6Ad03PlB00d>400=3Q803PlB00l@4P0?41@04A<G00P<3`0F6Qd0<3@g
00`@4`0010L05ATL00041`0:3Q4061`O00/?4P0>4QD05APN00X=500C5Qd04A@K01@G7P0N8BP04A@L
014D7@0B5Ah05APQ01<F7`0@4a`05APO00852P0D5a`051PK01<G600B5QH03a<B01HK5`0B5a405a`E
01PM5P0<4PT04ALC00`B400:40h03aDE018H600?51H0:c0c01XO8P0:3a8061dP00P>3P0H7Al04QLK
01@I7@0A5Q/04AHL01DJ7P0B5a`04QLM018G6`0A5Q/03Q<I00hC5`0@5AX03A4D010D5`0E6A/00P0I
7Ah0;`0G6a`0EUYK01@H6@0=4A003Q8A018F5@0010D05aHK01DD6@0>3a405aTH024V8P0F7AH04APA
010E4@0@4Q40414C014@5@0?3Q<0414E02DY:`1=DE80720S018F600D61T04QHI01@H6P0A5AH04aLJ
01PL7P0E6A`00`L:018E6009314082<Z00lB70092aL03Q0L00L95@0O8Bd02@XF01DG8`0]<3T06ATP
01TH800D51`04Q8J00804QDN00T04ADP00hB7@0N930020dI03ToB`0?5R005AXL00L;30072`h00P0@
51L09@0<3a@04A@I00hA5P0@4aX03Q4H00d@5`0@4aX05ATN01HI7P062@h02`hC01HI7P0?4QL041<G
00T=400E6A/00PH7014E500=4A<03A4D014D6@0>4QH051PK00852P0;3a<03A4D00lB5`0@51P03a<F
00d@5@0=4A@020`=00`@4@0E6AX0004201@H6@0A5AH00P0@51D2014E5P03010D5@0B5QL041@E0080
41@E02D01`/<01/O800N8R<05QXK00lC500=4A80310A01PL7P0:3A803Q4H01PK800@4aP03a<F00/?
4P093@h04ADF00lC4P0:3Pd041DA00lC4@0@4Q403a4>00lA3`0>40l03a4>010B400C5A@01@L400lA
3`0F61L04Q@A00lC400>4Q4041HD018H600E6Qd03a@H00803A8H01l041DK010E6@0<4Q803A<C01DK
6@0:51<05AlO01XT8`0D7Ql02aDE00TC4P0;4aD05AdN00L@3`063Q004API00D;2`0;4A404aTG00lE
4`083P`02a4?00lE4`0A5aD07bDS00X@3P0;4@l03aDC00D;2@0;4@l03Q@B00802Q0>00@03Q@B00/A
3`0D6QP03A<A0P093`d03P0:40h03A<A00L=2`0>51<02Q0>00X@3`0?5AD04ALE00hD4`0A5aL03Q@B
014G5P0B61P0318@0P0=4Ph05P0B5a<03a@@014G5@0?5A<02A8?01<L6`0=5QD01Pl>00TB4@084Q40
31DD00050P0?5A<020`700`>2@0I6aH0414<00lA300?4@h041<B00dA4P0?4a@600dA400601LK6P08
30/0=SXi01dQ800010<03A4?0`0=4Ph00`0<4@d03Q<?00hC3`0200`A3@0L00lD400@5A404AHB018G
4`083@T04aPD00X?2`0320@04AHB00`A3@0:3`/0314=00X?2`0M8Qh0?dA000H<10093`<0318800lD
300>4`d03A8<00X?2`0M8Qh020d900P=1`0D6A<04AH@00H;10804aPA00D02@h700hC300=4P/02a09
00`A2P0200hC300400`A2P0:3`P02a0:00`A2`803A8<0P0<4@/020062`D04QLA00T>200>4`l02Pl9
00dB3P093PX02Pl;0P0<4@d01@0:3`/01``800hC3`0>4`l03a8?00<02a0<02X02@h800hC3@0C6180
3Q<=00T>200@5@l020d700hC3@0?50h02Pl900`A2`0C61806b0J00hC3@0E6Q@02a0:014F401HGEL0
SY>=02DZ900E6Q@0314;014F400B50l05aPB00X:1`0H6A<08R4L00d>200F5a402Pd600`?200>4@X0
3a4<00dA2P0;40T02Q0900D:10093PP041D?00`A2`083@L200T>200700X?2@0?50h04aPB01DJ5P0<
40l03A4@00/?3P02010D4`0900X>3@0<40l03Q8A00X>3@0<40l03Q8A00T=300830/02Ph=00802`l>
00D02Ph=00T=300>4Q403a<B00hB4@0200`@3`0Q00dA400?4a801`/:00`@3`0?4a801PX900`@3`0>
4Q<05a/L010D5@0?4a@04ADF00P<3@0A5AH04QHG00/?400=4A803Q8C00T=3P0@51D00042018F5`09
3@h02`l@00/?3`0<40l03Q8A00lC4P0>4Q40310?00X>3@0;3`h03A4@00804ADD00@041@C00lC4P0>
4Q403A4@0P0>4Q402P0;3`h03a<B00030P0>4Q40DEED06mcLP0B5QD02@h:00X?2`0<4@d300dB3P0<
00hC3`0>4`d03Q<=00hC3@0=4P`02a0:00X?2`0=4Ph041DA00dB3P0;40`03A8>0P0:3`/300`A3@0V
00/@300=50d06B0I00<:0`0[<R/051/D00`C300:4@T02a8:00dD30001`0041L?00hE3P084@h01a0>
00L@2`084PX02A<:00LA1P0D7QD02A<;01<M5@0740/02a@B01XS8P0U:bT010P601DK5`0<4Q0041HB
00@:1P083PX02A0:00/B2`0=50d041L?014H400<4@X200hC300R00dB300:3`T020d700P=2@0;40d0
3Q8A00dA4@0:3Pl020`=00lD40083@T03A8>00`A3@0:3`/0:BhZ020U8@052PH07R<O024V8P0<4@d0
51TE010D4`0C5aH06AdL00870`0M8Q`010T300hC300=4P/03a@=018G400=4`T02@h700hC3@802a0:
00@0314;00lD3P0A5Q004AH@0P0;40X00`0?50h03Q<=00dB300600dB3080314;01X03A8<00lD3P0A
5Q0041D?00/B2`0=4P`03aD?010G400B5a4041H@00hE3P0?50h03Q@>00`C300<4@/03A<>00/A3@09
3`/03Q@@018H500?5A402Q0<00D;1`0O9B406AlK01@J5P803aDA00L03a@@00`A3@0<4@d03A8>00`A
3@0A5Q8041DA00<03Q<?00d02a0<010E3`0F6aD06AhH01PM5`0C6180314;018G4@0>4`d03a@>01@I
4`0F6aD07R<M00803a@@0P0@5A401P0A5Q804QLC01<H50000`002a0<01/P7080314=00D02A0901`S
700>51000`T500/A3P0200hD4P0A010F5@0J820041HF00/A4P0B5aX03a8G01@G6`0@51L041DH01PM
7`0J82004AXI00`E4`094Pl02a@A00XD400540`05?ooool001_ooooo00<03`hC00`;400:2@h00P0?
3Q<01`0>3A802`X?024P9@0I61d02`X?00X93P0>3A800P0:2@h0300;2Pl030/@00h=4P0=31402`X?
014@5@0:2@h030/@010?500<2a003@`A00h=4P803`hC00<03PdB00d<4@0;2Pl00`0<2a002@0>3A80
3a0C02P];@0<41005a/K00d@4P0;310030dA00d>4`0200`;4P0600l>5@0?3QL03`hE00`<4`0>3aD0
4A4H0P0C51X03P0D51/04a@J00/;4P0>3QD0410G00d=500?41@030dA01`M8@0H6Ad0<34e00l@500@
4AD03a0D0P0@4AD2014B5P0400hA4`0<41403A4B010D5@<03a<D00X01`/<00lC500<41405a/L010D
5@0F6Qh02PdC00lB600F6Al03Q4G0P0E62005P0B51l04A@N010B7P0@4Ql04aDR01@F8P0H6bD03a8L
01<F7@0E61l04QDJ014D5`0=4A803A8@018G500=4Ph04aPD00hD4@0?5A@05Q`K01dS8P0K8B0200lE
500=01HL6`0?5A@02`l>01HL6`0=4a804aTJ01@J6`0@5AP03a@H01@J6`0C61/03a@H010F5`02014F
6@0O018G6@0D6A`05a/L01DI6@0B5QH041@D018F5P0D61P05ATI00/?3`0B5QH02Ph>014E5@0B4aD0
6APN010>500C4aD04Q@C00`B3@0A614051/E014F4P0E5aH071`N01/I7`0@3aD051DI00dA500P92L0
3a<F010D5`02014E600B01<G6P0>4QD03Q8E014E600=4A@051PL01LJ8018Be80EUQT00d?700E5bD0
4A<R00H85`0C5B@04A<P00d?6`0>4AX05QDL0P0E51/0<`0C4a/04A@M014D7@0@51l05adY01HJ9P0S
:CL0YJfj07b3S@0L82804QHF010D500@51H03A4D00T=400A51P03Q4G010C6@0?4QP03A0H010C6@0?
4aD03A4B01<G600<41403Q8C01`P8@0=4A802Ph?00/?400@51D02Ph?00dA4`0<41@04QHJ00/?4`0F
6Qh030lC00hB5P0=4AD03a<G010D600?4aL03A4E00lC5@0T:2T07B4R00dA4P0@51D02Ph?00lC5002
00dA4P0700hB4`0=4A803A4B00lC500;3a007B4R010D5@0200`@4@0[01HJ6`0B5QL02`l@010D5@0A
5AH03Q8D00lB600I7280FemT01/N8P093A404QHI014E5P0?4a@03A4A00lC4P0A5A<04AHC00hC400=
4a003A8?00hA3`0=4Pl03a<@010C4@0>51403Q<@00/>300E6aP03A4?00X@3@0B61H03Q@D00L:3P0E
6Qh0Ad]D00X>5`0<4AL03A8G00T>4@0:410041PE00dG5P02014M6`0@00/G5@0951<02aDD02hg=P0F
7ah04AXI014I600:410041HF01<I5`073@/04aTG00dC4@0>5180318@00dC4@802@l=00D06R0N03Hl
>P0A5aD02a4?00hD4P0200X@3P0=00hD4P0;4@l03aDC00`B40093`d02Q0>00dC4@0?5A<020h<00`B
400>518051XH014G5@0200X@3P0M00hD4P0;4@l02a4?00dC4@0<4Ph041D@014F4P0<4@d041DA00lE
4`0=4a403AHC00<<2`084A006B<R01<M7P033@h02aHE00/E500;51403Q<?010B3@0;3@L03a0;00/;
20092`T03A0@01HJ700;41001P0<40l01`052@P02@d<014E50031`H05QXI00X>300=4Ph00P0?5100
0`0=4Ph03a@@00hC3`0200/@300Q00`A3@0=4Ph03A8>00dB3P0;40`05Q/G02H[9`0@5A401``800hC
3`0;40`02Pl;00`A3@0F6aL0;34]00`A200:4080318800lD300>4`d03A8>02lc<@1fNWT04aPD01<H
4P072PH03a@=010E3P0I7QP05a`F00dB2`0?50h03Q<<00803A8<00<03A8;00`A2P0<4@X00P0;40X0
0`0<4@/03A8<00dB300200`A2`0900dB300;40X03A8<00hC3@0A5Q002`l:00dB3P0<4@d02Pl;0080
2@h:00P02a0<00P;200B5a<03A8>00/>2`0A5Q803a@@00hC3@801``601d04aPB01`Q6`0B5a4041D?
00`A2`093PP02Pl900hC3@0A5Q00EeaF010D400@5@l02@h801PM5`2FViD0b/o902/`:P0G71H07B8L
00dB300<40X0418<00h@2@092`L03Q0:010B30051`<03Q0:00lA3002010B3@0500lB3@0=40/02a0:
00/@2P0<4@/00`0>4`d02`0=4P`03a@>01<H4P0F6aD03Q<=00L<1P0A5A@041@C00/?3P0<40l03a<B
00803A4@00L03a<B00`@3`0>4Q403Q8A00/?3P0>4Q403a<B008041@C0P0?4a8200hB4@0F00dA400:
3Pd02Ph=00/?3P0<40l09BTX03Di>00D61L041@C00hA400:3Pd01`/:00dA400:3Pd0310?00dA4@0?
4a@041@E00`@4@0=4A803a<D00X>3`804ADF00P0310A00H92P0E6AX02`l?00hB4@0=4A00310?00dA
40<03Q8A100=4A00300>4Q403A4@00`@3`0>4Q403a<B00`@3`0;3`h05QXI00dA400F6QT07R8Q00hB
4@803A8>00<03Q<?00dB3P0<4@d00`0;40`02P0<4@d02a0<00/@300;40`02@h:00`A3@0>4`l03A8>
00/@300=4Ph200/@30<0314=02D02a0<00`B3P083PX0=C/g0:>YY@0M8al041L@00H=1@0A61003QD=
00`D2@0<50X02a8:00XC400;5A<02aD?00TC3@0950/02QD:00TD2@0=5Pd02Q<;00dG4`0=5Q@0R96@
05eSH@0E6aT03A<A00lE4`0L8Ql03Q@@00lE4@0>50l031<<00/B2`0940T020l7008041D=02@03Q<<
00dB300=4P/0314;00/@300<40h03A4@00dA4P0;3a402`l@00dA3`0C61@01`/702db;P1>Ddl03Q<?
014F4P0<4@d03Q<?014F4P0>4`l02a0<00lC4P0>4Q402@d<02``;00<4@/02a0:010E3P0>50X03aD;
018H3P0A5`/03aD;00dB2`0>4`d200lD3P80314;0P0?50h200hC3@L03A8<0P0?50h0100>4`d03A8<
00dB300>4`d200lD3PH03Q<=0P0?50h200hC3@0@00hC3P0;4@d02Q0<00lE4@0B61@03Q@@00`B3P09
3`/0:Bl[01TO6`0<4Ph03Q@@00lE4@0?5100314=00lD40804AHB00`051TE018G4`0@5A403a@@010E
4@0?51004AH@02<X8P0C618020d701DJ500<4@/200/@2P0501DJ500H7AL04QLA00dB300<4@d00`0=
4Ph300hC3`0301HK5`0=4Ph03A8>00804AHB01P06B0I00hE3P0A5a<01P`800lE4P0D6QP0@DM5014F
5@0A5aL03Q@D00lD5P0B5aX03A8F010F6@0;4A@02A0B00lE5`0A5aL041LG00`C4P094@h02a8@00`E
4@0:510Dooooo`006oooool02@0<2a0010<801<B5`0:2@h00`8701@C600A41D061LL01<B5`0200h=
4P0=00T83@0?3Q<05QDJ00X93P061@X030/@00T83@081``030/@00h=4P0B4AH03@`A00D42@0300d<
4@0300`;400:2@h02PT>00803`hC00/03PdB00`;400=31403@hB00L<3@0@51L0004403a0@`1ZJfl0
4Q<G00`=4@0200/:400E00h=4`0?3Q@03PdC00l@5@0A4QL04a@I01HG700H6Ah06AXO014B5`0>3a@0
414F01<D6@0A4QL02P/@02LX;00000@06a`P01<D600o@4@07QlS00803a0D0P0@4AD0>@0A4QH03Q4C
014E5P0@51D0310A01DI6P0A5AH02`l@00`@4@0H71d03a<D00T=3P000@8061`N00/?4P0;3Q<03a8G
00/>4`0@4aP04QDL00d@5`0<3aH04QDN01DH8@0B52009bTe05aNJ`0Q8c0051HS01<E8@0;3QP030lH
02P[=00;3QD03Q4F00442@0@4aL03a@G018H600J82407b@W01/Q8@0@5AL041DH018H600G7Ah04aPK
014G5`0@5QL03A<C00lE5@0>51@03aDE018H600?5AD04aTI018H6002014G5`0R010F5P0>51@03a<D
00hB4`0>4Q@04ADH01XN800P92D0720S01<G6@0;3a002`lB014E5`0;310051<K018@5`0B4aL03a<D
00dB4@0B61H03Q@B00/@3`0<41404a@H018@600:2A406AXO00/?4P0A5AP0720S01@H6`0830l02`lB
014E60803Q8E01804ADH00lC5P0830l07B4U00P;4P0=41T04Q@Q00P:5`0<3Qd02`dL00`>6`0A4al0
30lH01DH8@0C4QT04a8J01HE7@0F5Qh2010C700B00hB7@0<4Qh0/kW503HlBP0G7b`03aHP00`@4`0?
4aH04ADH018F6@0C5aX051PK00lC5P0=41D041<H00lB5P0<3a@03a<F0P0?4a@0400A5AH00PH7024U
9P1?De@04QHG00`@4@0;3a00<CDf00`@4@0A5AL03Q8E01LK7P0:3Q4051PK00dA500<41<200hB5@0;
00lC5P0>4QD03Q8E00/?4@0d>3T0=CTj018F5`0G6a`010P901LK700?4a@00P0>4Q<0B@0=4A803Q8C
014E5P0Y;Bh0EEUJ00lC500E6AX0310A010D5@0<41402Ph?01<G600I7Ah051PI00X>4@0C5aX03Q8D
00lC5P0<41<06AdP01LK700:3Pl020`=010D5@0>4Q403a<C00hD500=4a40318A00`B4P0<4Q003Q@C
00dC4`0F71X041HE00061P0:40h02Ph=00hD4P0D6QP0318C00021P042@d092P`00X>5`0<4AL0314E
00X?4P0:41003QDD00<=30074a402aLE00hJ600E81l07BLV0>_dl`1HHF0000T800H<300?5AD05A/K
01@J600@5Q@05Q`J00881P0A5aD061hL00P>300C6AL02@l=014G5@18CT`00P0:40h0<00>51802a4?
00/A3`0>51802Q0>00lE4`0@5Q@02a4?00T?3@0;4@l02Q0>00H<2P0<4Q003aDC01@J600A5aD02@l=
00hD4P0C6AL04ALE00hD4P0A5aD051XF018G4P0:3`/01``801HK5`0=4a40318@00TB3`084A002a@C
010J6@0=5aP0218C00<<300A7Ad031HE00L?3@0:3`/0418=00h@3@0>40l02Ph?018F600Y;S406AhQ
00`@40@0310?00@02`l>01@H5`021PD03Q8A0P011@@0100<4@h0314=00hC3`0>4`l200`A3@@03Q<?
00P03A8>00`A3@0>4`l02a0<010E4@0J7a/0314=00T>2P8041DA01402@h:00X?2`052PH020d900/A
200:4080318800dC2`0=4P`03A8>00X>300a=C@02@h:024V800C618010T200H;1@0200dB300;00T>
200<4@/03A8<00lD3P0>4`d02a0:00X?2@0;40X03A8<00/@2P0<4@/00P0=4P`300`A2`0E01@I4`0?
50h02Pl900H;1@0;40X03A8>00`A3@0:3`/02@h:00X?2`0<4@d0008001@I5@083@T0008000/@3005
2PH01``601PM5`0<4@/00`P200803A8<01T051TC010E3`0<4@/0314;00dB300>4`d03a@>02ld;P0:
3`T000@001hS7@062`D07b@N00`A2`0C61803A8<00hC3@0<4@/0318>00H<200<4Ph03A<?018H500=
4P`0314;00803@l:00P030h900/=200:30L01``600hC3@0:3`T01``600`A2`803a@>00D0314;00dB
300@5@l041D?00lD3P02010D4`0300dA400:3Pd0310?00803Q8A0`0?4a80100>4Q403A4@00dA400=
4A0400hB4@0300dA400>4Q403A4@00802`l>00L03A4@00/?3P0W:bX0F5aK014E50000@004ADD0080
1`/:0P0@51<0100<40l03A4A00`@4@0>4Q<200dA4P0900lC500C5aP04QHG01<G600A5AH01@T:00X>
3`093@d03Q8A00<0310?100>4Q4300lC4P0=00hB4@0;3`h02`l>00hB4@0@51<03Q8A00H:2@0E6AP0
1`/:01lS8P0I7A`03A4@00`A3@0300dB3P0300`A3@0;40`0314=0080314=00@03A8>00hC3`0?5100
2Pl;1@0;40`200`A3@0E00dB3P0<4@d0314=00/@300:40`04aTE00/A3@0D6QH041HB00P>200:4@T0
3QD=010G3`001`002Q8701@K4`063``031DC00`E40084@`0218:00803QP=00h02Q@<010J4P012PL0
31DC01HO7P0L8R001@/900lE4`0=4a403Q@A00T?2`0;4@d02a8<00/B2`802Q4:02H02Q4900lD3@0=
4P/02Pl800T>200:3`T02a0:00dB3P0<40h02`l>00/?400<41403A4@00@91@0;40`01P/7014F4P0V
:bL0008000X?2`0A5Q802@h:00/@300A5Q803A8>00D9200<40l000@3038g<`052P@04aPB00`A2P0:
40H02@l500`B200@5PX04AL=00hC30803a@>00T03Q<=00/@2P0:3`T0314;018G4@0A5Q003A8<00`A
2`0>4`d01@0=4P`300`A2`0500hC3@0@5@l04AH@010E3`0>4`d00P0=4P`200`A2`<03A8<00H03Q<=
00lD3P0@5@l03Q<>00/A3@0<4Ph2010F4P0:00`B3P0B61@05A/G03Lm>@0P9R803aDA01TO6`0G71P0
41DA00`A3@802a0<00<02Pl;01DJ5P0B5a<00P0?5102010E4@0<01DJ500U:R@041D?00L<1P0D6A<0
3a@>010E3`0=4P`041D?018G4@0@5@l04aPB1P0<4@d07P0320@0008002DZ9P1_M7008RLS00D91@0>
5@h00@P100hD400?5A404ALD018H5P0@5Q@05adL00020P0A5aL05Q`M010E600<51L041TK00`D5P0:
4Q@03aHG00lE5@0@5QH03A<B00/A3`0<4Q0041DD018H5QCooooo000Kooooo`0F018A5P0=31404A0E
00T83@0B4AH02`X?018A5P0=314020L<00X93P0=31401`H;01LF6`0P7b@040lD00L62`0>3A804a8G
024P9@0:2@h03`hC01<B5`802PT>0`0=31401P0<2a002PT>00T83@0?3Q<03PdB00d<4@802`X?00d0
30dA014E600D5a`03a8G01dP9@0`<CD02``@00`=4@0:2@h02`X?00h=4@0>3A803@`A00802``@0180
30dA00h?4`0?41@03a0D00h?4`0?41@0414E018C5`0@4AD06AXN04e>DP0P8BD0=3Di00P93@0X:Bd0
2``@00d>4P0>3a<300l@5003010B5@0>4Q<03Q8C00804aLH00/03a<D00X>3`0?4a@041@E01hR8`1N
HV<07b<T00/?400G6a`04QHI00X>4@02010D5`0>01dP9@0P8bP05APM01@G7P0F6B003Q4J00H84`0Z
;3/00P@C00`>7@0E5b@05QPU01dO;01JG6P2020R;P0E010B7P0H6RD03Q<G00hC5P0@5AP04AHJ010E
600=4QH06AhR00X?4P093Q40314E01PM800C61`02a4A00lE5@0B61P051XJ01HL700?5AD04QPH0080
41HF0P0A5aL0@@0=4a<04aLJ01<G6P0B5QX04QDJ01@G6`0D61/02PdB01DI7@0=4A@020/@00`@500H
6Ah02`XB020N9`0D5AX020/@010E600D6QX04QPH018G600>4AH03PlD00l=5P0A41P04a@I00dA500?
4aH0720S018F6@093A002PhA014E600?4aH03A4D00lC5P0>4QD02`lB01@H700>4AP041<L00lA7P0>
41d02P`K01`N:`0=3a`08bDa01/N9`0:3AH051@L014A6@0G5al061PR014D7@0B5Ah04QHQ00`@6`0_
<ch01`dI04Q>FP0941X05ATN01PK800G6Ql04aHK00804ADH0P0=4A@00`0@51L03a<E00`@4`0200hB
4`0@00/?400A5AH04QHG018F5`0G6a`04aLH00010P0D61T0DEEF01lS900@51H000@700dA50093A00
5ATL018F6@H03Q8E00T02`lA01LK700B5QL02Ph?01PL7@062P/02Ph?010D5@0>4Q<00`0=4A80900A
5AH06QhO0455AP0<41403a<D00H:2`0B5QL04aLH014E5P0@51D04ADF010D5@052@X05a/L014E5@0C
5aP02@d>01/O800V:R/061`M014E600C5aX03A4B00/?4@0>4aH031DD00/C500:4Q@02a@C00`E5@09
4A<03aPG00hF5`073a405b0O03Lo@0802a4A00d0314D01@I7@0C61`041DK00dB600>4aT03Q<G00dB
5@0=4a<03aHF00XD4`0<61H03QXH00803aTH01D041XI03Y3@P0L8b<04ALG01DK6`0>51@010X:00L=
2`0?5A<03Q@B00<91`0D6QP03Q@B01DK6@073@/05Q`J00H<2P0=4a400PP600T?3@0>51800P0<4Q00
2P0>51802@l=00D;2@0<4Q0020h<00H<2P0;4@l02Q0>00H<2P0>518200`B400300lE4`0>51802a4?
00803Q@B01`02a4?00`B400@5Q80314<00dB3P0;40`03A8>00/A3`0=4a4031DB00hG5P0=5QD0218A
00H@4@064Q80@e5B010K7@0=5aP04ATG00T?3@0:3`/0310?010D4`0;3a002a4D01/S9P0@61/03Q<B
100>4Q402P0;3`h05ATH0045100<40l0720O01XN7@0:3``02a0<00dB3P0<4@d200X?2`0Q00dB3P0>
4`l03Q<?00dB3P0<4@d02a0<00hC3`093PX03a@@00L<20083@T04aPD00X?2`0=4Ph02a0<00hC3`0<
4@d01``8018G3P0;4@<0318800dB2P0=4P`0314=01<H5@0D61L02Pl;00H;1@0J7aT03Q<<018G4@0D
6A<04AH@00802a0:00T02Pl900lD3P0>4`d02a0:00X?2@0;40X03A8<00/@2P0<4@/00P0=4P`200`A
2`0800X?2@0J7aT010T300`A2`0730H02@h800T>2P0:3`/200dB3P0h00`A3@0;40`02Pl;00`A3@06
2`L04QLC00dB3P0@5A401``6024V800E6Q@01P/500X?2@0>4`d04QLA01HK5@0D6A<03Q<=00X?2@0<
4@/000@005QME`1;D4X03Q<=00@90`0K81X020d700lD3P042@<00PL101@I4`073@T01a0=00TC4P0>
5aH0214>01DN6`0@5Q803aDA010D3`0@4Pd03a8;010B2`0>4@X041D?01PM5`0?50h01``600`A2`0?
50h04AH@010E3`0<4@/02@h800/@2P0=4P`200dA400400hB4@0;3`h02`l>00`@3`803Q8A0P0?4a80
0`0=4A003Q8A00`@3`0200`@3`803A4@00<03Q8A00`@3`0>4Q400P0>4Q406`0?4a804ADD014E500H
71/051PG00H:2@0A5A@02@d<01dQ800K7ah03a<B014E500<40l0310@00/?400=4A803Q8C00`@4@0>
4Q<02@d>00hB4`0=4A803Q8C028V9`0I7Ah041@D00`@3`0300hB4@80310?00@03A4@00lC4P0A5A@0
3Q8A100;3`h02`0>4Q4041@C00hB4@0A5A@092PW00hB4@0;3`h00081014E500:3`/02a0<00D03A8>
0`0<4@d01@0>4`l041DA00`A3@0;40`02Pl;00<02a0<100=4Ph0400<4@d02a0<0088100<4Ph041HB
00`B3P0C6AD02@l901LN5P0940P072<K00XB1`0F7Q<01@`400L=2`0@5QD201DK5`0@01XQ6P0S:R80
5A`D00D:1@0?5Pl020h<00X@3`0=4a<05Q`J00`B400=4a401`d;00P>2`0A5a<02a4=00/B30<02a8;
00<031<;01<H4@0@5@l00P0=4P`01P0>4`h03Q<?00dB3P0=4@l02`l>00`@3`803A4@00L05AXF010E
4@0A5Q803A8>00D:1P0>4`l03A8>0080314=01H03Q<?00lD400A5Q80314=01XO6`0730P041DA01DJ
500b=c403a@=00dB2`0<4@X03Q@:01<I3`0E6a4041D>00dB300<4@/02a0:00`A2`0=4P`0314;0P0A
5Q0200dB300300hC3@0=4P`03A8<00<03A8<00@0314;00/@2P0<4@/03a@>0P0@5@l00`0?50h0314;
00`A2`0200dB30803Q<=0`0=4P`03P0>4`d041D?00lD3`0<4Ph03A<?010F4P0?5A40318>00X@3006
30P08bTU00lE4@042PH02Q0<0P0C61@0200?51003Q<?00lD400>4`l04aPD010E4@0>4`l03a@@0P0@
5A40100A5Q004aPB00/@2P0?50h200/@2P06014F400<4@/02a0:00`A2`0;40X041D?0`0>4`l300dB
3P0J024V8P0320@01PX604E:AP0=4Ph05a`H018I4P0E71D03A<?00lE4@0>51403Q@B01@J600@5QD0
92XZ01<I6@093a005alQ00/E5`0?6Q/031HG00/E5P0@6AT03aPG010F5P0@5A@200lC4P0301<F5@0F
6QWooooo01?ooooo000Kooooo`0600d<4@0>3A8020L<00l>4`0j>Ch030/@0P0>3A804@0:2@h01`H;
00P7300=31403PdB00l>4`0;2Pl020L<00X93P0C4QL0;Rdb00d<4@0<2a003PdB00X93P0C4QL030/@
00803@`A00<03PdB00`;400;2Pl00P0=31403@0<2a002PT>00`;400=3Q80>Si4014D7009318030lD
00T:3`0:2a0030dA00X:3@0;2`d00P0>3Pl00`0=3@h03@hA00`=400200/<3`0;00`=400=3Q402``?
014B5@0?41<0414D00h?4P092Ph04a@H018C5`0@4AD00P0;31000`0A4QH03PlC00h?4`0200l@5007
010A5@0A4aH02`lA00T=3`0?4aD0310B00hB500200lC5@0e018F600J7R00CU9D010C5@0D61T08RHV
01XN7P0?4a@05ATK00dA4`0H71l06AdQ00`?4`0<3a@051LM01<F700=41T051LR018D800H6RH05aTU
00h@70051a<0;2hj00h@700=3a`03a4N01HH900B5ah04QLL014F700@5A`041DJ014F70062A00724V
0497C@0@4a/05AXO00T>500?51P04aPL01HK7`0H7B406QlT01@I7P0@5AX03Q<H010E6P0F6al05Q/P
014F6P0?4QP0100@4aT0500?4QP03Q4G00d@5P0D5ad09bX`01LJ800>3QH061HQ014@6`0;2a@07R4Y
030e>P0A5aX04QPM01<H7@0?4QX030`E00d<5`0C4A/04a@I0P0A5AP0=00C5aX05QXM01HJ7@0C5aX0
6alR01PL7`0C5aX04QHI010D5`0@51H03a<G00d@5@0<3aP051HQ00lA7P0>41h03a4N010B7`0O8B`0
41<L01TL900F62003Q0H01DG7`0F62403a8L01<E800D5b<03a<N028V<@0B5b80:2di00X>6@0C5Qd0
4QDM014D6P0@4aP03Q4F00hB5P0;3a80310B014E5P0?4a@0310@00hB4P0>4Q<051PI014E5P0?4a@0
3A4B00/?400>4Q<200lC500901HI6P0@51D0:2`]00lC5@0B5QP04ADG01<G6@0B5QP041@F00D03Q8D
02H03A4C00X>3`0F6Q/03Q8C01XN7`1LH64082@U010D5@0>4Q<0310A00/?400<41404QHG00441@0?
4a@04QHG00X>3`0830d03a<D00dA4P0<41402`l@014E5P0B5QH04QHD00850@0>4`l02Ph<00P=2P0C
5aL04QHG00lC500=4A@03Q8F010C5`0@51P03ADG00`E5`<02a@F00h031DG00dF600=5QP02Q<E00TB
500M9RP0?4E700`A500:3a402@hA01<H700A5QX03A4F00hC60803Q<G0P0>4aH03@0=51D02A<B00XE
500<5aH03ALF00/E50084Q404APH01<J6P0=4a<02a0@010E5P0D6AX00P0?5A<01@083P`04QPF00/A
3`0?4a403a@B00803Q@B00D01``:00hD4P0;4@l02@l=00hD4P0200dC4@0500hD4P093`d051XH01dS
8@0C6AL00P0;4@l00`052`T0318@010F500200X@3P0Q00dC4@0>51802a4?00X@3P0@5Q@04ALE00/A
3`0<4Ph020d801HK5`0<4@d08RLS03m5@`0C6AL04a`I00PA400;51<031HE00PB4`084aD0DF1S00@B
5@0<5aT0218B00P?3`0A61L02a0?00/@4P083a403QHJ00@=4`043A403a@C00@03a<B00T041@C00X>
3@0?4a802@`;02hb<@1;Cdh0310>00lD400>4`l00P0:3`/00`0<4@d03Q<?00/@300200/@30802Pl;
01X0314=00P=2@0?510020`900/@300D6AD02Pl;00L<200>4`l02@h:00/@300110403A8900`B100<
4PP0318:00`A2`0<4@d03a<A00P:2@0?51001@T401`Q6`0>4``03Q<=00dB3@80314<00<03A8=00lD
3`0=4Pd00P0=4Pd200`A300300/@2`0;40X0314;00803A8<0P0<4@/09`0:3`T0<CH`038g<@0<4@/0
41D?00`A30093PX02a0<00dB3P0>4`l03A8>00`A3@0D6AD0GF9N04I;A`072`P03a@@00P=2@083@L0
3Q<=00`A2`0=4P`03a@>00`A2`0>4`d05AXD01@I4`0?50h0314;00hC3@0?50h04QLA00hC3@0<4@/0
3a@>010E3`0=4P`041D?00dB300200`A2`0A01LN6`095QL03Q`N02<`<P0>6Q/02aHF00dF500<4Q00
2a4<00`>2@0<3`P03a0900lB2`0L7aX08BHP01@I4`0;40X00`0@5@l04P0>4`d041D?01DJ500C6180
41D?01HJ6@0;3`h0310?00dA400:3Pd02`l>00dA400<40l041@C00hB4@0;3`h03Q8A00hB4P80310@
02803Q8B00lC4`0@51@03Q8B010D500?4a<03Q8B00lC4`0@51@041@C00T<2`0=4A002@d<00H:2@0G
6aX0<3@c02<W9P0:3Pd03A4@00P<2`0>4Q80310A00dA4P0?4a@02Ph?00/?400?4Q<04aLH01@G600A
5AH0A4Q902P/;@0<41003A4@0`0>4Q4200dA40<03Q8A01003A4@00`@3`0=4A003A4@00`@3`0>4Q40
3a<B00`@3`0H71/06alN018F5@0>4Q401`/:00lC4P0:3`/02a0<0P0=4Ph03P0>4`l03A8>00dB3P0<
4@d02Pl;00T>2P0;40`03A8>00lD400=4Ph02Pl;00`A3@0>4`l03A8>0`0>4`l0;`0=4Ph0314=00/@
30093`/04QPD00@:1P0C6AD000@0014H4@0:4@T03A@<00/B2P0F7Q@02a<9014H400;40`03Q8@00dC
3`0=4@d03A8<00hD3@0520@0;S<]00T=2P0=40d0310>01@I5`0>51802@l=00/A3`0A5aD03A<@00dC
3`0B61@04ALB00hE3P0<4``02Q4900P?1`0>4`d03Q<<00dB300<4@`02a0<00X?2`0<4@d03Q8?0080
3Q8@00H03A4?00`@3P0A5Q8020d900H;1`0@5A4200X?2`06010E4@0;40`03Q<?00`A3@0;40`04AHB
0P0<4@`0100A5Q408RLR01<H4P0;40X200dB2`0500`A2P0;40P03Q@;014F3`0?50h00P0<4@/0100=
4P`03Q<=00lD3P0=4P`200hC3@803a@>00<03Q<=00dB300=4P`00`0=4P`200hC3@0300lD3P0@5@l0
3Q<=00803A8<100>4`d0200?50h041D?00lD3P0=4P`0314;00hC3@0?50h03aD@0P0>51002P0=4`l0
318>00`B3P0=4`l0318>01LM6@0>51004ALC00P>2P0A5Q8200/@300600dB3P0@5A404AHB014F4P0?
510041DA0P0B5a<02@0?510051TC00`A2`0?50h07b@N00/@2P0?50h04aPB018G4@0201HK5@04010E
3`0>4`d041DA010E4@803a@@0P0>4`l07P0:3`/051TE00dB3P0>4`l04AHB00hC3`0P9b00:C0Y00lE
4@0G7AT07R@Q00lE4`0=4a40=3Xi00lE5@0D6QX02a4B018J700951H03Q/K00/H600:5AH03QLG00dF
5@0=4a<04QHE01<F5@0C51<04a@D01HG5QCooooo000Kooooo`0G01LF6`081``05aHK00D42@0>3A80
2@P=00h=4P061@X020L<00l>4`0>3A8020L<00h=4P040`P03PdB01<B5`0<2a002PT>00811P0920d0
3PdB00l>4`0<2a000P0;2Pl00`0=31403PdB00h=4P0200h=4P0:01LF6`0F5AX04a8G00h=4P0<2a00
30dB061SJ`0l?dP020/D00P;4P803@hC00L02``@00X:300:2P`03@d=00d=2`0=3@d02``>00802@X<
00l02P/=00`=3`0=3Q003a0B01LH6P0D5AL04a@F014B500;30l08B8V00<4200B4aL00@8601dN8P0E
5QX00P0?41@0>P0@4AD04A8F014B5P0>4A@04ADH01@H6`0>4QD02`lB00X>4@0;3a80310C00D9300h
?3l0Zjnb03Di?0093@l05QXI010D4`0G6a/051PI00X>3`0@51H0310C014E600D5a/04QDJ014D6@0I
72401`X?01HI800E61l04QDL014D6`0T9c0010L@01HH90051a<0418N01@F8P0:3QL03A4J018F7`0A
5Ah03A4J00X>5`0F6R<01PXC02<W<00=4AX02PhG01HJ8`0A5B004QHQ00lC7P0@51l05QXU01DI900G
6bH201@H8`8061`W00@041@O01DH8@0D5ah04A@K0P0?4QT07@0@4aX02@`C014D6`0L7bH0:B`c014D
6`0J7B@03PhH01DE800C5Ql03A4J00/@6@0@5ad04APP00lE7@0@51d04aHO01@C7P0?3aT03a8G018F
6@0G6ah03a<F010D5`0830l01`/>018F6@0A5AP0310C00803A4D01D07b<T00H:300@4aP03a8I00h@
6`0D5R804A<P01<E8P0H6RH0X:>/08J9T00H6b805QTR00X=5P0A51d04QDN00`>6P0A4al0418N010D
7`0>4Qd00P0A5B007`0C5b805QTR014D7@0@4a`041<J00lB5`0=41D02PhA00`@4@0A5AH03a<B00`A
3@0=4Ph04aLH00L;300<41404ADF00/?400830d04QHG00861`0@51D020`=01dQ8P0f>S/04ADF00X>
3`0=4A80310A014E5P0B5QL00P0>4Q<0300=4A803Q8C00hB4`0A5AH010P901@H6@0=4A80>3`m0<C8
b@0l@4404aLH014E5P803Q8C01X03a<D00`@4@0N8R<09RX[010D5@062P/05QXK00`@4@0@51D03A4B
00lC500G6a`02`l?00`A2`0G71D01PX601lT800>4`l020`;00dA4P0D61T04ADH00T<4@0>4AH02`lC
00dE60802aDG00l02Q@F00/E5`0<5QP010h@00/E5`0?6A/02A<E01XT9P012`d02@hA018G6P0C61/0
1@X=00@9300>4aL00P0:3a<01P0:3a802a0C00/@4`083Q4041TH00dG5P<031HE01D02a@C010F5P0=
4a<041HF00lC500;3a004ADF00T?3@0<4Q002Q0>01TO7@0B61H0IVaZ02H/:P0;4@l020h<01PN700>
51801`d;00P>300>51800P0=4a406`0>518020h<00D;2@0D6QP03Q@B00X@3P0@5Q@0318@01<I5`0@
5Q@02a4?00lE4`0=4a401`d;00/A3`073@/04ALE01DK6@0;4@l01`d901@I500;40`00`P406I[I`2G
WI/061hL00`E4P0200/D4`0@00D?3P0<5QL05b8T0;k>dP0[>C`04AlP00L=3`0=5QD02a@C00L=3@03
2`d041PJ030i?P0F8BL07RL/00dB4@@03A4@00T03Q8A00dA40062PT04QHE00@81`0;3`h03Q<@018G
4`0@5A400P0;40`00`0?510041DA00`A3@0400`A3@0400hC3`0:3`/01@X600`A3@802Pl;01@041DA
0002000=4Ph01P/701<H50093PX03A8900dC1@0<4PP02a4900/@2P0<4@d02Pl<024U900>4`l061dG
010E3`083@H04QLC00hC3`802a0<0P0:3`/0200;40`0314=00hC3`0>4`l0314=00X?2`0;40X0314;
0P0=4P`200`A2`0800/@2P0>4`d0;c@^020U7`1JGeT041D?00dB3P0<4@d200X?2`0900`A3@0?5100
20d9038g<`0/<Bd03a@@00D:1P0?51004AH@00803a@>00@02a0:00P=1`0A5Q003A8<0P0:3`T07@0=
4P`041D?00lD3P0V:bD0=S/e01DJ50093PP03a@>0005000;40X02@h800D:100B5a404AH@00dF4`06
51D0:3Tm0<?Be@2T/[D07RX[00/E500<4Q80314=00/@2P0?40X04A8;018E300;3`T04aPB00802@h8
0P0C6180600_=2h04QLA00`A2`0E6Q@041D?00L<1P0T:2L02`l>00T=300<40l02`l>00dA400;3`h0
2Ph=00lC4P0=4A002@d<00dA400<41402`l@00X>3`0;3a003A4B00hB4`804ADF02X03a<D00X>3`09
3@h02Ph?00/?3P0C5aH02`l>018F5@0J7Qd00PH501@H5`093@`03A4@010D4`0420L04aLG00`@4@0=
4A803a<D00P<3@093@h061`M00010P0:3Pl08RHW02X^;`0B5QL03Q8B00hB4@0<40l02`l>00`@3`0>
4Q403a<B00dA400;3`h03A4@01DI600M8B0061`K00hB4@0=4A0200hB4@0700/?3P0B5QD01`/:00/?
3P0830/03A4@014E500300dB3P0?00`A3@0;40`02Pl;014F4P0?5100314=00X?2`0;40`03Q<?014F
4P0=4Ph02Pl;00dB3P0?51003Q<?00<03a@@02P03A8>00`A3@0;40`051XF0002000E6aL01P`801DK
5`0/<b`02Q49010G3`0B6A40R92503U1=P0120003Q0;00d?300@4Pl04aDB01DG4`0E5a80828M00/=
2`0?4@h02@/800lA3P011P802`l>010F500:40h03A<A010F4`0Q9b<04aTE018H4`0?5Pl03A@=00/B
2P0940P03a@>0P0@5@l08`0?51003A8>00X?2`0:3`/03A8>010E4@0?5100314=00X?2`093@X03A8>
01LL600:3`/06b0L00H;1`0C61@05AXF00hC3`093PX0314=00hC3`0=4P`03a@>00D:100K81X000D0
01DJ500>4`d04AH?00lD3@0<4@X03A8;010E3P0:3`T03A8<00803a@>00<03A8<00`A2`0?50h00P0:
3`T2010E3`0300hC3@0=4P`03A8<00<03A8<0P0;40X03@0=4P`041D?010E3`0@5@l04AH@018G4@0A
5Q0041D?00dB300<4@/03a@>010E3`0>4`d00P0<4@/02@0>4`d041D@00lE4@0>51002a4=00X@300=
4`l041HB01@J5P0200hD400601XP70042PH04aPD00lD400=4Ph03a@@0P0A5Q82010E4@0501@I5@0F
6aL05AXF010E4@0C61800P0>4`d02P0O91h03A8<00lD3P0A5Q003a@>018G4@0E6Q@04QLA01@I4`0@
5A4200lD400Q00hC3`0=4Ph03A8>01LL60001@402a0<01/P700=4Ph03a@@00L>1`0<4``04aTE02hd
<00k@3d04aTG00L=2`0?5A@000D501@J6P0>4aD0210B00dK700A820031XJ00/G5`0<5QH02A8A00T=
3P0@4a<051HE018B4P0@3`l04@l@01Cooooo000Kooooo`0600L62`0;2Pl040lD010?500>3A802PT>
1P0;2Pl050020@H05A@I03Lf>`0C4QL030/@010?50061@X02`X?00h=4P0=314030/@00d<4@0920d0
40lD00H52P0C4QL0?Se202`[<00>3A803@`A0P0>3A800`0<2a002@X?00`@600200d@6@0K00/>5@0:
2a002@X?010A5@0820X04Q8D00`<30051@<03`l?00T:3@0:2`l01`P<010A5@0E5QX03PlC010A5@07
20`04Q<G0411A@0:2`l051DI00h?4`0<3A405aPL00421P0>3a<0:R/_00D0414E00D030hB01HI7P0D
5a`02PdB00D83@0200lB5`0i00011P0>4AH0<cHk0:2SZ00L7b@03a<E01/O7P1RIVD0310@00P<3@00
0@804aLI00/?4P0?4aH041@H00`?500?4QL05a/N02@X:@0;3a007R8S01PL7@0>4QD04QHI00dA500@
4aP05APM01HI7P0B5A/041@M00`@6`0?4ah051PS018F8@0@51l01`/F00lC7P0J7RT0310K00P<5`0>
4Qd02PdL06Q[O00f>DX02`hO024T=@0E62T051LX00X=7P0b=DH061//01`O<00F6BT05QTR01@G7P0A
51/03Q4H008041<J01@030lF01<F7@0D5ah041<J00lB6@0C5Qd02`/E01DE7`0B5Ah07b<^00lD7`0:
4aX01a0I00hD7P0H72L03Q4J00d>600=3AD04QDJ018F6@805ATL0P0A5AP03@0<41<03a<F00lC5P0=
4A@03a<F01@H6`0@51D03A4C010C600A51/0418M01@F8P082QH00P0F62@0<P2=T9T0GV5X01HI800=
4A/04ADP00X>6@0>4Qd04aDQ00`>6P0@4Qh03A0I00`?600=41T03Q4J00lB6`0C5Ql041<L00X=5P0@
4aX051LL010C600C5aX051PI01<G600A5A@0314=00X?2`0?4a@00`L8010D5@0:3Pl04ADF00lC500>
4Q<041@E00hB4`0A5AH04QHG010D5@0M8B80=3Pi00lC500D61T01`/<01PL7@0<41401@T:01`P8@0C
5aP02@d>0`0>4Q<01P0@51D05ATJ01PL7@0H71d04QHG00lC50803Q8C01H03A4B00T=3P0F6Q/0R8b=
02/_<0072``07R8S03Tm?P021PL06alP00P:2`0@51D02Ph>00P=1`0;40T02@h700/@2P0A5Q002Pl;
00/?3P0<40l03Q8C0P0>4QD03@0;3a@03ADH00TC5@0;4aD01@lA00/E5`0B71h010h@014K7@043Q00
4adO04QBE0043Q000P0>4aL0100?51L03Q<F00`A500:3a8200hC5P05010E600D6A`051TL00hE600;
51<00P0=5QD01@0;51<02Q8A00`B4P0;4A403Q<C008041@E00X03Q8C00`@4@0>51804aTG014G5@0?
5A<04QPF01DK6@0G7A/02a4?0P0<4Q003`0;4@l05adK00`B40083P`04ALE010F500;4@l05adK00T?
3@0A5aD02a4?00D;2@0E6aT01`d;014G5@0200`B400Y014G5@0?5A<02a4?00dC4@0>51803aDC00hD
4P0<4Q00318>01<H4`0>4`l0314=01@I5@0G7A/04QPF00PA3P0330/02a@C018L6`0<5QL02QDG06Ig
NP0M:bh00@l@00LA4P0<5A@010d<00T?3`0841800PX<01@M8P2Y];X0UYnT01@I6@0B5QD01`/:018F
5@0;3`h02Ph=00P<2`062PT00P0=4A002@0;3`h03A8?00T>2P083@T0314=00X?2`093PX02Pl;00T>
2P0200X?2`0500/@300>4`l0314=00T>2P0@5A400P0;40`08@0=4Ph01P/700D:1P0B5a<02a0<0005
0@0@5A404aT@00H<000220003Q<;00/@2P093PX0:2`Z08:6Q@0C61@0314;018G4@0H7AL051TE00hC
3`0=4Ph01@X601lT80062`L01``8010E4@0:3`/082DQ00T>2P0S9b@0>Sli00/@2P0200dB300A00hC
3@0A5Q0010T300`A2`0?50h03A8<00lD3P0<4@/0314=00/@300;3P/061dI00P=2@0?5100314=00hC
3`0?51000P0<4@d01`0>4`l02a0:00dB300:3`T01``600/@2P0B5a400P0;40X0300?50h03A8<00/@
2P0D6A<05a`F02<X8P0A5Q003a@>00`A2`083@L07B8L018G4@803Q<=01/02Pl900L@3@0651D0=DI:
0=k]l030c]405b<T00lI600630`06AhJ014F400D5@l0>c`e014D2`0;3`T061dG01@I4`0<4@/06QlI
05eRG037c<H08RLQ00X?2@0B5a403A8<00T>200>4Q400P0;3`h02@0=4A003Q8A00hB4@0;3`h03Q8A
01TM700@51<03Q8A010D4`0300lC500300dA4P0:3Pl020`=00<03Q8C02L041@E01@H6@0E6AX02`l>
00dA400<40l04QHE010D4`0>4Q403A4@00D9200A5A@02`l>00hB4@0=4A402`l@01DI6P0@51D01PX;
01DI6P093@h04QHG014E5P0C5aP04ADF00dA4P0D61P04QHE00hB4@0:3Pd02`l>00dA400@51<03A4@
01HJ6@062PT082@S075eM00G6aX00P0=4A001`0;3`h02Ph=00dA40072`X02`l>01DI60093@`00P0<
40l01@0B5a<03A8>00T>2P0;40`0314=00803Q<?00L02Pl;00P=2@0>4`l04AHB00dB3P0:3`/02a0<
00803Q<?00D03A8>00/@30062`L020d900`A3@0300dB3P0A014G4`0=4`l02@l;00@:1P0;4@d0;SD^
00dD300940P05ahF03Y2=`0L91T02A08010B3@0A4`l06Q`I01<E4P0=3``00P0B51403@0=3``04A<@
010B3`0;3@T0314=00H:2@0;4@l02Q0>00dC4@083P/061hJ00hD400>5@l00P0530D01@0<4``02Q49
018G4@0:3@X02a0<00802Pl;00P03Q<?010E4@0>4`l04AHB00hC3@083@L02Pl900dB3P80314=00X0
3A8>00hC3`0>4`l04AHB00/@300=4Ph04aPD018G4`0?51003Q<<0P0=4P/0400?50d041D?010E3`0<
4@/02@h800P=1`0D6A<01``600lD3P0A5Q0041D?018G4@0;40X020d700hC3@0A5Q0200/@2P0K00hC
3@0?50h03A8<00hC3@0?50h02a0:00P=1`0;40X04aPB01TN600F6aD041D?018G4@0C61804AH@00`A
2`0:3`T0314;00L<1P0:3`T041D?00lD3P0>4`d0314;00/@2P0<4@/02Q0;00803Q@@02T02@l;018H
500@5Q803aDA01LM6@0D6QH03A<?00hD400E6aL06R0L00<8100C61@0008001DJ5P0D6AD03Q<?018G
4`0:3`/02a0<01DJ5P0>4`l041D?014F400B5a403a@>00hC3@0@5@l03A8<00/@2P0>4`d04AH@00hC
3@0?50h020d901DJ5P0A5Q804aPD01@I5@0B5a<04AHB00lD400200hC3`0J00dB3P0A5Q803A@=00`C
300<4Ph03aDA00lE4P0<4Q005Q`J00`B4@0D6QX02a4A00`A4`0E7Al01aDF02He=@0@7Qh0>DE501XT
900E7Qd04QHG01DH600C5A@04a<C01DD500A3a0Dooooo`006oooool01P0?3Q<03@`A00`;400;2Pl0
3@`A00h=4PH02`X?00T03`hC00T83@0;2Pl05A@I00`;400A41D03`hC00`;400;2Pl00`0<2a005@0>
3A802@P=01TH7@0920d04Q4F014@5@0;2Pl01`H;00`;400E51T051<H00h?4`0;3a@02PdE00X=4`09
31402P/@00T:3`0:2`l030`?010@4P0200l?400C01@D5@1@DED01@H;00`=4@0?41D00`@800h?500>
3a<05AHJ01DF6`0<3A804a@I00T:3P0C51P03@hB00`=4@0@4AD03@hB018C5`05010A5@0K010B5`0<
3a@03A0E00lB5`0G6Ql020/@00d@5@0E61d02`hC00hA5P0V:Bh030lD018F600;3`l04aLG010D5@0C
5aT01`/=00d@4`0<3a<05a/O01LJ7`0=41H04aHL02da=00k?ch061`K00803a@A00X05ATG01@H600:
3Ph04ADE00dA4@093@d0>Cdn028W;P0F6R@03A4K0P0D62805@0>4Q`041@N00dA6`0J7BL0HVI`02@X
<P0V:S@09BPh03m2E00Q93H04aHX01DH:P0B5BL06ah`09:EY`22QIL05aX/018E9`0B5BD03Q4J00hA
5`02014D6P04010C6@0>4AL04A@J010C6@803A0F00P06ahT02X]<`0D51/05ALO01@G800H72L041PR
00XC7@8031@N00D020`G00lB6`0E5al051DK010C5`05010D5`0L018F6@0C5aX04QHI00lC5P0@51L0
4QHI01@H6@0A5AH04QHI018E6P0?4QX04aDP014C7`0:31L04QDN01TL900I72<05QTP01<H8`0G72L0
4QLR01PL9`0M82/05aXU00d?6P0?4AX0414K018D70804aDM02403Q4H00lB6P0=41H04A@I00lB5`0:
3Q803a<F010D5P0A5AH03a<C00/?3`0:3Ph03Q8C00dA4P0D61T020`=00X>3`0?4a@05ATJ01LK700>
4Q<02`l@00`@4@0>4Q809RXZ01hR8P0C5aL02`l?01TM7@0L82006AdM00`@400>4Q800P0<41002P0?
4a@03A4B00`@4@0<41403A4B00lC500@51D03A4B00`@4@0=4A8300lC500C01@H6@0?4a@041@E00hB
4`0G6a`0N7am00lC500;3a003Q8C01dQ8P0>4Q803a@?018G400?50d0314;010E3`0@5A403A4?00hB
400200lC4`0800hB500=4Q@02PlA018K7@0>5aT09Bh`09FNX00c?3h200hG6@0400hF600f?d40FV=U
00lH6P804AHJ00L04QLK018G6P0A5QT03aDF00hC5@0=4Q@03a@G00804QLK00@03Q<H00XB500<5QD0
31DD0P0<4a<0200>51@03A8B00hC500?4a@041<D010B500=4A803Q@B0P0;4@l01@0>51803aDC00/A
3`0;4@l041HD00801`d;00`041HD00/A3`0@5Q@03A<A00hD4P0:40h04QPF02hd<P0@5Q@02Q0>00hD
4P093`d200dC4@803aDC0P0>518200dC4@0800lE4`0<4Q002Q0>00X@3P0<4Q003A<?00dB3@0@5A42
00`A3@0Q014G5@0B61H03A@A00H?3P0<5A@0@de<00/E5P0E82804R0S008@4`033Q0031HF00lF5P07
3`d02@h>01@I6`0@5QT03aLJ03m8CP0W;c<041DD020T8`0A5A@01`/:00H:2@0@51<02Ph=00P<2`0>
4Q403A4@00`@3`0>4a003a@@0080314=00L041DA00`A3@0<4@d03Q<?00/@300>4`l04AHB00803Q<?
00L02Pl;00dB3P0<4@d020d900lD400>4`l03A8>00802Pl;02l05AXF01@I5@0=4`X020h100`B200J
81P051TC00/@300;3`d0=3Pg00X>2P0F6aD04QLA01LL5@0=40d02`l=00lC4@0B5Q@010T600hB400=
4@l041@B00dA3`0=4Pl02Pl<038f<`17C4H061dG00X?2@052P@02@h800dA30083@L03Q<=00lD3P0<
4@/03A8<00`A2`0@5A402Pl;00lD400J7a/02@h:00X?2`0<4@d03A8>00lD400200hC3`03010E4@0=
4P`03Q<=00803a@>00@03Q<=00dB300>4`d041D?0P0;40X0;`0=4P`02a0:00T>200B5a401``600`A
2`0>4`d02Pl900dB300G71H04AH@00/@2P0?50h02Q8>00LD5@0@7Al0=45202Hc=00:5AD02a@B00/A
3`0`=C008R@O010C300C50d02@/700lB3@0;40X0314;00hC3@0T:B<0Be1:09FJU00J7aT04AH@01LL
5P0<4@/04QLA014E500=4A002`l>00dA400<40l02`l>00X>3@0D61L0720O00802`l>00T03a<B00hB
4`0>4Q@03a<E00hB500<41802`lA014E5`0?4aD00P0>4Q@02`0@51H041@E018F5@0>4Q402Ph=014E
500C5aH041@C00dA400;3`h041@C00803A4@00P03Q8B00X>3`0h?3d01PX;01@H6@0:3Pl0310A014E
5P803Q8C00@03A4B00T=3P0?4a<0310?0P0;3`h01P0=4A003Q8A018F5@0;3`h041@C018F5@80310?
00d03a<B00dA400>4Q403A4@00`@3`0?4a804QHE00/?3P0<40l03Q8A00`@3`0>4Q4061dI00803Q<?
00<04aPD00dB3P0<4@d00P0;40`0100=4Ph041DA014F4P0>4`l200`A3@<03A8>03P0314=00hC3`0;
40`020d900/@300>4`l03A8>00T?2`0:40`041HB00hD400;4@d05QdF07AkL`0H7aL02A0800lG300C
6a003QH;01<I4P0;3`X03Q<?00H:1P0B5Q@020h;00X=3@0;3`d04QLC01DH5@0?50h03aD>00/A3@0:
40h04aTG01hT8P0<4Pl020h:00dC3`0=50h04APA01TP6@0L8a`03aH?01`Q7@0<4@h02`l=00dB3`0>
4Ph02Pl;00hC3`0;40`03A8=00/@2P093PP0314;00hC3`80314=0P0;40`200`A3@0600X?2`0<4@d0
4AHB00hC3`0;40X03A8;0P0=4PX02@0>4``03Q<=00hC3@0=4P`02@h901XO6P0;40/061dH01<H4`02
010E3`08014F400<4@/02Pl900lD3P0G71H03a@>00`A2`0=4P`200hC3@8041D?00H03Q<=00dB300?
50h04aPB01LL5P0E6Q@300lD3P80314;00D03a@>018G4@0=4P`03a@>014F400200lD3P8041D?01L0
4AH@00lD3`0D6QH05Q`H00hD400?5A403Q@@00/A3@0B61@05A/G01<I5@0?5A4041HB02T^:P0K81`0
7R<O00X?2`0:3P/041DA01DJ5P0@5A402a0<00lD4002018G4`0>014F400B5a404QLA00lD3P0=4P`0
3a@>018G4@0@5@l04QLA010E3`0<4@/04AH@00X>2`0H7AT2010E4@0:00hC3`0<4@d03A8>00hC3`0@
5A403A8>00/@300=4Ph01`h700XA2P803aDA01@03Q@A00lE4`0A5aD03Q@C01@J6P0630`05adN01@L
7P18DeD0cm_L05MTI00Q;2d07RPX00dF5@0D6QX03a<C018E500B4a<04a@C01lP7aCooooo000Koooo
o`06010?500=31402@P=00P7300:2@h03@`A1P0;2Pl01`0920d02`/?014@5@0/:c004a8G00D42@09
20d00P0<2a004@0:2@h030/@00h=4P020PH06aXO04i=DP0_;S<01PD:0000100>3A802PT>00`;400B
4AH03`hC00T:3P0=4QD02`hC00802PdB0P0=3Q801`0>3a<05aHK00l>4`0<2`l040lD00h=4P0Q8RP0
0P0<31@0300A4AT0410H010@600;2a<0>c]304=3B`0>3QH0000700l@5@0:2`l010D900l@50803@hB
00<04a@H00l@500?41@00`0?41@0EP0=3a@041<H01<F6`0=41D0CE1E01/N8`0B5AX05APM00021`0I
72405APM01@G700?4aL04ADF00L;3P0:3Q406AdP01/O8P0H6b002@`A00X=4P0?4QT041<J018E7P0:
3Q<01`/<00lC500<414041@C014E500:3Pd041@C014E4`0=4Ph04QLC00P=2`0C61`03a<L01DI8P0O
8b`06AdV00/?600K7bP0310I01PL9@1GFf@00@D>04]?F00`=4005a/W018F8`0F6BP0310L00lB800M
82l08RHb03DiAP0E62L051PT01hQ;P0=41L03Q8E010C5`0@4aP03a8F00dA500F6Ah05a/O01DI700C
5Q/04aLK01HJ7@0H6Ah041<H010E6`0>5Ad04aXU01LO:P0>5R402Q8K01HM9@0Q9R`02`dB01DF6P0?
4aH041@G0P0<41<01@0A5AP041@G014E600@51L03a<F00803Q8E01@03a<D014E5P0>4Q804QHI01@G
700C5Qh061/T03@f@P0D5b0041<L01<F7@0R9BX03A8H00hE800A5b<03A<O01<G8P0E6B@04QHQ018E
7P805ADO028051@L014A6@0@4AH03a<G010C600A51T04aHK010D5`0=4A@03a<F010D5`0A5AP04ADG
010D5`0?4a@041@E00P<3@0C5aP07B4R00hB4`093@h05QXK01dQ8P0B5QL0310A00hB4`0B5QH07R8Q
014E500=4A001@T800lC4P0830/03a<B0P0@51<00`0D61L05QXI014E5@0200`@4@0500dA4P0@51D0
4QHG01<G600@51D00`0>4Q<04`0=4A802@d>01TM7P0E6AX04aLH018F5`0:3Pl00PH700L;300S9bP0
4ADF01DI6P0>4Q802a0<00/@2P0;40/03A8<010E3`0?51000P0>4`l0400?51003a<B00hC3`0>4a00
0PP800L@3`053@h03ADG06I_KP0Q:RX031@F018K6P0@61P031@F010I600B6Q`200dB600400hC5`0>
4aH03Q@D00hD5080318B00D03Q<F00lD600>4aL03A8G00TA4`0200/D4`0300`B4P0=4a<041HF00<0
3Q8C0P0@4A<01@0>4Q<03Q8A00/A3`0?5A<04ALE00803aDC01D03A<A00X@3P0?5A<03aDC00X@3P0=
4a402Q0>00hD4P0B61H03A<A00`B400J81h04ALE00P>300;4@l010X800X@3P0;4@l03A<A014G5@0@
5Q@00P0:40h200hD4P802a4?00L03A<A010F500B61@02Pl:00hC3`093PX02Pl;00803A<A01P03QLD
00dF5@0?61L0FVAS00<=3P064Q804AlP00LB50033@h01`l=018H5P0F6aL041@C00dA400420T01`d@
00D=400<51L041DD018F5@0:3Pd03Q8A00/?3P0@51<200/?3P0500lC4P0<40l0310?00/?3@0=4Ph0
0P0<4@d0<`0J7a/05Q/G00`A3@0>4`l0314=010E4@0B5a<03Q<?00T>2P001@40314=01XO6`0:3`/0
2@h:00X?2`0B5a<02a0<00`A3@0=4Ph01``800dB2@0:408041H<01/P600D6A<0314=00X>300A5A@0
2Pl;00`A2`0;40X02Pl90002000:3Pd02`l>014E501FFUT082@S00/?3P0010<0310?00/?3P0@51<0
1P/800@91@011P005Q/E00dB30062`D02a0:00`A2`0200hC3@802Pl901002a0:00P=2@0>4`l01@X6
00hC3`0A5Q801``800/@300<4@d03a@@00hC3`0?51004QLC00dB300:3`T0314;0P0@5@l02P0<4@/0
41D?00X?2@0A5Q005AXD010E3`0>4`d04AH@01@I4`0<4@/201DJ500R010E3`0730H03a@>00lD3P0;
40X0314;00lE4@0:4a001a0?014J6@0@6AH04AXG00P>2P0<4Ph02`h:0001000E61404A<=00/>1`0I
7QP03A8<010E3`0;40X0314;00@90`0B5a403a@>02@Y8`0/<B/041D?00P=1`0@51<0310?00/?3P80
3A4@00L0310?01DI600M8B008RHU01@H5`0C5aH04QHE0080310C00D03A4D00hB5@0>4QD03Q8E00lC
5P0200hB5@803A4D01H03A4B014E5@0:3Pd020`;00/?3P0=4A003Q8A00/?3P0A5A@03Q8A014E500<
40l02Ph>00hB4`093@h020`=01LK700i?Ch04aLH010D5@0;3a002Ph?0P0;3a00100?4a<02Ph=00/?
3P0=4A0200hB4@0E00L:2@0G6aX02Ph=00D9200E6AP010P700`@3`0:3Pd0310?00dA400<40l03Q8A
01@H5`0K7ah04ADD00<71P0=4A0051PG09nTX01QIV8051TE00801@X600P03A8>00X?2`0<4@d03A8>
00`A3@0=4Ph041DA00`A3@D03A8>0P0>4`l0600<4@d02Pl;00X?2`0<4@d03aDA00dC3`0<4Ph02Q0<
00T?2`0;4P/08BPP00H=1P0I81P051`A00hF2`0=5@X041L?00`C30063@H03Q@B00X@3`093`l02a4A
00dC4P8041HB01H03A@=00/B2`0:40`020h<00hD4P0F71X020h;00X@300?5A402Q4;00XA2P0A6140
61lG01HM5P0Y;RX04QHE00P<2`0?4a804QLD00/@300@5A40314<0P0=4P`01P0>4``04QL@01<H500@
5A403a@@00hC3`803A8>0P0;40`01@0>4`l041DA00dB3P0:3`T02a48008031880`0<4@X01P0F6aD0
2a0<0002000S:2@0X:FQ09JKU`803Q<=00d03a@>00hC3@0>4`d03a@>01@I4`0A5Q003a@>00dB300<
4@/04AH@01HK5@0D6A<03a@>00<02a0:00<03Q<=00lD3P0>4`d00P0@5@l200X?2@0B00hC3@0?50h0
314;00dB300>4`d0314;00dB300>4`d03a@>00hC3@0=4`h05A/G01TO6`0A5a<03A<?00`B3P0;4@d0
3aDA0P0D6QH04@0:40`01`d9018H50042@D04QLC01<H500D6AD05AXF01hS7`0B5a<04AHB01@I5@0;
40`03A8>00lD3P0@5@l04AH@00803a@>00d04AH@00dB300=4P`041D?00lD3P0=4P`061dG02H[9`2R
Yj<0=c`h01dR7P0>4`l03A8>00803a@@00H03A8>00hC3`0A5Q803a@@00`C300?5Pl201@J5P0D010F
4`0<4Q001`d;00lE500M8b<00PP801DK700P:2X0:cDg09NRX`12C4d031HG00lH600>5aH02a4A018G
5P0F6QT04aLF01DH5`0I7A`Dooooo`006oooool200`;40802PT>0P0920d600/:3`0J00l>4`0;2Pl0
2`X?014@5@0>3A803`hC00P7300D4aP05QDJ00`;400:2@h03PdB01HE6P0;2Pl05QDJ00T83@0;2Pl0
5A@I00h=4P0?3Q<03PdB00/:3`0:2@h02@X>00dB4`0;3a8200X>4@0J00d>4P0>3a<0414E01XI7`0@
3aD02`X@00h=4`0920h01@D?01<C7@0=3AL030`F00l?6@0:2Q@07QhX0;nob@39bM<0820Z01dM9`0?
3aH02@X>00`=4@0@4AD01PL;00X;3`0A4QH500l@5008018D6@0931<00`H=01DH7`1ZKG@0:B`c01PK
8P0E61l400`?5P0601LJ7`000@@06A`Q01@G700:3A8000870P0=41L0@P0E61l05QTR00d@6@0?4Ad0
4QDM01HI800D5ad02@`A00lB5`0D61/01`/<01<G600C5aL0310?01DI600?4a<051TM010E6`0?51X0
4AHL010E6`0D6Al00@H<00X?5@0>4aT07B8X00/@5P0?51X08bP^00lD6P0D6B004QHO00dB600?51/0
8BD^00011`0G6b<051PQ00L<4P0D62004aLJ018F5`0?4aD03Q8E00hB500?4a@0310C014E5`0D61T0
51PK018F600B5QL06QhQ00X>4P0?51X05A`T00P@6@074AX02aDN01<K901oQXh0PXN=01<G6`0C5aX0
2`lB00hB5@802@d@00<041@G00hB5@0?4aH00P0>4QD05P0?4aH041@G014E5P0A5AH03a<C018F6@0C
5Q/04aHN01PK901<CeP051LP00/>5`0?4QT03A0E014F700>5B403Q@R00/A7@0<4Qh03Q8M00/?6P0C
5Ql201DE7@0701DD700B4AL03a0E014E5`0>4QD03a<F014E6002010D5`0N00/?4P0<3a@030lD00dA
5@0=41D0310C014E5P0=4A801`/<00T=3P0420T04aLH00`@4@0D61T0310A00X>3`0>4Q<03Q8B00@8
1`0?4a802Ph=01DI60093@`0310?018F5@0G6aX04ADD010D4`0?4a803A4A0P0>4Q<01P0@51D04ADF
018F5`0C5aP04ADF010D5@804ADF01003a<D01<G60011@H020`=00lC500830d09b//01<G60052@X0
310A01<G60093@h03a<D014E500=4Ph03A8?0P0D6AD01@0=4Ph03Q<=00hC3@0>4`d03Q<?00803Q<=
00`04aTG01LM6`0B61L010X:00dC4@0<4Q4010X:00881P093`h05adM014G5@0;4A8200`A5`0B00`A
5@0<4A@0318B00dC4P0<4Q003A<A00hC5@0=4QH0314E00`A5`094A<031<C00`B4P0;4A403Q<D018F
5`0>4Q<03a8C0`0@4A<02@0>4Q<03a<B010F500A5aD02a4?00D;2@0<4Q001@/900`B4002014G5@04
00`B40052`T02Q0>00/A3`803aDC0P093`d0300:40h03A<A00P>30032@L05Q`J00lE4`0<4Q004QPF
010F50093`d02Q0>00hD4P80318@0`0=4a407`0=4`l03A8=00/@30093PX03Q<?00hD4P093`d031DB
00dF5@0<5A@04Q`K00092P094a@01Q8B00@@400640l02a8A00hC3`0<3PT04A<@01HH5`0?4a@03a@F
00031P0?51L00@<301DI600D61L03Q8A00H:2@0@51<00P0<40l02`0?4a802`l>00/?3P0<40h041DA
014F4P0?51007B8N01XO6`0<4@d03A8>00@03Q<?00H04QLC00dB3P0I7QX09BXV018G4`0>4`l200lD
400R00L<200B5a<03Q<?00D:1P0@5@`02a4300`B200A5Ph03a@>00dB3P093@/020`;00dB3P062`D0
3a@>00/@2P0J7a/0720O010D4`17BdX0hNGT038f=@0;3`h01PX901<G5P000`802`l>01PM6P0F6aL0
2Pl900T>200<4@/03a@>00X?2@803A8<00`03Q<=00/@2P093PP02a0:00hC3`0;40`02@h:02H[9`0J
7a/041DA00X?2`0<4@d200hC3`0300lD400B5a<03Q<=00802Pl902/03a@>01DJ500D6A<03A8<00/@
2P0Z;bT0;C8/00lD3P093PP03a@>010E3`093PP04AH@00lD3P0;40X04aPB00`A2`0A5Q0041D?00/@
2P0F6aD03A<?00D:1P093`/01P`800`B3P0:3`T01``601<E400<3PT05ALB00P:1@0G6A@07R<M00L<
1P062`D02a0:01DJ500:3`T05AXD01HK5@0>4`d03a@>00804AH@00@03A4@00X>3@0:3Pd03Q8A0P0?
4a8201PL6`0401dQ800F6QT051PG00hB4@<0310C00<03Q8E00lC5P0?4aH00P0=4A@05`0>4QD03a<F
00lC5P0>4Q<03a<C00X>3@0<40l02`l>00X>3@0;3`h01@T8010D4`093@`04aLF00L;2P0?4a<04QHG
00D92P0@51D02`l@02da<P0=4A803a<D00802`l@0P0>4Q<05P0B5QH03Q8A00lC4P0?4a803Q8A00`@
3`0E6AP04QHE0001000Z;Rd0008100X>3@0D61L03A4@00lC4P0@51<03Q8A00lC4P031`H01PX900P<
2`0I7A`200X>3@0602db;P0D6AD02@h:01XO6`0D6AD01@X60P0<4@d01@0;40`02@h:00/@300A5Q80
3Q<?00@03A8>01/03Q<?00T>2P0>4`l04QLC00/@300730P02a0<010F4P0>51002a4=00T?2`0;4@d0
3A@=0003000:4@T01Pd500hF2`0840H04QX?00LA1P0>60l00@/301HO70012PP01Pl>00`E500<5A<0
0P094Pd07P0;5@`02Q@;0088100@5Q@03aDC010F50083P/041HB00hD400;4P`02A0900P?200;4P/0
4QTB00/?3P082P/01`/<018F5@0B5a@01@X6010E3`0<4@/03Q<=00hC300?50d04aPA01<H500@5A40
3a@@00hC3`<03A8>00L03a@@014F4P0C61@03a@@00dB300<4PL0318800803A<900T02a0900X?2008
3@L04aPD00`A3@0C5aH0CE5@024V8P0>4`d00P0=4P`200lD3P0@00hC3@0<4@/03a@>010E3`0>4`d0
2a0:010E3`0D6A<04AH@00hC3@0;40X02Pl900T>200=4P`03Q<=00dB308041D?00<03Q<=010E3`0@
5@l00P0?50h00`0@5@l03a@>00lD3P0200lD3P0800hC3@0=4P`02a0;010F4P0E6aL041HB00`B3P0=
4`l200hD400>018H500D6QH0318>00`B3P0B5a<01P/700dB3P083@T05Q/G00`A3@0J7a/03a@@01<H
500G71P200/@300300`A2`0>4`d041D?008041D?00<04aPB00dB300<4@/00P0>4`d01P0=4P`05Q/E
03@i=@2d^KD0ADY601dR7P802a0<00H04aPD018G4`0<4@d041DA01PM6@0E6QH200`C300F010F4P0F
71P04aTF00/A3`0E6aT03A<B01/Q8@083Ph0314C01@I700=5AP0:S<e01XR900A6A/03QDF01LM7@09
3`l051XI00dC4@0;4@l051TG00lE4aCooooo000Kooooo`0600X93P0<2a003@`A00d<4@0<2a002PT>
1P0;2Pl200h=4P08014@5@071P/03PdB010?500?3Q<05aHK01PG700?3Q<200X93P0500T83@0B4AH0
30/@00d<4@0<2a000P0:2@h200h=4P802`X?00D03@hA00T>3@093@d02@d=00T=3`0200/<400H00d>
4P0C4QT03`hE00h=500=31D02PTB00d=6@0821D03`hK00h>6`0<31T04Q4N018B7`17Ae@0Bd]H00d<
6@0G5R<030`D00T:3P0?41@03@hB00l@500F5a/03@hB1@0>3a<09P0?4AH02`hE00d@5`0B5A`06A`S
00D83`0@4aX02`hE00`?5P0;3QD061/R00T<4`0m@4L07b8X00hA5`0B5A/05aXP01<F7P0>4AT04aDP
02T/=P0S9C402P`I00lA7@0A4R006AXY00h@7`0>41d04Q@O00hA6`0A51/01`XA00lC5`0V:Rd09b/]
010D5P0?51P03a@I0P0E6Ql0600=4QL02a0E01HK800?51T04AHK00H;400@5AX041DI00dC4P0D6QL0
5ahJ00lE4P0B61D04APD00P?2`0H7Q/03aDB01HL6@0G7AX020d:01<G5`0B5QH03a<C00dA4@803Q8B
01@05ATI014E5@0=4A40310@00hB4P0@51@02@d=01@I6`0@5AT03aHL01TS:`2FX:T0CeUR01<L900U
;3808BHZ018F600;3a003Q8E01DI708041@G01/061`O018F6@0B5QT041@G00lC5P0B5QT04aLJ018F
5`0G6aX04QHF01<G600A51T03Q4H014D7@0B5Ah07R4Z00T<5@0>4AL051LL00lD6P0B6BD04ALU010F
900>52003Q8M00dA700@4a`00P0C4a/02P0E51/05A@J01@E6@0?4Q802`l?010D500@51H03A4D00hB
5@0?4QH300hA5`0D00hA6@0?4QP02Ph@00/?400@51D0;30a00hB4`0?4a@02`l@014E5P0=4A803a<D
01<G600D61P02@d<01@H5`0?4a804aLF00L;2P0@51<200lC4P80310?00P03a<B018F5P0A5AH04ADF
00lC500=4A80310A00dA4P803Q8C01004QHG01@H6@0C5aP03a<D01@H6@0@51D041<D00lC500=4A80
2Ph?01@H6@0B5QL02Ph?018F5`0@51D04ADE0P0=4A406P0?4a80310>00dB3P0>4`d03A8<00`A2`0;
40X0318900hC2`0:3`X02a4>018F500=40h02Q0=010E4P0A51802a0=00hC400B5A<020d:00lC4P0@
5A/03a@J00hC5`0<4A@03A<C0P0>51403`0?5A<03aDE00`A5@0;41@03A8I00dD5P0>5A@0318B00/A
4@0=4Q<04QHG00lC500@4Q@03a0B010@4P02014B500300X>3@0;4@l04QPF00803aDC00<08BLU00lE
4`0?5A<00P0A5aD200lE4`0400hD4P0;4@l02Q0>00/A3`803Q@B00L020h<00lE4`0<4Q002@l=01`R
800D6QP02a4?00803aDC00@02Q0>00/A3`0>5180318@0`0=4a40:@0<4Q002a4=00lD3`0>4`l0314=
010E4@0?5A<02@l=00/B3`0<5A@03AHE00hF5@094a@02Q@E00`G5@084Q40214>00hB3`0C5A004Q@>
00l?2P0?3``03@l=00hA4@0B5QP07b@T02L[:P0?4a801@T800hB4@072`X03A4@00`@3`0=4A003Q8A
00P<2`0:3Pd0310>00dB3P0>4`l02a0<00803A8>00<0314=00dB3P0<4@d00P0;40`01`0=4Ph051TE
010E4@0B5a<03a@@00P=2@0=4Ph01@0>4`l06`0;40`02a0700dC1@0<4PP0318:00dB300>4`l03A8?
00/?3P0J7a/041D?01<H4P0<4@X0314=00861@0>4Q404ADD02hb<@0?4a804ADD00H:2@0<3Pd020`;
014E500;40d01``800hC3@0200`A2`0400dB300<4@/02a0:00X?2@803a@>00/02Pl900`A2`0?5100
0PH3010E4@0f>cL05AXF00lD400:3`/0314=00dB3P0200`A3@0C00lD400?50h03Q<=00hC3@0?50h0
51TC01LL5P0F6aD0314;014F400@5@l01P/500hC3@093PP0314;00P=1`0?50h02a0:00hC3@0201@I
4`0I00hC3@0:3`T02Pl900hA300A4`d04Q@>00d?1`082@D05aPC00h@2P0<3PP0418=01<E400F61<0
3A0<00dA2`0=4P`0314;00X?2@0C61802a0:00T>200?50h05AXD01@I4`0200`A2`0500dB300=4A00
2Ph=00X>3@0>4Q400P0@51<01`0A5A@03A4@00lC4P0<40l03a<B00L;300=4A@00P0<41@05`0=4AD0
3a8F00lC5`0?4QH03a<G010D600A51P03a8F00hB5@0=4A402`l>014E500>4Q402`l>014E50072`X0
5QXI00`@3`0Q9B@0310?00dA4@011@H06AdN00802Ph?00<03a<D00X>3`0A5AH00P0=4A807@0?4a@0
3Q8C01@H600A5A@041@C00hB4@0<40l02`l>00hB4@093@`03A4@03i2@@0<40l051PG00hA400B5QD0
51PG01<G5P0A5A@041@C014E50031`H04aHE04iBD@0K7ah04QHE00`A3@0>4`l03a@@00803Q<?00T0
4AHB010E4@0>4`l0314=00lD400A5Q804QLC00lD400>4`l00`0=4Ph0400?51002a0<00hC3`0@5A40
3A8>00/@300<4@d01`d900dC3`0@5Q803Q@@010F4P0>5@h031<;018I4@052P@200lG300?00hF2`07
4@H03AL=00@?1`0@6QL0?TM501lX:00:51@031HD00LA30084P`03AP?00`F3@0@5Q8092XX008051XH
01D04aTF00D91P0>51003A<>00hE3P0;4P/020l800lF3`15BDT0<3@e014E5P0<40l03Q<@00dB3P0=
4P`02a0900hC3@0>4``0318900lD3@0>4`h00P0<4@d200/@300400`A3@0?510041DA014F4P8041DA
00<041D?00hD2@0?5@/00P0?5@/02`0<4@X02Pl800hC3@042@D05Q/G00`@3`0E6AP02a0<00lD3`0>
4`d0314;008041D?00X02a0:00T>200>4`d03a@>00hC3@0=4P`03a@>00`A2`0:3`T03A8<0P0@5@l0
100A5Q0051TC018G4@0=4P`300lD3P07010E3`0=4P`03Q<=01DJ500A5Q003A8<014F400201<H4P04
014F400?50h03A8=00dC3`803Q@@00d03A<?00hD400?5A402Q0<00dC3`0C6AD03aDA01@J5P0L8Qh0
4QLC00dB3P0:3P/05AXF00803a@@00P02@h:00hC3`0B5a<03A8>018G4`0=4P`03Q<=014F408041D?
02/04aPB01DJ500@5@l03a@>018G4@0?50h041D?00/@300S:2@05Q/G00/@300=4Ph03a@@00L<200B
5a<04AHB00T>2P0?51004QLC00P?200;4P/041HB014G4`0A5a@041HD014G5@0C6AP03Q@D010F5P0D
6A/03Q<F01HK7`0>51L04ALJ00/B500>51D03aDE014I600=5A<03ADB00lG500>5a@031HB01Cooooo
000Kooooo`<03@`A00<03PdB010?500@3a@01P0;2Pl0=@0>3A802@P=00H52P0920d03PdB00`;4009
20d01@@900P7300?3Q<03@`A00P7300;2`l06aXO00h=4P0A41D020L<00L62`0>3A8030/@00d<4@0?
3Q<03@`A00T:30093P`0310?00dA400=4A803@hB00`=4@0=3Q<03@`D010?5`0?3AP02@LB00P64@0:
2AL040lM01<B800@3ad02@PF00H54`0B4Al08B0^06MVM00A41h05aHT03Hg?`0N7b<020T=01@E6@07
20`030dA00H03PlC02P030hD010C6P062A001PT@010C6P0I72<020/B020S:P0C5Qd02`hE00H94007
2Q405APO02<V;@0000L04A@K04M:D@1FFF806A`V00/=6@0@4Qh05ALS010B7`0B52405QPY030aAP0A
4RH051DY01@E9`0<3Q`0000=01@G800F6B402PdB01TL8@0@51L06AhR014F6P0<4AD041DI0P0?51P0
2P0=4QH04aPL00/@500<4AD04AHJ00hD5P073PL0620E01@L4@0?5``2018J3`0=01DM4P001@004a/@
00D=0P0840D05A`C00X?2`0;3`h03Q8A00lC4P0>4Q40310?014E5002010D4`804QHE0P0@51<0500@
51D02Q8D01lV;00K9B`0[[S10>7[m00Z=3/03QPJ00H;3`0?51D05a/J00H:3@0@51L02`lB00`@4`0D
61/02`lB01@H6`0?4aH03A4D0P0?4aH05P0<41404aLF010D4`0A5AH041<H00hA600A51d051LP0044
3@0H6b806A`R01XM8P0@5A/031<P00/A7`0=4b402a4M00`@6`0=4A`051LP01<C6`0A4AT2014@5P0:
010A5@0?4Q003Q8A01HJ6@0E6AX0310C00dA500>4AH030lF00/>5@802`hG00X02`hE01DI6`0<4140
00@501@H6@021PL04ADF00dA4P0>4Q<02`l@0P0>4Q<03P0@51@061`K00D9200D61L00`L601HJ6@0A
5A@02@d<00/?3P0@51<02Ph=00T=300?4a<041@E0`0A5AH2010D5@0500hB4`0?4a@04ADF014E5P0>
4Q<00P0?4a@0200:3Pl03A4B01HJ6`000P<04QHG01HJ6`0830d03Q8C0P0:3Pl0:@0;3a003A4B010D
5@0:3Pd02@d<020U8@0<4@/02a0:00X?20093`D02Q0600`B1`0K7AP0008000lA3P082PL09bTV00h@
3@0B51403a4>018D4@0<3P/01@L400lB400B5A`041DK00dB5`0;41<02a4?00`B3`0>510041HB010F
5P0<4AD02a0D00hC6P0@5AP03aDE00`B4P093`l0314A008041@E00L03a8C00h?4@0?3a404A4C018C
5@0C5aH020h<00803A<A00@02a4?01PN700F71X04aTG0P1bN7H0300C6AL05Q`J00T?3@0A5aD041HD
00`B400;4@l0318@01<I5`0;4@l04ALE00X@3P8020h<00H02Q0>00dC4@0<4Q002a4?00`B400=4a42
00/A3`0800dC4@0C6AL06R0N01hT800=4Pd04aPD00lD400=4Ph200dC4@0:00/D4@063`h01@h=00/D
4`0230d031HG00PB4@0>5a@03aDA00X>2@802``600H04A0;00/<1`0@4@`030h=01DI6P0:3Pl201<G
5P05010D4`0>4Q4010P700dA400;3`h00P0=4A002P062PT020`;00dA3`0<4@d03a@@014F4P0;40`0
3a@@01PM6@0@5A4200T>2P0P00hC3`0=4Ph03Q<?00lD400B5a<03A8>01DJ5P0P9B404QLC02db;P14
BDD03a@@00870`0G71P0318900dC1@0B60h04aP@014F400?510041@B00D9200@5A403A8<00<80P0<
4@X01``801`P7`0=4A004aLF00H:2@0=4A0200`@3`0I010D4`0;3`h02Ph=00lC4@0>4`l041D?00D:
100I7QP092TS01@I4`083@L01``600lD3P0A5Q002a0:00`A2`093PX051TE00dB3P0A5Q8061dI018G
4`0:3`/0314=00dB3P0200X?2`0M00/@30083@L03Q<=00lD3P0<4@/02a0:00dB30001@005AXD00hC
3@0;40X04AH@00@90`0<4@/04AH@00dB300?50h020d7010E3`0A5Q00<CH`01LL5P0:3`T06AhH00`?
200>3`T010@001LG3`0E5@d00P0;30H04`0D5a002`d900/=200;3@P05QXD018G4@0?50h04aPB00D:
100B5a402@h801`Q6`0S:2801@X401DJ500<4@/02@h801PM5`0?4a800P0;3`h00`0=4A003Q8A00dA
4002010D4`0800hB4@072`X04ADD00hB4`0?4QH030lD00/>4`0<3a@200hA5P0Q018E6P0C5Q/04QDJ
010C600=41D02`lB00X>3P062PT03Q8A00/?3P0:3Pd041@C00040`0A5A@01PX902<W9P0830/02`l?
01hR8`031`P03a<D01LK7013AdP03a<D01@H6@0@51D03Q8C00`@4@093@h041@D00hB4@0=4A002`l>
00<02Ph=01X01`/:014E500=4A004ADD00P<2`0;3`h041@C018F5@0A5A@0310?00X>3@0A5A@06alN
00dA400J7Qd0310?00/=300D6AD04AHB00<8100:3`/06QlK01<H500@5A403Q<?014F4P806AhJ0P0@
5A40?00?51003A8>00`A3@0=4Ph041DA01@I5@0=4Ph01``800hC3`0B5a<03A8>00T?2`0?5A403Q@@
00L=2@0<4Ph04APA01<J4P0;4@X061lG00D=0P094@H01Q05014K400;5P`051lG00TD402S[J`0D5YK
00dG600B71/031LA00XE3`0;5`d0110600D;1`0?5A<0008001PN700k@Ch082HR01PN6P083PT010/4
00L>1`0>5@d06R4J01/O800N8R@041@E00`@3`0<40h02Pl;00lD3P0>4``04QL@010E3P0=4`T03a@=
00dB3@80314=00<03A8>00hC3`0>4`l00P0<4@d200/@300A00dB3P0?50h03Q@9010F300A5`d03aD;
00`A2P0:3`P0314;00hC3`083@T03A4@00H:2@0F6aL041D@00lD3P0;40X00P0@5@l0;P093PP03Q<=
00hC3@0<4@/02a0:010E3`0B5a40314;00X?2@0=4P`04AH@010E3`0A5Q0051TC018G4@0=4P`04QLA
01@I4`0B5a404AH@00hC3@0G71H08bPR01TN600:3`T0314;00lD3P0B5a404AH@00lD3P0@5Q403Q@@
00/A3@0<4Ph03Q@@00lE4@0>51001`d900P>2P0=4`l01@/700P>2P0B5a<020d9010E4@0K81`200lD
400700hC3`0;40`020d900L<20093PX04aPD014F4002018G4@0400lD3P0=4P`03a@>01HK5@803Q<=
00D061dG01LL5P0A5Q004aPD020U8@0200hC3`0N01XO6`0<4@d01``8024V8P0/<Bd04QLC00hC3`0H
7AT041L@01XQ6P0N92003A<?00X@3@0E6aT01`d;04A:B@0H7Qh01P`<00hC5@0E6Qd06ahS01<F6P0G
6ah01@X=00hD5@0A5aL051dL00H?3@0Z<c00<3/g0P0=61@Dooooo`00oooooooooooooooooooo;Ooo
ool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooo
oooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{270.188, 270.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 7.9 The Andromeda galaxy, at a distance of roughly 2 million \
light years, is the nearest galaxy to our own milky way. Photo Credit:  Bill \
Schoening, Vanessa Harvey/REU program/NOAO/AURA/NSF.\
\>", "Caption",
  CellTags->"Fig. 7.9"],

Cell["\<\
\tHowever, stars interact with many other stars at the same time, \
and the net effect of all these weak interactions is that the galaxy is \
gravitationally bound together. We cannot completely neglect gravity in any \
model of galactic  dynamics; without it,  the galaxy would simply fly apart. \
\
\>", "Text"],

Cell[TextData[{
  "\tWe could, of course, try to keep all of the binary interactions between \
the stars, using a molecular dynamics code to model the  evolution. However, \
the number ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " of stars that can be handled with such a code is at most a few thousand, \
even on very fast  computers. This is because the number of interacting pairs \
equals ",
  Cell[BoxData[
      \(TraditionalForm\`N\ \((N - 1)\)/2\)]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`N = 10\^3 - 10\^5\)]],
  " is insufficient to handle many problems in galactic dynamics, considering \
that the galaxy contains roughly ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " stars (not to mention dust, gas, and other material such as \"dark matter\
\")."
}], "Text"],

Cell[TextData[{
  "\t One approach to modeling large collections of self-gravitating material \
is to go back to the picture of a collisionless gas. For simplicity, we \
consider here a system of identical particles  of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", and with phase-space density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". The evolution of this density is determined by the collisionless \
Boltzmann equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]f\/\[PartialD]t\), "+", 
            RowBox[{
              FractionBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["m",
                  FontWeight->"Plain"]], "\[CenterDot]", \(\[Del]f\)}], "-", 
            RowBox[{"m", " ", 
              RowBox[{\(\[Del]\[Phi]\), "\[CenterDot]", 
                FractionBox[\(\[PartialD]f\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["p",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}]}], "=", "0"}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->{"i:54", "(7.3.1)"}],

Cell[TextData[{
  "However,  the gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is not imposed from some external source; rather,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is created by the mean density itself via Newton's law of gravitation [in \
differential form, Poissons equation ",
  ButtonBox["(4.3.78)",
    ButtonData:>{"Chapter4.nb", "(4.3.78)"},
    ButtonStyle->"Hyperlink"],
  " ]:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 4  \[Pi]\ G\ \[Rho]\)]],
  ","
}], "NE3",
  CellTags->"(7.3.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = 
        m\ \(\[Integral]f \(\(\[DifferentialD]\^3 p\)\(\ \)\)\)\)]],
  " is the mass density."
}], "Text"],

Cell[TextData[{
  "\tWe should think of  the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " as a reasonably  smooth function of position. This density does not \
contain information concerning the position of individual stars, but rather \
is the mean density of matter  at any given point, averaged over a \"small\" \
volume element (but one that is much larger than the mean distance between \
stars, so that many stars are contained in an element). Thus, the \
gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " does not tell us about the interaction between individual pairs of stars. \
 Rather, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is the mean potential due to the smooth \"fluid\" of stars (and anything \
else that contributes to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tThis is, in part,  why it is acceptable to take the mass of all the \
stars to be the same: in our model only the mean mass density of the matter \
is important to the mean potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ".  Also, the gravitational acceleration of a particle is independent of \
that particle's mass: a heavy and a light star will behave identically in a \
given mean potential.  Therefore, we can safely assume our system consists of \
a distribution of like-mass stars."
}], "Text"],

Cell[TextData[{
  "\tIt is worthwhile to note that Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  can also be applied to high-temperature plasmas, which are also nearly \
collisionless. Now ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is the phase-space density of some species of charged particle, and the \
Coulomb interaction replaces the gravitational interaction. (However, it is \
now important to follow distributions for each species separately because \
particle acceleration now depends on both mass and charge.) In fact, \
equations of this general form appear in several area of physics. Some \
examples will be discussed in the exercises."
}], "Text"],

Cell[TextData[{
  "\tAlthough Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  are much easier to deal with than Newton's equations for all ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " stars in the galaxy, these equations are still difficult to solve. The \
problem is that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " depends on  the momentum integral over ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", so Eq. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  is  really a nonlinear equation for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". Analytic  solutions of these equations can only be obtained in certain \
highly simplified cases. "
}], "Text"],

Cell[TextData[{
  "\tIn this section, we will discuss one method for solving this nonlinear \
system numerically, called the particle-in-cell (PIC) method. We will then \
consider a few examples, focusing on the phenomenon of gravitational \
collapse. Our examination of this complex process is necessarily limited in \
scope [for more detail see, for example,  ",
  ButtonBox["Binney and Tremaine (1987)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "], but  it is hoped that the simulation results give some flavor of what \
can be accomplished using the PIC method. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.2 Strategy of the PIC Method", "Subsubtitle",
  CellTags->"c:29"],

Cell[TextData[{
  "\tWe will solve Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "   and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  in periodic boundary conditions in two spatial dimensions. (The \
following code can be easily modified for three spatial dimensions, but runs \
too slowly to be of much utility, unless it is adapted for use with a \
compiled language such a Fortran or C, and run on a fast computer. Modifying \
the code to run in one dimension is left to the exercises.) The simulation \
box contains the ranges  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < L\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t The strategy  for solving Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  in this periodic 2D domain is similar to that used previously in solving \
the collisionless Boltzmann equation: basically, we solve for the dynamics of \
a large number of particles, and determine the density using histograms of \
the particle positions. These particles should not be thought of as \
individual stars. Rather, a single particle  represents  a whole cloud of \
stars, and is located at this cloud's center of mass. The mean density is a \
superposition of these clouds. Thus, we can still model a galaxy or other \
large stellar system using far fewer than ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " particles."
}], "Text"],

Cell["\t  Broken down into individual steps,  at each time step, ", "Text"],

Cell[TextData[{
  "(1) We make a histogram of the particle positions on an ",
  Cell[BoxData[
      \(TraditionalForm\`M\ by\ M\)]],
  " spatial grid in order to determine the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " on  the grid."
}], "Text"],

Cell[TextData[{
  "(2) We use this density in Poissons equation to solve for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the grid using Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  " . We also determine  the gradient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " (i.e. the force field), evaluated at the grid positions. "
}], "Text"],

Cell["\<\
(3) We then interpolate the force field  from the values at the \
grid positions back to the particle positions, and update the positions and \
velocities of the particles to the next time step using Newtons second law.\
\
\>", "Text"],

Cell[TextData[{
  " These three tasks are shown schematically in Fig. ",
  ButtonBox["7.10",
    ButtonData:>"Fig. 7.10",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015625 0.31746 [
[ 0 0 0 0 ]
[ 1 .65625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .65625 L
0 .65625 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.015625 0.321429 0.313244 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -10.625 0 ]
[.5 .82364 10.625 12.9375 ]
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -71.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
75.000 14.562 moveto
(j) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38897 .58867 .40512 .60371 .43216 .5956 .41618 .58041 Metetra
.664 .741 .908 r
.41618 .58041 .43216 .5956 .45948 .58741 .44367 .57206 Metetra
.664 .741 .908 r
.44367 .57206 .45948 .58741 .48707 .57913 .47145 .56362 Metetra
.664 .741 .908 r
.47145 .56362 .48707 .57913 .51495 .57077 .4995 .5551 Metetra
.664 .741 .908 r
.4995 .5551 .51495 .57077 .54311 .56232 .52785 .54649 Metetra
.664 .741 .908 r
.52785 .54649 .54311 .56232 .57156 .55378 .5565 .53779 Metetra
.664 .741 .908 r
.5565 .53779 .57156 .55378 .6003 .54516 .58544 .529 Metetra
.664 .741 .908 r
.58544 .529 .6003 .54516 .62935 .53645 .61469 .52012 Metetra
.664 .741 .908 r
.61469 .52012 .62935 .53645 .6587 .52764 .64425 .51114 Metetra
.664 .741 .908 r
.64425 .51114 .6587 .52764 .68836 .51874 .67412 .50207 Metetra
.664 .741 .908 r
.67412 .50207 .68836 .51874 .71833 .50975 .70431 .4929 Metetra
.664 .741 .908 r
.70431 .4929 .71833 .50975 .74862 .50066 .73483 .48363 Metetra
.664 .741 .908 r
.73483 .48363 .74862 .50066 .77923 .49148 .76568 .47426 Metetra
.664 .741 .908 r
.76568 .47426 .77923 .49148 .81018 .4822 .79686 .46479 Metetra
.664 .741 .908 r
.79686 .46479 .81018 .4822 .84146 .47281 .82838 .45522 Metetra
.664 .741 .908 r
.82838 .45522 .84146 .47281 .87308 .46333 .86025 .44554 Metetra
.664 .741 .908 r
.86025 .44554 .87308 .46333 .90504 .45374 .89247 .43576 Metetra
.664 .741 .908 r
.89247 .43576 .90504 .45374 .93736 .44404 .92505 .42586 Metetra
.664 .741 .908 r
.92505 .42586 .93736 .44404 .97003 .43424 .95799 .41586 Metetra
.664 .741 .908 r
.37251 .57335 .38897 .58867 .41618 .58041 .3999 .56493 Metetra
.664 .741 .908 r
.3999 .56493 .41618 .58041 .44367 .57206 .42757 .55642 Metetra
.664 .741 .908 r
.42757 .55642 .44367 .57206 .47145 .56362 .45552 .54782 Metetra
.664 .741 .908 r
.45552 .54782 .47145 .56362 .4995 .5551 .48377 .53914 Metetra
.664 .741 .908 r
.48377 .53914 .4995 .5551 .52785 .54649 .51231 .53036 Metetra
.664 .741 .908 r
.51231 .53036 .52785 .54649 .5565 .53779 .54115 .52149 Metetra
.544 .699 .941 r
.54115 .52149 .5565 .53779 .58544 .529 .57039 .51998 Metetra
.689 .855 .962 r
.57039 .51998 .58544 .529 .61469 .52012 .59985 .50821 Metetra
.357 .681 .978 r
.59985 .50821 .61469 .52012 .64425 .51114 .63006 .51134 Metetra
.039 .608 .724 r
.63006 .51134 .64425 .51114 .67412 .50207 .66064 .51029 Metetra
.793 .98 .706 r
.66064 .51029 .67412 .50207 .70431 .4929 .69002 .47571 Metetra
.664 .741 .908 r
.69002 .47571 .70431 .4929 .73483 .48363 .72077 .46626 Metetra
.664 .741 .908 r
.72077 .46626 .73483 .48363 .76568 .47426 .75185 .4567 Metetra
.664 .741 .908 r
.75185 .4567 .76568 .47426 .79686 .46479 .78327 .44704 Metetra
.664 .741 .908 r
.78327 .44704 .79686 .46479 .82838 .45522 .81504 .43727 Metetra
.664 .741 .908 r
.81504 .43727 .82838 .45522 .86025 .44554 .84716 .42739 Metetra
.664 .741 .908 r
.84716 .42739 .86025 .44554 .89247 .43576 .87963 .4174 Metetra
.664 .741 .908 r
.87963 .4174 .89247 .43576 .92505 .42586 .91248 .4073 Metetra
.664 .741 .908 r
.91248 .4073 .92505 .42586 .95799 .41586 .94569 .39709 Metetra
.664 .741 .908 r
.35574 .55773 .37251 .57335 .3999 .56493 .3833 .54915 Metetra
.664 .741 .908 r
.3833 .54915 .3999 .56493 .42757 .55642 .41115 .54048 Metetra
.664 .741 .908 r
.41115 .54048 .42757 .55642 .45552 .54782 .43929 .53172 Metetra
.664 .741 .908 r
.43929 .53172 .45552 .54782 .48377 .53914 .46772 .52286 Metetra
.664 .741 .908 r
.46772 .52286 .48377 .53914 .51231 .53036 .49646 .51391 Metetra
.578 .713 .935 r
.49646 .51391 .51231 .53036 .54115 .52149 .5255 .51049 Metetra
.754 .248 0 r
.5255 .51049 .54115 .52149 .57039 .51998 .55532 .54882 Metetra
.55532 .54882 .57039 .51998 .59985 .50821 .58481 .50329 Metetra
.75 .231 0 r
.58481 .50329 .59985 .50821 .63006 .51134 .61614 .53782 Metetra
.255 0 .09 r
.61614 .53782 .63006 .51134 .66064 .51029 .64678 .52206 Metetra
.64678 .52206 .66064 .51029 .69002 .47571 .6777 .50739 Metetra
.128 0 .098 r
.6777 .50739 .69002 .47571 .72077 .46626 .70812 .47929 Metetra
.015 0 0 r
.70812 .47929 .72077 .46626 .75185 .4567 .73945 .46501 Metetra
.7 .946 .659 r
.73945 .46501 .75185 .4567 .78327 .44704 .76967 .43249 Metetra
.706 .802 .924 r
.76967 .43249 .78327 .44704 .81504 .43727 .80142 .41895 Metetra
.664 .741 .908 r
.80142 .41895 .81504 .43727 .84716 .42739 .83379 .40887 Metetra
.664 .741 .908 r
.83379 .40887 .84716 .42739 .87963 .4174 .86653 .39867 Metetra
.664 .741 .908 r
.86653 .39867 .87963 .4174 .91248 .4073 .89965 .38836 Metetra
.664 .741 .908 r
.89965 .38836 .91248 .4073 .94569 .39709 .93314 .37793 Metetra
.664 .741 .908 r
.33865 .54182 .35574 .55773 .3833 .54915 .36639 .53307 Metetra
.664 .741 .908 r
.36639 .53307 .3833 .54915 .41115 .54048 .39441 .52423 Metetra
.664 .741 .908 r
.39441 .52423 .41115 .54048 .43929 .53172 .42274 .5153 Metetra
.664 .741 .908 r
.42274 .5153 .43929 .53172 .46772 .52286 .45136 .50627 Metetra
.664 .741 .908 r
.45136 .50627 .46772 .52286 .49646 .51391 .48029 .49714 Metetra
.468 .667 .949 r
.48029 .49714 .49646 .51391 .5255 .51049 .50948 .49878 Metetra
0 .464 .861 r
.50948 .49878 .5255 .51049 .55532 .54882 .53922 .51022 Metetra
.667 .591 .761 r
.53922 .51022 .55532 .54882 .58481 .50329 .56933 .49653 Metetra
0 .431 .76 r
.56933 .49653 .58481 .50329 .61614 .53782 .60022 .50631 Metetra
.656 .623 .805 r
.60022 .50631 .61614 .53782 .64678 .52206 .63116 .49586 Metetra
.604 .637 .856 r
.63116 .49586 .64678 .52206 .6777 .50739 .66269 .49133 Metetra
.692 .776 .916 r
.66269 .49133 .6777 .50739 .70812 .47929 .69426 .47898 Metetra
0 .574 .714 r
.69426 .47898 .70812 .47929 .73945 .46501 .72694 .47941 Metetra
.407 0 0 r
.72694 .47941 .73945 .46501 .76967 .43249 .76023 .48035 Metetra
0 0 .069 r
.76023 .48035 .76967 .43249 .80142 .41895 .78784 .40419 Metetra
.71 .808 .926 r
.78784 .40419 .80142 .41895 .83379 .40887 .82015 .38995 Metetra
.664 .741 .908 r
.82015 .38995 .83379 .40887 .86653 .39867 .85316 .37954 Metetra
.664 .741 .908 r
.85316 .37954 .86653 .39867 .89965 .38836 .88654 .36901 Metetra
.664 .741 .908 r
.88654 .36901 .89965 .38836 .93314 .37793 .92032 .35836 Metetra
.664 .741 .908 r
.32123 .5256 .33865 .54182 .36639 .53307 .34914 .51668 Metetra
.664 .741 .908 r
.34914 .51668 .36639 .53307 .39441 .52423 .37735 .50766 Metetra
.664 .741 .908 r
.37735 .50766 .39441 .52423 .42274 .5153 .40586 .49855 Metetra
.452 .663 .952 r
.40586 .49855 .42274 .5153 .45136 .50627 .43438 .50055 Metetra
.126 .641 .892 r
.43438 .50055 .45136 .50627 .48029 .49714 .46338 .50321 Metetra
.46338 .50321 .48029 .49714 .50948 .49878 .49301 .49622 Metetra
.562 .911 .968 r
.49301 .49622 .50948 .49878 .53922 .51022 .523 .48572 Metetra
.386 .541 .888 r
.523 .48572 .53922 .51022 .56933 .49653 .55348 .4945 Metetra
.223 0 0 r
.55348 .4945 .56933 .49653 .60022 .50631 .5846 .50166 Metetra
.929 .889 .77 r
.5846 .50166 .60022 .50631 .63116 .49586 .61492 .45518 Metetra
.122 .259 .733 r
.61492 .45518 .63116 .49586 .66269 .49133 .64791 .49006 Metetra
.842 .98 .872 r
.64791 .49006 .66269 .49133 .69426 .47898 .67915 .46146 Metetra
.673 .759 .915 r
.67915 .46146 .69426 .47898 .72694 .47941 .7114 .45034 Metetra
.078 .311 .792 r
.7114 .45034 .72694 .47941 .76023 .48035 .74666 .47888 Metetra
.987 .867 .628 r
.74666 .47888 .76023 .48035 .78784 .40419 .7746 .39764 Metetra
.838 .943 .892 r
.7746 .39764 .78784 .40419 .82015 .38995 .80622 .37064 Metetra
.664 .741 .908 r
.80622 .37064 .82015 .38995 .85316 .37954 .8395 .36001 Metetra
.664 .741 .908 r
.8395 .36001 .85316 .37954 .88654 .36901 .87316 .34925 Metetra
.664 .741 .908 r
.87316 .34925 .88654 .36901 .92032 .35836 .90722 .33837 Metetra
.664 .741 .908 r
.30346 .50906 .32123 .5256 .34914 .51668 .33156 .49996 Metetra
.664 .741 .908 r
.33156 .49996 .34914 .51668 .37735 .50766 .35995 .49077 Metetra
.664 .741 .908 r
.35995 .49077 .37735 .50766 .40586 .49855 .38865 .48148 Metetra
.533 .697 .944 r
.38865 .48148 .40586 .49855 .43438 .50055 .41741 .47991 Metetra
.814 .366 0 r
.41741 .47991 .43438 .50055 .46338 .50321 .44533 .53284 Metetra
.747 .383 .365 r
.44533 .53284 .46338 .50321 .49301 .49622 .47481 .57722 Metetra
.013 0 .217 r
.47481 .57722 .49301 .49622 .523 .48572 .50628 .50429 Metetra
.194 0 0 r
.50628 .50429 .523 .48572 .55348 .4945 .53715 .49369 Metetra
.544 0 0 r
.53715 .49369 .55348 .4945 .5846 .50166 .56871 .51083 Metetra
.926 .972 .697 r
.56871 .51083 .5846 .50166 .61492 .45518 .59962 .46047 Metetra
.856 .434 .224 r
.59962 .46047 .61492 .45518 .64791 .49006 .63388 .52601 Metetra
.63388 .52601 .64791 .49006 .67915 .46146 .66405 .45132 Metetra
.878 .876 .829 r
.66405 .45132 .67915 .46146 .7114 .45034 .69538 .41623 Metetra
.199 .355 .796 r
.69538 .41623 .7114 .45034 .74666 .47888 .73044 .44219 Metetra
.553 .555 .81 r
.73044 .44219 .74666 .47888 .7746 .39764 .76479 .44279 Metetra
.76479 .44279 .7746 .39764 .80622 .37064 .79292 .36191 Metetra
.786 .921 .928 r
.79292 .36191 .80622 .37064 .8395 .36001 .82554 .34005 Metetra
.664 .741 .908 r
.82554 .34005 .8395 .36001 .87316 .34925 .85949 .32906 Metetra
.664 .741 .908 r
.85949 .32906 .87316 .34925 .90722 .33837 .89384 .31795 Metetra
.664 .741 .908 r
.28535 .49219 .30346 .50906 .33156 .49996 .31362 .48291 Metetra
.664 .741 .908 r
.31362 .48291 .33156 .49996 .35995 .49077 .34221 .47354 Metetra
.612 .726 .927 r
.34221 .47354 .35995 .49077 .38865 .48148 .37093 .46761 Metetra
.034 .476 .881 r
.37093 .46761 .38865 .48148 .41741 .47991 .3994 .47844 Metetra
.742 .233 .001 r
.3994 .47844 .41741 .47991 .44533 .53284 .42801 .5076 Metetra
.526 .615 .884 r
.42801 .5076 .44533 .53284 .47481 .57722 .45823 .50822 Metetra
.658 .519 .683 r
.45823 .50822 .47481 .57722 .50628 .50429 .48922 .48666 Metetra
.768 .775 .859 r
.48922 .48666 .50628 .50429 .53715 .49369 .52034 .46548 Metetra
.741 .685 .797 r
.52034 .46548 .53715 .49369 .56871 .51083 .55159 .443 Metetra
.492 .416 .698 r
.55159 .443 .56871 .51083 .59962 .46047 .58358 .45538 Metetra
.729 .2 0 r
.58358 .45538 .59962 .46047 .63388 .52601 .61703 .49121 Metetra
.806 .683 .728 r
.61703 .49121 .63388 .52601 .66405 .45132 .64878 .44747 Metetra
.245 .742 .908 r
.64878 .44747 .66405 .45132 .69538 .41623 .68224 .44525 Metetra
.68224 .44525 .69538 .41623 .73044 .44219 .71406 .40538 Metetra
.42 .48 .816 r
.71406 .40538 .73044 .44219 .76479 .44279 .74928 .41776 Metetra
.842 .753 .765 r
.74928 .41776 .76479 .44279 .79292 .36191 .78112 .37644 Metetra
.723 .881 .481 r
.78112 .37644 .79292 .36191 .82554 .34005 .81189 .3263 Metetra
.74 .851 .932 r
.81189 .3263 .82554 .34005 .85949 .32906 .84552 .30844 Metetra
.664 .741 .908 r
.84552 .30844 .85949 .32906 .89384 .31795 .88016 .29707 Metetra
.664 .741 .908 r
.26687 .47499 .28535 .49219 .31362 .48291 .29533 .46553 Metetra
.664 .741 .908 r
.29533 .46553 .31362 .48291 .34221 .47354 .3241 .45596 Metetra
.454 .665 .953 r
.3241 .45596 .34221 .47354 .37093 .46761 .35261 .45739 Metetra
.427 .76 .996 r
.35261 .45739 .37093 .46761 .3994 .47844 .38175 .45597 Metetra
.51 .635 .909 r
.38175 .45597 .3994 .47844 .42801 .5076 .41129 .45655 Metetra
.168 .246 .701 r
.41129 .45655 .42801 .5076 .45823 .50822 .44052 .4902 Metetra
.035 .427 .867 r
.44052 .4902 .45823 .50822 .48922 .48666 .47121 .50489 Metetra
.47121 .50489 .48922 .48666 .52034 .46548 .50302 .475 Metetra
.744 .282 .152 r
.50302 .475 .52034 .46548 .55159 .443 .53502 .50877 Metetra
.489 .173 .357 r
.53502 .50877 .55159 .443 .58358 .45538 .56774 .50349 Metetra
0 0 .098 r
.56774 .50349 .58358 .45538 .61703 .49121 .60003 .45758 Metetra
.814 .692 .73 r
.60003 .45758 .61703 .49121 .64878 .44747 .63202 .41264 Metetra
.527 .555 .827 r
.63202 .41264 .64878 .44747 .68224 .44525 .66574 .41468 Metetra
.398 .515 .86 r
.66574 .41468 .68224 .44525 .71406 .40538 .70058 .42508 Metetra
.70058 .42508 .71406 .40538 .74928 .41776 .73287 .38268 Metetra
.404 .487 .831 r
.73287 .38268 .74928 .41776 .78112 .37644 .76905 .39511 Metetra
.816 .872 .432 r
.76905 .39511 .78112 .37644 .81189 .3263 .79904 .32549 Metetra
.882 .991 .795 r
.79904 .32549 .81189 .3263 .84552 .30844 .83124 .28735 Metetra
.664 .741 .908 r
.83124 .28735 .84552 .30844 .88016 .29707 .86618 .27574 Metetra
.664 .741 .908 r
.24802 .45744 .26687 .47499 .29533 .46553 .27667 .44778 Metetra
.664 .741 .908 r
.27667 .44778 .29533 .46553 .3241 .45596 .30563 .43802 Metetra
.819 .352 0 r
.30563 .43802 .3241 .45596 .35261 .45739 .33167 .48364 Metetra
.134 0 0 r
.33167 .48364 .35261 .45739 .38175 .45597 .36207 .46768 Metetra
.842 .994 .748 r
.36207 .46768 .38175 .45597 .41129 .45655 .39357 .43019 Metetra
.138 .394 .845 r
.39357 .43019 .41129 .45655 .44052 .4902 .4232 .44751 Metetra
0 .173 .691 r
.4232 .44751 .44052 .4902 .47121 .50489 .45327 .48387 Metetra
.891 .754 .703 r
.45327 .48387 .47121 .50489 .50302 .475 .48583 .41873 Metetra
0 0 .378 r
.48583 .41873 .50302 .475 .53502 .50877 .51735 .5012 Metetra
.88 .447 .136 r
.51735 .5012 .53502 .50877 .56774 .50349 .55102 .57409 Metetra
.55102 .57409 .56774 .50349 .60003 .45758 .58361 .46901 Metetra
.991 .888 .588 r
.58361 .46901 .60003 .45758 .63202 .41264 .61502 .37628 Metetra
.633 .604 .803 r
.61502 .37628 .63202 .41264 .66574 .41468 .64833 .36665 Metetra
.631 .556 .751 r
.64833 .36665 .66574 .41468 .70058 .42508 .68198 .35528 Metetra
.606 .49 .695 r
.68198 .35528 .70058 .42508 .73287 .38268 .71612 .34514 Metetra
.258 .384 .8 r
.71612 .34514 .73287 .38268 .76905 .39511 .75311 .36865 Metetra
.918 .76 .671 r
.75311 .36865 .76905 .39511 .79904 .32549 .7831 .29293 Metetra
.755 .688 .788 r
.7831 .29293 .79904 .32549 .83124 .28735 .81664 .2658 Metetra
.664 .741 .908 r
.81664 .2658 .83124 .28735 .86618 .27574 .85189 .25392 Metetra
.664 .741 .908 r
.22879 .43953 .24802 .45744 .27667 .44778 .25763 .42968 Metetra
.664 .741 .908 r
.25763 .42968 .27667 .44778 .30563 .43802 .28678 .41972 Metetra
.367 .624 .951 r
.28678 .41972 .30563 .43802 .33167 .48364 .31534 .42392 Metetra
.495 .432 .715 r
.31534 .42392 .33167 .48364 .36207 .46768 .34428 .43174 Metetra
.285 .406 .81 r
.34428 .43174 .36207 .46768 .39357 .43019 .37349 .44811 Metetra
.923 .964 .657 r
.37349 .44811 .39357 .43019 .4232 .44751 .40627 .3907 Metetra
.244 .28 .701 r
.40627 .3907 .4232 .44751 .45327 .48387 .4361 .42136 Metetra
.377 .354 .707 r
.4361 .42136 .45327 .48387 .48583 .41873 .46723 .4436 Metetra
.46723 .4436 .48583 .41873 .51735 .5012 .49976 .41703 Metetra
.613 .473 .668 r
.49976 .41703 .51735 .5012 .55102 .57409 .53239 .40279 Metetra
.545 .376 .603 r
.53239 .40279 .55102 .57409 .58361 .46901 .56555 .40485 Metetra
.771 .598 .664 r
.56555 .40485 .58361 .46901 .61502 .37628 .59797 .34589 Metetra
.749 .692 .797 r
.59797 .34589 .61502 .37628 .64833 .36665 .63092 .32091 Metetra
.362 .406 .772 r
.63092 .32091 .64833 .36665 .68198 .35528 .66593 .33966 Metetra
0 .187 .672 r
.66593 .33966 .68198 .35528 .71612 .34514 .70248 .3665 Metetra
.70248 .3665 .71612 .34514 .75311 .36865 .7361 .33017 Metetra
.823 .689 .716 r
.7361 .33017 .75311 .36865 .7831 .29293 .76852 .28018 Metetra
.88 .89 .835 r
.76852 .28018 .7831 .29293 .81664 .2658 .80172 .24376 Metetra
.664 .741 .908 r
.80172 .24376 .81664 .2658 .85189 .25392 .83727 .23161 Metetra
.664 .741 .908 r
.20917 .42126 .22879 .43953 .25763 .42968 .23819 .4112 Metetra
.664 .741 .908 r
.23819 .4112 .25763 .42968 .28678 .41972 .26753 .40103 Metetra
.655 .739 .911 r
.26753 .40103 .28678 .41972 .31534 .42392 .29716 .39141 Metetra
.407 .503 .845 r
.29716 .39141 .31534 .42392 .34428 .43174 .32605 .39948 Metetra
.311 .453 .842 r
.32605 .39948 .34428 .43174 .37349 .44811 .35536 .41225 Metetra
.678 .624 .788 r
.35536 .41225 .37349 .44811 .40627 .3907 .38668 .39674 Metetra
.175 0 0 r
.38668 .39674 .40627 .3907 .4361 .42136 .41777 .39634 Metetra
0 .114 .654 r
.41777 .39634 .4361 .42136 .46723 .4436 .44871 .42641 Metetra
.327 .633 .962 r
.44871 .42641 .46723 .4436 .49976 .41703 .48118 .43109 Metetra
.973 .926 .628 r
.48118 .43109 .49976 .41703 .53239 .40279 .51463 .35536 Metetra
.705 .598 .734 r
.51463 .35536 .53239 .40279 .56555 .40485 .54749 .32984 Metetra
.452 .381 .686 r
.54749 .32984 .56555 .40485 .59797 .34589 .58121 .34659 Metetra
.739 .99 .881 r
.58121 .34659 .59797 .34589 .63092 .32091 .61475 .32194 Metetra
.861 .994 .821 r
.61475 .32194 .63092 .32091 .66593 .33966 .64799 .2864 Metetra
.659 .559 .73 r
.64799 .2864 .66593 .33966 .70248 .3665 .682 .268 Metetra
.576 .435 .653 r
.682 .268 .70248 .3665 .7361 .33017 .71699 .26096 Metetra
.632 .509 .695 r
.71699 .26096 .7361 .33017 .76852 .28018 .7518 .24389 Metetra
.718 .658 .79 r
.7518 .24389 .76852 .28018 .80172 .24376 .78645 .22121 Metetra
.664 .741 .908 r
.78645 .22121 .80172 .24376 .83727 .23161 .82231 .20878 Metetra
.664 .741 .908 r
.18913 .4026 .20917 .42126 .23819 .4112 .21834 .39234 Metetra
.664 .741 .908 r
.21834 .39234 .23819 .4112 .26753 .40103 .24788 .38195 Metetra
.659 .74 .91 r
.24788 .38195 .26753 .40103 .29716 .39141 .27774 .37178 Metetra
.762 .281 0 r
.27774 .37178 .29716 .39141 .32605 .39948 .3044 .4135 Metetra
.485 0 0 r
.3044 .4135 .32605 .39948 .35536 .41225 .3344 .42092 Metetra
.3344 .42092 .35536 .41225 .38668 .39674 .36601 .40999 Metetra
.59 .915 .676 r
.36601 .40999 .38668 .39674 .41777 .39634 .39864 .38252 Metetra
0 .451 .849 r
.39864 .38252 .41777 .39634 .44871 .42641 .43016 .39432 Metetra
.382 .508 .861 r
.43016 .39432 .44871 .42641 .48118 .43109 .46259 .40352 Metetra
.897 .736 .674 r
.46259 .40352 .48118 .43109 .51463 .35536 .49662 .32401 Metetra
.681 .662 .825 r
.49662 .32401 .51463 .35536 .54749 .32984 .52974 .30886 Metetra
.286 .564 .932 r
.52974 .30886 .54749 .32984 .58121 .34659 .56346 .31724 Metetra
.151 .391 .84 r
.56346 .31724 .58121 .34659 .61475 .32194 .5983 .33707 Metetra
.722 .923 .58 r
.5983 .33707 .61475 .32194 .64799 .2864 .63207 .29282 Metetra
.776 .987 .744 r
.63207 .29282 .64799 .2864 .682 .268 .66594 .25715 Metetra
.859 .908 .866 r
.66594 .25715 .682 .268 .71699 .26096 .6999 .22483 Metetra
.653 .629 .814 r
.6999 .22483 .71699 .26096 .7518 .24389 .73517 .21175 Metetra
.663 .661 .838 r
.73517 .21175 .7518 .24389 .78645 .22121 .77083 .19815 Metetra
.664 .741 .908 r
.77083 .19815 .78645 .22121 .82231 .20878 .80701 .18543 Metetra
.664 .741 .908 r
.16868 .38356 .18913 .4026 .21834 .39234 .19808 .37308 Metetra
.664 .741 .908 r
.19808 .37308 .21834 .39234 .24788 .38195 .22782 .36247 Metetra
.664 .741 .908 r
.22782 .36247 .24788 .38195 .27774 .37178 .2579 .35174 Metetra
0 .322 .796 r
.2579 .35174 .27774 .37178 .3044 .4135 .28626 .36856 Metetra
.277 .357 .766 r
.28626 .36856 .3044 .4135 .3344 .42092 .31535 .38764 Metetra
.646 .631 .821 r
.31535 .38764 .3344 .42092 .36601 .40999 .34706 .37661 Metetra
.559 .592 .843 r
.34706 .37661 .36601 .40999 .39864 .38252 .37876 .37394 Metetra
.868 .887 .847 r
.37876 .37394 .39864 .38252 .43016 .39432 .41213 .33982 Metetra
.043 .164 .666 r
.41213 .33982 .43016 .39432 .46259 .40352 .44354 .38021 Metetra
.878 .763 .732 r
.44354 .38021 .46259 .40352 .49662 .32401 .47785 .32475 Metetra
.82 .992 .868 r
.47785 .32475 .49662 .32401 .52974 .30886 .51155 .29488 Metetra
.591 .81 .983 r
.51155 .29488 .52974 .30886 .56346 .31724 .5454 .28648 Metetra
.639 .657 .851 r
.5454 .28648 .56346 .31724 .5983 .33707 .57971 .27588 Metetra
0 .058 .599 r
.57971 .27588 .5983 .33707 .63207 .29282 .61659 .33753 Metetra
.006 0 .046 r
.61659 .33753 .63207 .29282 .66594 .25715 .65145 .29668 Metetra
.724 .766 .267 r
.65145 .29668 .66594 .25715 .6999 .22483 .68325 .20115 Metetra
.675 .739 .899 r
.68325 .20115 .6999 .22483 .73517 .21175 .71879 .18739 Metetra
.663 .731 .9 r
.71879 .18739 .73517 .21175 .77083 .19815 .75484 .17454 Metetra
.664 .741 .908 r
.75484 .17454 .77083 .19815 .80701 .18543 .79135 .16152 Metetra
.664 .741 .908 r
.14779 .36411 .16868 .38356 .19808 .37308 .17739 .3534 Metetra
.664 .741 .908 r
.17739 .3534 .19808 .37308 .22782 .36247 .20732 .34257 Metetra
.664 .741 .908 r
.20732 .34257 .22782 .36247 .2579 .35174 .23761 .33161 Metetra
.631 .732 .92 r
.23761 .33161 .2579 .35174 .28626 .36856 .26806 .32292 Metetra
.603 .548 .765 r
.26806 .32292 .28626 .36856 .31535 .38764 .29884 .31514 Metetra
.575 .462 .687 r
.29884 .31514 .31535 .38764 .34706 .37661 .32995 .30891 Metetra
.238 .25 .67 r
.32995 .30891 .34706 .37661 .37876 .37394 .35953 .34112 Metetra
.818 .702 .736 r
.35953 .34112 .37876 .37394 .41213 .33982 .39363 .29581 Metetra
.55 .531 .788 r
.39363 .29581 .41213 .33982 .44354 .38021 .42605 .29406 Metetra
.374 .31 .656 r
.42605 .29406 .44354 .38021 .47785 .32475 .45848 .32081 Metetra
.548 .907 .965 r
.45848 .32081 .47785 .32475 .51155 .29488 .49256 .30873 Metetra
.664 .93 .643 r
.49256 .30873 .51155 .29488 .5454 .28648 .52704 .27309 Metetra
.432 .756 .995 r
.52704 .27309 .5454 .28648 .57971 .27588 .56183 .27078 Metetra
.776 .965 .925 r
.56183 .27078 .57971 .27588 .61659 .33753 .59677 .24632 Metetra
.659 .497 .654 r
.59677 .24632 .61659 .33753 .65145 .29668 .63162 .21401 Metetra
.683 .522 .662 r
.63162 .21401 .65145 .29668 .68325 .20115 .66625 .17744 Metetra
.673 .744 .903 r
.66625 .17744 .68325 .20115 .71879 .18739 .70211 .16354 Metetra
.664 .741 .908 r
.70211 .16354 .71879 .18739 .75484 .17454 .73848 .15038 Metetra
.664 .741 .908 r
.73848 .15038 .75484 .17454 .79135 .16152 .77531 .13705 Metetra
.664 .741 .908 r
.12646 .34425 .14779 .36411 .17739 .3534 .15624 .33331 Metetra
.664 .741 .908 r
.15624 .33331 .17739 .3534 .20732 .34257 .18638 .32224 Metetra
.664 .741 .908 r
.18638 .32224 .20732 .34257 .23761 .33161 .21688 .31104 Metetra
.664 .741 .908 r
.21688 .31104 .23761 .33161 .26806 .32292 .24773 .29971 Metetra
.662 .717 .89 r
.24773 .29971 .26806 .32292 .29884 .31514 .27896 .28824 Metetra
.657 .686 .865 r
.27896 .28824 .29884 .31514 .32995 .30891 .31056 .27663 Metetra
.385 .514 .865 r
.31056 .27663 .32995 .30891 .35953 .34112 .34141 .28404 Metetra
.533 .475 .736 r
.34141 .28404 .35953 .34112 .39363 .29581 .3734 .28397 Metetra
.433 .773 .997 r
.3734 .28397 .39363 .29581 .42605 .29406 .40615 .28092 Metetra
.013 .501 .871 r
.40615 .28092 .42605 .29406 .45848 .32081 .43915 .2906 Metetra
.806 .724 .774 r
.43915 .2906 .45848 .32081 .49256 .30873 .47383 .25342 Metetra
.691 .577 .721 r
.47383 .25342 .49256 .30873 .52704 .27309 .50832 .22707 Metetra
.753 .636 .731 r
.50832 .22707 .52704 .27309 .56183 .27078 .54287 .19132 Metetra
.591 .467 .679 r
.54287 .19132 .56183 .27078 .59677 .24632 .57776 .17988 Metetra
.613 .505 .707 r
.57776 .17988 .59677 .24632 .63162 .21401 .61306 .16606 Metetra
.634 .572 .767 r
.61306 .16606 .63162 .21401 .66625 .17744 .64881 .15241 Metetra
.663 .732 .901 r
.64881 .15241 .66625 .17744 .70211 .16354 .68503 .13911 Metetra
.664 .741 .908 r
.68503 .13911 .70211 .16354 .73848 .15038 .72172 .12564 Metetra
.664 .741 .908 r
.72172 .12564 .73848 .15038 .77531 .13705 .75889 .11199 Metetra
.664 .741 .908 r
.10466 .32395 .12646 .34425 .15624 .33331 .13464 .31277 Metetra
.664 .741 .908 r
.13464 .31277 .15624 .33331 .18638 .32224 .16498 .30146 Metetra
.664 .741 .908 r
.16498 .30146 .18638 .32224 .21688 .31104 .19568 .29001 Metetra
.664 .741 .908 r
.19568 .29001 .21688 .31104 .24773 .29971 .22676 .27843 Metetra
.664 .741 .908 r
.22676 .27843 .24773 .29971 .27896 .28824 .2582 .26671 Metetra
.664 .741 .908 r
.2582 .26671 .27896 .28824 .31056 .27663 .29003 .25484 Metetra
.664 .741 .908 r
.29003 .25484 .31056 .27663 .34141 .28404 .32225 .24283 Metetra
.586 .568 .801 r
.32225 .24283 .34141 .28404 .3734 .28397 .35454 .23655 Metetra
.614 .557 .767 r
.35454 .23655 .3734 .28397 .40615 .28092 .38753 .22618 Metetra
.649 .553 .733 r
.38753 .22618 .40615 .28092 .43915 .2906 .42122 .20865 Metetra
.565 .445 .675 r
.42122 .20865 .43915 .2906 .47383 .25342 .45497 .20191 Metetra
.652 .567 .746 r
.45497 .20191 .47383 .25342 .50832 .22707 .4894 .18458 Metetra
.666 .611 .783 r
.4894 .18458 .50832 .22707 .54287 .19132 .52416 .16755 Metetra
.664 .741 .908 r
.52416 .16755 .54287 .19132 .57776 .17988 .55932 .15444 Metetra
.662 .728 .898 r
.55932 .15444 .57776 .17988 .61306 .16606 .59493 .14117 Metetra
.663 .736 .904 r
.59493 .14117 .61306 .16606 .64881 .15241 .631 .12772 Metetra
.664 .741 .908 r
.631 .12772 .64881 .15241 .68503 .13911 .66754 .1141 Metetra
.664 .741 .908 r
.66754 .1141 .68503 .13911 .72172 .12564 .70456 .10029 Metetra
.664 .741 .908 r
.70456 .10029 .72172 .12564 .75889 .11199 .74207 .08631 Metetra
.664 .741 .908 r
.08238 .30321 .10466 .32395 .13464 .31277 .11256 .29178 Metetra
.664 .741 .908 r
.11256 .29178 .13464 .31277 .16498 .30146 .14311 .28022 Metetra
.664 .741 .908 r
.14311 .28022 .16498 .30146 .19568 .29001 .17402 .26852 Metetra
.664 .741 .908 r
.17402 .26852 .19568 .29001 .22676 .27843 .20531 .25667 Metetra
.664 .741 .908 r
.20531 .25667 .22676 .27843 .2582 .26671 .23698 .24468 Metetra
.664 .741 .908 r
.23698 .24468 .2582 .26671 .29003 .25484 .26904 .23255 Metetra
.664 .741 .908 r
.26904 .23255 .29003 .25484 .32225 .24283 .3015 .22026 Metetra
.664 .741 .908 r
.3015 .22026 .32225 .24283 .35454 .23655 .33436 .20782 Metetra
.657 .687 .866 r
.33436 .20782 .35454 .23655 .38753 .22618 .36763 .19522 Metetra
.654 .671 .854 r
.36763 .19522 .38753 .22618 .42122 .20865 .40132 .18247 Metetra
.661 .715 .888 r
.40132 .18247 .42122 .20865 .45497 .20191 .43544 .16955 Metetra
.653 .665 .849 r
.43544 .16955 .45497 .20191 .4894 .18458 .47 .15647 Metetra
.659 .703 .879 r
.47 .15647 .4894 .18458 .52416 .16755 .505 .14322 Metetra
.664 .741 .908 r
.505 .14322 .52416 .16755 .55932 .15444 .54045 .1298 Metetra
.664 .741 .908 r
.54045 .1298 .55932 .15444 .59493 .14117 .57637 .1162 Metetra
.664 .741 .908 r
.57637 .1162 .59493 .14117 .631 .12772 .61276 .10243 Metetra
.664 .741 .908 r
.61276 .10243 .631 .12772 .66754 .1141 .64962 .08847 Metetra
.664 .741 .908 r
.64962 .08847 .66754 .1141 .70456 .10029 .68698 .07433 Metetra
.664 .741 .908 r
.68698 .07433 .70456 .10029 .74207 .08631 .72483 .06 Metetra
.664 .741 .908 r
.05962 .28201 .08238 .30321 .11256 .29178 .08999 .27033 Metetra
.664 .741 .908 r
.08999 .27033 .11256 .29178 .14311 .28022 .12074 .25851 Metetra
.664 .741 .908 r
.12074 .25851 .14311 .28022 .17402 .26852 .15187 .24654 Metetra
.664 .741 .908 r
.15187 .24654 .17402 .26852 .20531 .25667 .18337 .23442 Metetra
.664 .741 .908 r
.18337 .23442 .20531 .25667 .23698 .24468 .21527 .22216 Metetra
.664 .741 .908 r
.21527 .22216 .23698 .24468 .26904 .23255 .24756 .20974 Metetra
.664 .741 .908 r
.24756 .20974 .26904 .23255 .3015 .22026 .28026 .19717 Metetra
.664 .741 .908 r
.28026 .19717 .3015 .22026 .33436 .20782 .31337 .18444 Metetra
.664 .741 .908 r
.31337 .18444 .33436 .20782 .36763 .19522 .3469 .17155 Metetra
.664 .741 .908 r
.3469 .17155 .36763 .19522 .40132 .18247 .38086 .1585 Metetra
.664 .741 .908 r
.38086 .1585 .40132 .18247 .43544 .16955 .41525 .14527 Metetra
.664 .741 .908 r
.41525 .14527 .43544 .16955 .47 .15647 .45009 .13188 Metetra
.664 .741 .908 r
.45009 .13188 .47 .15647 .505 .14322 .48538 .11831 Metetra
.664 .741 .908 r
.48538 .11831 .505 .14322 .54045 .1298 .52114 .10456 Metetra
.664 .741 .908 r
.52114 .10456 .54045 .1298 .57637 .1162 .55736 .09063 Metetra
.664 .741 .908 r
.55736 .09063 .57637 .1162 .61276 .10243 .59407 .07652 Metetra
.664 .741 .908 r
.59407 .07652 .61276 .10243 .64962 .08847 .63126 .06222 Metetra
.664 .741 .908 r
.63126 .06222 .64962 .08847 .68698 .07433 .66896 .04773 Metetra
.664 .741 .908 r
.66896 .04773 .68698 .07433 .72483 .06 .70716 .03304 Metetra
.664 .741 .908 r
.03634 .26033 .05962 .28201 .08999 .27033 .06692 .24839 Metetra
.664 .741 .908 r
.06692 .24839 .08999 .27033 .12074 .25851 .09787 .2363 Metetra
.664 .741 .908 r
.09787 .2363 .12074 .25851 .15187 .24654 .12921 .22406 Metetra
.664 .741 .908 r
.12921 .22406 .15187 .24654 .18337 .23442 .16094 .21167 Metetra
.664 .741 .908 r
.16094 .21167 .18337 .23442 .21527 .22216 .19306 .19912 Metetra
.664 .741 .908 r
.19306 .19912 .21527 .22216 .24756 .20974 .22559 .18641 Metetra
.664 .741 .908 r
.22559 .18641 .24756 .20974 .28026 .19717 .25853 .17355 Metetra
.664 .741 .908 r
.25853 .17355 .28026 .19717 .31337 .18444 .29189 .16051 Metetra
.664 .741 .908 r
.29189 .16051 .31337 .18444 .3469 .17155 .32568 .14732 Metetra
.664 .741 .908 r
.32568 .14732 .3469 .17155 .38086 .1585 .35991 .13395 Metetra
.664 .741 .908 r
.35991 .13395 .38086 .1585 .41525 .14527 .39458 .12041 Metetra
.664 .741 .908 r
.39458 .12041 .41525 .14527 .45009 .13188 .4297 .10669 Metetra
.664 .741 .908 r
.4297 .10669 .45009 .13188 .48538 .11831 .46529 .09279 Metetra
.664 .741 .908 r
.46529 .09279 .48538 .11831 .52114 .10456 .50134 .0787 Metetra
.664 .741 .908 r
.50134 .0787 .52114 .10456 .55736 .09063 .53788 .06443 Metetra
.664 .741 .908 r
.53788 .06443 .55736 .09063 .59407 .07652 .57491 .04997 Metetra
.664 .741 .908 r
.57491 .04997 .59407 .07652 .63126 .06222 .61244 .03531 Metetra
.664 .741 .908 r
.61244 .03531 .63126 .06222 .66896 .04773 .65049 .02045 Metetra
.664 .741 .908 r
.65049 .02045 .66896 .04773 .70716 .03304 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.015625 0.64881 0.313244 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -10.625 0 ]
[.5 .82364 10.625 12.9375 ]
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -71.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
75.000 14.562 moveto
(j) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.663 .722 .893 r
.38107 .78681 .39811 .80437 .42673 .79589 .40987 .77812 Metetra
.69 .729 .88 r
.40987 .77812 .42673 .79589 .45569 .78513 .43901 .76687 Metetra
.71 .73 .866 r
.43901 .76687 .45569 .78513 .48492 .77233 .46845 .75328 Metetra
.724 .728 .853 r
.46845 .75328 .48492 .77233 .5144 .75787 .49813 .73777 Metetra
.731 .722 .842 r
.49813 .73777 .5144 .75787 .54408 .74229 .52801 .72087 Metetra
.732 .712 .832 r
.52801 .72087 .54408 .74229 .57394 .72628 .55806 .7033 Metetra
.726 .699 .825 r
.55806 .7033 .57394 .72628 .60401 .71063 .58828 .68599 Metetra
.71 .683 .822 r
.58828 .68599 .60401 .71063 .63432 .69624 .61873 .67024 Metetra
.693 .668 .822 r
.61873 .67024 .63432 .69624 .66493 .68375 .64945 .65649 Metetra
.666 .65 .825 r
.64945 .65649 .66493 .68375 .69594 .67377 .68058 .64588 Metetra
.634 .633 .832 r
.68058 .64588 .69594 .67377 .72743 .66656 .71222 .63889 Metetra
.608 .624 .841 r
.71222 .63889 .72743 .66656 .75947 .66177 .74442 .63461 Metetra
.584 .618 .851 r
.74442 .63461 .75947 .66177 .79209 .65896 .77724 .63255 Metetra
.564 .615 .862 r
.77724 .63255 .79209 .65896 .82532 .65754 .8107 .63215 Metetra
.551 .619 .873 r
.8107 .63215 .82532 .65754 .85913 .65677 .8448 .63254 Metetra
.55 .63 .884 r
.8448 .63254 .85913 .65677 .89348 .65583 .87945 .63269 Metetra
.56 .648 .894 r
.87945 .63269 .89348 .65583 .92827 .65395 .91457 .63168 Metetra
.579 .668 .9 r
.91457 .63168 .92827 .65395 .96342 .65048 .95005 .62882 Metetra
.605 .689 .902 r
.95005 .62882 .96342 .65048 .99883 .64493 .98577 .62359 Metetra
.664 .702 .875 r
.36382 .76701 .38107 .78681 .40987 .77812 .39277 .75802 Metetra
.692 .709 .861 r
.39277 .75802 .40987 .77812 .43901 .76687 .4221 .74603 Metetra
.713 .71 .845 r
.4221 .74603 .43901 .76687 .46845 .75328 .45174 .73126 Metetra
.727 .705 .83 r
.45174 .73126 .46845 .75328 .49813 .73777 .48162 .71413 Metetra
.734 .696 .815 r
.48162 .71413 .49813 .73777 .52801 .72087 .51169 .6952 Metetra
.734 .684 .802 r
.51169 .6952 .52801 .72087 .55806 .7033 .54189 .67516 Metetra
.728 .668 .791 r
.54189 .67516 .55806 .7033 .58828 .68599 .57223 .65489 Metetra
.705 .643 .785 r
.57223 .65489 .58828 .68599 .61873 .67024 .60276 .63735 Metetra
.693 .63 .781 r
.60276 .63735 .61873 .67024 .64945 .65649 .63352 .62118 Metetra
.661 .604 .781 r
.63352 .62118 .64945 .65649 .68058 .64588 .66467 .60947 Metetra
.619 .579 .787 r
.66467 .60947 .68058 .64588 .71222 .63889 .69643 .60361 Metetra
.598 .575 .799 r
.69643 .60361 .71222 .63889 .74442 .63461 .72875 .60033 Metetra
.576 .57 .809 r
.72875 .60033 .74442 .63461 .77724 .63255 .76173 .59954 Metetra
.553 .566 .821 r
.76173 .59954 .77724 .63255 .8107 .63215 .79543 .601 Metetra
.538 .572 .836 r
.79543 .601 .8107 .63215 .8448 .63254 .82984 .60356 Metetra
.538 .588 .853 r
.82984 .60356 .8448 .63254 .87945 .63269 .86483 .60563 Metetra
.55 .611 .867 r
.86483 .60563 .87945 .63269 .91457 .63168 .9003 .60615 Metetra
.571 .637 .878 r
.9003 .60615 .91457 .63168 .95005 .62882 .93612 .60433 Metetra
.6 .663 .883 r
.93612 .60433 .95005 .62882 .98577 .62359 .97217 .59968 Metetra
.664 .688 .862 r
.34635 .74537 .36382 .76701 .39277 .75802 .37545 .736 Metetra
.696 .696 .846 r
.37545 .736 .39277 .75802 .4221 .74603 .40497 .72303 Metetra
.719 .696 .828 r
.40497 .72303 .4221 .74603 .45174 .73126 .43482 .70667 Metetra
.733 .691 .81 r
.43482 .70667 .45174 .73126 .48162 .71413 .46491 .68735 Metetra
.739 .68 .793 r
.46491 .68735 .48162 .71413 .51169 .6952 .49516 .66573 Metetra
.74 .666 .777 r
.49516 .66573 .51169 .6952 .54189 .67516 .52552 .64236 Metetra
.736 .649 .763 r
.52552 .64236 .54189 .67516 .57223 .65489 .55595 .61788 Metetra
.697 .614 .76 r
.55595 .61788 .57223 .65489 .60276 .63735 .58654 .59931 Metetra
.697 .611 .757 r
.58654 .59931 .60276 .63735 .63352 .62118 .6173 .58037 Metetra
.656 .58 .758 r
.6173 .58037 .63352 .62118 .66467 .60947 .64846 .56801 Metetra
.622 .561 .765 r
.64846 .56801 .66467 .60947 .69643 .60361 .68016 .56095 Metetra
.588 .539 .767 r
.68016 .56095 .69643 .60361 .72875 .60033 .71253 .55875 Metetra
.566 .532 .776 r
.71253 .55875 .72875 .60033 .76173 .59954 .74561 .55944 Metetra
.534 .521 .787 r
.74561 .55944 .76173 .59954 .79543 .601 .77955 .56389 Metetra
.512 .525 .806 r
.77955 .56389 .79543 .601 .82984 .60356 .81431 .57008 Metetra
.514 .548 .828 r
.81431 .57008 .82984 .60356 .86483 .60563 .84968 .57511 Metetra
.531 .578 .848 r
.84968 .57511 .86483 .60563 .9003 .60615 .88553 .57781 Metetra
.558 .611 .862 r
.88553 .57781 .9003 .60615 .93612 .60433 .92172 .57748 Metetra
.591 .642 .87 r
.92172 .57748 .93612 .60433 .97217 .59968 .9581 .57365 Metetra
.666 .681 .854 r
.32865 .72247 .34635 .74537 .37545 .736 .3579 .71264 Metetra
.702 .69 .835 r
.3579 .71264 .37545 .736 .40497 .72303 .38762 .69845 Metetra
.727 .69 .814 r
.38762 .69845 .40497 .72303 .43482 .70667 .4177 .68008 Metetra
.743 .683 .793 r
.4177 .68008 .43482 .70667 .46491 .68735 .44801 .65794 Metetra
.747 .669 .775 r
.44801 .65794 .46491 .68735 .49516 .66573 .47847 .63316 Metetra
.744 .654 .761 r
.47847 .63316 .49516 .66573 .52552 .64236 .50898 .60709 Metetra
.733 .639 .754 r
.50898 .60709 .52552 .64236 .55595 .61788 .53953 .5818 Metetra
.713 .627 .76 r
.53953 .5818 .55595 .61788 .58654 .59931 .57019 .56055 Metetra
.696 .609 .755 r
.57019 .56055 .58654 .59931 .6173 .58037 .60101 .54136 Metetra
.662 .591 .766 r
.60101 .54136 .6173 .58037 .64846 .56801 .6322 .52826 Metetra
.634 .575 .771 r
.6322 .52826 .64846 .56801 .68016 .56095 .66385 .51939 Metetra
.592 .546 .772 r
.66385 .51939 .68016 .56095 .71253 .55875 .69618 .51633 Metetra
.567 .53 .773 r
.69618 .51633 .71253 .55875 .74561 .55944 .72922 .51666 Metetra
.534 .511 .776 r
.72922 .51666 .74561 .55944 .77955 .56389 .76313 .52111 Metetra
.47 .475 .781 r
.76313 .52111 .77955 .56389 .81431 .57008 .79833 .53293 Metetra
.48 .51 .811 r
.79833 .53293 .81431 .57008 .84968 .57511 .83412 .54194 Metetra
.504 .549 .835 r
.83412 .54194 .84968 .57511 .88553 .57781 .87037 .5474 Metetra
.539 .589 .852 r
.87037 .5474 .88553 .57781 .92172 .57748 .90693 .54893 Metetra
.58 .626 .862 r
.90693 .54893 .92172 .57748 .9581 .57365 .94366 .54612 Metetra
.669 .68 .852 r
.31068 .69901 .32865 .72247 .3579 .71264 .34009 .68867 Metetra
.71 .691 .829 r
.34009 .68867 .3579 .71264 .38762 .69845 .37002 .6731 Metetra
.739 .691 .804 r
.37002 .6731 .38762 .69845 .4177 .68008 .40035 .65231 Metetra
.758 .683 .779 r
.40035 .65231 .4177 .68008 .44801 .65794 .43095 .62628 Metetra
.759 .665 .757 r
.43095 .62628 .44801 .65794 .47847 .63316 .46165 .59706 Metetra
.744 .64 .746 r
.46165 .59706 .47847 .63316 .50898 .60709 .49231 .56872 Metetra
.724 .624 .746 r
.49231 .56872 .50898 .60709 .53953 .5818 .52297 .54382 Metetra
.716 .622 .751 r
.52297 .54382 .53953 .5818 .57019 .56055 .5537 .52093 Metetra
.695 .606 .753 r
.5537 .52093 .57019 .56055 .60101 .54136 .5846 .50152 Metetra
.654 .585 .765 r
.5846 .50152 .60101 .54136 .6322 .52826 .61586 .48934 Metetra
.648 .587 .772 r
.61586 .48934 .6322 .52826 .66385 .51939 .64747 .47823 Metetra
.581 .543 .777 r
.64747 .47823 .66385 .51939 .69618 .51633 .67985 .47626 Metetra
.552 .532 .787 r
.67985 .47626 .69618 .51633 .72922 .51666 .71296 .47778 Metetra
.53 .527 .797 r
.71296 .47778 .72922 .51666 .76313 .52111 .74684 .48154 Metetra
.437 .472 .798 r
.74684 .48154 .76313 .52111 .79833 .53293 .78213 .4948 Metetra
.439 .482 .807 r
.78213 .4948 .79833 .53293 .83412 .54194 .81827 .50742 Metetra
.471 .524 .831 r
.81827 .50742 .83412 .54194 .87037 .5474 .85491 .51589 Metetra
.515 .571 .85 r
.85491 .51589 .87037 .5474 .90693 .54893 .89186 .51951 Metetra
.566 .616 .862 r
.89186 .51951 .90693 .54893 .94366 .54612 .92893 .51787 Metetra
.673 .687 .855 r
.29238 .67583 .31068 .69901 .34009 .68867 .32196 .66494 Metetra
.72 .698 .828 r
.32196 .66494 .34009 .68867 .37002 .6731 .35213 .64798 Metetra
.752 .698 .8 r
.35213 .64798 .37002 .6731 .40035 .65231 .38274 .62488 Metetra
.774 .691 .772 r
.38274 .62488 .40035 .65231 .43095 .62628 .41365 .5955 Metetra
.784 .678 .748 r
.41365 .5955 .43095 .62628 .46165 .59706 .44467 .56046 Metetra
.759 .646 .737 r
.44467 .56046 .46165 .59706 .49231 .56872 .47554 .52782 Metetra
.711 .61 .742 r
.47554 .52782 .49231 .56872 .52297 .54382 .50627 .50445 Metetra
.709 .615 .749 r
.50627 .50445 .52297 .54382 .5537 .52093 .5371 .48228 Metetra
.7 .613 .757 r
.5371 .48228 .5537 .52093 .5846 .50152 .56808 .46238 Metetra
.658 .592 .769 r
.56808 .46238 .5846 .50152 .61586 .48934 .59937 .44954 Metetra
.652 .586 .769 r
.59937 .44954 .61586 .48934 .64747 .47823 .631 .43755 Metetra
.554 .531 .784 r
.631 .43755 .64747 .47823 .67985 .47626 .6635 .43852 Metetra
.524 .529 .803 r
.6635 .43852 .67985 .47626 .71296 .47778 .69676 .44233 Metetra
.515 .539 .819 r
.69676 .44233 .71296 .47778 .74684 .48154 .73071 .44649 Metetra
.449 .506 .825 r
.73071 .44649 .74684 .48154 .78213 .4948 .76578 .45637 Metetra
.396 .457 .806 r
.76578 .45637 .78213 .4948 .81827 .50742 .80221 .47228 Metetra
.427 .497 .829 r
.80221 .47228 .81827 .50742 .85491 .51589 .83925 .48424 Metetra
.483 .555 .854 r
.83925 .48424 .85491 .51589 .89186 .51951 .8766 .4902 Metetra
.548 .611 .868 r
.8766 .4902 .89186 .51951 .92893 .51787 .91402 .48979 Metetra
.678 .701 .864 r
.27367 .65373 .29238 .67583 .32196 .66494 .30344 .6423 Metetra
.732 .712 .833 r
.30344 .6423 .32196 .66494 .35213 .64798 .33387 .62403 Metetra
.767 .712 .801 r
.33387 .62403 .35213 .64798 .38274 .62488 .36479 .59883 Metetra
.787 .705 .773 r
.36479 .59883 .38274 .62488 .41365 .5955 .39602 .56736 Metetra
.795 .696 .756 r
.39602 .56736 .41365 .5955 .44467 .56046 .4273 .53194 Metetra
.786 .693 .761 r
.4273 .53194 .44467 .56046 .47554 .52782 .45842 .49892 Metetra
.761 .684 .778 r
.45842 .49892 .47554 .52782 .50627 .50445 .48938 .47201 Metetra
.73 .655 .775 r
.48938 .47201 .50627 .50445 .5371 .48228 .52036 .44926 Metetra
.712 .646 .781 r
.52036 .44926 .5371 .48228 .56808 .46238 .55148 .42948 Metetra
.686 .636 .794 r
.55148 .42948 .56808 .46238 .59937 .44954 .58284 .41396 Metetra
.64 .602 .795 r
.58284 .41396 .59937 .44954 .631 .43755 .61461 .40421 Metetra
.538 .563 .828 r
.61461 .40421 .631 .43755 .6635 .43852 .64719 .40547 Metetra
.512 .553 .834 r
.64719 .40547 .6635 .43852 .69676 .44233 .68049 .40895 Metetra
.471 .53 .836 r
.68049 .40895 .69676 .44233 .73071 .44649 .71467 .41586 Metetra
.431 .529 .857 r
.71467 .41586 .73071 .44649 .76578 .45637 .74977 .42474 Metetra
.363 .484 .848 r
.74977 .42474 .76578 .45637 .80221 .47228 .78612 .4389 Metetra
.371 .478 .839 r
.78612 .4389 .80221 .47228 .83925 .48424 .8235 .4537 Metetra
.44 .543 .865 r
.8235 .4537 .83925 .48424 .8766 .4902 .86126 .46212 Metetra
.527 .614 .882 r
.86126 .46212 .8766 .4902 .91402 .48979 .89904 .46286 Metetra
.685 .724 .879 r
.25447 .6335 .27367 .65373 .30344 .6423 .28444 .62149 Metetra
.744 .733 .841 r
.28444 .62149 .30344 .6423 .33387 .62403 .31516 .60202 Metetra
.783 .732 .805 r
.31516 .60202 .33387 .62403 .36479 .59883 .34643 .57499 Metetra
.795 .722 .784 r
.34643 .57499 .36479 .59883 .39602 .56736 .37792 .54373 Metetra
.806 .727 .777 r
.37792 .54373 .39602 .56736 .4273 .53194 .40945 .50983 Metetra
.818 .74 .778 r
.40945 .50983 .4273 .53194 .45842 .49892 .44092 .47463 Metetra
.796 .724 .785 r
.44092 .47463 .45842 .49892 .48938 .47201 .4722 .44357 Metetra
.752 .687 .79 r
.4722 .44357 .48938 .47201 .52036 .44926 .5034 .419 Metetra
.741 .674 .786 r
.5034 .419 .52036 .44926 .55148 .42948 .53467 .39547 Metetra
.681 .63 .792 r
.53467 .39547 .55148 .42948 .58284 .41396 .56615 .38032 Metetra
.585 .587 .821 r
.56615 .38032 .58284 .41396 .61461 .40421 .59818 .3768 Metetra
.479 .58 .878 r
.59818 .3768 .61461 .40421 .64719 .40547 .63096 .3807 Metetra
.465 .6 .901 r
.63096 .3807 .64719 .40547 .68049 .40895 .66442 .38449 Metetra
.437 .59 .906 r
.66442 .38449 .68049 .40895 .71467 .41586 .69867 .38977 Metetra
.376 .541 .891 r
.69867 .38977 .71467 .41586 .74977 .42474 .73395 .39937 Metetra
.347 .534 .896 r
.73395 .39937 .74977 .42474 .78612 .4389 .7702 .41024 Metetra
.299 .475 .866 r
.7702 .41024 .78612 .4389 .8235 .4537 .80781 .42618 Metetra
.381 .538 .887 r
.80781 .42618 .8235 .4537 .86126 .46212 .84594 .43661 Metetra
.502 .628 .907 r
.84594 .43661 .86126 .46212 .89904 .46286 .88406 .43803 Metetra
.692 .754 .899 r
.23466 .61571 .25447 .6335 .28444 .62149 .26488 .60314 Metetra
.758 .761 .854 r
.26488 .60314 .28444 .62149 .31516 .60202 .29591 .58262 Metetra
.804 .757 .809 r
.29591 .58262 .31516 .60202 .34643 .57499 .32762 .55298 Metetra
.8 .738 .795 r
.32762 .55298 .34643 .57499 .37792 .54373 .35937 .52223 Metetra
.806 .745 .796 r
.35937 .52223 .37792 .54373 .40945 .50983 .39112 .49082 Metetra
.826 .767 .797 r
.39112 .49082 .40945 .50983 .44092 .47463 .4229 .45702 Metetra
.83 .782 .807 r
.4229 .45702 .44092 .47463 .4722 .44357 .45457 .42415 Metetra
.786 .766 .835 r
.45457 .42415 .4722 .44357 .5034 .419 .48607 .39909 Metetra
.791 .765 .83 r
.48607 .39909 .5034 .419 .53467 .39547 .51764 .37299 Metetra
.722 .729 .856 r
.51764 .37299 .53467 .39547 .56615 .38032 .54934 .35589 Metetra
.518 .63 .901 r
.54934 .35589 .56615 .38032 .59818 .3768 .5816 .35607 Metetra
.341 .581 .931 r
.5816 .35607 .59818 .3768 .63096 .3807 .61466 .36348 Metetra
.343 .629 .959 r
.61466 .36348 .63096 .3807 .66442 .38449 .6484 .36868 Metetra
.315 .635 .964 r
.6484 .36868 .66442 .38449 .69867 .38977 .68291 .37399 Metetra
.266 .607 .955 r
.68291 .37399 .69867 .38977 .73395 .39937 .71829 .38114 Metetra
.272 .578 .942 r
.71829 .38114 .73395 .39937 .7702 .41024 .75464 .39008 Metetra
.162 .485 .9 r
.75464 .39008 .7702 .41024 .80781 .42618 .79242 .40534 Metetra
.305 .57 .932 r
.79242 .40534 .80781 .42618 .84594 .43661 .83074 .41502 Metetra
.477 .662 .943 r
.83074 .41502 .84594 .43661 .88406 .43803 .86912 .41606 Metetra
.695 .788 .922 r
.21418 .60056 .23466 .61571 .26488 .60314 .24464 .58771 Metetra
.765 .794 .877 r
.24464 .58771 .26488 .60314 .29591 .58262 .27593 .5674 Metetra
.812 .798 .838 r
.27593 .5674 .29591 .58262 .32762 .55298 .30788 .53942 Metetra
.838 .814 .827 r
.30788 .53942 .32762 .55298 .35937 .52223 .34008 .50737 Metetra
.838 .804 .818 r
.34008 .50737 .35937 .52223 .39112 .49082 .37228 .47427 Metetra
.82 .793 .827 r
.37228 .47427 .39112 .49082 .4229 .45702 .40429 .44437 Metetra
.847 .833 .833 r
.40429 .44437 .4229 .45702 .45457 .42415 .43635 .41208 Metetra
.829 .847 .861 r
.43635 .41208 .45457 .42415 .48607 .39909 .46828 .38415 Metetra
.768 .818 .892 r
.46828 .38415 .48607 .39909 .51764 .37299 .50018 .36371 Metetra
.65 .873 .982 r
.50018 .36371 .51764 .37299 .54934 .35589 .53227 .35187 Metetra
.291 .771 .924 r
.53227 .35187 .54934 .35589 .5816 .35607 .56484 .34848 Metetra
.112 .619 .897 r
.56484 .34848 .5816 .35607 .61466 .36348 .59812 .35268 Metetra
.202 .641 .948 r
.59812 .35268 .61466 .36348 .6484 .36868 .63215 .35731 Metetra
.253 .666 .964 r
.63215 .35731 .6484 .36868 .68291 .37399 .66688 .36092 Metetra
.253 .643 .963 r
.66688 .36092 .68291 .37399 .71829 .38114 .70245 .36596 Metetra
.16 .555 .929 r
.70245 .36596 .71829 .38114 .75464 .39008 .73917 .37607 Metetra
.063 .503 .895 r
.73917 .37607 .75464 .39008 .79242 .40534 .77704 .38873 Metetra
.251 .597 .95 r
.77704 .38873 .79242 .40534 .83074 .41502 .81555 .39701 Metetra
.456 .701 .973 r
.81555 .39701 .83074 .41502 .86912 .41606 .85418 .39699 Metetra
.694 .82 .943 r
.19297 .58772 .21418 .60056 .24464 .58771 .22369 .57471 Metetra
.766 .825 .899 r
.22369 .57471 .24464 .58771 .27593 .5674 .25525 .55489 Metetra
.813 .829 .862 r
.25525 .55489 .27593 .5674 .30788 .53942 .28747 .5283 Metetra
.847 .84 .838 r
.28747 .5283 .30788 .53942 .34008 .50737 .3201 .49591 Metetra
.852 .839 .832 r
.3201 .49591 .34008 .50737 .37228 .47427 .35273 .46244 Metetra
.839 .843 .848 r
.35273 .46244 .37228 .47427 .40429 .44437 .38517 .43199 Metetra
.836 .842 .851 r
.38517 .43199 .40429 .44437 .43635 .41208 .41757 .40218 Metetra
.831 .876 .877 r
.41757 .40218 .43635 .41208 .46828 .38415 .44992 .37468 Metetra
.758 .889 .937 r
.44992 .37468 .46828 .38415 .50018 .36371 .4822 .35556 Metetra
.515 .844 .998 r
.4822 .35556 .50018 .36371 .53227 .35187 .51465 .34861 Metetra
.257 .755 .899 r
.51465 .34861 .53227 .35187 .56484 .34848 .5476 .34523 Metetra
.18 .705 .867 r
.5476 .34523 .56484 .34848 .59812 .35268 .58115 .34366 Metetra
.211 .673 .944 r
.58115 .34366 .59812 .35268 .63215 .35731 .61544 .34624 Metetra
.159 .614 .933 r
.61544 .34624 .63215 .35731 .66688 .36092 .6506 .3521 Metetra
.038 .554 .87 r
.6506 .3521 .66688 .36092 .70245 .36596 .68666 .3596 Metetra
0 .483 .78 r
.68666 .3596 .70245 .36596 .73917 .37607 .72369 .36848 Metetra
0 .517 .827 r
.72369 .36848 .73917 .37607 .77704 .38873 .76166 .37715 Metetra
.209 .644 .951 r
.76166 .37715 .77704 .38873 .81555 .39701 .80028 .38218 Metetra
.443 .743 .992 r
.80028 .38218 .81555 .39701 .85418 .39699 .83915 .38043 Metetra
.689 .844 .957 r
.17102 .57657 .19297 .58772 .22369 .57471 .20202 .56348 Metetra
.762 .849 .916 r
.20202 .56348 .22369 .57471 .25525 .55489 .23386 .54416 Metetra
.813 .853 .878 r
.23386 .54416 .25525 .55489 .28747 .5283 .2664 .51827 Metetra
.854 .853 .84 r
.2664 .51827 .28747 .5283 .3201 .49591 .29953 .48499 Metetra
.851 .849 .84 r
.29953 .48499 .3201 .49591 .35273 .46244 .33257 .45205 Metetra
.839 .863 .861 r
.33257 .45205 .35273 .46244 .38517 .43199 .3654 .42231 Metetra
.825 .879 .883 r
.3654 .42231 .38517 .43199 .41757 .40218 .39813 .39542 Metetra
.813 .919 .909 r
.39813 .39542 .41757 .40218 .44992 .37468 .43087 .37053 Metetra
.722 .948 .953 r
.43087 .37053 .44992 .37468 .4822 .35556 .46358 .35195 Metetra
.381 .827 .942 r
.46358 .35195 .4822 .35556 .51465 .34861 .49643 .34559 Metetra
.288 .777 .904 r
.49643 .34559 .51465 .34861 .5476 .34523 .52979 .34104 Metetra
.293 .773 .922 r
.52979 .34104 .5476 .34523 .58115 .34366 .56371 .33718 Metetra
.265 .738 .94 r
.56371 .33718 .58115 .34366 .61544 .34624 .59828 .33588 Metetra
.165 .63 .932 r
.59828 .33588 .61544 .34624 .6506 .3521 .63372 .34065 Metetra
.066 .548 .894 r
.63372 .34065 .6506 .3521 .68666 .3596 .67017 .34949 Metetra
0 .503 .85 r
.67017 .34949 .68666 .3596 .72369 .36848 .70766 .35981 Metetra
.058 .574 .877 r
.70766 .35981 .72369 .36848 .76166 .37715 .7459 .36664 Metetra
.248 .688 .959 r
.7459 .36664 .76166 .37715 .80028 .38218 .78474 .36896 Metetra
.448 .773 .997 r
.78474 .36896 .80028 .38218 .83915 .38043 .8239 .3655 Metetra
.68 .858 .967 r
.14837 .56641 .17102 .57657 .20202 .56348 .17964 .55343 Metetra
.751 .866 .933 r
.17964 .55343 .20202 .56348 .23386 .54416 .21173 .53498 Metetra
.802 .876 .9 r
.21173 .53498 .23386 .54416 .2664 .51827 .24452 .51086 Metetra
.846 .888 .87 r
.24452 .51086 .2664 .51827 .29953 .48499 .27789 .4806 Metetra
.858 .92 .87 r
.27789 .4806 .29953 .48499 .33257 .45205 .31134 .44906 Metetra
.84 .945 .889 r
.31134 .44906 .33257 .45205 .3654 .42231 .34463 .42022 Metetra
.818 .962 .903 r
.34463 .42022 .3654 .42231 .39813 .39542 .37786 .39353 Metetra
.753 .968 .93 r
.37786 .39353 .39813 .39542 .43087 .37053 .41099 .37166 Metetra
.671 .971 .908 r
.41099 .37166 .43087 .37053 .46358 .35195 .44426 .35174 Metetra
.381 .843 .885 r
.44426 .35174 .46358 .35195 .49643 .34559 .47759 .3424 Metetra
.318 .795 .915 r
.47759 .3424 .49643 .34559 .52979 .34104 .51136 .33701 Metetra
.277 .765 .912 r
.51136 .33701 .52979 .34104 .56371 .33718 .54571 .33324 Metetra
.206 .72 .884 r
.54571 .33324 .56371 .33718 .59828 .33588 .58069 .3312 Metetra
.188 .703 .887 r
.58069 .3312 .59828 .33588 .63372 .34065 .61638 .33021 Metetra
.061 .56 .887 r
.61638 .33021 .63372 .34065 .67017 .34949 .65313 .33798 Metetra
0 .471 .841 r
.65313 .33798 .67017 .34949 .70766 .35981 .69106 .3502 Metetra
.113 .608 .906 r
.69106 .3502 .70766 .35981 .7459 .36664 .72965 .35585 Metetra
.299 .721 .973 r
.72965 .35585 .7459 .36664 .78474 .36896 .76878 .35623 Metetra
.463 .793 .999 r
.76878 .35623 .78474 .36896 .8239 .3655 .8083 .35132 Metetra
.67 .862 .972 r
.12503 .55647 .14837 .56641 .17964 .55343 .15656 .54373 Metetra
.734 .874 .946 r
.15656 .54373 .17964 .55343 .21173 .53498 .18888 .52642 Metetra
.78 .888 .923 r
.18888 .52642 .21173 .53498 .24452 .51086 .22185 .50466 Metetra
.814 .912 .906 r
.22185 .50466 .24452 .51086 .27789 .4806 .25532 .47894 Metetra
.823 .958 .901 r
.25532 .47894 .27789 .4806 .31134 .44906 .28902 .45143 Metetra
.798 .989 .887 r
.28902 .45143 .31134 .44906 .34463 .42022 .32279 .42392 Metetra
.779 .994 .873 r
.32279 .42392 .34463 .42022 .37786 .39353 .35663 .39647 Metetra
.66 .971 .887 r
.35663 .39647 .37786 .39353 .41099 .37166 .39027 .37565 Metetra
.585 .946 .856 r
.39027 .37565 .41099 .37166 .44426 .35174 .42407 .35646 Metetra
.418 .862 .795 r
.42407 .35646 .44426 .35174 .47759 .3424 .45804 .34161 Metetra
.325 .809 .875 r
.45804 .34161 .47759 .3424 .51136 .33701 .4923 .33386 Metetra
.214 .729 .874 r
.4923 .33386 .51136 .33701 .54571 .33324 .52708 .33087 Metetra
.139 .681 .827 r
.52708 .33087 .54571 .33324 .58069 .3312 .56253 .32911 Metetra
.021 .592 .762 r
.56253 .32911 .58069 .3312 .61638 .33021 .59874 .33033 Metetra
.174 0 0 r
.59874 .33033 .61638 .33021 .65313 .33798 .63589 .33572 Metetra
.148 0 0 r
.63589 .33572 .65313 .33798 .69106 .3502 .67403 .34257 Metetra
.143 .652 .9 r
.67403 .34257 .69106 .3502 .72965 .35585 .71289 .34518 Metetra
.344 .753 .981 r
.71289 .34518 .72965 .35585 .76878 .35623 .75235 .34341 Metetra
.485 .808 1 r
.75235 .34341 .76878 .35623 .8083 .35132 .79224 .3371 Metetra
.663 .857 .974 r
.10108 .54591 .12503 .55647 .15656 .54373 .13287 .53342 Metetra
.717 .869 .953 r
.13287 .53342 .15656 .54373 .18888 .52642 .1654 .51715 Metetra
.756 .885 .937 r
.1654 .51715 .18888 .52642 .22185 .50466 .19856 .49738 Metetra
.783 .908 .927 r
.19856 .49738 .22185 .50466 .25532 .47894 .23219 .47474 Metetra
.794 .941 .923 r
.23219 .47474 .25532 .47894 .28902 .45143 .26614 .45041 Metetra
.785 .97 .917 r
.26614 .45041 .28902 .45143 .32279 .42392 .30027 .42542 Metetra
.765 .986 .901 r
.30027 .42542 .32279 .42392 .35663 .39647 .33455 .4001 Metetra
.669 .975 .879 r
.33455 .4001 .35663 .39647 .39027 .37565 .36882 .378 Metetra
.61 .955 .89 r
.36882 .378 .39027 .37565 .42407 .35646 .40317 .359 Metetra
.482 .9 .861 r
.40317 .359 .42407 .35646 .45804 .34161 .43768 .34396 Metetra
.221 .743 .771 r
.43768 .34396 .45804 .34161 .4923 .33386 .47245 .33625 Metetra
.47245 .33625 .4923 .33386 .52708 .33087 .50774 .33263 Metetra
.017 0 0 r
.50774 .33263 .52708 .33087 .56253 .32911 .54371 .33168 Metetra
.064 0 0 r
.54371 .33168 .56253 .32911 .59874 .33033 .58043 .33146 Metetra
.075 0 0 r
.58043 .33146 .59874 .33033 .63589 .33572 .61798 .33283 Metetra
.034 .6 .782 r
.61798 .33283 .63589 .33572 .67403 .34257 .65639 .33433 Metetra
.251 .723 .942 r
.65639 .33433 .67403 .34257 .71289 .34518 .69555 .33359 Metetra
.406 .783 .992 r
.69555 .33359 .71289 .34518 .75235 .34341 .73534 .32965 Metetra
.514 .816 1 r
.73534 .32965 .75235 .34341 .79224 .3371 .77564 .322 Metetra
.661 .844 .971 r
.07661 .53394 .10108 .54591 .13287 .53342 .10865 .52162 Metetra
.705 .855 .954 r
.10865 .52162 .13287 .53342 .1654 .51715 .1414 .50613 Metetra
.738 .869 .942 r
.1414 .50613 .1654 .51715 .19856 .49738 .17477 .48779 Metetra
.76 .888 .935 r
.17477 .48779 .19856 .49738 .23219 .47474 .20861 .46715 Metetra
.772 .912 .934 r
.20861 .46715 .23219 .47474 .26614 .45041 .2428 .44506 Metetra
.771 .937 .937 r
.2428 .44506 .26614 .45041 .30027 .42542 .27724 .42241 Metetra
.753 .959 .937 r
.27724 .42241 .30027 .42542 .33455 .4001 .31186 .40006 Metetra
.69 .97 .926 r
.31186 .40006 .33455 .4001 .36882 .378 .34659 .37936 Metetra
.591 .946 .904 r
.34659 .37936 .36882 .378 .40317 .359 .38143 .36165 Metetra
.435 .875 .848 r
.38143 .36165 .40317 .359 .43768 .34396 .41646 .34782 Metetra
.251 .761 .754 r
.41646 .34782 .43768 .34396 .47245 .33625 .45182 .33799 Metetra
.162 .701 .756 r
.45182 .33799 .47245 .33625 .50774 .33263 .48766 .33213 Metetra
.134 .681 .787 r
.48766 .33213 .50774 .33263 .54371 .33168 .52412 .32873 Metetra
.163 .696 .843 r
.52412 .32873 .54371 .33168 .58043 .33146 .56131 .32641 Metetra
.191 .707 .885 r
.56131 .32641 .58043 .33146 .61798 .33283 .59927 .32486 Metetra
.27 .739 .944 r
.59927 .32486 .61798 .33283 .65639 .33433 .63802 .32308 Metetra
.378 .773 .987 r
.63802 .32308 .65639 .33433 .69555 .33359 .67753 .31975 Metetra
.471 .796 .999 r
.67753 .31975 .69555 .33359 .73534 .32965 .7177 .31398 Metetra
.546 .814 .996 r
.7177 .31398 .73534 .32965 .77564 .322 .75841 .30516 Metetra
.66 .825 .963 r
.05171 .51988 .07661 .53394 .10865 .52162 .08399 .50763 Metetra
.697 .834 .948 r
.08399 .50763 .10865 .52162 .1414 .50613 .11697 .49262 Metetra
.725 .845 .938 r
.11697 .49262 .1414 .50613 .17477 .48779 .15056 .47516 Metetra
.744 .859 .933 r
.15056 .47516 .17477 .48779 .20861 .46715 .18465 .45574 Metetra
.756 .875 .933 r
.18465 .45574 .20861 .46715 .2428 .44506 .21911 .43508 Metetra
.758 .894 .938 r
.21911 .43508 .2428 .44506 .27724 .42241 .25385 .41398 Metetra
.748 .913 .948 r
.25385 .41398 .27724 .42241 .31186 .40006 .28879 .3933 Metetra
.719 .929 .96 r
.28879 .3933 .31186 .40006 .34659 .37936 .3239 .37407 Metetra
.662 .934 .969 r
.3239 .37407 .34659 .37936 .38143 .36165 .35919 .35722 Metetra
.578 .917 .968 r
.35919 .35722 .38143 .36165 .41646 .34782 .39471 .34338 Metetra
.485 .88 .961 r
.39471 .34338 .41646 .34782 .45182 .33799 .43057 .33273 Metetra
.405 .836 .954 r
.43057 .33273 .45182 .33799 .48766 .33213 .46689 .32505 Metetra
.369 .804 .963 r
.46689 .32505 .48766 .33213 .52412 .32873 .50382 .31957 Metetra
.367 .787 .976 r
.50382 .31957 .52412 .32873 .56131 .32641 .54143 .31537 Metetra
.381 .777 .987 r
.54143 .31537 .56131 .32641 .59927 .32486 .5798 .31176 Metetra
.417 .776 .995 r
.5798 .31176 .59927 .32486 .63802 .32308 .61893 .30786 Metetra
.468 .781 .998 r
.61893 .30786 .63802 .32308 .67753 .31975 .6588 .30274 Metetra
.522 .79 .994 r
.6588 .30274 .67753 .31975 .7177 .31398 .69936 .29559 Metetra
.572 .801 .986 r
.69936 .29559 .7177 .31398 .75841 .30516 .7405 .28585 Metetra
.661 .801 .95 r
.02646 .50322 .05171 .51988 .08399 .50763 .05898 .49092 Metetra
.692 .809 .937 r
.05898 .49092 .08399 .50763 .11697 .49262 .0922 .47609 Metetra
.716 .817 .928 r
.0922 .47609 .11697 .49262 .15056 .47516 .12604 .45901 Metetra
.734 .826 .922 r
.12604 .45901 .15056 .47516 .18465 .45574 .16039 .44015 Metetra
.744 .835 .921 r
.16039 .44015 .18465 .45574 .21911 .43508 .19514 .42014 Metetra
.747 .846 .924 r
.19514 .42014 .21911 .43508 .25385 .41398 .23019 .39974 Metetra
.742 .856 .933 r
.23019 .39974 .25385 .41398 .28879 .3933 .26547 .37977 Metetra
.725 .865 .947 r
.26547 .37977 .28879 .3933 .3239 .37407 .30095 .3611 Metetra
.695 .87 .964 r
.30095 .3611 .3239 .37407 .35919 .35722 .33662 .34449 Metetra
.651 .865 .98 r
.33662 .34449 .35919 .35722 .39471 .34338 .37255 .33045 Metetra
.598 .85 .992 r
.37255 .33045 .39471 .34338 .43057 .33273 .40883 .31916 Metetra
.546 .827 .998 r
.40883 .31916 .43057 .33273 .46689 .32505 .44557 .31042 Metetra
.507 .801 .998 r
.44557 .31042 .46689 .32505 .50382 .31957 .48289 .30368 Metetra
.486 .78 .997 r
.48289 .30368 .50382 .31957 .54143 .31537 .52089 .29824 Metetra
.482 .766 .994 r
.52089 .29824 .54143 .31537 .5798 .31176 .55962 .29335 Metetra
.494 .76 .99 r
.55962 .29335 .5798 .31176 .61893 .30786 .59912 .28819 Metetra
.52 .762 .985 r
.59912 .28819 .61893 .30786 .6588 .30274 .63936 .28194 Metetra
.554 .768 .978 r
.63936 .28194 .6588 .30274 .69936 .29559 .68031 .27389 Metetra
.59 .778 .97 r
.68031 .27389 .69936 .29559 .7405 .28585 .72188 .26349 Metetra
.661 .776 .934 r
.00095 .48363 .02646 .50322 .05898 .49092 .03369 .47117 Metetra
.689 .782 .922 r
.03369 .47117 .05898 .49092 .0922 .47609 .06717 .45623 Metetra
.711 .788 .912 r
.06717 .45623 .0922 .47609 .12604 .45901 .10129 .43907 Metetra
.727 .792 .904 r
.10129 .43907 .12604 .45901 .16039 .44015 .13593 .42013 Metetra
.736 .796 .9 r
.13593 .42013 .16039 .44015 .19514 .42014 .171 .40003 Metetra
.739 .799 .9 r
.171 .40003 .19514 .42014 .23019 .39974 .20638 .37951 Metetra
.734 .8 .904 r
.20638 .37951 .23019 .39974 .26547 .37977 .24201 .35939 Metetra
.721 .8 .913 r
.24201 .35939 .26547 .37977 .30095 .3611 .27783 .34053 Metetra
.699 .796 .925 r
.27783 .34053 .30095 .3611 .33662 .34449 .31386 .32362 Metetra
.668 .789 .938 r
.31386 .32362 .33662 .34449 .37255 .33045 .35013 .3092 Metetra
.631 .776 .951 r
.35013 .3092 .37255 .33045 .40883 .31916 .38674 .29745 Metetra
.592 .761 .959 r
.38674 .29745 .40883 .31916 .44557 .31042 .4238 .28816 Metetra
.559 .744 .963 r
.4238 .28816 .44557 .31042 .48289 .30368 .46144 .28084 Metetra
.535 .731 .965 r
.46144 .28084 .48289 .30368 .52089 .29824 .49975 .27485 Metetra
.525 .724 .964 r
.49975 .27485 .52089 .29824 .55962 .29335 .53881 .26943 Metetra
.528 .723 .962 r
.53881 .26943 .55962 .29335 .59912 .28819 .57864 .26375 Metetra
.544 .728 .96 r
.57864 .26375 .59912 .28819 .63936 .28194 .61924 .25702 Metetra
.569 .738 .956 r
.61924 .25702 .63936 .28194 .68031 .27389 .66056 .24852 Metetra
.598 .751 .95 r
.66056 .24852 .68031 .27389 .72188 .26349 .70254 .23773 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.015625 0.97619 0.313244 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0001 w
.76704 .46948 m
.71545 .47993 L
s
% Start of user PostScript
0.76704 0.46948 0.715445 0.479928 MAarrowhead1
% End of user PostScript
.51511 .50359 m
.51761 .49714 L
s
% Start of user PostScript
0.515112 0.503592 0.517615 0.497136 MAarrowhead1
% End of user PostScript
.67112 .56246 m
.62536 .54887 L
s
% Start of user PostScript
0.671121 0.56246 0.625365 0.548873 MAarrowhead1
% End of user PostScript
.64281 .47418 m
.60064 .48496 L
s
% Start of user PostScript
0.64281 0.474181 0.600638 0.484956 MAarrowhead1
% End of user PostScript
.62936 .33058 m
.59457 .36765 L
s
% Start of user PostScript
0.629358 0.330578 0.594572 0.36765 MAarrowhead1
% End of user PostScript
.66175 .745 m
.62506 .69447 L
s
% Start of user PostScript
0.661746 0.744997 0.625062 0.69447 MAarrowhead1
% End of user PostScript
.76889 .46261 m
.7172 .47476 L
s
% Start of user PostScript
0.768889 0.462608 0.717195 0.474763 MAarrowhead1
% End of user PostScript
.3357 .2376 m
.3669 .28333 L
s
% Start of user PostScript
0.335704 0.237599 0.366905 0.283335 MAarrowhead1
% End of user PostScript
.82982 .48202 m
.77829 .48682 L
s
% Start of user PostScript
0.829824 0.482023 0.77829 0.48682 MAarrowhead1
% End of user PostScript
.30921 .4263 m
.35936 .44003 L
s
% Start of user PostScript
0.309205 0.426297 0.359364 0.440033 MAarrowhead1
% End of user PostScript
.27372 .6541 m
.31817 .62934 L
s
% Start of user PostScript
0.273721 0.654104 0.31817 0.62934 MAarrowhead1
% End of user PostScript
.75811 .61384 m
.70491 .59253 L
s
% Start of user PostScript
0.758111 0.613843 0.704915 0.592527 MAarrowhead1
% End of user PostScript
.48847 .47807 m
.50463 .48478 L
s
% Start of user PostScript
0.488469 0.478071 0.50463 0.484776 MAarrowhead1
% End of user PostScript
.44937 .77505 m
.47204 .72945 L
s
% Start of user PostScript
0.449368 0.775045 0.472043 0.729451 MAarrowhead1
% End of user PostScript
.67112 .31136 m
.62594 .35069 L
s
% Start of user PostScript
0.671121 0.311356 0.625937 0.350695 MAarrowhead1
% End of user PostScript
.30849 .42772 m
.35878 .44103 L
s
% Start of user PostScript
0.30849 0.427717 0.358782 0.441029 MAarrowhead1
% End of user PostScript
.49182 .59647 m
.5077 .55783 L
s
% Start of user PostScript
0.491817 0.596465 0.507697 0.557831 MAarrowhead1
% End of user PostScript
.34502 .28582 m
.37666 .32672 L
s
% Start of user PostScript
0.34502 0.285818 0.376663 0.326719 MAarrowhead1
% End of user PostScript
.3026 .45528 m
.3531 .46048 L
s
% Start of user PostScript
0.302599 0.455276 0.353097 0.46048 MAarrowhead1
% End of user PostScript
.52022 .80144 m
.52139 .74947 L
s
% Start of user PostScript
0.520219 0.801438 0.521391 0.749466 MAarrowhead1
% End of user PostScript
.56038 .28783 m
.55145 .34113 L
s
% Start of user PostScript
0.560379 0.287834 0.551449 0.341134 MAarrowhead1
% End of user PostScript
.65916 .42592 m
.61595 .44647 L
s
% Start of user PostScript
0.659159 0.425923 0.615947 0.446468 MAarrowhead1
% End of user PostScript
.30896 .27118 m
.35027 .31182 L
s
% Start of user PostScript
0.308961 0.271181 0.350272 0.311821 MAarrowhead1
% End of user PostScript
.68909 .66578 m
.6486 .63248 L
s
% Start of user PostScript
0.689095 0.665779 0.648596 0.632482 MAarrowhead1
% End of user PostScript
.56159 .78676 m
.55045 .73444 L
s
% Start of user PostScript
0.561592 0.786763 0.550454 0.734441 MAarrowhead1
% End of user PostScript
.77441 .66365 m
.72241 .63391 L
s
% Start of user PostScript
0.774409 0.663647 0.722415 0.633907 MAarrowhead1
% End of user PostScript
.42102 .44332 m
.45055 .45417 L
s
% Start of user PostScript
0.421025 0.443321 0.450554 0.454166 MAarrowhead1
% End of user PostScript
.5348 .30527 m
.53247 .3576 L
s
% Start of user PostScript
0.534799 0.305266 0.532468 0.357597 MAarrowhead1
% End of user PostScript
.4972 .49833 m
.5115 .49391 L
s
% Start of user PostScript
0.497203 0.498332 0.511499 0.493915 MAarrowhead1
% End of user PostScript
.29286 .69988 m
.33124 .66685 L
s
% Start of user PostScript
0.292864 0.699882 0.331235 0.666855 MAarrowhead1
% End of user PostScript
.42821 .72027 m
.45233 .68104 L
s
% Start of user PostScript
0.428209 0.720272 0.45233 0.681041 MAarrowhead1
% End of user PostScript
.24667 .71364 m
.29358 .67972 L
s
% Start of user PostScript
0.246672 0.713636 0.293582 0.679718 MAarrowhead1
% End of user PostScript
.5015 .46034 m
.51008 .47968 L
s
% Start of user PostScript
0.5015 0.460339 0.510077 0.479675 MAarrowhead1
% End of user PostScript
.43727 .26886 m
.45083 .31647 L
s
% Start of user PostScript
0.437274 0.268859 0.450827 0.316465 MAarrowhead1
% End of user PostScript
.41214 .5975 m
.44107 .56902 L
s
% Start of user PostScript
0.412138 0.597497 0.441065 0.569019 MAarrowhead1
% End of user PostScript
.68501 .22129 m
.64887 .26777 L
s
% Start of user PostScript
0.68501 0.221285 0.64887 0.267773 MAarrowhead1
% End of user PostScript
.33591 .61857 m
.37184 .59585 L
s
% Start of user PostScript
0.335915 0.618574 0.371845 0.595848 MAarrowhead1
% End of user PostScript
.55492 .50265 m
.53139 .49958 L
s
% Start of user PostScript
0.554917 0.502653 0.531392 0.499575 MAarrowhead1
% End of user PostScript
.64661 .549 m
.60487 .53841 L
s
% Start of user PostScript
0.646615 0.549001 0.604869 0.538407 MAarrowhead1
% End of user PostScript
.24904 .53244 m
.29669 .52292 L
s
% Start of user PostScript
0.249039 0.532443 0.296688 0.522916 MAarrowhead1
% End of user PostScript
.46704 .34929 m
.48226 .39388 L
s
% Start of user PostScript
0.467038 0.349291 0.482264 0.393884 MAarrowhead1
% End of user PostScript
.31323 .75137 m
.34364 .70483 L
s
% Start of user PostScript
0.313232 0.751365 0.343641 0.704827 MAarrowhead1
% End of user PostScript
.35626 .25489 m
.3834 .30054 L
s
% Start of user PostScript
0.356258 0.254889 0.383396 0.300536 MAarrowhead1
% End of user PostScript
.57489 .81816 m
.55929 .76518 L
s
% Start of user PostScript
0.57489 0.818157 0.559286 0.765178 MAarrowhead1
% End of user PostScript
.64754 .73109 m
.61466 .684 L
s
% Start of user PostScript
0.647536 0.731093 0.61466 0.684001 MAarrowhead1
% End of user PostScript
.50572 .33081 m
.51141 .37786 L
s
% Start of user PostScript
0.505723 0.330805 0.511409 0.377863 MAarrowhead1
% End of user PostScript
.70213 .55575 m
.64999 .54644 L
s
% Start of user PostScript
0.702131 0.555752 0.649988 0.546436 MAarrowhead1
% End of user PostScript
.59621 .65616 m
.5763 .61939 L
s
% Start of user PostScript
0.596214 0.656158 0.576301 0.61939 MAarrowhead1
% End of user PostScript
.52258 .48189 m
.51878 .48785 L
s
% Start of user PostScript
0.522585 0.481889 0.518776 0.487852 MAarrowhead1
% End of user PostScript
.36571 .59196 m
.40042 .5706 L
s
% Start of user PostScript
0.365714 0.591963 0.400421 0.570603 MAarrowhead1
% End of user PostScript
.73365 .65054 m
.68507 .62253 L
s
% Start of user PostScript
0.733648 0.650535 0.685071 0.62253 MAarrowhead1
% End of user PostScript
.623 .74101 m
.5966 .69217 L
s
% Start of user PostScript
0.623005 0.741011 0.596602 0.692166 MAarrowhead1
% End of user PostScript
.36261 .36198 m
.39724 .39504 L
s
% Start of user PostScript
0.36261 0.361984 0.397238 0.395044 MAarrowhead1
% End of user PostScript
.77272 .63508 m
.71966 .61027 L
s
% Start of user PostScript
0.772722 0.635077 0.719663 0.610271 MAarrowhead1
% End of user PostScript
.56641 .75713 m
.55685 .70825 L
s
% Start of user PostScript
0.566407 0.757132 0.556852 0.708253 MAarrowhead1
% End of user PostScript
.74876 .70575 m
.69852 .66512 L
s
% Start of user PostScript
0.748756 0.705749 0.698523 0.665119 MAarrowhead1
% End of user PostScript
.39543 .82042 m
.42184 .77863 L
s
% Start of user PostScript
0.395428 0.820422 0.421836 0.778625 MAarrowhead1
% End of user PostScript
.31413 .35656 m
.35821 .38592 L
s
% Start of user PostScript
0.314128 0.356564 0.35821 0.385918 MAarrowhead1
% End of user PostScript
.28526 .49004 m
.33156 .48627 L
s
% Start of user PostScript
0.285265 0.490044 0.331561 0.486267 MAarrowhead1
% End of user PostScript
.46202 .39951 m
.47621 .43198 L
s
% Start of user PostScript
0.462021 0.399515 0.47621 0.431977 MAarrowhead1
% End of user PostScript
.63738 .34406 m
.59905 .37718 L
s
% Start of user PostScript
0.637385 0.344064 0.599045 0.377183 MAarrowhead1
% End of user PostScript
.1996 .42677 m
.25069 .4415 L
s
% Start of user PostScript
0.199597 0.426769 0.250692 0.441503 MAarrowhead1
% End of user PostScript
.77988 .54227 m
.72467 .53441 L
s
% Start of user PostScript
0.779884 0.542269 0.724665 0.534407 MAarrowhead1
% End of user PostScript
.42494 .43535 m
.45292 .45016 L
s
% Start of user PostScript
0.424939 0.43535 0.452919 0.450163 MAarrowhead1
% End of user PostScript
.40408 .37057 m
.43109 .40669 L
s
% Start of user PostScript
0.404083 0.370574 0.43109 0.40669 MAarrowhead1
% End of user PostScript
.54045 .34233 m
.53258 .38589 L
s
% Start of user PostScript
0.540451 0.342335 0.532584 0.385893 MAarrowhead1
% End of user PostScript
.40352 .26194 m
.42114 .30933 L
s
% Start of user PostScript
0.40352 0.261939 0.421137 0.309329 MAarrowhead1
% End of user PostScript
.67442 .41791 m
.62859 .44032 L
s
% Start of user PostScript
0.67442 0.417906 0.628592 0.440319 MAarrowhead1
% End of user PostScript
.32879 .29693 m
.36592 .33561 L
s
% Start of user PostScript
0.328785 0.296934 0.365915 0.335611 MAarrowhead1
% End of user PostScript
.22342 .35824 m
.27409 .38378 L
s
% Start of user PostScript
0.223422 0.358236 0.274093 0.383778 MAarrowhead1
% End of user PostScript
.41819 .57573 m
.45057 .54953 L
s
% Start of user PostScript
0.418188 0.575733 0.450568 0.549526 MAarrowhead1
% End of user PostScript
.67928 .69801 m
.64175 .6577 L
s
% Start of user PostScript
0.679281 0.698014 0.641755 0.657703 MAarrowhead1
% End of user PostScript
.52801 .22559 m
.52344 .27796 L
s
% Start of user PostScript
0.528012 0.225593 0.523441 0.277958 MAarrowhead1
% End of user PostScript
.67123 .2475 m
.63244 .29863 L
s
% Start of user PostScript
0.671226 0.247502 0.632445 0.298633 MAarrowhead1
% End of user PostScript
.83778 .48372 m
.78672 .48775 L
s
% Start of user PostScript
0.837782 0.48372 0.786722 0.487747 MAarrowhead1
% End of user PostScript
.23558 .53058 m
.28469 .52158 L
s
% Start of user PostScript
0.235584 0.530576 0.28469 0.521583 MAarrowhead1
% End of user PostScript
.28453 .35585 m
.33321 .38364 L
s
% Start of user PostScript
0.284526 0.355846 0.333214 0.383637 MAarrowhead1
% End of user PostScript
.66108 .43821 m
.61751 .45593 L
s
% Start of user PostScript
0.661077 0.438214 0.617513 0.455933 MAarrowhead1
% End of user PostScript
.50835 .51231 m
.51601 .5006 L
s
% Start of user PostScript
0.508349 0.512305 0.516014 0.500597 MAarrowhead1
% End of user PostScript
.47574 .82891 m
.48788 .77932 L
s
% Start of user PostScript
0.475736 0.828913 0.487875 0.779321 MAarrowhead1
% End of user PostScript
.51724 .33543 m
.51859 .38124 L
s
% Start of user PostScript
0.517239 0.335434 0.518592 0.381236 MAarrowhead1
% End of user PostScript
.55883 .47513 m
.53428 .48472 L
s
% Start of user PostScript
0.558826 0.475128 0.534282 0.484721 MAarrowhead1
% End of user PostScript
.43625 .42725 m
.46106 .44678 L
s
% Start of user PostScript
0.436247 0.427252 0.461064 0.446779 MAarrowhead1
% End of user PostScript
.67598 .56142 m
.62919 .54856 L
s
% Start of user PostScript
0.675983 0.561416 0.629186 0.548563 MAarrowhead1
% End of user PostScript
.6444 .63438 m
.60975 .60254 L
s
% Start of user PostScript
0.644395 0.634376 0.609752 0.602537 MAarrowhead1
% End of user PostScript
.27234 .56059 m
.31606 .54464 L
s
% Start of user PostScript
0.272336 0.560593 0.316059 0.544637 MAarrowhead1
% End of user PostScript
.35274 .6437 m
.38391 .61506 L
s
% Start of user PostScript
0.352739 0.643701 0.383914 0.615058 MAarrowhead1
% End of user PostScript
.54596 .81476 m
.53858 .76175 L
s
% Start of user PostScript
0.545961 0.814759 0.538583 0.761752 MAarrowhead1
% End of user PostScript
.79282 .5618 m
.73672 .54936 L
s
% Start of user PostScript
0.792819 0.561803 0.736724 0.549356 MAarrowhead1
% End of user PostScript
.27909 .4503 m
.33213 .45931 L
s
% Start of user PostScript
0.279086 0.450303 0.332131 0.45931 MAarrowhead1
% End of user PostScript
.70608 .71395 m
.66292 .66994 L
s
% Start of user PostScript
0.706077 0.713951 0.662916 0.669945 MAarrowhead1
% End of user PostScript
.25838 .46407 m
.31089 .47131 L
s
% Start of user PostScript
0.258382 0.464066 0.310889 0.471311 MAarrowhead1
% End of user PostScript
.34118 .36629 m
.38082 .39618 L
s
% Start of user PostScript
0.34118 0.36629 0.380824 0.396178 MAarrowhead1
% End of user PostScript
.61559 .31048 m
.58782 .35355 L
s
% Start of user PostScript
0.615586 0.310479 0.587816 0.353551 MAarrowhead1
% End of user PostScript
.52427 .65901 m
.53159 .62217 L
s
% Start of user PostScript
0.524265 0.659011 0.531592 0.62217 MAarrowhead1
% End of user PostScript
.58161 .51756 m
.55383 .51278 L
s
% Start of user PostScript
0.581611 0.517555 0.553827 0.512782 MAarrowhead1
% End of user PostScript
.30258 .74925 m
.33498 .70266 L
s
% Start of user PostScript
0.302576 0.749248 0.334979 0.702657 MAarrowhead1
% End of user PostScript
.60574 .29286 m
.58365 .3407 L
s
% Start of user PostScript
0.605741 0.292863 0.583655 0.340696 MAarrowhead1
% End of user PostScript
.52481 .69319 m
.5309 .65357 L
s
% Start of user PostScript
0.524813 0.693191 0.530902 0.653575 MAarrowhead1
% End of user PostScript
.65236 .28522 m
.6131 .33167 L
s
% Start of user PostScript
0.652363 0.285218 0.613098 0.33167 MAarrowhead1
% End of user PostScript
.26442 .58221 m
.30949 .56388 L
s
% Start of user PostScript
0.264424 0.582207 0.309487 0.563878 MAarrowhead1
% End of user PostScript
.41617 .46498 m
.44965 .4665 L
s
% Start of user PostScript
0.416169 0.464979 0.449654 0.466497 MAarrowhead1
% End of user PostScript
.22655 .37429 m
.27767 .39729 L
s
% Start of user PostScript
0.226545 0.374288 0.277674 0.39729 MAarrowhead1
% End of user PostScript
.44396 .72125 m
.46683 .68304 L
s
% Start of user PostScript
0.443958 0.72125 0.466825 0.683042 MAarrowhead1
% End of user PostScript
.54534 .66455 m
.54584 .62754 L
s
% Start of user PostScript
0.545339 0.66455 0.545839 0.627538 MAarrowhead1
% End of user PostScript
.49202 .47416 m
.50617 .48368 L
s
% Start of user PostScript
0.492018 0.474157 0.506172 0.483678 MAarrowhead1
% End of user PostScript
.50387 .5328 m
.51507 .50911 L
s
% Start of user PostScript
0.50387 0.532804 0.515073 0.509106 MAarrowhead1
% End of user PostScript
.78079 .3424 m
.73521 .37344 L
s
% Start of user PostScript
0.78079 0.3424 0.735208 0.373442 MAarrowhead1
% End of user PostScript
.56702 .56676 m
.55324 .54158 L
s
% Start of user PostScript
0.567018 0.566761 0.553242 0.541584 MAarrowhead1
% End of user PostScript
.40538 .64214 m
.42944 .60838 L
s
% Start of user PostScript
0.405377 0.642139 0.429442 0.60838 MAarrowhead1
% End of user PostScript
.66953 .71863 m
.63312 .67416 L
s
% Start of user PostScript
0.669533 0.718629 0.633117 0.674161 MAarrowhead1
% End of user PostScript
.49209 .23331 m
.49437 .28344 L
s
% Start of user PostScript
0.492088 0.233314 0.494366 0.283437 MAarrowhead1
% End of user PostScript
.5719 .47587 m
.54375 .48583 L
s
% Start of user PostScript
0.571901 0.475866 0.54375 0.485831 MAarrowhead1
% End of user PostScript
.29034 .59498 m
.33224 .5757 L
s
% Start of user PostScript
0.29034 0.594984 0.332236 0.575698 MAarrowhead1
% End of user PostScript
.39716 .39065 m
.42736 .42122 L
s
% Start of user PostScript
0.397157 0.39065 0.427359 0.421217 MAarrowhead1
% End of user PostScript
.49027 .50776 m
.5082 .49783 L
s
% Start of user PostScript
0.490268 0.507765 0.508203 0.497828 MAarrowhead1
% End of user PostScript
.34565 .20772 m
.37211 .25645 L
s
% Start of user PostScript
0.345646 0.207719 0.372114 0.256454 MAarrowhead1
% End of user PostScript
.81765 .37537 m
.77168 .3992 L
s
% Start of user PostScript
0.817654 0.375374 0.771678 0.399203 MAarrowhead1
% End of user PostScript
.38347 .19818 m
.4029 .24808 L
s
% Start of user PostScript
0.383474 0.198177 0.402902 0.248082 MAarrowhead1
% End of user PostScript
.49107 .56449 m
.50798 .52993 L
s
% Start of user PostScript
0.491071 0.564489 0.507982 0.529928 MAarrowhead1
% End of user PostScript
.61733 .23647 m
.59383 .29212 L
s
% Start of user PostScript
0.61733 0.236472 0.593833 0.292121 MAarrowhead1
% End of user PostScript
.62188 .75247 m
.59543 .7017 L
s
% Start of user PostScript
0.621881 0.752466 0.595433 0.701695 MAarrowhead1
% End of user PostScript
.53929 .47892 m
.52422 .48637 L
s
% Start of user PostScript
0.539295 0.478923 0.524218 0.486374 MAarrowhead1
% End of user PostScript
.48029 .45587 m
.4967 .4733 L
s
% Start of user PostScript
0.480288 0.455871 0.496697 0.473299 MAarrowhead1
% End of user PostScript
.5556 .82686 m
.54567 .7741 L
s
% Start of user PostScript
0.555603 0.826862 0.545674 0.774101 MAarrowhead1
% End of user PostScript
.28086 .49884 m
.32628 .49308 L
s
% Start of user PostScript
0.280865 0.498845 0.326279 0.493084 MAarrowhead1
% End of user PostScript
.64397 .28322 m
.60774 .3308 L
s
% Start of user PostScript
0.64397 0.283218 0.607742 0.330801 MAarrowhead1
% End of user PostScript
.36367 .66903 m
.39064 .63446 L
s
% Start of user PostScript
0.363669 0.669028 0.390644 0.634464 MAarrowhead1
% End of user PostScript
.25749 .63207 m
.30426 .6087 L
s
% Start of user PostScript
0.257491 0.632068 0.304262 0.608703 MAarrowhead1
% End of user PostScript
.39028 .30757 m
.41254 .3503 L
s
% Start of user PostScript
0.390285 0.30757 0.412536 0.350298 MAarrowhead1
% End of user PostScript
.79643 .46117 m
.74354 .47312 L
s
% Start of user PostScript
0.796432 0.461175 0.743544 0.473117 MAarrowhead1
% End of user PostScript
.37969 .34362 m
.40874 .38215 L
s
% Start of user PostScript
0.37969 0.343619 0.408742 0.382147 MAarrowhead1
% End of user PostScript
.46438 .52179 m
.49438 .50538 L
s
% Start of user PostScript
0.464383 0.521793 0.494384 0.50538 MAarrowhead1
% End of user PostScript
.44443 .23409 m
.45584 .28302 L
s
% Start of user PostScript
0.444433 0.234086 0.45584 0.283016 MAarrowhead1
% End of user PostScript
.48049 .15685 m
.4852 .20278 L
s
% Start of user PostScript
0.480495 0.156848 0.485198 0.202779 MAarrowhead1
% End of user PostScript
.44521 .752 m
.46843 .70988 L
s
% Start of user PostScript
0.445206 0.752002 0.468427 0.709875 MAarrowhead1
% End of user PostScript
.50538 .45208 m
.5109 .47619 L
s
% Start of user PostScript
0.505375 0.452084 0.510899 0.476189 MAarrowhead1
% End of user PostScript
.59102 .51929 m
.56084 .51555 L
s
% Start of user PostScript
0.591022 0.519289 0.560844 0.515554 MAarrowhead1
% End of user PostScript
.58499 .66545 m
.5699 .62779 L
s
% Start of user PostScript
0.584987 0.665452 0.569897 0.627785 MAarrowhead1
% End of user PostScript
.72831 .38406 m
.67868 .41226 L
s
% Start of user PostScript
0.728307 0.384057 0.67868 0.412265 MAarrowhead1
% End of user PostScript
.76632 .50643 m
.71438 .50764 L
s
% Start of user PostScript
0.766319 0.506435 0.714384 0.507644 MAarrowhead1
% End of user PostScript
.41388 .49584 m
.4527 .48541 L
s
% Start of user PostScript
0.413875 0.495838 0.4527 0.485408 MAarrowhead1
% End of user PostScript
.45163 .81081 m
.47222 .76178 L
s
% Start of user PostScript
0.451628 0.810811 0.472224 0.761779 MAarrowhead1
% End of user PostScript
.70557 .67458 m
.6623 .63958 L
s
% Start of user PostScript
0.705573 0.674581 0.662299 0.63958 MAarrowhead1
% End of user PostScript
.73207 .69687 m
.684 .65701 L
s
% Start of user PostScript
0.732074 0.696868 0.683999 0.657011 MAarrowhead1
% End of user PostScript
.28952 .22921 m
.32935 .27049 L
s
% Start of user PostScript
0.289516 0.229209 0.329352 0.270493 MAarrowhead1
% End of user PostScript
.2787 .28954 m
.32541 .32648 L
s
% Start of user PostScript
0.278699 0.289544 0.32541 0.326479 MAarrowhead1
% End of user PostScript
.36978 .39122 m
.40653 .41896 L
s
% Start of user PostScript
0.369781 0.391216 0.406528 0.418959 MAarrowhead1
% End of user PostScript
.7331 .67667 m
.68474 .642 L
s
% Start of user PostScript
0.733096 0.676674 0.684737 0.641996 MAarrowhead1
% End of user PostScript
.55612 .39405 m
.53978 .42683 L
s
% Start of user PostScript
0.55612 0.394053 0.539778 0.426835 MAarrowhead1
% End of user PostScript
.579 .66451 m
.56631 .62706 L
s
% Start of user PostScript
0.579002 0.66451 0.566314 0.62706 MAarrowhead1
% End of user PostScript
.63567 .69256 m
.60733 .65348 L
s
% Start of user PostScript
0.635671 0.692564 0.60733 0.653483 MAarrowhead1
% End of user PostScript
.25659 .62421 m
.30334 .60149 L
s
% Start of user PostScript
0.256595 0.624213 0.303337 0.601494 MAarrowhead1
% End of user PostScript
.65723 .37745 m
.61421 .40595 L
s
% Start of user PostScript
0.657233 0.37745 0.614207 0.405952 MAarrowhead1
% End of user PostScript
.25251 .67903 m
.30077 .6494 L
s
% Start of user PostScript
0.252512 0.679032 0.30077 0.649397 MAarrowhead1
% End of user PostScript
.77805 .55772 m
.72256 .54663 L
s
% Start of user PostScript
0.778049 0.557719 0.722561 0.546634 MAarrowhead1
% End of user PostScript
.49072 .49772 m
.50821 .4933 L
s
% Start of user PostScript
0.490721 0.497719 0.50821 0.493303 MAarrowhead1
% End of user PostScript
.31466 .28234 m
.35505 .32204 L
s
% Start of user PostScript
0.314656 0.282338 0.355046 0.322038 MAarrowhead1
% End of user PostScript
.55264 .5921 m
.54751 .55995 L
s
% Start of user PostScript
0.552641 0.5921 0.547515 0.559954 MAarrowhead1
% End of user PostScript
.46792 .68749 m
.48707 .65137 L
s
% Start of user PostScript
0.467918 0.687493 0.487071 0.651375 MAarrowhead1
% End of user PostScript
.42795 .66902 m
.45061 .63334 L
s
% Start of user PostScript
0.427947 0.669016 0.450609 0.633337 MAarrowhead1
% End of user PostScript
.46259 .38622 m
.47724 .422 L
s
% Start of user PostScript
0.462592 0.386225 0.477242 0.422001 MAarrowhead1
% End of user PostScript
.49355 .50566 m
.50986 .49693 L
s
% Start of user PostScript
0.493552 0.505657 0.509863 0.496933 MAarrowhead1
% End of user PostScript
.5747 .25517 m
.56277 .31111 L
s
% Start of user PostScript
0.574696 0.255167 0.562767 0.311108 MAarrowhead1
% End of user PostScript
.5378 .64911 m
.54108 .61352 L
s
% Start of user PostScript
0.537795 0.649108 0.541076 0.613523 MAarrowhead1
% End of user PostScript
.56781 .59649 m
.55753 .56492 L
s
% Start of user PostScript
0.567813 0.596487 0.557533 0.564917 MAarrowhead1
% End of user PostScript
.692 .57624 m
.64368 .56011 L
s
% Start of user PostScript
0.692001 0.576244 0.643677 0.560115 MAarrowhead1
% End of user PostScript
.36101 .64815 m
.39048 .61776 L
s
% Start of user PostScript
0.361013 0.648148 0.390481 0.617763 MAarrowhead1
% End of user PostScript
.52802 .29671 m
.52791 .35028 L
s
% Start of user PostScript
0.528021 0.296708 0.527914 0.350284 MAarrowhead1
% End of user PostScript
.76932 .46973 m
.71761 .48006 L
s
% Start of user PostScript
0.769316 0.469732 0.717609 0.480055 MAarrowhead1
% End of user PostScript
.59185 .38072 m
.56445 .41144 L
s
% Start of user PostScript
0.591852 0.380723 0.564451 0.411439 MAarrowhead1
% End of user PostScript
.64415 .45833 m
.6028 .47219 L
s
% Start of user PostScript
0.644149 0.458333 0.602799 0.472189 MAarrowhead1
% End of user PostScript
.58048 .18904 m
.56428 .24037 L
s
% Start of user PostScript
0.580476 0.189042 0.564281 0.240372 MAarrowhead1
% End of user PostScript
.43477 .49763 m
.47319 .48906 L
s
% Start of user PostScript
0.434772 0.497633 0.473192 0.48906 MAarrowhead1
% End of user PostScript
.31984 .23521 m
.355 .27974 L
s
% Start of user PostScript
0.31984 0.235209 0.355 0.279739 MAarrowhead1
% End of user PostScript
.69345 .44857 m
.64413 .46339 L
s
% Start of user PostScript
0.693446 0.448571 0.644127 0.463388 MAarrowhead1
% End of user PostScript
.41634 .27023 m
.43259 .3173 L
s
% Start of user PostScript
0.416338 0.270232 0.432589 0.317296 MAarrowhead1
% End of user PostScript
.62575 .5463 m
.59046 .53521 L
s
% Start of user PostScript
0.625752 0.546298 0.590464 0.535207 MAarrowhead1
% End of user PostScript
.56727 .44014 m
.54236 .46215 L
s
% Start of user PostScript
0.567266 0.440141 0.542361 0.462154 MAarrowhead1
% End of user PostScript
.77124 .38509 m
.72209 .41113 L
s
% Start of user PostScript
0.771241 0.385086 0.722086 0.411132 MAarrowhead1
% End of user PostScript
.32792 .70157 m
.3572 .6641 L
s
% Start of user PostScript
0.327922 0.701573 0.357198 0.664096 MAarrowhead1
% End of user PostScript
.52014 .56777 m
.5252 .53479 L
s
% Start of user PostScript
0.520136 0.56777 0.525202 0.534795 MAarrowhead1
% End of user PostScript
.5092 .31763 m
.51408 .36736 L
s
% Start of user PostScript
0.5092 0.317627 0.51408 0.367361 MAarrowhead1
% End of user PostScript
.20154 .50222 m
.2552 .5004 L
s
% Start of user PostScript
0.20154 0.502218 0.255202 0.500398 MAarrowhead1
% End of user PostScript
.54293 .70874 m
.54279 .6667 L
s
% Start of user PostScript
0.542931 0.708735 0.542787 0.666702 MAarrowhead1
% End of user PostScript
.51214 .77749 m
.51691 .72945 L
s
% Start of user PostScript
0.512135 0.777491 0.516912 0.729446 MAarrowhead1
% End of user PostScript
.59328 .27601 m
.576 .32799 L
s
% Start of user PostScript
0.593277 0.276014 0.576003 0.32799 MAarrowhead1
% End of user PostScript
.35562 .4683 m
.39666 .46538 L
s
% Start of user PostScript
0.355623 0.468299 0.396662 0.46538 MAarrowhead1
% End of user PostScript
.26768 .7525 m
.30618 .7112 L
s
% Start of user PostScript
0.267682 0.752502 0.30618 0.711202 MAarrowhead1
% End of user PostScript
.49465 .46111 m
.5063 .47889 L
s
% Start of user PostScript
0.494654 0.461114 0.506303 0.478888 MAarrowhead1
% End of user PostScript
.46895 .18992 m
.47615 .23858 L
s
% Start of user PostScript
0.468949 0.18992 0.476154 0.238576 MAarrowhead1
% End of user PostScript
.6315 .53556 m
.59326 .52865 L
s
% Start of user PostScript
0.631501 0.535562 0.59326 0.52865 MAarrowhead1
% End of user PostScript
.4191 .42243 m
.44678 .44219 L
s
% Start of user PostScript
0.4191 0.422433 0.446775 0.442188 MAarrowhead1
% End of user PostScript
.58484 .55236 m
.56353 .53411 L
s
% Start of user PostScript
0.584844 0.552361 0.563528 0.534113 MAarrowhead1
% End of user PostScript
.72448 .6945 m
.67782 .65499 L
s
% Start of user PostScript
0.724481 0.6945 0.677823 0.654991 MAarrowhead1
% End of user PostScript
.59097 .35502 m
.56504 .39025 L
s
% Start of user PostScript
0.590966 0.355024 0.565035 0.390255 MAarrowhead1
% End of user PostScript
.59683 .62632 m
.57612 .59312 L
s
% Start of user PostScript
0.59683 0.626324 0.576121 0.593116 MAarrowhead1
% End of user PostScript
.64336 .29226 m
.60652 .33756 L
s
% Start of user PostScript
0.643364 0.292263 0.60652 0.337562 MAarrowhead1
% End of user PostScript
.25928 .36147 m
.31085 .38751 L
s
% Start of user PostScript
0.259278 0.361466 0.31085 0.387507 MAarrowhead1
% End of user PostScript
.34281 .43577 m
.38676 .44502 L
s
% Start of user PostScript
0.342805 0.435766 0.386755 0.445016 MAarrowhead1
% End of user PostScript
.22732 .56143 m
.2762 .5459 L
s
% Start of user PostScript
0.227325 0.56143 0.276201 0.545895 MAarrowhead1
% End of user PostScript
.63588 .57862 m
.60022 .55684 L
s
% Start of user PostScript
0.635879 0.578622 0.600219 0.556843 MAarrowhead1
% End of user PostScript
.81196 .46182 m
.75973 .4728 L
s
% Start of user PostScript
0.81196 0.461821 0.759727 0.472799 MAarrowhead1
% End of user PostScript
.48656 .55043 m
.50574 .51832 L
s
% Start of user PostScript
0.486562 0.550426 0.505736 0.518324 MAarrowhead1
% End of user PostScript
.29246 .33057 m
.33946 .36255 L
s
% Start of user PostScript
0.292464 0.330571 0.339459 0.362554 MAarrowhead1
% End of user PostScript
.19156 .59288 m
.23958 .57369 L
s
% Start of user PostScript
0.191556 0.592884 0.239583 0.573691 MAarrowhead1
% End of user PostScript
.49069 .1823 m
.49264 .22976 L
s
% Start of user PostScript
0.490686 0.182305 0.492636 0.229762 MAarrowhead1
% End of user PostScript
.65287 .32498 m
.61111 .36166 L
s
% Start of user PostScript
0.652866 0.324979 0.611113 0.361663 MAarrowhead1
% End of user PostScript
.63885 .30742 m
.60259 .3493 L
s
% Start of user PostScript
0.638851 0.307419 0.602586 0.349304 MAarrowhead1
% End of user PostScript
.46277 .82559 m
.47851 .77665 L
s
% Start of user PostScript
0.462766 0.825586 0.478511 0.776648 MAarrowhead1
% End of user PostScript
.1927 .4684 m
.24448 .47467 L
s
% Start of user PostScript
0.192703 0.468399 0.244481 0.47467 MAarrowhead1
% End of user PostScript
.7311 .43503 m
.68034 .4534 L
s
% Start of user PostScript
0.731104 0.435029 0.680341 0.453399 MAarrowhead1
% End of user PostScript
.47356 .57871 m
.49526 .54438 L
s
% Start of user PostScript
0.473562 0.578708 0.495258 0.544384 MAarrowhead1
% End of user PostScript
.60414 .60142 m
.58053 .57151 L
s
% Start of user PostScript
0.604136 0.601421 0.580525 0.571514 MAarrowhead1
% End of user PostScript
.37736 .44138 m
.41455 .44915 L
s
% Start of user PostScript
0.377356 0.441384 0.414552 0.44915 MAarrowhead1
% End of user PostScript
.60784 .56057 m
.57978 .54348 L
s
% Start of user PostScript
0.607843 0.560572 0.57978 0.543477 MAarrowhead1
% End of user PostScript
.55556 .72821 m
.55081 .68333 L
s
% Start of user PostScript
0.555559 0.728209 0.55081 0.683331 MAarrowhead1
% End of user PostScript
.61412 .39011 m
.58045 .41796 L
s
% Start of user PostScript
0.61412 0.390106 0.580451 0.417956 MAarrowhead1
% End of user PostScript
.44472 .24002 m
.45595 .28867 L
s
% Start of user PostScript
0.444722 0.240015 0.45595 0.288674 MAarrowhead1
% End of user PostScript
.47529 .78553 m
.49064 .73763 L
s
% Start of user PostScript
0.47529 0.785526 0.490644 0.737626 MAarrowhead1
% End of user PostScript
.55701 .5517 m
.5445 .52765 L
s
% Start of user PostScript
0.557008 0.551701 0.544497 0.527646 MAarrowhead1
% End of user PostScript
.50839 .80461 m
.51339 .75324 L
s
% Start of user PostScript
0.50839 0.804608 0.513393 0.753244 MAarrowhead1
% End of user PostScript
.58258 .38771 m
.55788 .41837 L
s
% Start of user PostScript
0.582583 0.387714 0.557883 0.41837 MAarrowhead1
% End of user PostScript
.36735 .46662 m
.40694 .4645 L
s
% Start of user PostScript
0.367348 0.46662 0.40694 0.464502 MAarrowhead1
% End of user PostScript
.52821 .41195 m
.52138 .44319 L
s
% Start of user PostScript
0.528212 0.411951 0.521375 0.443186 MAarrowhead1
% End of user PostScript
.32979 .2066 m
.35965 .25364 L
s
% Start of user PostScript
0.329791 0.206595 0.359648 0.253643 MAarrowhead1
% End of user PostScript
.18369 .54321 m
.23337 .53243 L
s
% Start of user PostScript
0.183688 0.54321 0.23337 0.532435 MAarrowhead1
% End of user PostScript
.64611 .25254 m
.61203 .30799 L
s
% Start of user PostScript
0.646111 0.252542 0.612027 0.307991 MAarrowhead1
% End of user PostScript
.33664 .48311 m
.37898 .47639 L
s
% Start of user PostScript
0.336643 0.483107 0.378978 0.47639 MAarrowhead1
% End of user PostScript
.55414 .69493 m
.55078 .6541 L
s
% Start of user PostScript
0.554135 0.694927 0.55078 0.6541 MAarrowhead1
% End of user PostScript
.74657 .57968 m
.69313 .56497 L
s
% Start of user PostScript
0.746572 0.579677 0.693135 0.564968 MAarrowhead1
% End of user PostScript
.59426 .75254 m
.57628 .70296 L
s
% Start of user PostScript
0.594257 0.752543 0.576285 0.702957 MAarrowhead1
% End of user PostScript
.59478 .70995 m
.57682 .66657 L
s
% Start of user PostScript
0.594782 0.709947 0.576821 0.666573 MAarrowhead1
% End of user PostScript
.60095 .79503 m
.57679 .74026 L
s
% Start of user PostScript
0.600951 0.795031 0.576788 0.740264 MAarrowhead1
% End of user PostScript
.36864 .42608 m
.40726 .44025 L
s
% Start of user PostScript
0.368644 0.426077 0.407261 0.440253 MAarrowhead1
% End of user PostScript
.70799 .36485 m
.6587 .39624 L
s
% Start of user PostScript
0.707994 0.364855 0.658702 0.396237 MAarrowhead1
% End of user PostScript
.59542 .51959 m
.56401 .51656 L
s
% Start of user PostScript
0.595424 0.519594 0.56401 0.51656 MAarrowhead1
% End of user PostScript
.24585 .51285 m
.2947 .50846 L
s
% Start of user PostScript
0.245854 0.512853 0.294704 0.508465 MAarrowhead1
% End of user PostScript
.54648 .36789 m
.53462 .40624 L
s
% Start of user PostScript
0.546476 0.367894 0.53462 0.406241 MAarrowhead1
% End of user PostScript
.76272 .32641 m
.71718 .36056 L
s
% Start of user PostScript
0.762719 0.326408 0.717185 0.360556 MAarrowhead1
% End of user PostScript
.18059 .42345 m
.2286 .43738 L
s
% Start of user PostScript
0.180592 0.423447 0.2286 0.437384 MAarrowhead1
% End of user PostScript
.68495 .44014 m
.63718 .45715 L
s
% Start of user PostScript
0.684947 0.440143 0.637182 0.457155 MAarrowhead1
% End of user PostScript
.48865 .35349 m
.49862 .39658 L
s
% Start of user PostScript
0.48865 0.353487 0.498619 0.396584 MAarrowhead1
% End of user PostScript
.7797 .51238 m
.72646 .51156 L
s
% Start of user PostScript
0.779698 0.512375 0.726459 0.511559 MAarrowhead1
% End of user PostScript
.59516 .23667 m
.57797 .2926 L
s
% Start of user PostScript
0.595158 0.236665 0.577971 0.292596 MAarrowhead1
% End of user PostScript
.7928 .61488 m
.73806 .5932 L
s
% Start of user PostScript
0.792801 0.614882 0.73806 0.593202 MAarrowhead1
% End of user PostScript
.30245 .53307 m
.3431 .51949 L
s
% Start of user PostScript
0.302448 0.533065 0.343097 0.519491 MAarrowhead1
% End of user PostScript
.38542 .58192 m
.41955 .55929 L
s
% Start of user PostScript
0.385419 0.581921 0.419547 0.559292 MAarrowhead1
% End of user PostScript
.44528 .35823 m
.46496 .40072 L
s
% Start of user PostScript
0.44528 0.358229 0.464961 0.400724 MAarrowhead1
% End of user PostScript
.63629 .71256 m
.60762 .66974 L
s
% Start of user PostScript
0.636293 0.71256 0.60762 0.669736 MAarrowhead1
% End of user PostScript
.52338 .52739 m
.52296 .50911 L
s
% Start of user PostScript
0.523379 0.527386 0.522957 0.509109 MAarrowhead1
% End of user PostScript
.2145 .49608 m
.26702 .49586 L
s
% Start of user PostScript
0.214505 0.496079 0.267025 0.495862 MAarrowhead1
% End of user PostScript
.54475 .43849 m
.52775 .4627 L
s
% Start of user PostScript
0.544748 0.438488 0.52775 0.462697 MAarrowhead1
% End of user PostScript
.55287 .34398 m
.54024 .38646 L
s
% Start of user PostScript
0.552871 0.343984 0.540237 0.386456 MAarrowhead1
% End of user PostScript
.30317 .73075 m
.33676 .68906 L
s
% Start of user PostScript
0.303169 0.730751 0.336762 0.689062 MAarrowhead1
% End of user PostScript
.73508 .56824 m
.68209 .55584 L
s
% Start of user PostScript
0.735076 0.568239 0.682087 0.55584 MAarrowhead1
% End of user PostScript
.52493 .43365 m
.51896 .46058 L
s
% Start of user PostScript
0.524934 0.433653 0.518956 0.460583 MAarrowhead1
% End of user PostScript
.52543 .77749 m
.52624 .72851 L
s
% Start of user PostScript
0.525427 0.777488 0.526242 0.728511 MAarrowhead1
% End of user PostScript
.27615 .37025 m
.32664 .39535 L
s
% Start of user PostScript
0.276148 0.370246 0.32664 0.395355 MAarrowhead1
% End of user PostScript
.67873 .60456 m
.63566 .57888 L
s
% Start of user PostScript
0.678735 0.60456 0.635656 0.578883 MAarrowhead1
% End of user PostScript
.60881 .63535 m
.5844 .60155 L
s
% Start of user PostScript
0.60881 0.63535 0.5844 0.601551 MAarrowhead1
% End of user PostScript
.63919 .77313 m
.60786 .72059 L
s
% Start of user PostScript
0.639195 0.773134 0.607864 0.720586 MAarrowhead1
% End of user PostScript
.4952 .66248 m
.51074 .62523 L
s
% Start of user PostScript
0.495204 0.662483 0.510736 0.62523 MAarrowhead1
% End of user PostScript
.55887 .46897 m
.53449 .48125 L
s
% Start of user PostScript
0.55887 0.468973 0.534493 0.481248 MAarrowhead1
% End of user PostScript
.42909 .39622 m
.45179 .4274 L
s
% Start of user PostScript
0.429092 0.396224 0.45179 0.427403 MAarrowhead1
% End of user PostScript
.30339 .70727 m
.33858 .67176 L
s
% Start of user PostScript
0.303395 0.707265 0.338577 0.671762 MAarrowhead1
% End of user PostScript
.32095 .45138 m
.36877 .45629 L
s
% Start of user PostScript
0.320954 0.451382 0.368774 0.456294 MAarrowhead1
% End of user PostScript
.41121 .45417 m
.4435 .45902 L
s
% Start of user PostScript
0.411206 0.454168 0.443503 0.459019 MAarrowhead1
% End of user PostScript
.65434 .4854 m
.60983 .49375 L
s
% Start of user PostScript
0.654345 0.485397 0.609833 0.493754 MAarrowhead1
% End of user PostScript
.33462 .3945 m
.3794 .41878 L
s
% Start of user PostScript
0.334625 0.394497 0.379399 0.418775 MAarrowhead1
% End of user PostScript
.34958 .28914 m
.38006 .32984 L
s
% Start of user PostScript
0.34958 0.289144 0.380059 0.329839 MAarrowhead1
% End of user PostScript
.51296 .16393 m
.50959 .21039 L
s
% Start of user PostScript
0.512961 0.163935 0.509592 0.210386 MAarrowhead1
% End of user PostScript
.50875 .34793 m
.51282 .39135 L
s
% Start of user PostScript
0.50875 0.347932 0.512817 0.391351 MAarrowhead1
% End of user PostScript
.54207 .42477 m
.52794 .45224 L
s
% Start of user PostScript
0.542067 0.42477 0.527944 0.452239 MAarrowhead1
% End of user PostScript
.50944 .16237 m
.50691 .20873 L
s
% Start of user PostScript
0.509444 0.162374 0.506907 0.208735 MAarrowhead1
% End of user PostScript
.52203 .53394 m
.52315 .51208 L
s
% Start of user PostScript
0.522034 0.533935 0.523148 0.512082 MAarrowhead1
% End of user PostScript
.333 .73031 m
.36037 .68732 L
s
% Start of user PostScript
0.333001 0.730309 0.360366 0.687319 MAarrowhead1
% End of user PostScript
.64541 .53495 m
.60323 .52896 L
s
% Start of user PostScript
0.645405 0.534952 0.603225 0.52896 MAarrowhead1
% End of user PostScript
.66157 .56123 m
.61754 .54731 L
s
% Start of user PostScript
0.661572 0.561228 0.61754 0.547311 MAarrowhead1
% End of user PostScript
.47896 .41423 m
.4905 .4441 L
s
% Start of user PostScript
0.478957 0.41423 0.490499 0.444104 MAarrowhead1
% End of user PostScript
.47849 .5438 m
.50124 .51604 L
s
% Start of user PostScript
0.478489 0.543796 0.50124 0.51604 MAarrowhead1
% End of user PostScript
.31225 .69662 m
.34596 .66245 L
s
% Start of user PostScript
0.312247 0.696615 0.345957 0.662446 MAarrowhead1
% End of user PostScript
.66524 .41089 m
.62101 .43491 L
s
% Start of user PostScript
0.665242 0.410886 0.621009 0.434907 MAarrowhead1
% End of user PostScript
.6862 .28932 m
.63893 .33154 L
s
% Start of user PostScript
0.686205 0.289315 0.63893 0.331536 MAarrowhead1
% End of user PostScript
.43336 .54105 m
.46984 .51943 L
s
% Start of user PostScript
0.433356 0.541049 0.469837 0.519426 MAarrowhead1
% End of user PostScript
.44727 .74272 m
.47014 .7019 L
s
% Start of user PostScript
0.447266 0.742724 0.470138 0.701902 MAarrowhead1
% End of user PostScript
.57711 .44948 m
.5485 .46886 L
s
% Start of user PostScript
0.577108 0.449478 0.5485 0.46886 MAarrowhead1
% End of user PostScript
.33141 .66711 m
.36381 .63648 L
s
% Start of user PostScript
0.331409 0.667108 0.363809 0.636475 MAarrowhead1
% End of user PostScript
.56524 .32843 m
.55084 .37308 L
s
% Start of user PostScript
0.565243 0.328433 0.550841 0.373085 MAarrowhead1
% End of user PostScript
.37283 .42134 m
.41043 .4379 L
s
% Start of user PostScript
0.37283 0.421345 0.410426 0.4379 MAarrowhead1
% End of user PostScript
.53596 .50004 m
.52325 .49658 L
s
% Start of user PostScript
0.535957 0.500042 0.523245 0.496579 MAarrowhead1
% End of user PostScript
.57 .57128 m
.55577 .5456 L
s
% Start of user PostScript
0.569996 0.571282 0.555766 0.545598 MAarrowhead1
% End of user PostScript
.80553 .35037 m
.76009 .37851 L
s
% Start of user PostScript
0.805527 0.350373 0.760094 0.378506 MAarrowhead1
% End of user PostScript
.704 .50656 m
.65389 .50935 L
s
% Start of user PostScript
0.704003 0.506562 0.653892 0.509347 MAarrowhead1
% End of user PostScript
.49062 .73914 m
.50282 .69761 L
s
% Start of user PostScript
0.490625 0.739142 0.502818 0.697614 MAarrowhead1
% End of user PostScript
.28693 .67644 m
.32802 .648 L
s
% Start of user PostScript
0.286933 0.67644 0.328022 0.647997 MAarrowhead1
% End of user PostScript
.67308 .6162 m
.63188 .58864 L
s
% Start of user PostScript
0.673079 0.616198 0.63188 0.588638 MAarrowhead1
% End of user PostScript
.45197 .56123 m
.48346 .53254 L
s
% Start of user PostScript
0.451965 0.561229 0.48346 0.532537 MAarrowhead1
% End of user PostScript
.34774 .56429 m
.3854 .54699 L
s
% Start of user PostScript
0.347738 0.56429 0.385398 0.546986 MAarrowhead1
% End of user PostScript
.52826 .72564 m
.53152 .68279 L
s
% Start of user PostScript
0.52826 0.725642 0.531515 0.682788 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.343006 0.64881 0.640625 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.76704 .46948 Mdot
.51511 .50359 Mdot
.67112 .56246 Mdot
.64281 .47418 Mdot
.62936 .33058 Mdot
.66175 .745 Mdot
.76889 .46261 Mdot
.3357 .2376 Mdot
.82982 .48202 Mdot
.30921 .4263 Mdot
.27372 .6541 Mdot
.75811 .61384 Mdot
.48847 .47807 Mdot
.44937 .77505 Mdot
.67112 .31136 Mdot
.30849 .42772 Mdot
.49182 .59647 Mdot
.34502 .28582 Mdot
.3026 .45528 Mdot
.52022 .80144 Mdot
.56038 .28783 Mdot
.65916 .42592 Mdot
.30896 .27118 Mdot
.68909 .66578 Mdot
.56159 .78676 Mdot
.77441 .66365 Mdot
.42102 .44332 Mdot
.5348 .30527 Mdot
.4972 .49833 Mdot
.29286 .69988 Mdot
.42821 .72027 Mdot
.24667 .71364 Mdot
.5015 .46034 Mdot
.43727 .26886 Mdot
.41214 .5975 Mdot
.68501 .22129 Mdot
.33591 .61857 Mdot
.55492 .50265 Mdot
.64661 .549 Mdot
.24904 .53244 Mdot
.46704 .34929 Mdot
.31323 .75137 Mdot
.35626 .25489 Mdot
.57489 .81816 Mdot
.64754 .73109 Mdot
.50572 .33081 Mdot
.70213 .55575 Mdot
.59621 .65616 Mdot
.52258 .48189 Mdot
.36571 .59196 Mdot
.73365 .65054 Mdot
.623 .74101 Mdot
.36261 .36198 Mdot
.77272 .63508 Mdot
.56641 .75713 Mdot
.74876 .70575 Mdot
.39543 .82042 Mdot
.31413 .35656 Mdot
.28526 .49004 Mdot
.46202 .39951 Mdot
.63738 .34406 Mdot
.1996 .42677 Mdot
.77988 .54227 Mdot
.42494 .43535 Mdot
.40408 .37057 Mdot
.54045 .34233 Mdot
.40352 .26194 Mdot
.67442 .41791 Mdot
.32879 .29693 Mdot
.22342 .35824 Mdot
.41819 .57573 Mdot
.67928 .69801 Mdot
.52801 .22559 Mdot
.67123 .2475 Mdot
.83778 .48372 Mdot
.23558 .53058 Mdot
.28453 .35585 Mdot
.66108 .43821 Mdot
.50835 .51231 Mdot
.47574 .82891 Mdot
.51724 .33543 Mdot
.55883 .47513 Mdot
.43625 .42725 Mdot
.67598 .56142 Mdot
.6444 .63438 Mdot
.27234 .56059 Mdot
.35274 .6437 Mdot
.54596 .81476 Mdot
.79282 .5618 Mdot
.27909 .4503 Mdot
.70608 .71395 Mdot
.25838 .46407 Mdot
.34118 .36629 Mdot
.61559 .31048 Mdot
.52427 .65901 Mdot
.58161 .51756 Mdot
.30258 .74925 Mdot
.60574 .29286 Mdot
.52481 .69319 Mdot
.65236 .28522 Mdot
.26442 .58221 Mdot
.41617 .46498 Mdot
.22655 .37429 Mdot
.44396 .72125 Mdot
.54534 .66455 Mdot
.49202 .47416 Mdot
.50387 .5328 Mdot
.78079 .3424 Mdot
.56702 .56676 Mdot
.40538 .64214 Mdot
.66953 .71863 Mdot
.49209 .23331 Mdot
.5719 .47587 Mdot
.29034 .59498 Mdot
.39716 .39065 Mdot
.49027 .50776 Mdot
.34565 .20772 Mdot
.81765 .37537 Mdot
.38347 .19818 Mdot
.49107 .56449 Mdot
.61733 .23647 Mdot
.62188 .75247 Mdot
.53929 .47892 Mdot
.48029 .45587 Mdot
.5556 .82686 Mdot
.28086 .49884 Mdot
.64397 .28322 Mdot
.36367 .66903 Mdot
.25749 .63207 Mdot
.39028 .30757 Mdot
.79643 .46117 Mdot
.37969 .34362 Mdot
.46438 .52179 Mdot
.44443 .23409 Mdot
.48049 .15685 Mdot
.44521 .752 Mdot
.50538 .45208 Mdot
.59102 .51929 Mdot
.58499 .66545 Mdot
.72831 .38406 Mdot
.76632 .50643 Mdot
.41388 .49584 Mdot
.45163 .81081 Mdot
.70557 .67458 Mdot
.73207 .69687 Mdot
.28952 .22921 Mdot
.2787 .28954 Mdot
.36978 .39122 Mdot
.7331 .67667 Mdot
.55612 .39405 Mdot
.579 .66451 Mdot
.63567 .69256 Mdot
.25659 .62421 Mdot
.65723 .37745 Mdot
.25251 .67903 Mdot
.77805 .55772 Mdot
.49072 .49772 Mdot
.31466 .28234 Mdot
.55264 .5921 Mdot
.46792 .68749 Mdot
.42795 .66902 Mdot
.46259 .38622 Mdot
.49355 .50566 Mdot
.5747 .25517 Mdot
.5378 .64911 Mdot
.56781 .59649 Mdot
.692 .57624 Mdot
.36101 .64815 Mdot
.52802 .29671 Mdot
.76932 .46973 Mdot
.59185 .38072 Mdot
.64415 .45833 Mdot
.58048 .18904 Mdot
.43477 .49763 Mdot
.31984 .23521 Mdot
.69345 .44857 Mdot
.41634 .27023 Mdot
.62575 .5463 Mdot
.56727 .44014 Mdot
.77124 .38509 Mdot
.32792 .70157 Mdot
.52014 .56777 Mdot
.5092 .31763 Mdot
.20154 .50222 Mdot
.54293 .70874 Mdot
.51214 .77749 Mdot
.59328 .27601 Mdot
.35562 .4683 Mdot
.26768 .7525 Mdot
.49465 .46111 Mdot
.46895 .18992 Mdot
.6315 .53556 Mdot
.4191 .42243 Mdot
.58484 .55236 Mdot
.72448 .6945 Mdot
.59097 .35502 Mdot
.59683 .62632 Mdot
.64336 .29226 Mdot
.25928 .36147 Mdot
.34281 .43577 Mdot
.22732 .56143 Mdot
.63588 .57862 Mdot
.81196 .46182 Mdot
.48656 .55043 Mdot
.29246 .33057 Mdot
.19156 .59288 Mdot
.49069 .1823 Mdot
.65287 .32498 Mdot
.63885 .30742 Mdot
.46277 .82559 Mdot
.1927 .4684 Mdot
.7311 .43503 Mdot
.47356 .57871 Mdot
.60414 .60142 Mdot
.37736 .44138 Mdot
.60784 .56057 Mdot
.55556 .72821 Mdot
.61412 .39011 Mdot
.44472 .24002 Mdot
.47529 .78553 Mdot
.55701 .5517 Mdot
.50839 .80461 Mdot
.58258 .38771 Mdot
.36735 .46662 Mdot
.52821 .41195 Mdot
.32979 .2066 Mdot
.18369 .54321 Mdot
.64611 .25254 Mdot
.33664 .48311 Mdot
.55414 .69493 Mdot
.74657 .57968 Mdot
.59426 .75254 Mdot
.59478 .70995 Mdot
.60095 .79503 Mdot
.36864 .42608 Mdot
.70799 .36485 Mdot
.59542 .51959 Mdot
.24585 .51285 Mdot
.54648 .36789 Mdot
.76272 .32641 Mdot
.18059 .42345 Mdot
.68495 .44014 Mdot
.48865 .35349 Mdot
.7797 .51238 Mdot
.59516 .23667 Mdot
.7928 .61488 Mdot
.30245 .53307 Mdot
.38542 .58192 Mdot
.44528 .35823 Mdot
.63629 .71256 Mdot
.52338 .52739 Mdot
.2145 .49608 Mdot
.54475 .43849 Mdot
.55287 .34398 Mdot
.30317 .73075 Mdot
.73508 .56824 Mdot
.52493 .43365 Mdot
.52543 .77749 Mdot
.27615 .37025 Mdot
.67873 .60456 Mdot
.60881 .63535 Mdot
.63919 .77313 Mdot
.4952 .66248 Mdot
.55887 .46897 Mdot
.42909 .39622 Mdot
.30339 .70727 Mdot
.32095 .45138 Mdot
.41121 .45417 Mdot
.65434 .4854 Mdot
.33462 .3945 Mdot
.34958 .28914 Mdot
.51296 .16393 Mdot
.50875 .34793 Mdot
.54207 .42477 Mdot
.50944 .16237 Mdot
.52203 .53394 Mdot
.333 .73031 Mdot
.64541 .53495 Mdot
.66157 .56123 Mdot
.47896 .41423 Mdot
.47849 .5438 Mdot
.31225 .69662 Mdot
.66524 .41089 Mdot
.6862 .28932 Mdot
.43336 .54105 Mdot
.44727 .74272 Mdot
.57711 .44948 Mdot
.33141 .66711 Mdot
.56524 .32843 Mdot
.37283 .42134 Mdot
.53596 .50004 Mdot
.57 .57128 Mdot
.80553 .35037 Mdot
.704 .50656 Mdot
.49062 .73914 Mdot
.28693 .67644 Mdot
.67308 .6162 Mdot
.45197 .56123 Mdot
.34774 .56429 Mdot
.52826 .72564 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{520.688, 341.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000::0001Zb000`400?l00000o`00003ooooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooo
oon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?ooooooiOooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00002_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`02_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`04_ooool4o`00
0003oa0@4?oooooooooo01cooooo003oooooonGooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`08ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0:ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@0Dooooo`03o`000?oooooo
oooo01kooooo003oooooonGooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00002Oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool07_ooool0
07oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0aoooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP24ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP0:ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000:oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00[ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805?ooool00ol0003o
ooooooooo`0Nooooo`00Ooooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`37ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg08Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`02_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00Dooooo`03o`000?oooooooooo01ko
oooo0020ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4038ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4024ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`00000:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7
ooooo`0<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
01Cooooo00?o0000ooooooooool07_ooool0087ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo00000<Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
2_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000002_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P03?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Dooooo`03o`000?oooooooooo01kooooo0022
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00003:ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000024ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT04_ooool00omEEEGoIVIVo`00000Pooooo`00Poooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0bOooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool0ooooool@ooooo`;o00000_ooool2o`0001?ooooo001oooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Oooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolBooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4oooool007oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0aoooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP3ooooooa?ooooo00CogMgMo`000?l@413oc<c<5?ooool00?ooooood_oooonIo`0000So
oooo00Cok^k^ob4Q8Ol@413ok^k^5?ooool00?ooooood_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01?lQ8B7oMgMgogMgMolb<S8Doooo
o`00oooooooBooooo`03o`000?oooooooooo09gooooo0_l00002ooooo`;o00004oooool008_ooooo
0_l0003Cooooo`;o0000Koooool00ol0003oooooooooo`2fooooo`00R?ooool6o`000<oooooo0ol0
00000ooooooo0000ooooo`1^ooooo`03o`000?oooooooooo0;Kooooo001Mooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo01_ooooo1Ol000000onY_NSo0000o`00
002Sooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo01cooooo
0_l00004ooooo`;o0000K_ooool00ol0003oooooooooo`2fooooo`00Goooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo01Sooooo1Ol00004ojVmj0?o0000Y?ooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00006ooooo`03o`000?oooooo000006gooooo00?o
0000ooooooooool0]_ooool005oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`Ko00001_nY_NP00ol0003oZKgXo`00002Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05Oooool3o`0000Wooooo00?o0000ooooool00000KOooool00ol0003oooooooooo`2f
ooooo`00Goooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01?ooooo1Ol00002ojVm
j003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00_l0002Rooooo`03o`000?oooooooooo
00Kooooo00?oMgMgoc8b<_ooool05?ooool2o`0000cooooo00Co0000ooooool0003o0000K?ooool0
0ol0003oooooooooo`2fooooo`00Goooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04Oooool5o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXojVmj002
o`000:;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01;ooooo1?l0
000=ooooo`05o`000?ooooooooooooooool00000Joooool00ol0003oooooooooo`2fooooo`00Gooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l000000onY_NSo0000ojVm
j007ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol000000onY_NSo0000ooooo`2Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool2o`00017ooooo00Go0000oooooooooooooooo
o`00001[ooooo`03o`000?oooooooooo0;Kooooo001Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool5o`0000CoZKgX00?o0000ojVmj?nY_NP01_nY_NP01_l0003oZKgXo`00
0?l0003oZKgXo`0000?oZKgX00?o0000ooooooooool0Woooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`2fooooo`00GOooool00omEEEGoIVIVo`000005ooooo`Co0000
2oooool2o`000003ooooool0003o000000OoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000?oZKgX
00?o0000ojVmj?nY_NP00_nY_NP00ol0003oooooooooo`2Looooo`03oeEEEOmVIVKo000000Gooooo
1?l0000;ooooo`?o00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2fooooo`00LOooool6o`000003ojVmj?l0
003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj005o`000?nY_NSoZKgXojVmj?l00000
1?nY_NP2o`000;;ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`2fooooo`00K_ooool6o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSo00001?nY_NP2o`000:oooooo1?l0000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2fooooo`00K?oo
ool2o`000004ooooool0003o0000o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo
0000ojVmj007ojVmj004o`000?nY_NSo0000ojVmj0?o000000?oZKgXo`000?l00000[?ooool2o`00
01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
0;Kooooo001Yooooo`Ko00000_nY_NP00ol0003oZKgXojVmj006ojVmj004o`000?nY_NSo0000o`00
00GoZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?oooooo
oooo0:Oooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`2fooooo`00Ioooool5o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`00
00SoZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000OoZKgX00?o0000ooooooooool01Oooool01Om4
A4Co0000o`000?lb<S;ogMgM09Wooooo0ol000000ooooooo0000ooooo`0Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01Om4A4Co0000o`000?lb<S;ogMgM05[ooooo00?o
0000ooooooooool0]_ooool003cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^7?ooool5o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o00001onY_NP2o`0000Wo
oooo00?oMgMgoc8b<_ooool0KOooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hMooooo`;o00009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
MgMgoc8b<_ooool0FOooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool5o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000[ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool4o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0]_ooool003kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Oooooo1_l00007ojVmj003o`00
0?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0?o
000000?oZKgXo`000?nY_NP01_nY_NP2o`0000;oZKgX0ol00002ojVmj0;o00002?ooool00omgMgOo
<S8booooo`1_ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Hoooo
o`;o0000;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool0FOooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000005Oooool5o`0000;oZKgX00?o0000ojVmj?nY_NP01_nY_NP01?l0
003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0Co00001_nY_NP00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0L?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0002kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0F_ooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool5o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP3o`0000OoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00Co0000ojVm
j?nY_NSoZKgX0ol000000onY_NSo0000ojVmj007ojVmj0;o00000oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`;o000000?o
ooooo`000?ooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003oooool5o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol0
0002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00000_nY_NP01?l0003oZKgX
ojVmj?l00007ojVmj0;o00000oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`?o0000<oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`2foooo
o`00?_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool5o`00
00CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000CoZKgX00Go0000ojVmj?nY_NSoZKgXo`000003
ojVmj0?o000000?oZKgXo`000?ooool00_ooool4o`00077ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00gooooo1?l0000eooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooooooo1?l0001Kooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
KOooool003cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo
0ol000000ooooooo0000o`000007ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000
ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ojVmj004o`000?nY_NSo0000
o`0000GoZKgX00?o0000ooooooooool0Loooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool2o`0003Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo04Kooooo00Co0000oooooooooooooooo0_l0001Zooooo`00D?oo
ool2o`000004ooooool0003o0000o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgX
o`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0
003oZKgXojVmj005ojVmj0?o00001_nY_NP01Ol0003oZKgXojVmj?nY_NSo000000;oZKgX0_l00008
ojVmj003o`000?oooooooooo08Kooooo0ol0000kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooooooo`;o0000J_oo
ool004gooooo1_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKcWo`000?nY_NP01onY
_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00OoZKgX0_l00025ooooo`;o00000_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooooooo`;o0000J_ooool004_ooooo1Ol0
00000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY
_NSo0000o`0000GoZKcW00?o0000ojVmj?nY_NP01OnY_NP4o`0000CoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP3o`0008;ooooo0ol00010ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
A?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool00ol0003o
ooooooooo`16ooooo`?o000000?oooooo`000?l00000J_ooool004Sooooo1Ol00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0_l00008ojVli`04o`000?nY_NSoZKgXojVmj0?o000000CoZK_Vo`000?nY
_NSo00001OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX0_l0001nooooo`Co0000@_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Cooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooo`000005o`0000Wooooo00?o0000ooooooooool0G_ooool002Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Kooooo`?o000000Coooooo`000?l0003o00001onY_NP01?l0003oZKgX
ojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol000000onX/n7o
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY^^D00ol0003oZKcWojVli`05ojVli`04
o`000?nY_NSo0000o`0000GoZK_V0_l00005ojVmj0?o00001_nY_NP00ol0003oooooooooo`1Ioooo
o`05odA4A?l0003o0000oc8b<_oMgMd07?ooool2o`0000Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Go00002Oooool00ol0003oooooooooo`1Nooooo`00:?ooool0
0omgMgOo<S8booooo`0Hooooo`;o000000Coooooo`000?l0003o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000GoZ;?Q
00?o0000ojVmj?nY_NP01?nY_NP4o`0000KoZK[U00?o0000ojVlionY_>L01?nY_>L2o`0000SoZK_V
00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo0000ojVmj007ojVmj0;o0000G?ooool00omgMgOo
<S8booooo`0Hooooo`?o0000B?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04;o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Cooooo0_l0000hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`09oooo
o`03o`000?oooooooooo05kooooo000Yooooo`03o`000?oooooooooo01Cooooo1_l00006ojVmj003
o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oYj[Io`00
0?nX/n401_nX/n400ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVjiOnY^^D01_nY^^D00ol0
003oZKcWojVli`03o`000003oj:Ba?l0003oZK_V00OoZK_V00Co0000ojVmj?l0003o00001?nY_NP0
0ol0003oZKgXojVmj005ojVmj0;o0000GOooool00ol0003oooooooooo`0Eooooo`;o00000_ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo0_l00013ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooool000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool02?ooool00ol0003oooooooooo`1Oooooo`00:?ooool00omgMgOo<S8booooo`0C
ooooo`;o000000?oooooo`000?l000000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoYj[I00?o
0000ojRchOnX/n401?nX/n43o`0000KoZKgX00?o0000ojVjiOnY^^D01OnY^^D3o`0000GoXY;400?o
0000ojVki_nY^nH01?nY^nH3o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000
ooooo`1Kooooo`03ogMgMolb<S;ooooo01?ooooo0ol0001=ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0@Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool02Oooool5o`0000_ooooo00?o0000ooooooooool0Goooool002Gooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Aooooo`Ko00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003o
ZKgXojVmj004ojVmj0;o00001onWZ]T00ol0003oZ;?QojRch@03ojRch@03o`000?nZW<So000000So
ZKgX00Co0000ojVjiOnY^^GoZK[U0ol000000onLPKCo0000oj:Ba006oj:Ba003o`000?nY^nKoZK_V
00?o000000?o[;kWo`000?l000001onY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?oooooo
oooo05Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Booooo`;o000000?oooooo`000?ooool0COoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo043ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool02Oooool3o`000003ooooool0003ooooo00Wo
oooo0_l0000@ooooo`03o`000?oooooooooo04kooooo000Uooooo`03o`000?oooooooooo017ooooo
0_l00002ooooo`;o00002?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVghol0003oYj[I00OoYj[I00?o0000ojRchOnX/n40
0_l00003ojZLb003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVjiOl0003o00001OnLPK@00ol0003o
XY;4oj:Ba005oj:Ba0;o00001?n/_^L00ol0003o[;kWo`000006ojVmj0;o00002?nY_NP00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo017ooooo0ol0001Booooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0?oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2
o`0000Gooooo0ol00009ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`03
ooooo`;o00004?ooool00ol0003oooooooooo`1>ooooo`009Oooool00ol0003oooooooooo`0>oooo
o`Oo00000_nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0?o00001OnY]n<00ol0003oYj[IojNZf@05ojNZf@03o`000?nX/n7o000000KoZYc800?o0000ojVm
j?nY_NP01?nY_NP2o`0000OoW86d00?o0000oj:Ba?nRT/@01OnRT/@00ol0003o[;kWojbni`03ojbn
i`04o`000?n/_^Oo[;kWo`0000;oZKgX0ol000000onY^nKo0000ojVmj007ojVmj0;o0000E_ooool0
0ol0003oooooooooo`0>ooooo`Co0000E?ooool00ol0003oooooooooo`0@ooooo`;o0000F_ooool0
0ol0003oooooooooo`0Zooooo`08o`000?ooooooooooooooool0003oooooo`000?ooool4o`0000;o
oooo0ol00006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo04oooooo000Uooooo`Co00002_ooool3o`000004ooooool0003o0000
o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000
ojVmj?nY_NP00ol000000onWZm[o0000ojVgh`06ojVgh`03o`000?nWZ]WoYj[I00CoYj[I0_l00008
ojZLb003o`000?nY_NSoZKgX00?o000000?oUgN]o`000?nLPK@01_nLPK@00ol0003oXY;4oj:Ba004
oj:Ba003o`000?n^QJWo000000Co[;kW00?o0000ojbnion/_^L00ol00005ojVkiP03o`000?nY_NSo
ZKgX00CoZKgX0ol0001Fooooo`Co00002oooool2o`0005Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooooooo0000oooo
o`06o`0000?ooooo0_l00006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo053ooooo000aooooo`;o000000Coooooo`000?l0003o
00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVm
j?nY_NP01OnY_NP3o`0000GoYj_J00?o0000ojVghonY]n<01?nY]n<00ol0003oYj[IojNZf@02ojNZ
f@;o000000?oYY6no`000?nZW<P01onZW<P3o`0000GoUgN]00?o0000oib1]?nLPK@01OnLPK@00ol0
003oXY;4oj:Ba002oj:Ba005o`000?n^QJWo[XFYojj5ZOl000000on/_^L3o`000003ojbmi_l0003o
ZK_V00KoZK_V00?o0000ojVmj?nY_NP00ol00002ojVmj0;o0000HOooool3o`0005_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02cooooo00Oo0000
oooooooooooo0000ooooool0003ooooo00?o00001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0001Booooo`00;_ooool6o`0000KoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojR_gOl0003oYj_J00KoYj_J
00?o0000ojVghonY]n<01?nY]n<01?l0003oYj[Io`000?l00004ojJA_P03o`000?nZW<SoZYc800Co
ZYc800?o0000ol2R^ol000001_nGMjd00ol0003oW86doib1]005oib1]005o`000?nRT/CoXY;4oj:B
a?l000001?n^QJT00ol0003o[;kWo`000002o`0000Co[;gV00?o0000ojVki_nY^nH01?nY^nH3o`00
00KoZKgX00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^i<ooooo`;o00000_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i5
ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooo0000ooooo`04o`0000_ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Kooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o0000D_ooool002cooooo
1Ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nX[md00ol0003oYj_JojN[fP05ojN[fP04
o`000?nY]n?oZKOSojVgh`Co00001_nVTKh00ol0003oZYc8ojZLb003ojZLb004o`000?o0X[_o`::k
o`0000KoUgN]00?o0000oib1]?nLPK@01OnLPK@01?l0003oXY;4oj:Ba?l00006ojj5Z@04o`000?n/
_NKo[;gVo`0000Go[;gV00?o0000ojVki_nY^nH00ol000000onYZMKo0000ojVmj006ojVmj0;o0000
2?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool3o`00063o
oooo00?o0000ooooooooool04_ooool2o`0000Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg04Gooooo00?o0000ooooooooool0;?ooool3o`0000;ooooo1?l00005oooo
o`03o`000?oooooooooo00Cooooo0_l00004ooooo`?o00000_ooool3o`0000Gooooo00Ko0000oooo
oooooooo0000ooooool00005ooooo`Co0000Doooool002Wooooo1Ol00006ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojR_g@03o`000?nWZm[o
Yj_J00CoYj_J1?l00003oi1a[003o`000?nVTKkoYY6n00GoYY6n00Go0000ojZLb?nZW<SoZYc8o`00
0004ol2R^`03o`000?nGMjgoUgN]00CoUgN]00?o0000oib1]?nLPK@01OnLPK@2o`0000Oo[XFY00Go
0000ojbmi_n/_NKo[;gVo`000004ojbmiP?o00001OnYZMH00ol0003oZKgXojVmj004ojVmj0?o0000
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100A_ooool3o`0000;o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04Gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`06o`0000Gooooo00?o0000ooooool000000_ooool01?l0
003oooooo`000?l00004ooooo`?o00000_ooool3o`0000Gooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0005Cooooo000Wooooo`Co00000_nY_NP0
0ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005
ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nX[md01_nX[md00ol0003oYj_JojN[fP02
ojN[fP;o000000?oYXfko`000?n@LJ`01On@LJ`00ol0003oYY6nojJA_P04ojJA_P04o`000?nZW<So
ZYc8o`0000Go`::k00?o0000oiMg[OnGMjd01?nGMjd00ol0003oW86doib1]005oib1]003o`000?n^
QJWo[XFY00Go[XFY00?o0000okW4A?l000000_n/_NH00ol0003o[;gVo`000002o`000003ojNQd?l0
003oZJWF00KoZJWF00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`000007ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000014ooooo`;o0000I_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000004Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03ooooo`Co
00001Oooool2o`0000;ooooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo1_l00003ooooo`04o`000?ooooooooooo`0005Gooooo000Toooo
o`Go00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0?o00001OnY_NP00ol0003oZ:oMojR_g@05ojR_g@04o`000?nWZm[o0000o`0000?oYXfk00?o0000
oi1a[?n@LJ`01?n@LJ`00ol0003oYY6nojJA_P04ojJA_P03o`000?nZW<So000000Ko`::k00?o0000
oiMg[OnGMjd01?nGMjd00ol0003oW86doib1]004oib1]0;o00001on^QJT01Ol0003o^LA4okW4A?l0
003o[;gV00;o00001OnWXM000ol0003oZJWFojVYeP04ojVYeP?o00001OnY_NP2o`0000Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000047ooooo1Ol0001Vooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000AOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?o
oooo00Co0000ooooool0003o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo1_l00003
ooooo`Co0000EOooool002;ooooo0_l00002ooooo`;o00001onY_NP01?l0003oZKgXojVmj?nY_NP2
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000
ojVmj?nY_NP01?nY_NP00ol0003oZ:oMojR_g@04ojR_g@;o00001_nVSK/00ol0003oT76/oi1a[003
oi1a[003o`000?nVTKkoYY6n00CoYY6n0_l00007ol2R^`03o`000?nGMjgoUgN]00GoUgN]00?o0000
oib1]?nLPK@00_nLPK@00ol0003oZ7nWo`000007ojj5Z@04o`000?nia4Co^LA4okW4A0;o00001_nW
XM000ol0003oZJWFojVYeP03ojVYeP03o`000?ngZ<[o000000OoZKgX0_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`;o0000Joooool00ol0003ooooo
ooooo`0Eooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100AOooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ol0003oooooooooo`02o`0000;o
oooo0_l00005ooooo`;o00000_ooool00ol0003oooooo`00000?ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`1>oooo
o`007oooool7o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000005ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojR_gOnX
[md00ol000000onMS/Co0000ojJ=^`05ojJ=^`03o`000?n@LJcoT76/00CoT76/00?o0000ojJA__nV
TKh00_nVTKh00ol0003o/9>ho`000007ol2R^`03o`000?nGMjgoUgN]00GoUgN]00Go0000oib1]?nL
PKCoW86do`000003ojQoY`03o`000?n^QJWo[XFY00?o[XFY00Co0000okW4A?nia4Co^LA40ol00007
ojNQd003o`000?nYZMKoZJWF00;o00000ongZ<X00ol0003oZKgXojVmj004ojVmj0;o00001Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0??ooool4o`0006cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`15ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000002oooool00ol0003ooooo
ooooo`02ooooo`Ko000000?oooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo04oooooo
000Looooo`?o000000Coooooo`000?l0003o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o0000
1onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgX
ojVmj?nY_NP5o`0000CoWHk400?o0000ojJ=^onVSK/01?nVSK/00ol0003oT76/oi1a[004oi1a[005
o`000?nVTKkoYY6nojJA__l000000on`TkP00ol0003o`::kol2R^`05ol2R^`03o`000?nGMjgoUgN]
00CoUgN]00Co0000oib1]?nLPKCo00001?nXOjL00ol0003o[XFYojj5Z@03ojj5Z@04o`000?nia4Co
^LA4o`0000;ofnSM00?o0000ojNQd?nWXM001OnWXM000ol0003oZJWFo`000006okNXbP03o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?l000000_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0>Oooool3o`0006kooooo0ol0000Iooooo`06o`000?oooooooooooeEEEOmV
IVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02
ooooo`?o000000?oooooo`000?l000002oooool00ol0003oooooooooo`02ooooo`?o000000Cooooo
o`000?oooooooooo0ol000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo053ooooo
000Jooooo`Ko00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0Co00000onF
TLd00ol0003oWHk4oif>a004oif>a003o`000?nVSK_oYXfk00?oYXfk00?o0000oi1a[?n@LJ`01?n@
LJ`01?l0003oYY6nojJA__l00004ok2C^003o`000?o0X[_o`::k00Go`::k00?o0000oiMg[OnGMjd0
1OnGMjd2o`0000GoZ7nW00?o0000ojj5ZOn^QJT00on^QJT00ol0003o^LA4o`000003om_Xg@03o`00
0?nWXM3oYj7@00GoYj7@0_l00008okNXbP;o00001OnY_NP00ol0003oooooooooo`13ooooo`?o0000
KOooool3o`0000;oVL3c00?o0000ooooooooool05oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo02_ooooo0_l00004ooooo`03o`000?oooooo000000;o00000_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo0_l000001_oooooo0000
o`000?oooooo0000ooooo`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1Aoooo
o`005oooool6o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00Co0000ojVmj?nY
_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000oiJAc@05oiJAc@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onVSK/00ol0
003oT76/oi1a[005oi1a[0;o00001_n`TkP00ol0003o`::kol2R^`04ol2R^`03o`000?nGMjgoUgN]
00CoUgN]0_l00006ojQoY`03o`000?n^QJWo[XFY00;o[XFY00?o0000okW4A?l000000ooKj=d3o`00
00?oYj7@0ol000000onQP[7o0000okNXbP07okNXbP03o`000?nY_NSoZKgX00GoZKgX0_l00010oooo
o`?o00000oooool00ol0003oooooooooo`1Vooooo`Co00001?nI`?<3o`0001Wooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooooooo`?o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool02_ooool2
o`0000?ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo1?l000000ooooooo0000o`00
0002o`0005;ooooo000Fooooo`Co00000onY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000GoZKgX00?o0000
ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000oiJAcOnFTLd00onFTLd00ol0003oWHk4oif>a003
oif>a003o`000?nVSK_oYXfk00CoYXfk00?o0000oi1a[?n@LJ`01?n@LJ`00ol0003o/9>hok2C^005
ok2C^003o`000?o0X[_o`::k00Co`::k00?o0000oiMg[OnGMjd00_nGMjd2o`000003olKgk?l0003o
Z7nW00GoZ7nW00?o0000ojj5ZOn^QJT00_n^QJT2o`000005om_XgOl0003o0000o`000?oKj=d00_l0
00000onWXM3o0000o`000005oj62/@03o`000?ngZ<[o]jS:00Co]jS:00?o0000on7SeOl000001OnY
_NP3o`0003oooooo0_l0001Zooooo`Co00000_nA_?@00ol0003oVL3coiW0l`03o`000004oiW0lol0
003oVL3co`0001Wooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0[ooooo`?o0000
1Oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`?o00000_ooool4o`0000;o
oooo0_l0001Dooooo`005_ooool00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?nFTLgoUY7=00?oUY7=00?o0000oif>a?nMS/@0
1?nMS/@00ol0003oYXfkojJ=^`03ojJ=^`03o`000?n@LJcoT76/00CoT76/00?o0000ok2C^?n`TkP0
1On`TkP00ol0003o`::kol2R^`04ol2R^`05o`000?nGMjgoUgN]oiMg[Ol000000oo6mn`00ol0003o
Z7nWojQoY`05ojQoY`04o`000?n^QJWo[XFYojj5Z@?o00001OoKj=d2o`0000OoXH:a00?o0000okNX
b_ngZ<X00ongZ<X01?l0003ohN?Eon7SeOl00002ojVmj0?o00000_nY_NP00ol0003oooooooooo`0m
ooooo`03o`000?oooooo000006Cooooo1Ol00006oi6lm0?o00001OnI`?<00ol0003oVL3co`00000H
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0;_ooool01?l0003ooooooooooooo
ool3o`000005ooooool0003o0000ooooool000004?ooool00ol0003oooooooooo`02o`0000;ooooo
0ol000000ooooooo0000o`000006o`0000;ooooo0_l0000?ooooo`;o0000A?ooool001Kooooo0_l0
0007ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY
_NP00ol0003oUY7=oiJAc@04oiJAc@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onV
SK/00ol0003oT76/oi1a[003oi1a[003o`000?o>^LKo000000Oo/9>h00?o0000ol2R^oo0X[/01?o0
X[/3o`0000Coa_O/00?o0000ojQoYonXOjL01OnXOjL5o`000004olKl__l0003ofnSMom_Xg@?o0000
00?oTfnWo`000?nQP[401onQP[401Ol0003o]jS:okNXb_ngZ<[o000000?ohN?E0ol00006ojVmj003
o`000?oooooooooo03cooooo00Co0000oooooooooooo0000G?ooool7o`0000CoRk[e00Co0000oi6l
m?nA_?CoTKcd0ol00002oi6lm003o`000?nI`??oVL3c00CoVL3c0ol0000Hooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0:Oooool2o`0000[ooooo00?o0000ooooooooool00_ooool2
o`0000kooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;ooooo2_l0000?
ooooo`03o`000?oooooooooo04Cooooo000Fooooo`03o`000?oooooo000000KoZKgX0_l00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003oUY7=oiJAc@03oiJA
c@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onVSK/00ol0003oT76/oi1a[002oi1a
[004o`000?o>^LKoc[W6o`0000Oo/9>h00Co0000ol2R^oo0X[_o`::k1_l00005olKgk003o`000?nX
OjOoZ7nW00;oZ7nW0ol00002ojj5Z@03o`000?o6o;koa_bn00?o00001?nCKjL2o`0000OoXH:a00Co
0000okNXb_ngZ<[o00000ooQhmD00ol0003o`K39o`000007ojVmj0;o0000?Oooool01Ol0003ooooo
oooooooooooo000005?ooooo2?l00004ohNimP03o`000?n;^_GoRk[e00GoRk[e0ol00005oi6lm003
o`000?nI`??oVL3c00Co000000?oUlOho`000?l000006?ooool2o`0004oooooo00?o0000oooooooo
ool0:oooool2o`0000gooooo0_l0000>ooooo`03o`000?oooooo000000?o000000Coooooo`000?oo
oooo00000_ooool6o`000004ooooool0003o0000o`0000gooooo0_l00004ooooo`;o0000@Oooool0
01Gooooo00Go0000ooooooooooooooooo`000002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj004
ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj004o`000?nY_NSo
0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000;oZKgX00?o0000oiJAcOnFTLd00onF
TLd00ol0003oWHk4oif>a004oif>a003o`000?nVSK_oYXfk00;oYXfk00Go0000oi1a[?n@LJcoT76/
o`000003oljiaP03o`000?n`TkSo/9>h00Ko/9>h0ol00005ofk1oP;o00001?o6mn`00ol0003oZ7nW
o`000002o`0000;oZ7nW00?o0000ojj5ZOn^QJT00ol000000onXSk[o0000oi=_Y`05oi=_Y`03o`00
0?nQP[7oXH:a00GoXH:a00?o0000okNXb_l000000ooQhmD01Ol0003o`K39ol6`bOo1/<Wo000000Ko
ZKgX0_l0000mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool7o`0000Co
Q[Wf00?o0000ohNim_n7^OH01_n7^OH01?l0003oRk[eoh^jmOn;^_D3o`000003oh^jmOl0003oTKcd
00?oTKcd1Ol00005oiO7n003o`000?nGaoSo000001Sooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0]ooooo`;o00002?ooool01?l0003oooooooooooooool2o`0000Oooooo00?o0000
ooooooooool00oooool6o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?oo
ool3o`0000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`005Oooool0
0ol0003oooooooooo`02ooooo`;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o00001onY_NP00ol0003oZKgXojVmj003o`000003ojR_gOl0003o
HX?M00?o00001_nFTLd00ol0003oWHk4oif>a006o`0000?oYXfk00?o0000oi1a[?l000001Oo>^LH0
0ol0003o/9>hok2C^004ok2C^004o`000?nYkZCoZNjTo`0000;oK/7n0ol000000onSZ=Wo0000olKg
k002olKgk0?o00001OnXOjL01?l0003o[XFYo`000?l00003ojR?^P03o`000?nCKjOoTfnW00CoTfnW
0_l00007oj62/@05o`000?oQhmGohN?Eon7SeOl000001Oo1/<T00ol0003oZKgXojVmj003o`000003
ojVmj?l0003o000003_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`Ko
00001?n8^oL00ol0003oQ[WfohJimP05ohJimP03o`000?n7^OKoQkWf00KoQkWf0ol00002oh^jm@Oo
00001?n=a?X00ol0003oUlOhoiO7n004oiO7n003o`000?nGaoSo000001Sooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Xooooo`;o00000oooool3o`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo1_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?ooool00ol0000=ooooo`?o00000_ooool2o`00
00Gooooo0_l0000mooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?nY_NSoZKgX00Go
ZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l0
00000_l00003ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojR_g@04o`000?mRPmgoHX?Mof:3
g@Wo00001Om^aOl6o`0000Koc[W600?o0000ok2C^?n`TkP00on`TkP01?l0003oZNjTojW^Y?nYkZ@3
o`0000GoXjSI0ol000000oo6mnco0000ojQoY`06ojQoY`;o00001OnXSkX00ol0003oTfnWoi=_Y`03
oi=_Y`03o`000?nQP[7o000000KoXH:a0_l000000ooQhmGo0000ol6`b@06ol6`b@;o00001OnY_NP2
o`0003[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`Ko00000on?__H0
0ol0003oR;_gohRkm`05ohRkm`03o`000?n6^OKoQ[Wf00GoQ[Wf00?o0000ohNim_n7^OH00_n7^OH8
o`0000?oQL?l00?o0000ohg4n_n=a?X01_n=a?X00ol0003oUlOhoiO7n004oiO7n0?o00006?ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`;o00001?ooool0
0ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ol000000ooooooo0000
o`000003o`0000Cooooo1Ol0000>ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`;o0000
?oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003oZKgXojVmj004ojVmj0;o00001_nY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVghol0
003oZ:oM00GoZ:oM00Go0000of:3gOmRPmgoHX?Mo`000007ohQi_0;o00000om^aOl4o`000003o`>0
g_l0003oc[W600Ooc[W600Ko0000ok2C^?n`TkSo/9>ho`000?nYkZ@3o`000003oiO?nol0003oXjSI
00;oXjSI1Ol00002olKgk003o`000?nXOjOoZ7nW00GoZ7nW0_l00005ojR?^P03o`000?nCKjOoTfnW
00CoTfnW0_l00005oj62/@04o`000?oB/;Ood[2go`0000So`K3900?o0000ojVmj?nY_NP01OnY_NP2
o`0003Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`?o00000onG`_D0
0ol0003oSkkfohnnmP04ohnnmP03o`000?n8^oOoR;_g00GoR;_g00?o0000ohJim_n6^OH00_n6^OH7
o`0000CoO/;m00?o0000ohG3o?n5`o`01On5`o`00ol0003oSLCjohg4nP06ohg4nP03o`000?nGaoSo
UlOh00Co00000_nBcO`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool08Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool01?l0003oooooo`000?l0
0002ooooo`04o`000?ooooooooooooooo`;o00001_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool3o`000003ooooool0003o000000;o00001?ooool3o`000003ooooool0003o0000
00cooooo0_l00004ooooo`?o00000_ooool2o`00047ooooo000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY
_NP00ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVgh`03o`000?nX[mgoZ:oM00Co
Z:oM00Co0000of:3gOmRPmgo00002On8NK`3o`0000?oS8O90ol00008oljiaP03o`000?n`TkSo/9>h
00?o00001OnGco/3o`0000?oXjSI0_l00003olKgk003o`000?nXOjOoZ7nW00CoZ7nW00?o0000ojR?
^_nXSkX01?nXSkX00ol0003oTfnWoi=_Y`04oi=_Y`03o`000?nQP[7o000000?oXH:a00Go0000om:`
]ooB/;Ood[2go`000007ol6`b@03o`000?oQoL_o000000KoZKgX0_l0000iooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0<_ooool4o`0000OoUl;e00?o0000ohnnm_n?__H01?n?__H0
0ol0003oR;_gohRkm`02ohRkm`Oo00000_mka?h3o`0000OoO/;m00?o0000ohG3o?n5`o`01On5`o`0
0ol0003oSLCjohg4nP02ohg4nPKo00001?nBcO`01?l0003oT/gloi;=o?l0000Gooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool07oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0002o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000000ol000000ooooooo
0000o`000002o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00003ooooo`;o0000??ooool001Gooooo00?o0000ooooooooool0
1_ooool2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVgh`06ojVgh`03o`000?nX[mgoZ:oM00?oZ:oM00Go0000of:3gOmRPmgo
HX?Mo`000008ohQi_003o`000?n<QlWoS8O900?oS8O900Co0000oem?Yol0003o00001oo>^LH00ol0
003o/9>ho`000003om7mgP03o`000?nGco_o000000;o000000?oUloko`000?nSZ=T01?nSZ=T2o`00
00;oa_O/00?o0000ojQoYonXOjL01?nXOjL2o`0000GoZ8nj00?o0000oi=_YonCKjL01?nCKjL01?l0
003oXH:aoj62/Ol00002oj62/@06o`000?oB/;Ood[2go`000?o[`Z_o00001Oo1/<T01Ol0003ohOg;
on7mbooQoL_o000000;oZKgX0ol000000onY_NSo0000o`000007ooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000003oc8b<_oMgMgooooo02?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0^ooooo`?o00000onQa_<00ol0003oUl;eoiO2m@06oiO2m@04o`000?n?__KoSkkf
ohnnmPOo00001Omlaol4o`0000?oNlCn00?o0000ogk2oOmn`_d01Omn`_d00ol0003oQL?lohG3o002
ohG3o0Oo00001On5b_h00ol0003oT/gloi;=o003oi;=o0Go00005_ooool00ol0003oooooooooo`05
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo03Kooooo00?o
0000ooooooooool08Oooool6o`0000;ooooo2_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000Kooooo0_l000000ooooooo0000o`000006o`000004ooooool0003o0000o`0000?o
oooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?ooool00_l0000:ooooo`;o
00000oooool2o`0003kooooo000Dooooo`03o`000?oooooooooo00Sooooo00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000GoZKgX
00?o0000ojVghonY]n<01?nY]n<01?l0003oZ:oMojR_gOnX[md4o`0000;oHX?M00?o0000ohQi_?n8
NK`01On8NK`00ol0003odK>lo`000004ohb7b@03o`000?mOCjOoGdnW00;o00001Oo>^LH3o`0000Co
dOgN1?l00002oiO?n`03o`000?nSZ=WoXjSI00?oXjSI00Go0000o`0>VOl0003oa_O/o`000005ojQo
Y`03o`000?oLo];o000000GoZ8nj00?o0000oi=_YonCKjL01OnCKjL00ol0003oXH:aoj62/@02o`00
00?od[2g00?o0000on_2Zol000001?o1/<T00ol0003ohOg;on7mb`02on7mb`?o00001OnY_NP00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool08oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo0ol00007oj76l`03o`000?nG`_GoUl;e
00CoUl;e1Ol00005oh7=o`03o`000?mlaoooO<Oo00;oO<Oo1?l00006og_4oP03o`000?mn`_goO/;m
00;oO/;m1ol00005ogO7o`03o`000?n5b_koQL[n00GoQL[n00?o0000oi;=o?nBcO`01?l00003oh_@
oP03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool08oooool5o`000003ooooool0003o
000000Ko00000_ooool3o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?ooool2
o`000003ooooool0003o000000?o000000Coooooo`000?oooooooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0
003o0000043ooooo000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ojVmj?nY_NP01?nY_NP2
o`0000OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY]n?o
ZKOS00?oZKOS1?l00003oi=f[`04o`000?mRPmgoHX?Mo`0000KoR7Vl00Co0000om6c_?oA/kco0000
1On<QlT01?l0003oGdnWoem?Yol00002oljiaP?o000000CoS>Sgo`000?oAoMkodOgN0ol00002ojjY
d`03o`000?m9T>ko000000?o00001?nSZ=T01Ol0003o00jIo`000?o6mnco000000CoZ7nW00Co0000
omcnd_oLo];o00001_nXSkX00ol0003oTfnWoi=_Y`04oi=_Y`04o`000?nQP[7oXH:ao`0000Cod[2g
00Co0000on_2Zoo[`Z_o00000_o1/<T01?l0003ohOg;on7mbooQoL/2o`000003okgIk_l0003oZKgX
00GoZKgX0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo0_l00002oj_9l003o`000?nQa_?oXLKc
00KoXLKc00?o0000oiO2mOnG`_D00ol00004oh_Co`03o`000?n1cOooPLgo00CoPLgo1?l000000oml
aooo0000o`00000<o`0000GoJ/Kn00?o0000ogO7oomgaol01Omgaol00ol0003oQL[nohG:oP02ohG:
oPGo00000on;d?h00ol0003oRm3noh_@oP02oh_@oP03o`000?oooooooooo01;ooooo0_l00008oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool3
o`0000Cooooo1ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00000
0ooooooo0000ooooo`02o`000004ooooool0003oooooooooo`?o000000Koooooo`000?l0003o0000
ooooool00002ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l00004ooooo`;o
00000_ooool3o`00043ooooo000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX
00?o0000ojVghol000000_l000000onJS<?o0000oi=f[`04oi=f[`;o00000_mRPmd00ol0003oR7Vl
ohQi_002ohQi_005o`000?oA/kcodK>lom6c_?l000001On<QlT01?l0003oGdnWoem?YomOCjL3o`00
00;oS>Sg1Ol00005ojjYd`04o`000?m9T>koBI3^odV@kP?o00000onSZ=T01?l0003o00jIo`000?l0
0003ojQoY`;o00000ooLo]800ol0003oZ8njojR?^P03ojR?^P03o`000?nCKjOoTfnW00CoTfnW00?o
0000oj62/OnQP[400_l00002om:`]`07o`000?o[`Z_ojl:[on_2Zol0003o`K39o`000002on7mb`;o
00001?nmfNh00ol0003oZKgXojVmj003ojVmj0?o00001oooool00ol0003oooooooooo`06ooooo`03
ogMgMolb<S;ooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`;o
00001On[bO000ol0003oXLKcoj76l`04oj76l`Co00002?n;dol01?l0003oPLgooh7=oon1cOl7o`00
00GoGLWi0_l00005of76o0;o00001_mZa_h00ol0003oMlOoogO7o`02ogO7o`Oo00001?mhbol00ol0
003oRm3noh_@oP02oh_@oP03o`000?n;d?koRm3n00?o00005Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool07Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00004ooooo`;o0000:?ooool00ol0003oooooooooo`08ooooo`;o00000oooool0
1_l0003ooooooooooooooooo0000ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000?ooooo
0ol00004ooooo`;o00000oooool2o`0004;ooooo000Dooooo`03o`000?oooooooooo00_ooooo0_l0
0006ojVmj004o`000?nY_NSoZKgXojVmj0;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj004o`00
0?nY_NSoZKgXojVmj0Co00001?nJS<<00ol0003oTgJ_oi=f[`04oi=f[`;o000000?oHX?Mo`000?n8
NK`00_n8NK`00ol0003odK>lom6c_003om6c_003o`000?n<QlWoS8O900;oS8O900?o0000oem?YomO
CjL01?mOCjL5o`0000So[ZWC00Ko0000odV@k_m9T>koBI3^o`000?lVI=L2o`000007oj>XfOl0003o
00jIo`000?o6mnco0000ojQoY`02o`000005oeaWaOl0003og?kBomcnd_l000001OnXSkX00ol0003o
TfnWoi=_Y`05oi=_Y`;o00000_oB/;L00ol0003od[2go`000004on_2Z`Co00001_nmfNh00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
027ooooo0_l00008oj_9l003o`000?nQa_?oXLKc00?o00001?nIfOd2o`0000CoRm?o1_l00005oek=
mP;o00001?mMbOTEo`0000CoH<Gl00?o0000ogS;oomhbol01Omhbol00ol0003oRm3noh_@oP04o`00
00?oPm3o00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00005ooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o0000
0_ooool00ol0003oooooo`000002o`0000;ooooo0ol00008ooooo`05o`000?oooooo0000o`000?oo
ool00_l00002ooooo`03o`000?oooooooooo00;o00002Oooool3o`0000Cooooo0ol00017ooooo`00
5?ooool00ol0003oooooooooo`0=ooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?l00000
1OnY_NP00ol0003oZKgXojVmj003ojVmj0Co00000onQ^n/00ol0003oVXc3oiZ<``03oiZ<``03o`00
0?nCMZooTgJ_00?oTgJ_00Co0000oc`oZol0003o00000_n8NK`00ol0003odK>lom6c_004om6c_003
o`000?n<QlWoS8O900;oS8O900Co0000oem?YomOCjOoGdnW0ol000001OmOCjOo0000on33^ooP`k_o
000000So[ZWC0ol00002odV@kP03o`000?lVI=Oo9VCG00;o000000?o00jIo`000?l000000_l00002
oknac003o`000?mLIlGo000000;o00001OnXSkX00ol0003oTfnWoi=_Y`05oi=_Y`03o`000?oB/;Oo
d[2g00;od[2g0_l00004on_2Z`04o`000?o@gfkod=m^o`0000Ko_MW^0ol00006ojVmj0;o00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Mooooo`?o00000_nbbn`00ol0003oZlW`oj_9l005oj_9l0?o00001onI
fOdYo`000003odFmlOl0003oH<Gl00GoH<Gl00?o0000ogS;oomhbol00_mhbol5o`0000?oPm3o00?o
0000oh?@oon3d?l00_n3d?l00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00005ooooo`03o`000?oooooooooo03Cooooo0ol000000ooooooo
0000o`000004o`000003ooooool0003o000000?ooooo0ol00006ooooo`03o`000?oooooooooo00Co
00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o0000BOooool001Cooooo
00?o0000ooooooooool03_ooool01?l0003oZKgXojVmj?nY_NP4o`0000OoZKgX00?o0000ojVmj?l0
00000_l00002ojVmj003o`000?nQ^n_oXK_[00?oXK_[00?o0000oiZ<`onJS<<00_nJS<<00ol0003o
TgJ_oi=f[`03oi=f[`03o`000?ll?j_o?3n[00?o00001ooA/k`00ol0003oS8O9ohb7b@02ohb7b@Co
00000omOCjL01_l0003oh<>kon33^ol0003oiKb/o`0000Ko[ZWC00Co0000okBI^ol0003oLf6_0_l0
00001?m9T>ko0000obITeolVI=L2o`000003okgmhOl0003o000000?o_k7<00Co0000oeaWaOmLIlGo
G6O50_l00005ojR?^P03o`000?nCKjOoTfnW00CoTfnW00?o0000om:`]ooB/;L00_oB/;L00ol0003o
jl:[on_2Z`02on_2Z`06o`000?o@gfkod=m^o`000?nihG_o00000_nmfNh3o`0000;oZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool2o`0000Ko//_/00?o0000
oj_9l?n[bO000_n[bO02o`0000?oY]gj0_l00002oiWIo@?o00000omlhOHAo`0000?oA/?Y7ol00005
ofO8o@05o`000?n3d?ooPm3oo`000?n3d?l01Ol0000Booooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000ol00006ooooo`06o`000?oooooo0000o`00
0?oooooo00000_ooool2o`0000Kooooo1?l00002ooooo`;o0000DOooool001?ooooo00?o0000oooo
ooooool04?ooool3o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000oj6k
jonQ^n/00_nQ^n/00ol0003oVXc3oiZ<``02oiZ<``03o`000?nCMZooTgJ_00?oTgJ_00Go0000oc`o
Zoll?j_o?3n[o`000009om6c_003o`000?n<QlWo000000?o00001?mOCjL01Ol0003oh<>kon33^ooP
`k_o000000;oiKb/00?o0000ojjYdon^ZM<00_n^ZM<01?l0003o]9VkokBI^ol00003og=Q[`;o0000
00Go9VCGo`000?nmoN7o_OgQo`000005oknac003o`000?mLIlGoG6O500;oG6O50_l00004ojR?^P03
o`000?nCKjOoTfnW00?oTfnW0ol00003om:`]`;o00000oo[`Z/00ol0003od=m^o`000002okWQN`?o
00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003ooooo00;ooooo00?oEEEEofIVI_l0
00001Oooool4o`0002Cooooo00?o0000ooooooooool04?ooool2o`0001Sooooo0_l00009ok;;k004
o`000?n[bO3o0000o`0000KoY]gj1?l00002ogcQmPko00000omAbnX6o`0000?oBlG/1ol000001?m3
_?3o0000obZQk_lZXNh6o`000003o`n?hol0003o000000Go000000?o@;Wao`000?mWb?d00omWb?d7
o`0000CoO<ko00?o0000ooooooooool04_ooool01ol0003oooooooooooooooooEEEEofIVI_l00000
1Oooool4o`0001oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Go
oooo00?o0000ooooooooool06?ooool7o`0000gooooo0ol00006ooooo`Go00000oooool4o`000003
ooooool0003ooooo00Co00001?ooool4o`0000cooooo1ol0001Cooooo`004oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00CoZKgX00Go0000oj6kjonQ^n_oXK_[o`000004oiZ<``03o`000?nCMZooTgJ_00Co
TgJ_00Co0000oc`oZoll?j_o00002?oA/k`3o`0000?oS8O900?o0000oem?YomOCjL00_mOCjL01?l0
003oh<>kon33^ol00003onFl[005o`000?n^ZM?o[ZWCojjYdol000001?ndVK/00ol0003oLf6_og=Q
[`02og=Q[`Co00001ono/L`00ol0003oG6O5oeaWa@03oeaWa@05o`000?nXSk[oZ8njojR?^_l00000
1?nCKjL4o`0000?od[2g00?o0000on_2Zol000000_o[`Z/01Ol0003od=m^o`000?nihG_o000000;o
bN_]00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo0_l00002okS<j@03o`000?nbbnco//_/00Ko
//_/0ol00005ojKMnP;o00001?nCj_L4o`0000;oNnKL1Ol00002of7GhQ?o000000?o;[CMo`000?lf
[?401ol000000olZXNko0000oa2<i006o`0000;o9:KV1_l00004oeS0n`04o`000?mlc_ooO<koo`00
00CoO<ko00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooooooo01_ooooo2?l0000<
ooooo`Go00001?ooool3o`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00001?ooool4
o`0000_ooooo1Ol0000;ooooo`;o0000BOooool001?ooooo00?o0000ooooooooool04_ooool00ol0
003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00000_nQ^n/00ol0
003oVXc3oiZ<``02oiZ<``03o`000?nCMZooTgJ_00?oTgJ_00Go0000oc`oZoll?j_o?3n[o`000004
om6c_0?o000000?og^?Ho`000?l000000on<QlT01Ol0003oGdnWoem?YomOCjOo000000?oh<>k00?o
0000onFl[?oU_:`00_oU_:`00ol0003o[ZWCo`000005okBI^`03o`000?mcHJooLf6_00GoLf6_00?o
0000oknac?no/L`01Ono/L`00ol0003oG6O5oeaWa@03oeaWa@?o000000?oZ8njo`000?nCKjL00_nC
KjL6o`000003om:`]ol0003ojl:[00;ojl:[0_l000001?o@gfko0000o`000?l00004olW[k@03o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP2o`00037ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0@ooooo`;o00001Onhc>T00ol0003o//_/ok;;k002ok;;k0?o0000
0onag_H2o`000003ojKMn_l0003o000000?oTn[g1Ol00002og_Vg0Wo00000_mQdo43o`0000?oPmSo
1?l00005od[5k003o`000?lLW^Go000000So000000?o:9g^o`000?l000001?l000000ol@S>Co0000
o`000005o`000003obBVi_l0003oF<3k00GoF<3k00Go0000ogc>oomlc_oo0000ogc>o`05o`0001;o
oooo0_l00015ooooo`03o`000?oooooooooo01cooooo2?l0000<ooooo`co00000_ooool5o`0000Co
oooo0_l00003ooooo`Go00000_ooool00ol0003oooooooooo`06ooooo`Oo000000?oooooo`000?l0
00000_ooool3o`0004_ooooo000Cooooo`03o`000?oooooooooo01?ooooo00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00003ojVmj0?o0000
1?nJS<<00ol0003oTgJ_oi=f[`03oi=f[`03o`000?ll?j_o?3n[00;o?3n[1?l000000ooA/kco0000
omkSf002omkSf0;o00000_n<QlT01Ol0003oGdnWoem?YomOCjOo000000?oh<>k00?o0000onFl[?oU
_:`00ooU_:`00ol0003o]9VkokBI^`04okBI^`03o`000?mcHJooLf6_00CoLf6_00?o0000olFIZOl0
00001_no/L`01?l0003oG6O5oeaWaOmLIlD2o`000003oj6>`?l0003oVgfa00;o00000_nCKjL2o`00
00;o@V;<0ol000000ooB/;Oo0000on_2Z`02on_2Z`Co00001_o9jnd3o`0000GoZKgX00?o0000ojVm
j?nY_NP00onY_NP2o`00033ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=oooo
o`;o00002?nhc>T01?l0003o//_/o`000?l00007ok7NmPoo00000_n[n>P2o`0000?o^?;c1?l00002
oh?Ho`?o00000onVgo/;o`000004oabNiOl0003o<jCboc>TlPKo000000?o:9g^o`000?l9SMh05Ol0
0005ogK;o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0eooooo`Oo000000?oooooo`000?l000000ol000000ooooooo0000ooooo`03ooooo`04o`000?oo
ooooooooooooo`Oo00002?ooool9o`000004ooooool0003o0000o`0004kooooo000Cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj004ojVmj0;o0000
1onY_NP2o`0000CoVXc300?o0000oi=f[onCMZl00onCMZl00ol0003o?3n[oc`oZ`03o`0000?odK>l
00?o0000omkSf?oNhmP00_oNhmP01Ol0003o2bVZo`000?n<QlWo000000;oGdnW00Go0000on33^ooP
`k_oh<>ko`000006onFl[003o`000?ndVK_o]9Vk00Co]9Vk00?o0000og=Q[omcHJl00omcHJl01Ol0
003oaIVYolFIZOo5VJWo000000Ko_k7<0ol00003oj6>`003o`000?nKOK7oVgfa00?o000000?oVgfa
o`000?m2H/`00_m2H/`2o`000003om:`]ol0003ojl:[00;ojl:[1Ol00002olW[k@?o000000?oZKgX
o`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o000002oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`;o00000_nkc>L00ol0003o^<cYokS<j@05
okS<j@?o00001_nag_H2o`000003ojW_n?l0003o000000Go00000_nLm><3o`0000;oZoSX0_l00003
okSbl`;o00001?o2hnl3o`0000?oY]ok0_l00002okRjf`03o`000?n4XNKoQ:7V00?oQ:7V00?o0000
oeNDk_mGU>h01_l000001?lcY?;o0000od2Zm_m0Z_H@o`0000KoC;Si0_l00003ogK;o`Co00004_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Oooooo3_l00004ooooo`[o00001ooo
ool00ol0003oooooo`000006o`000003ooooool0003o000000Kooooo1ol000000ooooooo0000o`00
0003o`0004gooooo000Cooooo`03o`000?oooooooooo01Gooooo00?o0000ojVmj?nY_NP01?nY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000;oVXc300?o0000
oi=f[onCMZl01?nCMZl2o`0000?o?3n[00?o0000om6c_?l000001OoNhmP01Ol0003o2bVZo`/YZ_l0
003oS8O900;o00001?oP`k/00ol0003oiKb/onFl[003onFl[003o`000?oikJ3o000000Ko]9Vk00?o
0000og=Q[omcHJl00_mcHJl01Ol0003oaIVYolFIZOo5VJWo000000?o_k7<1?l00006oj6>`004o`00
0?nKOK7oVgfao`0000?oVgfa00?o0000od9Rc?m2H/`00_m2H/`00ol0003ojl:[on_2Z`02on_2Z`Oo
00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003o^lcWok_<i`03ok_<i`03
o`000?nhc>Wo^<cY00;o^<cY0_l00003okWMlP?o000000?o/Mkfo`000?l000000ol000001?nYkoSo
0000o`000?nGl^L2o`000003oicdhol0003o000000Oo000000?o^?;co`000?l000001Oo2hnl01ol0
003oa=7TolCAi?o4dNCo0000ojKOnol000001Onh^]/00ol0003oQ:7VohBQiP03ohBQiP03o`000?mG
U>koEiC^00;oEiC^00?o0000oeNQmOmGXOD01ol000000om0Z_Ko0000od2TmP03od2TmP03o`000?lX
S^go000000oo00001?mbaOl00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0:oooool;o`0000;ooooo0ol00002ooooo`Co00001Oooool9o`000003ooooool0
003ooooo00;o00001oooool2o`000003ooooool0003o000000Co00004?ooool3o`0003oooooo000B
ooooo`03o`000?oooooooooo01Oooooo00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP00ol000001?nX_NSo0000o`000?m6Fl@3o`0000?oTgJ_3?l00005omkSf003o`000?l;
:J[o2bVZ00?o00000ooP`k/00ol0003oiKb/onFl[004onFl[003o`000?oikJ3o000000Ko]9Vk00Go
0000og=Q[omcHJooLf6_o`000005olFIZ@?o00000onRV/d00ol0003oXHk0oj6>`004oj6>`003o`00
0?nKOK7oVgfa00CoVgfa00?o0000od9Rc?m2H/`00_m2H/`00ol0003ojl:[on_2Z`02on_2Z`Co0000
00?oe_7To`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool2o`0000Oo^lcW00Co0000okS<jOl0003o00001onigO84o`0000;oZNoh0_l00002oiObi`Go
00000oo0mnh00ol0003od>_Xom3[j002om3[j0;o00001?o2hnl2o`0000Coa=7T0_l00007okRjf`04
o`000?n4XNKoQ:7VohBQiPKo000000?oEiC^o`000?mGXOD00omGXOD01?l0003oD:;foe2Rm_m@X_H6
o`000003od2Tm_l0003o:8k]00;o:8k]3?l00006og;5o`03o`000?oooooooooo00kooooo0_l00013
ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`So00000oooool2o`0000Cooooo3Ol00004
ooooo`Ko000000Goooooo`000?oooooo0000ooooo`03o`0000Kooooo1?l000000ooooooo0000o`00
0002o`0000Wooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol0000looooo`004_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003
ojVmj0?o00001OnX_NP2o`0000;oAU_41_l000000onUXM;o0000ohnGe`07ohnGe`?o00000_oNhmP0
1Ol0003o2bVZo`/YZ_l;:J[o000000Coh<>k00?o0000onFl[?oU_:`00ooU_:`01?l0003onNfPooW]
X?l00006okBI^`05o`000?mcHJooLf6_og=Q[ol000001Oo5VJT00ol0003oXY[=oj:Jc@04oj:Jc@03
o`000?nQS/3oXHk000?oXHk000?o0000oi]m/OnKOK401OnKOK42o`0000?o@V;<00?o0000on_2Zoo[
`Z/01Ol00002omKai003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVm
j0Co0000;Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0ol00008ok_<
i`?o00001OnigO84o`0000?o^>ge2_l00003ol3gkP03o`000?o@jnSod>_X00;od>_X00?o0000omCP
h?oDh>000_l000000oo2hnoo0000olCAi004olCAi003o`000?o:`mCo000000Oo^;[K1?l00002oiFF
dP04o`000?mjU>3oNYCPogZDh0Ko000000?oEj7eo`000?m@X_H01?m@X_H00ol0003oA9_dodBKm005
o`0000;o:8k]1Ol00003ocFTl`[o00004Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01[ooooo2?l00007ooooo`Co00001_ooool7o`0000Cooooo0_l00007ooooo`Go000000?ooooo
o`000?l000001?l00006ooooo`Oo00002oooool:o`00047ooooo000Booooo`03o`000?oooooooooo
01Wooooo0_l00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZ;gXojRmj003ojRm
j0Oo00001OnUXM800ol0003oSiOGohnGe`04ohnGe`03o`000?nGjZgoUnZ]00Co00000ol;:JX01Ol0
003oh<>kon33^ooP`k_o000000KoiKb/00Go0000ooW]X?oikJ3onNfPo`000005okBI^`04o`000?mc
HJooLf6_o`0000GoaIVY00?o0000oogSU_l000001OnRV/d00ol0003oXHk0oj6>`003oj6>`003o`00
0?nKOK7oVgfa00GoVgfa00?o0000ofMle?l000000_l000001_m2H/co0000on_2Zol0003oel33o`00
00;oe_7T00?o0000omKai?l000000_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`00
00?oZKgX00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Jooooo`04o`000?oooooooooo
o`0000?o_LcV00?o0000ok_<ionkc>L01?nkc>L01?l0003o_M_^okgKk_nmfnh2o`000004okWMl_l0
003o0000o`0000Co^>ge0_l00002ok3hk@;o000000CoZoWQo`000?nXn>?o00001?o0mnh00ol0003o
d>_Xom3[j002om3[j003o`000?oDh>3oe>3P00;oe>3P0ol00003olCAi0;o00000oo:`m@00ol0003o
^;[KokRjf`02okRjf`;o000000?o[Z7:o`000?nEU]801?nEU]800ol0003oNYCPogZDh002ogZDh004
o`000?mgVNKoMiWVogNIiPOo000000?oD:;fo`000?m4Vo@00om4Vo@00ol0003oAI?ao`000003o`00
00;o483U0_l00004ocFTl`;o00001_ma__d00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool07oooool4o`00013ooooo1Ol0000?ooooo`Go000000?oooooo`00
0?l000001_l00005ooooo`?o00003Oooool4o`0000Oooooo0_l0000oooooo`004_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?nY_NSoZKgX00?oZKgX0_l00006ojVmj004o`000?nX_NSoZ;gXojRm
j0?o00000om6Fl@00ol0003oYJ7BojFQdP05ojFQdP03o`000?n?UmOoSiOG00;oSiOG00?o0000oiOZ
[OnGjZd00_nGjZd01?l0003o07?Io`000?l00003o`/YZP04o`000?oP`k_oh<>ko`0000GoiKb/00?o
0000ooW]X?oikJ000_oikJ000ol0003o]9VkokBI^`03okBI^`03o`000?mcHJoo000000KoaIVY00?o
0000oogSU_l000001OnRV/d00ol0003oXHk0oj6>`004oj6>`003o`000?nKOK7oVgfa00?oVgfa0ol0
0003ofMle0;o000000?ojl:[o`000?l000001?oFlN@4o`0000KoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000ojVmj005ojVmj0;o0000:oooool00ol0003oooooooooo`0Kooooo`;o00001Onm
c>H01?l0003o^lcWok_<ionkc>L2o`0000Go_M_^0ol00005okS]m@06o`000?n`n>go/?S]ok3hkOl0
003oZoWQ1_l00002ol3gkP03o`000?o@jnSod>_X00;od>_X00?o0000omCPh?oDh>000_oDh>001ol0
003oe=SLomCHg?oDf=co0000olCAi?l000001_o:`m@01?l0003o^;[Ko`000?l00004ojjQbP03o`00
0?nEU];oUIKB00?oUIKB00?o0000ogZDh?mjU>000_mjU>000ol0003oMiWVogNIiP02ogNIiP03o`00
0?m_UnOoKiOW00;oKiOW1_l000000om4VoCo0000odFCl@02odFCl@?o00000_l@P>D7o`0000KoLKkm
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02cooooo
2_l00009ooooo`Co00001?ooool4o`000003ooooool0003o000000Ko00001?ooool:o`0000_ooooo
00?o0000ooooooooool00oooool;o`0003Sooooo000Booooo`03o`000?oooooooooo01cooooo00?o
0000ojVmj?l000000_l000000onY_NSo0000ojVmj006ojVmj0Oo00000om6Fl@00ol0003oYJ7BojFQ
dP04ojFQdP04o`000?n?UmOoSiOGohnGe`go000000Co2bVZo`000?oP`k_o00001OoU_:`00ol0003o
nNfPooW]X002ooW]X003o`000?ndVK_o]9Vk00Co]9Vk0_l00006olFIZ@04o`000?omhiKooN>Fo`00
00GoXY[=00?o0000oj6>`?nQS/000onQS/000ol0003oVgfaoi]m/@02oi]m/@Co00001?mWO=@2o`00
0004omO0`ol0003oe_7TomKai0?o00000_nec^d00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP0
0ol0003oZKgXojVmj003ojVmj0;o0000:_ooool00ol0003oooooooooo`0Kooooo`03o`000?nmc>Ko
_LcV00Ko_LcV00?o0000ok_<iol000001?nmfnh3o`0000?o_nWb0_l000000onhkOGo0000o`000002
ok3hk@Ko00001?oAm^L4o`0000;od>_X00?o0000omCPh?oDh>000_oDh>000ol0003oe=SLomCHg002
omCHg0;o00001oo:`m@2o`0000Ko[Z7:00?o0000oiFFd_nEU]800onEU]800ol0003oNYCPogZDh003
ogZDh003o`000?mgVNKoMiWV00;oMiWV00?o0000ofnGiom_UnL00om_UnL01?l0003oH8[Tof2:i?mP
R^@5o`0000;oAI?a1Ol00003od2Hl`[o00004?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo02;ooooo0ol00003ooooo`Oo00003oooool3o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001?l0000=ooooo`Co00005oooool4o`0003gooooo000Booooo`03o`000?oooooo
oooo01gooooo00?o0000ojVmj?nY_NP00onY_NP01?l0003oZKgXojVmj?nY_NP5o`0000CoYkgY00?o
0000odIKa?m6Fl@00_m6Fl@00ol0003oYJ7BojFQdP04ojFQdP03o`000?n?UmOo000000Co[Io90_l0
00001?lnAk?o0000o`0MYol00003of62g0?o00001_oU_:`00ol0003onNfPooW]X002ooW]X0So0000
1_o5VJT01Ol0003ooN>FoogSU_omhiKo000000GoXY[=00?o0000oj6>`?nQS/000onQS/001?l0003o
Vgfaoi]m/OnKOK46o`0000?oIgcD00?o0000omO0`ooG`<<00ol00003okG>k@04o`000?nec^go]Lk]
o`0000;oZKgX0ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgX
o`000?ooool01Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`03o`000?oo
oooooooo01Wooooo0ol00008okg<iP?o000000?o_M_^o`000?l000000ol00005okoYlPSo00000_o7
o]l00ol0003odOKWom7fi`02om7fi`03o`000?oChN;odn7R00;odn7R0ol00003omCPh003o`000?oD
f=coe=SL00;oe=SL00?o0000olW4eOl000001_o:`m@00ol0003o_Jc9o`000007ojjQbP03o`000?nE
U];oUIKB00;oUIKB1Ol000000omjU>3o0000ogNIiP04ogNIiP03o`000?m_UnOoKiOW00?oKiOW00?o
0000of2:i?mPR^@00_mPR^@00ol0003oF8SUoeR8i@04o`0000;o:GcV0_l00003od2Hl`03o`000?m0
V??o000000GoM;?i00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02gooooo00?o0000ooooooooool07Oooool9o`0000;ooooo
1_l0000>ooooo`;o000000?oooooo`000?l000000ol00003ooooo`_o00002oooool00ol0003ooooo
ooooo`1Fooooo`004_ooool00ol0003oooooooooo`0Nooooo`03o`000?nY_NSoZKgX00?oZKgX1_l0
0002ojVmj005o`000?nW_NWoYkgYojNmjOl000001?m6Fl@00ol0003oYJ7BojFQdP04ojFQdP;o0000
1?n]WlT02?l0003ok?JXoncfZ?l0003o?TNco`000?l07JOo00001?mQP]`00ol0003oiKb/onFl[003
onFl[004o`000?oikJ3onNfPooW]X0;o000000?oW7V[o`000?n;H9X01?n;H9X00ol0003oaIVYolFI
Z@04olFIZ@05o`000?omhiKooN>FoogSU_l000001OnRV/d00ol0003oXHk0oj6>`003oj6>`004o`00
0?nKOK7oVgfaoi]m/@Ko00000_mWO=@01Ol0003oel33omO0`ol0003oo=fP00;o00001?nec^d00ol0
003o]Lk]o`000002o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000oooo
ooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Gooooo`03o`000?oooooooooo01Kooooo0ol00003okc;iP03o`000?nmc>Ko_LcV00;o_LcV0ol0
00000onof>co0000o`000002o`000003okgKk_l0003o_nWb00Go_nWb00Go0000ol3ekoo0mNoo`?G_
o`000002ol?liP04o`000?o7o]ooaokOo`0000CodOKW00?o0000om?Qh_oChN800_oChN801ol0003o
e]OIomKGfOoFemWo0000omCPh?l000001?oDf=`01Ol0003obLCEolW4eOo9a=Go000000?ob/?D0_l0
0003okf/b@03o`000?n^XL[o[Z7:00Co[Z7:00?o0000oiFFd_l000000_l000000onSV/_o0000ohV@
d`02ohV@d`co000000?oKiOWo`000?mPR^@01?mPR^@00ol0003oF8SUoeR8i@02oeR8i@?o00000_lY
O>H5o`000003od2Hlol0003oM;?i00CoM;?i00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02go
oooo00?o0000ooooooooool06oooool5o`000004ooooool0003o0000o`0000?ooooo0ol00002oooo
o`03o`000?oooooooooo01Sooooo0ol000000ooooooo0000o`000002ooooo`?o00004?ooool7o`00
00?ooooo1ol00013ooooo`004Oooool00ol0003oooooooooo`0Pooooo`03o`000?nY_NSo000000Go
00001_nY_NP01?l0003oYkgYojNmjOnW_NT4o`000004odIKa?l0003oYJ7BojFQdP?o00001_n]WlT0
1?l0003ok?JXoncfZ?l00002oci7/`03o`000?l07JOo000000CoHH;L00?o0000onFl[?oU_:`00_oU
_:`01?l0003onNfPo`000?l00003oiaiZ`03o`000?n;H9[oRf2J00?oRf2J00?o0000olFIZOo5VJT0
1?o5VJT00ol0003ooN>FoogSUP02oogSUPWo00000_nQS/000ol0003oVgfaoi]m/@02o`0000;oJg[@
0ol000000omWO=Co0000omO0``02omO0``;o00000_l001400ol0003o]Lk]okG>k@03o`000003ojVm
j?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0;o0000
1Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41005oooool00ol0003o
ooooooooo`0Dooooo`;o00001onlbnH01Ol0003o_LcVo`000?l0003o_mS/00?o00000onof>`3o`00
00Co_nWb0_l00002ol3ek`;o00000_o3o>H01?l0003oaokOolOngol00004om7fi`03o`000?oChN;o
dn7R00;odn7R00?o0000omKGfOoFemT00ooFemT2o`0000?oe=SL00?o0000olW4eOo9a=D00oo9a=D0
0ol0003ob/?Do`000005okf/b@03o`000?n^XL[o[Z7:00Co[Z7:0_l00005oj>Jb`03o`000?n9T=?o
RI3C00;oRI3C00?o0000oh>=eOn3SMD00on3SMD01?l0003oN8OFogR7e_mhQmH5o`0000?oH8[T00?o
0000oeR8iOmHR>D00_mHR>D00ol0003oC7WMo`000002o`0000CoCY7^1ol000000omd/oWo0000oooo
o`0>ooooo`;o00001Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
;Oooool00ol0003oooooooooo`0Rooooo`Wo00006_ooool4o`000003ooooool0003o000000;o0000
0oooool6o`0000Wooooo1Ol00005ooooo`_o0000@Oooool0017ooooo00?o0000ooooooooool07ooo
ool5o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP6o`0000;oJ83H1?l00002odmce`03o`000?n]
WlWo[Io900?o[Io900Go0000oncfZ?o/mZSok?JXo`000003oci7/`?o00001?mQP]`00ol0003oiKb/
onFl[003o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@03o`00
0?omhiKooN>F00?ooN>F00?o0000ohJ>don6S]<00on6S]<00ol0003oIH?LofF3g008o`0000CoJg[@
00?o0000omO0`ooG`<<00_oG`<<2o`0000;o000A0ol00002ojVmj004o`000?nY_NSoZKgXo`0000Go
ZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?ooool01Oooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`0Boooo
o`?o00002?nlbnH5o`0000Go_mS/00Co0000ol;Tl?o2i?3o`^C`0_l000000onojO;o0000ol3ek`02
ol3ek`04o`000?o3o>Ko`ocVol?liPKo00000_oAm^L00ol0003odn7Rom?QhP02om?QhP03o`000?oF
emWoe]OI00?oe]OI00Ko0000omSEeOoHeMGo0000omCHg?l00006olW4e@;o00001onm[<T01?l0003o
[Z7:ojjQb_n^XLX2o`000003ojnRbol0003oXi[;00CoXi[;00?o0000ohV@don9T=<00on9T=<00ol0
003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00;oN8OF00?o0000ofj7fom^Qm/01?l00005oeR8
i@03o`000?m<NMgoC7WM00;o00000om>TNh00ol0003oCY7^o`000004ogZYl@?o00003oooool00ol0
003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000]
ooooo`03o`000?oooooooooo02Gooooo1?l00007ooooo`;o00004Oooool4o`0000;ooooo1Ol00004
ooooo`Oo00005_ooool00ol0003oooooooooo`14ooooo`004Oooool00ol0003oooooooooo`0Loooo
o`?o00000oooool00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oGIocoefOl`05o`000003ofR0f?l0003oCg?G00;oCg?G00?o0000ojfObOn]WlT00_n]WlT00ol0
003ok?JXoncfZ002oncfZ005o`000?lnAk?o?TNco`000?mPF[@01Ol000000omQP]co0000onFl[003
o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@03o`000?omhiKo
oN>F00;ooN>F00?o0000om2a^_l000001On6S]<00ol0003oIH?LofF3g002ofF3g0Go00001?m[N]00
1_l0003oel33omO0`ooG`<?o0000oocMX0?o000000?o]<g/o`000?nY_NP00onY_NP00ol0003oZKgX
o`000002ojVmj0?o000000?oZKgXo`000?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ooooooooool0
1?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000005oooool00ol0003o
ooooooooo`0Aooooo`05o`000?njb^Oo^/[Wok[:iol000001_nlbnH3o`000003okkEjol0003o0000
00?o_mS/0_l00005ol;Tl0_o000000?oc?gSo`000?oGlN<00_oGlN<4o`0000;odn7R00?o0000omKG
fOoFemT00ooFemT00ol0003of=GEomSEe@02omSEe@03o`000?o9a=GobLCE00CobLCE00?o0000ol2_
b_l000001onm[<T01?l0003o[Z7:o`000?l00004ojnRb`03o`000?nSV/_oXi[;00?oXi[;00?o0000
ohV@don9T=<00_n9T=<00ol0003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00?oN8OF00?o0000
ofj7fom^Qm/00_m^Qm/3o`0000?oF8SU00?o0000odaigOm<NMd00_m<NMd3o`000004odjAk_l0003o
CY7^o`0000GoNZWa00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo02Gooooo
1_l00002ooooo`?o00004Oooool4o`0000?ooooo1_l00006ooooo`?o00001?ooool2o`0005Wooooo
000Aooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`03o`000?nY_NSoZKgX00?oZKgX0_l0
0006ojVmj004o`000?mMWo?oGIoco`0000?oOVjg1?l000000om?LmOo0000ojfOb@02ojfOb@Co0000
0_o/mZP01ol0003o?TNcoci7/olnAk?o0000of1J]?l000000omCX_H6o`0000GoW7V[00?o0000oh]P
V_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@05o`000?omhiKooN>FoogSU_l000000_o@/KX0
0ol0003oQXkCohJ>d`03ohJ>d`03o`000?mUPmcoIH?L00;oIH?L00?o0000oc9JbolbF//00ol00004
of]jd003o`000?oG`<?oel3300?o00001?ndcN`01?l0003oZKgXojVmj?nY_NP5o`0000GoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0;o00001_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`;o0000
1Onjb^L00ol0003o_<_Vokc;iP03o`0000Ko_]G[00?o0000okoHk?l000001_o2i?001Ol0003oaNo_
olG_koo5knoo000000?ob?SZ00Go0000olcmhoo<oN?oc?gSo`000003omOah`03o`000?oFg=coe]cL
00;oe]cL0_l00005omKGf@03o`000?oHeMGof=GE00?of=GE00?o0000olW4eOo9a=D00oo9a=D01Ol0
003o`:o:ol2_b_o0[l[o000000Ko_Jc90_l00006ojnRb`03o`000?nSV/_oXi[;00?oXi[;00?o0000
ohV@don9T=<00on9T=<00ol0003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00;oN8OF00?o0000
ofj7fom^Qm/00om^Qm/01_l0003oG7_Io`000?l0003oF8SUo`0000CoC7WM00?o0000of69homQRN<0
1?l00006ogZYl@03o`000?oooooooooo00cooooo0ol00006ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0[ooooo`03o`000?oooooooooo01gooooo3?l00002ooooo`;o
000000?oooooo`000?ooool04Oooool3o`0000;ooooo2?l00002ooooo`03o`000?oooooooooo00Co
oooo1_l0000@ooooo`;o0000Aoooool0017ooooo00?o0000ooooooooool05oooool3o`0000[ooooo
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000oefOlol00000
1OmnK[L00ol0003oB6O?o`000002o`000006ojfObOl0003o0000odQWcol0003o8fCH0ol00003oci7
/`04o`000?mPF[CoH5Zdo`0000?oDj;f00?o0000onC1/ol000000ol00005oiaiZ`03o`000?n;H9[o
Rf2J00?oRf2J00Go0000olFIZOo5VJWoaIVYo`000003oogSUP03o`000?o@/K[od;6j00;od;6j00?o
0000ohJ>don6S]<00on6S]<00ol0003oIH?LofF3g002o`0000?o<U[;0_l00005of]jd004o`000?oG
`<?o0000o`0000Go]<g/1?l000001?nY_NSo0000ojVmj?l00006ojVmj0?o00001OnY_NP00ol0003o
ZKgXojVmj003ojVmj0;o00000_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00oooooo00?o0000ok[:ionjb^L01Onjb^L4
o`0000So_]G[0ol00004ol;Tl0;o00000oo5knl01Ol0003ob?SZolShj_o8n>[o000000?oc?gS00Go
0000omOahooGlN?oeo7So`000005omKLg003o`000?oFemWo000000?oe]OI00?o0000omSEeOoHeMD0
0ooHeMD00ol0003oe<S>o`000003olW4e@03o`000?o0[l[o`:o:00;o`:o:00?o0000okf/bOnm[<T0
0onm[<T00ol0003o]ZG7o`000007ojnRb`03o`000?nSV/_oXi[;00;oXi[;1Ol000000on9T=?o0000
oh>=e@04oh>=e@03o`000?mhQmKoN8OF00?oN8OF00?o0000ofj7fom^Qm/00om^Qm/00ol0003oG7_I
oeakf@03o`0000CoC7WM00Co0000of69homQRN?oHHWS1ol000000omjZO7o0000ooooo`0:ooooo`?o
00000_ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02gooooo00?o0000ooooooooool06oooool4o`00027ooooo00?o0000ooooool00000
0_ooool6o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002ooooo`Wo0000
2oooool6o`0004Gooooo000Aooooo`03o`000?oooooooooo01Cooooo0ol0000>ooooo`03o`000?nY
_NSoZKgX00CoZKgX00Co0000ojVmj?nY_NSoZKgX1?l000000omMWo?o0000ogi^]`04ogi^]`0:o`00
0?m8IlooB6O?o`000?n]WlWo0000odQWcol0003oeojoo`0000;o8fCH0_l00002oci7/`06o`000?mP
F[CoH5Zdof1J]?l0003oDj;f0_l000000ooT`K?o0000o`000002o`0000GoW7V[00?o0000oh]PV_n;
H9X01?n;H9X01?l0003oaIVYolFIZOl00003oogSUP03o`000?o@/K[od;6j00;od;6j00?o0000ohJ>
don6S]<00on6S]<00ol0003oIH?Lo`000002on3Pe003o`000?lbF/_o<U[;00;o<U[;1ol000001?ol
gJ3o0000okC=k?ndcN`3o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_nY_NP3
o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000002Ooooooo0000oooooooo
ooooV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool00ol0
003oooooooooo`0=ooooo`?o00001Onjb^L2o`000004ok[:iol0003o0000o`0000Ko_]G[0_l00003
ol7OkP;o000000?o`^C`o`000?o5knl00oo5knl01Ol0003ob?SZolShj_o8n>[o000000?oc?gS00Go
0000omOahooGlN?oeo7So`000005omKLg007o`000?oFemWoe]OIomKGfOl0003oe]OIo`000005omSE
e@07o`000?oDb<koe<S>omC8c_l0003obLCEo`000006ol2_bP03o`000?nm[<Wo_Jc900;o00000onf
YLL00ol0003o[j;;ojnRb`04ojnRb`03o`000?nSV/_oXi[;00;o000000?oYYK4o`000?n=QlP00_n=
QlP<o`000003ogR7e_l0003oKXOK00CoKXOK00?o0000oeakfOmLNmT00_mLNmT3o`0000?oC7WM00Co
0000of69homQRN?oHHWS0_l00004oh2Pj0?o00001oooool3o`0000Gooooo00So0000oooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0]ooooo`03o`000?oo
oooooooo01Wooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`;o00004Ooo
ool00ol0003oooooooooo`02ooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003ooooo
ooooo`08o`000003ooooool0003ooooo00Co000000?oooooo`000?l000000_l00009ooooo`;o0000
0_ooool4o`00047ooooo000@ooooo`03o`000?oooooooooo01;ooooo0ol0000Booooo`03o`000?nY
_NSoZKgX00?oZKgX1?l00003ojVmj003o`000?mMWo?o000000GoOVjg00Oo0000odQWcom8IlooB6O?
o`000?m8Iloo000000?oeojo00Co0000ob=Tf?lSI=So00000olnAk<01?l0003oH5Zdof1J]?mPF[@2
o`0000?oi<6c0ol00005oiaiZ`03o`000?n;H9[oRf2J00CoRf2J00Co0000olFIZOo5VJWo00000_om
hiH00ol0003od;6jom2a^P04om2a^POo00000ooPh=@00ol0003o<U[;oc9Jb`02oc9Jb`03o`000?n=
S/ooSHk?00;oSHk?00?o0000oocMX?l000000ol00005ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l0
0005ojVmj004o`000?nY_NSoZKgXojVmj0Go00001?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00_ooooo0_l00003okK9j@Go000000?o^/[Wo`000?l000000onkdn`00ol0003o_]G[
okkEj`02okkEj`03o`000?o1gnko`Mo^00Co`Mo^1?l00002olG_k`05o`000?o8n>[ob?SZolShj_l0
00000oo<oN<01Ol0003oeo7SomOahooGlN?o000000Goe]cL00?o0000omKGfOoFemT00_oFemT3o`00
00Cof=GE00?o0000omC8c_oDb<h00ooDb<h00ol0003o`:o:ol2_bP05ol2_bP03o`000?nm[<Wo0000
00Go]ZG700?o0000ojnRbon_X//01?n_X//00ol0003oXi[;o`000004ojJFa003o`000?n=QlSoSHO8
00;oSHO800?o0000ohJ7cOn6Qld00on6Qld01?l0003oPhWAoh>9dOn3RM45o`0000?oKXOK00Go0000
oeakfOmLNmWoG7_Io`000002oeijePCo00001?mQRN<2o`0000GoP:3X00Co0000oooooooooooooooo
1?l00008ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool3o`0000?ooooo
0ol00008ooooo`Go00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000ooooo`03o`0000;ooooo1_l000000ooooooo0000
o`000003o`0000Cooooo1_l00015ooooo`004?ooool00ol0003oooooooooo`0?ooooo`?o00005_oo
ool00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000KoOVjg00Go
0000odQWcom8IlooB6O?o`000004omOn_`04o`000?lSI=So8fCHo`0000?o?TNc00?o0000of1J]?mP
F[@00_mPF[@01?l0003oi<6conC1/ooT`K<3o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0
003oaIVYo`000002oogSUP03o`000?o@/K[od;6j00God;6j00Co0000olj^^_o>[[[o00001_oPh=@3
o`0000?o<U[;00Oo0000ohf>con=S/ooSHk?o`000?olgJ3o000000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXo`000003o`000003ojVmj?l0003oZKgX00CoZKgX1?l0000:ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02Oooool2o`0000Co]/WY1?l000000onjb^Oo0000
o`000006ok_Ck004o`000?nneN_o0000o`0000Ko`Mo^00?o0000olGYkoo5jNl00_o5jNl?o`0000Co
e]cL00?o0000omKGfOoFemT00_oFemT01?l0003odL_Com7;dooAbm<2o`000003omSEeOl0003oe<S>
00Coe<S>0_l00007ol2_bP;o00001onfYLL00ol0003o[j;;ojnRb`03ojnRb`;o00001OnVU/@00ol0
003oSHO8ohf7b003ohf7b003o`000?n6QlgoQXO=00?oQXO=00?o0000oh>9dOn3RM400_n3RM400ol0
003oLX7Cog:1d`04o`0000CoG7_I00?o0000oeije_mNN]H00_mNN]H4o`0000;oHHWS0_l00005oh2P
j0?o00003?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo023ooooo0ol000001?oo
oooo0000ooooooooool2o`000003ooooool0003ooooo00Sooooo0ol00005ooooo`;o000000Kooooo
o`000?l0003o0000ooooool00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
00000oooool4o`0000?ooooo1_l000000ooooooo0000o`000002o`0000Gooooo00?o0000ooooool0
00001?l00011ooooo`004?ooool00ol0003oooooooooo`0<ooooo`?o00006_ooool2o`0000KoZKgX
00Oo0000ojVmj?nY_NSoZKgXo`000?mMWo?o000000GoOVjg00?o0000odQWcom8Ill02?l00002ob=T
f004o`000?lnAk?o?TNco`0000?oH5Zd00?o0000onC1/ooT`K<00ooT`K<2o`0000GoW7V[00?o0000
oh]PV_n;H9X01?n;H9X00ol0003oaIVYo`000002o`0000Ood;6j00Co0000olj^^_o>[[[ocZjj0_l0
0002on3Pe0?o000000Co[<;Zo`000?lCCl[o00000_lbF//01?l0003oSHk?ohf>col00002oocMX005
o`000?nY_NSoZKgXojVmj?l000000onY_NP4o`0000?oZKgX00Go0000ojVmj?nY_NSo0000ojVmj003
o`0000kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`?o00000_nfbNT3
o`0000?o]/WY0ol00007ok_Ck0?o00001Oo1gnh2o`0000CoaNW_00Go0000ol_`k?o;l>cobo3/o`00
0003om;eiP03o`000?oKjmkofn_N00;ofn_N00?o0000omWIeooIfML00_l000000ooFg=co0000omKG
f@03omKGf@03o`000?oAbm?odL_C00CodL_C00?o0000omC8c_oDb<h00ooDb<h01?l0003obkW8ol^i
b?l00005ol2_bP03o`000?njYlKo000000Oo]ZG700?o0000ojnRbon_X//00ol000000onXUlCo0000
ojJFa004ojJFa003o`000?n=QlSoSHO800?oSHO800?o0000ohJ7cOn6Qld00on6Qld00ol0003oPhWA
oh>9d@03oh>9d@03o`000?mbPM?oLX7C00;oLX7C0ol00002oeakf@03o`000?mNN]KoGW[F00?oGW[F
00?o0000og2;gOm`Rmd01?l00006oh2Pj003o`000?oooooooooo00cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool2o`0000Gooooo0_l000000ooooooo0000ooooo`04ooooo`?o000000Goooooo`000?l0003o
ooooo`000003ooooo`?o000000Coooooo`000?oooooo00000oooool00ol0003oooooo`000002o`00
00Cooooo0ol00003ooooo`Ko000000?oooooo`000?l000001?l00009ooooo`;o0000?oooool0013o
oooo00?o0000ooooooooool02Oooool3o`0001oooooo00?o0000ojVmj?nY_NP00onY_NP4o`000003
ojVmj?l0003o000000GoOVjg00Ko0000odQWcol0003o0000ofg2o_l00004oh:Rj003o`000?lSI=So
8fCH00;o00000_lnAk<01?l0003oH5Zdof1J]?l00005onC1/`?o00001?nLNJ/00ol0003oRf2Joh]P
VP05oh]PVPCo00001_o@/KX01?l0003ocZjjolj^^_o>[[X5o`0000Go[<;Z00[o0000oa=?b_l0003o
0000oc9Jbol0003oSHk?o`000?olgJ3o00001?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY
_NP01?l0003oZKgXo`000?l0000Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1Oooool2o`0000;o/<S/0ol00003okK9j@?o00000ongdNd00ol0003o^m?/ok_Ck002ok_Ck0;o0000
0onnfnh3o`000003ol7Ok_l0003oaNW_00?oaNW_0_l00003ol_`k005o`000?oBmNKod_GVom;ei_l0
00001?oKjmh00ol0003ofMWGomWIe`03omWIe`;o00000ooFemT00ol0003odL_Com7;d`04om7;d`03
o`000?oCa<co000000?oe<S>00?o0000ol^ib?o;^LP00_o;^LP01Ol0003o`:o:ol2_b_o0[l[o0000
00?o^ZO600?o0000okJUaonfYLL01?nfYLL3o`0000GoZ9O400?o0000ojJFa?nVU/@00onVU/@00ol0
003oSHO8ohf7b003ohf7b003o`000?n6QlgoQXO=00?oQXO=00?o0000oh>9dOn3RM400_n3RM400ol0
003oLX7Cog:1d`03og:1d`06o`000?mUM<ko0000o`000?mLNmWo00001OmNN]H00ol0003oL8_Mog2;
g@02og2;g@Wo00003Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Sooooo0ol0
000>ooooo`Co000000Coooooo`000?l0003o00001Oooool00ol0003oooooooooo`02o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooool000001?l00003ooooo`04o`000?oooooo0000o`0000Co
oooo0ol00003ooooo`Ko0000B?ooool0013ooooo00?o0000ooooooooool01_ooool3o`0002?ooooo
00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj002ojVmj0;o00001OmnK[L5o`000003ofg2
o_l0003oPZ;X00?oPZ;X00Wo0000ob=Tf?l0003o02b`o`000?lnAk?o0000of1J]?l000001_oT`K<3
o`0000CoW7V[00?o0000oh]PV_n;H9X01On;H9X3o`000003o`006Ol0003od;6j00?od;6j00?o0000
olj^^_o>[[X00_o>[[X3o`000003omOjgol0003o[<;Z00Go[<;Z00?o0000oa=?b_lCClX00_l00000
1On=S/oo0000oocMX?l0003oZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVm
j003o`0001?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`;o000000Co
/<S/o`000?l0003o00000_n`b>`01?l0003o]/WYo`000?l00007okOAk@04o`000?nkdnco0000o`00
00Oo_]_^1?l00002olGYk`03o`000?o;l>cobo3/00;obo3/00Go0000om;ei_oBmNKod_GVo`000004
om_[gP03o`000?oIfMOofMWG00?ofMWG00Ko0000om[Fe?oJe]Co0000omKGfOl00006om7;d`07o`00
0?oCa<codlC<om?4c?l0003oe<S>o`000006ol^ib003o`000?o0[l[o000000Co^ZO600?o0000okJU
aonfYLL00onfYLL00ol0003o/ic1o`000006ojRGa003o`000?nVU/CoYYK400?oYYK400?o0000ohf7
b?n=QlP00on=QlP00ol0003oQXO=ohJ7c@03ohJ7c@03o`000?n3RM7oPhWA00?oPhWA00?o0000og:1
dombPM<00ombPM<00ol0003oIGC>ofEdcP02o`0000GoGW[F00?o0000og2;gOm`Rmd00om`Rmd00ol0
003oQYgQohJMh@04ohJMh@03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Nooooo`Co00001?ooool2o`000003ooooool0003ooooo00?ooooo0_l00007oooo
o`?o000000?oooooo`000?ooool01?l00004ooooo`03o`000?oooooooooo00?o00001Oooool4o`00
0004ooooool0003o0000o`0000Kooooo0ol00004ooooo`;o00000_ooool00ol0003oooooooooo`03
o`0004Oooooo000@ooooo`03o`000?oooooooooo00?ooooo0ol0000Wooooo`03o`000?nY_NSoZKgX
00?oZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ogi^]`;o00001OnL^Nd3o`0000?oPZ;X0_l00000
0olSI=So0000o`0//002o`000003of1J]?l0003oi<6c00Koi<6c0_l00004oiaiZ`03o`000?n;H9[o
Rf2J00GoRf2J1Ol00004om2a^P04o`000?o>[[[ocZjjolj^^P?o00000ooGn]l00ol0003o[<;Zojc2
jP03ojc2jP04o`000?lCCl[o4do:oa=?bP;o00000_olgJ02o`0000GoZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo1Ol00005ok38k0?o00002?ngdNd3o`0000Ko_]_^0_l00004ol;Sk`Co0000
0_o;l>`01Ol0003od_GVom;ei_oBmNKo000000Cofn_N00?o0000omWIeooIfML00ooIfML00ol0003o
f]KDom[Fe002om[Fe0;o00001OoAbm<00ol0003odlC<om?4c003om?4c003o`000?o;^LSobkW800Go
bkW80_l00006okZWaP03o`000?nfYLOo]ZG700;o00000oncW<400ol0003oZ9O4ojRGa004ojRGa003
o`000?nVU/CoYYK400;oYYK400Co0000ohf7b?n=QlSoSHO81ol000000on6Qlgo0000oh>9d@04oh>9
d@03o`000?mbPM?oLX7C00?oLX7C00?o0000ofEdc_mUM<h00_mUM<h3o`0000?oGW[F00?o0000og2;
gOm`Rmd00om`Rmd00ol0003oQYgQohJMh@04ohJMh@03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01?ooool00ol0003oooooooooo`0Mooooo`Co00001?ooool00ol0003ooooooooo
o`04ooooo`?o00001oooool00ol0003oooooo`000004ooooo`?o00002Oooool00ol0003ooooooooo
o`04ooooo`Co00000_ooool3o`0000Gooooo1?l0000=ooooo`03o`000?oooooooooo04Cooooo000?
ooooo`04o`000?ooooooooooooooo`?o0000:oooool00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSo000000Co000000?oZKgXo`000?nL^Nd01?nL^Nd4o`0000;oPZ;X00Co0000ob/n/ol0003o0000
0_l0;;03o`0000Koi<6c0ol00004oiaiZ`03o`000?n;H9[oRf2J00GoRf2J0_l000001?o]n;;o0000
o`000?l00002om2a^P03o`000?o>[[[ocZjj00;ocZjj0_l00004omOjg`ko000000?oZKgXo`000?nY
_NP01?nY_NP00ol0003oZKgXojVmj003o`0000Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooo000000Co000000?oZLK_o`000?n`b>`00on`b>`2o`0000?o
/Lo_0_l00004okOAk@;o00000onif?000ol0003o_]_^okkKkP02okkKkP03o`000?o2hnoo`^?_00?o
`^?_00?o0000olSXkOo8j>d00_o8j>d8o`0000;ofn_N00?o0000omWIeooIfML00ooIfML00ol0003o
f]KDom[Fe002om[Fe004o`000?oFcM7oe/gAo`0000?odL_C00?o0000om?4c?oCa<`01?oCa<`00ol0
003obkW8ol^ib004ol^ib003o`000?o2[lOo000000Ko^ZO600?o0000okJUaol000001OncW<400ol0
003oZ9O4ojRGa004ojRGa003o`000?nVU/CoYYK400;oYYK41?l00003oiB;aP04o`000?n=R<WoSHS9
ohf8b@[o00001?mbPM<01Ol0003oIGC>ofEdc_mUM<ko000000;oKGoD1?l00005og2;g@;o00001_n6
WN400ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Cooooo00?o0000oooooooo
ool06oooool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo00Ko
oooo00?o0000ooooooooool01Oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00?ooooo1_l0001Cooooo`003oooool4o`0002oooooo
00Co0000ojVmj?nY_NSoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000oibikOl0
00000_l00002ojVmj003o`000?n8/_7o000000;oPZ;X00?o0000ob/n/ol000000ol0;;000ol0003o
i<6conC1/`04onC1/`04o`000?o4a]_oa<KKo`0000CoW7V[00?o0000oh]PV_n;H9X01?n;H9X3o`00
0006ongh/_l0003okN?5o`000?o@/K[o00001?o>[[X2o`0000;oeo[O0ol00002ok76jP04o`000?nY
_NSoZKgXojVmj0Co00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`Co00001OnYa^l01?l0003o/<S/o`000?l00007ok7?
k`04o`000?ngdNgo0000o`0000Ko^MS`00Co0000okkKk_l0003o00001?o2hnl2o`0000Cob>S]00?o
0000om3Yioo@jNL00_o@jNL01?l0003of>?NomSSg_oHhmh3o`0000CofMWG00?o0000om[Fe?oJe]@0
0_oJe]@00ol0003oe/gAomK=d@02omK=d@03o`000?oAbm?o000000KodlC<00?o0000om6maol00000
1?o;^LP01Ol0003o`Zo7ol:_aoo2[lOo000000Go^ZO60_l00007ok>L`@03o`000?nXUlCoZ9O400?o
Z9O400?o0000ojJFa?l000000_l000000onUU/Go0000oiB;aP05oiB;aP03o`000?n=R<WoSHS900;o
SHS900?o0000ohN6c?n7Q/`00on7Q/`00ol0003oKgS<o`000002o`000003og:1dol0003oIGC>00?o
IGC>00?o0000ofeoe?m]Om@00_m]Om@6o`000003og2;gOl0003oQYgQ00GoQYgQ00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Pooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo0ol00002
ooooo`03o`000?oooooooooo00;ooooo1?l000000ooooooo0000o`000002o`0004Gooooo000?oooo
o`;o0000<_ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00Go0000ohRb
lOl0003oPZ;Xo`000002ob/n/`;o000000?o02b`o`000?oT`K<01?oT`K<01?l0003oa<KKolC6foo4
a]/2o`0000CoW7V[00?o0000oh]PV_n;H9X00on;H9X2o`000004ongh/_l0003okN?5ongSa@;o0000
1Oo>[[X4o`0000Co/LKZ1Ol00003ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l0000?ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08?ooool4o`0000GoZLK_0ol00008ok7?k`?o0000
1onif?05o`0000;o`^?_00?o0000olSXkOo8j>d00oo8j>d00ol0003od>WWom3Yi`02om3Yi`03o`00
0?oHhmkof>?N00;of>?N00?o0000om[JeooJf]L00_l000000ooIfMOo0000om[Fe003om[Fe003o`00
0?oFcM7oe/gA00Coe/gA00?o0000om?4c?oCa<`01?oCa<`01Ol0003odKg7om6maooA_LOo000000;o
bkW800?o0000ol:_aoo2[lL00_o2[lL00ol0003o^ZO6okZWaP02okZWaP03o`000?neWKoo000000Oo
/ic100?o0000ojRGa?nXUl@00onXUl@2o`0000GoYIK500?o0000oiB;a_nDRlH00onDRlH00ol0003o
SHS9ohf8b@03ohf8b@03o`000?n7Q/coQhK<00?oQhK<00Co0000ofmhc?m_N<coKgS<0_l00004ofEd
cP03o`000?m]OmCoKGoD00?oKGoD00?o0000og^>f_mkS]X00_mkS]X:o`0000[ooooo00?o0000oooo
ooooool08?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@04ooooo`;o0000:oooool2o`0000Kooooo0ol0000Pooooo`;o00000_ooool2o`0000Cooooo0ol0
0002ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`?o0000@oooool0017ooooo00?o0000
ooooooooool0<?ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj003ojVmj0Go00000ol[?[<4o`0000?oi<6c00?o0000ojR4[_l000000_o4a]/2
o`0000CoW7V[00?o0000oh]PV_n;H9X00on;H9X00ol0003okORbo`000004ongSa@03o`000?o>[[[o
cZjj00?ocZjj00Co0000oiZSfonJXm_o00000onaa^X2o`000003ojVmj?l0003oZKgX00GoZKgX00?o
0000ojVmj?nY_NP00ol0000Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_oo
ool01?l0003oooooo`000?nYa^l3o`0000?oZLgc0_l00004ok7?k`;o00000onbeO800ol0003o^MS`
okWHl002okWHl0;o00001Onlg_43o`0000Cob>S]00?o0000om3Yioo@jNL00_o@jNL00ol0003of>?N
omSSgP02omSSgP03o`000?oJf]Oof][G00?of][G0_l00003om[Fe003o`000?oFcM7oe/gA00Coe/gA
0_l00005om?4c003o`000?oA_LOodKg700;odKg700?o0000ol^ib?l000001_o2[lL01?l0003o^ZO6
okZWa_l00003okFM_`03o`000?ncW<7o/ic100Co/ic100?o0000ojRGa?nXUl@00ol000000onWUL?o
0000ojFFa@04ojFFa@03o`000?nDRlKoU8_600?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003o
QhK<ohN6c003ohN6c003o`000?m_N<coKgS<00?oKgS<0ol00002ofEdcP03o`000?m]OmCoKGoD00?o
KGoD00?o0000og^>f_mkS]X00omkS]X00ol0003oS9cNohbLgP04ohbLgP03o`000?oooooooooo00So
oooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c004ooooo`03o`000?oooooooooo02Oooooo1Ol00005ooooo`03o`000?oooooo
000000[ooooo00?o0000ooooooooool05Oooool2o`0000;ooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo1_l00003ooooo`?o0000@?ooool001;ooooo00?o0000ooooooooool0<?ooool01?l0
003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l000000_l000001?nY_NSo0000og>Ylomc
ZO<2o`0000?o:cjc00Ko0000o`Q]gOl0003o0000onC1/ol00003ojR4[P04o`000?o4a]_oa<KKo`00
00CoW7V[00?o0000oh]PV_n;H9X00_n;H9X5o`0000;okN?50ol00003olj^^P03o`000?nJXm_oVZ?K
00;oVZ?K00?o0000ok76j_l000001?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00005oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00Co0000ooooool0003o00001onYcO<0
1?l0003o/Lo_o`000?l00006ok;ElP04o`000?nif?3o0000o`0000Ko_=ka00Co0000ol7Rkoo1h^oo
`N;_0_l000000oo8j>go0000om3Yi`03om3Yi`03o`000?oHhmkof>?N00;of>?N00?o0000om[JeooJ
f]L00ooJf]L01_l0003of=OFomSGe_l0003of]KDo`0000Koe/gA00Co0000oljnboo>_/_o00000ooC
a<`00ol0003odKg7om6ma`04om6ma`03o`000?o2[lOo`Zo700Go`Zo700?o0000okZWa_l000001?ne
WKl00ol0003o/ic1ok>L`@04ok>L`@?o00001OnWUL<00ol0003oYIK5ojFFa@03ojFFa@03o`000?nD
RlKoU8_600?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003oQhK<ohN6c002ohN6c003o`000?m_
N<coKgS<00?oKgS<00?o0000og1kc_m`Nlh00ol00005ofeoe003o`000?mkS][oNhkJ00CoNhkJ00?o
0000ohbLg_n<W=h01?n<W=h00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Kooooo00?o0000ooooooooool0
9Oooool2o`000004ooooool0003o0000o`0000Gooooo00?o0000ooooooooool00oooool3o`0000Co
oooo0_l0000@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o00001_ooool00ol0003o
ooooooooo`06ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`0mooooo`00
4oooool00ol0003oooooooooo`0`ooooo`?o00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o0000
1OnY_NP00ol0003oLjWcog>Yl`06o`0000;oZ8B^00?o0000ojR4[_nXQ:h00onXQ:h3o`0000CoW7V[
00?o0000oh]PV_n;H9X00_n;H9X00ol0003oZYO2o`000002o`1^`P;o00000_nWWlh01Ol0003ocZjj
olj^^_o>[[[o000000CoVZ?K0_l00006ojVmj003o`000?nY_NSo000000;o00006oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00001_nYcO<3o`00
00Oo/]Gb0ol00005okcNl@;o00001Oo1h^l4o`0000;od>WW00?o0000omSSg_oHhmh00_oHhmh00ol0
003of][Gom[Je`03om[Je`03o`000?oHemKof=OF00;of=OF0_l00005omK=d@03o`000?o>_/_oc[k;
00;oc[k;00?o0000om?4c?l000001_oA_LL2o`0000Oo`Zo70_l00006okFM_`03o`000?ncW<7o/ic1
00;o/ic100?o0000ok6K`?l000001_nWUL<00ol0003oYIK5ojFFa@03ojFFa@03o`000?nDRlKoU8_6
00?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003oQhK<ohN6c003ohN6c003o`000?m_N<coKgS<
00?oKgS<00?o0000og1kc_m`Nlh00_m`Nlh3o`0000?oKGoD00?o0000og^>f_mkS]X01?mkS]X00ol0
003oS9cNohbLgP03ohbLgP03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`0T
ooooo`06o`000?ooooooooooo`000?oooooo00002_ooool5o`0000?ooooo0_l0000=ooooo`03o`00
0?oooooooooo00;o00001Oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000Oo
oooo0ol00005ooooo`Co0000AOooool001Cooooo0_l0000booooo`03o`000?nY_NSoZKgX00?oZKgX
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000og>Ylol00000
1?n6WN800ol0003oZ8B^ojR4[P06ojR4[PCo00000onLNJ/00ol0003oRf2Joh]PVP02oh]PVPCo0000
00?o06k2o`000?nWWlh00onWWlh01?l0003ocZjjo`000?l00002oiZSf`;o00000_nY_NP01?l0003o
ZKgXojVmj?nY_NP4o`0001oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uoooo
o`;o000000Coooooo`000?nYcO?oZLgc0ol00003ojSCmP03o`000?nbeO;o/]Gb00;o/]Gb0_l00003
okCJm0?o000000?o_=kao`000?o1h^l01Oo1h^l00ol0003oan?/olOSk002olOSk0Co00000_oHhmh0
0ol0003of][Gom[Je`03om[Je`03o`000?oHemKof=OF00?of=OF00?o0000omK@dol000000ooFcM40
0ol0003oc[k;oljnb`04oljnb`03o`000?oA_LOodKg700CodKg700Co0000olVa`_o9/L;o00001Oo2
[lL00ol0003o]Ybmo`000006okFM_`03o`000?ncW<7o/ic100;o00000onaVl000ol0003oYiG3ojNE
``04ojNE``03o`000?nUU/GoYIK500;oYIK500?o0000oiB;a_nDRlH00onDRlH00ol0003oSHS9ohf8
b@03ohf8b@03o`000?n7Q/coQhK<00?oQhK<00?o0000ofmhc?m_N<`00om_N<`00ol0003oL7_>og1k
cP02og1kcP03o`000?mhQ]CoN8KD00Co00001_mkS]X2o`0000CoS9cN00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Oooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4104ooooo`03o`000?oooooooooo02Gooooo0_l00005ooooo`;o00001oooool3o`0000Co
oooo0_l0000=ooooo`03o`000?oooooooooo00?o00000_ooool4o`000003ooooool0003o000000Co
oooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l00013ooooo`005_ooool00ol0003ooooo
ooooo`0`ooooo`04o`000?nY_NSoZKgXojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`00
0003ojVmj?l0003oQYgR00;oQYgR00?o0000ojR4[_nXQ:h01OnXQ:h01Ol0003oTkK_oi>fkonC]^oo
000000?oW7V[00Oo0000oh]PV_n;H9[oRf2Jo`000?nZUl;o000000;o/=[f00?o0000o`1^`_l00000
0onWWlh01_l0003ocZjjo`000?l0003oVZ?Ko`0000CoZKgX1?l0000Sooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09oooool01?l0003oooooo`000?l00007ojSCmP04o`000?nbeO;o
0000o`0000Oo]=[d0ol00004ol7Rk`;o00001?o7hn`00ol0003ocN3VolgPiP02olgPiP?o00001?oJ
f]L00ol0003of=OFomSGeP03omSGeP07o`000?oFd=?oe]3ComK@dol0003oe/gAo`000006oljnb`;o
00001OoA_LL00ol0003obK72olVa`P02olVa`P03o`000?o2[lOo`Zo700;o00000onfW;d00ol0003o
]IfookFM_`03okFM_`03o`000?ncW<7o000000Go/I_000?o0000ojNE`onWUL<01?nWUL<00ol0003o
YIK5ojFFa@02ojFFaA7o000000?oQhK<o`000?m_N<`01Om_N<`00ol0003oL7_>og1kcP02og1kcP03
o`000?mhQ]CoN8KD00;oN8KD3ol00009ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`03ooooo`?o00001_ooool2o`000004ooooool0003o0000o`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooo`000004o`0000Gooooo00?o0000ooooooooool0@?ooool001Oooooo00?o0000oooooooo
ool0<?ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?l0
00000on6WN800ol0003oZ8B^ojR4[P04ojR4[P;o00000onC]^l01?l0003oW7V[oiaiZol00003oh]P
VP?o00000_n`f_H3o`0000CoYio>00?o0000ojNOc_l000000_l000001?nY_NSo0000o`000?l0000X
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
o`0000GoZ=?f0ol00006okCJm0;o00000ongg_<2o`000003ol7Rkol0003oan?/00?oan?/0_l00004
olgPiP04o`000?o@f^3od=[Pom3Jh0;o000000?of][Go`000?oHemH01?oHemH00ol0003oe]3ComK@
d`02omK@d`;o00001_o>_//01?l0003oc[[6oljja_l00003om6ma`03o`000?o9/L;obK7200?obK72
00?o0000ol:_aol000001OnfW;d00ol0003o]IfookFM_`03okFM_`;o00001onaVl000ol0003oYiG3
ojNE``03ojNE``03o`000?nUU/Go000000;o000000?oXY?5o`000?nGRlD01?nGRlD00ol0003oTHO5
oi67a@03oi67a@04o`000?n8P/KoR8;6ohR2aPGo00000om_N<`00ol0003oL7_>og1kcP02og1kcP03
o`000?mhQ]CoN8KD00?oN8KD00?o0000oh>BfOn3T]T01?n3T]T2o`0000CoT9gL00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool0
00001_ooool4o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000004o`000006ooooool0003o0000o`000?oooooo00002Oooool7
o`0000?ooooo1?l00017ooooo`006?ooool00ol0003oooooooooo`0`ooooo`03o`000?nY_NSoZKgX
00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00003ohJM
hP03o`000?nXQ:koZ8B^00?oZ8B^00?o0000ojVmj?l000001?l00002oiaiZ`06o`000?n;H9[oRf2J
oh]PV_l0003oRk;`0ol00002ojVmj0;o00000onWWlh6o`0002cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Xooooo`06o`000?ooooooooooooooool0003oZ=?f0ol00003ojWHn0?o
000000?o]=[do`000?l000001_ngg_<4o`0000;oan?/00?o0000olgPi_o=h>H00oo=h>H00ol0003o
d=[Pom3Jh003om3Jh0?o00001?oHemH00ol0003oe]3ComK@d`02omK@d`03o`000?o<_<_o000000Go
c[k;00?o0000oljja_o>^/H00_o>^/H00ol0003odKg7o`000007olVa`P03o`000?nfW;go]Ybm00Go
]Ybm00Oo0000okFM_oneWKoo]Ifoo`000?ngWl3o000000Oo/I_000?o0000ojNE`onWUL<00onWUL<2
o`0000GoXY?500?o0000oiN;aOnGRlD00onGRlD00ol0003oTHO5oi67a@03oi67a@03o`000?n8P/Ko
R8;600;oR8;600?o0000ogQiaomhNLL01?l00005og1kcP03o`000?mhQ]CoN8KD00?oN8KD00?o0000
oh>BfOn3T]T01?n3T]T2o`0000CoT9gL00?o0000ooooooooool01_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000007ooooo`;o00001_ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooo000000;o000000Koooooo`000?l0003o0000ooooool0000:ooooo`Oo
00001?ooool01?l0003oooooo`000?l00015ooooo`006Oooool2o`00037ooooo00Co0000ojVmj?nY
_NSoZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00000_n6WN800ol0003oZ8B^ojR4[P03
ojR4[P;o00000_nY_NP01_l0003oZKgXojVmj?l0003oW7V[o`0000;oRf2J0ol00002ojVmj006o`00
0?nY_NSoZKgXojVmj?l0003oYio>1?l0000aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:Oooool2o`0000;ooooo0_l00007ojWHn0?o00001Ongg_<2o`0000Co^mob0ol00004olgP
iP03o`000?o@f^3od=[P00?od=[P00Co0000om3Dg?o@e=cod=CL0_l000000ooHemKo0000omK@d`03
omK@d`05o`000?o<_<_oc;c;olblbol000000oo>_//00ol0003oc[[6oljjaP04oljjaP03o`000?o9
/L;obK7200GobK720_l00007okJL_@04o`000?neWKoo]Ifoo`0000?o]io000?o0000ok6K`?naVl00
1?naVl000ol0003oYiG3ojNE``03o`000003ojVGa?l0003oXY?500CoXY?500?o0000oiN;aOnGRlD0
0onGRlD00ol0003oTHO5oi67a@03oi67a@03o`000?n8P/KoR8;600?oR8;600?o0000ogQiaomhNLL0
0_mhNLL5o`000003og1kc_l0003oN8KD00GoN8KD00?o0000oh>BfOn3T]T00on3T]T00ol0003oT9gL
o`000004oi2Mg003o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Vooooo`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`03o`000?oooooo000000;o
oooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo1_l00007ooooo`;o
0000@oooool001_ooooo00?o0000ooooooooool0;oooool3o`0000?oZKgX00?o0000ojVmj?nY_NP0
0onY_NP4o`0000?oZKgX00Co0000ohJMh_n6WN;o00001?nXQ:h00ol0003oZKgXojVmj003ojVmj005
o`000?nY_NSo0000oiaiZol000000_n;H9X00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo0000
00;o0000=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00Co0000oooo
oooooooooooo0_l00002ojWHn0?o00000onYfoT2o`000003okONlol0003o000000Co^mob0_l00003
ol3MkP;o000000?ocN3Vo`000?o@f^001?o@f^000ol0003od=CLom3Dg003om3Dg0?o00000ooFd=<0
0ol0003oc;c;olblb`03olblb`03o`000?o>_/_o000000Ooc[[600?o0000olVa`_o9/L801?o9/L80
1?l0003o`ZFlol:U_?l00006okJL_@03o`000?neWKoo000000Co]io000?o0000ok6K`?naVl001?na
Vl03o`0000CoZIO400?o0000oj:CaOnRTlD00onRTlD00ol0003oUh_5oiN;a@04oiN;a@03o`000?nA
QlGoTHO500;oTHO500?o0000ohR2a_n8P/H00on8P/H00ol0003oN7W7ogQia`03ogQia`04o`000?mj
P/ooNX;?ogZ2c`Oo000000?oN8KDo`000?n3T]T01?n3T]T00ol0003oT9gLo`000004oi2Mg003o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o000000Coooooo`000?oooooo00002Oooool00ol0003o
ooooooooo`04ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o
00000oooool2o`0000?ooooo1?l00002ooooo`;o00001oooool00ol0003oooooooooo`10ooooo`00
7?ooool00ol0003oooooooooo`0_ooooo`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00Co0000ohJMh_n6WN;o00000onXQ:h00ol0003o
ZKgXojVmj003ojVmj0?o000000GoW7V[o`000?n;H9[oRf2Jo`000005ojVmj0;o0000>Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool2o`00
00OoZM_i1?l00002ok_OlP;o00001_o0gNh3o`0000Cod=[P00?o0000om3Dg?o@e=`00oo@e=`01ol0
003oclcFolo<e_o?c=Ko0000omK@dol000001oo<_</00ol0003oc[[6oljjaP05oljjaP03o`000?o;
//7o000000CobK7200Go0000ol:U_?o2YKco`ZFlo`000006okJL_@;o00001_ngWl000ol0003o/I_0
ok6K`002ok6K`003o`000?nbVl7o000000KoZIO400?o0000oj:CaOnRTlD00onRTlD00ol0003oUh_5
oiN;a@03oiN;a@03o`000?nAQlGoTHO500?oTHO500?o0000ohR2a_n8P/H00on8P/H00ol0003oN7W7
ogQia`03ogQia`03o`000?mjP/ooNX;?00;oNX;?00?o0000oh6<eOn1S=D00_n1S=D6o`0000;oPi;I
00Co0000oi2Mg?l0003oT9gL1?l00007ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool09Oooool2o`0000;ooooo0_l00003ooooo`Oo00002Oooool00ol0003oooooooooo`04ooooo`;o
00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`Co00000oooool3o`00
00;ooooo1Ol00002ooooo`03o`000?oooooooooo04Oooooo000Mooooo`03o`000?oooooooooo02oo
oooo00Co0000ojVmj?nY_NSoZKgX0ol00006ojVmj003o`000?nY_NSo000000;o000000CoZKgXo`00
0?n6WN;o00000onXQ:h2o`000004ojVmj?l0003o0000o`0000;oZKgX0_l000001_nLNJ_o0000o`00
0?nY_NSo0000ojVmj0?o0000??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool00oooool2o`0000;oZM_i0ol00004oj_Ln0?o00001Oo0gNh2o`0000?o
`mWZ0_l000000oo@f^3o0000om3Dg004om3Dg003o`000?o?c=KoclcF00?oclcF00?o0000olblboo<
_</01Oo<_</00ol0003obkS8o`000005oljjaP05o`000?o;//7obk;1ol^b`Ol000000_o9/L800ol0
003o`ZFlol:U_003ol:U_003o`000?nfW;go]Ybm00;o]Ybm00?o0000okVO__l000001_ngWl000ol0
003o/I_0ok6K`002o`0000?o/Y_100?o0000ojVGa?nYUl@00onYUl@00ol0003oXY?5oj:Ca@03oj:C
a@03o`000?nGRlGoUh_500?oUh_500?o0000oi67aOnAQlD00onAQlD00ol0003oR8;6ohR2aP03ohR2
aP03o`000?mhNLOoN7W700?oN7W700?o0000ogZ2comjP/l00omjP/l00ol0003oPHcEoh6<e@03oh6<
e@04o`000?n9U][oRIKJohVFfPKo00000onDX=`00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000?ooooo1ol0
000Booooo`;o00001Oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo1?l00002ooooo`Go00000_ooool00ol0003oooooooooo`16ooooo`00
7_ooool2o`00033ooooo0ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003o`00
0?n6WN;o000000;oZ8B^1?l00006ojVmj003o`000?nLNJ_o000000Co0000@?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00001On[g?P2o`0000?o[]_g
0_l000000oo0gNko0000o`000006ol?IjP?o00001?o@e=`00ol0003oclcFolo<eP03olo<eP03o`00
0?o=`Loo000000Goc;c;00Go0000ol^hb?o;^<SobkS8o`000003oljjaP03o`000?o;//7obk;100;o
bk;100?o0000olVa`_l000001_o2YK`00ol0003o]YbmokJL_@02o`0000?o^Inn00?o0000okNO`?ng
Wl000ongWl000ol0003o/I_0o`000005ok:K`@03o`000?nYUlCoZIO400?oZIO400?o0000oj:CaOnR
TlD00onRTlD01?l0003oUh_5oiN;aOnGRlD7o`000003oi67aOl0003oR8;600CoR8;600?o0000ogQi
aomhNLL01?mhNLL00ol0003oNX;?ogZ2c`02ogZ2c`03o`000?n1S=GoPHcE00CoPHcE00?o0000ohVF
f_n9U]X00_n9U]X01Ol0003oU:3LoiBPg?nDX=co000000?oU:3L00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool2
o`000003ooooool0003o000000Go00003_ooool2o`000003ooooool0003o000000Oooooo1Ol00003
ooooo`?o00000_ooool6o`0000;ooooo0ol00004ooooo`;o0000Boooool0023ooooo00?o0000oooo
ooooool0;_ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oZKgXojVmj002ojVmj0;o00000_nXQ:h01Ol0003oZKgXojVmj?nY_NSo000000GoZKgX1?l00013
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`04
ooooo`?o000000?oZmcho`000?n^foL01On^foL3o`0000Go`mWZ0_l00003olCCiP;o000000?od=CL
o`000?o?c=H01?o?c=H01Ol0003ocL7?olg1coo=`Loo000000?oc;c;00?o0000ol^hb?o;^<P00oo;
^<P00ol0003oc[[6o`000006ol^b`@03o`000?o2YKco`ZFl00Go`ZFl00?o0000okJL_Ol000001Oni
Wkh00ol0003o]io0okNO`003okNO`0;o00001onbVl400ol0003oZIO4ojVGa003ojVGa003o`000?nR
TlGoXY?500Ko00000onFRL@01?l0003oT8S6oi28a_n@R<H=o`000003ogQiaol0003oNX;?00CoNX;?
00?o0000oh6<eOn1S=D00on1S=D00ol0003oRIKJohVFfP03ohVFfP04o`000?nDX=coU:3Lo`0000Co
U:3L00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oo
oooo0_l00002ooooo`03o`000?oooooo000000Co000000?oooooo`000?l000002oooool3o`000003
ooooool0003ooooo00Oooooo1Ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003o00001Oooool3o`0004Wooooo000Qooooo`03o`000?oooooooooo02ko
oooo00Co0000ojVmj?nY_NSoZKgX1?l00005ojVmj003o`000?nY_NSo000000?o000000?oZ8B^o`00
0?nY_NP01?nY_NP00ol0003oZKgXo`000002o`000003ooooool0003o000004Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Kooooo0_l00004ojkK
m`;o00000on`f?@2o`000003ol?Ij_l0003o000000Koa=?V0_l00005olo<eP03o`000?o=`LoocL7?
00?ocL7?00?o0000olblbol000001oo;^<P00ol0003obk;1ol^b`@05ol^b`@03o`000?o2YKco`ZFl
00Ko`ZFl00?o0000okVO__niWkh01OniWkh01ol0003o]io0okNO`?ngWl3o0000okJP`_l000001onb
Vl400ol0003oZIO4ojVGa002ojVGa0Co00000onOSl<00ol0003oUXW4oiJ9a004oiJ9a003o`000?n@
R<KoT8S600;oT8S600?o0000ohR5bOn8QLT00on8QLT00ol0003oPhK>oh>6cP02oh>6cPKo000000?o
NX;?o`000?n1S=D01On1S=D00ol0003oRIKJohVFfP03ohVFfP04o`000?nDX=coU:3Lo`0000?oU:3L
00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo
0_l00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001?oooooo0000o`000?l0000:oooo
o`?o000000?oooooo`000?ooool02?ooool2o`000004ooooool0003o0000o`0000?ooooo00?o0000
ooooool000000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooool000001Oooool3
o`0004Sooooo000Rooooo`03o`000?oooooooooo02kooooo0ol00004ojVmj004o`000?nY_NSoZKgX
ojVmj0?o00000onY_NP4o`0000?oZKgX0ol00005ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo0_l00000
0on^foOo0000ok3Hm005ok3Hm0?o00001_o4dnH01?l0003o`l_Pol?;h?l00003olo<eP03o`000?o=
`LoocL7?00CocL7?0_l00007ol^hb0;o00001_o;//400ol0003ob:foo`000006ol:U_0;o00001oni
Wkh01?l0003o]io0okNO`?l00003okJP`P03o`000?nbVl7o/Y_100Co/Y_100?o0000ojVGa?l00000
0_l000000onWU<;o0000oin?``05oin?``03o`000?nFRLCoUXW400?oUXW400?o0000oi28a_n@R<H0
0on@R<H00ol0003oR8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00Co0000oh><don3S=?o
PhcC1ol000000on1S=Go0000ohVFfP04ohVFfP04o`000?nDX=coU:3LoiBPg0Go00001?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`05o`000?oooooooooo
o`000?ooool01_l0000<ooooo`Go00001?ooool01?l0003oooooooooooooool2o`000004ooooool0
003o0000o`0000;ooooo00?o0000ooooool000000_l00002ooooo`;o00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000001oooool00ol0003oooooooooo`15ooooo`008oooool00ol0003o
ooooooooo`0^ooooo`03o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj006o`000?nY_NSoZKgXojVm
j?l0003oZKgX1?l0001?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`08ooooo`;o00001?n`f?@2o`0000?o/M7a00Co0000olCCi_o4dnKoa=?V0_l0
0004ol?;h003o`000?o?c=Ko000000KocL7?00?o0000olRkc_l000001_o;^<P01?l0003obKC5olVd
aOl00004ol^b`@05o`000?o8[Koob:foolR]_ol000001?o2YK`01?l0003o_Z>nokjS__l00006okVO
_P03o`000?ngWl3o000000Co]Z3200?o0000ok:K`OnbVl401?nbVl42o`0000GoYiC200?o0000oin?
`onOSl<00onOSl<00ol0003oUXW4oiJ9a003oiJ9a003o`000?n@R<KoT8S600?oT8S600?o0000ohR5
bOn8QLT00on8QLT00ol0003oPhK>oh>6cP03oh>6cP03o`000?n3S=?oPhcC00?oPhcC00?o0000ohNC
fOn7TmT00_n7TmT<o`0000?oUjCN00?o0000ooooooooool00_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04o`00
0003ooooool0003ooooo00_ooooo00?o0000ooooool000000_l00004ooooo`05o`000?oooooooooo
ooooool000000_ooool3o`0000;ooooo00?o0000ooooool000000ol000001?oooooo0000o`000?l0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`14ooooo`009?ooool2o`0002oooooo00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSo
ZKgX00?oZKgX00?o0000ojVmj?l000000_l0001Dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0<oooool2o`0000[ooooo0_l000000on`f?Co0000ok7Al@05ok7Al@03o`000?o4dnKo
000000Ko`l_P0ol00005olg1c`05o`000?o8^lkob;_>olRkc_l000001?o;^<P00ol0003obKC5olVd
a@02olVda@04o`000?o;//7obk;1o`0000Cob:fo00Go0000ol:U_?o2YKco`ZFlo`000003okjS_P03
o`000?niWkko^Inn00Co^Inn0_l00006okJP`P03o`000?nbVl7o/Y_100;o/Y_100?o0000ok:L`Ol0
00001OnWU<800ol0003oWho3oin?``03oin?``03o`000?nFRLCoUXW400CoUXW400?o0000oi28a_n@
R<H00on@R<H00ol0003oR8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00?o0000oh><don3
S=<00on3S=<00ol0003oQi?IohNCf@03ohNCf@03o`000?n>W=coSYcL00?oSYcL00Go0000oiNTg_nG
Y=koUjCNo`000003oiNTgP05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`000004o`0000cooooo00?o0000
ooooool000000ol00003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04_ooooo000Vooooo`03o`000?oooooooooo02gooooo00?o0000ojVmj?nY_NP01?nY_NP0
1?l0003oZKgXojVmj?nY_NP3o`0005Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Wooooo0_l00006ok7Al@?o00001?o3bn02o`0000?o`/;J00Go
0000olg1coo=`LoocL7?o`000005olRkcP04o`000?o;^<SobkS8o`0000GobKC500?o0000ol^b`Ol0
00001_o8[Kl00ol0003o`ZFlo`000005okjS_P03o`000?niWkko^Inn00;o^Inn00?o0000ok^S`Ol0
00001_nfX<800ol0003o/Y_1ok:K`@02o`0000?o/Yc100?o0000ojND`_nWU<800_nWU<800ol0003o
Who3oin?``04oin?``03o`000?nFRLCoUXW400?oUXW400?o0000oi28a_n@R<H00on@R<H00ol0003o
R8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00?o0000oh><don3S=<00on3S=<00ol0003o
Qi?IohNCf@04ohNCf@03o`000?n>W=coSYcL00?oSYcL00Go0000oiNTg_nGY=koUjCNo`000002oiNT
gP05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0Yooooo`?o000000?ooooo
o`000?l000000ol0000<ooooo`03o`000?oooooo000000;ooooo0_l00004ooooo`05o`000?oooooo
ooooooooool000000oooool3o`000004ooooool0003o0000ooooo`?o00000_ooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo053ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o
0000ojVmj?nY_NP00onY_NP4o`0005cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00[ooooo0_l000001?nadO7o0000o`000?l00003ok79k0;o0000
00?o`l_Po`000?o2`]X01Oo2`]X00ol0003ocL7?o`000006olRkcP03o`000?o;^<So000000KobKC5
0_l00008olR]_`03o`000?nnXkko_Z>n00Co_Z>n00?o0000okVO__niWkh00_l00003ok^S`@03o`00
0?nfX<;o]Z3200?o]Z3200?o0000ok:K`Ol000001OnbW<400ol0003oYiC2ojND`P03ojND`P03o`00
0?nOSl?oWho300?oWho300?o0000oiJ9a?nFRL@00onFRL@00ol0003oT8S6oi28aP03oi28aP03o`00
0?n8QLWoR8G900?oR8G900?o0000oh>6c_n3Q/h00on3Q/h00ol0003oPhcCoh><d`04oh><d`03o`00
0?n7TmWoQi?I00?oQi?I00?o0000ohjLg?n>W=`01?n>W=`01ol0003oUjCNoiNTg_nGY=ko0000oiNT
g_l000001?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02[ooooo00Go0000oooo
ool0003o0000ooooo`03o`00013ooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo0_l0
0003ooooo`?o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0001Fooooo`00:?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?nY_NSo000000;o0000H?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003o/LW/ok79k005
ok79k0;o00001oo2`]X2o`0000Oob;_>0_l00006olVda@03o`000?o6/<Go000000Oob:fo0_l00006
okjS_P03o`000?niWkko000000Go^j?100?o0000okJP`_nfX<800onfX<82o`0000Ko/Yc100?o0000
ojND`_nWU<800onWU<800ol0003oWho3oin?``03oin?``04o`000?nFRLCoUXW4oiJ9a1?o00000_n3
Q/h00ol0003oPhcCoh><d`03oh><d`03o`000?n7TmWoQi?I00?oQi?I00?o0000ohjLg?n>W=`01?n>
W=`01?l0003oUjCNoiNTg_nGY=h4o`0000?ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Yooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool04?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000?ooooo00Co0000
oooooooooooooooo0ol00002ooooo`;o0000EOooool002Wooooo0_l0000^ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`;o00003?ooool0
0ol0003o/LW/ok79k002ok79k0;o000000?o/L7Vo`000?o2`]X01Oo2`]X00ol0003o_[_Go`000006
olRkcP03o`000?o4]/go000000GobKC500Go0000olJ`aOo6/<Goa[35o`000005olR]_`04o`000?o2
Z/7o`Z[1o`0000Ko_Z>n00?o0000ok^S`OnkXl401OnkXl400ol0003o]Z32okJP`P02o`000003ok:M
`_l0003o/Yc100Ko/Yc100?o0000ojND`_nWU<800_nWU<801?l0003oWho3oin?`onOSl<6o`0000?o
VI?<00?o0000oi>AconCTLl00onCTLl00ol0003oSI3Bohf@dP03ohf@dP04o`000?n9T]KoRI;FohVB
eQWo000000CoVJWRo`000?nIZN;o00000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Sooooo00Oo0000ooooooooooooooooo`000?oooooo000001;ooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00Co00000_ooool01?l0003oooooo`000?ooool2o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo05;ooooo000[ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02_ooool01?l0003o/LW/o`000?l00004ok71iP04o`000?o2`][o`/;Jol;2
fP;o00000onn^mL01?l0003ob;_>olRkc_o8^lh2o`0000?oa;K=00Go0000olVdaOo9]<GobKC5o`00
0004olJ`a@03o`000?o8[Koob:fo00;ob:fo00Go0000ol:Z`Oo2Z/7o`Z[1o`000005okjS_P;o0000
1onkXl400ol0003o]Z32o`000004ok:M`P03o`000?nbW<7o/Yc100Co/Yc100?o0000ojND`_nWU<80
0_nWU<84o`0000?oWYC900?o0000oiVCc?nITl`01?nITl`00ol0003oTi7?oi>Ac`03oi>Ac`03o`00
0?n=T=;oSI3B00?oSI3B00?o0000ohVBe_n9T]H00_n9T]H00ol0003oRIKJohVFfP04ohVFfP03o`00
0?n<W=goS9cM00?oS9cM00?o0000oi:Sh?nBXn001?nBXn000ol0003oVJWRoiVYhP02oiVYhP03o`00
0?nIZN;o000000;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`07o`00
0?ooooooooooooooool0003oooooo`00000Dooooo`?o00000_ooool2o`000003ooooool0003o0000
00?o00000_ooool3o`000004ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
06Cooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo00[ooooo0_l00006
ok71iP03o`000?o2`][o000000Ko_[_G00?o0000olRkc_l000001_o4]/d00ol0003obKC5o`000006
olJ`a@04o`000?o8[Koob:foo`0000Go`Z[100Go0000okjS__nnXkko_Z>no`000002okjW`P03o`00
0?nkXl7o^j?100Co^j?10_l00005ok:M`P03o`000?nbW<7o/Yc100Co/Yc100?o0000ojND`_l00000
0_l000000onYV/Oo0000oijDb@05oijDb@03o`000?nITlcoVI?<00?oVI?<00?o0000oi>AconCTLl0
0onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X0
1?n9U]X00ol0003oS9cMohbLg@03ohbLg@03o`000?nBXn3oTZ?P00CoTZ?P00?o0000oiVYh_nIZN80
0_nIZN801Ol0003oVJWRo`000?oooooo000003Sooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooool0003o0000ooooo`02o`00
00?ooooo0ol00003ooooo`?o000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`1G
ooooo`00;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00?o0000ok71i_na`NH00ona`NH2
o`0000Oo_[_G0_l00008olBfc@03o`000?o6/<Goa[3500Goa[3500?o0000olR]_ol000001_o2Z/40
1?l0003o_Z>nokjS__l00003okjW`P03o`000?nkXl7o^j?100?o^j?100?o0000okbV`ol000001_nb
WL800ol0003o/Yc1ok:L`@03ok:L`@;o00001OnYV/L00ol0003oWYC9oijDb@03oijDb@03o`000?nI
TlcoVI?<00CoVI?<00?o0000oi>AconCTLl00onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9
T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X00on9U]X00ol0003oS9cMohbLg@04ohbLg@03o`000?nB
Xn3oTZ?P00?oTZ?P00?o0000oiVYh_nIZN800_nIZN85o`0003Sooooo00?o0000ooooooooool0@_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo0ol000001ooooooo0000ooooool0003ooooo
o`000?ooool00ol00004ooooo`03o`000?oooooooooo05Oooooo000^ooooo`;o0000:Oooool00ol0
003oooooooooo`1Uooooo`04o`000?ooooooooooo`0003kooooo0_l0000<ooooo`03o`000?na`NKo
000000;o00000_n_^N400ol0003o_[_Gokjke`03okjke`03o`000?nk]]Go000000Ooa;K=0_l00007
olJ`a@;o00001oo2Z/400ol0003o_Z>no`000005okjW`P05o`000?nkXl7o^j?1ok^S`Ol000000onl
Y/<00ol0003o/Yg2ok:M`P03ok:M`P04o`000?nbW<7o/Yc1ok:L`@;o000000?o/J77o`000?nYV/L0
1?nYV/L00ol0003oWYC9oijDb@04oijDb@03o`000?nITlcoVI?<00?oVI?<00?o0000oi>AconCTLl0
0onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X0
0on9U]X00ol0003oS9cMohbLg@04ohbLg@04o`000?nBXn3oTZ?Poi:Sh0Oo000000?oV[3Vo`000?nJ
/>H00_l0000hooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00_l00003ooooo`Co
000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0E_ooool0033ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooo0000043ooooo00?o0000ooooooooool02_ooool00ol0003o[kWQojnih@04ojnih@05
o`000?nn^mOo_[_Gokjkeol000000onk]]D00ol0003oa;K=olBfc@03olBfc@04o`000?o0//co`;;<
o`0000Goa[3500?o0000ol:^aol000001oo2Z/42o`0000Ko_ZO200Co0000ok^S`OnkXl7o00001?nl
Y/<00ol0003o/Yg2ok:M`P03ok:M`P04o`000?nbW<7o0000o`0000Co/J7700?o0000ojVJaonYV/L0
0onYV/L00ol0003oWYC9oijDb@03oijDb@04o`000?nITlcoVI?<oiVCc2Go00000onDZnH00ol0003o
V[3VoiZ`iP03oiZ`iP03o`000?nJ/>Ko000003Sooooo00?o0000ooooooooool0@Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo1ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0EOooool0037ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool02Oooool00ol0
003o[kWQojnih@05ojnih@03o`000?nn^mOo000000Go^kKE00Go0000olBfcOo4]/goa;K=o`000004
ol2bc003o`000?o6/<Goa[3500;o00000oo2[/L00ol0003o`Z[1ol:Z`@03ol:Z`@03o`000?noZlKo
000000Ko_ZO200?o0000ok^S`Ol000001_nlY/<00ol0003o/Yg2ok:M`P02ok:M`P;o00001_naXLL0
0ol0003oZI[7ojVJa`03ojVJa`04o`000?nNU<WoWYC9oijDb@Ko00000onKWmL00ol0003oUIkIoiFN
f@03oiFNf@03o`000?n@WMcoT9gL00?oT9gL00?o0000ohfNgon=W]l00on=W]l00ol0003oS:7RohbQ
hP03ohbQhP03o`000?n?YNCoSjGT00CoSjGT00?o0000oiB[i_nDZnH01?nDZnH00ol0003oV[3VoiZ`
iP02oiZ`iP04o`000?nJ/>Ko0000o`0003Oooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`03ooooo`;o000000?oooooo`000?l000000oooool6o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool0G?ooool003;ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool02Oooool00ol0003o[kWQojni
h@04ojnih@;o00001onk]]D00ol0003oa;K=o`000005ol2bc003o`000?o6/<Go000000Ko`Zk700?o
0000ol:Z`Oo2Z/400_l00003okn[aP03o`000?nnYl;o_ZO200?o_ZO20_l00007okbV``03o`000?nb
WL;o/Yg200;o000000?o]:C8o`000?naXLL01_naXLL00ol0003oZI[7ojVJa`02ojVJa`Co00000onR
X]@00ol0003oVioGoi^Oe`04oi^Oe`03o`000?nEW]WoUIkI00?oUIkI00?o0000oi2Mg?n@WM`00on@
WM`00ol0003oSIkOohfNg`03ohfNg`03o`000?n<XN;oS:7R00?oS:7R00?o0000ohnUi?n?YN@01?n?
YN@00ol0003oU:_VoiB[iP04oiB[iP04o`000?nJ/>KoV[3VoiZ`iPCo00007_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`0looooo`;o00001_ooool4o`0000;ooooo00?o0000ooooool000000_ooool6o`00
00;ooooo00?o0000ooooooooool0G?ooool003?ooooo0_l0000Tooooo`03o`000?oooooooooo06So
oooo0_l00012ooooo`;o00002_ooool00ol0003o[kWQojnih@03o`000003ojfcgOl0003o^kKE00Ko
^kKE0_l00006ol2bc0;o00001oo2[/L00ol0003o`Z[1o`000005okn[aP03o`000?nnYl;o_ZO200;o
_ZO200?o0000okfZa_l000001onlY/<00ol0003o/Yg2o`000004okBTb003o`000?naXLOo/J7700Co
/J7700?o0000ojVJaol000000_l000000onZY]?o0000oj:Re005oj:Re003o`000?nKWmOoVioG00Co
VioG00?o0000oiFNfOnEW]T00onEW]T00ol0003oT9gLoi2Mg003oi2Mg003o`000?n=W]ooSIkO00?o
SIkO00?o0000ohbQh_n<XN800on<XN800ol0003oSjGTohnUi003ohnUi003o`000?nDZnKoU:_V00;o
U:_V1_l00002ooooo`;o00007_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401?ooool00ol0003oooooooooo`0kooooo`;o00001_ooool5
o`0000;ooooo00?o0000ooooool000000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000
ooooooooool0Foooool003Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Xoooo
o`?o0000A?ooool00ol0003oooooooooo`08ooooo`;o00001On]/md00ol0003o^kKEok^fe@02ok^f
e@;o000000?o^;;Co`000?o0//`01?o0//`00ol0003o_K3=o`000007ol:^a`;o00001onoZlH01?l0
003o_ZO2okjW`_l00003okfZaP03o`000?nlY/?o_:K300Co_:K30_l00005okBTb003o`000?naXLOo
/J7700Co/J770_l00005ojZVd`03o`000?nRX]CoXZ;D00CoXZ;D00?o0000oi^OeonKWmL00onKWmL0
0ol0003oUIkIoiFNf@03oiFNf@04o`000?n@WMcoT9gLoi2Mg1Wo00001oooool3o`0001kooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001?ooool2o`0003co
oooo0_l00006ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000003ooooo`04
o`000?ooooooooooo`0006;ooooo000fooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0I?ooool4o`0004Sooooo00?o0000ooooooooool02?ooool00ol0003o[K?Mojfcg@04ojfcg@04
o`000?nk]]Go0000o`0000Co^;;C00Go0000ol2bc?o0//co`;;<o`000003okf`c@03o`000?o2[/Oo
`Zk700?o`Zk700?o0000okj^bol000001onoZlH00ol0003o_ZO2o`000004okfZaP03o`000?nlY/?o
_:K300?o_:K300?o0000okZ[b_l000001_ndY<P01?l0003o/J77ok6QaonaXLL2o`000003ok6[d_l0
003oZZKC00GoZZKC00?o0000oj:Re?nRX]@00onRX]@01?l0003oVioGoi^OeonKWmL<o`0001cooooo
1?l0000Qooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool0HOooool003Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Pooooo`Co0000COooool00ol0003o
ooooooooo`08ooooo`03o`000?n]/mgo[K?M00?o[K?M0_l00007okRbd`03o`000?o0//co000000Go
_K3=00Go0000ol:^aoo2[/Oo`Zk7o`000003okj^b`03o`000?noZlKo_j_600Co_j_60_l00006okfZ
aP03o`000?nlY/?o_:K300;o00000onjZlX00ol0003o]:C8okBTb003okBTb004o`000?naXLOo0000
o`0000Co/J_B00?o0000ojZVdonZY]<00onZY]<01?l0003oXZ;Doj:Re?nRX]@6o`0002Cooooo1?l0
000Uooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo0000oooo
ool000002Oooool2o`0000;ooooo00?o0000ooooooooool0Goooool003Sooooo0_l0000Nooooo`03
o`000?oooooooooo05cooooo1?l0001Booooo`;o00002Oooool00ol0003o[K?Mo`000002o`000003
ojb_f_l0003o^;;C00Ko^;;C0_l00007okf`c@03o`000?o2[/Oo000000Co_Zk;00?o0000okn[a_no
ZlH00onoZlH00ol0003o_Jk;o`000006okfZaP03o`000?nlY/?o000000Go^Z_:00?o0000okBTb?nd
Y<P00ondY<P2o`0000Ko/J_B00?o0000ojZVdonZY]<00onZY]<4o`0002Kooooo1?l0000Yooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000[ooooo00Co0000
oooooooooooo0000HOooool003[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1H
ooooo`Co0000F?ooool00ol0003oooooooooo`07ooooo`03o`000?n/[m[o[:oJ00?o[:oJ00?o0000
okRbdonh/]<00_nh/]<2o`000003okF`e?l0003o_K3=00Ko_K3=0_l00006okj^b`03o`000?noZlKo
_j_600;o00000onm[//00ol0003o_J[6okfZaP03okfZaP;o00001onjZlX00ol0003o]:C8okBTb002
o`000003okF^d_l0003o/J_B00Go/J_B00?o0000ojZVdonZY]<00ol0000Vooooo`Co0000;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`1Rooooo`00>ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Cooooo1?l0001Mooooo`03o`000?oo
oooooooo00Kooooo00?o0000ojb_f_n/[mX01?n/[mX01?l0003o^;;Co`000?l00004okF`e003o`00
0?nm/<go_K3=00?o_K3=00?o0000okZ`d?l000001_nn[//00ol0003o_j_6o`000006okf^b`03o`00
0?nmZ/Ko_J[600;o000000?o^jo=o`000?njZlX01_njZlX00ol0003o]:C8o`000004okF^dP03o`00
0?naZm;o/J_B00?o/J_B0ol0000Vooooo`?o0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0K_ooool003cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`Co
0000H_ooool00ol0003oooooooooo`06ooooo`03o`000?n/[m[o[:oJ00?o[:oJ0_l00007okF`e003
o`000?nm/<go_K3=00;o00000onj/=000ol0003o_Zk;okj^b`03okj^b`;o00001onm[//00ol0003o
_J[6o`000004ok^_c@03o`000?njZl[o^Z_:00Co^Z_:0_l00006okF^dP03o`000?naZm;o000000;o
00009Oooool4o`0004gooooo00?o0000ooooooooool0]_ooool003gooooo0_l0000Iooooo`03o`00
0?oooooooooo04gooooo0ol0001Wooooo`;o00001oooool00ol0003o[:oJo`000002o`0000;oZjkJ
00?o0000okF`e?ne/=@01?ne/=@00ol0003o_K3=o`000006okZ`d003o`000?nn[/_o_Zk;00;o0000
00?o^k3?o`000?nm[//01_nm[//2o`0000Ko^jo=00Co0000okZ[b_njZl[o^Z_:0_l000000oni/]?o
0000okF^dP05okF^dP;o00009?ooool4o`00057ooooo00?o0000ooooooooool0]_ooool003oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`19ooooo`Co0000K?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?n[[][oZjkJ00CoZjkJ00?o0000okF`e?ne/=@00one/=@2o`0000Oo^[3@
00?o0000okj^bol000001?nk/<l00ol0003o_Jk;okf^b`03okf^b`03o`000?nk/]3o000000Ko^jo=
00Co0000okZ[b_l0003o00001?ni/]<01?l0003o]JkBokF^d_ne[]82o`0002;ooooo1?l0001Eoooo
o`03o`000?oooooooooo0;Kooooo0010ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0AOooool4o`00077ooooo00?o0000ooooooooool01?ooool00ol0003oZjkJoj^^fP05oj^^fP03
o`000?ne/=Co000000;o000000?o/k3Eo`000?nj/=001_nj/=02o`0000Ko^k3?00?o0000okf^bonm
[//00_l00003ok^bd003o`000?nk[lgo^jo=00?o^jo=0_l00006okVbd`04o`000?ne[];o0000o`00
023ooooo1?l0001Iooooo`03o`000?oooooooooo0;Kooooo0011ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@Oooool4o`0007Kooooo00?o0000ooooooooool01?ooool00ol0003o
ZjkJoj^^fP04oj^^fP;o00001Onc/=D00ol0003o^[3@okZ`d002okZ`d0;o000000?o^;;Co`000?nk
/<l01Onk/<l00ol0003o_Jk;o`000006ok^bd003o`000?nk[lgo^jo=00;o000000?o^kKDo`000?ni
/]<01Oni/]<2o`0001kooooo1?l0001Mooooo`03o`000?oooooooooo0;Kooooo0012ooooo`;o0000
5?ooool00ol0003oooooooooo`0mooooo`Co0000Noooool2o`0000Gooooo00?o0000oj^^f_n[[]X0
0ol000000onZ[][o0000ok>`e@05ok>`e@04o`000?nj/=3o0000o`0000Co^;;C00?o0000ok^`conk
/<l00onk/<l2o`0000Oo^k;@00?o0000ok^_cOl000001?nk]]@01?l0003o^K;CokVbdoni/]<2o`00
01cooooo1?l0001Qooooo`03o`000?oooooooooo0;Kooooo0014ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0>Oooool4o`00087ooooo00?o0000ooooooooool00oooool2o`0000Go
ZZkJ00?o0000ok>`eOnc/=D00onc/=D2o`0000Oo^;;C00?o0000ok^`conk/<l00_l000000onj]=Co
0000ok^bd006ok^bd0;o00001_nk]]@00ol0003o^K;Co`00000Jooooo`Co0000IOooool00ol0003o
ooooooooo`2fooooo`00AOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo
1?l00026ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZ^f_nZ[]X01?nZ[]X00ol0003o/k3E
ok>`e@02o`000003ok:bf?l0003o^;;C00Ko^;;C00?o0000ok^`col000001?nj]=@00ol0003o^k;@
ok^bd002ok^bd0;o000000?o^kSGo`000?nk]]@01Onk]]@2o`0001Oooooo1?l0001Yooooo`03o`00
0?oooooooooo0;Kooooo0016ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Ooo
ool4o`0008_ooooo00?o0000ooooooooool00oooool00ol0003oZZkJojZ^fP03ojZ^fP03o`000?nc
/=Go000000Co/[;H00?o0000okRbdonh/]<01?nh/]<2o`0000Ko^[CD00Co0000ok^bd?l0003o0000
1?nk^=L01?l0003o^kKDok^fe?nk]]@2o`0001Kooooo0ol0001]ooooo`03o`000?oooooooooo0;Ko
oooo0017ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool4o`00093ooooo
00?o0000ooooooooool00oooool01?l0003oZZkJojZ^f_nZ[]X3o`0000Ko/[;H00?o0000okRbdonh
/]<00ol000000onf]MSo0000okZde005okZde0;o00001onk^=L00ol0003o^kKDo`00000Dooooo`Co
0000L?ooool00ol0003oooooooooo`2fooooo`00B?ooool2o`0000kooooo00?o0000ooooooooool0
:Oooool4o`0009Gooooo0_l00004ooooo`?o00000_nY/=`00ol0003o/[;Hok:bf004ok:bf0?o0000
1Onf]MP01?l0003o^[CDokZde?nj]=@2o`000003okVjf_l0003o^kSG00Ko^kSG0_l0000Aooooo`Co
0000M?ooool00ol0003oooooooooo`2fooooo`00B_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Gooooo1?l0002Kooooo`05o`000?ooooooooooooooool000001OnY/=`01?l0003o
/[;Hok:bf?nb/]P2o`000003ok6eg?l0003o][GH00Ko][GH00?o0000okZde?l000001?ni^]X00ol0
003o^kSGok^he`02ok^he`;o00003oooool4o`0007Sooooo00?o0000ooooooooool0]_ooool004_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`Co0000X?ooool01Ol0003o
oooooooooooooooo000000GoZK3L00?o0000ok:bf?l000001?na]M`00ol0003o][GHokJef004okJe
f0;o00001_ni^]X01?l0003o^kSGo`000?l0000=ooooo`Co0000O?ooool00ol0003oooooooooo`2f
ooooo`00C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Uoooo
o`05o`000?ooooooooooooooool000000onY/=`3o`0000Ko/KGL00?o0000okJef?nf]MP00ol00002
okFjg@03o`000?ni^][o^K[J00?o^K[J0_l0000;ooooo`Co0000P?ooool00ol0003oooooooooo`2f
ooooo`00COooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:[ooooo0_l00002oooo
o`?o00000onY/ml00ol0003o/KGLok6eg003ok6eg0?o00001_ne^]d00ol0003o^K[Jo`000002o`00
00Wooooo1?l00024ooooo`03o`000?oooooooooo0;Kooooo001?ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05oooool3o`000;3ooooo00?o0000ooooool000001_nY/ml00ol0003o
/KGLo`000002o`000003ok2jhOl0003o]K[M00Ko]K[M0_l00008ooooo`Co0000R?ooool00ol0003o
ooooooooo`2fooooo`00D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo
1?l0002dooooo`03o`000?oooooo000000GoZK?O0_l00005ok2jh@03o`000?ne^]go]K[M00;o]K[M
0_l00006ooooo`Co0000S?ooool00ol0003oooooooooo`2fooooo`00DOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo1?l0002iooooo`04o`000?oooooo0000ojVcg`?o0000
0_nY^>@00ol0003o/;[Qok2jh@03ok2jh@04o`000?ne^]go0000o`0000Gooooo0ol0002@ooooo`03
o`000?oooooooooo0;Kooooo001Booooo`;o00000oooool00ol0003oooooooooo`0;ooooo`Co0000
__ooool3o`0000KoZKST00Co0000ok2jhOn`^^7o/;[Q0ol00003ooooo`Co0000Toooool00ol0003o
ooooooooo`2fooooo`00E?ooool01?l0003oooooooooool00009ooooo`Co0000a?ooool2o`0000Go
ZKST1?l00002ooooo`Co0000Uoooool00ol0003oooooooooo`2fooooo`00EOooool00ol0003ooooo
o`000005ooooo`Co0000bOooool2o`000004ojVhi?l0003o0000o`0000;ooooo1?l0002Kooooo`03
o`000?oooooooooo0;Kooooo001Fooooo`;o000000?oooooo`000?l000000_l0003>ooooo`;o0000
00?oooooo`000?l000000_l0002Oooooo`03o`000?oooooooooo0;Kooooo001Gooooo`;o0000dooo
ool2o`0009_ooooo1?l000001Ol@413ooooooooooooooooo00000;Sooooo003oooooolcooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2fooooo`00ooooooo<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0]_ooool00?ooooooc?ooool00ol0003oooooooooo`03oooo
o`;o0000]oooool006kooooo0_l0003ooooooecooooo00?o0000ooooooooool0_?ooool0073ooooo
00?o0000ooooooooool0d?ooool2o`0008Kooooo00?o0000ooooooooool0_?ooool005oooooo00?o
0000omgMgOooool01_ooool3o`0000Gooooo00?o0000ooooooooool0a?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0_?ooool005oooooo00?o<S8b
okZj^_ooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Cooooo00?o410@
omgMgOooool00_ooool3o`0000Kooooo00?o0000ooooooooool0POooool00omEEEGoIVIVo`00002n
ooooo`00Goooool01_mgMgOoQhN7odA4A?l0003o410@ohN7Q`Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`32ooooo`05olc<c?l@413o0000o`000?n7QhL00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08Gooooo0ol000000ol@413oooooooooo`2gooooo`00Gooo
ool01onYZJWo0000okZj^_oooooogMgMob4Q8On7QhL00_ooool2o`0000Cooooo0ol00034ooooo`06
ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN70_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08Oooooo00?o410@okZj^_ooool0^?ooool005oooooo00?ogMgMoa0@4?ooool00_ooool00ooM
gMgo410@ooooo`3>ooooo`07o`000?ooooooIVIVohN7QooMgMgo410@ooooo`02o`0000Gooooo0ol0
0029ooooo`03oiRHV?lb<S;ooooo0;Sooooo001Pooooo`03oa0@4?oMgMgooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0<;ooooo00Ko410@omgMgOmgMgOoMgMg
ooooool0002Dooooo`03omgMgOl0003o^[Zj0;Sooooo001Pooooo`06ohN7QolQ8B7ogMgMoooooomg
MgOo<S8bcoooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`27ooooo`03oeEEEOmgMgOoA4A40;Sooooo001Qooooo`05ogMgMol0003o
0000oc8b<_o<c<`0d?ooool01OnHV9So0000o`000?l@413oc<c<09?ooooo00GogMgMoa0@4?oooooo
8B4QomgMg@2gooooo`00oooooolhooooo`03okZj^_lb<S;ooooo09Cooooo00GoIVIVohN7Qooooooo
V9RHoeEEE@2gooooo`00ooooooliooooo`03o`000?oooooooooo09;ooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`2eooooo`00ooooooo>ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool0]?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooo
ooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?oo
ool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooo
oooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<oooo
o`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00oooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooo
oon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00
ooooooooooooohcooooo003ooooooa7ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<01?ooooo1?l000000ol@413oooooooooo`3`ooooo`00oooo
oolAooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B402Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B405Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0:ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`00000Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B402Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Sooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`02Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c00Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41005Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000005Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<
c?m4A4Co0000oa0@40Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT04oooool00omEEEGoIVIVo`00003dooooo`00oooooonMooooo`;o00000_ooool2o`00
0>Sooooo003ooooooigooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMgXooooo`00oooooonNoooo
o`04omgMgOl0003o410@olc<c>Wooooo003loooooi[o00001oooool01?o^k^ko8B4Qoa0@4?o^k^kY
ooooo`00o?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool01?lQ8B7oMgMgogMgMolb<S;Yooooo`00o?ooool00ol0003oooooooooo`2Moooo
o`;o00000_ooool2o`000>Sooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo
00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgooooo003looooo`03
o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?oo
ool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool0
0?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<oooo
o`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?oooooo
S?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgo
oooo003looooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0oooooom3ooooo`00o?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0?oooooo?_ooool00?cooooo00?o0000
ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0oooooom1ooooo`00hoooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolcooooo`00hoooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0003Wooooo00?o0000
ooooooooool0oooooomAooooo`00hoooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01?ooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`000?ooooooFOoo
ool00>?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o
0000ooooooooool0oooooon<ooooo`00hoooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo8oooool00>?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo003looooo`03o`000?oooooooooo02kooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`000?oooooo<?ooool00?cooooo
00?o0000ooooooooool0oooooon<ooooo`00o?ooool2o`00067ooooo00Co0000oooooooooooo0000
oooooolXooooo`00o?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0ooooooldooooo`00o?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0?ooooooC_ooool00?cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>oooo
o`04o`000?ooooooooooo`000?ooooooBoooool00?cooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`3ooooooc7ooooo003looooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo00000?oooooo:_ooool00?cooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooolSooooo`00o?ooool2o`00033ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`3ooooooc_ooooo003looooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool0ooooooljooooo`00o?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0?oooooo9_ooool0
0?cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`3oooooockooooo003looooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0oooooolXooooo`00o?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0oooooolHooooo`00o?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0?oooooo?Oooool00?cooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0Fooooo`;o00003?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0?oooooo5Oooool00?cooooo0_l00015ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3ooooooa7ooooo003looooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0?oooooo<_ooool00?cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooolPooooo`00o?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo>Oooool00?cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0ooooool?ooooo`00hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooaKooooo003Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool^
ooooo`00hoooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00004ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo0?oooooo=oooool00>?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Gooooo0_l00015ooooo`03o`000?oooooooooo0?ooooooAOooool00>?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Gooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`3oooooobKooooo003Sooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo9Oooool00>?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom<ooooo`00hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`3oooooobOooooo003looooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0oooooolLooooo`00o?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000gooooo00Go
0000ooooooooooooooooo`00003oooooobGooooo003looooo`;o0000:Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolRooooo`00o?ooool0
0ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo00000?oooooo@Oooool00?cooooo00?o0000ooooooooool0BOoo
ool2o`0001Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo00000?oooooo4_ooool00?cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolGooooo`00o?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002_ooool00ol0
003oooooooooo`3oooooob[ooooo003looooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000002cooooo00?o0000oooooooo
ool0ooooool=ooooo`00o?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooo`cooooo003looooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3oooooodgooooo003l
ooooo`;o00007Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool2o`0000Gooooo00Co0000oooooooooooo0000ooooooliooooo`00o?ooool0
0ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo5oooool00?cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0oooooolE
ooooo`00o?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00oooooo0ol0003ooooo
oc?ooooo003looooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0oooooollooooo`00
o?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool0000?ooooo`04o`000?ooooooooooo`000?oooooo:oooool00?co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0?oo
oooo5Oooool00?cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo0000ooooool[ooooo`00o?ooool2o`0004Sooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo00000?oooooo=Oooool00?cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`00003ooooooaGooooo003looooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
7?ooool00?cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`3oooooocGooooo003l
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooooa[ooooo003Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`3ooooooe7ooooo003Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo
>?ooool00>?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001?ooool2o`0002[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc3o
oooo003Sooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`3oooooobCooooo003Sooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`3ooooooaSooooo003Sooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo4oooool0
0>?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo<Oooool0
0>?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Cooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`3oooooofGooooo003looooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo0?oooooo5_ooool00?cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooC_ooool00?cooooo0_l0000eooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3ooooooacooooo003looooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0?oooooo<Oooool00?cooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0oooooolFooooo`00o?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooood_ooooo003loooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0moooo
o`05o`000?ooooooooooooooool00000oooooolNooooo`00o?ooool00ol0003oooooooooo`3ooooo
ohcooooo003looooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo:oooool00?cooooo0_l0000^ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`;o0000
oooooolNooooo`00o?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`3ooooooa[ooooo003looooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0ooooool[ooooo`00o?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ob3ooooo003looooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`3ooooooc_ooooo003looooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0oooooolYooooo`00o?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?oooooo
@Oooool00?cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolWooooo`00o?ooool2o`0002cooooo00?o0000
ooooool000004oooool00ol0003oooooooooo`3oooooodSooooo003looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000ooooool_ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03
o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0oooooolZooooo`00hooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01?ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocKooooo003Sooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`3ooooooc3ooooo003Sooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Cooooo0_l0001<ooooo`;o0000oooo
ooloooooo`00hoooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c004ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0oooooom7ooooo`00hooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0ooooooliooooo`00hoooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooocCooooo003Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00?o0000
ooooooooool0A?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0?oooooo=oooool0
0?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<oooo
o`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?oooooo
S?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooo
oon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo
0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003ooooo
ooooo`3oooooohcooooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000oooooooo
ool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003dooooo`Co000000Go
410@ooooooooooooooooo`00003oooooohkooooo003fooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooon<ooooo`00m_ooool00ol0003oooooooooo`03ooooo`;o0000oooooon=
ooooo`00m_ooool00ol0003oooooooooo`3ooooooi;ooooo003fooooo`03o`000?oooooooooo0?oo
ooooT_ooool00?Kooooo00?o0000ooooooooool0oooooonBooooo`00m_ooool00ol0003ooooooooo
o`3ooooooi;ooooo003dooooo`03oeEEEOmVIVKo00000?ooooooU?ooool00?Sooooo0ol000000ol@
413oooooooooo`3oooooohgooooo003jooooo`03oa0@4?nj^[[ooooo0?ooooooS_ooool00?[ooooo
00?oV9RHoc8b<_ooool0oooooon>ooooo`00n_ooool00ooMgMgo0000okZj^P3oooooohkooooo003j
ooooo`03oeEEEOmgMgOoA4A40?ooooooS_ooool00?Wooooo00GogMgMoa0@4?oooooo8B4QomgMg@3o
ooooohgooooo003iooooo`05ofIVI_n7QhOooooooiRHV?mEEED0oooooon=ooooo`00n?ooool00oo^
k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?ooooooRoooool00?Sooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`3ooooooh[ooooo003oooooooooooooS?ooool00?oooooo
oooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<oooo
o`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00oooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 649.812}, {426.062, 0}} -> {-0.0764092, -0.0492291, \
0.00606487, 0.00606487}, {{15.75, 208.938}, {415.875, 222.688}} -> \
{-0.0826818, -0.0958102, 0.00656167, 0.00656167}, {{228.25, 421.5}, {415.875, \
222.688}} -> {-1.19775, -0.0956182, 0.00655937, 0.00655937}, {{440.812, \
634.062}, {415.875, 222.688}} -> {-3.05005, -0.181531, 0.00819518, \
0.00819518}, {{228.25, 421.5}, {203.312, 10.125}} -> {-1.65646, -1.57512, \
0.00819518, 0.00819518}}],

Cell[TextData[{
  "Fig. 7.10 To determine the force on a collection of particles, shown in \
the top picture, three steps must be carried out (bottom from left to right):\
\n(1) determine the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " on a grid, (2) determine the potential  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  "(and gradients) on the grid,  (3) interpolate forces back to the particle \
positions."
}], "Caption",
  CellTags->"Fig. 7.10"],

Cell[TextData[{
  " \tIn order to move the particles, we use the leapfrog method discussed in \
Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:28"},
    ButtonStyle->"Hyperlink"],
  ". To solve Poisson's equation on the grid, we use the FFT method, which is \
fast and well adapted to periodic boundary conditions. "
}], "Text"],

Cell[TextData[{
  " \tThe more particles we keep, and the finer the grid, the finer the \
resolution of the simulation results. Density variations on a scale smaller \
than the grid will not be picked up.  This is an inherent limitation of grid \
methods: they work only if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is smooth compared to the grid spacing."
}], "Text"],

Cell["\<\
 \tOf course, this means that close interactions between individual \
stars are neglected in the PIC method. Since the density and potential are \
smoothed on the scale of the grid, and since this scale is large compared to \
an average interstellar spacing, the method cannot model the dynamics of \
binary star systems, and also neglects collisional effects such as \
hydrodynamic shocks. \
\>", "Text"],

Cell[TextData[{
  "\tAnother obvious limitation of our PIC method is that periodic boundary \
conditions are often poor approximations to the actual conditions in a \
self-gravitating system. For instance, to model an isolated galaxy, it would \
be more appropriate to impose the condition that the potential vanishes at \
infinity, or at least at some large distance from the galaxy. It is possible \
to modify the PIC method so as to account for such boundary conditions, by \
forgoing the use of the FFT method. In such situations, where a large region \
of the computational domain is empty, a uniform grid is highly inefficient.  \
Much recent progress has been made using time-varying nonuniform grids (",
  StyleBox["adaptive grids",
    FontSlant->"Italic"],
  "), chosen so that the grid is fine where there is rapid variation in the \
potential, and coarse outside of these regions. "
}], "Text",
  CellTags->"i:89"],

Cell[TextData[{
  "\t Recently, ",
  StyleBox["tree codes",
    FontSlant->"Italic"],
  " have also been applied to such problems with great success.  In a tree \
code, the potential is not determined on a grid. Rather, the force on a mass \
point is broken into two parts: one part due to nearby particles is treated \
exactly as a sum of pairwise interactions as in molecular dynamics, and the \
second part due to far-away particles is treated approximately as a multipole \
expansion of the far-away mass distribution.  Although these codes are quite \
complex compared to PIC, their overall efficiency is similar to that of the \
PIC method (",
  ButtonBox["Greengard, 1994",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.3 Leapfrog Method", "Subsubtitle",
  CellTags->{"i:61", "c:30"}],

Cell[TextData[{
  "\tAs discussed in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "i:65"},
    ButtonStyle->"Hyperlink"],
  ", the leapfrog method is a second-order-accurate technique for integrating \
ODEs of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], " ", 
            "=", " ", 
            RowBox[{
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], "/", "m"}]}], ",", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], " ", 
            "=", " ", 
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}]}], TraditionalForm]]],
  ",  where particle positions are evaluated at times ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(t\_n\), " ", "=", " ", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(n = 0\), ",", 
          "1", ",", "2", ",", "..."}], TraditionalForm]]],
  ", and particle momenta are evaluated at the intermediate times ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_\(n + 1/2\)\), "=", 
          RowBox[{\((n + 1/2)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ".  Positions are updated using the centered-difference form of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "/", "m"}]}], TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"], "-", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n - 1\)]}], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], \(n - 1/2\)], "/", "m"}]}]}], 
        TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Momenta are updated using the centered difference form of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n + 1/2\)], "-", " ", 
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n - 1/2\)]}], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", 
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "n"], ")"}]}]}], TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "We will define the initial positions for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "particles as a list ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], "=", 
          " ", \({{x\_1, y\_1}, \ {x\_2, y\_2},  ... , {x\_N, y\_N}}\)}], 
        TraditionalForm]]],
  ". The initial momenta are in a second list, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], 
          "=", \({{p\_\(x\_1\), p\_\(y\_1\)}, \ {p\_\(x\_2\), 
              p\_\(y\_2\)}, \(\(...\)\(.\)\), {p\_\(x\_N\), p\_\(y\_N\)}}\)}],
         TraditionalForm]]],
  ". \n\tAlthough initial conditions are provided for both ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["p",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", the leapfrog method requires the momentum at time step ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "/", "2"}], TraditionalForm]]],
  " in order to begin calculating ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". The momentum ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], TraditionalForm]]],
  "can be found from the initial conditions  using a second-order accurate \
predictor-corrector step:\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], " ", "=", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"], " ", "+", " ", 
              RowBox[{
                FractionBox[
                  SubscriptBox[
                    StyleBox["p",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], "m"], " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "/", "2"}]}]}]}], ",", "\n", 
          
          RowBox[{
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], "=", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"], " ", "+", " ", 
              RowBox[{\(1\/\(2  m\)\), 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"], ")"}], " ", "+", " ", 
                    RowBox[{
                      StyleBox["f",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], \(1/2\)], ")"}]}], ")"}], " ", 
                
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "/", "2."}]}]}]}]}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "The following module then runs the leapfrog method for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " steps. Updated positions and momenta  are placed in lists ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  ",",
  " which have the same structure as ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(leapfrog[r0_, p0_, Nstep_, \[CapitalDelta]t_]\), " ", ":=", 
        " ", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*\ initial\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
            
            RowBox[{\(r[0]\  = \ r0\), ";", 
              "\[IndentingNewLine]", \(p[0]\  = \ p0\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  account\ for\ periodic\ boundary\ conditions\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(md[x_]\  := \ Mod[x, L]\), ";", 
              "\[IndentingNewLine]", \(r[
                  n_]\  := \((\ r[n]\  = Map[md, \ r1[n]])\)\  /; \ n > \ 0\),
               ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              StyleBox[\( (*\ first\ half - step\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(r1[1/2]\  = \ 
                r0\  + \ p0\ \[CapitalDelta]t/\((2\ m)\)\), ";", 
              "\[IndentingNewLine]", \(p[1/2]\  = \ 
                p0\  + \ \(\[CapitalDelta]t\/\(4\ m\)\) \((f[r[0]]\  + \ 
                        f[r[1/2]])\)\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ the\ leapfrog\ method\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(p[
                  n_]\  := \ \((p[n]\  = \ 
                      p[n - 1]\  + \ \[CapitalDelta]t\ f[r[n - 1/2]])\) /; \ 
                  n + 1/2 \[Element] Integers\  && \ n \[GreaterEqual] \ 1\), 
              ";", "\[IndentingNewLine]", \(r1[n_]\  := 
                r[n - 1]\  + \ \[CapitalDelta]t\ p[n - 1/2]/m\  /; 
                  n \[GreaterEqual] \ 1\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  determine\ solution\ up\ to\ time\ step\ Nstep\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(Table[r[n], {n, 1, Nstep}]\), ";"}]}], 
          "]"}]}], ";"}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.66"],

Cell[TextData[{
  "Two details need to be mentioned. First, the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " determines the force on all ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles for given positions, with a structure of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{{f\_\(1\ x\), f\_\(1\ y\)}, {f\_\(2\ x\), \ 
          f\_\(2\ y\)}, \(\(...\)\(.\)\), {f\_\(N\ x\), f\_\(N\ y\)}}\)]],
  ". We will specify this function in the next section. Second, the periodic \
boundary conditions  must be taken into account.  If a particle strays \
outside the box,  it is put back into the box on the other side using the ",
  StyleBox["Mod",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. This function is applied to the entire vector of positions \
using ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Map ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "takes any function ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " and applies it to each element  of  the  vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          StyleBox[\({{x\_1, y\_1},  ... , {x\_N, y\_N}}\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " according to  "
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["Map",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"g", ",", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "=", 
          " ", \({g({x\_1, y\_1}),  ... , g({x\_N, y\_N})}\), " "}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Using ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " we can apply the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function to all of the the particle positions in a single step, without \
needing a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " works only with functions ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " of a single variable, so we write the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function (a function of two variables) in terms of a user-defined function \
",
  StyleBox["md",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a function of a single variable."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.4 Force", "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{

Cell["Mass Density on the Grid", "Section",
  CellTags->"c:32"],

Cell[TextData[{
  "\tIn order to obtain the force field from given particle positions, we \
must first determine the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " on the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " grid. The grid is defined by the following points:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{"i", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2,  ... , M - 1\)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"y", "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}]}], ",", 
          FormBox[\(j = 0, 1, 2,  ... , M - 1\),
            "TraditionalForm"]}], TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], " ", "=", " ", \(L/M\)}]}], 
        TraditionalForm]]],
  ". The points ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = L\)]],
  " are not kept in this grid, because  the periodic boundary conditions \
imply that these points are equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " respectively."
}], "Text"],

Cell[TextData[{
  "Below, we choose values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " for use in some of the following examples. We assume that the particles \
have unit mass:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 20;\)\), "\n", 
    \(\(L = 1;\)\), "\n", 
    \(\(\[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ L/M\);\)\), "\n", 
    \(\(m = 1;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.67"],

Cell[TextData[{
  "\tFor given particle positions we determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " using the technique of area weighting, also known as linear \
interpolation. This is only one of several methods one may use to obtain the \
density, but it is one of the most popular due to its relative simplicity and \
accuracy. For a discussion of other methods, see ",
  ButtonBox["Birdsall and Langdon, (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:88"],

Cell[TextData[{
  "\tA given particle at position ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  " falls inside one cell of the grid, as shown in Fig. ",
  ButtonBox["7.11",
    ButtonData:>"Fig. 7.11",
    ButtonStyle->"Hyperlink"],
  ". The four surrounding grid points are those closest to ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  ",  and are labeled ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((i + 1, j)\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j + 1)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\((i + 1, j + 1)\)\)]],
  ". The correct values of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " can be determine using the ",
  StyleBox["Quotient",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function:"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{"i", "=", 
          RowBox[{
            StyleBox["Quotient",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"x", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ";"}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"j", "=", 
        RowBox[{
          RowBox[{
            StyleBox["Quotient",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"y", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "."}]}], TraditionalForm]}]]], "NE3",
  CellTags->"(7.3.3)"],

Cell[TextData[{
  "However, the points ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\)\(+\)\(1\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1\)]],
  " may actually be at ",
  Cell[BoxData[
      \(TraditionalForm\`i + 1 = M\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1 = M\)]],
  ". Consequently, we use the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function to put these points back inside the correct range of ",
  Cell[BoxData[
      \(TraditionalForm\`i\ and\ j\)]],
  ", and call the results ",
  Cell[BoxData[
      \(TraditionalForm\`i\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\_1\)]]
}], "Text",
  CellTags->"i:59"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(i\_1\), " ", "=", " ", 
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], \(i + 1, M\), 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], ";"}], " "}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{\(j\_1\), " ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], \(j + 1; M\), 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "."}]}], TraditionalForm]}]]], "NE3",
  CellTags->"(7.3.4)"],

Cell[TextData[{
  "\tNow we must increment the density on these four grid points due to the \
presence of the particle. If we call this increment ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Rho]\_\(i\ j\)\)]],
  ",",
  " then we require that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Sum]\+\(i, j\)\), 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["A",
                    FontSlant->"Italic"]}]], 
              " ", \(\[CapitalDelta]\[Rho]\_\(i\ j\)\)}]}], " ", "=", " ", 
          "m"}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.5)"],

Cell[TextData[{
  "where the sum is over all points on the grid, and where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]], "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " is the area of a cell.  One way to satisfy Eq. ",
  ButtonBox["(7.3.5)",
    ButtonData:>{"Chapter7.nb", "(7.3.5)"},
    ButtonStyle->"Hyperlink"],
  "  would be to weight equally each of the four grid points surrounding the \
particle : ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\)\), " ", "=", " ", 
          RowBox[{"m", "/", 
            RowBox[{"(", 
              RowBox[{"4", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["A",
                      FontSlant->"Italic"]}]]}], 
              StyleBox[")",
                FontSlant->"Italic"]}]}]}], TraditionalForm]]],
  " for the four surrounding grid points, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Rho]\_\(i\ j\) = 0\)]],
  " for the other points.   However, this equal weighting is crude. What if \
the particle is very close to one of the grid points? This grid point should \
then get the lion's share of the particle's mass."
}], "Text"],

Cell[TextData[{
  "\tIn area weighting,  that portion of the mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " that is assigned to each of the four grid points  depends on the distance \
of the particle to the points. For instance, if the particle is right at the \
center of the cell, all four surrounding grid points get ",
  Cell[BoxData[
      \(TraditionalForm\`m/4\)]],
  ". However, if the particle is closest to the point ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " as shown in Fig. ",
  ButtonBox["7.11",
    ButtonData:>"Fig. 7.11",
    ButtonStyle->"Hyperlink"],
  ", this grid point is given more of the particles mass than the other \
points, according to the following prescription: break the cell into four \
rectangles as shown, each with a vertex at ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  ". Call the areas of these rectangles ",
  Cell[BoxData[
      \(TraditionalForm\`A\_1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  ". These areas can be determined in terms of the length of the rectangle \
sides, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["y",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "1"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "1"], TraditionalForm]]],
  "where"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"x", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"y", ",", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "1"], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "1"], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "-", 
            RowBox[{
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "."}]}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(7.3.6)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75456 
%%ImageSize: 713 538 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00133574 0.0179657 0.00133574 [
[ 0 0 0 0 ]
[ 1 .75456 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75456 L
0 .75456 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01797 translate
.95238 .71862 scale
713 string
713 538 8 [713 0 0 538 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFF0000000000
0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00000000000000FFFFFFFFFFFFFF00
00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF00
000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00
000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF00
000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFF000000FFFFFFFF00000000000000FFFFFFFFFFFFFF0000000000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF00000000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF00000000FFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFF000000000000FFFFFFFFFF000000FFFF00000000FFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFF000000000000FFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF000000
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFF000000000000FFFFFFFFFF000000FFFF00000000FFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000000000FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFF0000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF00000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFF
FFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFF000000000000FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFF00000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFF00000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFF
FFFF0000000000FFFF0000FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFF
FFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF00000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF000000
00FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF00000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF000000000000FFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{187.125, 141},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Y0000/2000`400?l00000o`00003ojOooool0
0>Wooooo003Yooooo`00jOooool00>Wooooo003Yooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolS0?ooo`80ZZZZ2`3oool0102Z
ZZX000000000002o_kmO0?ooo`030410@0000000EEEE02@0oooo00<0EEEE0>?Sh`3oool07`3oool6
ooooo`001ooooolG0?ooo`030;no_`2EUID0oooo00H0oooo00H0_kno0?ooo`3oool0oooo02/[:`2Z
ZZX30?ooo`030=CDe02EUID0oooo00@0oooo00@0ZZZZ000000000000_knoBP3oool0102_[jl00000
06YZJP3De=@A0?ooo`030410@0000000EEEE00D0oooo00<0T92@0>[ZjP3oool0603oool01`3De=@0
j^[Z0?ooo`3oool0eMGE01DE5@3_knl00P3oool00`3Zj^X0UIFE0>o_k`0J0?ooo`Kooooo0007oooo
oaH0oooo00<0_kno0:ZZZP3oool01`3oool01P3Shn<0LG5a0?ooo`3oool0SXj>01`L70@0oooo00<0
hn?S09FEU@3oool00`3oool0102ZZZX000000000002o_km;0?ooo`030000002ZZZX0oooo0140oooo
00<0@4100000001EEED0103oool00`1aLG40j^[Z0?ooo`0J0?ooo`06075aL@3Zj^X0oooo0?ooo`0i
>CT0UIFE103oool00`20P800oooo0?ooo`0H0?ooo`Kooooo0007oooooaH0oooo00<0@4100?ooo`3o
ool0203oool01P2>SXh0a/K60?ooo`3Shn<000000<K6aP@0oooo00<0JVYZ0:ZZZP3oool00P3oool0
102ZZZX000000000002o_km;0?ooo`030000002ZZZX0oooo0140oooo00<0@4100000001EEED00`3o
ool00`1aLG40SXj>0?ooo`0K0?ooo`060>?Sh`2EUID0oooo0?ooo`2>SXh0EEEE103oool00`2ZZZX0
EEEE0?ooo`0H0?ooo`Kooooo0007oooooaD0oooo00<0LG5a0820P03oool00P3oool00`2ZZZX00000
08j>SP020?ooo`040=GEe@0L71`000000:ZZZP80oooo00<071`L075aL@3oool00`3oool00`2o_kl0
71`L0?ooo`020?ooo`040:ZZZP00000000000;no_`@0oooo00<0j^[Z0:ZZZP2ZZZX00`3oool00`2Z
ZZX0hn?S0?ooo`020?ooo`030:ZZZP3oool0oooo03T0oooo00<000000:ZZZP3oool04@3oool00`10
@400000005EEE@020?ooo`030<K6aP000000oooo00<0oooo00<0>CTi0410@03Shn<01@3oool00`1E
EED0ZZZZ0?ooo`050?ooo`060:ZZZP1EEED0000003Ti>@2ZZZX0hn?S0P3oool00`0i>CT000000820
P0020?ooo`030<K6aP0E5AD0oooo00@0oooo00<000000<K6aP3oool05`3oool6ooooo`001ooooolD
0?ooo`030>[ZjP000000_kno00<0oooo00P0X:2P0000003Zj^X0_kno0?ooo`3_knl0@41006][J`<0
oooo00<0P82002/[:`3oool0103oool01@000000UIFE0?ooo`3oool0ZZZZ008000000180_kno0?oo
o`3oool0oooo09FEU@0`<300j^[Z0?ooo`2ZZZX0P8200?ooo`000000EEEE0=oOg`3oool0P82001DE
5@20P80X0?ooo`090=oOg`2EUID0_kno0;no_`3De=@0oooo0=GEe@20P800j^[Z0080oooo00<0_kno
09FEU@3_knl0103oool00`000000ZZZZ0?ooo`0A0?ooo`030410@0000000EEEE0080oooo00<0@410
05EEE@3oool00`3oool0100[:b/0P8200;no_`3Zj^X40?ooo`0305EEE@2ZZZX0oooo00L0oooo00<0
00000:ZZZP3oool00`3oool00`1ZJVX0EEEE0=oOg`030?ooo`03020P803EeMD0oooo00<0oooo00<0
EEEE0410@03oool05`3oool6ooooo`001ooooolD0?ooo`030:ZZZP000000j^[Z00<0oooo00@0eMGE
00000036a/H0hn?S1`3oool00`36a/H000000=GEe@040?ooo`0505EEE@0i>CT0oooo0?ooo`2ZZZX0
0P0000001P2o_kl0oooo0?ooo`3oool000000820P0<0oooo00X0JVYZ075aL@3oool0oooo09FEU@3o
ool0EEEE075aL@3oool0ZZZZ9`3oool02@0E5AD0ZZZZ0?ooo`3oool0ZZZZ0820P02ZZZX071`L05EE
E@020?ooo`0301`L701EEED0UIFE00@0oooo00<000000:ZZZP3oool04@3oool00`10@400000005EE
E@020?ooo`030000002>SXh0oooo00<0oooo00@0LG5a05EEE@3oool0hn?S103oool00`1EEED0ZZZZ
0?ooo`070?ooo`030000002ZZZX0oooo00T0oooo00<0EEEE075aL@3oool00`3oool00`2ZZZX00000
0>?Sh`0G0?ooo`Kooooo0007oooooa@0oooo00<0EEEE0000003oool0103oool00`0L71`0SXj>0?oo
o`080?ooo`0301`L702ZZZX0oooo00<0oooo00D0EEEE0000003oool0oooo0:ZZZP02000000060;no
_`3oool0oooo0:ZZZP000000UIFE0`3oool0202o_kl000000>?Sh`3oool0_kno0:ZZZP000000ZZZZ
:03oool00`2ZZZX000000?ooo`030?ooo`0:02/[:`36a/H0oooo0>?Sh`2ZZZX0oooo00000036a/H0
eMGE0>?Sh`<0oooo00<000000:ZZZP3oool04@3oool01`10@400000005EEE@3oool0_kno0000002Z
ZZX0103oool00`36a/H0:b/[0?ooo`050?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000:ZZZP3o
ool02@3oool00`2EUID0>CTi0?ooo`030?ooo`030:ZZZP000000ZZZZ01L0oooo1_ooool000Oooooo
503oool00`1EEED000000?ooo`040?ooo`80EEEE2@3oool00`1EEED0JVYZ0?ooo`030?ooo`0505EE
E@000000oooo0?ooo`2ZZZX00P0000001P2o_kl0oooo0?ooo`3Shn<000000820P0<0oooo00<0eMGE
0000002>SXh00P3oool00`1aLG4000000>?Sh`0X0?ooo`0305EEE@0E5AD0oooo00<0oooo00L0P820
03Ti>@3oool0oooo09FEU@2>SXh0000000D0oooo00<0j^[Z0000002ZZZX04P3oool01`10@4000000
05EEE@3oool0_kno0000002ZZZX01@3oool010000000oooo0?ooo`1EEED8000000030:ZZZP3oool0
oooo0080oooo00<000000:ZZZP3oool02@3oool00`2o_kl000000>?Sh`030?ooo`030:ZZZP000000
ZZZZ01L0oooo1_ooool000Oooooo503oool00`1EEED000000?ooo`040?ooo`030;no_`000000j^[Z
00P0oooo00<0_kno030`<03oool00`3oool01@1EEED000000?ooo`3oool0ZZZZ0080000000H0_kno
0?ooo`3oool0oooo02/[:`1`L7040?ooo`060000001EEED0oooo0?ooo`2EUID00000:@3oool00`2E
UID000000?ooo`030?ooo`050:2PX0000000eMGE0?ooo`3_knl00P10@4050?ooo`030;no_`1EEED0
ZZZZ0180oooo00L0@4100000001EEED0oooo0;no_`000000ZZZZ00D0oooo00<0D51@09FEU@3oool0
103oool00`1EEED0ZZZZ0?ooo`070?ooo`030000002ZZZX0oooo00X0oooo00<05ADE09FEU@3oool0
0P3oool00`2ZZZX000000:ZZZP0G0?ooo`Kooooo0007oooooa@0oooo00<0SXj>0000003oool01@3o
ool00`0L71`0ZZZZ0?ooo`080?ooo`030000003Shn<0oooo0080oooo00D0>CTi05EEE@3oool0oooo
0:ZZZP02000000060;no_`3oool0oooo0?ooo`2ZZZX0:b/[103oool01`000000EEEE0?ooo`3oool0
EEEE01`L702ZZZX0:03oool00`3Shn<000000>?Sh`030?ooo`030;no_`000000ZZZZ0080oooo00<0
>CTi05EEE@3oool06@3oool01`10@400000005EEE@3oool0j^[Z0000002ZZZX01@3oool00`2EUID0
EEEE0?ooo`040?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000:ZZZP3oool02P3oool00`1EEED0
>CTi0?ooo`020?ooo`0308j>SP000000oooo01L0oooo1_ooool000Oooooo503oool00`36a/H00000
0;no_`040?ooo`030:ZZZP0L71`0EEEE00L0oooo00@0hn?S0:ZZZP0E5AD0ZZZZ0`3oool01@000000
SXj>0?ooo`3oool0ZZZZ0080000000<0_kno0?ooo`3oool00P3oool01`10@400ZZZZ0?ooo`3oool0
ZZZZ00000036a/H00P3oool01@000000SXj>08j>SP3EeMD0ZZZZ02L0oooo00<0@41008j>SP3oool0
0P3oool00`2o_kl000000:ZZZP020?ooo`030000000i>CT0hn?S01T0oooo00<0@4100000001EEED0
0P3oool00`0L71`0EEEE0?ooo`030?ooo`030>?Sh`1ZJVX0000000D0oooo00<0EEEE0:ZZZP3oool0
1`3oool00`000000ZZZZ0?ooo`090?ooo`030;no_`1EEED0000000<0oooo00<0EEEE03Ti>@3oool0
5`3oool6ooooo`001ooooolE0?ooo`0303Ti>@2EUID0oooo00@0oooo00<0hn?S0<K6aP3oool0203o
ool01`3EeMD0a/K60?ooo`3oool0eMGE0000003Shn<00P3oool0102ZZZX000000000002o_kl50?oo
o`0>075aL@2>SXh0ZZZZ02/[:`0i>CT0oooo0<K6aP2EUID000000>?Sh`3oool0EEEE00000036a/HV
0?ooo`030;no_`0L71`0hn?S0080oooo00X0JVYZ01`L703oool0oooo0;no_`000000hn?S075aL@3E
eMD0a/K65`3oool00`10@400000005EEE@020?ooo`0308j>SP0L71`0oooo00D0oooo00<0ZZZZ0?oo
o`3oool00`3oool00`1EEED0ZZZZ0?ooo`070?ooo`030000002ZZZX0oooo00/0oooo00H0ZZZZ0>?S
h`3oool0oooo01`L702>SXhH0?ooo`Kooooo0007oooooaD0oooo00<0eMGE051@D03oool04`3oool0
0`20P800ZZZZ0?ooo`020?ooo`040:ZZZP00000000000;no_`H0oooo00@0_kno0410@010@400j^[Z
<03oool03P3Zj^X0UIFE0:ZZZP20P800410@0:ZZZP3oool0_kno092@T01ZJVX0oooo0>[ZjP1PH600
EEEE5`3oool00`10@400000005EEE@030?ooo`030410@02ZZZX0oooo01@0oooo00<000000:ZZZP3o
ool03P3oool00`2o_kl0EEEE0?ooo`0H0?ooo`Kooooo0007oooooaH0oooo00<0_kno08j>SP3oool0
0`3oool00`36a/H00000075aL@080?ooo`0505EEE@0L71`0oooo0>?Sh`20P800103oool0102ZZZX0
00000000002o_kl50?ooo`050:ZZZP000000SXj>0?ooo`3Shn<0<P3oool00`1aLG40000009FEU@0P
0?ooo`030410@0000000EEEE00@0oooo00<0EEEE0>[ZjP3oool00`3oool201`L70`0oooo00@0ZZZZ
05EEE@000000ZZZZ2`3oool01@36a/H00000075aL@3oool0JVYZ01X0oooo1_ooool000Oooooo5`3o
ool20:ZZZP<0oooo00<0a/K60000001aLG40203oool0101EEED071`L0>?Sh`1aLG450?ooo`040:ZZ
ZP00000000000;no_`D0oooo00D0EEEE08j>SP3oool0oooo05EEE@0a0?ooo`0505EEE@0L71`0a/K6
0?ooo`3Shn<07`3oool00`10@400000005EEE@050?ooo`030820P03oool0oooo0080oooo0P0L71`=
0?ooo`030>?Sh`1EEED0ZZZZ00/0oooo00D0a/K60000001aLG40LG5a0>[ZjP0J0?ooo`Kooooo0007
oooooaP0oooo00<0hn?S0?ooo`3oool03P3oool00`36a/H0oooo0?ooo`040?ooo`040:ZZZP000000
00000;no_`D0oooo00D0hn?S05EEE@2ZZZX0P8200<K6aP0a0?ooo`050000003Shn<0oooo0>[ZjP1a
LG407`3oool00`10@400000005EEE@060?ooo`030>?Sh`3oool0oooo0200oooo0P3Shn<K0?ooo`Ko
oooo0007oooooc00oooo00@0ZZZZ000000000000_kno>`3oool01@2ZZZX0LG5a0:ZZZP20P800hn?S
01l0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no
_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool@0?ooo`0308j>SP1EEED0EEEE01d0
EEEE00@0>CTi000000000000@410G`1EEED00`0E5AD0000001`L700P05EEEBH0oooo1_ooool000Oo
oooo403oool00`1EEED000000000002S000002H0oooo1_ooool000Oooooo403oool00`1EEED00000
0000002S000002H0oooo1_ooool000Oooooo403oool00`3De=@0_kno0;no_`0M0;no_`0407moO`00
0000000008n?SaT0_kno00<0P8200:ZZZP2o_kl0@`2o_kl00`0`<30000000410@00P0;no_bH0oooo
1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030000002ZZZX0oooo04<0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo
00<000000:ZZZP3oool0@`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0
ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?ooo`130?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030410@02o_kl0oooo04<0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_``0oooo
00<0ZZZZ0000001aLG400P2ZZZX00`3Shn<0oooo0?ooo`0b0?ooo`030410@0000000000000800000
00<0>CTi0?ooo`3oool04@3oool00`10@400000005EEE@160?ooo`Kooooo0007ooooobH0oooo00<0
ZZZZ0>[ZjP3oool01`3oool0102ZZZX000000000002o_kl<0?ooo`030=GEe@3Shn<0oooo0080oooo
00<0>CTi0>?Sh`3oool0<P3oool00`3Zj^X0>CTi0:ZZZP020:ZZZP0305EEE@3Shn<0oooo0140oooo
00<0@4100000001EEED0AP3oool6ooooo`001ooooolV0?ooo`0300000010@400hn?S00L0oooo00@0
ZZZZ000000000000_kno4@3oool00`1EEED0LG5a0?ooo`050?ooo`0305EEE@36a/H0oooo02/0oooo
00<0hn?S075aL@3oool00P3oool00`3Shn<0oooo0?ooo`0@0?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo9P3oool0102o_kl0oooo0;no_`2o_kl60?ooo`040:ZZZP00000000000;no_a00
oooo00<0kno_01DE5@1ZJVX01P3oool00`000000ZZZZ0?ooo`0/0?ooo`030>[ZjP20P800kno_01@0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolY0?ooo`030:ZZZP3Shn<0oooo00@0oooo
00D0ZZZZ000000000000_kno0?ooo`030:ZZZP040>[ZjP3oool0oooo0<K6aP@0ZZZZ0P3oool01@2Z
ZZX0SXj>02/[:`0L71`0hn?S00H0oooo00<000000:ZZZP3oool07P3oool30:ZZZP040>?Sh`3oool0
oooo0<K6aP@0ZZZZ103oool00`3Shn<0JVYZ0?ooo`0C0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo803oool00`3Shn<0ZZZZ0:ZZZP070?ooo`0305EEE@3oool0oooo00<0oooo00P0ZZZZ
000000000000_kno0?ooo`2>SXh000000:ZZZP@0oooo00@0P8200000000L71`0hn?S0`3oool00`2>
SXh0@4100>?Sh`070?ooo`030000002ZZZX0oooo01h0oooo00<0SXj>0000002ZZZX0103oool0102Z
ZZX0000001`L703Shn<50?ooo`0306YZJP36a/H0oooo0180oooo00<0@4100000001EEED0AP3oool6
ooooo`001ooooolO0?ooo`060820P00L71`0hn?S0?ooo`20P800ZZZZ1@3oool00`000000_kno0?oo
o`030?ooo`040:ZZZP00000000000;no_`80oooo00<0EEEE08j>SP3oool00`3oool00`2ZZZX00000
05EEE@050?ooo`0309FEU@1aLG40oooo02P0oooo00<0EEEE08j>SP3oool00`3oool00`3Shn<00000
05EEE@020?ooo`060=GEe@3oool0oooo0?ooo`20P800EEEE4`3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooal0oooo00<0410@0:ZZZP3oool00P3oool00`0[:b/0UIFE0?ooo`020?ooo`03
0:ZZZP000000_kno00@0oooo00@0ZZZZ000000000000_kno0P3oool00`3Zj^X0:b/[0>o_k`030?oo
o`060820P0000000ZZZZ0?ooo`3?cll0j^[Z0P3oool00`2_[jl000000?ooo`0X0?ooo`030>[ZjP0[
:b/0j^[Z00<0oooo00<0ZZZZ0000002ZZZX00P3oool01P20P800e=CD0?ooo`3De=@0<30`06YZJQ<0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolN0?ooo`030:ZZZP000000a/K600<0oooo
00<0ZZZZ0000003Shn<00P3oool0101aLG40>CTi0>[ZjP36a/H30?ooo`040:ZZZP00000000000;no
_`<0oooo00<0a/K605EEE@2ZZZX00P2ZZZX00`10@40000000<K6aP020?ooo`05075aL@2ZZZX0ZZZZ
01DE5@2>SXh0:P3oool00`36a/H0>CTi0:ZZZP020:ZZZP0305EEE@000000a/K60080oooo00H0eMGE
01`L70000000000001DE5@3Shn<C0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo7P3o
ool00`3Shn<000000:ZZZP030?ooo`030<K6aP000000SXj>0080oooo0P1EEED00`3oool0ZZZZ0?oo
o`020?ooo`040:ZZZP00000000000;no_`@0oooo00H0@41005EEE@1EEED0EEEE01DE5@0000040?oo
o`030>?Sh`2ZZZX0eMGE02`0oooo00H0EEEE0410@01EEED0EEEE01`L700000050?ooo`80ZZZZ5@3o
ool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo00<05ADE0:ZZZP3oool00`3oool0
2@000000EEEE0?ooo`3oool000000:ZZZP3oool0hn?S0<K6aP020?ooo`040:ZZZP00000000000;no
_`@0oooo00H0ZZZZ08j>SP3oool0oooo01DE5@0L71`c0?ooo`060>?Sh`1ZJVX0oooo0?ooo`0L71`0
5ADE703oool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo0P1EEED40?ooo`060000
001EEED0oooo0:ZZZP000000hn?S0P3oool0102>SXh0oooo0?ooo`2ZZZX2000000030;no_`3oool0
oooo00<0oooo00D0>CTi0>?Sh`3oool0000005EEE@0d0?ooo`0506YZJP3Shn<0oooo00000010@400
703oool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo00<0gmoO01DE5@2o_kl00P3o
ool01P2ZZZX000000:ZZZP3oool0EEEE0410@080oooo00D0_kno01DE5@3oool0oooo0:ZZZP020000
00030;no_`3oool0oooo00<0oooo00D0eMGE06YZJP2o_kl000000820P00?0?ooo`030820P03EeMD0
oooo0280oooo00D0gmoO06YZJP2o_kl00000061PH00L0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo8@3oool02@1aLG40SXj>09FEU@0L71`0>CTi0>?Sh`20P80000000:ZZZP020?ooo`05
075aL@0L71`0oooo0?ooo`2ZZZX00P0000000`2o_kl0oooo0?ooo`040?ooo`0408j>SP1EEED00000
0:ZZZPl0oooo00<000000:ZZZP3oool08`3oool0102>SXh0EEEE00000020P80L0?ooo`030410@000
0000EEEE04H0oooo1_ooool000Oooooo8P3oool0103Shn<0@41001`L703Shn<:0?ooo`040:ZZZP00
000000000;no_`L0oooo00<071`L0000003Shn<03`3oool00`000000ZZZZ0?ooo`0T0?ooo`0301`L
70000000ZZZZ01`0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolQ0?ooo`030>?Sh`0L
71`0EEEE00`0oooo00@0ZZZZ000000000000_kno1`3oool00`36a/H000000?ooo`0?0?ooo`030000
002ZZZX0oooo02@0oooo00<0a/K60000002o_kl0703oool00`10@400000005EEE@160?ooo`Kooooo
0007ooooob40oooo00D0EEEE06YZJP3oool0oooo06YZJP0:0?ooo`040:ZZZP00000000000;no_`P0
oooo00<0P8200?ooo`3oool03P3oool00`2o_kl0j^[Z0?ooo`0U0?ooo`0306YZJP3_knl0oooo01/0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolQ0?ooo`050>?Sh`1EEED0ZZZZ075aL@36
a/H02P3oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_klI0?ooo`030:ZZZP3Shn<0oooo04<0oooo00<0@4100000
001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZ
ZP3oool0@`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ00000000
0000_kno6@3oool00`000000ZZZZ0?ooo`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_klH0?ooo`040820P0000000EEEE0<K6aT<0oooo00<0@410
0000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aL0oooo00<0EEEE
0000000000000P0000000`3EeMD0oooo0?ooo`100?ooo`030410@0000000EEEE04H0oooo1_ooool0
00Oooooo<03oool0102ZZZX000000000002o_klF0?ooo`030:ZZZP000000000000<0000000<0P820
0?ooo`3oool0@03oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00D0ZZZZ0000
00000000<30`0410@0060?ooo`050;no_`10@400@4100410@02o_kl01@3oool01P2o_kl0@4100410
@010@400_kno06YZJPD0000000@0410@0410@010@400@4101P3oool01020P800@4100410@010@406
0?ooo`050;no_`10@400@4100410@02o_kl01@3oool01@2o_kl0@4100410@010@400L71`00H0oooo
00@0P8200410@010@400@4101P3oool01020P800@4100410@010@4060?ooo`090;no_`10@400@410
0410@020P800oooo0410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool01@2ZZZX000000000
0020P800ZZZZ00H0oooo00D0hn?S0:ZZZP2ZZZX0ZZZZ0>?Sh`050?ooo`060>?Sh`2ZZZX0ZZZZ0:ZZ
ZP3Shn<0ZZZZ1@000000101EEED0ZZZZ0:ZZZP2ZZZX60?ooo`040<K6aP2ZZZX0ZZZZ0:ZZZPH0oooo
00D0hn?S0:ZZZP2ZZZX0ZZZZ0>?Sh`050?ooo`050>?Sh`2ZZZX0ZZZZ0:ZZZP2o_kl01P3oool01036
a/H0ZZZZ0:ZZZP2ZZZX60?ooo`040<K6aP2ZZZX0ZZZZ0:ZZZPH0oooo00T0hn?S0:ZZZP2ZZZX0ZZZZ
0<K6aP3oool0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no
_aL0oooo00<071`L0000000000000P0000000`2o_kl0oooo0?ooo`100?ooo`030410@0000000EEEE
04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klH0?ooo`0406YZJP0i>CT0EEEE
0<K6aQ80oooo00<0000003Ti>@3Shn<0;P3oool00`10@400000005EEE@160?ooo`Kooooo0007oooo
oc00oooo00@0ZZZZ000000000000_kno7`3oool00`2EUID0_kno0?ooo`080?ooo`080>[ZjP3De=@0
oooo0?ooo`20P800j^[Z0;no_`3?cll40?ooo`030>[ZjP2EUID0j^[Z02H0oooo00<0@4100000001E
EED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZZP3o
ool00P3oool00`1aLG40hn?S0?ooo`0:0?ooo`80ZZZZ103oool00`2ZZZX0oooo0?ooo`040?ooo`03
075aL@3Zj^X0oooo02@0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZ
ZP00000000000;no_aT0oooo00H000000:ZZZP3oool0oooo075aL@2>SXh=0?ooo`0305EEE@3oool0
oooo0080oooo00<0j^[Z08j>SP3oool0103oool00`3Shn<0@4100?ooo`0T0?ooo`030410@0000000
EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`050000002ZZZX0
oooo0=GEe@0000000`3oool01`10@400EEEE0?ooo`3oool0eMGE0000001aLG400P3oool00`2>SXh0
0000000000050?ooo`030000003Shn<0oooo00@0oooo00<0@4100<K6aP3oool08`3oool00`10@400
000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool01@10@400
_kno0?ooo`1`L700EEEE00<0oooo00`0X:2P0;no_`20P800oooo0820P010@400j^[Z09FEU@3oool0
ZZZZ0410@02ZZZX40?ooo`030<o?c`000000UIFE00D0oooo00<0P8200410@03oool08`3oool00`10
@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno703oool00`10
@400SXj>0?ooo`040?ooo`040<K6aP2ZZZX0EEEE0:ZZZPX0oooo00@0ZZZZ01`L703oool0ZZZZ103o
ool00`2o_kl000000>?Sh`0S0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0
102ZZZX000000000002o_klL0?ooo`030000002ZZZX0oooo00D0oooo00<0LG5a02/[:`36a/H02P3o
ool01020P800EEEE0?ooo`2ZZZX40?ooo`030;no_`000000ZZZZ02<0oooo00<0@4100000001EEED0
AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_a`0oooo00<000000:ZZZP3oool0
1P3oool00`000000oooo0?ooo`090?ooo`0505EEE@2>SXh0oooo0?ooo`2o_kl00`3oool00`2o_kl0
00000:ZZZP0S0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX00000
0000002o_klL0?ooo`030000002ZZZX0oooo00D0oooo00<0a/K60000003oool02P3oool01@0E5AD0
a/K60?ooo`3oool0ZZZZ00<0oooo00<0_kno0000002ZZZX08`3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno703oool00`0P8200ZZZZ0?ooo`050?oo
o`030820P010@400P82000T0oooo00<0eMGE020P803oool00P3oool01`1PH600oooo0?ooo`3oool0
[jn_0000003Zj^X08`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ
000000000000_kno703oool205EEE@@0oooo00P0a/K60>?Sh`0i>CT0UIFE0>?Sh`0i>CT071`L09FE
U@@0oooo00@0hn?S0:ZZZP0L71`0JVYZ0P3oool00`2ZZZX000000?ooo`020?ooo`030820P00i>CT0
oooo02<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_aT0oooo00D0EEEE0<K6aP3oool0ZZZZ01`L70050?ooo`030<K6aP2ZZZX0j^[Z0080oooo00<0
ZZZZ0>[ZjP3oool01@3oool00`2ZZZX0eMGE0?ooo`020?ooo`060;no_`3oool0oooo0?ooo`1EEED0
SXj>903oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000
_kno6@3oool01P000000ZZZZ0?ooo`3oool071`L0<K6aQX0oooo00<0@4100?ooo`3oool08`3oool0
0`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool0
1`000000ZZZZ0?ooo`3oool0j^[Z05EEE@3Zj^X0603oool00`1ZJVX0clo?0?ooo`0T0?ooo`030410
@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030000
002ZZZX0oooo00<0oooo00<0LG5a0>?Sh`3oool05@3oool00`1aLG40hn?S0?ooo`0U0?ooo`030410
@0000000EEEE04H0oooo1_ooool000Oooooo:`3oool30:ZZZP030<K6aP3oool0ZZZZ0080000000<0
_kno0?ooo`3oool07P3oool00`3Shn<0oooo0?ooo`0C0?ooo`80hn?S9`3oool00`10@400000005EE
E@160?ooo`Kooooo0007ooooob00oooo00<0a/K605EEE@36a/H0203oool00`3Zj^X0000008j>SP02
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolP
0?ooo`040;no_`1EEED0ZZZZ0<o?c`P0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no
_`3oool0oooo00h0oooo00<0gmoO0820P03oool0<P3oool01@3Zj^X0X:2P0820P02ZZZX0j^[Z01D0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolS0?ooo`030;no_`36a/H0oooo00H0oooo
00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no_`3oool0oooo00h0oooo00<0_kno0000003o
ool0<`3oool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo
903oool00`2>SXh0oooo0?ooo`050?ooo`050000002ZZZX0oooo0?ooo`2ZZZX00P0000000`2o_kl0
oooo0?ooo`0>0?ooo`030;no_`000000oooo03<0oooo00<0_kno0000003oool05P3oool00`10@400
000005EEE@160?ooo`Kooooo0007oooooaX0oooo00D0eMGE075aL@2ZZZX0ZZZZ0<K6aP050?ooo`03
0:ZZZP1aLG40oooo00D0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no_`3oool0oooo
00X0oooo00<0P820000000000000100000000`1EEED0oooo0?ooo`0`0?ooo`030;no_`000000oooo
01H0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolI0?ooo`030>[ZjP0@4100_kno0080
oooo00<0_kno061PH03oool00`3oool00`20P800:b/[0;no_`050?ooo`050000002ZZZX0oooo0?oo
o`2ZZZX00P0000000`2o_kl0oooo0?ooo`0:0?ooo`060=oOg`3De=@0oooo0?ooo`2o_kl000001`3o
ool00`20P800eMGE0?ooo`0Z0?ooo`030;no_`000000oooo01H0oooo00<0@4100000001EEED0AP3o
ool6ooooo`001ooooolI0?ooo`0308j>SP000000oooo00<0oooo00<0EEEE08j>SP3oool00P3oool2
05EEE@030:ZZZP3oool0oooo00<0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000060;no_`3o
ool0>CTi0000001aLG40j^[Z0P3oool02`36a/H0@410000000000000SXj>0?ooo`3Shn<0a/K60?oo
o`2o_kl0000000L0oooo00<000000:ZZZP3oool0703oool0102>SXh00000075aL@3Shn<20?ooo`05
0=GEe@1EEED000000000001ZJVX00`3oool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE
04H0oooo1_ooool000Oooooo6@3oool00`1EEED05ADE0?ooo`030?ooo`030820P00L71`0oooo0080
oooo00@000000:ZZZP3oool0_kno0`3oool00`2ZZZX000000:ZZZP020?ooo`040:ZZZP0000000000
0;no_`80oooo00<071`L0:ZZZP3oool00`3oool00`2o_kl0000005EEE@030?ooo`040<K6aP3Shn<0
_kno000000L0oooo00<000000:ZZZP3oool07@3oool00`1EEED0ZZZZ0?ooo`040?ooo`800000103o
ool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo6@3oool0
0`2ZZZX000000?ooo`030?ooo`090:ZZZP000000a/K60?ooo`3Zj^X000000<K6aP3oool0_kno00<0
oooo00<0j^[Z075aL@2ZZZX00P3oool0102ZZZX000000000002o_kl20?ooo`030<K6aP0i>CT0oooo
00<0oooo00<0P8200000002>SXh0103oool00`2ZZZX0_kno000000070?ooo`030000002ZZZX0oooo
01d0oooo00<0eMGE03Ti>@3oool00`3oool00`2ZZZX0000003Ti>@040?ooo`030;no_`000000oooo
01H0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolI0?ooo`030>[ZjP000000eMGE00<0
oooo00H0_kno0000002ZZZX0oooo0:2PX00E5AD20?ooo`030<o?c`3EeMD0oooo00H0oooo00@0ZZZZ
000000000000_kno0`3oool00`1ZJVX0/;2`0?ooo`020?ooo`03071`L0000000ZZZZ00D0oooo00<0
Shn?0000003oool01P3oool00`20P800eMGE0?ooo`0N0?ooo`0306YZJP2EUID0oooo0080oooo00<0
UIFE0000001EEED00`3oool00`3Zj^X0P8200000000G0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo6P3oool00`1ZJVX0LG5a0?ooo`020?ooo`060:ZZZP000000a/K60?ooo`1ZJVX0LG5a
0P3oool00`3Zj^X0LG5a0?ooo`060?ooo`040:ZZZP00000000000;no_`@0oooo00<05ADE00000000
00000`0000060?ooo`030>[ZjP1EEED0oooo02P0oooo00<071`L0000000000000`0000000`2ZZZX0
oooo0?ooo`030?ooo`0308j>SP3oool0oooo01D0oooo00<0@4100000001EEED0AP3oool6ooooo`00
1ooooolJ0?ooo`030>[ZjP0i>CT0ZZZZ0080oooo00H0EEEE03Ti>@3oool0hn?S01DE5@36a/H20?oo
o`80EEEE1`3oool0102ZZZX000000000002o_kl40?ooo`0609FEU@36a/H0oooo0?ooo`0[:b/00000
<@3oool01`36a/H0LG5a0?ooo`3oool0>CTi0000002ZZZX07@3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooa`0oooo00@0ZZZZ08j>SP1EEED000000P36a/H00`2>SXh0EEEE0?ooo`020?oo
o`0309FEU@2ZZZX0oooo00H0oooo00@0ZZZZ000000000000_kno103oool01P3Zj^X0>CTi0?ooo`3o
ool0000005EEEC80oooo00<0EEEE0<K6aP3oool00P00000N0?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo703oool0103Zj^X0EEEE01DE5@2`/;0@0?ooo`040:ZZZP00000000000;no_`D0
oooo00D0ZZZZ0820P03EeMD0000006YZJP0b0?ooo`050>[ZjP10@400gmoO0000000E5AD07P3oool0
0`10@400000005EEE@160?ooo`Kooooo0007oooooa`0oooo00D071`L05EEE@3oool0oooo0:ZZZP0?
0?ooo`040:ZZZP00000000000;no_`H0oooo00@0LG5a08j>SP000000ZZZZ<`3oool01036a/H0JVYZ
0000001EEEDN0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo703oool01@0L71`0hn?S
0?ooo`2o_kl0SXj>00l0oooo00@0ZZZZ000000000000_kno1P3oool0103Shn<0000000000036a/Hd
0?ooo`0302/[:`000000LG5a01h0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolL0?oo
o`040>?Sh`2>SXh0ZZZZ0:ZZZQ00oooo00@0ZZZZ000000000000_kno1`3oool00`2>SXh000000?oo
o`0?0?ooo`030000002ZZZX0oooo0280oooo00<0ZZZZ0000002ZZZX07P3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno203oool00`1@D500oooo0?oo
o`0>0?ooo`030000002ZZZX0oooo02<0oooo00<0@4100=GEe@3oool07@3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno203oool00`3Zj^X0oooo0?oo
o`0>0?ooo`030000002ZZZX0oooo02<0oooo00<0hn?S0?ooo`3oool07@3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`1EEED0a/K60?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030410@02o_kl0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZZP3oool0@`3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030000002ZZZX0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_aT0oooo00<0EEEE0<K6aP3oool0@`3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030000002ZZZX0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool@
0?ooo`0305EEE@00000000000:<000009P3oool6ooooo`001oooool@0?ooo`0305EEE@0000000000
0:<000009P3oool6ooooo`001oooool@0?ooo`0308j>SP1EEED0EEEE01d0EEEE00@0>CTi00000000
0000@410G`1EEED00`0E5AD0000001`L700P05EEEBH0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE02H0oooo00<0_kno0>?Sh`3oool07@3oool6oooo
o`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0203oool00`2>
SXh0oooo0?ooo`0K0?ooo`030>[ZjP0L71`0hn?S01H0oooo00<0eMGE0>?Sh`3oool0103oool6oooo
o`001oooool40?ooo`80j^[Z2@3oool00`3EeMD0Jf][0>[ZjP0F0?ooo`030>[ZjP3oool0oooo00D0
oooo00@0ZZZZ000000000000_knoG`3oool00`10@400000005EEE@060?ooo`030>[ZjP20P800j^[Z
01X0oooo00H0ZZZZ0;no_`3oool0oooo06YZJP1EEEDG0?ooo`0309FEU@2o_kl0oooo00<0oooo1_oo
ool000Oooooo0`3oool00`3Shn<0LG5a0?ooo`060?ooo`060:ZZZP3oool0oooo0?ooo`2>SXh0>CTi
5P3oool00`3Shn<0LG5a0?ooo`050?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001E
EED01@3oool00`3Zj^X0>CTi0?ooo`0L0?ooo`06075aL@3Shn<0oooo0<K6aP000000hn?S5`3oool0
0`1aLG40ZZZZ0?ooo`020?ooo`Kooooo0007ooooo`80oooo00<0j^[Z075aL@3oool01`3oool01`3S
hn<0LG5a0?ooo`3oool0hn?S0000003EeMD05P3oool00`3Shn<0LG5a0?ooo`040?ooo`040:ZZZP00
000000000;no_el0oooo00<0@4100000001EEED01@3oool00`20P800SXj>0?ooo`020?ooo`030<K6
aP1EEED0hn?S00H0oooo00<0EEEE0?ooo`3oool0103oool01P3Zj^X0ZZZZ05EEE@1EEED0JVYZ0:ZZ
ZP80oooo00@0j^[Z075aL@0i>CT0ZZZZ0P3oool00`000000SXj>0?ooo`050?ooo`0308j>SP36a/H0
oooo00D0oooo00H0ZZZZ075aL@1EEED0EEEE0:ZZZP3Shn<30?ooo`030>?Sh`000000j^[Z0080oooo
1_ooool000Oooooo0P3oool00`1EEED0hn?S0?ooo`080?ooo`0608j>SP3EeMD0oooo0?ooo`0i>CT0
UIFE5`3oool00`2>SXh0P8200?ooo`030?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000
001EEED01@3oool00`0E5AD0hn?S0?ooo`020?ooo`0405EEE@000000SXj>0>[ZjPD0oooo00<00000
0?ooo`3oool01P3oool00`2>SXh000000;no_`030?ooo`040=GEe@00000000000>?Sh`80oooo0P1E
EED60?ooo`0305EEE@2ZZZX0oooo00H0oooo00<0hn?S00000020P8001P3oool0100i>CT0UIFE0?oo
o`3oool6ooooo`001oooool00`3oool0ZZZZ051@D0030?ooo`090=oOg`000000JVYZ0=GEe@3oool0
_kno01DE5@000000clo?0080oooo00<0P820051@D03oool01@3oool00`1EEED0_kno0?ooo`050?oo
o`060;no_`20P800000005EEE@2o_kl0j^[Z103oool00`0P8200j^[Z0?ooo`020?ooo`040:ZZZP00
000000000;no_el0oooo00<0@4100000001EEED0103oool00`2o_kl0410@0?ooo`030?ooo`040:ZZ
ZP000000j^[Z0<o?c`D0oooo00<000000?ooo`3oool01P3oool00`2ZZZX000000;no_`040?ooo`03
0;no_`3Zj^X0oooo0080oooo00<0ZZZZ0000003Zj^X01@3oool00`1EEED0ZZZZ0?ooo`070?ooo`03
00000020P800oooo00D0oooo00@0P820051@D03oool0oooo1_ooool000Oooooo00<0oooo03Ti>@20
P8000`3oool0203Zj^X000000:ZZZP36a/H0j^[Z0?ooo`1EEED0SXj>0`3oool00`3Shn<05ADE0?oo
o`050?ooo`0305EEE@2o_kl0oooo00L0oooo00<000000:ZZZP3oool01@3oool00`10@400SXj>0?oo
o`020?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0103oool00`1aLG40@410
0?ooo`040?ooo`030000002ZZZX0oooo00D0oooo00<000000?ooo`3oool01P3oool00`2ZZZX00000
0;no_`0:0?ooo`030000002ZZZX0oooo00@0oooo00<0EEEE0:ZZZP3oool01`3oool00`000000P820
0?ooo`050?ooo`040:ZZZP000000oooo0?ooo`Kooooo0007ooooo`030?ooo`000000ZZZZ00@0oooo
00@071`L075aL@3oool0j^[Z1`3oool00`0E5AD0a/K60?ooo`040?ooo`0305EEE@2o_kl0oooo00L0
oooo00<000000:ZZZP3oool01@3oool00`20P800>CTi0?ooo`020?ooo`040:ZZZP00000000000;no
_el0oooo00<0@4100000001EEED0103oool00`1EEED0@4100?ooo`040?ooo`80EEEE0P3oool405EE
E@030000001EEED0EEEE0080EEEE103oool00`2ZZZX000000;no_`0:0?ooo`80EEEE00<0oooo08j>
SP1EEED00P1EEED00`0L71`0>CTi05EEE@0205EEE@030<K6aP3oool0oooo0080oooo00<000000820
P03oool01@3oool0102ZZZX000000?ooo`3oool6ooooo`001oooool00`2ZZZX000000;no_`040?oo
o`03075aL@0i>CT0oooo00P0oooo00<0EEEE08j>SP3oool0103oool00`1EEED0_kno0?ooo`070?oo
o`030000002ZZZX0oooo00D0oooo00<0P8200000003oool00P3oool0102ZZZX000000000002o_kmO
0?ooo`030410@0000000EEEE00@0oooo00<0EEEE0410@03oool0103oool0102>SXh071`L0?ooo`3o
ool40:ZZZP030000002ZZZX0ZZZZ0080ZZZZ103oool00`2ZZZX000000;no_`0:0?ooo`0408j>SP00
0000oooo0<K6aP<0ZZZZ00<0>CTi075aL@2ZZZX00P2ZZZX00`3Shn<0oooo0?ooo`020?ooo`030000
0020P800oooo00D0oooo00@0ZZZZ0000003oool0oooo1_ooool000Oooooo00<0ZZZZ0000002o_kl0
103oool00`2o_kl000000>[ZjP080?ooo`04092@T00[:b/0oooo0820P0<0@41000<05ADE030`<010
@4000P10@4000`2o_kl0oooo0?ooo`020?ooo`030000002ZZZX0oooo00D0oooo00<0P8200000003o
ool00P3oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE00@0oooo00<0JVYZ0410
@03oool0103oool00`3Zj^X000000<o?c`050?ooo`030000003oool0oooo00H0oooo00<0ZZZZ0000
002o_kl02P3oool00`3Zj^X000000<o?c`040?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000820
P03oool01@3oool0102ZZZX0820P0?ooo`3oool6ooooo`001oooool00`2ZZZX000000;no_`050?oo
o`0301`L702>SXh0oooo00L0oooo00<0eMGE0000003Shn<0103oool00`1EEED0_kno0?ooo`070?oo
o`030000002ZZZX0oooo00D0oooo00<0P8200000003oool00P3oool0102ZZZX000000000002o_kmO
0?ooo`030410@0000000EEEE00@0oooo00<0ZZZZ01DE5@3oool01@3oool00`0i>CT0UIFE0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<0ZZZZ0000002o_kl02`3oool00`0L71`0P8200?ooo`03
0?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000820P03oool01@3oool205EEE@80oooo1_ooool0
00Oooooo00<0hn?S0000002o_kl01@3oool00`1aLG40EEEE0?ooo`080?ooo`030000002>SXh0oooo
00<0oooo00<0EEEE0;no_`3oool01`3oool00`000000ZZZZ0?ooo`050?ooo`0306YZJP1EEED0oooo
0080oooo00@0ZZZZ000000000000_knoG`3oool00`10@400000005EEE@050?ooo`0301DE5@3Shn<0
oooo00<0oooo00<0ZZZZ08j>SP2ZZZX01@3oool00`000000oooo0?ooo`060?ooo`030:ZZZP000000
_kno00T0oooo00@0hn?S0:ZZZP2>SXh0UIFE103oool00`1EEED0ZZZZ0?ooo`070?ooo`0300000020
P800oooo00D0oooo00@0>CTi09FEU@3oool0oooo1_ooool000Oooooo00<0oooo01`L7020P800103o
ool00`36a/H0EEEE000000080?ooo`030:ZZZP0L71`0EEEE00@0oooo00<0EEEE0;no_`3oool01`3o
ool00`000000ZZZZ0?ooo`050?ooo`030410@02>SXh0oooo0080oooo00@0ZZZZ000000000000_kno
G`3oool00`10@400000005EEE@050?ooo`0306YZJP2>SXh0oooo00/0oooo00<0ZZZZ0?ooo`3oool0
1P3oool00`2ZZZX000000;no_`0A0?ooo`030<K6aP3Shn<0oooo00L0oooo00<000000820P03oool0
103oool00`3Shn<071`L0>[ZjP020?ooo`Kooooo0007ooooo`030?ooo`2ZZZX0D51@00H0oooo00<0
_kno0?ooo`3oool01`3oool00`3Zj^X0_kno0?ooo`030?ooo`030820P03?cll0oooo00L0oooo00<0
00000:ZZZP3oool01@3oool00`0P8200j^[Z0?ooo`020?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED01@3oool00`3_knl0EEEE0=GEe@040?ooo`030>[ZjP20P800j^[Z00/0oooo
00D0kno_0;no_`1oOgl000000;no_`0;0?ooo`030;no_`2@T900oooo00/0oooo0P2o_kl00`000000
P8200?ooo`040?ooo`0305EEE@2o_kl0oooo0080oooo1_ooool000Oooooo0P3oool00`10@400hn?S
0?ooo`0N0?ooo`030000002ZZZX0oooo00@0oooo00<0SXj>09FEU@3oool00`3oool0102ZZZX00000
0000002o_kmO0?ooo`030410@0000000EEEE00L0oooo00<0LG5a0>?Sh`3oool00P3oool00`2ZZZX0
00000:ZZZP0<0?ooo`040>?Sh`1aLG4000000;no_`/0oooo00<0EEEE0000003oool0303oool00`2>
SXh071`L0820P0040?ooo`03075aL@3Shn<0oooo00<0oooo1_ooool000Oooooo0P3oool00`3Zj^X0
EEEE0?ooo`040?ooo`0301`L701EEED0oooo00L0oooo00<0LG5a00000036a/H02`3oool0102ZZZX0
EEEE0000002ZZZX40?ooo`030>?Sh`1EEED0oooo00@0oooo00@0ZZZZ000000000000_knoG`3oool0
0`10@400000005EEE@080?ooo`030:ZZZP3oool0oooo0080oooo00<0ZZZZ0?ooo`3oool03@3oool0
0`3Shn<0j^[Z0?ooo`0:0?ooo`030>?Sh`2o_kl0oooo00h0oooo00H0eMGE0?ooo`3oool0oooo0;no
_`3Shn<50?ooo`Kooooo0007ooooo`<0oooo00<0hn?S075aL@3oool00`3oool00`0L71`0EEEE0?oo
o`070?ooo`03075aL@000000a/K600`0oooo00<0hn?S05EEE@2ZZZX00`3oool00`3Shn<0LG5a0?oo
o`050?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooo
ool50?ooo`030>[ZjP3oool0oooo0200oooo00<0e=CD0?ooo`3oool01@3oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool00>Wooooo003Yooooo`00jOooool00>Wo
oooo0000\
\>"],
  ImageRangeCache->{{{2.3125, 232.875}, {175.25, 0}} -> {-25.3376, -15.5257, \
4.05886, 4.05886}}],

Cell["Fig. 7.11 Quantities associated with area weighting.", "Caption",
  CellTags->"Fig. 7.11"],

Cell["We then increment the density according to the formulae", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\)\), " ", "=", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_1\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\_1\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_2\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(\(i\_1\) j\_1\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_3\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(\(i\_1\) j\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_4\), "/", 
              RowBox[{
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["A",
                          FontSlant->"Italic"]}]], "2"], ")"}], "."}]}]}]}]}],
       TraditionalForm]]]], "NE3",
  CellTags->"(7.3.7)"],

Cell[TextData[{
  "In other words, the density increment at point ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " is weighted by the area of the rectangle in the ",
  StyleBox["opposite corner",
    FontSlant->"Italic"],
  ".  The reasoning behind this type of weighting is as follows. First, one \
can see that Eq. ",
  ButtonBox["(7.3.5)",
    ButtonData:>{"Chapter7.nb", "(7.3.5)"},
    ButtonStyle->"Hyperlink"],
  "  is still satisfied, because ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%4 A\_i\), "=", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ". Second, one can also see that the closer the particle is to a given grid \
point, the larger the area associated with that grid point,  and the more \
mass is assigned to that grid point."
}], "Text"],

Cell[TextData[{
  "\tAlso, this type of weighting can be easily applied to one- or \
three-dimensional grids. In fact, we have used a form of one-dimensional area \
weighting already, in a different context; see the discussion surrounding \
Fig. ",
  ButtonBox["6.11",
    ButtonData:>{"Chapter6.nb", "Fig. 6.11"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "The following module takes a single particle at position ",
  Cell[BoxData[
      \(TraditionalForm\`z = {x, y}\)]],
  " and  increments the density matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " according to Eq. ",
  ButtonBox["(7.3.6)",
    ButtonData:>{"Chapter7.nb", "(7.3.6)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(setden[z_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({x, y, \[Delta]x, \[Delta]y, \[Delta]x1, \[Delta]y1, i, 
              j, i1, j1}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*\ x\ and\ y\ positions\ of\ particle\ *) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
            
            RowBox[{\(x = z[\([1]\)]\), ";", \(y = z[\([2]\)]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ lengths\ of\ the\ rectangle\ sides\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Delta]x = Mod[x, \[CapitalDelta]x]\),
               ";", "\[IndentingNewLine]", \(\[Delta]y = 
                Mod[y, \[CapitalDelta]y]\), ";", 
              "\[IndentingNewLine]", \(\[Delta]x1\  = \ \[CapitalDelta]x - \
\[Delta]x\), ";", 
              "\[IndentingNewLine]", \(\[Delta]y1\  = \ \[CapitalDelta]y - \
\[Delta]y\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  determine\ surrounding\ grid\ points\ \((values\ \
incremented\ by\ 1\ in\ accord\ with\ Mathematica\ list\ notation)\)\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(i\  = 
                Quotient[x, \[CapitalDelta]x] + 1\), ";", 
              "\[IndentingNewLine]", \(j = \ 
                Quotient[y, \[CapitalDelta]y] + 1\), ";", 
              "\[IndentingNewLine]", \(i1\  = \ 1 + Mod[i, M]\), ";", 
              "\[IndentingNewLine]", \(j1\  = \ 1 + Mod[j, M]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ increment\ the\ density\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Rho][\([i, 
                    j]\)]\  = \ \[Rho][\([i, j]\)] + \[Delta]x1*\[Delta]y1\), 
              ";", "\[IndentingNewLine]", \(\[Rho][\([i, 
                    j1]\)]\  = \[Rho][\([i, j1]\)] + \[Delta]x1*\[Delta]y\), 
              ";", "\[IndentingNewLine]", \(\[Rho][\([i1, 
                    j]\)]\  = \ \[Rho][\([i1, 
                      j]\)] + \ \[Delta]x*\[Delta]y1\), ";", 
              "\[IndentingNewLine]", \(\[Rho][\([i1, 
                    j1]\)]\  = \ \[Rho][\([i1, j1]\)] + \[Delta]x*\[Delta]y\),
               ";"}]}], "]"}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.68"],

Cell[TextData[{
  "Note that matrix indices are increased by 1 over those in Eqs. ",
  ButtonBox["(7.3.3)",
    ButtonData:>{"Chapter7.nb", "(7.3.3)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.4)",
    ButtonData:>{"Chapter7.nb", "(7.3.4)"},
    ButtonStyle->"Hyperlink"],
  " ,  in order to comply with list notation:  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({i, j}\)\(\ \)\(=\)\(\ \)\({0, 0}\)\(\ \)\)\)]],
  "in the notation of Eq. ",
  ButtonBox["(7.3.3)",
    ButtonData:>{"Chapter7.nb", "(7.3.3)"},
    ButtonStyle->"Hyperlink"],
  "  corresponds to element ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho][\([1, 1]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rho]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ".   Also, note that this whole  procedure is applied to only one particle. \
We must now apply it to all the particles. Before we do so,  note that we did \
not divide the density increment by ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  "; nor did we multiply by ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". That's because these factors are the same for every particle. It is more \
efficient to wait until we have incremented the density due to all the \
particles, then multiply the density matrix by these constant factors \
(assuming that there are more particles than grid points, as is usually the \
case).  The following module evaluates the density for given particle \
positions:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(density[r_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[CapitalDelta]A}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*area\ of\ a\ cell*) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(\[CapitalDelta]A = \[CapitalDelta]x*\[CapitalDelta]y\), 
            ";", "\[IndentingNewLine]", 
            StyleBox[\( (*initialize\ the\ density\ matrix*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]\  = \ Table[0, {M}, {M}]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*increment\ the\ density\ for\ all\ N\ particles\ at\
\ once*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Map[setden, r]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[
              RowBox[{"(*", 
                RowBox[{
                "properly", " ", "normalize", " ", Cell[TextData[StyleBox[
                  "\[Rho]",
                    FontColor->RGBColor[1, 0, 0]]]]}], "*)"}],
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho] = \[Rho]*m/\[CapitalDelta]A^2\), 
            " ", ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.69"],

Cell[TextData[{
  "We use the ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function in order to apply our function ",
  Cell[BoxData[
      FormBox[
        StyleBox["setden",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " to the list of positions  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\({{x\_1, y\_1},  ... , {x\_N, y\_N}}\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAs a test of the module, in Cell ",
  ButtonBox["7.70",
    ButtonData:>"Cell 7.70",
    ButtonStyle->"Hyperlink"],
  " we evaluate the density due to 20 particles with unit mass, distributed \
uniformly along the diagonal of the domain."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(r = 
        Table[{\[CapitalDelta]x\ i, \[CapitalDelta]x\ i}, {i, 0, 
            M - 1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(density[r];\)\), "\n", 
    \(\(ListContourPlot[\[Rho]];\)\ \), "\n", 
    \(Sum[\[CapitalDelta]x\ \[CapitalDelta]y\ \[Rho][\([i, j]\)], {i, 1, 
        M}, {j, 1, M}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.70"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0313765 0.0506073 -0.0313765 0.0506073 [
[.09514 -0.0125 -9 -9 ]
[.09514 -0.0125 9 0 ]
[.22166 -0.0125 -3 -9 ]
[.22166 -0.0125 3 0 ]
[.34818 -0.0125 -9 -9 ]
[.34818 -0.0125 9 0 ]
[.4747 -0.0125 -6 -9 ]
[.4747 -0.0125 6 0 ]
[.60121 -0.0125 -12 -9 ]
[.60121 -0.0125 12 0 ]
[.72773 -0.0125 -6 -9 ]
[.72773 -0.0125 6 0 ]
[.85425 -0.0125 -12 -9 ]
[.85425 -0.0125 12 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09514 -18 -4.5 ]
[-0.0125 .09514 0 4.5 ]
[-0.0125 .22166 -6 -4.5 ]
[-0.0125 .22166 0 4.5 ]
[-0.0125 .34818 -18 -4.5 ]
[-0.0125 .34818 0 4.5 ]
[-0.0125 .4747 -12 -4.5 ]
[-0.0125 .4747 0 4.5 ]
[-0.0125 .60121 -24 -4.5 ]
[-0.0125 .60121 0 4.5 ]
[-0.0125 .72773 -12 -4.5 ]
[-0.0125 .72773 0 4.5 ]
[-0.0125 .85425 -24 -4.5 ]
[-0.0125 .85425 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09514 0 m
.09514 .00625 L
s
[(2.5)] .09514 -0.0125 0 1 Mshowa
.22166 0 m
.22166 .00625 L
s
[(5)] .22166 -0.0125 0 1 Mshowa
.34818 0 m
.34818 .00625 L
s
[(7.5)] .34818 -0.0125 0 1 Mshowa
.4747 0 m
.4747 .00625 L
s
[(10)] .4747 -0.0125 0 1 Mshowa
.60121 0 m
.60121 .00625 L
s
[(12.5)] .60121 -0.0125 0 1 Mshowa
.72773 0 m
.72773 .00625 L
s
[(15)] .72773 -0.0125 0 1 Mshowa
.85425 0 m
.85425 .00625 L
s
[(17.5)] .85425 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(20)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.12045 0 m
.12045 .00375 L
s
.14575 0 m
.14575 .00375 L
s
.17105 0 m
.17105 .00375 L
s
.19636 0 m
.19636 .00375 L
s
.24696 0 m
.24696 .00375 L
s
.27227 0 m
.27227 .00375 L
s
.29757 0 m
.29757 .00375 L
s
.32287 0 m
.32287 .00375 L
s
.37348 0 m
.37348 .00375 L
s
.39879 0 m
.39879 .00375 L
s
.42409 0 m
.42409 .00375 L
s
.44939 0 m
.44939 .00375 L
s
.5 0 m
.5 .00375 L
s
.5253 0 m
.5253 .00375 L
s
.55061 0 m
.55061 .00375 L
s
.57591 0 m
.57591 .00375 L
s
.62652 0 m
.62652 .00375 L
s
.65182 0 m
.65182 .00375 L
s
.67713 0 m
.67713 .00375 L
s
.70243 0 m
.70243 .00375 L
s
.75304 0 m
.75304 .00375 L
s
.77834 0 m
.77834 .00375 L
s
.80364 0 m
.80364 .00375 L
s
.82895 0 m
.82895 .00375 L
s
.87955 0 m
.87955 .00375 L
s
.90486 0 m
.90486 .00375 L
s
.93016 0 m
.93016 .00375 L
s
.95547 0 m
.95547 .00375 L
s
.06984 0 m
.06984 .00375 L
s
.04453 0 m
.04453 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09514 m
.00625 .09514 L
s
[(2.5)] -0.0125 .09514 1 0 Mshowa
0 .22166 m
.00625 .22166 L
s
[(5)] -0.0125 .22166 1 0 Mshowa
0 .34818 m
.00625 .34818 L
s
[(7.5)] -0.0125 .34818 1 0 Mshowa
0 .4747 m
.00625 .4747 L
s
[(10)] -0.0125 .4747 1 0 Mshowa
0 .60121 m
.00625 .60121 L
s
[(12.5)] -0.0125 .60121 1 0 Mshowa
0 .72773 m
.00625 .72773 L
s
[(15)] -0.0125 .72773 1 0 Mshowa
0 .85425 m
.00625 .85425 L
s
[(17.5)] -0.0125 .85425 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(20)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .12045 m
.00375 .12045 L
s
0 .14575 m
.00375 .14575 L
s
0 .17105 m
.00375 .17105 L
s
0 .19636 m
.00375 .19636 L
s
0 .24696 m
.00375 .24696 L
s
0 .27227 m
.00375 .27227 L
s
0 .29757 m
.00375 .29757 L
s
0 .32287 m
.00375 .32287 L
s
0 .37348 m
.00375 .37348 L
s
0 .39879 m
.00375 .39879 L
s
0 .42409 m
.00375 .42409 L
s
0 .44939 m
.00375 .44939 L
s
0 .5 m
.00375 .5 L
s
0 .5253 m
.00375 .5253 L
s
0 .55061 m
.00375 .55061 L
s
0 .57591 m
.00375 .57591 L
s
0 .62652 m
.00375 .62652 L
s
0 .65182 m
.00375 .65182 L
s
0 .67713 m
.00375 .67713 L
s
0 .70243 m
.00375 .70243 L
s
0 .75304 m
.00375 .75304 L
s
0 .77834 m
.00375 .77834 L
s
0 .80364 m
.00375 .80364 L
s
0 .82895 m
.00375 .82895 L
s
0 .87955 m
.00375 .87955 L
s
0 .90486 m
.00375 .90486 L
s
0 .93016 m
.00375 .93016 L
s
0 .95547 m
.00375 .95547 L
s
0 .06984 m
.00375 .06984 L
s
0 .04453 m
.00375 .04453 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
.09514 .99375 m
.09514 1 L
s
.22166 .99375 m
.22166 1 L
s
.34818 .99375 m
.34818 1 L
s
.4747 .99375 m
.4747 1 L
s
.60121 .99375 m
.60121 1 L
s
.72773 .99375 m
.72773 1 L
s
.85425 .99375 m
.85425 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.12045 .99625 m
.12045 1 L
s
.14575 .99625 m
.14575 1 L
s
.17105 .99625 m
.17105 1 L
s
.19636 .99625 m
.19636 1 L
s
.24696 .99625 m
.24696 1 L
s
.27227 .99625 m
.27227 1 L
s
.29757 .99625 m
.29757 1 L
s
.32287 .99625 m
.32287 1 L
s
.37348 .99625 m
.37348 1 L
s
.39879 .99625 m
.39879 1 L
s
.42409 .99625 m
.42409 1 L
s
.44939 .99625 m
.44939 1 L
s
.5 .99625 m
.5 1 L
s
.5253 .99625 m
.5253 1 L
s
.55061 .99625 m
.55061 1 L
s
.57591 .99625 m
.57591 1 L
s
.62652 .99625 m
.62652 1 L
s
.65182 .99625 m
.65182 1 L
s
.67713 .99625 m
.67713 1 L
s
.70243 .99625 m
.70243 1 L
s
.75304 .99625 m
.75304 1 L
s
.77834 .99625 m
.77834 1 L
s
.80364 .99625 m
.80364 1 L
s
.82895 .99625 m
.82895 1 L
s
.87955 .99625 m
.87955 1 L
s
.90486 .99625 m
.90486 1 L
s
.93016 .99625 m
.93016 1 L
s
.95547 .99625 m
.95547 1 L
s
.06984 .99625 m
.06984 1 L
s
.04453 .99625 m
.04453 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .09514 m
1 .09514 L
s
.99375 .22166 m
1 .22166 L
s
.99375 .34818 m
1 .34818 L
s
.99375 .4747 m
1 .4747 L
s
.99375 .60121 m
1 .60121 L
s
.99375 .72773 m
1 .72773 L
s
.99375 .85425 m
1 .85425 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .12045 m
1 .12045 L
s
.99625 .14575 m
1 .14575 L
s
.99625 .17105 m
1 .17105 L
s
.99625 .19636 m
1 .19636 L
s
.99625 .24696 m
1 .24696 L
s
.99625 .27227 m
1 .27227 L
s
.99625 .29757 m
1 .29757 L
s
.99625 .32287 m
1 .32287 L
s
.99625 .37348 m
1 .37348 L
s
.99625 .39879 m
1 .39879 L
s
.99625 .42409 m
1 .42409 L
s
.99625 .44939 m
1 .44939 L
s
.99625 .5 m
1 .5 L
s
.99625 .5253 m
1 .5253 L
s
.99625 .55061 m
1 .55061 L
s
.99625 .57591 m
1 .57591 L
s
.99625 .62652 m
1 .62652 L
s
.99625 .65182 m
1 .65182 L
s
.99625 .67713 m
1 .67713 L
s
.99625 .70243 m
1 .70243 L
s
.99625 .75304 m
1 .75304 L
s
.99625 .77834 m
1 .77834 L
s
.99625 .80364 m
1 .80364 L
s
.99625 .82895 m
1 .82895 L
s
.99625 .87955 m
1 .87955 L
s
.99625 .90486 m
1 .90486 L
s
.99625 .93016 m
1 .93016 L
s
.99625 .95547 m
1 .95547 L
s
.99625 .06984 m
1 .06984 L
s
.99625 .04453 m
1 .04453 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.9 g
.01923 .02122 m
.04408 .06984 L
.06984 .07569 L
.11459 .12045 L
.12045 .1263 L
.1652 .17105 L
.17105 .17691 L
.21581 .22166 L
.22166 .22751 L
.26641 .27227 L
.27227 .27812 L
.31702 .32287 L
.32287 .32873 L
.36763 .37348 L
.37348 .37934 L
.41823 .42409 L
.42409 .42994 L
.46884 .4747 L
.4747 .48055 L
.51945 .5253 L
.5253 .53116 L
.57006 .57591 L
.57591 .58177 L
.62066 .62652 L
.62652 .63237 L
.67127 .67713 L
.67713 .68298 L
.72188 .72773 L
.72773 .73359 L
.77249 .77834 L
.77834 .78419 L
.82309 .82895 L
.82895 .8348 L
.8737 .87955 L
.87955 .88541 L
.92431 .93016 L
.93016 .95592 L
.97878 .98077 L
.01923 .98077 L
F
0 g
.01923 .02122 m
.04408 .06984 L
.06984 .07569 L
.11459 .12045 L
.12045 .1263 L
.1652 .17105 L
.17105 .17691 L
.21581 .22166 L
.22166 .22751 L
.26641 .27227 L
.27227 .27812 L
.31702 .32287 L
.32287 .32873 L
.36763 .37348 L
.37348 .37934 L
.41823 .42409 L
.42409 .42994 L
.46884 .4747 L
.4747 .48055 L
.51945 .5253 L
.5253 .53116 L
.57006 .57591 L
.57591 .58177 L
.62066 .62652 L
.62652 .63237 L
.67127 .67713 L
.67713 .68298 L
.72188 .72773 L
.72773 .73359 L
.77249 .77834 L
.77834 .78419 L
.82309 .82895 L
.82895 .8348 L
.8737 .87955 L
.87955 .88541 L
.92431 .93016 L
.93016 .95592 L
.97878 .98077 L
s
.8 g
.01923 .02406 m
.03956 .06984 L
.06984 .08171 L
.10857 .12045 L
.12045 .13232 L
.15918 .17105 L
.17105 .18293 L
.20979 .22166 L
.22166 .23353 L
.26039 .27227 L
.27227 .28414 L
.311 .32287 L
.32287 .33475 L
.36161 .37348 L
.37348 .38536 L
.41222 .42409 L
.42409 .43596 L
.46282 .4747 L
.4747 .48657 L
.51343 .5253 L
.5253 .53718 L
.56404 .57591 L
.57591 .58778 L
.61464 .62652 L
.62652 .63839 L
.66525 .67713 L
.67713 .689 L
.71586 .72773 L
.72773 .73961 L
.76647 .77834 L
.77834 .79021 L
.81707 .82895 L
.82895 .84082 L
.86768 .87955 L
.87955 .89143 L
.91829 .93016 L
.93016 .96044 L
.97594 .98077 L
.01923 .98077 L
F
0 g
.01923 .02406 m
.03956 .06984 L
.06984 .08171 L
.10857 .12045 L
.12045 .13232 L
.15918 .17105 L
.17105 .18293 L
.20979 .22166 L
.22166 .23353 L
.26039 .27227 L
.27227 .28414 L
.311 .32287 L
.32287 .33475 L
.36161 .37348 L
.37348 .38536 L
.41222 .42409 L
.42409 .43596 L
.46282 .4747 L
.4747 .48657 L
.51343 .5253 L
.5253 .53718 L
.56404 .57591 L
.57591 .58778 L
.61464 .62652 L
.62652 .63839 L
.66525 .67713 L
.67713 .689 L
.71586 .72773 L
.72773 .73961 L
.76647 .77834 L
.77834 .79021 L
.81707 .82895 L
.82895 .84082 L
.86768 .87955 L
.87955 .89143 L
.91829 .93016 L
.93016 .96044 L
.97594 .98077 L
s
.7 g
.01923 .02709 m
.03603 .06984 L
.06984 .08681 L
.10347 .12045 L
.12045 .13742 L
.15408 .17105 L
.17105 .18803 L
.20468 .22166 L
.22166 .23864 L
.25529 .27227 L
.27227 .28924 L
.3059 .32287 L
.32287 .33985 L
.35651 .37348 L
.37348 .39046 L
.40711 .42409 L
.42409 .44106 L
.45772 .4747 L
.4747 .49167 L
.50833 .5253 L
.5253 .54228 L
.55894 .57591 L
.57591 .59289 L
.60954 .62652 L
.62652 .64349 L
.66015 .67713 L
.67713 .6941 L
.71076 .72773 L
.72773 .74471 L
.76136 .77834 L
.77834 .79532 L
.81197 .82895 L
.82895 .84592 L
.86258 .87955 L
.87955 .89653 L
.91319 .93016 L
.93016 .96397 L
.97291 .98077 L
.01923 .98077 L
F
0 g
.01923 .02709 m
.03603 .06984 L
.06984 .08681 L
.10347 .12045 L
.12045 .13742 L
.15408 .17105 L
.17105 .18803 L
.20468 .22166 L
.22166 .23864 L
.25529 .27227 L
.27227 .28924 L
.3059 .32287 L
.32287 .33985 L
.35651 .37348 L
.37348 .39046 L
.40711 .42409 L
.42409 .44106 L
.45772 .4747 L
.4747 .49167 L
.50833 .5253 L
.5253 .54228 L
.55894 .57591 L
.57591 .59289 L
.60954 .62652 L
.62652 .64349 L
.66015 .67713 L
.67713 .6941 L
.71076 .72773 L
.72773 .74471 L
.76136 .77834 L
.77834 .79532 L
.81197 .82895 L
.82895 .84592 L
.86258 .87955 L
.87955 .89653 L
.91319 .93016 L
.93016 .96397 L
.97291 .98077 L
s
.6 g
.01923 .03037 m
.03306 .06984 L
.06984 .09144 L
.09884 .12045 L
.12045 .14205 L
.14945 .17105 L
.17105 .19266 L
.20005 .22166 L
.22166 .24327 L
.25066 .27227 L
.27227 .29387 L
.30127 .32287 L
.32287 .34448 L
.35188 .37348 L
.37348 .39509 L
.40248 .42409 L
.42409 .44569 L
.45309 .4747 L
.4747 .4963 L
.5037 .5253 L
.5253 .54691 L
.55431 .57591 L
.57591 .59752 L
.60491 .62652 L
.62652 .64812 L
.65552 .67713 L
.67713 .69873 L
.70613 .72773 L
.72773 .74934 L
.75673 .77834 L
.77834 .79995 L
.80734 .82895 L
.82895 .85055 L
.85795 .87955 L
.87955 .90116 L
.90856 .93016 L
.93016 .96694 L
.96963 .98077 L
.01923 .98077 L
F
0 g
.01923 .03037 m
.03306 .06984 L
.06984 .09144 L
.09884 .12045 L
.12045 .14205 L
.14945 .17105 L
.17105 .19266 L
.20005 .22166 L
.22166 .24327 L
.25066 .27227 L
.27227 .29387 L
.30127 .32287 L
.32287 .34448 L
.35188 .37348 L
.37348 .39509 L
.40248 .42409 L
.42409 .44569 L
.45309 .4747 L
.4747 .4963 L
.5037 .5253 L
.5253 .54691 L
.55431 .57591 L
.57591 .59752 L
.60491 .62652 L
.62652 .64812 L
.65552 .67713 L
.67713 .69873 L
.70613 .72773 L
.72773 .74934 L
.75673 .77834 L
.77834 .79995 L
.80734 .82895 L
.82895 .85055 L
.85795 .87955 L
.87955 .90116 L
.90856 .93016 L
.93016 .96694 L
.96963 .98077 L
s
.5 g
.01923 .03393 m
.03045 .06984 L
.06984 .0958 L
.09448 .12045 L
.12045 .14641 L
.14509 .17105 L
.17105 .19702 L
.19569 .22166 L
.22166 .24763 L
.2463 .27227 L
.27227 .29823 L
.29691 .32287 L
.32287 .34884 L
.34752 .37348 L
.37348 .39945 L
.39812 .42409 L
.42409 .45006 L
.44873 .4747 L
.4747 .50066 L
.49934 .5253 L
.5253 .55127 L
.54994 .57591 L
.57591 .60188 L
.60055 .62652 L
.62652 .65248 L
.65116 .67713 L
.67713 .70309 L
.70177 .72773 L
.72773 .7537 L
.75237 .77834 L
.77834 .80431 L
.80298 .82895 L
.82895 .85491 L
.85359 .87955 L
.87955 .90552 L
.9042 .93016 L
.93016 .96955 L
.96607 .98077 L
.01923 .98077 L
F
0 g
.01923 .03393 m
.03045 .06984 L
.06984 .0958 L
.09448 .12045 L
.12045 .14641 L
.14509 .17105 L
.17105 .19702 L
.19569 .22166 L
.22166 .24763 L
.2463 .27227 L
.27227 .29823 L
.29691 .32287 L
.32287 .34884 L
.34752 .37348 L
.37348 .39945 L
.39812 .42409 L
.42409 .45006 L
.44873 .4747 L
.4747 .50066 L
.49934 .5253 L
.5253 .55127 L
.54994 .57591 L
.57591 .60188 L
.60055 .62652 L
.62652 .65248 L
.65116 .67713 L
.67713 .70309 L
.70177 .72773 L
.72773 .7537 L
.75237 .77834 L
.77834 .80431 L
.80298 .82895 L
.82895 .85491 L
.85359 .87955 L
.87955 .90552 L
.9042 .93016 L
.93016 .96955 L
.96607 .98077 L
s
.4 g
.01923 .03786 m
.02811 .06984 L
.06984 .10002 L
.09027 .12045 L
.12045 .15062 L
.14087 .17105 L
.17105 .20123 L
.19148 .22166 L
.22166 .25184 L
.24209 .27227 L
.27227 .30245 L
.2927 .32287 L
.32287 .35305 L
.3433 .37348 L
.37348 .40366 L
.39391 .42409 L
.42409 .45427 L
.44452 .4747 L
.4747 .50487 L
.49513 .5253 L
.5253 .55548 L
.54573 .57591 L
.57591 .60609 L
.59634 .62652 L
.62652 .6567 L
.64695 .67713 L
.67713 .7073 L
.69755 .72773 L
.72773 .75791 L
.74816 .77834 L
.77834 .80852 L
.79877 .82895 L
.82895 .85913 L
.84938 .87955 L
.87955 .90973 L
.89998 .93016 L
.93016 .97189 L
.96214 .98077 L
.01923 .98077 L
F
0 g
.01923 .03786 m
.02811 .06984 L
.06984 .10002 L
.09027 .12045 L
.12045 .15062 L
.14087 .17105 L
.17105 .20123 L
.19148 .22166 L
.22166 .25184 L
.24209 .27227 L
.27227 .30245 L
.2927 .32287 L
.32287 .35305 L
.3433 .37348 L
.37348 .40366 L
.39391 .42409 L
.42409 .45427 L
.44452 .4747 L
.4747 .50487 L
.49513 .5253 L
.5253 .55548 L
.54573 .57591 L
.57591 .60609 L
.59634 .62652 L
.62652 .6567 L
.64695 .67713 L
.67713 .7073 L
.69755 .72773 L
.72773 .75791 L
.74816 .77834 L
.77834 .80852 L
.79877 .82895 L
.82895 .85913 L
.84938 .87955 L
.87955 .90973 L
.89998 .93016 L
.93016 .97189 L
.96214 .98077 L
s
.3 g
.01923 .04227 m
.02598 .06984 L
.06984 .10416 L
.08612 .12045 L
.12045 .15477 L
.13673 .17105 L
.17105 .20538 L
.18733 .22166 L
.22166 .25599 L
.23794 .27227 L
.27227 .30659 L
.28855 .32287 L
.32287 .3572 L
.33916 .37348 L
.37348 .40781 L
.38976 .42409 L
.42409 .45842 L
.44037 .4747 L
.4747 .50902 L
.49098 .5253 L
.5253 .55963 L
.54158 .57591 L
.57591 .61024 L
.59219 .62652 L
.62652 .66084 L
.6428 .67713 L
.67713 .71145 L
.69341 .72773 L
.72773 .76206 L
.74401 .77834 L
.77834 .81267 L
.79462 .82895 L
.82895 .86327 L
.84523 .87955 L
.87955 .91388 L
.89584 .93016 L
.93016 .97402 L
.95773 .98077 L
.01923 .98077 L
F
0 g
.01923 .04227 m
.02598 .06984 L
.06984 .10416 L
.08612 .12045 L
.12045 .15477 L
.13673 .17105 L
.17105 .20538 L
.18733 .22166 L
.22166 .25599 L
.23794 .27227 L
.27227 .30659 L
.28855 .32287 L
.32287 .3572 L
.33916 .37348 L
.37348 .40781 L
.38976 .42409 L
.42409 .45842 L
.44037 .4747 L
.4747 .50902 L
.49098 .5253 L
.5253 .55963 L
.54158 .57591 L
.57591 .61024 L
.59219 .62652 L
.62652 .66084 L
.6428 .67713 L
.67713 .71145 L
.69341 .72773 L
.72773 .76206 L
.74401 .77834 L
.77834 .81267 L
.79462 .82895 L
.82895 .86327 L
.84523 .87955 L
.87955 .91388 L
.89584 .93016 L
.93016 .97402 L
.95773 .98077 L
s
.2 g
.01923 .04736 m
.02401 .06984 L
.06984 .10832 L
.08196 .12045 L
.12045 .15893 L
.13257 .17105 L
.17105 .20954 L
.18318 .22166 L
.22166 .26014 L
.23378 .27227 L
.27227 .31075 L
.28439 .32287 L
.32287 .36136 L
.335 .37348 L
.37348 .41197 L
.3856 .42409 L
.42409 .46257 L
.43621 .4747 L
.4747 .51318 L
.48682 .5253 L
.5253 .56379 L
.53743 .57591 L
.57591 .6144 L
.58803 .62652 L
.62652 .665 L
.63864 .67713 L
.67713 .71561 L
.68925 .72773 L
.72773 .76622 L
.73986 .77834 L
.77834 .81682 L
.79046 .82895 L
.82895 .86743 L
.84107 .87955 L
.87955 .91804 L
.89168 .93016 L
.93016 .97599 L
.95264 .98077 L
.01923 .98077 L
F
0 g
.01923 .04736 m
.02401 .06984 L
.06984 .10832 L
.08196 .12045 L
.12045 .15893 L
.13257 .17105 L
.17105 .20954 L
.18318 .22166 L
.22166 .26014 L
.23378 .27227 L
.27227 .31075 L
.28439 .32287 L
.32287 .36136 L
.335 .37348 L
.37348 .41197 L
.3856 .42409 L
.42409 .46257 L
.43621 .4747 L
.4747 .51318 L
.48682 .5253 L
.5253 .56379 L
.53743 .57591 L
.57591 .6144 L
.58803 .62652 L
.62652 .665 L
.63864 .67713 L
.67713 .71561 L
.68925 .72773 L
.72773 .76622 L
.73986 .77834 L
.77834 .81682 L
.79046 .82895 L
.82895 .86743 L
.84107 .87955 L
.87955 .91804 L
.89168 .93016 L
.93016 .97599 L
.95264 .98077 L
s
.1 g
.01923 .05346 m
.02217 .06984 L
.06984 .11257 L
.07772 .12045 L
.12045 .16317 L
.12832 .17105 L
.17105 .21378 L
.17893 .22166 L
.22166 .26439 L
.22954 .27227 L
.27227 .315 L
.28015 .32287 L
.32287 .3656 L
.33075 .37348 L
.37348 .41621 L
.38136 .42409 L
.42409 .46682 L
.43197 .4747 L
.4747 .51743 L
.48257 .5253 L
.5253 .56803 L
.53318 .57591 L
.57591 .61864 L
.58379 .62652 L
.62652 .66925 L
.6344 .67713 L
.67713 .71985 L
.685 .72773 L
.72773 .77046 L
.73561 .77834 L
.77834 .82107 L
.78622 .82895 L
.82895 .87168 L
.83683 .87955 L
.87955 .92228 L
.88743 .93016 L
.93016 .97783 L
.94654 .98077 L
.01923 .98077 L
F
0 g
.01923 .05346 m
.02217 .06984 L
.06984 .11257 L
.07772 .12045 L
.12045 .16317 L
.12832 .17105 L
.17105 .21378 L
.17893 .22166 L
.22166 .26439 L
.22954 .27227 L
.27227 .315 L
.28015 .32287 L
.32287 .3656 L
.33075 .37348 L
.37348 .41621 L
.38136 .42409 L
.42409 .46682 L
.43197 .4747 L
.4747 .51743 L
.48257 .5253 L
.5253 .56803 L
.53318 .57591 L
.57591 .61864 L
.58379 .62652 L
.62652 .66925 L
.6344 .67713 L
.67713 .71985 L
.685 .72773 L
.72773 .77046 L
.73561 .77834 L
.77834 .82107 L
.78622 .82895 L
.82895 .87168 L
.83683 .87955 L
.87955 .92228 L
.88743 .93016 L
.93016 .97783 L
.94654 .98077 L
s
.01923 .06138 m
.02044 .06984 L
.06984 .11699 L
.07329 .12045 L
.12045 .1676 L
.1239 .17105 L
.17105 .2182 L
.17451 .22166 L
.22166 .26881 L
.22512 .27227 L
.27227 .31942 L
.27572 .32287 L
.32287 .37003 L
.32633 .37348 L
.37348 .42063 L
.37694 .42409 L
.42409 .47124 L
.42754 .4747 L
.4747 .52185 L
.47815 .5253 L
.5253 .57246 L
.52876 .57591 L
.57591 .62306 L
.57937 .62652 L
.62652 .67367 L
.62997 .67713 L
.67713 .72428 L
.68058 .72773 L
.72773 .77488 L
.73119 .77834 L
.77834 .82549 L
.7818 .82895 L
.82895 .8761 L
.8324 .87955 L
.87955 .92671 L
.88301 .93016 L
.93016 .97956 L
.93862 .98077 L
.01923 .98077 L
F
.01923 .06138 m
.02044 .06984 L
.06984 .11699 L
.07329 .12045 L
.12045 .1676 L
.1239 .17105 L
.17105 .2182 L
.17451 .22166 L
.22166 .26881 L
.22512 .27227 L
.27227 .31942 L
.27572 .32287 L
.32287 .37003 L
.32633 .37348 L
.37348 .42063 L
.37694 .42409 L
.42409 .47124 L
.42754 .4747 L
.4747 .52185 L
.47815 .5253 L
.5253 .57246 L
.52876 .57591 L
.57591 .62306 L
.57937 .62652 L
.62652 .67367 L
.62997 .67713 L
.67713 .72428 L
.68058 .72773 L
.72773 .77488 L
.73119 .77834 L
.77834 .82549 L
.7818 .82895 L
.82895 .8761 L
.8324 .87955 L
.87955 .92671 L
.88301 .93016 L
.93016 .97956 L
.93862 .98077 L
s
.9 g
.98077 .97878 m
.95592 .93016 L
.93016 .92431 L
.88541 .87955 L
.87955 .8737 L
.8348 .82895 L
.82895 .82309 L
.78419 .77834 L
.77834 .77249 L
.73359 .72773 L
.72773 .72188 L
.68298 .67713 L
.67713 .67127 L
.63237 .62652 L
.62652 .62066 L
.58177 .57591 L
.57591 .57006 L
.53116 .5253 L
.5253 .51945 L
.48055 .4747 L
.4747 .46884 L
.42994 .42409 L
.42409 .41823 L
.37934 .37348 L
.37348 .36763 L
.32873 .32287 L
.32287 .31702 L
.27812 .27227 L
.27227 .26641 L
.22751 .22166 L
.22166 .21581 L
.17691 .17105 L
.17105 .1652 L
.1263 .12045 L
.12045 .11459 L
.07569 .06984 L
.06984 .04408 L
.02122 .01923 L
.98077 .01923 L
F
0 g
.98077 .97878 m
.95592 .93016 L
.93016 .92431 L
.88541 .87955 L
.87955 .8737 L
.8348 .82895 L
.82895 .82309 L
.78419 .77834 L
.77834 .77249 L
.73359 .72773 L
.72773 .72188 L
.68298 .67713 L
.67713 .67127 L
.63237 .62652 L
.62652 .62066 L
.58177 .57591 L
.57591 .57006 L
.53116 .5253 L
.5253 .51945 L
.48055 .4747 L
.4747 .46884 L
.42994 .42409 L
.42409 .41823 L
.37934 .37348 L
.37348 .36763 L
.32873 .32287 L
.32287 .31702 L
.27812 .27227 L
.27227 .26641 L
.22751 .22166 L
.22166 .21581 L
.17691 .17105 L
.17105 .1652 L
.1263 .12045 L
.12045 .11459 L
.07569 .06984 L
.06984 .04408 L
.02122 .01923 L
s
.8 g
.98077 .97594 m
.96044 .93016 L
.93016 .91829 L
.89143 .87955 L
.87955 .86768 L
.84082 .82895 L
.82895 .81707 L
.79021 .77834 L
.77834 .76647 L
.73961 .72773 L
.72773 .71586 L
.689 .67713 L
.67713 .66525 L
.63839 .62652 L
.62652 .61464 L
.58778 .57591 L
.57591 .56404 L
.53718 .5253 L
.5253 .51343 L
.48657 .4747 L
.4747 .46282 L
.43596 .42409 L
.42409 .41222 L
.38536 .37348 L
.37348 .36161 L
.33475 .32287 L
.32287 .311 L
.28414 .27227 L
.27227 .26039 L
.23353 .22166 L
.22166 .20979 L
.18293 .17105 L
.17105 .15918 L
.13232 .12045 L
.12045 .10857 L
.08171 .06984 L
.06984 .03956 L
.02406 .01923 L
.98077 .01923 L
F
0 g
.98077 .97594 m
.96044 .93016 L
.93016 .91829 L
.89143 .87955 L
.87955 .86768 L
.84082 .82895 L
.82895 .81707 L
.79021 .77834 L
.77834 .76647 L
.73961 .72773 L
.72773 .71586 L
.689 .67713 L
.67713 .66525 L
.63839 .62652 L
.62652 .61464 L
.58778 .57591 L
.57591 .56404 L
.53718 .5253 L
.5253 .51343 L
.48657 .4747 L
.4747 .46282 L
.43596 .42409 L
.42409 .41222 L
.38536 .37348 L
.37348 .36161 L
.33475 .32287 L
.32287 .311 L
.28414 .27227 L
.27227 .26039 L
.23353 .22166 L
.22166 .20979 L
.18293 .17105 L
.17105 .15918 L
.13232 .12045 L
.12045 .10857 L
.08171 .06984 L
.06984 .03956 L
.02406 .01923 L
s
.7 g
.98077 .97291 m
.96397 .93016 L
.93016 .91319 L
.89653 .87955 L
.87955 .86258 L
.84592 .82895 L
.82895 .81197 L
.79532 .77834 L
.77834 .76136 L
.74471 .72773 L
.72773 .71076 L
.6941 .67713 L
.67713 .66015 L
.64349 .62652 L
.62652 .60954 L
.59289 .57591 L
.57591 .55894 L
.54228 .5253 L
.5253 .50833 L
.49167 .4747 L
.4747 .45772 L
.44106 .42409 L
.42409 .40711 L
.39046 .37348 L
.37348 .35651 L
.33985 .32287 L
.32287 .3059 L
.28924 .27227 L
.27227 .25529 L
.23864 .22166 L
.22166 .20468 L
.18803 .17105 L
.17105 .15408 L
.13742 .12045 L
.12045 .10347 L
.08681 .06984 L
.06984 .03603 L
.02709 .01923 L
.98077 .01923 L
F
0 g
.98077 .97291 m
.96397 .93016 L
.93016 .91319 L
.89653 .87955 L
.87955 .86258 L
.84592 .82895 L
.82895 .81197 L
.79532 .77834 L
.77834 .76136 L
.74471 .72773 L
.72773 .71076 L
.6941 .67713 L
.67713 .66015 L
.64349 .62652 L
.62652 .60954 L
.59289 .57591 L
.57591 .55894 L
.54228 .5253 L
.5253 .50833 L
.49167 .4747 L
.4747 .45772 L
.44106 .42409 L
.42409 .40711 L
.39046 .37348 L
.37348 .35651 L
.33985 .32287 L
.32287 .3059 L
.28924 .27227 L
.27227 .25529 L
.23864 .22166 L
.22166 .20468 L
.18803 .17105 L
.17105 .15408 L
.13742 .12045 L
.12045 .10347 L
.08681 .06984 L
.06984 .03603 L
.02709 .01923 L
s
.6 g
.98077 .96963 m
.96694 .93016 L
.93016 .90856 L
.90116 .87955 L
.87955 .85795 L
.85055 .82895 L
.82895 .80734 L
.79995 .77834 L
.77834 .75673 L
.74934 .72773 L
.72773 .70613 L
.69873 .67713 L
.67713 .65552 L
.64812 .62652 L
.62652 .60491 L
.59752 .57591 L
.57591 .55431 L
.54691 .5253 L
.5253 .5037 L
.4963 .4747 L
.4747 .45309 L
.44569 .42409 L
.42409 .40248 L
.39509 .37348 L
.37348 .35188 L
.34448 .32287 L
.32287 .30127 L
.29387 .27227 L
.27227 .25066 L
.24327 .22166 L
.22166 .20005 L
.19266 .17105 L
.17105 .14945 L
.14205 .12045 L
.12045 .09884 L
.09144 .06984 L
.06984 .03306 L
.03037 .01923 L
.98077 .01923 L
F
0 g
.98077 .96963 m
.96694 .93016 L
.93016 .90856 L
.90116 .87955 L
.87955 .85795 L
.85055 .82895 L
.82895 .80734 L
.79995 .77834 L
.77834 .75673 L
.74934 .72773 L
.72773 .70613 L
.69873 .67713 L
.67713 .65552 L
.64812 .62652 L
.62652 .60491 L
.59752 .57591 L
.57591 .55431 L
.54691 .5253 L
.5253 .5037 L
.4963 .4747 L
.4747 .45309 L
.44569 .42409 L
.42409 .40248 L
.39509 .37348 L
.37348 .35188 L
.34448 .32287 L
.32287 .30127 L
.29387 .27227 L
.27227 .25066 L
.24327 .22166 L
.22166 .20005 L
.19266 .17105 L
.17105 .14945 L
.14205 .12045 L
.12045 .09884 L
.09144 .06984 L
.06984 .03306 L
.03037 .01923 L
s
.5 g
.98077 .96607 m
.96955 .93016 L
.93016 .9042 L
.90552 .87955 L
.87955 .85359 L
.85491 .82895 L
.82895 .80298 L
.80431 .77834 L
.77834 .75237 L
.7537 .72773 L
.72773 .70177 L
.70309 .67713 L
.67713 .65116 L
.65248 .62652 L
.62652 .60055 L
.60188 .57591 L
.57591 .54994 L
.55127 .5253 L
.5253 .49934 L
.50066 .4747 L
.4747 .44873 L
.45006 .42409 L
.42409 .39812 L
.39945 .37348 L
.37348 .34752 L
.34884 .32287 L
.32287 .29691 L
.29823 .27227 L
.27227 .2463 L
.24763 .22166 L
.22166 .19569 L
.19702 .17105 L
.17105 .14509 L
.14641 .12045 L
.12045 .09448 L
.0958 .06984 L
.06984 .03045 L
.03393 .01923 L
.98077 .01923 L
F
0 g
.98077 .96607 m
.96955 .93016 L
.93016 .9042 L
.90552 .87955 L
.87955 .85359 L
.85491 .82895 L
.82895 .80298 L
.80431 .77834 L
.77834 .75237 L
.7537 .72773 L
.72773 .70177 L
.70309 .67713 L
.67713 .65116 L
.65248 .62652 L
.62652 .60055 L
.60188 .57591 L
.57591 .54994 L
.55127 .5253 L
.5253 .49934 L
.50066 .4747 L
.4747 .44873 L
.45006 .42409 L
.42409 .39812 L
.39945 .37348 L
.37348 .34752 L
.34884 .32287 L
.32287 .29691 L
.29823 .27227 L
.27227 .2463 L
.24763 .22166 L
.22166 .19569 L
.19702 .17105 L
.17105 .14509 L
.14641 .12045 L
.12045 .09448 L
.0958 .06984 L
.06984 .03045 L
.03393 .01923 L
s
.4 g
.98077 .96214 m
.97189 .93016 L
.93016 .89998 L
.90973 .87955 L
.87955 .84938 L
.85913 .82895 L
.82895 .79877 L
.80852 .77834 L
.77834 .74816 L
.75791 .72773 L
.72773 .69755 L
.7073 .67713 L
.67713 .64695 L
.6567 .62652 L
.62652 .59634 L
.60609 .57591 L
.57591 .54573 L
.55548 .5253 L
.5253 .49513 L
.50487 .4747 L
.4747 .44452 L
.45427 .42409 L
.42409 .39391 L
.40366 .37348 L
.37348 .3433 L
.35305 .32287 L
.32287 .2927 L
.30245 .27227 L
.27227 .24209 L
.25184 .22166 L
.22166 .19148 L
.20123 .17105 L
.17105 .14087 L
.15062 .12045 L
.12045 .09027 L
.10002 .06984 L
.06984 .02811 L
.03786 .01923 L
.98077 .01923 L
F
0 g
.98077 .96214 m
.97189 .93016 L
.93016 .89998 L
.90973 .87955 L
.87955 .84938 L
.85913 .82895 L
.82895 .79877 L
.80852 .77834 L
.77834 .74816 L
.75791 .72773 L
.72773 .69755 L
.7073 .67713 L
.67713 .64695 L
.6567 .62652 L
.62652 .59634 L
.60609 .57591 L
.57591 .54573 L
.55548 .5253 L
.5253 .49513 L
.50487 .4747 L
.4747 .44452 L
.45427 .42409 L
.42409 .39391 L
.40366 .37348 L
.37348 .3433 L
.35305 .32287 L
.32287 .2927 L
.30245 .27227 L
.27227 .24209 L
.25184 .22166 L
.22166 .19148 L
.20123 .17105 L
.17105 .14087 L
.15062 .12045 L
.12045 .09027 L
.10002 .06984 L
.06984 .02811 L
.03786 .01923 L
s
.3 g
.98077 .95773 m
.97402 .93016 L
.93016 .89584 L
.91388 .87955 L
.87955 .84523 L
.86327 .82895 L
.82895 .79462 L
.81267 .77834 L
.77834 .74401 L
.76206 .72773 L
.72773 .69341 L
.71145 .67713 L
.67713 .6428 L
.66084 .62652 L
.62652 .59219 L
.61024 .57591 L
.57591 .54158 L
.55963 .5253 L
.5253 .49098 L
.50902 .4747 L
.4747 .44037 L
.45842 .42409 L
.42409 .38976 L
.40781 .37348 L
.37348 .33916 L
.3572 .32287 L
.32287 .28855 L
.30659 .27227 L
.27227 .23794 L
.25599 .22166 L
.22166 .18733 L
.20538 .17105 L
.17105 .13673 L
.15477 .12045 L
.12045 .08612 L
.10416 .06984 L
.06984 .02598 L
.04227 .01923 L
.98077 .01923 L
F
0 g
.98077 .95773 m
.97402 .93016 L
.93016 .89584 L
.91388 .87955 L
.87955 .84523 L
.86327 .82895 L
.82895 .79462 L
.81267 .77834 L
.77834 .74401 L
.76206 .72773 L
.72773 .69341 L
.71145 .67713 L
.67713 .6428 L
.66084 .62652 L
.62652 .59219 L
.61024 .57591 L
.57591 .54158 L
.55963 .5253 L
.5253 .49098 L
.50902 .4747 L
.4747 .44037 L
.45842 .42409 L
.42409 .38976 L
.40781 .37348 L
.37348 .33916 L
.3572 .32287 L
.32287 .28855 L
.30659 .27227 L
.27227 .23794 L
.25599 .22166 L
.22166 .18733 L
.20538 .17105 L
.17105 .13673 L
.15477 .12045 L
.12045 .08612 L
.10416 .06984 L
.06984 .02598 L
.04227 .01923 L
s
.2 g
.98077 .95264 m
.97599 .93016 L
.93016 .89168 L
.91804 .87955 L
.87955 .84107 L
.86743 .82895 L
.82895 .79046 L
.81682 .77834 L
.77834 .73986 L
.76622 .72773 L
.72773 .68925 L
.71561 .67713 L
.67713 .63864 L
.665 .62652 L
.62652 .58803 L
.6144 .57591 L
.57591 .53743 L
.56379 .5253 L
.5253 .48682 L
.51318 .4747 L
.4747 .43621 L
.46257 .42409 L
.42409 .3856 L
.41197 .37348 L
.37348 .335 L
.36136 .32287 L
.32287 .28439 L
.31075 .27227 L
.27227 .23378 L
.26014 .22166 L
.22166 .18318 L
.20954 .17105 L
.17105 .13257 L
.15893 .12045 L
.12045 .08196 L
.10832 .06984 L
.06984 .02401 L
.04736 .01923 L
.98077 .01923 L
F
0 g
.98077 .95264 m
.97599 .93016 L
.93016 .89168 L
.91804 .87955 L
.87955 .84107 L
.86743 .82895 L
.82895 .79046 L
.81682 .77834 L
.77834 .73986 L
.76622 .72773 L
.72773 .68925 L
.71561 .67713 L
.67713 .63864 L
.665 .62652 L
.62652 .58803 L
.6144 .57591 L
.57591 .53743 L
.56379 .5253 L
.5253 .48682 L
.51318 .4747 L
.4747 .43621 L
.46257 .42409 L
.42409 .3856 L
.41197 .37348 L
.37348 .335 L
.36136 .32287 L
.32287 .28439 L
.31075 .27227 L
.27227 .23378 L
.26014 .22166 L
.22166 .18318 L
.20954 .17105 L
.17105 .13257 L
.15893 .12045 L
.12045 .08196 L
.10832 .06984 L
.06984 .02401 L
.04736 .01923 L
s
.1 g
.98077 .94654 m
.97783 .93016 L
.93016 .88743 L
.92228 .87955 L
.87955 .83683 L
.87168 .82895 L
.82895 .78622 L
.82107 .77834 L
.77834 .73561 L
.77046 .72773 L
.72773 .685 L
.71985 .67713 L
.67713 .6344 L
.66925 .62652 L
.62652 .58379 L
.61864 .57591 L
.57591 .53318 L
.56803 .5253 L
.5253 .48257 L
.51743 .4747 L
.4747 .43197 L
.46682 .42409 L
.42409 .38136 L
.41621 .37348 L
.37348 .33075 L
.3656 .32287 L
.32287 .28015 L
.315 .27227 L
.27227 .22954 L
.26439 .22166 L
.22166 .17893 L
.21378 .17105 L
.17105 .12832 L
.16317 .12045 L
.12045 .07772 L
.11257 .06984 L
.06984 .02217 L
.05346 .01923 L
.98077 .01923 L
F
0 g
.98077 .94654 m
.97783 .93016 L
.93016 .88743 L
.92228 .87955 L
.87955 .83683 L
.87168 .82895 L
.82895 .78622 L
.82107 .77834 L
.77834 .73561 L
.77046 .72773 L
.72773 .685 L
.71985 .67713 L
.67713 .6344 L
.66925 .62652 L
.62652 .58379 L
.61864 .57591 L
.57591 .53318 L
.56803 .5253 L
.5253 .48257 L
.51743 .4747 L
.4747 .43197 L
.46682 .42409 L
.42409 .38136 L
.41621 .37348 L
.37348 .33075 L
.3656 .32287 L
.32287 .28015 L
.315 .27227 L
.27227 .22954 L
.26439 .22166 L
.22166 .17893 L
.21378 .17105 L
.17105 .12832 L
.16317 .12045 L
.12045 .07772 L
.11257 .06984 L
.06984 .02217 L
.05346 .01923 L
s
.98077 .93862 m
.97956 .93016 L
.93016 .88301 L
.92671 .87955 L
.87955 .8324 L
.8761 .82895 L
.82895 .7818 L
.82549 .77834 L
.77834 .73119 L
.77488 .72773 L
.72773 .68058 L
.72428 .67713 L
.67713 .62997 L
.67367 .62652 L
.62652 .57937 L
.62306 .57591 L
.57591 .52876 L
.57246 .5253 L
.5253 .47815 L
.52185 .4747 L
.4747 .42754 L
.47124 .42409 L
.42409 .37694 L
.42063 .37348 L
.37348 .32633 L
.37003 .32287 L
.32287 .27572 L
.31942 .27227 L
.27227 .22512 L
.26881 .22166 L
.22166 .17451 L
.2182 .17105 L
.17105 .1239 L
.1676 .12045 L
.12045 .07329 L
.11699 .06984 L
.06984 .02044 L
.06138 .01923 L
.98077 .01923 L
F
.98077 .93862 m
.97956 .93016 L
.93016 .88301 L
.92671 .87955 L
.87955 .8324 L
.8761 .82895 L
.82895 .7818 L
.82549 .77834 L
.77834 .73119 L
.77488 .72773 L
.72773 .68058 L
.72428 .67713 L
.67713 .62997 L
.67367 .62652 L
.62652 .57937 L
.62306 .57591 L
.57591 .52876 L
.57246 .5253 L
.5253 .47815 L
.52185 .4747 L
.4747 .42754 L
.47124 .42409 L
.42409 .37694 L
.42063 .37348 L
.37348 .32633 L
.37003 .32287 L
.32287 .27572 L
.31942 .27227 L
.27227 .22512 L
.26881 .22166 L
.22166 .17451 L
.2182 .17105 L
.17105 .1239 L
.1676 .12045 L
.12045 .07329 L
.11699 .06984 L
.06984 .02044 L
.06138 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00=Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd07?ooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQGooooo1?l000000ol@413oooooooooo`05o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd05?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000000olb<S;ogMgMooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool0
0ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01?ooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool003Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Nooooo`03ogMgMolb<S;ooooo01cooooo
00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool00ol0003oooooooooo`02ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05Oooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000fooooo`03oiRHV?lQ8B7o
k^k^017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03ojVYZOmEEEGo
oooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo000gooooo`03oiRHV?lQ
8B7ok^k^00oooooo00?oMgMgoc8b<_ooool07_ooool00omgMgOo<S8booooo`0Mooooo`03ob4Q8Ooo
oooooooo00kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000005oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Gooooo
00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01Cooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo000hooooo`03ogMg
MomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`05o`000?lQ8B7o0000oc8b
<_o<c<`07_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooooooo
o`05ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo00Go
oooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`03ojVYZOmgMgOooooo
00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01Wooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000eooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00Go
410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo00?o0000ooooooooool00_ooool01Ol0003o
^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool05Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`00=Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
1?l0000Mooooo`Co00007?ooool5o`0000cooooo1?l0000Iooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`Co00005Oooool00omEEEGoIVIVo`000005ooooo`Co00005Oooool00omE
EEGoIVIVo`000004ooooo`Go00003?ooool4o`0001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool002;oooooool00015o`0000;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`3ooooood7ooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo0?oooooo@Oooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0oooooom1
ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooo4Ol0003oooooobcooooo0_l00002oooo
o`008_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo00000?oo0000=Ol00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooooooooooo
0000=?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooooooo`0003;o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ool2o`0000Kooooo1?l000000oo<c<co0000o`00003oo`0002Wo00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00oooool3o`0000Oooooo1?l00002olc<c?oo0000:?l00006
ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`?o00002Oooooooo`00
02co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4o`0000[o
ooooool0000Zo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?ooool4o`0000cooooo
ool0000Xo`0000Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03ooooo`Go00002ooo
ooooo`0002So00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4
o`000003onKVi_l0003ooooo00Woooooool0000Xo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo1_l0000;oooooooo00009ol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooo`Go000000?oi^KVo`000?ooool02Oooool2o`000003
olc<c?l0003oVIVI00;o000000?oC4a<o`000?l00000ool0000Mo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?ooooo1ol0000:ooooo`;o000000?oc<c<o`000?l00000
0ol000000om<C4co0000o`00003oo`0001co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooool6o`000003onKVi_l0003ooooo00Sooooo00Ko0000onKVi_l0003oc<c<
o`000?nIVIT3o`000003oda<C?l0003o00000?oo00006ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooo`Ko000000?oi^KVo`000?ooool02Oooool2o`000004olc<
c?l0003o0000oiVIV@?o000000?oC4a<o`000?l00000ool0000Jo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`;o00001?ooool;o`0000Oooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo
0000o`000?l0003oC4a<0?oo00006ol00005ooooo`;o00000_ooool002;ooooo00?o0000oooooooo
ool00oooool2o`000003oaTI6Ol0003o000000[o00001?ooool01?l0003oi^KVo`000?o<c<`2o`00
0005oiVIVOl0003o0000o`000?m<C4`0ool0000Jo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo0ol000000olI6AWo0000o`000007o`0000;oi^KV0_l00003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C03oo`0001Wo00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4o`000003oaTI6Ol0003o
000000Go000000Koc<c<o`000?l0003o0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0;o
000000GoVIVIo`000?l0003o0000oda<C03oo`0001So00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00oooool5o`000004oaTI6Ol0003o0000ofIVIPGo00000_o<c<`00ol0
003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000OoVIVIo`000?l0003o0000oda<
C?l0003o6ATI0?oo00005Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03ooooo`Ko000000Co6ATIo`000?l0003oIVIV0_l000002?nIVIWo0000o`000?l0003oc<c<o`00
0?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000?o000000?o
6ATIo`000?l00000ool0000Bo`0000Kooooo0Ol00001ooooo`7ooooo0007ooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo1ol0
00000olI6AWo0000o`000003o`000008oiVIVOl0003o0000o`000?o<c<co0000onKVi_l00003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00003o
o`00017o00001_ooool1o`00007ooooo0Oooool000Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A005
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo2?l00000
0olI6AWo0000o`000004o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00003oo`00013o
00001_ooool1o`00007ooooo0Oooool000Sooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo2Ol000001OlI6AWo0000o`000?l0003oIVIV00;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00000onIVIWo0000ofIVIP03o`000003oaTI6Ol0003o00000?oo00003ol00006ooooo`7o00000Ooo
ool1ooooo`002Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003
ooooo`[o000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0Co000000GoIVIVo`000?l0003o0000oaTI6@3o
o`00013o00001?ooool3o`0000;ooooo000:ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo2ol000001OlI6AWo0000o`000?l0
003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<1?l000001OmVIVKo0000o`000?l0003o6ATI0?oo00003ol00006ooooo`7o00000Oooool1
ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00oooool<o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<
c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`4o`000005ofIVI_l0003o0000o`00
0?lI6AT0ool0000>o`0000Kooooo0Ol00001ooooo`7ooooo0007ooooo`05o`000?nj^[[ooooooiRH
V?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo3Ol000001OlI
6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo
00Go0000onKVi_l0003o0000ok>c/`03o`000005ofIVI_l0003o0000o`000?lI6AT0ool0000=o`00
00Kooooo0Ol00001ooooo`7ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00
00Kooooo00?o0000ooooooooool00oooool>o`000005oaTI6Ol0003o0000o`000?mVIVH00_l00000
1onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00?o
000000GoIVIVo`000?l0003o0000oaTI6@3oo`0000co00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00oooool?o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onI
VIWo0000o`000?o<c<co0000onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000Go
IVIVo`000?l0003o0000oaTI6@3oo`0000_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooool@o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000GoIVIVo`00
0?l0003o0000oaTI6@3oo`0000[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooolAo`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<
c<co0000onKVi_l000000_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`00
0?l0003o0000oaTI6@3oo`0000Wo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004oooo
oako000000Coi^KVo`000?oooooooooo1Ol000000onc/k?o0000o`00003oo`0000ko00001Oooool2
o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5Ol000001Olc<c?o0000o`000?l0003o
Ogmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00002?l00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooaKo000000Go<c<co`000?l0003o0000ogmoO`02o`000005
ok>c/ol0003o0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`3oo`0000Oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooolGo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`00
0?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`00
0?lc<c<0ool00006o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?o
oooo6?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003
ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?oo0000
1Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooaWo000000Go
<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l000000oooool01Ol0003o
i^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`3oo`0000Co00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolJo`000005oc<c<ol0003o0000
o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00000ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooa_o000000Go<c<co`000?l0003o0000ogmoO`03o`000004
olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o
0000o`000?lc<c<0ool00002o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooolL
o`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`00
0?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00000Ol00005oooo
o`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooolMo`000005oc<c<ol0003o0000o`00
0?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l0
00001OmoOgoo0000o`000?l0003o<c<c0?oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00ooooolNo`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c0?ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolOo`00
0005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?go00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooolPo`000005oc<c<ol0003o0000o`000?mo
Ogl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l00000
1OmoOgoo0000o`000?l0003o<c<c0?co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooolRo`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oVi^Ko0000
0oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`3ko`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo8ol000001?m<C4co
0000o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0n_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooobCo000000CoC4a<o`000?l0003oOgmo0ol000001?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c0?Wo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooobGo000000CoC4a<o`00
0?l0003oOgmo0ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?So00001Oooool2o`0000;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo9_l000001Om<C4co0000o`000?l0003oVIVI00;o000000Coc<c<o`000?oV
i^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o
6ATIo`000?l00000m?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03
ooooobOo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KVo`0000;ooooo
00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o0000
0??o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolXo`000005
oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`000003ooooo`04o`000?oVi^Ko0000
olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00003bo`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo:Ol000001Om<C4co0000o`000?l0
003oVIVI00;o000000?oc<c<o`000?l000000oooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000lOl00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooob[o000000GoC4a<o`000?l0003o0000oiVIV@03o`000003
onKVi_l0003ooooo00;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3
o`000003oaTI6Ol0003o00000?3o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooool[o`000005oda<C?l0003o0000o`000?nIVIT00ol000000ooVi^Ko0000ooooo`02
ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI
6Ol0003o00000>oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ool/o`000005oda<C?l0003o0000o`000?nIVIT00ol000000ooVi^Ko0000ooooo`02ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000
0>ko00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooobgo000000?oC4a<o`000?l0
00000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l00000
1OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000kOl00005ooooo`;o00000_oo
ool002;ooooo00?o0000ooooooooool00oooool^o`000003oda<C?l0003o000000;o000000Go/k>c
o`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o00000>co00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooool_o`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o00000>_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooool`o`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003oi^KVo`000003
ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI
6Ol0003o00000>[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oolbo`000005ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000
0>Wo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolco`000005
ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o00000>So00001_oo
ool1o`00007ooooo0Oooool001Sooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00?ooooo=?l000001OmVIVKo0000o`000?l0003o/k>c00;o000000?oi^KVo`000?ooool0
0_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l000000olI
6AWo0000o`00003Wo`0000Kooooo0Ol00001ooooo`7ooooo000Kooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00ooooolbo`000004oc<c<ol0003o0000ofIVIP?o000000Go/k>co`00
0?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000
oda<C002o`000003oaTI6Ol0003o00000>Ko00001_ooool1o`00007ooooo0Oooool001cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03oooooc?o000000Co<c<co`000?l0003oIVIV
0ol000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnI
VIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000iOl00006ooooo`7o00000Oooool1
ooooo`006oooool00omgMgOo<S8booooo`04ooooo`?o00000ooooolgo`000005ofIVI_l0003o0000
o`000?nc/k<01Ol00002ooooooCo00001?ooool3o`0000;ooooo000Hooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooocCo000000Go6ATIo`000?l0003o0000ofIV
IP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`00
0004ogmoOol0003o0000oda<C>Oo00001_ooool1o`00007ooooo0Oooool001Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooocGo000000Go6ATIo`000?l0003o0000ofIVIP03
o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`000004
ogmoOol0003o0000oda<C>Ko00001_ooool1o`00007ooooo0Oooool001Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooocKo000000Go6ATIo`000?l0003o0000ofIVIP03o`00
0006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`000004ogmo
Ool0003o0000oda<C>Go00001_ooool1o`00007ooooo0Oooool001Sooooo1?l00006ooooo`03o`00
0?oooooooooo00?ooooo=ol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<
c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000
oc<c<`3So`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo>?l0
00001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003oooo
o`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`3Ro`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo>Ol000001OlI6AWo0000o`000?l0
003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<
c0?o000000GoOgmoo`000?l0003o0000oc<c<`3Qo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo>_l000001OlI6AWo0000o`000?l0003oIVIV00Go000000Coc<c<
o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<n3o
00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004oooooc_o000000Go6ATIo`000?l0003o
0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko
0000olc<c0Co000000CoIVIVo`000?l0003o<c<cgol00005ooooo`;o00000_ooool002;ooooo00?o
0000ooooooooool00ooooollo`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o
0000oc<c<mko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolm
o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l0
00000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<mgo00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolno`000003oaTI6Ol0003o0000
00Co000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`03o`000004ofIVI_l0003o0000oc<c<mco00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooloo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0
003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0
003o0000oc<c<m_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oom0o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<m[o00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom1o`000004oaTI6Ol0003o
0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0
003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<mWo00001_ooool1o`00007ooooo0Oooool0
02;ooooo00?o0000ooooooooool00ooooom2o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVI
o`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004
ofIVI_l0003o0000oc<c<mSo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooodoo
000000?oi^KVo`000?ooool00_ooool01Ol0003oi^KVo`000?l0003o/k>c00?o000000CoIVIVo`00
0?l0003o<c<ceol00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooom6o`00
0005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go
0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<mKo00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooom7o`000005oc<c<ol0003o0000o`000?mo
Ogl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03
o`000004ofIVI_l0003o0000oc<c<mGo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooom8o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`00
0?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c
<mCo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom9o`000005
oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000
onKVi_l0003o0000ok>c/`03o`000003ofIVI_l0003o00000=Co00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooom:o`000005oc<c<ol0003o0000o`000?moOgl00_l0
00001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000003
ofIVI_l0003oC4a<0=?o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0
0ooooom;o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000003ofIVI_l0003oC4a<0=;o00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom<o`000005oc<c<ol0003o0000
o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`05o`000003oda<C?l0003o00000<oo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l0
0004ooooodgo000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l0
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000CoOgmoo`000?l0003oC4a<d?l00005
ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooom>o`000005oc<c<ol0003o0000
o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`02o`000004ogmoOol0003o0000oda<C<oo00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooom?o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o
0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000004ogmoOol0003o
0000oda<C<ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom@
o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo
00?o0000onKVi_l000001?l000001?moOgoo0000o`000?m<C4c=o`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooDOl000001Olc<c?o0000o`000?l0003oOgmo00;o
000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o000000CoOgmo
o`000?l0003oC4a<c?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03
oooooe;o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l00000
0oooool01?l0003oi^KVo`000?o<c<`3o`000004ogmoOol0003o0000oda<C<_o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooomCo`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0ol0
00001?moOgoo0000o`000?m<C4c:o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo00?oooooE?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o000000CoOgmoo`000?l0003oC4a<bOl00006
ooooo`7o00000Oooool1ooooo`008_ooool2o`0000CoooooEOl000001Olc<c?o0000o`000?l0003o
Ogmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o0000
00CoOgmoo`000?l0003oC4a<b?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool0
0ooooomDo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko
000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o0000
00?o6ATIo`000?l00000`ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooeGo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co0000onKV
i_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l0
00000olI6AWo0000o`000032o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooooE_l000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o00000<7o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooomGo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`00
0?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<
00;o000000?o6ATIo`000?l00000`?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03oooooeSo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co
0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<
C4`00_l000000olI6AWo0000o`00002oo`0000Kooooo0Ol00001ooooo`7ooooo0009ooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`03oooooeWo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co
0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000Co0000
00?o6ATIo`000?l00000__l00006ooooo`7o00000Oooool1ooooo`002Oooool00omEEEGoZJVYoooo
o`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooF_l0
00001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000002oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
002mo`0000Kooooo0Ol00001ooooo`7ooooo0009ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03oooooe_o000000Co6ATIo`000?l0003oC4a<1?l0
00001_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nI
VIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o00000;co00001_ooool1o`00007ooooo0Oooool0
00[ooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o00000ooooomLo`00
0004oaTI6Ol0003o0000oda<C0Co000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002ko`00
00Cooooo0ol00002ooooo`002_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`03oooooego000000Co6ATIo`000?l0003oC4a<1?l00000
1_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo
0000o`000?mVIVH3o`000003oaTI6Ol0003o00000;[o00001_ooool1o`00007ooooo0Oooool000[o
oooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
ooooG_l000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_oo
ool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l0
0000^Ol00006ooooo`7o00000Oooool1ooooo`001oooool01Ol@413ooooooooooooooooo<S8b00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooooeoo000000Go6ATIo`000?l0
003o0000ofIVIP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`00
0?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000^?l00006ooooo`7o
00000Oooool1ooooo`001oooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo00?ooooo
H?l000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002
ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000
o`00002go`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooHOl0
00001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
002fo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooH_l00000
1OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04
o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002e
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooHol000001OlI
6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002do`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooomTo`000005oaTI6Ol0003o0000o`00
0?mVIVH00ol000001_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo`ol00005ooooo`;o00000_oo
ool002;ooooo00?o0000ooooooooool00ooooomVo`000004oc<c<ol0003o0000ofIVIP?o000000Go
/k>co`000?l0003oi^KVo`000004ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo
0000o`000?l0003o<c<c0;Go00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00ooooomWo`000004oc<c<ol0003o0000ofIVIP?o000000Co/k>co`000?l0003oi^KV0_l00003
ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0;Co0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooomXo`000004oc<c<ol0
003o0000ofIVIP?o000000?o/k>co`000?l000000_oVi^H01_l0003ooooooooooooooooo0000onKV
iP;o000000Co/k>co`000?l0003oOgmo0ol000000olc<c?o0000o`00002ao`0000Kooooo0Ol00001
ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooJOl000001?lc<c?o0000o`000?mVIVH3
o`000006ok>c/ol0003o0000o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o
000000GoOgmoo`000?l0003o0000oc<c<`2bo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03
o`000?oooooooooo00?oooooJ_l000001?lc<c?o0000o`000?mVIVH3o`000006ok>c/ol0003oc<c<
o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o
0000oc<c<`2ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
Jol000001?lc<c?o0000o`000?mVIVH3o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool0
1Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`2`o`0000Kooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooK?l000001?lc<c?o0000o`00
0?mVIVH5o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`00
0005ogmoOol0003o0000o`000?lc<c<0[ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`00
00CoooooKOl000001?lc<c?o0000o`000?mVIVH2o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c
0:ko00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?oooooK_l000001?lc<c?o
0000o`000?mVIVH2o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0:go00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooom_o`000004oc<c<ol0003o0000ofIVIP;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0[?l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooog3o000000?o<c<co`000?l000000ol000001onIVIWo0000o`00
0?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`00
0?l0003o0000oc<c<`2[o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo
00?oooooLOl000000olc<c?o0000oda<C003o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`00
0003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0:[o
00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooombo`000003oc<c
<ol0003oC4a<00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKV
i_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0ZOl00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03ooooogGo000000GoC4a<o`000?l0003o0000oiVI
V@02o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005
ogmoOol0003o0000o`000?lc<c<0Z?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03ooooogKo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KV
o`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0
Yol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000CoooooMol000000om<C4co0000o`00
0004o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005
ogmoOol0003o0000o`000?lc<c<0Y_l00005ooooo`;o00000_ooool002;ooooo00?o0000oooooooo
ool00ooooomho`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oVi^Ko00000_ooool0
1_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`000?l0003o0000oaTI6@2To`0000Ko
oooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooNOl000001?m<C4co0000
o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000;ooooo00Ko0000onKVi_l0003oc<c<o`000?nc
/k<3o`000005ofIVI_l0003o0000o`000?lI6AT0Xol00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooog[o000000CoC4a<o`000?l0003oOgmo0ol000001?o<c<co0000
onKVi_l00002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c0ol000000omVIVKo0000o`00002T
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooNol000001?m<
C4co0000o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000;ooooo00Ko0000onKVi_l0003oc<c<
o`000?nc/k<3o`000003ofIVI_l0003o00000:?o00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooomlo`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oV
i^Ko00000_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000?oIVIVo`000?m<C4`0X_l0
0006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooggo000000CoC4a<
o`000?l0003oOgmo1Ol000002_oVi^Ko0000oooooooooooo0000onKVi_l0003oc<c<o`000?nc/k<3
o`000003ofIVI_l0003oC4a<0:7o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooomno`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KVo`00
0002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c1Ol000000om<C4co0000o`00002No`0000Ko
oooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooomoo`000004oda<C?l0003o0000ogmoO`;o
000000Go/k>co`000?l0003oi^KVo`000002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c1Ol0
00000om<C4co0000o`00002Mo`0000Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03
oooooh3o000000CoC4a<o`000?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko000000;ooooo
00So0000onKVi_l0003oc<c<o`000?nc/k?o0000oiVIV@?o000000?oC4a<o`000?l00000W?l00006
ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooh7o000000CoC4a<o`00
0?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko000000;ooooo00So0000onKVi_l0003oc<c<
o`000?nc/k?o0000oiVIV@?o000000?oC4a<o`000?l00000Vol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03oooooh;o000000CoC4a<o`000?l0003oOgmo0_l000001Onc
/k?o0000o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0ol000001OnIVIWo0000o`00
0?l0003oC4a<09co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oon3o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`03
o`000?oVi^Ko000000;oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<09_o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooon7o`000004ogmoOol0003o0000ok>c
/`;o000000Koi^KVo`000?ooooooooooo`000?oVi^H2o`000004olc<c?l0003o0000oiVIV@?o0000
00?oC4a<o`000?l00000V?l00006ooooo`7o00000Oooool1ooooo`004?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00?oooooQ?l000001Olc
<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`05o`000?oV
i^Koi^KVo`000?o<c<`00_l000001OnIVIWo0000o`000?l0003oC4a<09Wo00001_ooool1o`00007o
oooo0Oooool001;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool00ooooon5o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc
/k?o0000o`000?oVi^Ko000000;ooooo0_l000000ooVi^Ko0000olc<c002o`000005oiVIVOl0003o
0000o`000?m<C4`0V?l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000?oooooQ_l000001Olc<c?o0000o`00
0?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<
c0;o000000GoVIVIo`000?l0003o0000oda<C02Go`0000Cooooo0ol00002ooooo`004_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03
ooooohGo000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C02F
o`0000Kooooo0Ol00001ooooo`7ooooo000Booooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00?oooooQ_l000001OlI6AWo0000o`000?l0
003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<09Go00001_ooool1o`00007ooooo0Oooool0
01;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool00ooooon7o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`00
0?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000
o`000?m<C4`0U?l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooohSo000000Go6ATI
o`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04
o`000?oVi^Ko0000olc<c0;o000000OoVIVIo`000?l0003o0000oda<C?l0003o6ATI097o00001_oo
ool1o`00007ooooo0Oooool0013ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool00ooooon9o`000005oaTI6Ol0003o0000o`000?mVIVH0
0_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2
o`000003oiVIVOl0003o000000?o000000?o6ATIo`000?l00000S_l00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03oooooh[o000000Go6ATIo`000?l0003o0000ofIVIP02
o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o
000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00002=o`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooRol000001OlI6AWo0000o`000?l0003oIVIV00;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00000onIVIWo0000o`000003o`000003oaTI6Ol0003o000008co00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooon<o`000005oaTI6Ol0003o0000o`000?mVIVH00_l0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`00
0003oiVIVOl0003oIVIV00?o000000?o6ATIo`000?l00000Rol00006ooooo`7o00000Oooool1oooo
o`008_ooool2o`0000CoooooSOl000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`00
0?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<1?l000001OmVIVKo0000
o`000?l0003o6ATI08co00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
S_l000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko
000000?ooooo00Co0000onKVi_l0003oc<c<1?l000001OmVIVKo0000o`000?l0003o6ATI08_o0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooon?o`000005oaTI6Ol0
003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0
003oi^KVo`000?o<c<`4o`000005ofIVI_l0003o0000o`000?lI6AT0R_l00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03oooooi3o000000Go6ATIo`000?l0003o0000ofIV
IP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`00
0?nc/k<00ol000001OmVIVKo0000o`000?l0003o6ATI08Wo00001_ooool1o`00007ooooo0Oooool0
02;ooooo00?o0000ooooooooool00ooooonAo`000005oaTI6Ol0003o0000o`000?mVIVH00_l00000
1onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00?o
000000GoIVIVo`000?l0003o0000oaTI6@28o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03
o`000?oooooooooo00?oooooT_l000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`00
0?l0003oc<c<o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`03o`000005ofIVI_l0
003o0000o`000?lI6AT0Qol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooi?o000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0
003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol000001OmVIVKo0000o`000?l0003o
6ATI08Ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooonDo`00
0005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l00000
0_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`000?l0003o0000oaTI6@25
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonQo`000004onKVi_l0003ooooo
ooooo`Go000000?o/k>co`000?l00000R_l00005ooooo`;o00000_ooool002;ooooo00?o0000oooo
ooooool00ooooonHo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc
<c<0Q?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooiWo0000
00Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l000000oooool01Ol0
003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`23o`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooV_l000001Olc<c?o0000o`000?l0
003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`000?nc
/k<00_l000001OmoOgoo0000o`000?l0003o<c<c08;o00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00ooooonKo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc
/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0
003o0000o`000?lc<c<0POl00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooico000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l0
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`20
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooWOl000001Olc
<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`00
0?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1oo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooW_l000001Olc<c?o0000o`000?l0003oOgmo00?o
000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`1no`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonO
o`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`00
0?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c07go00001Oooool2o`00
00;ooooo000Rooooo`03o`000?oooooooooo00?oooooX?l000001Olc<c?o0000o`000?l0003oOgmo
00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000Go
Ogmoo`000?l0003o0000oc<c<`1lo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo00?oooooXOl000001Olc<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1k
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooX_l000001Olc
<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`00
0?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1jo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooXol000001Olc<c?o0000o`000?l0003oOgmo00?o
000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`1io`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooooY?l000001Olc<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko0000
0oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1ho`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooYOl000001Olc<c?o
0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0
003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1go`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooY_l000001Olc<c?o0000o`000?l0003oOgmo00?o0000
00Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`00
0?l0003o0000oc<c<`1fo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonWo`00
0005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c07Go00001Oooool2o`0000;o
oooo000Rooooo`03o`000?oooooooooo00?oooooZOl000001Om<C4co0000o`000?l0003oVIVI00;o
000000Coc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o
0000ofIVIP?o000000?o6ATIo`000?l00000LOl00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03oooooj[o000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0
003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`00
0003oaTI6Ol0003o0000073o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00ooooon[o`000005oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`000003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
001_o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo[?l00000
1Om<C4co0000o`000?l0003oVIVI00;o000000?oc<c<o`000?l000000oooool01?l0003oi^KVo`00
0?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000K_l00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooojgo000000GoC4a<o`000?l0003o
0000oiVIV@03o`000003onKVi_l0003ooooo00;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nI
VIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o000006go00001_ooool1o`00007ooooo0Oooool0
00Co000000?o410@ooooooooool01Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool00ooooon^o`000005oda<C?l0003o0000o`000?nIVIT00ol0
00000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o000006co00001_ooool1o`00007ooooo0Oooool000;ooooo
00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00ooooon_o`000005oda<C?l0003o0000o`00
0?nIVIT00ol000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVI
o`000?l0003o0000oda<C002o`000003oaTI6Ol0003o000006_o00001_ooool1o`00007ooooo0Ooo
ool000;ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo0ol00003oooook3o000000?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o
000000?o6ATIo`000?l00000J_l00004ooooo`?o00000_ooool000;ooooo00?o0000ooooooooool0
1?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
0ooooonao`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04
o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o
000006Wo00001_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03
oooook;o000000?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co
0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l0
0000J?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooook?o0000
00?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000Iol00006
ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooo
oiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo]Ol00000
1OmVIVKo0000o`000?l0003o/k>c00;o000000?oi^KVo`000?ooool00_ooool01?l0003oi^KVo`00
0?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l000000olI6AWo0000o`00001Vo`0000Ko
oooo0Ol00001ooooo`7ooooo00000omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0000Kooooo00?o0000ooooooooool00ooooonfo`000005ofIVI_l0003o0000o`00
0?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVI
o`000?l0003o0000oda<C002o`000003oaTI6Ol0003o000006Go00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooongo`000005ofIVI_l0003o0000o`000?nc/k<00_l0
00000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o000006Co00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooonho`000005ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko
0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o000006?o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooooneo`000005oaTI6Ol0003o0000o`000?mVIVH00ol000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o
000000?o6ATIo`000?l00000H_l00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooo
]_l000001OlI6AWo0000o`000?l0003oIVIV00?o000000?o/k>co`000?l000000ol00002ooooog7o
00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo]ol000001OlI6AWo0000
o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko
0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1So`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?ooooo^?l000001OlI6AWo0000o`000?l0003oIVIV00?o0000
00Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmo
o`000?l0003o0000oc<c<`1Ro`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo^Ol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000
onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1Q
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo^_l000001OlI
6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`00
0?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1Po`0000Kooooo0Ol00001oooo
o`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo^ol000001OlI6AWo0000o`000?l0003oIVIV
00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o0000
00GoOgmoo`000?l0003o0000oc<c<`1Oo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo_?l000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<
c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000
oc<c<`1No`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo_Ol0
00001OlI6AWo0000o`000?l0003oIVIV00Go000000Coc<c<o`000?oVi^Ko00000oooool01?l0003o
i^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<ego00001_ooool1o`00007ooooo0Oooool0
02;ooooo0_l00004oooookko000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o
0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0Co000000CoIVIVo`000?l0
003o<c<cG?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooonoo`000005
oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000ooo
ool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<e_o00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00oooooo0o`000005oaTI6Ol0003o0000o`000?mV
IVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<
c<`4o`000004ofIVI_l0003o0000oc<c<e[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooooo1o`000003oaTI6Ol0003o000000Co000000OoVIVIo`000?l0003oc<c<
o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000
oc<c<eWo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo2o`00
0004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo
00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<eSo00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo3o`000004oaTI6Ol0003o0000oda<
C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`03o`000004ofIVI_l0003o0000oc<c<eOo00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooo4o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0
003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0
003o0000oc<c<eKo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ooo5o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<eGo00001_oo
ool1o`00007ooooo0Oooool002;ooooo0_l00004ooooom;o000000?oi^KVo`000?ooool00_ooool0
1Ol0003oi^KVo`000?l0003o/k>c00?o000000CoIVIVo`000?l0003o<c<cE?l00005ooooo`;o0000
0_ooool002;ooooo00?o0000ooooooooool00oooooo9o`000005oc<c<ol0003o0000o`000?moOgl0
0_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`03o`000005
ofIVI_l0003o0000o`000?lI6AT0D_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03oooool[o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000
onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000GoIVIVo`000?l0003o0000oaTI
6@1Ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooobol00000
1Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o0000
00?oc<c<o`000?nc/k<00ol000000omVIVKo0000o`00001Bo`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooc?l000001Olc<c?o0000o`000?l0003oOgmo00;o0000
00Go/k>co`000?l0003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol000000omVIVKo
0000o`00001Ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
cOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`;o000000?oc<c<o`000?nc/k<00ol000000omVIVKo0000oda<C01@o`0000Kooooo0Ol00001oooo
o`7ooooo000Rooooo`03o`000?oooooooooo00?oooooc_l000001Olc<c?o0000o`000?l0003oOgmo
00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol00000
0omVIVKo0000oda<C01?o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo
00?ooooocol000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`00
0003ooooo`;o000000?oc<c<o`000?nc/k<01Ol000000om<C4co0000o`00001<o`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`;o00001?ooooo@o`000005oc<c<ol0003o0000o`000?moOgl00_l0
00001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`05o`000003oda<
C?l0003o000004_o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooodOl0
00001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o
000000Goc<c<o`000?nc/k?o0000oiVIV@03o`000003oda<C?l0003o000004[o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooBo`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000001Oo<c<co0000ok>c/ol0
003oVIVI00?o000000?oC4a<o`000?l00000BOl00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03ooooom?o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0
003o0000onKVi_l000000oooool2o`000005olc<c?l0003o0000o`000?nIVIT00ol000000om<C4co
0000o`000018o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
e?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`;o00000_o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`0BOl00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03ooooomGo000000Go<c<co`000?l0003o0000ogmoO`02
o`000005ok>c/ol0003o0000onKVi_l000000oooool3o`000004olc<c?l0003o0000oiVIV@?o0000
00?oC4a<o`000?l00000A_l00006ooooo`7o00000Oooool1ooooo`004?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo00?ooooo
e_l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C017o`0000Kooooo0Ol0
0001ooooo`7ooooo000Booooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`03ooooomOo000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0
003o0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`00
0?m<C4`0A_l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooomSo000000Go<c<co`000?l0003o0000ogmoO`02o`00
0005ok>c/ol0003o0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0
003o0000o`000?m<C4`0AOl00004ooooo`?o00000_ooool001;ooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooeol000001?lI6AWo0000o`00
0?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000043o00001_oo
ool1o`00007ooooo0Oooool001;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool00ooooooHo`000004oaTI6Ol0003o0000oda<C0?o0000
00OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l00000
1OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000?ol00006ooooo`7o00000Ooo
ool1ooooo`004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00ooooooIo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<
o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003o
C4a<00;o000000?o6ATIo`000?l00000?_l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooooooJo`00
0004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000;ooooo
00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`00
0?l00000?Ol00006ooooo`7o00000Oooool1ooooo`004?ooool00omEEEGoIVIVo`000005ooooo`Co
00001_ooool00ol0003oooooooooo`03ooooom_o000000Co6ATIo`000?l0003oC4a<0ol000001onI
VIWo0000o`000?o<c<co0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVI
VOl0003o0000o`000?m<C4`00_l000000olI6AWo0000o`00000lo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?ooooog?l000001?lI6AWo0000o`000?m<C4`3o`000007
oiVIVOl0003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000?o
VIVIo`000?l000001?l000000olI6AWo0000o`00000ko`0000Kooooo0Ol00001ooooo`7ooooo000R
ooooo`03o`000?oooooooooo00?ooooogOl000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0
003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`00
0?l0003oIVIV0ol000000olI6AWo0000o`00000jo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooog_l000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003o
c<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIV
IP?o000000?o6ATIo`000?l00000>Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Co
oooogol000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_oo
ool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l0
0000>?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooooPo`000004oaTI
6Ol0003o0000oda<C0Co000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`000?oVi^Ko
0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00000go`0000Kooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooohOl000001?lI6AWo0000o`00
0?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2
o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=_l00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03ooooon;o000000Go6ATIo`000?l0003o0000ofIV
IP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`00
0004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=Ol00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03ooooon?o000000Go6ATIo`000?l0003o0000ofIVIP03
o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004
oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=?l00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooonCo000000Go6ATIo`000?l0003o0000ofIVIP03o`00
0006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000<ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooonGo000000Go6ATIo`000?l0003o0000ofIVIP03o`000006
ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0
003o0000ofIVIP?o000000?o6ATIo`000?l00000<_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooonKo000000Go6ATIo`000?l0003o0000ofIVIP03o`000006ok>c
/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o
0000ofIVIP?o000000?o6ATIo`000?l00000<Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2
o`0000Coooooiol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000
onKVi_l00002oooood3o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
jOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000004oooo
o`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c03;o00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooZo`000005oc<c<ol0003o
0000o`000?moOgl00_l000001?nc/k?o0000o`000?oVi^H2o`0000?ooooo00Go0000onKVi_l0003o
0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0<Ol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooon_o000000Go<c<co`000?l0003o0000ogmoO`02o`00
0003ok>c/ol0003o000000;oi^KV00Ko0000ooooooooooooooooo`000?oVi^H2o`000004ok>c/ol0
003o0000ogmoO`?o000000?o<c<co`000?l00000;_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooonco000000Go<c<co`000?l0003o0000ogmoO`02o`000006ok>c
/ol0003o0000o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`0_o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooookOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Ko/k>co`000?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c02ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo^o`00
0005oc<c<ol0003o0000o`000?moOgl00_l000001_nc/k?o0000olc<c?l0003oi^KVo`0000?ooooo
00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0;Ol00006oooo
o`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooonoo000000Go<c<co`000?l0
003o0000ogmoO`04o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0;?l00006ooooo`7o00000Oooool1ooooo`008_oo
ool2o`0000Coooool?l000001olc<c?o0000o`000?l0003oOgmoo`000?nIVIT00_l000001?o<c<co
0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0
003o<c<c02_o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooolOl00000
1olc<c?o0000o`000?l0003oOgmoo`000?nIVIT00_l000001?o<c<co0000onKVi_l00003ooooo`05
o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c02[o00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooobo`000003oc<c<ol0003o0000
00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0:Ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooo?o000000?o<c<co`000?l000000ol000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`0Xo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?ooooom?l000000olc<c?o0000oda<C003o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c
02Oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooeo`000003
oc<c<ol0003oC4a<00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000
onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<09_l00006ooooo`7o0000
0Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooooSo000000GoC4a<o`000?l0003o0000
oiVIV@02o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`00
0005ogmoOol0003o0000o`000?lc<c<09Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0
003oooooooooo`03ooooooWo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003o
i^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc
<c<09?l00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooon_l000001Om<C4co0000
o`000?l0003oVIVI00;o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o
/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`0So`0000Gooooo0_l00002ooooo`008_ooool0
0ol0003oooooooooo`03oooooo_o000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0
003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`00
0003oaTI6Ol0003o000001oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00oooooolo`000005oda<C?l0003o0000o`000?nIVIT00_l000001?o<c<co0000onKVi_l00002
ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol00002oaTI6Aoo0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooomo`000005oda<C?l0
003o0000o`000?nIVIT00_l000001?o<c<co0000onKVi_l00002ooooo`04o`000?oVi^Ko0000olc<
c0;o000000CoVIVIo`000?l0003oIVIV1?l000000olI6AWo0000o`00000Lo`0000Kooooo0Ol00001
ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooo_l000001Om<C4co0000o`000?l0003o
VIVI00;o000000Coc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIPCo000000?o6ATIo`000?l000006ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooooo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004
olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001_nIVIWo0000o`000?mV
IVKo0000oda<C0;o000000?o6ATIo`000?l000006_l00006ooooo`7o00000Oooool1ooooo`001?l0
00000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03oooooooo00000Ol000001Om<C4co0000
o`000?l0003oVIVI00Co000000Soi^KVo`000?ooooooooooo`000?oVi^Ko0000olc<c0;o000000Ko
VIVIo`000?l0003oIVIVo`000?m<C4`2o`000003oaTI6Ol0003o000001Wo00001_ooool1o`00007o
oooo0Oooool000;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooool00002o`000007oda<
C?l0003o0000o`000?nIVIWo0000ok>c/`02o`000008onKVi_l0003oooooooooool0003oi^KVo`00
0?o<c<`2o`000003oiVIVOl0003o000000;o000000CoC4a<o`000?l0003o6ATI6_l00006ooooo`7o
00000Oooool1ooooo`000_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo013ooooo
00?o0000ooooooooool00oooool3o`0000?oooooool00003o`000007oda<C?l0003o0000o`000?nI
VIWo0000ok>c/`02o`000008onKVi_l0003oooooooooool0003oi^KVo`000?o<c<`2o`000003oiVI
VOl0003o000000;o000000CoC4a<o`000?l0003o6ATI6Ol00004ooooo`?o00000_ooool000;ooooo
00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool00oooooooo`0000Co000000?oC4a<o`000?l000000ol000001Onc/k?o0000
o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l00002oiVIV@?o000000CoC4a<o`00
0?l0003o6ATI6?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`05oooo
o`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00?oooooool00005o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KV
o`000002ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoVIVIo`000?l0003o0000oda<C002o`00
0003oaTI6Ol0003o000001Go00001_ooool1o`00007ooooo0Oooool000;ooooo00?o0000oooooooo
ool01Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooooooo`0000Ko000000CoC4a<o`000?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko
000000;ooooo00Co0000onKVi_l0003oc<c<0ol000001OnIVIWo0000o`000?l0003oC4a<00;o0000
00?o6ATIo`000?l000005?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?oooooool00007o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0
003oi^KVo`000002ooooo`03o`000?oVi^Ko000000;oc<c<0_l000001OnIVIWo0000o`000?l0003o
C4a<00;o000000?o6ATIo`000?l000004ol00006ooooo`7o00000Oooool1ooooo`0000?oEEEEofIV
I_l000001?ooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo00?oooooool0000;o`00
0004ogmoOol0003o0000ok>c/`;o000000Koi^KVo`000?ooooooooooo`000?oVi^H2o`000004olc<
c?l0003o0000oiVIV@?o000000CoC4a<o`000?l0003o6ATI5?l00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03oooooooo00002?l000001Olc<c?o0000o`000?l0003oOgmo
00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`05o`000?oVi^Koi^KVo`000?o<c<`00_l0
00001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000004Ol00006ooooo`7o0000
0Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00002Ol000001Olc<c?o0000o`00
0?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`;o000000?oi^KVo`000?o<
c<`00_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000004?l00006oooo
o`7o00000Oooool1ooooo`008_ooool2o`0000Coooooool0000:o`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000003ol00005ooooo`;o0000
0_ooool002;ooooo00?o0000ooooooooool00oooooooo`0000Wo000000Go6ATIo`000?l0003o0000
ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C00Co`0000Kooooo0Ol00001ooooo`7ooooo000R
ooooo`03o`000?oooooooooo00?oooooool0000:o`000005oaTI6Ol0003o0000o`000?mVIVH00_l0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`00
0005oiVIVOl0003o0000o`000?m<C4`04_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0
003oooooooooo`03oooooooo00002ol000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVI
o`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo
0000o`000?l0003oC4a<017o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00oooooooo`0000co000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000
olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C00@o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000=o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000
onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000o`0000;oC4a<
3_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00003_l0
00001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Co0000onKVi_l0003oc<c<0_l000000onIVIWo0000o`000002o`000003oda<C?l0003o
000000_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`00
00oo000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000_l000000om<C4co
0000o`00000:o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000@o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000
onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000;o000000?o
C4a<o`000?l000002Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Coooooool0000A
o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l0
00000oooool01?l0003oi^KVo`000?o<c<`2o`0000;oVIVI0ol000000om<C4co0000o`000008o`00
00Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03oooooooo00004_l000001OlI6AWo
0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co
0000onKVi_l0003oc<c<0ol000000onIVIWo0000o`00000;o`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooool0000Co`000005oaTI6Ol0003o0000o`000?mVIVH0
0_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`@
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000Do`00
0003oaTI6Ol0003o000000Co000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00?o
0000onKVi_l000000_o<c<`3o`000003oiVIVOl0003o000000So00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0001Go000000Co6ATIo`000?l0003oC4a<0ol0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?l00002olc<
c0co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0001Ko
000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co0000onKVi_l000000ooo
ool00ol0003oi^KVonKViP02o`0000;oc<c<2_l00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03oooooooo00005ol000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0
003o0000olc<c?l0003oi^KVo`000003ooooo`?o000000?oi^KVo`000?l000002_l00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00006?l000001?lI6AWo0000
o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000005ooooo`go00001_ooool1
o`00007ooooo0Oooool002;ooooo0_l00004oooooooo00006Ol000001?lI6AWo0000o`000?m<C4`3
o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000008ooooo`?o000000?oc<c<o`000?l00000
1?l00004ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00oooooooo`0001co000000Go
C4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KVo`0000Wooooo0_l000000oo<c<co
0000o`000004o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000Mo`000005oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`00000:ooooo`;o
000000?oc<c<o`000?l000000ol00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooo
ooooo`03oooooooo00007_l000000om<C4co0000o`000003o`000004olc<c?l0003oi^KVo`0000Wo
oooo0_l000000oo<c<co0000o`000003o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`00
0?oooooooooo00?oooooool0000Oo`000004oda<C?l0003o0000oiVIV@?o000000?oi^KVo`000?oo
ool02Oooool7o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000Po`000006oda<C?l0003o0000oiVIVOl0003oc<c<0_l0000:ooooo`;o000000?oc<c<o`00
0?l000000_l00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000:?l0000;ooooo`Ko00001Oooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0002Wo00002_ooool6o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oo
ooooo`0002[o00002_ooool5o`0000Cooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03
oooooooo00008ol000000om<C4co0000o`000002o`0000;oi^KV0_l00008ooooo`Go00001Oooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0002[o00000_oVi^H2o`00
00Oooooo1?l00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000;Ol000000ooVi^Ko0000o`000005ooooo`Co00001Oooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooooo`0002oo000000?oi^KVo`000?ooool01?ooool3o`0000Gooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000co`0000?ooooo0ol0
0005ooooo`7o00000Oooool1ooooo`003oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00?oooooool0000eo`0000;ooooo0_l00005ooooo`7o00000Ooo
ool1ooooo`003oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00?oooooool0000io`0000Gooooo0Ol00001ooooo`7ooooo
000@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
0oooooooo`0002_o000000?o6ATIo`000?l000002ol00003ooooo`?o00000_ooool0017ooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooom1ooooo`7o00000Oooool1ooooo`004_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood7ooooo0Ol00001ooooo`7ooooo
000Cooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool1o`00007ooooo0Oooool000oooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool000oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`008_ooooooo`0004Go00000_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.45856, -0.925172, 0.0763111, \
0.0763111}}],

Cell[BoxData[
    \(20\)], "Output"]
}, Open  ]],

Cell["\<\
The density is evenly distributed along the diagonal, and the total \
mass equals 20, as required. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["FFT for the Potential", "Section",
  CellTags->{"i:62", "c:33"}],

Cell[TextData[{
  "Now that we know the density on the grid, we solve Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  for the potential on the grid, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  ". We do so using the FFT method described in Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>{"Chapter6.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  ".  We then evaluate the force matrices ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(x\ i\ j\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(y\ i\ j\)\)]],
  ", given by the discretized ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(F\_\(\(x\)\(\ \)\(i\)\(\ \)\(j\)\(\ \)\)\), "=", " ", 
          
          FractionBox[\(\[Phi]\_\(\(\ \)\(i + 1\ j\)\) - \[Phi]\_\(\(\ \)\(i \
- 1\ j\)\)\), 
            RowBox[{"2", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]]}], ",", "\[IndentingNewLine]", 
        
        RowBox[{\(F\_\(\(y\)\(\ \)\(i\)\(\ \)\(j\)\(\ \)\)\), "=", " ", 
          RowBox[{
            
            FractionBox[\(\[Phi]\_\(\(\ \)\(i\ j + 1\)\) - \[Phi]\_\(\(\ \
\)\(i\ j - 1\)\)\), 
              RowBox[{"2", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]], "."}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(7.3.8)"],

Cell[TextData[{
  "However, care must be taken to make sure that ",
  Cell[BoxData[
      \(TraditionalForm\`i \[PlusMinus] 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j \[PlusMinus] 1\)]],
  " remain in the correct ranges. This is accomplished using the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function. The module ",
  StyleBox["fft\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " performs the FFT and determines the forces."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(G\  = \ 1;\), " ", 
      StyleBox[\( (*\ 
          in\ SI\ units\ G\  = \ 
            6.67\ 10^\(-11\)\ but\ here\ we\ use\ scaled\ units\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "\n", 
      StyleBox[\( (*\ \(function\ to\ keep\ i \[PlusMinus] 
              1\ and\ j\) \[PlusMinus] 1\ in\ the\ range\ from\ 1\ to\ M; \ 
          used\ in\ force\ evaluation\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\n", 
    RowBox[{\(imod[i_]\  := \ 1\  + \ Mod[i - 1, M];\), "\[IndentingNewLine]",
       "\n"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\( (*\ 
          factor\ in\ discrete\ Fourier\ transform\ \((see\ Eq . \ \((6  .2  \
.43)\))\)\ *) \),
        FontColor->RGBColor[1, 0, 
        0]], \(factor\[Phi][m_, n_, \[CapitalDelta]x_, \[CapitalDelta]y_, 
            M_]\  := \(factor\[Phi][m, n, \[CapitalDelta]x, \[CapitalDelta]y, 
              M] = \(-4\)\ \[Pi]\ G/\((\ \(4\/\[CapitalDelta]x\^2\) 
                        Sin[\[Pi]\ m/M]^2 + \(4\/\[CapitalDelta]y\^2\) 
                        Sin[\[Pi]\ n/M]^2\ )\)\  // N\);\)}], "\n", 
    RowBox[{\(factor\[Phi][0, 0, \[CapitalDelta]x_, \[CapitalDelta]y_, 
            M_]\  = \ 1;\), "\n", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(fft\[Phi][\[Rho]_]\), ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[Rho]ft, \[Phi]ft}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*\ FFT\ of\ the\ density\ matrix\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(\[Rho]ft = Fourier[\[Rho]]\), ";", "\[IndentingNewLine]", 
            
            
            StyleBox[\( (*\ 
                total\ mass\ in\ the\ box\ equals\ \(\(zero\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]ft[\([1, 1]\)] = 0\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ potential\ \(\((\)\(see\ Eq . \ \((6  .2  .43)\)\)\
\(\ \)\)*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi]ft = 
              Table[\[Rho]ft[\([m + 1, n + 1]\)]*
                  factor\[Phi][m, n, \[CapitalDelta]x, \[CapitalDelta]y, 
                    M], {m, 0, M - 1}, {n, 0, M - 1}]\), ";", 
            "\[IndentingNewLine]", \(\[Phi] = \ 
              Re[InverseFourier[\[Phi]ft]]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ \ data\ for\ forces, \ 
                including\ grid\ positions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Fx\  = \ \ Table[{\((i - 
                        1)\)\ \[CapitalDelta]x, \((j - 
                        1)\) \[CapitalDelta]y, \(-m\) \((\[Phi][\([imod[
                                i + 1], imod[j]]\)] - \[Phi][\([imod[i - 1], 
                              imod[j]]\)])\)/\((2\ \[CapitalDelta]x)\)}, {i, 
                  1, M + 1}, {j, 1, M + 1}]\), ";", 
            "\[IndentingNewLine]", \(Fy\  = \ \ Table[{\((i - 
                        1)\)\ \[CapitalDelta]x, \((j - 
                        1)\) \[CapitalDelta]y, \(-m\) \((\[Phi][\([imod[i], 
                              imod[j + 1]]\)] - \[Phi][\([imod[i], 
                              imod[j - 
                                  1]]\)])\)/\((2\ \[CapitalDelta]y)\)}, {i, 
                  1, M + 1}, {j, 1, M + 1}]\), ";"}]}], " ", 
        "]"}]}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.71"],

Cell[TextData[{
  "Note that we require the FFT  of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rho]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho]\&~\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", to satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(\[Rho]\&~[\([1, 1]\)]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  ". This is equivalent to ensuring that the total mass  in the domain is \
zero. Recall from Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>{"Chapter6.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  " that this constraint on the mass density is required by the periodic \
boundary conditions, in order to keep the potential finite. Since the term ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho]\&~[\([1, 1]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " creates a uniform mass density, setting it equal to zero has no effect on \
the force between the particles. Physically, setting this term equal to zero \
is equivalent to adding a uniform ",
  StyleBox["negative",
    FontSlant->"Italic"],
  " mass density to the system so that the total mass vanishes. But this \
uniform mass density has no effect on the particle dynamics. \n\tAlso, note \
that the factor used to convert Fourier-transformed density to potential, ",
  StyleBox["factor\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", is defined using double equal signs so that its values are remembered. \
We will be evaluating the potential many times, and it is wasteful to \
reevaluate the sin and cosine functions in ",
  StyleBox["factor\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at every timestep."
}], "Text"],

Cell[TextData[{
  "\tFinally,  note that we could have determined the force differently, by \
evaluating ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-\[ImaginaryI]\), " ", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["\[Phi]",
                  FontWeight->"Plain",
                  FontSlant->"Plain"], "~"],
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and then performing an FFT. However, this is not a good idea, for two \
reasons. First, two FFTs (one for each dimension) need to be done, and the \
FFT is the most time-consuming part of the algorithm. Second, this method \
places too much weight on large wavenumber contributions, and leads to large \
numerical error. This will be discussed in more detail in relation to Eq. (",
  ButtonBox["7.3.12",
    ButtonData:>"(7.3.12)",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.72",
    ButtonData:>"Cell 7.72",
    ButtonStyle->"Hyperlink"],
  ", we evaluate the potential and force created by the previous density \
distribution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(fft\[Phi][\[Rho]];\)\), "\n", 
    \(\(ListPlot3D[\[Phi], PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.72"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02317 .27102 -18 -2.74731 ]
[.02317 .27102 0 6.25269 ]
[.01234 .33888 -12 -2.80473 ]
[.01234 .33888 0 6.19527 ]
[.00103 .40979 -6 -2.865 ]
[.00103 .40979 0 6.135 ]
[-0.01081 .48397 -6 -2.92835 ]
[-0.01081 .48397 0 6.07165 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0354 .26625 m
.04151 .26387 L
s
[(-10)] .02317 .27102 1 -0.38949 Mshowa
.02462 .33425 m
.03076 .33194 L
s
[(-5)] .01234 .33888 1 -0.37673 Mshowa
.01336 .40531 m
.01953 .40307 L
s
[(0)] .00103 .40979 1 -0.36333 Mshowa
.00158 .47964 m
.00778 .47748 L
s
[(5)] -0.01081 .48397 1 -0.34926 Mshowa
.125 Mabswid
.03328 .27962 m
.03695 .2782 L
s
.03114 .2931 m
.03482 .29169 L
s
.02899 .3067 m
.03267 .30529 L
s
.02682 .32041 m
.0305 .31902 L
s
.02241 .34821 m
.0261 .34683 L
s
.02018 .3623 m
.02387 .36092 L
s
.01793 .37651 m
.02162 .37514 L
s
.01565 .39084 m
.01935 .38949 L
s
.01105 .41991 m
.01475 .41857 L
s
.00871 .43464 m
.01242 .43331 L
s
.00636 .4495 m
.01007 .44818 L
s
.00398 .4645 m
.0077 .46319 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.694 .303 .304 r
.38616 .65913 .40384 .64035 .43026 .66589 .41296 .68136 Metetra
.673 .255 .243 r
.41296 .68136 .43026 .66589 .45755 .68812 .44061 .70007 Metetra
.637 .181 .153 r
.44061 .70007 .45755 .68812 .48565 .70684 .46906 .71505 Metetra
.571 .064 .01 r
.46906 .71505 .48565 .70684 .5145 .72183 .49822 .72611 Metetra
.431 0 0 r
.49822 .72611 .5145 .72183 .54402 .73291 .52802 .73308 Metetra
.138 0 0 r
.52802 .73308 .54402 .73291 .57413 .73991 .55836 .7358 Metetra
.277 .753 .934 r
.55836 .7358 .57413 .73991 .60473 .74268 .58915 .73418 Metetra
.555 .83 .997 r
.58915 .73418 .60473 .74268 .63571 .74111 .62028 .7281 Metetra
.672 .8 .943 r
.62028 .7281 .63571 .74111 .66698 .73511 .65164 .71751 Metetra
.72 .757 .882 r
.65164 .71751 .66698 .73511 .69843 .72461 .68311 .70239 Metetra
.742 .721 .832 r
.68311 .70239 .69843 .72461 .72993 .70959 .71459 .68274 Metetra
.753 .693 .794 r
.71459 .68274 .72993 .70959 .76137 .69004 .74594 .6586 Metetra
.759 .671 .764 r
.74594 .6586 .76137 .69004 .79263 .66603 .77705 .63004 Metetra
.763 .653 .741 r
.77705 .63004 .79263 .66603 .82359 .6376 .80781 .59717 Metetra
.765 .639 .722 r
.80781 .59717 .82359 .6376 .85414 .60488 .83809 .56014 Metetra
.766 .627 .706 r
.83809 .56014 .85414 .60488 .88417 .568 .8678 .5191 Metetra
.767 .617 .693 r
.8678 .5191 .88417 .568 .91356 .52714 .89681 .47427 Metetra
.768 .608 .681 r
.89681 .47427 .91356 .52714 .94221 .48247 .92505 .42586 Metetra
.41 .387 .723 r
.92505 .42586 .94221 .48247 .97003 .43424 .96316 .45457 Metetra
.672 .254 .242 r
.36797 .67454 .38616 .65913 .41296 .68136 .39516 .69325 Metetra
.637 .18 .152 r
.39516 .69325 .41296 .68136 .44061 .70007 .42319 .70821 Metetra
.569 .062 .007 r
.42319 .70821 .44061 .70007 .46906 .71505 .45199 .71925 Metetra
.429 0 0 r
.45199 .71925 .46906 .71505 .49822 .72611 .48148 .72618 Metetra
.134 0 0 r
.48148 .72618 .49822 .72611 .52802 .73308 .51156 .72886 Metetra
.281 .755 .936 r
.51156 .72886 .52802 .73308 .55836 .7358 .54215 .72717 Metetra
.557 .83 .997 r
.54215 .72717 .55836 .7358 .58915 .73418 .57313 .72102 Metetra
.673 .799 .943 r
.57313 .72102 .58915 .73418 .62028 .7281 .6044 .71035 Metetra
.72 .757 .881 r
.6044 .71035 .62028 .7281 .65164 .71751 .63585 .69513 Metetra
.742 .721 .832 r
.63585 .69513 .65164 .71751 .68311 .70239 .66736 .67537 Metetra
.753 .692 .794 r
.66736 .67537 .68311 .70239 .71459 .68274 .6988 .6511 Metetra
.759 .67 .764 r
.6988 .6511 .71459 .68274 .74594 .6586 .73007 .6224 Metetra
.763 .653 .741 r
.73007 .6224 .74594 .6586 .77705 .63004 .76103 .58939 Metetra
.765 .639 .722 r
.76103 .58939 .77705 .63004 .80781 .59717 .79158 .55219 Metetra
.766 .627 .706 r
.79158 .55219 .80781 .59717 .83809 .56014 .8216 .51099 Metetra
.767 .617 .693 r
.8216 .51099 .83809 .56014 .8678 .5191 .85098 .46599 Metetra
.768 .608 .681 r
.85098 .46599 .8678 .5191 .89681 .47427 .87963 .4174 Metetra
.401 .381 .722 r
.87963 .4174 .89681 .47427 .92505 .42586 .91713 .4461 Metetra
.671 .228 .19 r
.91713 .4461 .92505 .42586 .96316 .45457 .95543 .47159 Metetra
.636 .179 .15 r
.3493 .68636 .36797 .67454 .39516 .69325 .37691 .70131 Metetra
.568 .06 .005 r
.37691 .70131 .39516 .69325 .42319 .70821 .40534 .71232 Metetra
.426 0 0 r
.40534 .71232 .42319 .70821 .45199 .71925 .4345 .71922 Metetra
.13 0 0 r
.4345 .71922 .45199 .71925 .48148 .72618 .46432 .72185 Metetra
.285 .757 .938 r
.46432 .72185 .48148 .72618 .51156 .72886 .4947 .7201 Metetra
.558 .829 .996 r
.4947 .7201 .51156 .72886 .54215 .72717 .52553 .71388 Metetra
.673 .799 .942 r
.52553 .71388 .54215 .72717 .57313 .72102 .55672 .70312 Metetra
.72 .756 .881 r
.55672 .70312 .57313 .72102 .6044 .71035 .58814 .6878 Metetra
.742 .72 .831 r
.58814 .6878 .6044 .71035 .63585 .69513 .61967 .66792 Metetra
.753 .692 .793 r
.61967 .66792 .63585 .69513 .66736 .67537 .65121 .64352 Metetra
.759 .67 .764 r
.65121 .64352 .66736 .67537 .6988 .6511 .68262 .61469 Metetra
.763 .653 .741 r
.68262 .61469 .6988 .6511 .73007 .6224 .7138 .58153 Metetra
.765 .638 .722 r
.7138 .58153 .73007 .6224 .76103 .58939 .74461 .54417 Metetra
.766 .627 .706 r
.74461 .54417 .76103 .58939 .79158 .55219 .77496 .50281 Metetra
.767 .617 .693 r
.77496 .50281 .79158 .55219 .8216 .51099 .80472 .45763 Metetra
.768 .608 .681 r
.80472 .45763 .8216 .51099 .85098 .46599 .83379 .40887 Metetra
.391 .374 .721 r
.83379 .40887 .85098 .46599 .87963 .4174 .87066 .43755 Metetra
.671 .227 .189 r
.87066 .43755 .87963 .4174 .91713 .4461 .90836 .46302 Metetra
.644 .174 .122 r
.90836 .46302 .91713 .4461 .95543 .47159 .9468 .48501 Metetra
.567 .057 .002 r
.3302 .69435 .3493 .68636 .37691 .70131 .35825 .70533 Metetra
.424 0 0 r
.35825 .70533 .37691 .70131 .40534 .71232 .38709 .71219 Metetra
.125 0 0 r
.38709 .71219 .40534 .71232 .4345 .71922 .41663 .71477 Metetra
.289 .759 .94 r
.41663 .71477 .4345 .71922 .46432 .72185 .4468 .71296 Metetra
.56 .829 .996 r
.4468 .71296 .46432 .72185 .4947 .7201 .47748 .70667 Metetra
.674 .798 .941 r
.47748 .70667 .4947 .7201 .52553 .71388 .50857 .69582 Metetra
.721 .756 .88 r
.50857 .69582 .52553 .71388 .55672 .70312 .53996 .6804 Metetra
.742 .72 .831 r
.53996 .6804 .55672 .70312 .58814 .6878 .57152 .6604 Metetra
.753 .692 .793 r
.57152 .6604 .58814 .6878 .61967 .66792 .60315 .63588 Metetra
.759 .67 .764 r
.60315 .63588 .61967 .66792 .65121 .64352 .63472 .6069 Metetra
.762 .653 .74 r
.63472 .6069 .65121 .64352 .68262 .61469 .66611 .57359 Metetra
.765 .638 .722 r
.66611 .57359 .68262 .61469 .7138 .58153 .69719 .53608 Metetra
.766 .627 .706 r
.69719 .53608 .7138 .58153 .74461 .54417 .72786 .49454 Metetra
.767 .617 .693 r
.72786 .49454 .74461 .54417 .77496 .50281 .75801 .44919 Metetra
.768 .608 .681 r
.75801 .44919 .77496 .50281 .80472 .45763 .78751 .40025 Metetra
.381 .367 .719 r
.78751 .40025 .80472 .45763 .83379 .40887 .82373 .42891 Metetra
.671 .227 .188 r
.82373 .42891 .83379 .40887 .87066 .43755 .86083 .45436 Metetra
.643 .172 .12 r
.86083 .45436 .87066 .43755 .90836 .46302 .89871 .47633 Metetra
.6 .096 .027 r
.89871 .47633 .90836 .46302 .9468 .48501 .93725 .49456 Metetra
.421 0 0 r
.31072 .69827 .3302 .69435 .35825 .70533 .33922 .70509 Metetra
.121 0 0 r
.33922 .70509 .35825 .70533 .38709 .71219 .36849 .70763 Metetra
.293 .76 .942 r
.36849 .70763 .38709 .71219 .41663 .71477 .39844 .70576 Metetra
.561 .829 .996 r
.39844 .70576 .41663 .71477 .4468 .71296 .42896 .69939 Metetra
.674 .798 .941 r
.42896 .69939 .4468 .71296 .47748 .70667 .45995 .68845 Metetra
.721 .755 .88 r
.45995 .68845 .47748 .70667 .50857 .69582 .49131 .67292 Metetra
.742 .72 .831 r
.49131 .67292 .50857 .69582 .53996 .6804 .52291 .65281 Metetra
.753 .692 .793 r
.52291 .65281 .53996 .6804 .57152 .6604 .55463 .62816 Metetra
.759 .67 .764 r
.55463 .62816 .57152 .6604 .60315 .63588 .58635 .59904 Metetra
.762 .652 .74 r
.58635 .59904 .60315 .63588 .63472 .6069 .61795 .56557 Metetra
.765 .638 .722 r
.61795 .56557 .63472 .6069 .66611 .57359 .64931 .5279 Metetra
.766 .627 .706 r
.64931 .5279 .66611 .57359 .69719 .53608 .68032 .4862 Metetra
.767 .617 .693 r
.68032 .4862 .69719 .53608 .72786 .49454 .71085 .44067 Metetra
.767 .608 .681 r
.71085 .44067 .72786 .49454 .75801 .44919 .74079 .39154 Metetra
.37 .36 .718 r
.74079 .39154 .75801 .44919 .78751 .40025 .77635 .4202 Metetra
.67 .226 .186 r
.77635 .4202 .78751 .40025 .82373 .42891 .81283 .44562 Metetra
.643 .171 .119 r
.81283 .44562 .82373 .42891 .86083 .45436 .85013 .46756 Metetra
.6 .095 .024 r
.85013 .46756 .86083 .45436 .89871 .47633 .88815 .48576 Metetra
.528 0 0 r
.88815 .48576 .89871 .47633 .93725 .49456 .92676 .49996 Metetra
.116 0 0 r
.29091 .69793 .31072 .69827 .33922 .70509 .31989 .70042 Metetra
.296 .762 .944 r
.31989 .70042 .33922 .70509 .36849 .70763 .34961 .69848 Metetra
.562 .828 .995 r
.34961 .69848 .36849 .70763 .39844 .70576 .37997 .69203 Metetra
.674 .797 .94 r
.37997 .69203 .39844 .70576 .42896 .69939 .41087 .68101 Metetra
.721 .755 .879 r
.41087 .68101 .42896 .69939 .45995 .68845 .44219 .66537 Metetra
.742 .719 .831 r
.44219 .66537 .45995 .68845 .49131 .67292 .47381 .64515 Metetra
.753 .692 .793 r
.47381 .64515 .49131 .67292 .52291 .65281 .50563 .62036 Metetra
.759 .67 .764 r
.50563 .62036 .52291 .65281 .55463 .62816 .53751 .5911 Metetra
.762 .652 .74 r
.53751 .5911 .55463 .62816 .58635 .59904 .56933 .55748 Metetra
.764 .638 .721 r
.56933 .55748 .58635 .59904 .61795 .56557 .60097 .51964 Metetra
.766 .626 .706 r
.60097 .51964 .61795 .56557 .64931 .5279 .63231 .47777 Metetra
.767 .617 .693 r
.63231 .47777 .64931 .5279 .68032 .4862 .66323 .43206 Metetra
.767 .608 .681 r
.66323 .43206 .68032 .4862 .71085 .44067 .69362 .38276 Metetra
.358 .352 .716 r
.69362 .38276 .71085 .44067 .74079 .39154 .7285 .41139 Metetra
.67 .225 .185 r
.7285 .41139 .74079 .39154 .77635 .4202 .76435 .4368 Metetra
.642 .17 .117 r
.76435 .4368 .77635 .4202 .81283 .44562 .80106 .45871 Metetra
.599 .093 .022 r
.80106 .45871 .81283 .44562 .85013 .46756 .83855 .47686 Metetra
.527 0 0 r
.83855 .47686 .85013 .46756 .88815 .48576 .87668 .49102 Metetra
.403 0 0 r
.87668 .49102 .88815 .48576 .92676 .49996 .91534 .50095 Metetra
.3 .763 .946 r
.27083 .69314 .29091 .69793 .31989 .70042 .30032 .69114 Metetra
.564 .828 .995 r
.30032 .69114 .31989 .70042 .34961 .69848 .33051 .68461 Metetra
.675 .797 .94 r
.33051 .68461 .34961 .69848 .37997 .69203 .3613 .67349 Metetra
.721 .754 .879 r
.3613 .67349 .37997 .69203 .41087 .68101 .39258 .65775 Metetra
.742 .719 .83 r
.39258 .65775 .41087 .68101 .44219 .66537 .42424 .6374 Metetra
.753 .691 .793 r
.42424 .6374 .44219 .66537 .47381 .64515 .45614 .61249 Metetra
.759 .67 .764 r
.45614 .61249 .47381 .64515 .50563 .62036 .48818 .58309 Metetra
.762 .652 .74 r
.48818 .58309 .50563 .62036 .53751 .5911 .52022 .54931 Metetra
.764 .638 .721 r
.52022 .54931 .53751 .5911 .56933 .55748 .55214 .51131 Metetra
.766 .626 .706 r
.55214 .51131 .56933 .55748 .60097 .51964 .58383 .46926 Metetra
.767 .617 .693 r
.58383 .46926 .60097 .51964 .63231 .47777 .61515 .42338 Metetra
.767 .608 .681 r
.61515 .42338 .63231 .47777 .66323 .43206 .64599 .37389 Metetra
.346 .344 .714 r
.64599 .37389 .66323 .43206 .69362 .38276 .68018 .4025 Metetra
.67 .224 .184 r
.68018 .4025 .69362 .38276 .7285 .41139 .71538 .42788 Metetra
.642 .169 .115 r
.71538 .42788 .7285 .41139 .76435 .4368 .7515 .44976 Metetra
.598 .092 .02 r
.7515 .44976 .76435 .4368 .80106 .45871 .78844 .46787 Metetra
.525 0 0 r
.78844 .46787 .80106 .45871 .83855 .47686 .82608 .48198 Metetra
.4 0 0 r
.82608 .48198 .83855 .47686 .87668 .49102 .8643 .49185 Metetra
.186 0 0 r
.8643 .49185 .87668 .49102 .91534 .50095 .90296 .49728 Metetra
.565 .828 .995 r
.25054 .68372 .27083 .69314 .30032 .69114 .28056 .67711 Metetra
.675 .796 .939 r
.28056 .67711 .30032 .69114 .33051 .68461 .31125 .6659 Metetra
.721 .754 .879 r
.31125 .6659 .33051 .68461 .3613 .67349 .34249 .65006 Metetra
.742 .719 .83 r
.34249 .65006 .3613 .67349 .39258 .65775 .37417 .62959 Metetra
.753 .691 .793 r
.37417 .62959 .39258 .65775 .42424 .6374 .40617 .60454 Metetra
.759 .669 .763 r
.40617 .60454 .42424 .6374 .45614 .61249 .43836 .57499 Metetra
.762 .652 .74 r
.43836 .57499 .45614 .61249 .48818 .58309 .47063 .54106 Metetra
.764 .638 .721 r
.47063 .54106 .48818 .58309 .52022 .54931 .50284 .50289 Metetra
.766 .626 .706 r
.50284 .50289 .52022 .54931 .55214 .51131 .53487 .46067 Metetra
.767 .617 .693 r
.53487 .46067 .55214 .51131 .58383 .46926 .5666 .4146 Metetra
.767 .608 .682 r
.5666 .4146 .58383 .46926 .61515 .42338 .5979 .36493 Metetra
.333 .335 .712 r
.5979 .36493 .61515 .42338 .64599 .37389 .63138 .39352 Metetra
.669 .223 .183 r
.63138 .39352 .64599 .37389 .68018 .4025 .66592 .41888 Metetra
.641 .168 .114 r
.66592 .41888 .68018 .4025 .71538 .42788 .70143 .44072 Metetra
.597 .09 .018 r
.70143 .44072 .71538 .42788 .7515 .44976 .73781 .45879 Metetra
.524 0 0 r
.73781 .45879 .7515 .44976 .78844 .46787 .77495 .47285 Metetra
.397 0 0 r
.77495 .47285 .78844 .46787 .82608 .48198 .81273 .48266 Metetra
.183 0 0 r
.81273 .48266 .82608 .48198 .8643 .49185 .85101 .48801 Metetra
.119 .657 .85 r
.85101 .48801 .8643 .49185 .90296 .49728 .88964 .48874 Metetra
.675 .795 .939 r
.23012 .66954 .25054 .68372 .28056 .67711 .2607 .65823 Metetra
.721 .754 .878 r
.2607 .65823 .28056 .67711 .31125 .6659 .29189 .64228 Metetra
.742 .718 .83 r
.29189 .64228 .31125 .6659 .34249 .65006 .3236 .62169 Metetra
.753 .691 .792 r
.3236 .62169 .34249 .65006 .37417 .62959 .3557 .59651 Metetra
.758 .669 .763 r
.3557 .59651 .37417 .62959 .40617 .60454 .38805 .56681 Metetra
.762 .652 .74 r
.38805 .56681 .40617 .60454 .43836 .57499 .42055 .53272 Metetra
.764 .638 .721 r
.42055 .53272 .43836 .57499 .47063 .54106 .45305 .49439 Metetra
.766 .626 .706 r
.45305 .49439 .47063 .54106 .50284 .50289 .48543 .45199 Metetra
.767 .617 .693 r
.48543 .45199 .50284 .50289 .53487 .46067 .51757 .40574 Metetra
.767 .608 .682 r
.51757 .40574 .53487 .46067 .5666 .4146 .54934 .35589 Metetra
.319 .326 .71 r
.54934 .35589 .5666 .4146 .5979 .36493 .5821 .38445 Metetra
.669 .222 .181 r
.5821 .38445 .5979 .36493 .63138 .39352 .61596 .40978 Metetra
.64 .166 .112 r
.61596 .40978 .63138 .39352 .66592 .41888 .65084 .43159 Metetra
.596 .088 .016 r
.65084 .43159 .66592 .41888 .70143 .44072 .68665 .44962 Metetra
.522 0 0 r
.68665 .44962 .70143 .44072 .73781 .45879 .72327 .46362 Metetra
.395 0 0 r
.72327 .46362 .73781 .45879 .77495 .47285 .7606 .47336 Metetra
.179 0 0 r
.7606 .47336 .77495 .47285 .81273 .48266 .79849 .47864 Metetra
.123 .66 .853 r
.79849 .47864 .81273 .48266 .85101 .48801 .83681 .47928 Metetra
.404 .798 .987 r
.83681 .47928 .85101 .48801 .88964 .48874 .8754 .47514 Metetra
.721 .753 .878 r
.20965 .65049 .23012 .66954 .2607 .65823 .2408 .63443 Metetra
.742 .718 .83 r
.2408 .63443 .2607 .65823 .29189 .64228 .27253 .61372 Metetra
.752 .691 .792 r
.27253 .61372 .29189 .64228 .3236 .62169 .30472 .5884 Metetra
.758 .669 .763 r
.30472 .5884 .3236 .62169 .3557 .59651 .33724 .55855 Metetra
.762 .652 .74 r
.33724 .55855 .3557 .59651 .38805 .56681 .36996 .5243 Metetra
.764 .638 .721 r
.36996 .5243 .38805 .56681 .42055 .53272 .40276 .4858 Metetra
.766 .626 .706 r
.40276 .4858 .42055 .53272 .45305 .49439 .4355 .44323 Metetra
.767 .616 .693 r
.4355 .44323 .45305 .49439 .48543 .45199 .46806 .3968 Metetra
.767 .608 .682 r
.46806 .3968 .48543 .45199 .51757 .40574 .50031 .34675 Metetra
.304 .315 .707 r
.50031 .34675 .51757 .40574 .54934 .35589 .53233 .3753 Metetra
.669 .221 .18 r
.53233 .3753 .54934 .35589 .5821 .38445 .56549 .40059 Metetra
.64 .165 .11 r
.56549 .40059 .5821 .38445 .61596 .40978 .59973 .42236 Metetra
.595 .087 .013 r
.59973 .42236 .61596 .40978 .65084 .43159 .63495 .44035 Metetra
.521 0 0 r
.63495 .44035 .65084 .43159 .68665 .44962 .67105 .45429 Metetra
.392 0 0 r
.67105 .45429 .68665 .44962 .72327 .46362 .70791 .46397 Metetra
.175 0 0 r
.70791 .46397 .72327 .46362 .7606 .47336 .74541 .46917 Metetra
.127 .663 .856 r
.74541 .46917 .7606 .47336 .79849 .47864 .7834 .46972 Metetra
.406 .798 .988 r
.7834 .46972 .79849 .47864 .83681 .47928 .82173 .46547 Metetra
.581 .824 .991 r
.82173 .46547 .83681 .47928 .8754 .47514 .86025 .45631 Metetra
.742 .718 .829 r
.18919 .6265 .20965 .65049 .2408 .63443 .22095 .60566 Metetra
.752 .69 .792 r
.22095 .60566 .2408 .63443 .27253 .61372 .25323 .58021 Metetra
.758 .669 .763 r
.25323 .58021 .27253 .61372 .30472 .5884 .28591 .55021 Metetra
.762 .652 .74 r
.28591 .55021 .30472 .5884 .33724 .55855 .31887 .5158 Metetra
.764 .638 .721 r
.31887 .5158 .33724 .55855 .36996 .5243 .35196 .47713 Metetra
.765 .626 .706 r
.35196 .47713 .36996 .5243 .40276 .4858 .38507 .43437 Metetra
.766 .616 .693 r
.38507 .43437 .40276 .4858 .4355 .44323 .41805 .38776 Metetra
.767 .608 .682 r
.41805 .38776 .4355 .44323 .46806 .3968 .45079 .33753 Metetra
.288 .305 .704 r
.45079 .33753 .46806 .3968 .50031 .34675 .48205 .36604 Metetra
.668 .22 .179 r
.48205 .36604 .50031 .34675 .53233 .3753 .51451 .39131 Metetra
.639 .164 .109 r
.51451 .39131 .53233 .3753 .56549 .40059 .54809 .41304 Metetra
.594 .085 .011 r
.54809 .41304 .56549 .40059 .59973 .42236 .58271 .43098 Metetra
.519 0 0 r
.58271 .43098 .59973 .42236 .63495 .44035 .61826 .44487 Metetra
.39 0 0 r
.61826 .44487 .63495 .44035 .67105 .45429 .65465 .45448 Metetra
.171 0 0 r
.65465 .45448 .67105 .45429 .70791 .46397 .69174 .4596 Metetra
.131 .665 .86 r
.69174 .4596 .70791 .46397 .74541 .46917 .72939 .46005 Metetra
.409 .799 .989 r
.72939 .46005 .74541 .46917 .7834 .46972 .76747 .45569 Metetra
.582 .823 .99 r
.76747 .45569 .7834 .46972 .82173 .46547 .8058 .44641 Metetra
.672 .8 .943 r
.8058 .44641 .82173 .46547 .86025 .45631 .84423 .43214 Metetra
.752 .69 .792 r
.16884 .59753 .18919 .6265 .22095 .60566 .20122 .57193 Metetra
.758 .669 .763 r
.20122 .57193 .22095 .60566 .25323 .58021 .23407 .54178 Metetra
.762 .652 .74 r
.23407 .54178 .25323 .58021 .28591 .55021 .26726 .50721 Metetra
.764 .638 .721 r
.26726 .50721 .28591 .55021 .31887 .5158 .30066 .46837 Metetra
.765 .626 .706 r
.30066 .46837 .31887 .5158 .35196 .47713 .33413 .42543 Metetra
.766 .616 .693 r
.33413 .42543 .35196 .47713 .38507 .43437 .36755 .37864 Metetra
.767 .608 .682 r
.36755 .37864 .38507 .43437 .41805 .38776 .40078 .32821 Metetra
.271 .293 .701 r
.40078 .32821 .41805 .38776 .45079 .33753 .43127 .3567 Metetra
.668 .219 .177 r
.43127 .3567 .45079 .33753 .48205 .36604 .463 .38193 Metetra
.639 .163 .107 r
.463 .38193 .48205 .36604 .51451 .39131 .49591 .40362 Metetra
.593 .083 .009 r
.49591 .40362 .51451 .39131 .54809 .41304 .52991 .42151 Metetra
.518 0 0 r
.52991 .42151 .54809 .41304 .58271 .43098 .56491 .43534 Metetra
.387 0 0 r
.56491 .43534 .58271 .43098 .61826 .44487 .60081 .44488 Metetra
.167 0 0 r
.60081 .44488 .61826 .44487 .65465 .45448 .63748 .44992 Metetra
.136 .668 .863 r
.63748 .44992 .65465 .45448 .69174 .4596 .67479 .45027 Metetra
.412 .8 .989 r
.67479 .45027 .69174 .4596 .72939 .46005 .71259 .4458 Metetra
.583 .823 .99 r
.71259 .4458 .72939 .46005 .76747 .45569 .75074 .43639 Metetra
.673 .799 .943 r
.75074 .43639 .76747 .45569 .8058 .44641 .78905 .42198 Metetra
.719 .766 .89 r
.78905 .42198 .8058 .44641 .84423 .43214 .82737 .40254 Metetra
.758 .669 .763 r
.14868 .56357 .16884 .59753 .20122 .57193 .1817 .53327 Metetra
.762 .651 .74 r
.1817 .53327 .20122 .57193 .23407 .54178 .21513 .49854 Metetra
.764 .638 .721 r
.21513 .49854 .23407 .54178 .26726 .50721 .24884 .45952 Metetra
.765 .626 .706 r
.24884 .45952 .26726 .50721 .30066 .46837 .28269 .4164 Metetra
.766 .616 .693 r
.28269 .4164 .30066 .46837 .33413 .42543 .31654 .36942 Metetra
.767 .608 .682 r
.31654 .36942 .33413 .42543 .36755 .37864 .35027 .31881 Metetra
.252 .28 .697 r
.35027 .31881 .36755 .37864 .40078 .32821 .37998 .34726 Metetra
.667 .218 .176 r
.37998 .34726 .40078 .32821 .43127 .3567 .41097 .37245 Metetra
.638 .162 .105 r
.41097 .37245 .43127 .3567 .463 .38193 .44318 .3941 Metetra
.592 .082 .007 r
.44318 .3941 .463 .38193 .49591 .40362 .47655 .41194 Metetra
.516 0 0 r
.47655 .41194 .49591 .40362 .52991 .42151 .51099 .42571 Metetra
.384 0 0 r
.51099 .42571 .52991 .42151 .56491 .43534 .54638 .43517 Metetra
.163 0 0 r
.54638 .43517 .56491 .43534 .60081 .44488 .58262 .44013 Metetra
.14 .67 .866 r
.58262 .44013 .60081 .44488 .63748 .44992 .61957 .44038 Metetra
.414 .8 .99 r
.61957 .44038 .63748 .44992 .67479 .45027 .6571 .4358 Metetra
.584 .822 .989 r
.6571 .4358 .67479 .45027 .71259 .4458 .69504 .42626 Metetra
.673 .799 .942 r
.69504 .42626 .71259 .4458 .75074 .43639 .73325 .41171 Metetra
.719 .766 .889 r
.73325 .41171 .75074 .43639 .78905 .42198 .77153 .39211 Metetra
.744 .734 .843 r
.77153 .39211 .78905 .42198 .82737 .40254 .80974 .36748 Metetra
.762 .651 .74 r
.12879 .52467 .14868 .56357 .1817 .53327 .16246 .48977 Metetra
.764 .638 .721 r
.16246 .48977 .1817 .53327 .21513 .49854 .19649 .45058 Metetra
.765 .626 .706 r
.19649 .45058 .21513 .49854 .24884 .45952 .23072 .40728 Metetra
.766 .616 .693 r
.23072 .40728 .24884 .45952 .28269 .4164 .26502 .36011 Metetra
.767 .608 .682 r
.26502 .36011 .28269 .4164 .31654 .36942 .29926 .3093 Metetra
.233 .267 .692 r
.29926 .3093 .31654 .36942 .35027 .31881 .32816 .33773 Metetra
.667 .218 .175 r
.32816 .33773 .35027 .31881 .37998 .34726 .35839 .36288 Metetra
.638 .16 .103 r
.35839 .36288 .37998 .34726 .41097 .37245 .3899 .38449 Metetra
.591 .08 .004 r
.3899 .38449 .41097 .37245 .44318 .3941 .42262 .40227 Metetra
.515 0 0 r
.42262 .40227 .44318 .3941 .47655 .41194 .45647 .41597 Metetra
.382 0 0 r
.45647 .41597 .47655 .41194 .51099 .42571 .49135 .42536 Metetra
.159 0 0 r
.49135 .42536 .51099 .42571 .54638 .43517 .52715 .43023 Metetra
.144 .673 .869 r
.52715 .43023 .54638 .43517 .58262 .44013 .56374 .43039 Metetra
.417 .801 .991 r
.56374 .43039 .58262 .44013 .61957 .44038 .60098 .42569 Metetra
.586 .822 .989 r
.60098 .42569 .61957 .44038 .6571 .4358 .63872 .41602 Metetra
.674 .798 .941 r
.63872 .41602 .6571 .4358 .69504 .42626 .6768 .40132 Metetra
.719 .765 .889 r
.6768 .40132 .69504 .42626 .73325 .41171 .71505 .38156 Metetra
.744 .734 .843 r
.71505 .38156 .73325 .41171 .77153 .39211 .75331 .35676 Metetra
.758 .707 .804 r
.75331 .35676 .77153 .39211 .80974 .36748 .79138 .32699 Metetra
.764 .637 .721 r
.10926 .48092 .12879 .52467 .16246 .48977 .1436 .44155 Metetra
.765 .626 .706 r
.1436 .44155 .16246 .48977 .19649 .45058 .17822 .39807 Metetra
.766 .616 .693 r
.17822 .39807 .19649 .45058 .23072 .40728 .21298 .35071 Metetra
.767 .608 .682 r
.21298 .35071 .23072 .40728 .26502 .36011 .24773 .29971 Metetra
.211 .252 .687 r
.24773 .29971 .26502 .36011 .29926 .3093 .27581 .32809 Metetra
.667 .217 .174 r
.27581 .32809 .29926 .3093 .32816 .33773 .30526 .35321 Metetra
.637 .159 .102 r
.30526 .35321 .32816 .33773 .35839 .36288 .33605 .37476 Metetra
.59 .078 .002 r
.33605 .37476 .35839 .36288 .3899 .38449 .36811 .39249 Metetra
.513 0 0 r
.36811 .39249 .3899 .38449 .42262 .40227 .40136 .40613 Metetra
.379 0 0 r
.40136 .40613 .42262 .40227 .45647 .41597 .43571 .41545 Metetra
.155 0 0 r
.43571 .41545 .45647 .41597 .49135 .42536 .47106 .42022 Metetra
.148 .675 .872 r
.47106 .42022 .49135 .42536 .52715 .43023 .50727 .42027 Metetra
.42 .801 .991 r
.50727 .42027 .52715 .43023 .56374 .43039 .54421 .41546 Metetra
.587 .822 .988 r
.54421 .41546 .56374 .43039 .60098 .42569 .58174 .40566 Metetra
.674 .798 .941 r
.58174 .40566 .60098 .42569 .63872 .41602 .61969 .39081 Metetra
.719 .765 .889 r
.61969 .39081 .63872 .41602 .6768 .40132 .65791 .37088 Metetra
.744 .734 .842 r
.65791 .37088 .6768 .40132 .71505 .38156 .69621 .34591 Metetra
.758 .707 .804 r
.69621 .34591 .71505 .38156 .75331 .35676 .73443 .31595 Metetra
.767 .685 .772 r
.73443 .31595 .75331 .35676 .79138 .32699 .77238 .28111 Metetra
.765 .626 .706 r
.09017 .43242 .10926 .48092 .1436 .44155 .12518 .38876 Metetra
.766 .616 .693 r
.12518 .38876 .1436 .44155 .17822 .39807 .1604 .34121 Metetra
.767 .608 .682 r
.1604 .34121 .17822 .39807 .21298 .35071 .19568 .29001 Metetra
.189 .236 .681 r
.19568 .29001 .21298 .35071 .24773 .29971 .22292 .31836 Metetra
.666 .216 .172 r
.22292 .31836 .24773 .29971 .27581 .32809 .25158 .34343 Metetra
.636 .158 .1 r
.25158 .34343 .27581 .32809 .30526 .35321 .28163 .36494 Metetra
.589 .076 0 r
.28163 .36494 .30526 .35321 .33605 .37476 .31301 .38261 Metetra
.511 0 0 r
.31301 .38261 .33605 .37476 .36811 .39249 .34565 .39618 Metetra
.376 0 0 r
.34565 .39618 .36811 .39249 .40136 .40613 .37946 .40542 Metetra
.151 0 0 r
.37946 .40542 .40136 .40613 .43571 .41545 .41433 .4101 Metetra
.152 .678 .874 r
.41433 .4101 .43571 .41545 .47106 .42022 .45016 .41005 Metetra
.422 .802 .992 r
.45016 .41005 .47106 .42022 .50727 .42027 .48679 .40511 Metetra
.588 .821 .988 r
.48679 .40511 .50727 .42027 .54421 .41546 .5241 .39518 Metetra
.674 .797 .94 r
.5241 .39518 .54421 .41546 .58174 .40566 .56193 .38018 Metetra
.719 .764 .888 r
.56193 .38018 .58174 .40566 .61969 .39081 .6001 .36009 Metetra
.744 .733 .842 r
.6001 .36009 .61969 .39081 .65791 .37088 .63845 .33493 Metetra
.758 .707 .804 r
.63845 .33493 .65791 .37088 .69621 .34591 .6768 .30477 Metetra
.767 .685 .772 r
.6768 .30477 .69621 .34591 .73443 .31595 .71498 .26974 Metetra
.772 .666 .746 r
.71498 .26974 .73443 .31595 .77238 .28111 .7528 .22999 Metetra
.766 .616 .693 r
.0716 .37935 .09017 .43242 .12518 .38876 .10729 .33161 Metetra
.767 .608 .682 r
.10729 .33161 .12518 .38876 .1604 .34121 .14311 .28022 Metetra
.164 .219 .674 r
.14311 .28022 .1604 .34121 .19568 .29001 .16948 .30853 Metetra
.666 .215 .171 r
.16948 .30853 .19568 .29001 .22292 .31836 .19733 .33356 Metetra
.636 .157 .098 r
.19733 .33356 .22292 .31836 .25158 .34343 .22662 .35501 Metetra
.588 .075 0 r
.22662 .35501 .25158 .34343 .28163 .36494 .25731 .37262 Metetra
.51 0 0 r
.25731 .37262 .28163 .36494 .31301 .38261 .28932 .38612 Metetra
.374 0 0 r
.28932 .38612 .31301 .38261 .34565 .39618 .32257 .39528 Metetra
.146 0 0 r
.32257 .39528 .34565 .39618 .37946 .40542 .35697 .39987 Metetra
.156 .68 .877 r
.35697 .39987 .37946 .40542 .41433 .4101 .39239 .3997 Metetra
.425 .802 .992 r
.39239 .3997 .41433 .4101 .45016 .41005 .42871 .39464 Metetra
.589 .821 .988 r
.42871 .39464 .45016 .41005 .48679 .40511 .4658 .38457 Metetra
.675 .797 .94 r
.4658 .38457 .48679 .40511 .5241 .39518 .50348 .36942 Metetra
.719 .764 .888 r
.50348 .36942 .5241 .39518 .56193 .38018 .54161 .34916 Metetra
.744 .733 .842 r
.54161 .34916 .56193 .38018 .6001 .36009 .58001 .32382 Metetra
.758 .707 .804 r
.58001 .32382 .6001 .36009 .63845 .33493 .61849 .29347 Metetra
.766 .684 .772 r
.61849 .29347 .63845 .33493 .6768 .30477 .6569 .25823 Metetra
.772 .666 .746 r
.6569 .25823 .6768 .30477 .71498 .26974 .69503 .21826 Metetra
.776 .65 .724 r
.69503 .21826 .71498 .26974 .7528 .22999 .73272 .17377 Metetra
.767 .608 .682 r
.05363 .32191 .0716 .37935 .10729 .33161 .08999 .27033 Metetra
.137 .2 .666 r
.08999 .27033 .10729 .33161 .14311 .28022 .11548 .2986 Metetra
.665 .214 .17 r
.11548 .2986 .14311 .28022 .16948 .30853 .1425 .32357 Metetra
.635 .155 .097 r
.1425 .32357 .16948 .30853 .19733 .33356 .17102 .34497 Metetra
.587 .073 0 r
.17102 .34497 .19733 .33356 .22662 .35501 .201 .36252 Metetra
.508 0 0 r
.201 .36252 .22662 .35501 .25731 .37262 .23236 .37595 Metetra
.371 0 0 r
.23236 .37595 .25731 .37262 .28932 .38612 .26504 .38502 Metetra
.142 0 0 r
.26504 .38502 .28932 .38612 .32257 .39528 .29895 .38951 Metetra
.161 .682 .88 r
.29895 .38951 .32257 .39528 .35697 .39987 .33396 .38924 Metetra
.427 .803 .993 r
.33396 .38924 .35697 .39987 .39239 .3997 .36996 .38406 Metetra
.59 .82 .987 r
.36996 .38406 .39239 .3997 .42871 .39464 .40681 .37384 Metetra
.675 .796 .939 r
.40681 .37384 .42871 .39464 .4658 .38457 .44435 .35854 Metetra
.719 .763 .887 r
.44435 .35854 .4658 .38457 .50348 .36942 .48243 .33811 Metetra
.744 .733 .842 r
.48243 .33811 .50348 .36942 .54161 .34916 .52087 .31258 Metetra
.758 .706 .803 r
.52087 .31258 .54161 .34916 .58001 .32382 .55949 .28204 Metetra
.766 .684 .772 r
.55949 .28204 .58001 .32382 .61849 .29347 .59812 .24659 Metetra
.772 .666 .746 r
.59812 .24659 .61849 .29347 .6569 .25823 .63658 .2064 Metetra
.775 .65 .724 r
.63658 .2064 .6569 .25823 .69503 .21826 .67468 .16168 Metetra
.778 .637 .705 r
.67468 .16168 .69503 .21826 .73272 .17377 .71225 .11269 Metetra
.109 .18 .657 r
.03634 .26033 .05363 .32191 .08999 .27033 .06093 .28856 Metetra
.665 .213 .168 r
.06093 .28856 .08999 .27033 .11548 .2986 .0871 .31348 Metetra
.635 .154 .095 r
.0871 .31348 .11548 .2986 .1425 .32357 .11482 .33483 Metetra
.587 .071 0 r
.11482 .33483 .1425 .32357 .17102 .34497 .14407 .35231 Metetra
.506 0 0 r
.14407 .35231 .17102 .34497 .201 .36252 .17477 .36567 Metetra
.368 0 0 r
.17477 .36567 .201 .36252 .23236 .37595 .20687 .37465 Metetra
.138 0 0 r
.20687 .37465 .23236 .37595 .26504 .38502 .24026 .37904 Metetra
.165 .685 .883 r
.24026 .37904 .26504 .38502 .29895 .38951 .27485 .37866 Metetra
.43 .803 .993 r
.27485 .37866 .29895 .38951 .33396 .38924 .31052 .37335 Metetra
.591 .82 .987 r
.31052 .37335 .33396 .38924 .36996 .38406 .34713 .36299 Metetra
.675 .795 .939 r
.34713 .36299 .36996 .38406 .40681 .37384 .38452 .34752 Metetra
.72 .763 .887 r
.38452 .34752 .40681 .37384 .44435 .35854 .42254 .32692 Metetra
.744 .732 .841 r
.42254 .32692 .44435 .35854 .48243 .33811 .46103 .30121 Metetra
.758 .706 .803 r
.46103 .30121 .48243 .33811 .52087 .31258 .49979 .27046 Metetra
.766 .684 .772 r
.49979 .27046 .52087 .31258 .55949 .28204 .53865 .2348 Metetra
.772 .666 .746 r
.53865 .2348 .55949 .28204 .59812 .24659 .57743 .19439 Metetra
.775 .65 .724 r
.57743 .19439 .59812 .24659 .63658 .2064 .61594 .14945 Metetra
.778 .637 .705 r
.61594 .14945 .63658 .2064 .67468 .16168 .65401 .10022 Metetra
.78 .625 .689 r
.65401 .10022 .67468 .16168 .71225 .11269 .69147 .04701 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00ioooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1dooooo`00ioooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1dooooo`00j?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@4100M?ooool00>Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000007Cooooo003Zooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00001dooooo`00joooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool0L_ooool00>Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0M?ooool00>Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0M?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?Cooooo0_l0001booooo`00lOooool3o`000003ooooool0003ooooo077ooooo003_ooooo`;o
00001?ooool2o`00077ooooo003/ooooo`?o00001_ooool00ol0003oooooo`00001`ooooo`00j_oo
ool2o`0000Wooooo00?o0000ooooool00000L?ooool00>Oooooo0ol0000;ooooo`04o`000?oooooo
ooooo`0006oooooo003Uooooo`;o000000?oooooo`000?ooool02oooool01Ol0003ooooooooooooo
oooo000006kooooo003Rooooo`?o00001?ooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool00000K_ooool00=oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Joooool00=gooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0J_ooool00=[ooooo0ol0000Iooooo`04o`000?ooooooooooooooo`;o0000K?ooool00=So
oooo0_l00002ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Yooooo`00eOooool3o`0000Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06Sooooo002Xooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000003oc8b<_oMgMgooooo01gooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0J?ooool00:[ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`0Jooooo`?o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo002Z
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool2o`0002Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Wooooo`00Z_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01Gooooo0ol000000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0I_ooool00:[ooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Cooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Uooooo`00Z_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo0ol0000/ooooo`;o00002Oooool00ol0003oooooooooo`1Uooooo`00
Z_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo0_l0000^ooooo`04o`00
0?o7Wk3o0000o`0000Sooooo0_l0001Vooooo`00Z?ooool00omEEEGoIVIVo`000005ooooo`Co0000
3Oooool3o`00033ooooo00Co0000olNO/?l0003o00002_ooool00ol0003oooooooooo`1Sooooo`00
__ooool3o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0003oain`olNO/002o`0000[ooooo
00?o0000ooooooooool0Hoooool00;cooooo0_l0000dooooo`07o`000?o7Wk3oain`olNO/?l0003o
ain`o`00000:ooooo`03o`000?oooooooooo06;ooooo002iooooo`?o0000=_ooool01ol0003oain`
olNO/?o7Wk3o0000olNO/?l000002oooool00ol0003oooooooooo`1Qooooo`00]oooool2o`0003So
oooo00?o0000olNO/?o7Wk000_o7Wk000ol0003oain`o`00000;ooooo`03o`000?oooooooooo067o
oooo002dooooo`?o0000>Oooool00ol0003oain`olNO/003olNO/004o`000?o7Wk3oain`o`0000_o
oooo00?o0000ooooooooool0H?ooool00;;ooooo0_l00003ooooo`03o`000?oooooooooo03Kooooo
00?o0000olNO/?o7Wk001?o7Wk000ol0003oain`o`00000<ooooo`03o`000?oooooooooo05oooooo
002_ooooo`?o00001_ooool00ol0003oooooooooo`0dooooo`03o`000?o7Wk3oain`00Goain`00?o
0000olNO/?l000003?ooool00ol0003oooooooooo`1Oooooo`00[Oooool2o`0003oooooo00?o0000
olNO/?o7Wk001_o7Wk001?l0003oain`olNO/?l0000;ooooo`;o0000H?ooool00:[ooooo0ol00011
ooooo`03o`000?o7Wk3oain`00Koain`00Co0000olNO/?o7Wk3o00003Oooool00ol0003ooooooooo
o`1Mooooo`00Z?ooool3o`0004;ooooo00?o0000olNO/?o7Wk001oo7Wk001?l0003oain`olNO/?l0
000=ooooo`03o`000?oooooooooo00Sooooo00GoA4A4o`000?l0003o<S8bomgMg@1@ooooo`00YOoo
ool3o`0000?ooooo00?o0000ooooooooool0?_ooool00ol0003oain`olNO/008olNO/005o`000?o7
Wk3oain`olNO/?l000003Oooool00ol0003oooooooooo`0:ooooo`03ogMgMolb<S;ooooo04oooooo
002Sooooo`;o0000Aoooool00ol0003oain`olNO/008olNO/005o`000?o7Wk3oain`olNO/?l00000
3_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo002Pooooo`?o0000B?oo
ool00ol0003oain`olNO/009olNO/005o`000?o7Wk3oain`olNO/?l000003_ooool00ol0003ooooo
ooooo`09ooooo`03ogMgMolb<S;ooooo04oooooo002Nooooo`;o0000B_ooool00ol0003oain`olNO
/00:olNO/003o`000?o7Wk3oain`00;oain`00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0D?ooool009_ooooo1?l0001;ooooo`03o`000?o7
Wk3oain`00[oain`00?o0000olNO/?o7Wk000_o7Wk000ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0D_ooool006cooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^8?ooool3o`0000Cooooo00?o0000ooooooooool0Aoooool2o`0000co
ain`00?o0000olNO/?o7Wk000_o7Wk000ol0003oooooooooo`0=ooooo`;o00001Oooool00ol0003o
ooooooooo`1Booooo`00K_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL07_ooool2o`00053ooooo00Co0000olNS]?o7XkCo00002oo7Wk000ol0003oain`olNO/003olNO
/003o`000?oooooooooo00_ooooo00?o0000ooooool000001Oooool4o`00057ooooo001^ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`?o0000DOooool01Ol0
003oaj>dolNS]?o7XkCo000000_oain`00?o0000olNO/?o7Wk000oo7Wk000ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo05Sooooo001^ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`?o0000Doooool01Ol0003oaj>dolNS]?o7XkCo000000_oain`00?o
0000olNO/?o7Wk000oo7Wk000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Oooooo001^
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o00000_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?o7XkCoaj>d00?oaj>d00?o0000olNO/?o7Wk002?o7
Wk000ol0003oain`olNO/002olNO/003o`000?o7XkCo0000013ooooo00?o0000ooooooooool0E_oo
ool006kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo0_l0
001Gooooo`03o`000?o7XkCoaj>d00Coaj>d00?o0000olNO/?o7Wk002?o7Wk001Ol0003oain`olNO
/?o7Wk3o000000;oaj>d00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Fooooo`00K_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool3o`0005Sooooo
00?o0000olNS]?o7Xk@01Oo7Xk@00ol0003oain`olNO/009olNO/003o`000?o7Wk3o000000?oaj>d
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Eooooo`00K?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool2o`0005[ooooo00?o0000olNS]?o7Xk@0
1_o7Xk@00ol0003oain`olNO/009olNO/003o`000?o7Wk3o000000Coaj>d00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Dooooo`00Q?ooool4o`0005_ooooo00?o0000olNS]?o7Xk@01oo7
Xk@00ol0003oain`olNO/008olNO/0;o00001Oo7Xk@00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0022ooooo`;o00001?ooool00ol0003oooooooooo`1Gooooo`03o`000?o7XkCo
aj>d00Soaj>d00?o0000olNO/?o7Wk002?o7Wk000ol0003oaj>dolNS]004olNS]003o`000?oooooo
oooo00oooooo0_l0001Eooooo`00Ooooool3o`0005oooooo00?o0000olNS]?o7Xk@02Oo7Xk@00ol0
003oain`olNO/007olNO/0;o00001oo7Xk@00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05;ooooo001mooooo`;o0000HOooool00ol0003oaj>dolNS]00;olNS]003o`000?o7Wk3oain`00Go
ain`00?o0000olNS]?l000001oo7Xk@00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05;o
oooo001jooooo`?o0000Hoooool00ol0003oaj>dolNS]00;olNS]003o`000?o7Wk3oain`00Goain`
00?o0000olNS]?l000001oo7Xk@00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo057ooooo
001hooooo`;o00000_ooool00ol0003oooooooooo`1Pooooo`03o`000?o7XkCoaj>d00coaj>d00?o
0000olNO/?o7Wk001?o7Wk001?l0003oaj>dolNS]?l00008olNS]003o`000?oooooooooo017ooooo
00?o0000ooooooooool0D?ooool007Gooooo0ol00005ooooo`03o`000?oooooooooo05kooooo00?o
0000olNS]?o7Xk@03Oo7Xk@00ol0003oain`olNO/003olNO/005o`000?o7XkCoaj>dolNS]?l00000
2?o7Xk@00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo001booooo`?o0000J?oo
ool00ol0003oaj>dolNS]00?olNS]005o`000?o7Wk3oain`olNO/?l000001?o7Xk@00ol0003oaj>d
olNS]006olNS]003o`000?oooooooooo01;ooooo00?o0000ooooooooool0Coooool0073ooooo0_l0
001[ooooo`03o`000?o7XkCoaj>d00ooaj>d00Go0000olNO/?o7Wk3oain`o`000004olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04_ooool00ol0003oooooooooo`1>ooooo`00KOoo
ool4o`0006_ooooo00?o0000olJV^Ol000004?o7Xk@01?l0003oain`olNO/?l00005olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04Oooool2o`00053ooooo001[ooooo`;o00001?oo
ool00ol0003oooooooooo`1Wooooo`04o`000?o6Y[WoaZJio`00017oaj>d0_l00006olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`00J?oo
ool3o`0006oooooo00Go0000olJV^Oo6Y[WoaZJio`00000AolNS]003o`000?o7XkCoaj>d00Goaj>d
00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04cooooo
001Vooooo`;o0000LOooool00ol0003oaZJiolJV^@03olJV^@03o`000?o7XkCoaj>d00koaj>d00?o
0000olNS]?o7Xk@01Oo7Xk@00ol0003oaj>dolNS]008olNS]003o`000?oooooooooo01?ooooo00?o
0000ooooooooool0C?ooool006?ooooo0ol0001booooo`03o`000?o6Y[WoaZJi00CoaZJi00?o0000
olNS]?o7Xk@03Oo7Xk@00ol0003oaZJio`000006olNS]003o`000?o7XkCoaj>d00Soaj>d00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1;ooooo`00>oooool01Om4A4Co0000o`000?lb<S;o
gMgM027ooooo0_l00003ooooo`03o`000?oooooooooo06kooooo00?o0000olJV^Oo6Y[T01Oo6Y[T0
0ol0003oaj>dolNS]00<olNS]004o`000?o6Y[WoaZJio`0000Koaj>d00?o0000olNS]?o7Xk@02Oo7
Xk@00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo000nooooo`03ogMgMolb<S;o
oooo01gooooo0ol0001eooooo`03o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@02_o7Xk@0
1Ol0003oaZJiolJV^Oo6Y[Wo000000Ooaj>d00?o0000olNS]?o7Xk@02?o7Xk@00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04[ooooo000oooooo`03o`000?oooooooooo01[ooooo0_l0001h
ooooo`03o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@02Oo7Xk@00ol0003oaZJiolJV^@03
olJV^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Wooooo000nooooo`03ogMgMolb<S;ooooo01Sooooo0ol0001ioooo
o`03o`000?o6Y[WoaZJi00WoaZJi00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oaZJiolJV^@03olJV
^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@01oo7Xk@00ol0003oaZJio`00000Eoooo
o`?o0000B_ooool003_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`;o00000_ooool00ol0
003oooooooooo`1fooooo`03o`000?o6Y[WoaZJi00[oaZJi00?o0000olNS]?o7Xk@01oo7Xk@00ol0
003oaZJiolJV^@04olJV^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@01_o7Xk@01?l0
003oaZJiolJV^Ol0000Gooooo`03o`000?oooooooooo04Sooooo000kooooo`03o`000?oooooooooo
01Kooooo0ol0001looooo`03o`000?o6Y[WoaZJi00_oaZJi00?o0000olNS]?o7Xk@01_o7Xk@00ol0
003oaZJiolJV^@06olJV^@03o`000?o7XkCoaj>d00?oaj>d00?o0000olNS]?o7Xk@01Oo7Xk@01Ol0
003oaZJiolJV^Oo6Y[Wo000001Sooooo00?o0000ooooooooool0Aoooool003_ooooo00?o0000oooo
ooooool04oooool3o`0007kooooo00?o0000olJV^Oo6Y[T03Oo6Y[T00ol0003oaj>dolNS]004olNS
]003o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@00oo7Xk@00ol0003oaj>dolNS]004olNS
]003o`000?o6Y[WoaZJi00?oaZJi00?o0000ooooooooool05Oooool00ol0003oooooooooo`17oooo
o`00>oooool4o`00013ooooo0_l00020ooooo`03o`000?o6Y[WoaZJi00koaZJi00?o0000olNS]?o7
Xk@00oo7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?o7XkCoaj>d00;oaj>d00?o0000olNS]?o7
Xk@00oo7Xk@00ol0003oaZJiolJV^@04olJV^@03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0A_ooool004cooooo1Ol0001oooooo`03o`000?o6Y[WoaZJi00ooaZJi00?o0000olNS]?o7Xk@0
0oo7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?o7XkCoaj>d00;oaj>d00?o0000olNS]?o7Xk@0
0_o7Xk@00ol0003oaZJiolJV^@05olJV^@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
AOooool004[ooooo0_l00023ooooo`;o00004_o6Y[T01Ol0003oaj>dolNS]?o7XkCo000000coaZJi
00?o0000olNS]?o7Xk@00_o7Xk@01Ol0003oaj>dolNS]?o7XkCo000000WoaZJi00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`15ooooo`00Aoooool3o`0008Cooooo00Co0000olFZ__o5Z[ko
00004Oo6Y[T01?l0003oaj>dolNS]?l0000>olJV^@05o`000?o7XkCoaj>dolNS]?l000000oo7Xk@0
0ol0003oaZJiolJV^@07olJV^@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A?ooool0
04Gooooo0_l00026ooooo`05o`000?o5Z[koaJZnolFZ__l000004Oo6Y[T00ol0003oaj>do`00000?
olJV^@05o`000?o7XkCoaj>dolNS]?l000000_o7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?oo
oooooooo01Kooooo0_l00015ooooo`00@_ooool4o`0008Kooooo00?o0000olFZ__o5Z[h00_o5Z[h0
0ol0003oaZJiolJV^@0@olJV^@03o`000?o6Y[WoaZJi00koaZJi00Oo0000olNS]?o7XkCoaj>do`00
0?o7XkCo000000coaZJi00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRoooooo0010ooooo`;o00001?ooool00ol0
003oooooooooo`22ooooo`03o`000?o5Z[koaJZn00CoaJZn00?o0000olJV^Oo6Y[T03_o6Y[T2o`00
017oaZJi00?o0000olNS]?o7Xk@00_l0000=olJV^@03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool0
03gooooo0ol0002:ooooo`03o`000?o5Z[koaJZn00GoaJZn00?o0000olJV^Oo6Y[T03Oo6Y[T01?l0
003oaJZnolFZ__l0000@olJV^@04o`000?o7XkCoaj>do`0000ooaZJi00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400_ooooo`00>oooool2o`0008cooooo00?o0000olFZ__o5Z[h01oo5Z[h00ol0003oaZJiolJV
^@0;olJV^@05o`000?o5Z[koaJZnolFZ__l000004?o6Y[T01?l0003oaj>do`000?l0000?olJV^@03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000;oooool003Sooooo0ol0002=ooooo`03o`000?o5Z[koaJZn00So
aJZn00?o0000olJV^Oo6Y[T02_o6Y[T00ol0003oaJZnolFZ_P02olFZ_P03o`000?o6Y[WoaZJi00oo
aZJi00?o0000olJV^Ol000003oo6Y[T00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002oooooo000fooooo`;o
00000oooool00ol0003oooooooooo`29ooooo`03o`000?o5Z[koaJZn00[oaJZn00?o0000olJV^Oo6
Y[T02?o6Y[T00ol0003oaJZnolFZ_P04olFZ_P03o`000?o6Y[WoaZJi00koaZJi00?o0000olJV^Ol0
00004?o6Y[T00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@02oooooo000cooooo`?o0000T?ooool00ol0003o
aJZnolFZ_P0;olFZ_P03o`000?o6Y[WoaZJi00OoaZJi00?o0000olFZ__o5Z[h01Oo5Z[h00ol0003o
aZJiolJV^@0=olJV^@05o`000?o5Z[ko0000olJV^Ol000003oo6Y[T00ol0003oooooooooo`0Ioooo
o`;o00001oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool0
037ooooo0_l0002Booooo`03o`000?o5Z[koaJZn00coaJZn00?o0000olJV^Oo6Y[T01_o6Y[T00ol0
003oaJZnolFZ_P07olFZ_P03o`000?o6Y[WoaZJi00_oaZJi00Ko0000olFZ__o5Z[ko0000olJV^Ol0
000?olJV^@03o`000?oooooooooo01Sooooo00?o0000ooooool000001Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;oooool002kooooo0ol0002Cooooo`03o`000?o5
Z[koaJZn00koaJZn00?o0000olJV^Oo6Y[T01?o6Y[T00ol0003oaJZnolFZ_P08olFZ_P03o`000?o6
Y[WoaZJi00[oaZJi00Oo0000olFZ__o5Z[koaJZno`000?o6Y[Wo0000013oaZJi00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0mooooo`00:oooool3o`0000;ooooo00?o0000ooooooooool0
Soooool2o`00017oaJZn00?o0000olJV^Oo6Y[T00oo6Y[T00ol0003oaJZnolFZ_P0:olFZ_P03o`00
0?o6Y[WoaZJi00SoaZJi00?o0000olFZ__o5Z[h00oo5Z[h2o`0000ooaZJi0_l0000Looooo`03o`00
0?oooooooooo03gooooo000Yooooo`;o0000U_ooool00ol0003oa:o5o`00000BolFZ_P05o`000?o6
Y[WoaZJiolJV^Ol000003Oo5Z[h00ol0003oaZJiolJV^@07olJV^@03o`000?o5Z[koaJZn00CoaJZn
0_l0000>olJV^@04o`000?o5Z[koaJZno`0001cooooo00?o0000ooooooooool0??ooool002Kooooo
0ol0002Gooooo`05o`000?o4[lGoa:o5olB_aOl000004Oo5Z[h01?l0003oaZJiolJV^Ol0000>olFZ
_P03o`000?o6Y[WoaZJi00KoaZJi00?o0000olFZ__o5Z[h01_o5Z[h00ol0003oaZJiolJV^@0;olJV
^@05o`000?o5Z[koaJZnolFZ__l000007Oooool00ol0003oooooooooo`0kooooo`009?ooool2o`00
09Wooooo00?o0000olB_aOo4[lD00_o4[lD00ol0003oaJZnolFZ_P0?olFZ_P03o`000?o6Y[Wo0000
013oaJZn00?o0000olJV^Oo6Y[T01?o6Y[T00ol0003oaJZnolFZ_P07olFZ_P03o`000?o6Y[WoaZJi
00[oaZJi00?o0000olFZ__o5Z[h00_o5Z[h00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03_ooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`2Eooooo`03o`000?o4[lGoa:o500Co
a:o500?o0000olFZ__o5Z[h03_o5Z[h2o`00017oaJZn00?o0000olJV^Oo6Y[T00oo6Y[T00ol0003o
aJZnolFZ_P07olFZ_P?o00002_o6Y[T00ol0003oaJZnolFZ_P04olFZ_P03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0>_ooool001oooooo0_l0002Looooo`03o`000?o4[lGoa:o500Goa:o5
00?o0000olFZ__o5Z[h03Oo5Z[h00ol0003oa:o5o`00000BolFZ_P05o`000?o6Y[WoaZJiolJV^Ol0
00001oo5Z[h3o`000003olFZ__l0003o000000WoaZJi00?o0000olFZ__o5Z[h01Oo5Z[h00ol0003o
ooooooooo`0Jooooo`?o0000>oooool001cooooo0ol0002Mooooo`03o`000?o4[lGoa:o500Koa:o5
00?o0000olFZ__o5Z[h03?o5Z[h01Ol0003oa:o5olB_aOo4[lGo0000017oaJZn00Co0000olJV^Oo6
Y[Wo00001Oo5Z[h3o`0000GoaJZn00?o0000olJV^Oo6Y[T01_o6Y[T00ol0003oaJZnolFZ_P06olFZ
_P03o`000?oooooooooo01cooooo00?o0000ooooooooool0>Oooool001_ooooo0_l0002Nooooo`03
o`000?o4[lGoa:o500Soa:o500?o0000olFZ__o5Z[h02_o5Z[h00ol0003oa:o5olB_a@02olB_a@03
o`000?o5Z[koaJZn00ooaJZn00?o0000olJV^Ol000000oo5Z[h3o`0000WoaJZn00?o0000olJV^Oo6
Y[T01?o6Y[T00ol0003oaJZnolFZ_P08olFZ_P03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0>?ooool001_ooooo00?o0000ooooool00000W?ooool00ol0003oa:o5olB_a@09olB_a@03o`00
0?o5Z[koaJZn00WoaJZn00?o0000olB_aOo4[lD01?o4[lD00ol0003oaJZnolFZ_P0>olFZ_P;o0000
00CoaJZno`000?l0003o00003?o5Z[h2o`0000CoaZJi00?o0000olFZ__o5Z[h02Oo5Z[h00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo03Sooooo000Jooooo`;o00000_ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?o4[lGoa:o500_oa:o500?o0000olFZ__o5Z[h01oo5Z[h00ol0003oa:o5
olB_a@05olB_a@03o`000?o5Z[koaJZn00goaJZn1?l0000@olFZ_P05o`000?o6Y[WoaZJiolJV^Ol0
00003?o5Z[h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Oooooo000Jooooo`?o0000
0_ooool00ol0003oooooooooo`2Fooooo`03o`000?o4[lGoa:o500coa:o500?o0000olFZ__o5Z[h0
1_o5Z[h00ol0003oa:o5olB_a@06olB_a@03o`000?o5Z[koaJZn00_oaJZn0ol00002olB_a@03o`00
0?o5Z[koaJZn00koaJZn0_l000000oo6Y[Wo0000olFZ_P0=olFZ_P03o`000?oooooooooo01gooooo
00?o0000ooooooooool0=_ooool001[ooooo00?o0000oa/^Z?l000000oooool00ol0003ooooooooo
o`2Dooooo`03o`000?o4[lGoa:o500koa:o500?o0000olFZ__o5Z[h01?o5Z[h00ol0003oa:o5olB_
a@08olB_a@03o`000?o5Z[koaJZn00OoaJZn1?l00004olB_a@03o`000?o5Z[koaJZn00koaJZn00?o
0000olJV^Ol000003oo5Z[h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Kooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo0_l000000olK;ZSo
0000ooooo`02ooooo`03o`000?oooooooooo00Oooooo0_l00028ooooo`;o00004Oo4[lD00ol0003o
aJZnolFZ_P03olFZ_P03o`000?o4[lGoa:o500Woa:o500?o0000olFZ__o5Z[h01Oo5Z[h2o`0000;o
aJZn00?o0000olB_aOo4[lD00oo4[lD00ol0003oaJZnolFZ_P0>olFZ_P?o00003oo5Z[h00ol0003o
ooooooooo`0Nooooo`;o0000=_ooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo0_l00002oa/^Z005o`000?ooooooooooooooool000001oooool00ol0
003oZSH[o`000027ooooo`03o`000?o2]<go0000017oa:o500?o0000olFZ__o5Z[h00_o5Z[h00ol0
003oa:o5olB_a@0;olB_a@04o`000?o5Z[koaJZnolFZ_P?o00000oo5Z[h00ol0003oa:o5olB_a@05
olB_a@03o`000?o5Z[koaJZn00coaJZn00Go0000olB_aOl0003oaJZno`00000?olFZ_P03o`000?oo
oooooooo01cooooo00?o0000ooooool00000=_ooool000Go00001Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000?o6bjX00Go0000oooooooooooooooo
o`000004ooooo`;o00000onZ=R/00ol0003oooooooooo`23ooooo`05o`000?o2]<go`[C=ol:dcOl0
00004Oo4[lD01?l0003oaJZnolFZ__l0000>olB_a@Co00001Oo5Z[h00ol0003oa:o5olB_a@06olB_
a@03o`000?o5Z[koaJZn00_oaJZn00Oo0000olB_aOo4[lGoa:o5o`000?o5Z[ko000000koaJZn00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`002_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001Oooool4o`0000?o6bjX00Go0000oooooooooooooooo
o`000002ooooo`03o`000?nZ=R_oZSH[00CoZSH[00?o0000ooooooooool03?ooool2o`0007;ooooo
0_l00004ol:dc@03o`000?o4[lGoa:o500ooa:o500?o0000olFZ__l000003Oo4[lD4o`0000KoaJZn
00?o0000olB_aOo4[lD01oo4[lD00ol0003oaJZnolFZ_P0:olFZ_P03o`000?o4[lGoa:o500;oa:o5
00Co0000olFZ__o5Z[ko00003Oo5Z[h00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03?o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo000000Co6bjX00Co0000oooooooooooooooo0_l00008ojXf:`03o`000?oooooooooo
00[ooooo00?o0000ojXf:ol00000LOooool00ol0003o`[C=ol:dc@05ol:dc@03o`000?o4[lGoa:o5
00koa:o50_l0000;olB_a@?o00000oo4[lD00ol0003oaJZnolFZ_P03olFZ_P03o`000?o4[lGoa:o5
00Woa:o500?o0000olFZ__o5Z[h02?o5Z[h00ol0003oa:o5olB_a@04olB_a@03o`000?o5Z[ko0000
00goaJZn0_l0000Qooooo`03o`000?oooooooooo03;ooooo000:ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4005ooooo`04o`000?ooooooooooo`0000Go6bjX00?o0000
ooooool000002onZ=R/00ol0003oooooooooo`08ooooo`05o`000?nZ=R_oZSH[ojXf:ol00000Kooo
ool00ol0003o`[C=ol:dc@06ol:dc@03o`000?o4[lGoa:o500goa:o500?o0000ol:dcOl000002?o4
[lD3o`0000Koa:o500?o0000olFZ__o5Z[h00_o5Z[h00ol0003oa:o5olB_a@0:olB_a@03o`000?o5
Z[koaJZn00OoaJZn00?o0000olB_aOo4[lD01Oo4[lD01?l0003oaJZnolFZ__l0000;olFZ_P03o`00
0?o4[lGo0000027ooooo00?o0000ooooooooool0<_ooool000[ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00Go0000ooooooooooooooooo`000005oa/^Z003
o`000?nZ=R_oZSH[00_oZSH[00?o0000ooooooooool01Oooool2o`0000GoZSH[00?o0000oooooooo
ool0Joooool00ol0003o`[C=ol:dc@08ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2
]<go`[C=o`000004olB_a@?o00002_o4[lD01?l0003oaJZnolFZ__l0000>olB_a@03o`000?o5Z[ko
aJZn00GoaJZn00?o0000olB_aOo4[lD01oo4[lD01?l0003oaJZnolFZ__l00009olFZ_P05o`000?o4
[lGoa:o5olB_aOl000008Oooool00ol0003oooooooooo`0aooooo`002?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000;ooooo00?o0000oa/^Z?lK;ZP0
0olK;ZP00ol0003oZSH[ojXf:`0<ojXf:`03o`000?oooooooooo00?ooooo00?o0000ojXf:onZ=R/0
1_nZ=R/00ol0003oooooooooo`0;ooooo`;o0000Foooool2o`0000_o`[C=00?o0000olB_aOo4[lD0
2Oo4[lD2o`0000Co`[C=00?o0000olB_aOl000000_l0000=olB_a@03o`000?o5Z[ko000000ooa:o5
00?o0000olFZ__o5Z[h01?o5Z[h00ol0003oa:o5olB_a@08olB_a@05o`000?o5Z[koaJZnolFZ__l0
00001oo5Z[h00ol0003oa:o5olB_a@02olB_a@03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0<?ooool001Wooooo00Go0000ooooooooooooooooo`000006oa/^Z003o`000?nZ=R_oZSH[00co
ZSH[00Go0000ooooooooooooooooo`00000:ojXf:`03o`000?oooooooooo00Wooooo00Co0000ojXg
:onZ=b_o0000FOooool00ol0003o`[C=ol:dc@0<ol:dc@03o`000?o4[lGoa:o500Ooa:o500?o0000
ol:dcOo2]<d01?o2]<d2o`00013oa:o50_l0000@olB_a@03o`000?o5Z[koaJZn00?oaJZn00?o0000
olB_aOo4[lD02_o4[lD01?l0003oaJZnolFZ__l00006olFZ_P03o`000?o4[lGoa:o500Coa:o500?o
0000ooooooooool07_ooool2o`0003;ooooo000Iooooo`05o`000?ooooooooooooooool000001olK
;ZP00ol0003oZSH[ojXf:`0<ojXf:`03o`000?oooooo000000coZSH[00?o0000ooooooooool01_oo
ool2o`0000CoZSL[00?o0000ooooooooool0EOooool00ol0003o`[C=ol:dc@0=ol:dc@03o`000?o4
[lGoa:o500Koa:o500?o0000ol:dcOo2]<d00_o2]<d3o`000003ol:dcOl0003oa:o500koa:o500?o
0000ol:dcOl000004Oo4[lD01Ol0003oaJZnolFZ__o5Z[ko000000goa:o500Go0000olFZ__o5Z[ko
aJZno`000004olFZ_P03o`000?o4[lGoa:o500Goa:o500?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0_ooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?lK;ZSo6bjX00Co6bjX
0_l0000=ojXf:`?o00003OnZ=R/00ol0003oooooooooo`04ooooo`03o`000?nZ=b_oZSL[00GoZSL[
00?o0000ooooooooool02_ooool2o`0004Kooooo0_l0000Aol:dc@03o`000?o4[lGoa:o500Coa:o5
00?o0000ol:dcOo2]<d00ol00005ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2]<go
`[C=o`00000@olB_a@04o`000?o5Z[koaJZno`0000koa:o500?o0000olFZ__o5Z[h00_o5Z[h01?l0
003oaJZnolFZ__l00009olB_a@03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool0
01Sooooo00?o0000ooooooooool00oooool00ol0003o6bjXoa/^Z004oa/^Z003o`000?o4Vjko0000
00[oZSH[0_l00003oj8W6003o`000?nZ=R_oZSH[00_oZSH[00Co0000oooooooooooooooo0_l00009
ojXg:`03o`000?oooooooooo00Sooooo00Co0000ojXg;?nZ=bco0000A?ooool00ol0003o_[_Go`00
000Aol:dc@03o`000?o4[lGoa:o500;oa:o51Ol00008ol:dc@03o`000?o4[lGoa:o500Woa:o50_l0
0004ol:dc@03o`000?o4[lGoa:o500koa:o500?o0000olFZ__l000004?o4[lD00ol0003oaJZnolFZ
_P02olFZ_P;o00002_o4[lD00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02kooooo000H
ooooo`;o00001?ooool00ol0003o6bjXoa/^Z003oa/^Z005o`000?o4Vjkoa9^^olBK[_l000001onZ
=R/2o`0000KoXRLH00?o0000ojXf:onZ=R/02onZ=R/00ol0003oooooo`00000<ojXg:`03o`000?oo
oooooooo00Kooooo00?o0000ojXg;?nZ=b`00_nZ=b`00ol0003oooooooooo`0oooooo`;o00000onn
^mL00ol0003o`[C=ol:dc@0?ol:dc@03o`000?o4[lGoa:o500?o00003?o2]<d00ol0003oa:o5olB_
a@07olB_a@03o`000?o2]<go`[C=00Go`[C=00?o0000olB_aOo4[lD03Oo4[lD2o`00017oa:o500?o
0000olFZ__o5Z[h00_o5Z[h00ol0003oa:o5olB_a@0:olB_a@03o`000?oooooooooo023ooooo00?o
0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool01?ooool01Ol0003o6bjXoa/^Z?lK
;ZSo000000Goa9^^00?o0000ojXf:onZ=R/00_nZ=R/2o`0000WoXRLH00?o0000ojXf:onZ=R/02_nZ
=R/3o`0000goZSL[00?o0000ooooooooool00oooool2o`0000KoZSL/00?o0000ooooooooool02ooo
ool2o`00033ooooo00?o0000okjkeonn^mL00onn^mL00ol0003o`[C=ol:dc@0?ol:dc@?o00003oo2
]<d00ol0003oa:o5olB_a@06olB_a@03o`000?o2]<go`[C=00Ko`[C=00?o0000olB_aOo4[lD03?o4
[lD00ol0003o`[C=o`00000BolB_a@06o`000?o5Z[koaJZno`000?o4[lGo00002oo4[lD00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02cooooo000Hooooo`03o`000?oooooooooo00Cooooo
00Co0000oa/^Z?lK;ZSo00001oo4Vjh01?l0003oZSH[o`000?l0000<oj8W6003o`000?nZ=R_oZSH[
00OoZSH[0_l00003oj8W6003o`000?nZ=b_oZSL[00_oZSL[00Go0000ooooooooooooooooo`000009
ojXg;003o`000?oooooooooo00Wooooo00?o0000ojXg;?l00000;_ooool2o`0000Oo_[_G00?o0000
ol:dcOo2]<d02oo2]<d5o`00017o`[C=00?o0000olB_aOo4[lD01?o4[lD00ol0003o`[C=ol:dc@07
ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2]<go`[C=o`00000AolB_a@03o`000?o5
Z[ko000000?oa:o500?o0000olB_aOo4[lD02?o4[lD00ol0003oooooooooo`0Qooooo`;o0000;Ooo
ool001Sooooo00?o0000ooooooooool01?ooool01?l0003o6bjXoa/^Z?l00008olBK[P;o00003_nR
9aP00ol0003oZSH[ojXf:`04ojXf:`;o00001_nR9aP00ol0003oZSL[ojXg:`0;ojXg:`03o`000?oo
oooo000000_oZSL/00?o0000ooooooooool01oooool01Ol0003oZSL/ojXg;?nZ=bco000002cooooo
00?o0000okjkeonn^mL01onn^mL00ol0003o`[C=ol:dc@08ol:dc@?o00000_o2]<d00ol0003o_[_G
o`00000Aol:dc@03o`000?o4[lGoa:o500;oa:o50_l0000;ol:dc@03o`000?o4[lGoa:o500Soa:o5
0_l00004ol:dc@03o`000?o4[lGoa:o500ooa:o50_l00004olB_a@03o`000?o4[lGoa:o500Woa:o5
00?o0000ooooooooool08?ooool2o`0000Wooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000?o<S8bomgMgOooool05_ooool001Sooooo00?o0000ooooooooool01Oooool2o`0000_oa9^^
00?o0000oj8W6?nR9aP03?nR9aP00ol0003oZSH[ojXf:`02ojXf:`03o`000?nR9aSoXRLH00OoXRLH
00?o0000ojXg:onZ=b/02_nZ=b/3o`0000coZSL/00?o0000ooooooooool01Oooool00ol0003oZSL/
ojXg;003ojXg;003o`000?oooooooooo00_ooooo0_l0000Kooooo`03o`000?nn^mOo_[_G00Wo_[_G
00?o0000ol:dcOo2]<d01?o2]<d3o`0000?o`[C=0_l00003okjke`03o`000?o2]<go`[C=00oo`[C=
00Co0000olB_aOo4[lGo00003Oo2]<d00ol0003oa:o5olB_a@07olB_a@03o`000?o2]<go`[C=00Go
`[C=00?o0000olB_aOo4[lD03Oo4[lD00ol0003o`[C=o`000005olB_a@03o`000?o4[lGoa:o500So
a:o500?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgoc8b<_ooool05_ooool001Oooooo00?o0000ooooooooool01_ooool00ol0003oa9^^
olBK[P0;olBK[P;o00003OnR9aP01?l0003oZSH[o`000?l0000;oj8W6003o`000?nZ=b_oZSL[00Oo
ZSL[0_l00003oj8X6@03o`000?nZ=bcoZSL/00[oZSL/00?o0000ooooooooool00oooool00ol0003o
ZSL/ojXg;005ojXg;003o`000?oooooooooo00Wooooo00Co0000ojXg;?nZ=bco00006?ooool2o`00
00go_[_G00Co0000ol:dcOo2]<go`[C=0_l00005ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000
ol:dcOo2]<d03oo2]<d00ol0003oa:o5o`00000?ol:dc@03o`000?o4[lGoa:o500Goa:o500?o0000
ol:dcOo2]<d01_o2]<d00ol0003oa:o5olB_a@0<olB_a@05o`000?o2]<go`[C=ol:dcOl000001Oo4
[lD00ol0003oa:o5olB_a@08olB_a@03o`000?oooooooooo027ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03o`000?oooooo
oooo00Kooooo00?o0000olBK[_o4Vjh03Oo4Vjh00ol0003oXRLHoj8W600:oj8W60?o00003OnR9aP0
0ol0003oZSL[ojXg:`04ojXg:`;o00001_nR:1T00ol0003oZSL/ojXg;00:ojXg;005o`000?oooooo
ooooooooool000002OnZ=b`00ol0003oooooooooo`07ooooo`03o`000?nZ=bcoZSL/00;oZSL/00?o
0000ooooooooool05?ooool00ol0003o_[_Gokjke`0=okjke`Co00001Oo2]<d2o`0000Oo_[_G00?o
0000ol:dcOo2]<d03_o2]<d2o`00013o`[C=00?o0000olB_aOo4[lD01?o4[lD00ol0003o`[C=ol:d
c@08ol:dc@03o`000?o4[lGoa:o500Woa:o50_l00004ol:dc@03o`000?o4[lGoa:o500Coa:o500?o
0000olB_aOo4[lD01oo4[lD00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`0Fooooo`005oooool00ol0003oooooooooo`06
ooooo`03o`000?o4Vjkoa9^^00koa9^^00?o0000oj8W6?nR9aP01onR9aP2o`0000?oUQ8000?o0000
oj8W6?nR9aP02onR9aP00ol0003oZSL[ojXg:`02ojXg:`03o`000?nR:1WoXRPI00OoXRPI00?o0000
ojXg;?nZ=b`02_nZ=b`00ol0003oooooo`00000;ojXg;003o`000?oooooooooo00Gooooo00?o0000
ojXg;?nZ=b`01?nZ=b`00ol0003oooooooooo`0Aooooo`;o00003_nn^mL4o`0000Ko`[C=00?o0000
okjkeonn^mL01onn^mL00ol0003o`[C=ol:dc@0=ol:dc@03o`000?nn^mOo0000017o`[C=00Co0000
olB_aOo4[lGoa:o50_l0000<ol:dc@03o`000?o4[lGoa:o500Ooa:o500?o0000ol:dcOo2]<d01Oo2
]<d00ol0003oa:o5olB_a@03olB_a@03o`000?o4[lGoa:o500Ooa:o50_l0000Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Oooooo
000Gooooo`03o`000?oooooooooo00Oooooo00?o0000olBK[_o4Vjh03_o4Vjh2o`0000CoXRLH0ol0
0006oiHB00;o00003?nR9aP01?l0003oZSL[o`000?l0000;oj8X6@03o`000?nZ=bcoZSL/00WoZSL/
0ol0000<ojXg;003o`000?oooooooooo00?ooooo00?o0000ojXg;?nZ=b`01_nZ=b`00ol0003ooooo
ooooo`09ooooo`?o00000_ooool2o`000003okS3hol0003o_[_G00[o_[_G0ol00003okjke`03o`00
0?o2]<go`[C=00?o`[C=00?o0000okjkeonn^mL02Onn^mL00ol0003o`[C=ol:dc@0:ol:dc@;o0000
0onn^mL00ol0003o`[C=ol:dc@0>ol:dc@04o`000?o4[lGoa:o5o`0000ko`[C=00?o0000olB_aOo4
[lD01_o4[lD00ol0003o`[C=ol:dc@06ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000olB_aOo4
[lD01Oo4[lD00ol0003o`[C=o`00000Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Iooooo`005oooool3o`0000Oooooo00?o0000olBK[_o4Vjh0
3_o4Vjh01?l0003oa9^^o`000?nR9aP2o`0000_oUQ8000?o0000oj8W6?nR9aP02OnR9aP3o`0000go
XRPI00?o0000ojXg;?nZ=b`01onZ=b`01Ol0003oXRPIoj8X6OnR:1Wo000000coZSL/00Go0000oooo
ooooooooooooo`00000:ojXg;003o`000?oooooooooo00Oooooo00Co0000ojXg;OnZ=bgoZSL]0_l0
0004okS3h`03o`000?nn^mOo_[_G00Go_[_G0ol00007okjke`03o`000?o2]<go`[C=00;o00003Onn
^mL00ol0003o`[C=ol:dc@08ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000ol:dcOo2]<d03_o2
]<d00ol0003oa:o5o`00000@ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000ol:dcOo2]<d01oo2
]<d00ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGoa:o500?oa:o500Go0000ol:dcOo2]<go`[C=
o`00000Sooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo
000Fooooo`;o00002Oooool00ol0003oa9^^olBK[P0>olBK[P03o`000?o4Vjkoa9^^00;o00003OnF
4P000ol0003oXRLHoj8W6006oj8W60;o00000onF4P000ol0003oXRPIoj8X6@0;oj8X6@03o`000?nZ
=bcoZSL/00CoZSL/0_l00005oj8X6@03o`000?nZ=bcoZSL/00[oZSL/00?o0000ooooool000003?nZ
=b`00ol0003oooooooooo`05ooooo`03o`000?nZ=bgoZSL]00;o00001onh`n<01?l0003o_[_Gokjk
eonn^mL3o`0000[o_[_G00?o0000ol:dcOl000003onn^mL00ol0003o`[C=ol:dc@06ol:dc@;o0000
1onn^mL00ol0003o`[C=ol:dc@0=ol:dc@;o00004Oo2]<d00ol0003oa:o5olB_a@02olB_a@;o0000
2oo2]<d00ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGoa:o500;o00001?o2]<d00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001Oooool4o`0001Sooooo
000<ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?o4Vjkoa9^^00coa9^^0_l00004olBK[P;o00003?nF4P02o`0000CoXRLH0_l00006oiHB0003o`00
0?nR:1WoXRPI00_oXRPI00Co0000ojXg;?nZ=bcoZSL/0_l00008oj8X6@03o`000?nZ=bcoZSL/00Wo
ZSL/0ol0000=ojXg;003o`000?oooooooooo00?ooooo00Co0000ojXg;OnZ=bgo00002Onh`n<4o`00
00go_[_G0_l0000Aokjke`03o`000?o2]<go`[C=00Co`[C=00?o0000okjkeonn^mL01onn^mL00ol0
003o`[C=ol:dc@0<ol:dc@03o`000?nn^mOo000001;o`[C=00Co0000olB_aOo4[lGo00003Oo2]<d0
0ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGo000000Oo`[C=00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Vooooo`003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000olBK[_o4Vjh02oo4Vjh01?l0003oa9faolBM/Ol00005olBK[P03o`000?nF4P3o
UQ8000_oUQ8000Co0000oj8W6?l0003o00002OnF4P000ol0003oXRPIoj8X6@0;oj8X6@03o`000?nZ
=bco000000_oXRPI0_l00008ojXg;005o`000?nS:1[oXbPJoj<X6_l000003OnZ=b`01_l0003ooooo
oooooooooooo0000ojXg;@;o00002?nh`n<4o`0000go_[_G0_l000000onh`n?o0000okjke`0@okjk
e`03o`000?o2]<go`[C=00?o`[C=00?o0000okjkeonn^mL02Onn^mL00ol0003o`[C=ol:dc@09ol:d
c@;o00000onn^mL00ol0003o`[C=ol:dc@0?ol:dc@03o`000?o4[lGo000000oo`[C=00?o0000olB_
aOo4[lD01Oo4[lD00ol0003o`[C=ol:dc@06ol:dc@03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool09Oooool000?ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oa9^^olBK[P0:olBK[P05o`000?o4WK7oa9faolBM/Ol000001_o4Vjh2o`00
00_oUQ800ol0000;oiHB00;o00002onR:1T3o`0000goXRPI00?o0000ojXg;?nZ=b`00onZ=b`2o`00
00GoXbPJ00?o0000ojXg;?nZ=b`02onZ=b`00ol0003oooooo`000002o`0000So^<?S0_l00004okS3
h`03o`000?nn^mOo_[_G00So_[_G0_l00004okS3h`03o`000?nn^mOo_[_G00oo_[_G00?o0000ol:d
cOo2]<d00_l0000<okjke`03o`000?o2]<go`[C=00Oo`[C=0_l00005okjke`03o`000?o2]<go`[C=
00oo`[C=0_l0000@ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000ol:dcOl000001oo2]<d00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Gooooo000?ooooo`03ogMgMolb<S;ooooo00Co
oooo0_l0000;ooooo`03o`000?o4Vjkoa9^^00Woa9^^00Go0000olBM/Oo4WK7oa9fao`000008olBK
[P;o00001_nF4P03o`0000?oP@000_l0000;oiHB0003o`000?nR:1WoXRPI00KoXRPI0_l00003oiHC
0003o`000?nR:1WoXRPI00_oXRPI00Go0000ojXg;?nZ=bcoZSL/o`000008oj<X6P03o`000?nZ=bco
ZSL/00[oZSL/0ol00007okS3h`?o00001_nh`n<00ol0003o_[_Gokjke`06okjke`;o00001onh`n<0
0ol0003o_[_Gokjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01Oo2]<d0
0ol0003o_[_Gokjke`06okjke`03o`000?o2]<go`[C=00go`[C=00?o0000okjkeol000004Oo2]<d0
1?l0003oa:o5olB_aOo4[lD2o`0000;o`[C=00?o0000ol:dcOo2]<d01_o2]<d00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?o4Vjkoa9^^00Soa9^^00?o0000olBM/Oo4WK400oo4
WK400ol0003oa9^^olBK[P07olBK[P03o`000?nF4P3oUQ8000?o00002?n100000ol0003oUQ80oiHB
0009oiHB0003o`000?nR:1WoXRPI00;oXRPI0ol00006oiHC00;o00003?nR:1T00ol0003oZSL/o`00
000:oj<X6P;o00002?nZ=b`3o`000003ojc;l?l0003o^<?S00?o^<?S0ol0000:okS3h`03o`000?nn
^mOo_[_G00Co_[_G00?o0000okS3honh`n<01onh`n<00ol0003o_[_Gokjke`0>okjke`;o00004?nn
^mL00ol0003o`[C=ol:dc@03ol:dc@;o00002_nn^mL00ol0003o`[C=ol:dc@0:ol:dc@;o00000onn
^mL00ol0003o`[C=ol:dc@0>ol:dc@04o`000?o4[lGoa:o5o`0000Go`[C=00?o0000ol:dcOo2]<d0
1Oo2]<d00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oa9^^olBK[P07olBK[P03o`000?o4
WK7oa9fa00Coa9fa00?o0000olBK[_o4Vjh02?o4Vjh2o`0000coP@000_l0000:oiHB0004o`000?nR
:1Wo0000o`0000_oUQ<000?o0000oj8X6OnR:1T02OnR:1T3o`0000coXbPJ00?o0000ojXg;?nZ=b`0
0onZ=b`2o`0000Go[<_`1?l0000=okS3h`03o`000?nn^mOo_[_G00;o_[_G0_l0000;okS3h`03o`00
0?nn^mOo_[_G00_o_[_G0_l000000onh`n?o0000okjke`0@okjke`03o`000?o2]<go`[C=00;o0000
3?nn^mL00ol0003o`[C=ol:dc@09ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000ol:dcOo2]<d0
3_o2]<d00ol0003oa:o5o`000007ol:dc@03o`000?o2]<go`[C=00Go`[C=00?o0000ooooooooool0
8_ooool3o`0002Cooooo000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oa9^^olBK[P06olBK[P03o`000?o4WK7oa9fa00Goa9fa00?o0000olBK[_o4Vjh02_o4
Vjh3o`0000_oP@000_l00007oiHB00Co00003OnF4`000ol0003oXRPIoj8X6@06oj8X6@;o00000onF
4`000ol0003oXbPJoj<X6P0:oj<X6P03o`000?nZ=bcoZSL/00;o00001On/bo04o`00013o^<?S00Co
0000okjkeol0003o00003_nh`n<00ol0003o_[_Gokjke`08okjke`;o00001?nh`n<00ol0003o_[_G
okjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01_o2]<d2o`0000Oo_[_G
00?o0000ol:dcOo2]<d03Oo2]<d2o`0000Wo`[C=00?o0000ol:dcOo2]<d01?o2]<d00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02;ooooo000<ooooo`Co00001Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?o4Vjkoa9^^00Goa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^olBK
[P08olBK[P04o`000?o4WK7oa9faolBM/@;o00002on100000ol0003oUQ80oiHB0004o`0000CoPP00
0_l0000<oiHC00;o00001?nR:1T2o`0000KoUQ<00_l0000:oj<X6P?o00001?n/bo03o`0000Co[<_`
00?o0000okS3honh`n<03Onh`n<2o`00017o^<?S00?o0000okjkeonn^mL01?nn^mL3o`0000Oo^<?S
00?o0000okjkeonn^mL03Onn^mL2o`00013o_[_G00?o0000ol:dcOo2]<d01Oo2]<d00ol0003o_[_G
okjke`07okjke`03o`000?o2]<go`[C=00co`[C=00?o0000okjkeol000002Oo2]<d00ol0003o`[C=
ol:dc@05ol:dc@03o`000?oooooooooo02Cooooo00?o0000ooooooooool08Oooool001Gooooo0_l0
000=ooooo`03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401oo4WK400ol0003oa9^^olBK
[P07olBK[P03o`000?o4WK7oa9fa00Coa9fa0ol00005oh4000Ko00002_n20003o`0000_oUQ<000Co
0000oj8X6Ol0003o00002_nF4`000ol0003oXbPJoj<X6P04oj<X6P?o00001?n/bo03o`0000So[<_`
00?o0000okS3honh`n<02Onh`n<3o`000003ojc;l?l0003o^<?S013o^<?S00?o0000okjkeonn^mL0
0_nn^mL2o`0000[o^<?S00?o0000okjkeonn^mL02onn^mL2o`000003okS3hol0003o_[_G013o_[_G
00?o0000ol:dcOo2]<d00oo2]<d00ol0003o_[_Gokjke`09okjke`03o`000?o2]<go`[C=00Wo`[C=
0_l00003okjke`03o`000?o2]<go`[C=00Oo`[C=00?o0000ol:dcOo2]<d01?o2]<d00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo027ooooo000Eooooo`03o`000?oooooooooo00cooooo00?o
0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@08olBM/@03o`000?o4Vjkoa9^^00Koa9^^00?o
0000olBM/Oo4WK401Oo4WK400ol0003oa9^^olBK[P05o`0000KoGP000_l0000;oh8000;o00002?nF
4`04o`0000coUQ<000?o0000oj<X6_nS:1X00ol00003oiOAo0Co00003?n/bo000ol0003o^<?SokS3
h`06okS3h`;o00001On/bo000ol0003o^<?SokS3h`0?okS3h`04o`000?nn^mOo0000o`0000go^<?S
00?o0000okjkeonn^mL02Onn^mL00ol0003o^<?SokS3h`02okS3h`03o`000?nn^mOo_[_G00oo_[_G
00?o0000ol:dcOo2]<d00_l0000<okjke`03o`000?o2]<go`[C=00Oo`[C=0_l00005okjke`03o`00
0?o2]<go`[C=00So`[C=00?o0000ol:dcOo2]<d00oo2]<d00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo023ooooo000Eooooo`03o`000?oooooooooo00gooooo00Go0000olBK[_o4Vjkoa9^^
o`00000<olBM/@03o`000?o4Vjkoa9^^00Goa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^
olBK[P02olBK[PCo00001_mN0002o`0000_oPP000_l00002oiHC00Co00001?n20002o`0000[oUQ<0
0ol00005oiOAo0?o00003on/bo000ol0003o^<?SokS3h`03okS3h`;o00002?n/bo000ol0003o^<?S
okS3h`0>okS3h`;o00004?nh`n<00ol0003o_[_Gokjke`06okjke`;o00001_nh`n<00ol0003o_[_G
okjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01Oo2]<d00ol0003o_[_G
okjke`06okjke`03o`000?o2]<go`[C=00So`[C=00?o0000ol:dcOo2]<d00_o2]<d2o`0002Oooooo
00?o0000ooooooooool07oooool001Gooooo00?o0000ooooooooool03Oooool01Ol0003oa9^^olBK
[_o4Vjko000000coa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@07olBM/@03o`00
0?o4Vjkoa9^^00Koa9^^0ol00005oeh000;o00002On20004o`0000[oPP0000?o0000oiHC0?nF4`00
1?nF4`03o`0000GoUm7l0ol00003oiOAo003o`000?n/bo3o[<_`00go[<_`00?o0000okS3hol00000
0_l0000;ojc;l003o`000?nh`n?o^<?S00[o^<?S0ol000000on/c?3o0000okS3h`0@okS3h`03o`00
0?nn^mOo_[_G00?o_[_G0_l00008okS3h`03o`000?nn^mOo_[_G00ko_[_G0_l0000@okjke`03o`00
0?o2]<go`[C=00?o`[C=0_l00009okjke`03o`000?o2]<go`[C=00So`[C=00Oo0000ol:dcOo2]<go
`[C=o`000?nn^mOo000002Oooooo00?o0000ooooooooool07oooool001Cooooo0_l0000?ooooo`04
o`000?o4Vjkoa9^^o`0000goa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@08olBM
/@03o`000?o4Vjkoa9^^00Koa9^^00?o0000olBM/Oo4WK401_l000000omN003o0000o`000002oh80
00Go00001?mN0002o`0000OoPP002?l00005oiOAo0?o00001onGdO`00ol0003o[<_`ojc;l00;ojc;
l0?o00003on/bo000ol0003o^<?SokS3h`06okS3h`?o00001On/c?000ol0003o^<?SokS3h`0>okS3
h`03o`000?nn^mOo_[_G00;o_[_G00?o0000okS3honh`n<02Onh`n<00ol0003o_[_Gokjke`0;okjk
e`;o000000?o^<?So`000?nn^mL04?nn^mL00ol0003o`[C=ol:dc@02o`0000co_[_G00?o0000ol:d
cOo2]<d02?o2]<d3o`0000?o_[_G00?o0000ooooooooool09?ooool2o`00023ooooo000Dooooo`03
o`000?oooooooooo00oooooo0_l0000?olBM/@05o`000?o4Vjkoa9^^olBK[_l000003?o4WK400ol0
003oa9^^olBK[P05olBK[P03o`000?o4WK7oa9fa00Goa9fa1ol00006oeh000_o00002?m^cOh00ol0
003oUm7lo`000002o`0000_oUm7l00?o0000ojc;l?n/bo001On/bo05o`0000?oUm7l00?o0000ojc;
l?n/bo003On/bo000ol0003o^<?SokS3h`03okS3h`;o00002On/c?000ol0003o^<?SokS3h`0>okS3
h`04o`000?nn^mOo0000o`0000go^<?S00?o0000okjkeonn^mL02?nn^mL2o`0000Co^<?S00?o0000
okjkeonn^mL03_nn^mL00ol0003o`[C=o`00000>okjke`03o`000?o2]<go`[C=00Oo`[C=0ol00004
okjke`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool001Cooooo00?o0000oooo
ooooool03oooool00ol0003oa9faolBM/@0>olBM/@05o`000?o4Vjkoa9^^olBK[_l000003?o4WK40
0ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_o4Vjkoa9^^2?l0
0007obZ_hP;o00002Om^cOh4o`0000koUm7l00?o0000ojc;l?n/bo001?l00009oiOAo003o`000?n/
bo3o[<_`00go[<_`00?o0000okS3hol000000_l0000<ojc<l003o`000?nh`n?o^<?S00go^<?S0_l0
000?okS3h`03o`000?nn^mOo_[_G00Ko_[_G0_l00007okS3h`03o`000?nn^mOo_[_G00go_[_G0_l0
000@okjke`03o`000?o2]<go`[C=00Go`[C=00Co0000okjkeonn^mOo00001Onn^mL00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo000Dooooo`03o`000?oooooooooo00oooooo00?o
0000olBM/Oo4WK403_o4WK401?l0003oa9^^olBK[_l0000=olBM/@03o`000?o4Vjkoa9^^00?oa9^^
00?o0000olBM/Oo4WK402?o4WK400ol0003oa9^^olBK[P06olBK[PCo00002?lZ[n82o`0000CoK/gn
0ol00004ofk=oP;o00002_nGdO`5o`0000koUm7l00?o0000ojc;l?n/bo003?n/bo02o`00013o[<c`
00?o0000okS3honh`n<02Onh`n<3o`000003ojc<l?l0003o^<?S00oo^<?S00?o0000okjkeonn^mL0
1?nn^mL00ol0003o^<?SokS3h`07okS3h`03o`000?nn^mOo_[_G00_o_[_G0_l000000onh`n?o0000
okjke`0?okjke`03o`000?o2]<go`[C=00?o`[C=0_l00004okjke`03o`000?nn^mOo_[_G00;o_[_G
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`005?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?o4WK7oa9fa00koa9fa0_l0000?olBM/@05o`000?o4Vjkoa9^^olBK[_l00000
3?o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00;oa9fa2?l00002obZ_hPCo0000
2Om^cOh01?l0003oUm7loiOAo?nGdO`6o`0000GoKLgn00?o0000oiOAo?nGdO`03?nGdO`00ol0003o
[<_`ojc;l008ojc;l0?o00000_nFd_`00ol0003o[<c`ojc<l00=ojc<l003o`000?nh`n?o^<?S00Ko
^<?S0ol00005ojc<l003o`000?nh`n?o^<?S00go^<?S00?o0000okjkeonn^mL00_nn^mL2o`0000_o
^<?S00?o0000okjkeonn^mL02?nn^mL2o`0000Co^<?S00?o0000okjkeonn^mL03_nn^mL00ol0003o
`[C=ol:dc@02o`0000Oo_[_G00?o0000okjkeonn^mL00_nn^mL00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01_ooooo000Dooooo`;o00004Oooool00ol0003oa9faolBM/@0>olBM/@03o`00
0?o4WK7oa9fa00koa9fa00Go0000olBK[_o4Vjkoa9^^o`00000<olBM/@03o`000?o4Vjkoa9^^00?o
a9^^00?o0000olBM/Oo4WK401oo4WK401?l0003oa9^^olBK[_o4VjhCo`0000coKLgn00?o0000oiOA
o?nGdO`03?nGdO`00ol0003o[<_`ojc;l004ojc;l0?o00001_nFd_`00ol0003o[<c`ojc<l00=ojc<
l003o`000?nh`n?o^<?S00?o^<?S0_l00009ojc<l003o`000?nh`n?o^<?S00go^<?S00Co0000okjk
eol0003o00003Onh`n<00ol0003o_[_Gokjke`06okjke`;o00001_nh`n<00ol0003o_[_Gokjke`0>
okjke`03o`000?o2]<go000000[o_[_G00?o0000okjkeonn^mL00_nn^mL00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`;o00004_ooool00ol0003oa9faolBM/@0>olBM
/@03o`000?o4WK7oa9fa00koa9fa00Co0000olBK[_o4Vjko00003Oo4WK400ol0003oa9^^olBK[P03
olBK[P03o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_l0003o00001Oo4Vjh00ol0003oa9fao`00
0003o`0000Oo:JkQ0_l0000<ofg=oP;o00003OnGdO`00ol0003o[<_`ojc;l003o`0000[oU];l00?o
0000ojc<l?n/c?003On/c?000ol0003o^<?So`000002o`0000_o[<c`00?o0000okS3honh`n<03Onh
`n<2o`00013o^<?S00?o0000okjkeonn^mL01?nn^mL00ol0003o^<?SokS3h`07okS3h`03o`000?nn
^mOo_[_G00go_[_G0_l0000;okjke`03o`000?nn^mOo_[_G00;o_[_G00?o0000ooooooooool09Ooo
ool2o`0001cooooo000Cooooo`03o`000?oooooooooo01;ooooo00?o0000olBM/Oo4WK403?o4WK40
0ol0003o`j2do`00000@olBM/@;o00003oo4WK401Ol0003oa9^^olBK[_o4Vjko000000Woa9fa0ol0
0006olBK[P03o`000?o4WK7oa9fa00Coa9fa1Ol00004obV^h@;o00003?m]cOh00ol0003oUm7loiOA
o008oiOAo0Go00003_nFd_`00ol0003o[<c`ojc<l00;ojc<l0?o00003on/c?000ol0003o^<?SokS3
h`09okS3h`?o000000?o[<c`o`000?nh`n<04?nh`n<01?l0003o_[_Gokjkeonn^mL2o`0000[o^<?S
00?o0000okjkeonn^mL02onn^mL2o`000003okS4hol0003o_[_G00_o_[_G00?o0000okjkeonn^mL0
0_nn^mL00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo000Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000olBM/Oo4WK402oo4WK401?l0003o`j2dol>P]?l0000@olBM/@03o`00
0?o4WK7oa9fa00koa9fa00Co0000olBK[_o4Vjko00001oo4WK43o`0000;oa9fa00?o0000olBK[_o4
Vjh00oo4Vjh00ol0003oa9faolBM/@07olBM/@03o`000?o4Vjkoa9^^00So00002om]cOh01?l0003o
Um7loiOAo?nGdO`6o`0000GoK<gm00?o0000oiKBo?nFd_`03?nFd_`00ol0003o[<c`ojc<l005ojc<
l0Go00000onFd_`00ol0003o[<c`ojc<l00=ojc<l003o`000?nh`n?o^<?S00Go^<?S0ol00005ojc<
l003o`000?nh`n?o^<?S00ko^<?S00Co0000okjkeol0003o00003Onh`n<00ol0003o_[_Gokjke`08
okjke`;o00001?nha><00ol0003o_[_Gokjke`0:okjke`05o`000?nn^mOo_[_Gokjkeol00000:?oo
ool00ol0003oooooooooo`0Iooooo`004oooool00ol0003oooooooooo`0Booooo`03o`000?o4WK7o
a9fa00[oa9fa00Go0000ol>P]?o3X;Co`j2do`00000@olBM/@03o`000?o4WK7oa9fa00koa9fa00Co
0000olBK[_o4Vjko00001?o4WK43o`0000Goa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9fa
olBM/@07olBM/@03o`000?o4Vjkoa9^^00Koa9^^4Ol0000<ofc=o@;o00003OnFd_`00ol0003o[<c`
ojc<l004o`0000WoU];l00?o0000ojc<l?n/c?003?n/c?000ol0003o^<?SokS3h`03okS3h`;o0000
2On/c?000ol0003o^<?SokS3h`0=okS3h`;o00004?nh`n<00ol0003o_[_Gokjke`05okjke`;o0000
1onha><00ol0003o_[_Gokjke`0:okjke`03o`000?nn^mOo_[_G00;o0000:?ooool00ol0003ooooo
ooooo`0Hooooo`004oooool3o`0001?ooooo00?o0000olBM/Oo4WK402?o4WK400ol0003o`j2dol>P
]003ol>P]003o`000?o4WK7oa9fa00coa9fa00?o0000ol>P]?l000004?o4WK42o`0000;oa9fa0ol0
0009olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`00
0?o4WK7oa9fa00Goa9fa1_l00003obN^h0?o00003?m/cOd00ol0003oU];loiKBo008oiKBo0Go0000
3_nFd_`00ol0003o[<c`ojc<l00<ojc<l003o`000?nh`n?o000000;o00003?n/c?000ol0003o^<?S
okS3h`09okS3h`?o000000?o[<c`o`000?nh`n<03onh`n<00ol0003o_[_Gokjke`04okjke`03o`00
0?nha>?o^<CS00Oo^<CS00?o0000okjkeonn^mL02_nn^mL3o`000003okS4hol0003ooooo02Oooooo
00?o0000ooooooooool06?ooool001?ooooo00?o0000ooooooooool04oooool00ol0003oa9faolBM
/@07olBM/@03o`000?o3X;Co`j2d00Co`j2d00?o0000olBM/Oo4WK402oo4WK401?l0003o`j2dol>P
]?l0000@olBM/@Co00003?o4WK401?l0003oa9^^olBK[_l0000<olBM/@03o`000?o4Vjkoa9^^00?o
a9^^00?o0000olBM/Oo4WK401oo4WK400ol0003oa9^^olBK[P02olBK[PSo00002om/cOd01?l0003o
U];loiKBo?nFd_`6o`0000GoK<gm00?o0000oiKBo?nFd_`03?nFd_`00ol0003o[<c`ojc<l00:ojc<
l0Co00003_n/c?000ol0003o^<?SokS3h`06okS3h`?o00001On/c?000ol0003o^<?SokS3h`0>okS3
h`04o`000?nn^mOo_[_Gokjke`;o00002onha><00ol0003o_[_Gokjke`08okjke`?o00000onha><0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo0008ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Cooooo`03o`000?o4WK7oa9fa00Koa9fa00?o0000
ol>P]?o3X;@01Oo3X;@00ol0003oa9faolBM/@0:olBM/@05o`000?o3X;Co`j2dol>P]?l000003_o4
WK43o`0000ooa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`00
0?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh01_o4Vjh00ol0003oa9fao`00000@o`0000coK<gm
0_l0000=oiKBo003o`000?n/c?3o[<c`00Go[<c`1?l00004oiKBo003o`000?n/c?3o[<c`00co[<c`
00?o0000okS3honh`n<00onh`n<2o`0000Wo[<c`00?o0000okS3honh`n<03Onh`n<01?l0003o_[_G
o`000?l0000=okS4h`03o`000?nn^mOo_[_G00Ko_[_G0_l00003okS4h`03o`000?nha>?o^<CS00?o
00009oooool00ol0003oooooooooo`0Fooooo`002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool05Oooool00ol0003oa9faolBM/@05olBM/@03o`000?o3X;Co`j2d00Ko
`j2d00?o0000olBM/Oo4WK402?o4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4WK7oa9fa00So
a9fa0ol000001?o4WK7o0000ol>P]?l0000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko
000000_oa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@05olBM/@?o00002?lV[Ml3
o`0000coK<gm00?o0000oiKBo?nFd_`02onFd_`00ol0003o[<c`ojc<l004o`0000WoU];l00?o0000
ojc<l?n/c?003?n/c?000ol0003o^<?So`000002o`0000co[<c`00?o0000okS3honh`n<02onh`n<3
o`00013o^<CS00?o0000okjkeonn^mL01?nn^mL00ol0003o^<CSokS4h`04okS4h`06o`000?nha>?o
^<CSo`000?n[>S3o00009Oooool2o`0000Wooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool000Sooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01Go
oooo00?o0000olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]007ol>P]003o`000?o4WK7oa9fa00So
a9fa00?o0000ol>P]?o3X;@00oo3X;@00ol0003oa9faolBM/@06olBM/@;o00000oo4WK401?l0003o
`j2dol>P]?l0000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000olBK[_o4Vjko00003?o4WK40
0ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000olBK[_l000001ol00003
obJ]g`;o00002om/cOd00ol0003oU];loiKBo005oiKBo0So00003_nFd_`00ol0003o[<c`ojc<l00:
ojc<l0?o00003on/c?000ol0003o^<?SokS3h`08okS3h`?o00000_n/c?400ol0003o^<CSokS4h`0?
okS4h`04o`000?nn^mOo_[_Gokjke`;o00001onha><01?l0003o^<CSokS4hol00002oj/j<003o`00
0?oooooooooo00Wooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool000Sooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00005_ooool00ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d
00So`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00?oa9fa0ol00004olBM/@05o`000?o3X;Co`j2dol>P]?l000003oo4WK400ol0003oa9faolBM/@0=
olBM/@04o`000?o4Vjkoa9^^o`0000coa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM
/@07olBM/@03o`000?o4Vjkoa9^^00Koa9^^6Ol00008of_=o@03o`000?nFd_coU];l00coU];l00?o
0000ojc<l?n/c?001On/c?04o`0000?oU];m00?o0000ojc<l?n/c?003On/c?000ol0003o^<?SokS3
h`04okS3h`?o00001_n/c?400ol0003o^<CSokS4h`0>okS4h`04o`000?nn^mOo0000o`0000[o^<CS
00Co0000okS4honha>?o00000_n[>S02o`0000Wooooo00?o0000oj/j<?l000006Oooool00ol0003o
ooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05_ooool01Ol0
003oa9faolBM/Oo4WK7o000000co`j2d00?o0000olBM/Oo4WK401Oo4WK400ol0003o`j2dol>P]006
ol>P]003o`000?o4WK7o000000;o00001_o4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4WK7o
a9fa00_oa9fa00?o0000ol>P]?l000003oo4WK42o`0000koa9fa00Go0000olBK[_o4Vjkoa9^^o`00
000;olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401_o4WK44o`0000So9JcO0_l0
000<of_=o@03o`000?nFd_coU];l00coU];l00?o0000ojc<l?n/c?001?l00008oiKBo@03o`000?n/
c?3o[<c`00go[<c`00?o0000okS3honh`n<00ol0000:ojc<l@03o`000?nha>?o^<CS00go^<CS0_l0
000=okS4h`03o`000?nha>?o000000CoZcX`00?o0000ooooooooool01Oooool01Ol0003oZcX`oj/j
<?n[>S3o000001Sooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000000_ooool000Sooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo01Kooooo00Co0000olBM/Oo4WK7o00003Oo3X;@00ol0003oa9faolBM/@04olBM
/@03o`000?o3X;Co`j2d00Ko`j2d0ol00009olBM/@03o`000?o3X;Co`j2d00?o`j2d00?o0000olBM
/Oo4WK402_o4WK401?l0003o`j2dol>P]?l0000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Go0000
olBK[_o4Vjkoa9^^o`00000;olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401_o4
WK401?l0003oa9^^olBK[_o4Vjh5o`0000Go9JcO00?o0000of_=oOm[cOd02_m[cOd00ol0003oU];l
oiKBo009oiKBo0Go00003OnFd_d00ol0003o[<c`ojc<l00<ojc<l0?o00003_n/c?400ol0003o^<CS
okS4h`09okS4h`?o000000?o[<cao`000?nha><03?nha><01?l0003o^<CSokS4hol00004oj/j<003
o`000?oooooooooo00Cooooo00?o0000oj/j<?n[>S000_n[>S02o`0000Wooooo0_l0000<ooooo`03
o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Foooo
o`03o`000?o4WK7o000000ko`j2d00?o0000olBM/Oo4WK400oo4WK400ol0003o`j2dol>P]004ol>P
]0?o000000?o`j2do`000?o4WK402?o4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000
olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBK[_o4Vjh01_o4Vjh8o`0000_oJlgm00Co0000oiKBo?nFd_coU];l1ol00005of[=o@03o`00
0?nFd_goU];m00_oU];m00?o0000ojc<l?n/c?002?n/c?03o`000003oiGBoOl0003o[<ca00ko[<ca
00?o0000okS4honha><01_nha><3o`0000Go[<ca00?o0000okS4honha><02onha><00ol0003o^<CS
o`000005oj/j<0;o00000oooool00ol0003oZcX`oj/j<005oj/j<003o`000?oooooooooo00Kooooo
00?o0000oj/j<?l000002_ooool3o`0000Wooooo00Go0000oooooooooooooooooa0@4003ooooo`7o
410@0Oooool1ooooo`002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000oooooooo
ool06?ooool00ol0003o`j2dol>P]00>ol>P]003o`000?o4WK7oa9fa00;oa9fa00Co0000ol>P]?o3
X;Co`j2d0ol00005ol>P]003o`000?o4WK7oa9fa00Goa9fa00?o0000ol>P]?o3X;@01_o3X;@00ol0
003oa9faolBM/@08olBM/@03o`000?o3X;Co`j2d00;o`j2d00?o0000olBM/Oo4WK402oo4WK400ol0
003o`j2do`00000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko000000_oa9fa00?o0000
olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@04olBM/A7o00003OmZcOd00ol0003oU];moiKBo@0;
oiKBo@03o`000?n/c?3o[<c`00Co[<c`0ol00005oiGBo@03o`000?n/c?7o[<ca00go[<ca00?o0000
okS4honha><00onha><2o`0000Wo[<ca00?o0000okS4honha><02onha><3o`0000KoZcX`00Co0000
oooooooooooo00002?n[>S000ol0003oooooooooo`04ooooo`;o00000_n[>S000ol0003ooooooooo
o`04ooooo`Co000000?oooooo`000?ooool01?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`004Oooool2o`0001Wooooo00?o0000ol>P]?o3X;@0
3_o3X;@01_l0003oa9faolBM/Oo4WK7o0000ol>P]0?o00002?o3X;@00ol0003oa9faolBM/@04olBM
/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]003ol>P
]003o`000?o4WK7oa9fa00[oa9fa00Co0000ol>P]?o3X;Co00003oo4WK400ol0003oa9faolBM/@0=
olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4
WK7oa9fa00Koa9fa00Co0000olBK[_o4Vjkoa9^^1_l00004obB/gP?o00003?mZcOd00ol0003oU];m
oiKBo@0;oiKBo@03o`000?n/c?3o[<c`00?o00002OnEd_d00ol0003o[<caojc<l@0=ojc<l@03o`00
0?nha>?o000000;o00002on/c?400ol0003o^<CSokS4h`09okS4h`Go00001on[>S03o`0000WoZcX`
00?o0000ooooooooool00oooool00ol0003oZcX`oj/j<002oj/j<0;o000000Coooooo`000?l0003o
00001Oooool2o`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00_ooool0017ooooo00?o0000ooooooooool06Oooool00ol0003o`j2dol>P]00=ol>P
]003o`000?o4WK7oa9fa00?o00002oo3X;@00ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d
00So`j2d00?o0000olBM/Oo4WK401_o4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000
olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBK[_o4Vjh01_o4Vjh:o`0000_oJ/gm00?o0000oiKBoOnFd_d01OnFd_d8o`0000goUM;m00?o
0000ojc<lOn/c?402on/c?43o`0000oo[<ca00?o0000okS4honha><01Onha><3o`0000?o[<ca00?o
0000ojc<lOl000001on[>S02o`0000[oZcX`0_l00002ooooo`;o00001_n[>S000ol0003ooooooooo
o`06ooooo`;o00004oooool0017ooooo00?o0000ooooooooool06Oooool00ol0003o`j2dol>P]00=
ol>P]0?o00003oo3X;@00ol0003oa9faolBM/@02olBM/@03o`000?o3X;Co`j2d00Wo`j2d00?o0000
olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]006ol>P]003o`000?o4WK7oa9fa00Soa9fa00?o0000
ol>P]?o3X;@00_o3X;@00ol0003oa9faolBM/@0;olBM/@03o`000?o3X;Co000000ooa9fa0_l0000>
olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4
WK7oa9fa00Goa9fa5_l00008ofW<o@03o`000?nEd_goUM;m00_oUM;m00?o0000ojc<lOn/c?401On/
c?45o`0000?oUM;m00?o0000ojc<lOn/c?403?n/c?400ol0003o^<CSokS4h`03okS4h`;o00001on/
c?400ol0003o[<cao`000006oj/j<003o`000?nT;1ko000000_oZcX`00Co0000ooooool0003o0000
1on[>S000ol0003oooooooooo`05ooooo`;o00004oooool0017ooooo00?o0000ooooooooool06Ooo
ool00ol0003o`j2dol>P]00;ol>P]0;o000000?o`j2do`000?o3X;@03oo3X;@01Ol0003oa9faolBM
/Oo4WK7o000000co`j2d00?o0000olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]006ol>P]003o`00
0?o4WK7oa9fa00Ooa9fa00?o0000ol>P]?o3X;@00oo3X;@00ol0003oa9faolBM/@0:olBM/@04o`00
0?o3X;Co`j2do`0000ooa9fa00?o0000olBM/Oo4WK403Oo4WK401Ol0003oa9^^olBK[_o4Vjko0000
00_oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@06olBM/@03o`000?o4Vjkoa9^^
00?oa9^^0ol00008ob>[g@;o00003?mYc?d2o`0000coUM;m00?o0000ojc<lOn/c?401?l00009oiGB
o@03o`000?n/c?7o[<ca00co[<ca00?o0000okS4hol000000_l0000:ojc<l@;o00001On[>S001?l0
003oY2`Noj@/7_nT;1h2o`0000[oZcX`0_l00009oj/j<003o`000?oooooooooo00?ooooo0ol0000C
ooooo`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?o3X;Co`j2d00Oo`j2d0ol00003ol>P
]003o`000?o3X;Co`j2d00ko`j2d00Co0000olBM/Oo4WK7o00003Oo3X;@00ol0003oa9faolBM/@03
olBM/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401_o4WK400ol0003o`j2dol>P]004
ol>P]003o`000?o4WK7oa9fa00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4
WK7oa9fa00goa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`00
0?o4WK7oa9fa00Koa9fa00?o0000olBK[_o4Vjh01_o4Vjh7o`0000?o8j_M0_l0000<ofW<o@03o`00
0?nEd_goUM;m00CoUM;m2?l0000>oiGBo@03o`000?n/c?7o[<ca00[o[<ca0ol0000>ojc<l@;o0000
1?n[>S000ol0003oY2`Noj@/7P03oj@/7P03o`000?n[>S3oZcX`00SoZcX`0_l00009oj/j<0;o0000
0oooool00ol0003oooooo`00000Cooooo`004?ooool3o`0001_ooooo00?o0000ol>P]?o3X;@01?o3
X;@3o`0000Go`j2d00?o0000ol>S^?l000004?o3X;@2o`0000oo`j2d00Go0000olBM/Oo4WK7oa9fa
o`00000;ol>P]003o`000?o4WK7oa9fa00Coa9fa00?o0000ol>P]?o3X;@01_o3X;@00ol0003oa9fa
olBM/@07olBM/@03o`000?o3X;Co`j2d00?o`j2d00?o0000olBM/Oo4WK402oo4WK400ol0003oa:2d
o`00000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko000000[oa9fa00?o0000olBK[_o4
Vjh01?o4Vjh00ol0003oa9faolBM/@05olBM/ASo00002?mYc?d00ol0003oUM;moiGBo@0<oiGBo@03
o`000?n/c?7o[<ca00Go[<ca1?l00002oiCBo@03o`000?n/c?7o[<ca00co[<ca00?o0000ojc<lOl0
00000_n[>S000ol0003oY2`Noj@/7P05oj@/7P;o00002?n[>S000ol0003oY2`Oo`00000:oj/j<006
o`000?oooooo0000o`000?oooooo00004oooool0013ooooo00?o0000ooooooooool07?ooool00ol0
003o`j2dol>P]003o`0000Oo`j2d00Co0000ol>S^?o3XkSo00004?o3X;@00ol0003o`j2dol>P]00>
ol>P]005o`000?o4WK7oa9faolBM/Ol000002oo3X;@00ol0003oa9faolBM/@04olBM/@03o`000?o3
X;Co`j2d00Ko`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4
WK7oa9fa00[oa9fa00Co0000olBP]?o4X;Co00003oo4WK400ol0003oa9faolBM/@0=olBM/@04o`00
0?o4Vjkoa9^^o`0000_oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@07olBM/@03
o`000?o4Vjkoa9^^00;oa9^^1Ol00009ob:[g003o`000?mYc?goJLcm00[oJLcm00?o0000oiGBoOnE
d_d03?nEd_d00ol0003o[<caojc<l@04o`0000OoU=;m00?o0000ojc<lOn/c?403?n/c?43o`000003
oj/j<?l0003oY2`N00SoY2`N00?o0000oj/j<?n[>S001?n[>S001?l0003oY2`Ooj@/7onT;1l2o`00
00WoZcX`0ol000000ooooooo0000ooooo`0Booooo`004?ooool00ol0003oooooooooo`0Looooo`?o
00002Oo3X;@00ol0003o`j>hol>S^002ol>S^003o`000?o3X;Co`j2d00go`j2d00?o0000ol>P]?o3
X;@03_o3X;@01?l0003oa9faolBM/Ol0000<ol>P]003o`000?o4WK7oa9fa00?oa9fa00?o0000ol>P
]?o3X;@01oo3X;@00ol0003oa9faolBM/@06olBM/@03o`000?o3X;Co`j2d00Co`j2d00?o0000olBM
/Oo4WK402Oo4WK401Ol0003oa:2dolBP]?o4X;Co000000ooa9fa00?o0000olBM/Oo4WK403Oo4WK40
1?l0003oa9^^olBK[_l0000;olBM/@03o`000?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK401oo4
WK400ol0003oa9^^olBK[P05olBK[PKo00001_lRZm`00ol0003oJLcmofW<o@0:ofW<o@03o`000?nE
d_goUM;m00WoUM;m1Ol0000<oiCBo@03o`000?n/c?7o[<ca00co[<ca1?l0000:oj@/7P03o`000?n[
>S3oZcX`00?oZcX`00?o0000oj@/7onT;1l00onT;1l00ol0003oZcX`oj/j<007oj/j<004o`000?oo
ooooooooo`0001?ooooo000@ooooo`03o`000?oooooooooo01Wooooo0ol000000ooooooo0000ol>P
]008ol>P]003o`000?o3XkSo`j>h00?o`j>h00?o0000ol>P]?o3X;@03?o3X;@00ol0003o`j>ho`00
000@ol>P]0;o00003_o3X;@01Ol0003oa9faolBM/Oo4WK7o000000_o`j2d00?o0000olBM/Oo4WK40
1?o4WK400ol0003o`j2dol>P]006ol>P]003o`000?o4WK7oa9fa00Ooa9fa00?o0000olBP]?o4X;@0
0oo4X;@00ol0003oa9faolBM/@0;olBM/@03o`000?o4X;Co000000ooa9fa0_l0000=olBM/@05o`00
0?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Co
a9fa1_l000000olRZmco0000ofW<o@0;ofW<o@04o`000?nEd_goUM;moiGBo@Oo00001?mXc?d00ol0
003oU=;moiCBo@0;oiCBo@03o`000?n/c?7o[<ca00_o[<ca0ol000000onI60Ko0000o`000009oj@/
7P;o00000_n[>S000ol0003oY2`Ooj@/7`05oj@/7`;o00001on[>S001?l0003oooooooooool0000C
ooooo`004?ooool00ol0003oooooooooo`0Fooooo`?o00001?ooool00ol0003o`j2dol>P]006ol>P
]003o`000?o3XkSo`j>h00Co`j>h00?o0000ol>P]?o3X;@02oo3X;@01?l0003o`j>hol>S^?l0000@
ol>P]003o`000?o3X;Co`j2d00go`j2d00Go0000olBM/Oo4WK7oa9fao`00000;ol>P]003o`000?o4
WK7oa9fa00?oa9fa00?o0000ol>P]?o3X;@01oo3X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4
X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402_o4WK401?l0003oa:2dolBP]?l0000?olBM/@03o`00
0?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03
o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_o4Vjkoa9^^4_l0000<ofS<o@03o`000?nDd_goU=;m
00_oU=;m00?o0000ojc<lOn/c?401On/c?45o`000003oiCBoOl0003o000000?oVAP60_l00009oj@/
7P03o`000?n[>S3o000000WoY2`O00?o0000oj/j<?n[>S000on[>S000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo000@ooooo`;o00005?ooool3o`0000Oooooo00?o0000ol>P]?o3
X;@01Oo3X;@00ol0003o`j>hol>S^006ol>S^003o`000?o3X;Co`j2d00Wo`j2d00Go0000ol>S^?o3
XkSo`j>ho`00000@ol>P]003o`000?o3X;Co`j2d00go`j2d00Co0000olBM/Oo4WK7o00003?o3X;@0
0ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401_o4WK40
0ol0003oa:2dolBP]004olBP]003o`000?o4WK7oa9fa00Woa9fa00Go0000olBP]?o4X;Coa:2do`00
000?olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^
olBK[P02olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh01Oo4Vjh00ol0003oa9fa
o`000005o`0000Go8J[L0_l0000<ofS<o@03o`000?nDd_goU=;m00_oU=;m00?o0000ojc<lOn/c?40
1?l00007oiCBo@;o00001?nI60H2o`0000SoY2`N0_l0000:oj@/7`03o`000?n[>S3oZcX`00;oZcX`
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`003oooool00ol0003ooooooooo
o`0Booooo`;o00002oooool00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Ko`j>h00?o
0000ol>P]?o3X;@02?o3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co`j2d00co`j2d00?o
0000ol>S^?l000003oo3X;@2o`0000ko`j2d00Go0000olBM/Oo4WK7oa9fao`00000;ol>P]003o`00
0?o4WK7oa9fa00Coa9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@07olBM/@03o`00
0?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402oo4WK42o`0000ooa9fa0_l0000=olBM/@05o`00
0?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Go
a9fa1ol000000olQZ]co0000ofS<o@0;ofS<o@03o`000?nDd_goU=;m00GoU=;m2?l0000<oiCBo@;o
00001OnI60H00ol0003oY2`Noj@/7P05oj@/7P04o`000?nI60Ko0000o`0000WoY2`O0_l00002oj/j
<003o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000oooooooo
ool03oooool3o`0000gooooo00?o0000ol>P]?o3X;@00oo3X;@00ol0003o`j>hol>S^008ol>S^003
o`000?o3X;Co`j2d00Ko`j2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003o`j2dol>P]00;ol>P]004
o`000?o3XkSo`j>ho`0000oo`j2d00?o0000ol>P]?o3X;@03Oo3X;@01?l0003oa9faolBM/Ol0000<
ol>P]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@07
olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402_o4WK401?l0003oa:2dolBP]?l0
000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^
olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh00oo4VjhFo`0000SoIlcl
00?o0000oiCBoOnDd_d02OnDd_d00ol0003oU=;mo`000005oiTH1P;o00001?nT;1h00ol0003oVAP6
oiTH1P02oiTH1P;o00002OnT;1l2o`0000Gooooo00?o0000ooooooooool04?ooool000oooooo00?o
0000ooooooooool03?ooool3o`00017ooooo00Go0000ol>P]?o3X;Co`j2do`00000;ol>S^003o`00
0?o3X;Co`j2d00Go`j2d00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`j2dol>P]00:ol>P]005o`00
0?o3XkSo`j>hol>S^?l000003oo3X;@00ol0003o`j2dol>P]00=ol>P]003o`000?o4WK7o000000go
`j2d00?o0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]007olBP]003o`000?o4WK7oa9fa00Ko
a9fa00?o0000olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@09olBM/@05o`000?o4X;Coa:2dolBP
]?l000003_o4WK400ol0003oa9faolBM/@0<olBM/@04o`000?o4Vjkoa9^^o`0000coa9fa00?o0000
olBK[_o4Vjh00_o4Vjh00ol0003oa9faolBM/@07olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000
olBM/Oo4WK400_o4WK45o`0000Ko8:WK0_l0000<ofO<o003o`000?nDd_goU=;m00WoU=;m00?o0000
oiCBoOl000001_nI60H2o`000003oj@/7_l0003oVAP600KoVAP60_l00008oj@/7`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000ooooooooool02Oooool3o`00
01Cooooo00Co0000ol>P]?o3X;Co00003Oo3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo
`j>h00Ko`j>h00?o0000ol>P]?o3X;@02?o3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co
`j2d00_o`j2d00?o0000ol>S^?l000003oo3X;@00ol0003o`j2dol>P]00=ol>P]005o`000?o4WK7o
a9faolBM/Ol000002oo4X;@00ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Koa:2d00?o
0000olBM/Oo4WK401oo4WK400ol0003oa:2dolBP]002olBP]003o`000?o4WK7oa9fa00_oa9fa00?o
0000olBP]?l000003_o4WK42o`0000goa9fa00Go0000olBK[_o4Vjkoa9^^o`00000:olBM/@03o`00
0?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^o`000006o`000003ob2Y
fol0003oIlcl00_oIlcl00?o0000oiCBoOnDd_d01OnDd_d8o`0000GoVAP60ol00009oiTH1P03o`00
0?nT;1ooY2`O00GoY2`O00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`003ooo
ool3o`0000Kooooo0ol0000Gooooo`03o`000?o3X;Co000000ko`j>h00?o0000ol>P]?o3X;@00oo3
X;@00ol0003o`j>hol>S^007ol>S^003o`000?o3X;Co`j2d00Oo`j2d00?o0000ol>S^?o3XkP01?o3
XkP00ol0003o`j2dol>P]00:ol>P]004o`000?o3XkSo`j>ho`0000oo`j2d00?o0000ol>P]?o3X;@0
3Oo3X;@01?l0003oa9faolBM/Ol0000<olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4
X;@01oo4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4
WK402Oo4WK401?l0003oa:2dolBP]?l0000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK
[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000
olBK[_o4Vjh01_o4VjhFo`0000GoIlcl00Co0000ofO<o?mWc?co00000onI60H01?l0003oQ`00ohL0
0?n70002o`0000SoVAP60_l00004oj@/7`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4?ooool000oooooo00?o0000ooooooooool00oooool3o`0001_ooooo00?o0000ol>S^?o3XkP03Oo3
XkP00ol0003o`j2dol>P]002ol>P]003o`000?o3XkSo`j>h00Wo`j>h00?o0000ol>P]?o3X;@01Oo3
X;@00ol0003o`j>hol>S^005ol>S^003o`000?o3X;Co`j2d00Wo`j2d00Go0000ol>S^?o3XkSo`j>h
o`00000>ol>P]003o`000?o3XkSo000000ko`j2d00?o0000olBM/Ol000003Oo4X;@00ol0003oa9fa
olBM/@03olBM/@03o`000?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401_o4WK400ol0003oa:2d
olBP]004olBP]003o`000?o4WK7oa9fa00Soa9fa00Go0000olBP]?o4X;Coa:2do`00000>olBM/@03
o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00003?o4WK401Ol0003oa9^^olBK[_o4Vjko
000000[oa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@04olBM/@Go00001_lOZ=X2
o`0000SoIlcl00Oo0000ofO<o?mWc?coIlclo`000?nI60Ko000000KoQ`000_l00008oiTH1P;o0000
00?oY2`Oo`000?ooool01oooool00ol0003oooooooooo`0?ooooo`001Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Cooooo00Co0000oooooooooooooooo0ol0000Nooooo`03o`000?o3XkSo`j>h00ko
`j>h00Co0000ol>P]?o3X;Co00003?o3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h
00Oo`j>h00?o0000ol>P]?o3X;@01oo3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co`j2d
00[o`j2d00Co0000ol>S^?o3XkSo00003oo3X;@00ol0003oa:2dolBP]00=olBP]005o`000?o4WK7o
a9faolBM/Ol000002oo4X;@00ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o
0000olBM/Oo4WK401oo4WK400ol0003oa:2dolBP]003olBP]003o`000?o4WK7oa9fa00[oa9fa00?o
0000olBP]?l000003_o4WK42o`0000goa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^
olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00Co0000olBK[_o4Vjkoa9^^1ol000000olOZ=[o
0000ofO<o007ofO<o004o`000?mWc?coIlclofO<o0;o00002?n70003o`0000OoVAP600?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`002?ooool00omgMgOo<S8booooo`03ooooo`Co
00008_ooool00ol0003o`j>hol>S^00=ol>S^003o`000?o3X;Co000000go`j>h00?o0000ol>P]?o3
X;@00oo3X;@00ol0003o`j>hol>S^008ol>S^003o`000?o3X;Co`j2d00Ko`j2d00?o0000ol>S^?o3
XkP01?o3XkP00ol0003o`j2dol>P]009ol>P]005o`000?o3XkSo`j>hol>S^?l000003oo3X;@00ol0
003oa:2dolBP]00=olBP]004o`000?o4WK7oa9fao`0000coa:2d00?o0000olBM/Oo4WK400oo4WK40
0ol0003oa:2dolBP]007olBP]003o`000?o4WK7oa9fa00Koa9fa00?o0000olBP]?o4X;@00oo4X;@0
0ol0003oa9faolBM/@09olBM/@04o`000?o4X;Coa:2do`0000koa9fa00?o0000olBM/Oo4WK403?o4
WK401?l0003oa9^^olBK[_l0000;olBM/@03o`000?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK40
1_o4WK400ol0003oa9^^olBK[P06olBK[P03o`000?o4WK7o000001;o00002?n70002o`0000CoVAP6
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`;o00009?ooool00ol0003o`j>hol>S^00=ol>S^0;o00003oo3XkP01Ol0003o`j2dol>P
]?o3X;Co000000co`j>h00?o0000ol>P]?o3X;@01?o3X;@00ol0003o`j>hol>S^006ol>S^003o`00
0?o3X;Co`j2d00Oo`j2d00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`j2dol>P]00;ol>P]003o`00
0?o3XkSo000000koa:2d00?o0000olBM/Ol000003Oo4X;@00ol0003oa9faolBM/@03olBM/@03o`00
0?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401Oo4WK400ol0003oa:2dolBP]004olBP]003o`00
0?o4WK7oa9fa00Soa9fa00Go0000olBP]?o4X;Coa:2do`00000>olBM/@03o`000?o4WK7oa9fa00go
a9fa0_l0000=olBM/@05o`000?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK
[P03o`000?o4WK7oa9fa00Coa9fa1_l000000olNZ=Wo0000oajXf@04oajXf@03o`000?mW003o0000
00;o00001on70002o`000003oiTH1_l0003ooooo00[ooooo00?o0000ooooooooool03oooool000So
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?o3XkSo`j>h00_o
`j>h00?o0000ol>V_Ol000003oo3XkP01?l0003o`j2dol>P]?l0000=ol>S^003o`000?o3X;Co`j2d
00Co`j2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`j2dol>P]006ol>P]003o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>P]?o3X;@02_o3X;@01?l0003o`j>hol>S^?l0000?olBP]003o`000?o4X;Co
a:2d00goa:2d00Go0000olBM/Oo4WK7oa9fao`00000:olBP]003o`000?o4WK7oa9fa00Coa9fa00?o
0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00;oa:2d00?o
0000olBM/Oo4WK402_o4WK400ol0003oa:2do`00000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co
0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Goa9fa
00?o0000olBK[_o4Vjh00oo4Vjh7o`000003oajXfOl0003oI`0000;oI`000_l00006ohL000;o0000
3?ooool00ol0003oooooooooo`0?ooooo`001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo
00?o0000ooooooooool08Oooool00ol0003o`j>hol>S^00:ol>S^005o`000?o3Y[go`jJmol>V_Ol0
00003_o3XkP00ol0003o`j2do`00000>ol>S^003o`000?o3X;Co`j2d00?o`j2d00?o0000ol>S^?o3
XkP01oo3XkP00ol0003o`j2dol>P]005ol>P]003o`000?o3XkSo`j>h00Go`j>h00?o0000ol>P]?o3
X;@02Oo3X;@01Ol0003o`j>hol>S^?o3XkSo000000ooa:2d00?o0000olBP]?o4X;@03Oo4X;@01?l0
003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01oo4X;@0
0ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402Oo4WK40
1?l0003oa:2dolBP]?l0000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko0000
2oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000olBK[_o4Vjh0
1Oo4Vjh01?l0003oa9faolBM/Oo4WK45o`0000;oI`000ol000000on7003o0000o`00000>ooooo`03
o`000?oooooooooo00oooooo0005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8?ooool00ol0003o`j>hol>S^009ol>S^003o`000?o3Y[go`jJm00;o`jJm00?o0000ol>S^?o3XkP0
3Oo3XkP00ol0003o`j>hol>S^00>ol>S^005o`000?o3X;Co`j2dol>P]?l000002oo3XkP00ol0003o
`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Ko`j>h00?o0000ol>P]?o3X;@01oo3X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00_oa:2d00?o0000ol>S^?l000003_o4X;@00ol0003o
a9fao`00000=olBP]003o`000?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003o
a9faolBM/@05olBM/@03o`000?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK401Ol0003o
a:2dolBP]?o4X;Co000000goa9fa00?o0000olBP]?l000003_o4WK42o`0000goa9fa00Go0000olBK
[_o4Vjkoa9^^o`000009olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Ol000001Oo4WK40
0ol0003oa9^^o`000005o`000003olBK[_l0003ooooo00gooooo00?o0000ooooooooool03oooool0
00Gooooo00?o0000ooooooooool02oooool2o`00027ooooo00?o0000ol>S^?o3XkP01oo3XkP00ol0
003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00_o`j>h0_l0000@ol>S^004o`000?o3X;Co`j2d
o`0000co`j>h00?o0000ol>P]?o3X;@00oo3X;@00ol0003o`j>hol>S^007ol>S^003o`000?o3X;Co
`j2d00Ko`j2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003oa:2dolBP]00:olBP]004o`000?o3XkSo
`j>ho`0000ooa:2d00?o0000olBP]?o4X;@03?o4X;@01Ol0003oa9faolBM/Oo4WK7o000000_oa:2d
00?o0000olBM/Oo4WK401?o4WK400ol0003oa:2dolBP]005olBP]003o`000?o4WK7oa9fa00Ooa9fa
00?o0000olBP]?o4X;@00_o4X;@00ol0003oa9faolBM/@09olBM/@04o`000?o4X;Coa:2do`0000ko
a9fa00?o0000olBM/Oo4WK403?o4WK401?l0003oa9^^olBK[_l0000:olBM/@03o`000?o4Vjkoa9^^
00?oa9^^00Co0000olBM/Oo4WK7o00001Oo4WK400ol0003oa9^^olBK[P05olBK[P03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool000Gooooo1?l0000<ooooo`03o`000?oooooooooo
01kooooo00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@05ol>V_@03o`000?o3XkSo`j>h
00[o`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j2do`00000>ol>S^005o`000?o3X;Co
`j2dol>P]?l000002oo3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Go`j>h00?o
0000olBP]?o4X;@02Oo4X;@01Ol0003o`j>hol>S^?o3XkSo000000ooa:2d00?o0000olBP]?o4X;@0
3?o4X;@01?l0003oa9faolBM/Ol0000<olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4
X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4
WK402?o4WK401Ol0003oa:2dolBP]?o4X;Co000000koa9fa00?o0000olBM/Oo4WK403?o4WK401?l0
003oa9^^olBK[_l0000:olBM/@03o`000?o4Vjkoa9^^00?oa9^^00Go0000olBM/Oo4WK7oa9fao`00
0004olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`005_ooool00ol0003oooooooooo`0Nooooo`03o`000?o3XkSo`j>h00Co`j>h00?o0000
ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJmol>V_Ol000004?o3
XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o3X;Co`j2do`0000co`j>h00?o0000ol>P]?o3X;@0
1?o3X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S^?o3XkP0
0oo3XkP00ol0003oa:2dolBP]00;olBP]003o`000?o3XkSo000000koa:2d0_l0000=olBP]003o`00
0?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@05olBM/@03o`00
0?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK400ol0003oa:2dolBP]002olBP]003o`00
0?o4WK7oa9fa00[oa9fa00?o0000olBP]?l000003_o4WK42o`0000coa9fa00Go0000olBK[_o4Vjko
a9^^o`000005olBM/@03o`000?o4WK7oa9fa00;oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo01gooooo
00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@08ol>V_@03o`000?o3XkSo`j>h00Oo`j>h
00?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00<ol>S^0;o00003oo3XkP00ol0003o`j2d
o`00000=ol>S^003o`000?o3X;Co`j2d00?o`j2d00?o0000ol>S^?o3XkP01oo3XkP00ol0003oa:2d
olBP]006olBP]003o`000?o3XkSo`j>h00Co`j>h00?o0000olBP]?o4X;@02_o4X;@01?l0003o`j>h
ol>S^?l0000>olBP]003o`000?o4X;Coa:2d00goa:2d00Co0000olBM/Oo4WK7o00002oo4X;@00ol0
003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o0000olBM/Oo4WK401_o4WK400ol0
003oa:2dolBP]003olBP]003o`000?o4WK7oa9fa00Woa9fa00Co0000olBP]?o4X;Co00003_o4WK40
0ol0003oa9faolBM/@0;olBM/@04o`000?o4Vjkoa9^^o`0000Ooa9fa00Go0000olBM/Oo4WK7oa9fa
o`000004olBK[P03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001Sooooo0_l0
000Nooooo`05o`000?o3XkSo`j>hol>S^?l000002oo3Y[d00ol0003o`j>hol>S^006ol>S^003o`00
0?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02oo3XkP01?l0003o`jJmol>V_Ol0000?ol>S^003
o`000?o3XkSo`j>h00go`j>h00Go0000ol>P]?o3X;Co`j2do`00000;ol>S^003o`000?o4X;Coa:2d
00Coa:2d00?o0000ol>S^?o3XkP01Oo3XkP00ol0003oa:2dolBP]009olBP]005o`000?o3XkSo`j>h
ol>S^?l000003_o4X;@00ol0003oa:2dolBP]00=olBP]004o`000?o4WK7oa9fao`0000_oa:2d00?o
0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]006olBP]003o`000?o4WK7oa9fa00Goa9fa00?o
0000olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@08olBM/@05o`000?o4X;Coa:2dolBP]?l00000
3_o4WK400ol0003oa9faolBM/@0;olBM/@04o`000?o4Vjkoa9^^o`0000Ooa9fa00Go0000olBM/Oo4
WK7oa9fao`000004olBK[P03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001[o
oooo00?o0000ooooooooool06oooool01?l0003o`j>hol>S^?l0000=ol>V_@03o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJm
ol>V_Ol000003oo3XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o3X;Co`j2do`0000co`j>h00?o
0000olBP]?o4X;@01?o4X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o
0000ol>S^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]003o`000?o3XkSo000000koa:2d00?o
0000olBM/Ol000003?o4X;@00ol0003oa9faolBM/@02olBM/@03o`000?o4X;Coa:2d00Soa:2d00?o
0000olBM/Oo4WK401?o4WK400ol0003oa:2dolBP]005olBP]003o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBP]?o4X;@00_o4X;@00ol0003oa9faolBM/@0:olBM/@;o00003_o4WK42o`0000Woa9fa00Go
0000olBM/Oo4WK7oa9fao`000002olBK[P03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool001_ooooo00?o0000ooooooooool06_ooool00ol0003o`j>ho`00000>ol>V_@03o`000?o3
XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>hol>S^008ol>S^003o`000?o3
Y[go`jJm00?o`jJm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`jJmo`00000>ol>S^003o`000?o3
X;Co000000go`j>h00?o0000olBP]?o4X;@00oo4X;@00ol0003o`j>hol>S^007ol>S^003o`000?o4
X;Coa:2d00Koa:2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003oa:2dolBP]009olBP]004o`000?o3
XkSo`j>ho`0000ooa:2d00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003
o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03
o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402Oo4WK401?l0003oa:2dolBP]?l0000=olBM
/@03o`000?o4WK7oa9fa00Woa9fa00Ko0000olBM/Oo4WK7o0000olBK[_l0000Dooooo`03o`000?oo
oooooooo00kooooo000Looooo`03o`000?oooooooooo01[ooooo00?o0000ol>V_Oo3Y[d03_o3Y[d0
1Ol0003o`j>hol>S^?o3XkSo000000_o`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V
_@04ol>V_@03o`000?o3XkSo`j>h00[o`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>h
ol>S^00=ol>S^005o`000?o4X;Coa:2dolBP]?l000002oo3XkP00ol0003oa:2dolBP]004olBP]003
o`000?o3XkSo`j>h00Go`j>h00?o0000olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo0000
00ooa:2d00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7o
a9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@05olBM/@03o`000?o4X;Co
a:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK401Ol0003oa:2dolBP]?o4X;Co000000goa9fa00?o
0000olBM/Oo4WK402_o4WK401Ol0003oa9fao`000?o4Vjko000001Gooooo00?o0000ooooooooool0
3Oooool001gooooo0_l0000Jooooo`03o`000?o3Y[go`jJm00ko`jJm00Co0000ol>S^?o3XkSo0000
3?o3Y[d00ol0003o`j>hol>S^005ol>S^003o`000?o3Y[go`jJm00Go`jJm00?o0000ol>S^?o3XkP0
2Oo3XkP01Ol0003o`jJmol>V_Oo3Y[go000000oo`j>h00?o0000ol>S^?o3XkP03Oo3XkP01?l0003o
a:2dolBP]?l0000<ol>S^003o`000?o4X;Coa:2d00Coa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0
003oa:2dolBP]007olBP]003o`000?o3XkSo`j>h00;o`j>h00?o0000olBP]?o4X;@02oo4X;@00ol0
003o`j>ho`00000=olBP]003o`000?o4WK7o000000goa:2d00Co0000olBM/Oo4WK7o00002oo4X;@0
0ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o0000olBM/Oo4WK401oo4WK40
1Ol0003oa:2dolBP]?o4X;Co000000coa9fa00?o0000olBP]?l000002oo4WK401?l0003oa9faolBM
/Ol0000Fooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Sooooo00?o
0000ol>V_Oo3Y[d03Oo3Y[d00ol0003o`j>ho`00000>ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o
0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00?o`jJm00?o
0000ol>S^?o3XkP02oo3XkP00ol0003o`jJmo`00000>ol>S^003o`000?o4X;Co000000go`j>h00?o
0000olBP]?o4X;@00oo4X;@00ol0003o`j>hol>S^007ol>S^003o`000?o4X;Coa:2d00Koa:2d00?o
0000ol>S^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]004o`000?o3XkSo`j>ho`0000koa:2d
00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00?o
a9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?o
a:2d00?o0000olBM/Oo4WK402?o4WK401?l0003oa:2dolBP]?l0000<olBM/@03o`000?o4WK7o0000
01Kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool05oooool00ol0003o
`jJmol>V_@0=ol>V_@;o00003oo3Y[d00ol0003o`j>hol>S^002ol>S^003o`000?o3Y[go`jJm00So
`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00[o
`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>hol>S^00=ol>S^005o`000?o4X;Coa:2d
olBP]?l000002oo3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Go`j>h00?o0000
olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo000000koa:2d00?o0000olBP]?o4X;@03?o4
X;@00ol0003oa9fao`00000<olBP]003o`000?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4
X;@00ol0003oa9faolBM/@05olBM/@03o`000?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK401oo4
WK401Ol0003oa:2dolBP]?o4X;Co000000goa9fa00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0=ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?o3Y[go`jJm00_o`jJm00?o
0000ol:[`ol000004?o3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^008ol>S^005o`000?o3Y[go`jJmol>V_Ol0
00003oo3XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o4X;Coa:2do`0000co`j>h00?o0000olBP
]?o4X;@00oo4X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S
^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]003o`000?o3XkSo000000koa:2d00?o0000olBP
]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00Coa9fa00?o0000
olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00;oa:2d00?o0000
olBM/Oo4WK402Oo4WK42o`0001Oooooo00?o0000ooooooooool03Oooool002;ooooo0_l0000Goooo
o`03o`000?o3Y[go`jJm00[o`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000?ol>V_@03o`000?o3XkSo
000000go`jJm00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@07ol>V_@03o`000?o3XkSo
`j>h00Oo`j>h00?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00;ol>S^003o`000?o3Y[go
000000ko`j>h00?o0000olBP]?l000003Oo3XkP00ol0003oa:2dolBP]002olBP]003o`000?o3XkSo
`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^004ol>S^003o`000?o4X;Co
a:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0003oa:2dolBP]00<olBP]004o`000?o4
WK7oa9fao`0000_oa:2d00?o0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]006olBP]003o`00
0?o4WK7oa9fa00Goa9fa00?o0000olBP]?o4X;@00oo4X;@00ol0003oa9faolBM/@08olBM/@04o`00
0?ooooooooooo`0001Kooooo00?o0000ooooooooool03Oooool002Cooooo00?o0000ooooooooool0
5Oooool00ol0003o`jJmol>V_@08ol>V_@03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol>V_Oo3Y[d0
3Oo3Y[d2o`0000oo`jJm00Go0000ol>S^?o3XkSo`j>ho`00000:ol>V_@03o`000?o3XkSo`j>h00Ko
`j>h00?o0000ol>V_Oo3Y[d01?o3Y[d00ol0003o`j>hol>S^00:ol>S^004o`000?o3Y[go`jJmo`00
00oo`j>h00?o0000ol>S^?o3XkP03Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000[o`j>h00?o0000
olBP]?o4X;@01?o4X;@00ol0003o`j>hol>S^005ol>S^003o`000?o4X;Coa:2d00Soa:2d00Go0000
ol>S^?o3XkSo`j>ho`00000=olBP]003o`000?o3XkSo000000goa:2d00?o0000olBM/Ol000003?o4
X;@00ol0003oa9faolBM/@02olBM/@03o`000?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401?o4
WK400ol0003oa:2dolBP]004olBP]003o`000?o4WK7oa9fa00Soa9fa00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo00gooooo000Uooooo`03o`000?oooooooooo01Gooooo00?o
0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00_o`jJm00?o
0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^008ol>S^003o`000?o3Y[go`jJm00;o`jJm
00?o0000ol>S^?o3XkP02oo3XkP2o`0000oo`j>h00Co0000olBP]?o4X;Co00002oo3XkP00ol0003o
a:2dolBP]003olBP]003o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0
003oa:2dolBP]00<olBP]004o`000?o4WK7oa9fao`0000[oa:2d00?o0000olBM/Oo4WK400oo4WK40
0ol0003oa:2dolBP]006olBP]003o`000?o4WK7oa9fa00Koa9fa00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo000Vooooo`03o`000?oooooooooo
01Cooooo00?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``05ol:[``03o`000?o3Y[go`jJm
00[o`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000>ol>V_@03o`000?o3XkSo000000go`jJm00?o0000
ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@07ol>V_@03o`000?o3XkSo`j>h00Oo`j>h00?o0000
ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00:ol>S^004o`000?o3Y[go`jJmo`0000ko`j>h00?o
0000olBP]?l000003Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000[o`j>h00?o0000olBP]?o4X;@0
1Oo4X;@00ol0003o`j>hol>S^004ol>S^003o`000?o4X;Coa:2d00Soa:2d00Go0000ol>S^?o3XkSo
`j>ho`00000>olBP]003o`000?o4X;Coa:2d00coa:2d00Co0000olBM/Oo4WK7o00002oo4X;@01Ol0
003oa9faolBM/Oo4WK7o000000Woa:2d00?o0000olBM/Oo4WK401Oo4WK400ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Eoooo
o`03o`000?o3Y[go`jJm00?o`jJm00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`jJmol>V_@08ol>V
_@03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol>V_Oo3Y[d03?o3Y[d2o`0000oo`jJm00Go0000ol>S
^?o3XkSo`j>ho`00000:ol>V_@03o`000?o3XkSo`j>h00Ko`j>h00?o0000ol>V_Oo3Y[d01?o3Y[d0
0ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJmol>V_Ol000003oo3XkP00ol0003o`j>hol>S
^00<ol>S^004o`000?o4X;Coa:2do`0000_o`j>h00?o0000olBP]?o4X;@01?o4X;@00ol0003o`j>h
ol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S^?o3XkP00_o3XkP00ol0003oa:2d
olBP]00:olBP]003o`000?o3XkSo000000goa:2d00?o0000olBM/Ol000003?o4X;@01Ol0003oa9fa
olBM/Oo4WK7o000000[oa:2d00?o0000olBM/Oo4WK401?o4WK400ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool002Wooooo00?o0000ooooooooool0
4_ooool00ol0003o`jJmol>V_@02ol>V_@03o`000?o2Zl?o`Z_300Wo`Z_300?o0000ol>V_Oo3Y[d0
1_o3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00[o`jJm00?o0000ol:[`ol00000
3oo3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h00?o0000ol>V_Oo3
Y[d01_o3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00?o`jJm00?o0000ol>S^?o3
XkP02oo3XkP2o`0000ko`j>h00?o0000olBP]?l000003Oo3XkP00ol0003oa:2dolBP]002olBP]003
o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^003ol>S^003
o`000?o4X;Coa:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0003oa:2dolBP]00;olBP
]004o`000?o4WK7oa9fao`0000_oa:2d00?o0000olBM/Oo4WK400oo4WK400ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000oooo
ooooool04_ooool01?l0003o`jJmol>V_Ol0000<ol:[``03o`000?o3Y[go`jJm00Go`jJm00?o0000
ol:[`oo2Zl<01Oo2Zl<00ol0003o`jJmol>V_@09ol>V_@05o`000?o2Zl?o`Z_3ol:[`ol000003_o3
Y[d00ol0003o`j>ho`00000=ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3
Y[d00ol0003o`j>hol>S^006ol>S^003o`000?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02_o3
XkP01?l0003o`jJmol>V_Ol0000>ol>S^003o`000?o3XkSo`j>h00co`j>h00Go0000olBP]?o4X;Co
a:2do`00000:ol>S^003o`000?o4X;Coa:2d00Goa:2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003o
a:2dolBP]008olBP]005o`000?o3XkSo`j>hol>S^?l000003_o4X;@00ol0003oa:2dolBP]00<olBP
]0;o00003?o4X;@00ol0003oa9faolBM/@02olBM/@03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`00:oooool00ol0003oooooooooo`0Aooooo`03
o`000?o3Y[go000000ko`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[``03
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0<ol>V_@;o
00003oo3Y[d01Ol0003o`j>hol>S^?o3XkSo000000_o`jJm00?o0000ol>S^?o3XkP01?o3XkP00ol0
003o`jJmol>V_@05ol>V_@03o`000?o3XkSo`j>h00Wo`j>h00Go0000ol>V_Oo3Y[go`jJmo`00000>
ol>S^003o`000?o3XkSo`j>h00co`j>h00Co0000olBP]?o4X;Co00003?o3XkP00ol0003oa:2dolBP
]003olBP]003o`000?o3XkSo`j>h00Ko`j>h00?o0000olBP]?o4X;@01oo4X;@00ol0003o`j>hol>S
^002ol>S^003o`000?o4X;Coa:2d00[oa:2d00?o0000ol>S^?l000003Oo4X;@00ol0003oa:2dolBP
]00<olBP]004o`000?o4WK7oa9fao`0000cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0<ooooo`00;?ooool2o`0001;ooooo00?o0000ol:[`oo2Zl<03Oo2Zl<00ol0003o`jJmol>V
_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3ol:[
``04ol:[``03o`000?o3Y[go`jJm00[o`jJm00?o0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S
^?l0000<ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>h
ol>S^007ol>S^003o`000?o3Y[go`jJm00;o`jJm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`jJm
o`00000>ol>S^0;o00003Oo3XkP00ol0003oa:2dolBP]002olBP]003o`000?o3XkSo`j>h00Oo`j>h
00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d
00Co0000ol>S^?o3XkSo00003Oo4X;@00ol0003oa:2dolBP]00<olBP]004o`000?o4WK7oa9fao`00
00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`00;_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?o2Zl?o`Z_300ko`Z_300Co0000ol>V_Oo3Y[go00002oo2Zl<00ol0
003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3Y[d02Oo3Y[d01Ol0
003o`Z_3ol:[`oo2Zl?o000000ko`jJm00?o0000ol>S^?l000003_o3Y[d01Ol0003o`j>hol>S^?o3
XkSo000000[o`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3
XkSo`j>h00Wo`j>h00Co0000ol>V_Oo3Y[go00003_o3XkP00ol0003o`j>hol>S^00=ol>S^005o`00
0?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Co
`j>h00?o0000olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo000000coa:2d00?o0000ol>S
^?l000003Oo4X;@00ol0003oa9fao`00000?ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02oooool002oooooo00?o0000ooooooooool03oooool00ol0003o`Z_3ol:[``0=ol:[``03
o`000?o3Y[go000000go`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[``03
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0=ol>V_@03
o`000?o3Y[go`jJm00go`jJm00Co0000ol>S^?o3XkSo00003?o3Y[d00ol0003o`j>hol>S^004ol>S
^003o`000?o3Y[go`jJm00Go`jJm00?o0000ol>S^?o3XkP02?o3XkP00ol0003o`jJmol>V_@02ol>V
_@03o`000?o3XkSo`j>h00_o`j>h00?o0000ol>S^?o3XkP03Oo3XkP01?l0003oa:2dolBP]?l0000;
ol>S^003o`000?o4X;Coa:2d00?oa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003oa:2dolBP]006
olBP]003o`000?o3XkSo`j>h00?o`j>h00?o0000olBP]?o4X;@02?o4X;@01?l0003o`j>hol>S^?l0
000>olBP]003o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0;ooooo`00<?ooool00ol0003oooooooooo`0>ooooo`03o`000?o2Zl?o`Z_300go`Z_30_l0000>
ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[`oo2Zl<02?o2Zl<00ol0003o`jJmol>V_@06
ol>V_@03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol>V_Oo3Y[d02oo3Y[d2o`0000oo`jJm00?o0000
ol>S^?l000003Oo3Y[d00ol0003o`j>hol>S^003ol>S^003o`000?o3Y[go`jJm00Ko`jJm00?o0000
ol>S^?o3XkP01oo3XkP00ol0003o`jJmol>V_@03ol>V_@03o`000?o3XkSo`j>h00[o`j>h00?o0000
ol>V_Ol000003_o3XkP00ol0003oa:2do`00000<ol>S^003o`000?o4X;Coa:2d00;oa:2d00?o0000
ol>S^?o3XkP01oo3XkP00ol0003oa:2dolBP]005olBP]003o`000?o3XkSo`j>h00Co`j>h00?o0000
olBP]?o4X;@01oo4X;@01Ol0003o`j>hol>S^?o3XkSo000000koa:2d00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo000aooooo`;o00003oooool0
0ol0003o`Z_3ol:[``0;ol:[``03o`000?o0/<[o000000oo`Z_300Co0000ol>V_Oo3Y[go00002oo2
Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3Y[d02_o3
Y[d01?l0003o`Z_3ol:[`ol0000>ol>V_@;o00003oo3Y[d01Ol0003o`j>hol>S^?o3XkSo000000[o
`jJm00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00Wo
`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>hol>S^00<ol>S^005o`000?o4X;Coa:2d
olBP]?l000002Oo3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Go`j>h00?o0000
olBP]?o4X;@01oo4X;@00ol0003o`j>hol>S^002ol>S^003o`000?o4X;Coa:2d00[oa:2d00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo000coooo
o`03o`000?oooooooooo00gooooo00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o`;3:ol2`b_o0/<[o
000000ko`Z_300?o0000ol>V_Ol000003Oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`000?o2Zl?o
`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d02?o3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o
0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S^?l0000;ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00;o`jJm
00?o0000ol>S^?o3XkP02oo3XkP2o`0000ko`j>h00Co0000olBP]?o4X;Co00002oo3XkP00ol0003o
a:2dolBP]002olBP]003o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01Oo4X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000dooooo`03o`000?oooooooooo00cooooo
00?o0000ol:[`oo2Zl<02?o2Zl<00ol0003o`;3:ol2`bP02ol2`bP03o`000?o2Zl?o`Z_300co`Z_3
0_l0000>ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[`oo2Zl<02Oo2Zl<00ol0003o`jJm
ol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o`Z_300?o0000ol>V_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3
ol:[`oo2Zl?o000000ko`jJm00?o0000ol>S^?l000003?o3Y[d00ol0003o`j>hol>S^003ol>S^003
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@03ol>V_@03
o`000?o3XkSo`j>h00[o`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003oa:2do`00000<ol>S
^005o`000?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo
`j>h00Go`j>h00?o0000olBP]?o4X;@01oo4X;@00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool003Gooooo00?o0000ooooooooool03?ooool00ol0
003o`Z_3ol:[``05ol:[``;o00001_o0/<X00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0/<[o0000
00oo`Z_300Co0000ol>V_Oo3Y[go00003?o2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o
`Z_300Co`Z_300?o0000ol>V_Oo3Y[d02?o3Y[d00ol0003o`Z_3ol:[``02ol:[``03o`000?o3Y[go
`jJm00co`jJm0_l0000>ol>V_@05o`000?o3XkSo`j>hol>S^?l000002oo3Y[d00ol0003o`j>hol>S
^004ol>S^003o`000?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02Oo3XkP01Ol0003o`jNmol>W
_Oo3Ykgo000000ko`j>h00?o0000ol>S^?o3XkP02oo3XkP01?l0003oa:2dolBP]?l0000;ol>S^003
o`000?o4X;Coa:2d00?oa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003oa:2dolBP]006olBP]003
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`00
=_ooool2o`0000cooooo00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`;3:ol2`bP06ol2`bP03o`00
0?o2Zl?o`Z_300Wo`Z_300Go0000ol2`b_o0/<[o`;3:o`00000>ol:[``03o`000?o3Y[go000000ko
`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``06ol:[``03o`000?o3Y[go`jJm00Ko
`jJm00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`jJmol>V_@0:ol>V_@03o`000?o2Zl?o000000ko
`jJm00Co0000ol>S^?o3XkSo00003?o3Y[d00ol0003o`j>hol>S^003ol>S^003o`000?o3Y[go`jJm
00Ko`jJm00?o0000ol>S^?o3XkP01oo3XkP00ol0003o`jNmol>W_@02ol>W_@03o`000?o3XkSo`j>h
00_o`j>h0_l0000>ol>S^0;o00003Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000Wo`j>h00?o0000
olBP]?o4X;@01Oo4X;@00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool003Sooooo00?o0000ooooooooool02_ooool00ol0003o`Z_3ol:[``02ol:[
``03o`000?o0/<[o`;3:00So`;3:00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`;3:ol2`bP03ol2`
bP03o`000?o2Zl?o`Z_300_o`Z_30_l0000?ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[
`oo2Zl<01oo2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V
_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o0000ol>S^?l000003_o3Y[d0
1Ol0003o`j>hol>S^?o3XkSo000000Wo`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jNmol>W
_@04ol>W_@03o`000?o3XkSo`j>h00Wo`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003o`j>h
ol>S^00<ol>S^005o`000?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003
o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00
>Oooool00ol0003oooooooooo`0:ooooo`04o`000?o2Zl?o`Z_3o`0000_o`;3:00?o0000ol:[`oo2
Zl<01Oo2Zl<2o`0000Ko`;3:00?o0000ol:[`oo2Zl<02_o2Zl<00ol0003o`;3:o`00000@ol:[``04
o`000?o3Y[go`jJmo`0000_o`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[
``03o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0<ol>V
_@03o`000?o3Y[go`jJm00go`jJm00Co0000ol>S^?o3XkSo00002oo3Y[d00ol0003o`j>hol>S^004
ol>S^003o`000?o3Ykgo`jNm00Go`jNm00?o0000ol>S^?o3XkP02?o3XkP01Ol0003o`jNmol>W_Oo3
Ykgo000000go`j>h00?o0000ol>S^?o3XkP03?o3XkP01?l0003oa:2dolBP]?l0000;ol>S^003o`00
0?o4X;Coa:2d00?oa:2d00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo000jooooo`03o`000?oooooooooo00Wooooo00?o0000ol:[`ol000003Oo0
/<X00ol0003o`Z_3ol:[``03ol:[``03o`000?o0/<[o`;3:00Oo`;3:00?o0000ol:[`oo2Zl<02?o2
Zl<01Ol0003o`;3:ol2`b_o0/<[o000000oo`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o`jJm
ol>V_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3
ol:[``04ol:[``03o`000?o3Y[go`jJm00[o`jJm0_l0000?ol>V_@03o`000?o3XkSo000000co`jJm
00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jNmol>W_@06ol>W_@03o`000?o3XkSo`j>h00Oo`j>h
00?o0000ol>W_Oo3Ykd00_o3Ykd00ol0003o`j>hol>S^00:ol>S^003o`000?o3Ykgo000000ko`j>h
0_l0000=ol>S^005o`000?o4X;Coa:2dolBP]?l000007_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000kooooo`;o00002_ooool00ol0003o`;3:ol2`bP0<ol2`bP03o`00
0?o2Zl?o`Z_300;o`Z_300?o0000ol2`b_o0/<X02Oo0/<X00ol0003o`Z_3ol:[``06ol:[``03o`00
0?o0/<[o`;3:00?o`;3:00?o0000ol:[`oo2Zl<03?o2Zl<2o`0000ko`Z_300Co0000ol>V_Oo3Y[go
00002oo2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3
Y[d02Oo3Y[d01?l0003o`Z_3ol:[`ol0000>ol>V_@;o00003_o3Y[d01Ol0003o`j>hol>S^?o3XkSo
000000[o`jNm00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`jNmol>W_@04ol>W_@03o`000?o3XkSo
`j>h00So`j>h00Co0000ol>W_Oo3Ykgo00003_o3XkP00ol0003o`j>hol>S^00<ol>S^004o`000?o4
X;Coa:2do`00023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00?Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?o0/<[o`;3:00go`;3:00Co0000ol:[`oo2Zl?o0000
3?o0/<X00ol0003o`Z_3ol:[``04ol:[``;o00001_o0/<X00ol0003o`Z_3ol:[``0;ol:[``03o`00
0?o0/<[o000000ko`Z_300?o0000ol>V_Ol000003Oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`00
0?o2Zl?o`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d01oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go
`jJm00?o0000ol:[`ol000003_o3Y[d01?l0003o`j>hol>S^?l0000;ol>W_@03o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>W_Oo3Ykd01Oo3Ykd00ol0003o`j>hol>S^007ol>S^003o`000?o3Ykgo`jNm
00;o`jNm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`j>hol>S^00<ol>S^003o`000?o4X;Co0000
027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00?_ooool00ol0003o
ooooooooo`07ooooo`03o`000?o0/<[o`;3:00co`;3:00?o0000ol:[`ol000003_o0/<X00ol0003o
`Z_3ol:[``02ol:[``03o`000?o0/<[o`;3:00Oo`;3:00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o
`;3:ol2`b_o0/<[o000000go`Z_30_l0000>ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[
`oo2Zl<02?o2Zl<00ol0003o`jJmol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o`Z_300?o0000ol>V
_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o0000ol>S^?l000003?o3Ykd0
0ol0003o`j>hol>S^003ol>S^003o`000?o3Ykgo`jNm00Oo`jNm00?o0000ol>S^?o3XkP01Oo3XkP0
0ol0003o`jNmol>W_@03ol>W_@03o`000?o3XkSo`j>h00[o`j>h00?o0000ol>W_Ol000003_o3XkP0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0
03oooooo00?o0000ooooooooool01oooool00ol0003o`;3:ol2`bP0;ol2`bP;o00003oo0/<X01Ol0
003o`Z_3ol:[`oo2Zl?o000000_o`;3:00?o0000ol:[`oo2Zl<01_o2Zl<2o`0000Co`;3:00?o0000
ol:[`oo2Zl<02_o2Zl<00ol0003o`;3;o`00000?ol:[``04o`000?o3Y[go`jJmo`0000_o`Z_300?o
0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00So`jJm00?o
0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0;ol>V_@;o00003_o3Ykd01Ol0003o`j>hol>S
^?o3XkSo000000[o`jNm00?o0000ol>S^?o3XkP01?o3XkP00ol0003o`jNmol>W_@04ol>W_@03o`00
0?o3XkSo`j>h00Wo`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0043ooooo0_l00007ooooo`03o`00
0?o0/<[o`;3:00[o`;3:00?o0000okfge?l000004?o0/<X00ol0003o`Z_3o`00000<ol2`bP03o`00
0?o2Zl?o`Z_300Go`Z_300?o0000ol2`b_o0/<X01Oo0/<X00ol0003o`Z_3ol:[``08ol:[``05o`00
0?o0/<_o`;3;ol2`bol000003_o2Zl<00ol0003o`jJmo`00000=ol:[``03o`000?o3Y[go`jJm00?o
`jJm00?o0000ol:[`oo2Zl<01_o2Zl<00ol0003o`jJmol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o
`Z_300?o0000ol>V_Oo3Y[d02_o3Y[d00ol0003o`Z_3o`00000>ol>W_@04o`000?o3XkSo`j>ho`00
00_o`jNm00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jNmol>W_@06ol>W_@03o`000?o3XkSo`j>h
00Oo`j>h00Go0000ol>W_Oo3Ykgo`jNmo`00000<ol>S^003o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00@_ooool00ol0003oooooooooo`05oooo
o`03o`000?o0/<[o`;3:00Oo`;3:0_l00003okfge003o`000?o0/<[o`;3:00go`;3:0_l0000>ol2`
bP03o`000?o2Zl?o`Z_300;o`Z_30_l00008ol2`bP03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol2`
boo0/</00_o0/</00ol0003o`Z_3ol:[``0<ol:[``;o00003_o2Zl<00ol0003o`jJmol>V_@02ol>V
_@03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``05ol:[
``03o`000?o3Y[go`jJm00So`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000=ol>W_@03o`000?o3XkSo
000000go`jNm00Go0000ol>S^?o3XkSo`j>ho`000009ol>W_@03o`000?o3XkSo`j>h00Ko`j>h00?o
0000ol>W_Oo3Ykd00oo3Ykd00ol0003o`j>hol>S^008ol>S^003o`000?oooooooooo02Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00@oooool00ol0003oooooooooo`05
ooooo`03o`000?o0/<[o`;3:00Go`;3:00?o0000okfge?nm]m@01?nm]m@00ol0003o`;3:ol2`bP0;
ol2`bP03o`000?nm]mCo000000ko`;3:00Go0000ol:[`oo2Zl?o`Z_3o`00000;ol2`bP03o`000?o2
Zl?o`Z_300Go`Z_300?o0000ol2`boo0/</01?o0/</00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0
/<_o000000oo`Z_300Co0000ol>V_Oo3Y[go00002oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`00
0?o2Zl?o`Z_300Ko`Z_300?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`Z_3ol:[``02ol:[``03o`00
0?o3Ykgo`jNm00_o`jNm0_l0000>ol>W_@04o`000?o3XkSo`j>ho`0000_o`jNm00?o0000ol>S^?o3
XkP01?o3XkP00ol0003o`jNmol>W_@04ol>W_@03o`000?o3XkSo`j>h00Oo`j>h00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0014ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ol2`b_o0/<X00oo0/<X00ol0003o_KODokfge006okfge003o`00
0?o0/<[o`;3:00So`;3:0_l00003okfge003o`000?o0/<[o`;3:00co`;3:00?o0000ol:[`ol00000
3Oo0/<X00ol0003o`Z_3ol:[``03ol:[``03o`000?o0/<_o`;3;00Go`;3;00?o0000ol:[`oo2Zl<0
2Oo2Zl<01Ol0003o`;3;ol2`boo0/<_o000000ko`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o
`jJmol>V_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o
`Z_3ol:[``04ol:[``03o`000?o3Ykgo`jNm00Wo`jNm00?o0000ol:[`ol000003_o3Ykd00ol0003o
`j>ho`00000<ol>W_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003o
`j>hol>S^005ol>S^003o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`00AOooool2o`0000Gooooo00Co0000ol2`b_o0/<[o`;3:0_l0000:okfge003
o`000?o0/<[o`;3:00Go`;3:0_l00006okfge003o`000?o0/<[o`;3:00_o`;3:0_l0000>ol2`bP03
o`000?o2Zl?o`Z_300;o`Z_300?o0000ol2`boo0/</01oo0/</00ol0003o`Z_3ol:[``06ol:[``;o
00001?o0/</00ol0003o`Z_3ol:[``0<ol:[``;o00003_o2Zl<01?l0003o`jJmol>V_Ol0000;ol:[
``03o`000?o3Y[go`jJm00Co`jJm00?o0000ol:[`oo2Zl<01Oo2Zl<00ol0003o`jNmol>W_@08ol>W
_@05o`000?o2Zl?o`Z_3ol:[`ol000003_o3Ykd00ol0003o`jNmol>W_@0<ol>W_@05o`000?o3XkSo
`j>hol>S^?l000002Oo3Ykd00ol0003o`j>hol>S^004ol>S^003o`000?oooooooooo02cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Aoooool00ol0003oooooooooo`03
ooooo`03o`000?o0/<[o000000co_KOD00?o0000ol2`b_o0/<X01?o0/<X00ol0003o_KODokfge006
okfge003o`000?o0/<[o`;3:00[o`;3:00?o0000okfge?l000003oo0/<X01?l0003o`Z_3ol:[`ol0
000;ol2`b`03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol2`boo0/</01Oo0/</00ol0003o`Z_3ol:[
``0:ol:[``03o`000?o0/L_o000000ko`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o`jJmol>V
_@03ol>V_@03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003o`Z_3ol:[
``02ol:[``03o`000?o3Ykgo`jNm00_o`jNm0_l0000>ol>W_@04o`000?o3XkSo`j>ho`0000[o`jNm
00?o0000ol>S^?o3XkP00oo3XkP00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool004Sooooo00?o0000ooooooooool00oooool00ol0003o_KODokfg
e00<okfge004o`000?o0/<[o`;3:ol2`bP;o00002_nm]m@00ol0003o`;3:ol2`bP07ol2`bP;o0000
0onm]m@00ol0003o`;3:ol2`bP0<ol2`bP03o`000?o2Zl?o000000co`;3;00?o0000ol:[`oo2Zl<0
0_o2Zl<2o`0000So`;3;00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o`;7;ol2aboo0/L_o000000go
`Z_30_l0000>ol:[``05o`000?o3Y[go`jJmol>V_Ol000002_o2Zl<00ol0003o`jNmol>W_@05ol>W
_@03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol>W_Oo3Ykd02Oo3Ykd01?l0003o`Z_3ol:[`ol0000=
ol>W_@03o`000?o3XkSo000000co`jNm00Go0000ol>S^?o3XkSo`j>ho`00000aooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool004Wooooo00?o0000ooooooooool00_ooool0
0ol0003o_KODokfge00=okfge003o`000?o0/<[o000000co_KOD00?o0000ol2`b_o0/<X01Oo0/<X2
o`0000Ko_KOD00?o0000ol2`b_o0/<X02oo0/<X2o`0000ko`;3;00Co0000ol:[`oo2Zl?o00002oo0
/</00ol0003o`Z_3ol:[``06ol:[``;o00001Oo0/L/00ol0003o`Z_3ol:[``09ol:[``03o`000?o0
/L_o000000ko`Z_300Co0000ol>V_Oo3Y[go00003?o2Zl<00ol0003o`jNmol>W_@03ol>W_@03o`00
0?o2Zl?o`Z_300Go`Z_300?o0000ol>W_Oo3Ykd02?o3Ykd01Ol0003o`Z_3ol:[`oo2Zl?o000000go
`jNm0_l0000=ol>W_@04o`000?o3XkSo`j>ho`0003?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`00B_ooool2o`0000?ooooo00?o0000okfge?nm]m@03?nm]m@2o`0000ko
_KOD00?o0000ol2`b_o0/<X00oo0/<X00ol0003o_KODokfge006okfge003o`000?o0/<[o`;3:00Wo
`;3:0_l000000onm^=Co0000ol2`b`0=ol2`b`03o`000?o2Zl?o000000go`;3;00?o0000ol:[`oo2
Zl<01?o2Zl<00ol0003o`;7;ol2ab`05ol2ab`03o`000?o2Zl?o`Z_300So`Z_300Go0000ol2aboo0
/L_o`;7;o`00000=ol:[``03o`000?o3Y[go000000go`Z_300?o0000ol>W_Oo3Ykd00_o3Ykd00ol0
003o`Z_3ol:[``07ol:[``03o`000?o3Ykgo`jNm00Ko`jNm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0
003o`jNmol>W_@0:ol>W_@03o`000?o2Zl?o000000go`jNm00?o0000ol>S^?l00000=Oooool01Ol0
003ooooooooooooooooo000000[ooooo001<ooooo`05o`000?ooooooooooooooool000002onm]m@2
o`000003okS0h?l0003o_KOD00ko_KOD00?o0000ol2`b_o0/<X00_l0000:okfge003o`000?o0/<[o
`;3:00Ko`;3:0_l00004okfhe003o`000?o0/<_o`;3;00_o`;3;0_l0000>ol2`b`03o`000?o2Zl?o
`Z_300;o`Z_30_l00009ol2ab`03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol2aboo0/L/00_o0/L/0
0ol0003o`Z_3ol:[``0;ol:[``;o00003oo2Zl<01?l0003o`jNmol>W_Ol0000:ol:[``03o`000?o3
Ykgo`jNm00Go`jNm00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`jNmol>W_@08ol>W_@05o`000?o2
Zl?o`Z_3ol:[`ol000003Oo3Ykd00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool0
00002_ooool004gooooo00Go0000ooooooooooooooooo`000009okfge003o`000?nh`>3o^<3P00;o
^<3P00?o0000okfge?nm]m@03?nm]m@00ol0003o`;3:o`00000=okfge003o`000?o0/<[o`;3:00Co
`;3:00?o0000okfhe?nm^=@01Onm^=@00ol0003o`;3;ol2`b`09ol2`b`03o`000?nm^=Co000000oo
`;3;00Co0000ol:[`oo2Zl?o00002oo0/L/00ol0003o`Z_3ol:[``04ol:[``;o00001_o0/L/00ol0
003o`Z_3ol:[``09ol:[``03o`000?o0/L_o000000oo`Z_300?o0000ol>W_Ol000003?o2Zl<00ol0
003o`jNmol>W_@03ol>W_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>W_Oo3Ykd01oo3Ykd00ol0
003o`Z_3ol:[``02ol:[``03o`000?o3Ykgo`jNm00[o`jNm00?o0000ooooooooool0=_ooool01?l0
003oooooooooool0000:ooooo`00C_ooool01Ol0003ooooooooooooooooo000000Ko_KOD0_l00006
okS0h003o`000?nm]mCo_KOD00_o_KOD0_l0000>okfge003o`000?o0/<[o`;3:00;o`;3:0_l00008
okfhe003o`000?o0/<_o`;3;00Oo`;3;0_l00003okfhe003o`000?o0/<_o`;3;00co`;3;00?o0000
ol:[`ol000003Oo0/L/00ol0003o`Z_3ol:[``02ol:[``03o`000?o0/L_o`;7;00Ko`;7;00?o0000
ol:[`oo2Zl<02?o2Zl<01Ol0003o`;7;ol2aboo0/L_o000000ko`Z_30_l0000=ol:[``03o`000?o3
Ykgo`jNm00;o`jNm00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`jNmol>W_@04ol>W_@;o00001Oo2
Zl<00ol0003o`jNmol>W_@09ol>W_@03o`000?oooooooooo03Sooooo00?o0000ooooool000002_oo
ool004oooooo0_l00002ooooo`04o`000?nm]mCo_KODokfge0;o00002Onh`>000ol0003o_KODokfg
e008okfge0;o000000?o^<7Po`000?nm]m@03_nm]m@01?l0003o`;3:o`000?l0000;okfhe003o`00
0?o0/<_o`;3;00Go`;3;00?o0000okfhe?nm^=@01?nm^=@00ol0003o`;3;ol2`b`0;ol2`b`;o0000
3oo0/L/01?l0003o`Z_3ol:[`ol0000:ol2ab`03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol2aboo0
/L/00oo0/L/00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0/L_o000000ko`Z_300Co0000ol>W_Oo3
Ykgo00002_o2Zl<00ol0003o`jNmol>W_@03ol>W_@03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol>W
_Oo3Ykd01oo3Ykd00ol0003oooooooooo`0iooooo`03o`000?oooooo000000[ooooo001Aooooo`06
o`000?ooooooooooo`000?nm]mCo00003?nh`>000ol0003o_KODokfge005okfge0;o00001?nh`N00
0ol0003o_KODokfge00<okfge0;o00003_nm^=@00ol0003o`;3;ol2`b`03ol2`b`03o`000?nm^=Co
_KSD00Go_KSD00?o0000ol2`boo0/</02_o0/</00ol0003o_KSDo`00000?ol2ab`03o`000?o2Zl?o
000000co`;7;00?o0000ol:[`oo2Zl<00oo2Zl<2o`0000Ko`;7;00?o0000ol:[`oo2Zl<02Oo2Zl<0
1Ol0003o`;7;ol2aboo0/L_o000000go`Z_300?o0000ol>W_Ol000003?o2Zl<01Ol0003o`jNmol>W
_Oo3Ykgo000000Wo`Z_300?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003oooooooooo`0kooooo`03o`00
0?oooooo000000Wooooo001Booooo`04o`000?ooooooooooo`0000ko^<3P00?o0000okfge?nm]m@0
0_nm]m@2o`0000Oo^<7P00?o0000okfge?nm]m@02Onm]m@2o`000003okS1hOl0003o_KSD00go_KSD
00Co0000ol2`boo0/<_o`;3;0_l00009okfhe003o`000?o0/<_o`;3;00Oo`;3;0_l00003okfhe003
o`000?o0/L_o`;7;00co`;7;0_l0000=ol2ab`03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol2aboo0
/L/01oo0/L/00ol0003o`Z_3ol:[``06ol:[``;o00001?o0/L/00ol0003o`Z_3ol:[``0;ol:[``;o
00003Oo2Zl<01?l0003o`jNmol>W_Ol0000;ol:[``03o`000?o3Ykgo`jNm00Co`jNm00?o0000oooo
ooooool0?Oooool2o`0000Wooooo001Cooooo`;o000000?oooooo`000?nh`>003Onh`>001?l0003o
_KODo`000?l0000:okS1h003o`000?nm]mCo_KOD00Oo_KOD00?o0000okS1hOnh`N400_nh`N400ol0
003o_KSDokfhe00<okfhe003o`000?o0/<_o000000co_KSD00?o0000ol2`boo0/</01Oo0/</00ol0
003o_KSDokfhe004okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000okfhe?l000003_o0/L/01?l0
003o`Z_3ol:[`ol0000:ol2ab`03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol2aboo0/L/01Oo0/L/0
0ol0003o`Z_3ol:[``09ol:[``03o`000?o0/L_o000000go`Z_300?o0000ol>W_Ol000003?o2Zl<0
0ol0003o`jNmol>W_@03ol>W_@03o`000?oooooooooo03gooooo0ol00009ooooo`00EOooool00ol0
003oooooo`00000=okS0h0;o00003Onh`N000ol0003o_KODokfge004okfge0;o00001_nh`N400ol0
003o_KSDokfhe00;okfhe0;o00003_nm^=@00ol0003o`;3;ol2`b`03ol2`b`03o`000?nm^=Co_KSD
00Go_KSD00?o0000ol2aboo0/L/02?o0/L/2o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/00ol0
003o`Z_3o`00000<ol2ab`03o`000?o2Zl?o`Z_300;o`Z_30_l00008ol2ab`03o`000?o2Zl?o`Z_3
00So`Z_300Go0000ol2aboo0/L_o`;7;o`00000<ol:[``;o00003_o2Zl<01Ol0003o`jNmol>W_Oo3
Ykgo000003cooooo1?l0000<ooooo`00E_ooool00ol0003oooooo`000009okS0h0?o000000?o[<_`
o`000?nh`N003Onh`N001?l0003o_KODokfge?nm]m@2o`0000Wo^<7Q00?o0000okfhe?nm^=@02?nm
^=@2o`000003okS1hOl0003o_KSD00go_KSD00Co0000ol2`boo0/<_o`;3;0_l00009okfhe003o`00
0?o0/L_o`;7;00Go`;7;0_l00005okfhe003o`000?o0/L_o`;7;00_o`;7;0_l0000>ol2ab`04o`00
0?o2Zl?o`Z_3o`0000_o`;7;00?o0000ol:[`oo2Zl<01Oo2Zl<2o`0000Co`;7;00?o0000ol:[`oo2
Zl<02Oo2Zl<00ol0003o`;7;o`00000>ol:[``04o`000?o3Ykgo`jNmo`0003Wooooo1?l0000@oooo
o`00Eoooool00ol0003oooooo`000005okS0h0?o00001On/bo000ol0003o^<7PokS1h00<okS1h003
o`000?nm]mCo000000_o^<7Q00?o0000okfhe?nm^=@01Onm^=@3o`0000Co^<7Q00?o0000okfhe?nm
^=@03?nm^=@00ol0003o`;3;o`00000<okfhe003o`000?o0/L_o`;7;00?o`;7;00?o0000okfhe?nm
^=@01_nm^=@00ol0003o`;7;ol2ab`09ol2ab`03o`000?nm^=Co000000ko`;7;00?o0000ol:[`ol0
00003?o0/L/00ol0003o`Z_3ol:[``04ol:[``03o`000?o0/L_o`;7;00Go`;7;00?o0000ol:[`oo2
Zl<01oo2Zl<01Ol0003o`;7;ol2aboo0/L_o000000go`Z_300?o0000ol>W_Ol00000=_ooool4o`00
01Cooooo001Hooooo`?o000000Co^<3Po`000?l0003o00002On/bo000ol0003o^<7PokS1h00;okS1
h0;o00003Onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N400ol0003o_KSDokfhe00;okfh
e0;o00003Onm^=@01?l0003o`;7;ol2aboo0/L/2o`0000Wo_KSD00?o0000ol2aboo0/L/01oo0/L/2
o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0000go`;7;00?o0000ol:[`oo2Zl<00_o2Zl<2
o`0000So`;7;00?o0000ol:[`oo2Zl<01_o2Zl<00ol0003o`;7;ol2ab`02ol2ab`03o`000?o2Zl?o
`Z_300_o`Z_30_l0000dooooo`?o00006?ooool005[ooooo0ol0000<ojc;l003o`000?nh`N3o^<7P
00Oo^<7P0ol00002ojc;l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000okfhe?l0003o00002onh`N40
0ol0003o_KSDokfhe008okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;o`00000<
okfhe003o`000?o0/L_o`;7;00Co`;7;0_l00005okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000
okfhe?l000003_o0/L/01?l0003o`Z_3ol:[`ol0000;ol2ab`03o`000?o2Zl?o`Z_300?o`Z_30_l0
0006ol2ab`03o`000?o2Zl?o`Z_300Wo`Z_300?o0000ooooooooool0<?ooool4o`0001_ooooo001K
ooooo`03o`000?oooooo000000co[<_`00?o0000okS1h?nh`N000onh`N03o`0000Ko[<_`00?o0000
okS1hOnh`N402_nh`N42o`0000go^<7Q00?o0000okfhe?nm^=@01Onm^=@3o`0000Co^<7Q00?o0000
okfhe?nm^=@02onm^=@2o`0000go_KSD00?o0000ol2aboo0/L/00oo0/L/00ol0003o_KSDokfhe006
okfhe003o`000?o0/L_o`;7;00Oo`;7;0_l00003okfhe003o`000?o0/L_o`;7;00_o`;7;00?o0000
ol:[`ol000003?o0/L/00ol0003o`Z_3ol:[``02ol:[``03o`000?o0/L_o`;7;00Ko`;7;00?o0000
ol:[`oo2Zl<02?o2Zl<00ol0003oooooooooo`0]ooooo`Co00007oooool005cooooo00Co0000oooo
ool0003o00002on/bo000ol0003o^<7Po`000002o`0000[o[<_`00?o0000okS1hOnh`N401_nh`N43
o`0000;o[<c`00?o0000okS1hOnh`N402onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N40
0ol0003o_KSDokfhe008okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;ol2ab`02
o`0000[o_KSD00?o0000ol2aboo0/L/01?o0/L/2o`0000Go_KSD00?o0000ol2aboo0/L/02oo0/L/2
o`0000ko`;7;00Co0000ol:[`oo2Zl?o00002_o0/L/00ol0003o`Z_3ol:[``06ol:[``03o`000?oo
oooooooo02[ooooo1?l0000Sooooo`00GOooool2o`000003ooooool0003o[<_`00So[<_`1?l0000=
ojc;l003o`000?nh`N7o^<7Q00?o^<7Q0_l00006ojc<l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000
okfhe?l0003o00002onh`N400ol0003o_KSDokfhe004okfhe0?o00001?nh`N400ol0003o_KSDokfh
e00;okfhe003o`000?o0/L_o000000co_KSD00?o0000ol2aboo0/L/00oo0/L/00ol0003o_KSDokfh
e006okfhe003o`000?o0/L_o`;7;00Wo`;7;00?o0000okfhe?l000003_o0/L/00ol0003o`Z_3o`00
000<ol2ab`03o`000?o2Zl?o`Z_300?o`Z_30_l0000Yooooo`Co00009oooool005oooooo00?o0000
ooooool000000on/bo05o`0000CoT=?n0_l0000<ojc;l003o`000?nh`N7o000000;o00002On/c?00
0ol0003o^<7QokS1h@0:okS1h@;o00003Onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N40
0ol0003o_KSDokfhe00:okfhe0;o00003_nm^=@00ol0003o`;7;ol2ab`02o`0000Wo_KSD00?o0000
ol2aboo0/L/01oo0/L/2o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0000go`;7;00?o0000
ol:[`oo2Zl<00_o2Zl<00ol0003oooooooooo`0Uooooo`Co0000:oooool0063ooooo00?o0000oooo
ool000000_l0000;oi3CoP03o`000?n/bo3o[<_`00So[<_`1?l0000<ojc<l003o`000?nh`N7o^<7Q
00Ko^<7Q0ol00002ojc<l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000okfhe?l0003o00002onh`N40
0ol0003o_KSDokfhe007okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;o`00000<
okfhe003o`000?o0/L_o`;7;00Co`;7;0_l00005okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000
okfhe?l000003_o0/L/01?l0003o`Z_3ol:[`ol0000Tooooo`Co0000;oooool0067ooooo00?o0000
ooooooooool00ol0000:oi3CoP;o00000on/bo05o`0000CoT=?n00?o0000ojc<l?n/c?002_n/c?00
0ol0003o^<7QokS1h@03okS1h@;o00001_n/c?000ol0003o^<7QokS1h@0:okS1h@;o00003Onh`N40
0ol0003o_KSDokfhe005okfhe0;o00001?nh`N400ol0003o_KSDokfhe00;okfhe0;o00003Onm^=@0
0ol0003o`;7;ol2ab`03ol2ab`03o`000?nm^=Co_KSD00Ko_KSD00?o0000ol2aboo0/L/01oo0/L/2
o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/00ol0003o`Z_3o`00000Qooooo`Co0000<oooool0
06;ooooo0_l00003ooooo`;o00001On@doh8o`0000[oT=?n00?o0000ojc<l?n/c?002_n/c?000ol0
003o^<7Qo`000002o`0000Wo[<c`00?o0000okS1hOnh`N401_nh`N43o`0000;o[<c`00?o0000okS1
hOnh`N402onh`N400ol0003o_KSDokfhe002okfhe0;o00001onh`N400ol0003o_KSDokfhe008okfh
e0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;ol2ab`02o`0000[o_KSD00?o0000ol2a
boo0/L/01?o0/L/2o`0000Go_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0001kooooo1?l0000goooo
o`00I?ooool00ol0003oooooooooo`02ooooo`Go00001om<`o83o`0000WoT=?n00?o0000ojc<l?n/
c?001on/c?05o`0000co[<c`00?o0000okS1hOnh`N400onh`N42o`0000Ko[<c`00?o0000okS1hOnh
`N402onh`N401?l0003o_KSDo`000?l0000:okS1h@03o`000?nm^=Co_KSD00Go_KSD0_l00004okS1
h@03o`000?nm^=Co_KSD00_o_KSD00?o0000ol2abol000003?nm^=@00ol0003o`;7;ol2ab`03ol2a
b`03o`000?nm^=Co_KSD00Ko_KSD00?o0000ol2aboo0/L/02?o0/L/2o`0001gooooo0ol0000koooo
o`00IOooool00ol0003oooooooooo`04ooooo`?o00002Om<`o82o`0000SoT=?n00Co0000ojc<l?n/
c?3o[<c`1Ol00005ohoCoP03o`000?n/c?3o[<c`00[o[<c`00?o0000okS1hOl000000_l00009ojc<
l003o`000?nh`N7o^<7Q00Wo^<7Q0ol0000=okS1h@03o`000?nm^=Co_KSD00;o_KSD0_l00007okS1
h@03o`000?nm^=Co_KSD00[o_KSD0_l0000>okfhe003o`000?o0/L_o`;7;00;o00002_nm^=@00ol0
003o`;7;ol2ab`05ol2ab`;o00006oooool4o`0003kooooo001Vooooo`03o`000?oooooooooo00Ko
oooo5ol0000;ohoCoP;o00002On/c?04o`0000co[<c`00?o0000okS1hOnh`N401?nh`N44o`0000;o
[<c`00?o0000okS1hOnh`N403?nh`N401?l0003o_KSDo`000?l0000:okS1h@03o`000?nm^=Co_KSD
00Oo_KSD0_l000000onh`N7o0000okfhe00=okfhe003o`000?o0/L_o000000co_KSD00?o0000ol2a
boo0/L/01?o0/L/00ol0003oooooooooo`0Gooooo`Co0000@_ooool006Oooooo0_l0000Aooooo`Ko
00001Om;`o43o`0000_oSm?n00Co0000ojc<l?n/c?3o[<c`1Ol00004ohoDoP03o`000?n/c?3o[<c`
00[o[<c`00?o0000okS1hOnh`N400ol00007ojc<l003o`000?nh`N7o^<7Q00_o^<7Q0_l0000<okS1
h@03o`000?nm^=Co_KSD00Go_KSD0_l00004okS1h@03o`000?nm^=Co_KSD00_o_KSD0_l0000>okfh
e004o`000?o0/L_o`;7;ol2ab`;o00005_ooool4o`0004Kooooo001Yooooo`03o`000?oooooooooo
01?ooooo1ol00002od_3l@;o00001On?doh8o`0000[oSmCn00?o0000ojc<l?n/c?002?n/c?04o`00
00_o[<c`00?o0000okS1hOnh`N401onh`N43o`000003ojc<lOl0003o^<7Q00co^<7Q00?o0000okfh
e?nm^=@00_nm^=@2o`0000Oo^<7Q00?o0000okfhe?nm^=@02?nm^=@2o`000003okS1hOl0003o_KSD
00go_KSD00Co0000ol2abol0003o00005?ooool4o`0004[ooooo001Zooooo`03o`000?oooooooooo
01Wooooo2Ol00007od_2l@;o00002_n?e?h00ol0003o[<c`ojc<l004ojc<l0?o00001?n?e?h00ol0
003o[<c`ojc<l009ojc<l003o`000?nh`N7o^<7Q00?o^<7Q0ol00005ojc<l@03o`000?nh`N7o^<7Q
00_o^<7Q00Co0000okfhe?l0003o00002_nh`N400ol0003o_KSDokfhe005okfhe0;o00001?nh`N40
0ol0003o_KSDokfhe00;okfhe0;o00004_ooool4o`0004kooooo001[ooooo`03o`000?oooooooooo
023ooooo2?l00002od_2l@;o00002On?e?h00ol0003o[<c`ojc<l003o`0000SoSmCn00?o0000ojc<
l?n/c?002On/c?000ol0003o^<7Qo`000002o`0000Wo[<ca00?o0000okS1hOnh`N402Onh`N43o`00
00go^<7Q00?o0000okfhe?nm^=@00_nm^=@2o`0000Oo^<7Q00?o0000okfhe?nm^=@02?nm^=@2o`00
013ooooo1?l0001Booooo`00K?ooool2o`0002Oooooo4Ol0000<ohoDoP03o`000?n/c?3o[<c`00Oo
[<c`1?l0000<ojc<l@03o`000?nh`N7o^<7Q00Co^<7Q1?l00002ojc<l@03o`000?nh`N7o^<7Q00co
^<7Q00Co0000okfhe?l0003o00002_nh`N400ol0003o_KSDokfhe004okfhe0?o00003_ooool4o`00
05Kooooo001^ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool4o`0000Ko
BL;`0_l0000;ohoDoP04o`000?n/c?3o[<c`ojc<l0Go00001?n>e?h00ol0003o[<caojc<l@0:ojc<
l@03o`000?nh`N7o^<7Q00?o00001on/c?400ol0003o^<7QokS1h@0;okS1h@;o00003?nh`N400ol0
003o_KSDokfhe002okfhe0;o00003Oooool4o`0005[ooooo001_ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01oooool7o`0000;oBL;`0_l00005ohoDoPSo00002_n>e?h2o`0000Wo
[<ca1?l0000;ojc<l@03o`000?nh`N7o^<7Q00Oo^<7Q0ol000000on/c?7o0000okS1h@0<okS1h@04
o`000?nm^=Co0000o`0000cooooo0ol0001Nooooo`00L?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00kooooo2Ol00007odS1l0;o00002on>e?h01?l0003o[<caojc<lOn/c?45o`00
00CoS]Co00?o0000ojc<lOn/c?402On/c?400ol0003o^<7QokS1h@03okS1h@?o00001On/c?400ol0
003o^<7QokS1h@0:okS1h@;o00002_ooool4o`00067ooooo001aooooo`;o00008_ooool00ol0003o
ooooooooo`0Fooooo`So00000_m8`O02o`0000GoS]Cn2?l0000:ohkDo`03o`000?n/c?7o[<ca00Wo
[<ca00?o0000okS1hOl000000_l00009ojc<l@03o`000?nh`N7o^<7Q00Ko^<7Q0ol00008ooooo`Co
0000IOooool007?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`Wo0000
1om7`Nl2o`0000[oS]Co00?o0000ojc<lOn/c?401on/c?44o`0000co[<ca00?o0000okS1hOnh`N40
0onh`N42o`0000Oooooo1?l0001Yooooo`00M?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo1ol00003odO1k`03o`000?n>e?ooS]Co00SoS]Co00Co0000ojc<lOn/c?7o[<ca
1Ol00004ohkDo`03o`000?n/c?7o[<ca00[o[<ca00?o0000okS1hOl000000_l00005ooooo`Co0000
KOooool007Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]oooooa;o00002_n>
e?l00ol0003o[<caojc<l@07ojc<l@Co00001?ooool4o`00077ooooo001fooooo`;o00007Oooool0
0ol0003oooooooooo`0cooooo`Co00001om6`>l2o`0000[oS]Co00Co0000ojc<lOn/c?7o[<ca1Ol0
0004ooooo`Co0000MOooool007Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0f
ooooo`Oo00000om6`>l00ol0003oS]CoohkDo`03ohkDo`So00001Oooool4o`0007Wooooo001ioooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?Oooool9o`0000[ooooo0ol0001moooo
o`00N_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo1?l00020ooooo`00
Noooool2o`0001Sooooo00?o0000ooooooooool0B?ooool4o`0008Cooooo001mooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0A?ooool4o`0008Sooooo001nooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0@?ooool4o`0008cooooo001oooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0?Oooool4o`00093ooooo0020ooooo`;o00004_ooool00ol0003o
ooooooooo`0iooooo`Co0000U?ooool008;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0eooooo`Co0000V?ooool008?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0aooooo`Co0000W?ooool008Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^
ooooo`?o0000X?ooool008Gooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Soooo
o`00Qoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Wooooo`00
R?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002[ooooo`00ROoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002_ooooo`00R_ooool2
o`0000Sooooo00?o0000ooooooooool06_ooool4o`000;?ooooo002<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05_ooool4o`000;Oooooo002=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool4o`000;_ooooo002>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03_ooool4o`000;oooooo002?ooooo`;o00000oooool00ol0003ooooooooo
o`0;ooooo`?o0000`oooool0097ooooo00Co0000oooooooooooo00002Oooool4o`000<Kooooo002B
ooooo`03o`000?oooooo000000Gooooo1?l0003:ooooo`00Toooool2o`000003ooooool0003o0000
00;o0000c_ooool009Cooooo0_l0003Booooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0418495, 0.0166322, \
0.00355091, 0.00355091}}]
}, Open  ]],

Cell[TextData[{
  "The potential is minimized along the diagonal where the density is \
maximum, but also goes to zero at the box vertices due to the periodic \
boundary conditions: the mass distribution in surrounding boxes affects the \
potential. In Cell ",
  ButtonBox["7.73",
    ButtonData:>"Cell 7.73",
    ButtonStyle->"Hyperlink"],
  ", we show the resulting force field, evaluated on the grid."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(field\  = \ 
        Table[{{i\ \[CapitalDelta]x, 
              j\ \[CapitalDelta]y}, {\(Fx[\([i + 1, 
                      j + 1]\)]\)[\([3]\)], \(Fy[\([i + 1, 
                      j + 1]\)]\)[\([3]\)]} 0.001}, {i, 0, M - 1}, {j, 0, 
            M - 1}];\)\), "\n", 
    \(\(ListPlotVectorField[Flatten[field, 1], 
        Axes \[Rule] True];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.73"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0744689 0.895855 0.0744689 0.895855 [
[.25364 .06197 -9 -9 ]
[.25364 .06197 9 0 ]
[.43281 .06197 -9 -9 ]
[.43281 .06197 9 0 ]
[.61198 .06197 -9 -9 ]
[.61198 .06197 9 0 ]
[.79115 .06197 -9 -9 ]
[.79115 .06197 9 0 ]
[.97032 .06197 -3 -9 ]
[.97032 .06197 3 0 ]
[.06197 .25364 -18 -4.5 ]
[.06197 .25364 0 4.5 ]
[.06197 .43281 -18 -4.5 ]
[.06197 .43281 0 4.5 ]
[.06197 .61198 -18 -4.5 ]
[.06197 .61198 0 4.5 ]
[.06197 .79115 -18 -4.5 ]
[.06197 .79115 0 4.5 ]
[.06197 .97032 -6 -4.5 ]
[.06197 .97032 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25364 .07447 m
.25364 .08072 L
s
[(0.2)] .25364 .06197 0 1 Mshowa
.43281 .07447 m
.43281 .08072 L
s
[(0.4)] .43281 .06197 0 1 Mshowa
.61198 .07447 m
.61198 .08072 L
s
[(0.6)] .61198 .06197 0 1 Mshowa
.79115 .07447 m
.79115 .08072 L
s
[(0.8)] .79115 .06197 0 1 Mshowa
.97032 .07447 m
.97032 .08072 L
s
[(1)] .97032 .06197 0 1 Mshowa
.125 Mabswid
.11926 .07447 m
.11926 .07822 L
s
.16405 .07447 m
.16405 .07822 L
s
.20885 .07447 m
.20885 .07822 L
s
.29843 .07447 m
.29843 .07822 L
s
.34323 .07447 m
.34323 .07822 L
s
.38802 .07447 m
.38802 .07822 L
s
.4776 .07447 m
.4776 .07822 L
s
.5224 .07447 m
.5224 .07822 L
s
.56719 .07447 m
.56719 .07822 L
s
.65677 .07447 m
.65677 .07822 L
s
.70157 .07447 m
.70157 .07822 L
s
.74636 .07447 m
.74636 .07822 L
s
.83595 .07447 m
.83595 .07822 L
s
.88074 .07447 m
.88074 .07822 L
s
.92553 .07447 m
.92553 .07822 L
s
.02968 .07447 m
.02968 .07822 L
s
.25 Mabswid
0 .07447 m
1 .07447 L
s
.07447 .25364 m
.08072 .25364 L
s
[(0.2)] .06197 .25364 1 0 Mshowa
.07447 .43281 m
.08072 .43281 L
s
[(0.4)] .06197 .43281 1 0 Mshowa
.07447 .61198 m
.08072 .61198 L
s
[(0.6)] .06197 .61198 1 0 Mshowa
.07447 .79115 m
.08072 .79115 L
s
[(0.8)] .06197 .79115 1 0 Mshowa
.07447 .97032 m
.08072 .97032 L
s
[(1)] .06197 .97032 1 0 Mshowa
.125 Mabswid
.07447 .11926 m
.07822 .11926 L
s
.07447 .16405 m
.07822 .16405 L
s
.07447 .20885 m
.07822 .20885 L
s
.07447 .29843 m
.07822 .29843 L
s
.07447 .34323 m
.07822 .34323 L
s
.07447 .38802 m
.07822 .38802 L
s
.07447 .4776 m
.07822 .4776 L
s
.07447 .5224 m
.07822 .5224 L
s
.07447 .56719 m
.07822 .56719 L
s
.07447 .65677 m
.07822 .65677 L
s
.07447 .70157 m
.07822 .70157 L
s
.07447 .74636 m
.07822 .74636 L
s
.07447 .83595 m
.07822 .83595 L
s
.07447 .88074 m
.07822 .88074 L
s
.07447 .92553 m
.07822 .92553 L
s
.07447 .02968 m
.07822 .02968 L
s
.25 Mabswid
.07447 0 m
.07447 1 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.07447 .07447 m
.07447 .07447 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.07447 .11926 m
.12513 .0686 L
s
% Start of user PostScript
0 0.05 0.0565487 -0.00654867 MAarrowhead1
% End of user PostScript
.07447 .16405 m
.1195 .11902 L
s
% Start of user PostScript
0 0.1 0.0502655 0.0497345 MAarrowhead1
% End of user PostScript
.07447 .20885 m
.11387 .16945 L
s
% Start of user PostScript
0 0.15 0.0439823 0.106018 MAarrowhead1
% End of user PostScript
.07447 .25364 m
.10824 .21987 L
s
% Start of user PostScript
0 0.2 0.0376991 0.162301 MAarrowhead1
% End of user PostScript
.07447 .29843 m
.10261 .27029 L
s
% Start of user PostScript
0 0.25 0.0314159 0.218584 MAarrowhead1
% End of user PostScript
.07447 .34323 m
.09698 .32071 L
s
% Start of user PostScript
0 0.3 0.0251327 0.274867 MAarrowhead1
% End of user PostScript
.07447 .38802 m
.09136 .37113 L
s
% Start of user PostScript
0 0.35 0.0188496 0.33115 MAarrowhead1
% End of user PostScript
.07447 .43281 m
.08573 .42155 L
s
% Start of user PostScript
0 0.4 0.0125664 0.387434 MAarrowhead1
% End of user PostScript
.07447 .4776 m
.0801 .47197 L
s
% Start of user PostScript
0 0.45 0.00628319 0.443717 MAarrowhead1
% End of user PostScript
.07447 .5224 m
.07447 .5224 L
s
% Start of user PostScript
0 0.5 MAarrowzero1
% End of user PostScript
.07447 .56719 m
.06884 .57282 L
s
% Start of user PostScript
0 0.55 -0.00628319 0.556283 MAarrowhead1
% End of user PostScript
.07447 .61198 m
.06321 .62324 L
s
% Start of user PostScript
0 0.6 -0.0125664 0.612566 MAarrowhead1
% End of user PostScript
.07447 .65677 m
.05758 .67366 L
s
% Start of user PostScript
0 0.65 -0.0188496 0.66885 MAarrowhead1
% End of user PostScript
.07447 .70157 m
.05195 .72408 L
s
% Start of user PostScript
0 0.7 -0.0251327 0.725133 MAarrowhead1
% End of user PostScript
.07447 .74636 m
.04632 .7745 L
s
% Start of user PostScript
0 0.75 -0.0314159 0.781416 MAarrowhead1
% End of user PostScript
.07447 .79115 m
.0407 .82493 L
s
% Start of user PostScript
0 0.8 -0.0376991 0.837699 MAarrowhead1
% End of user PostScript
.07447 .83595 m
.03507 .87535 L
s
% Start of user PostScript
0 0.85 -0.0439823 0.893982 MAarrowhead1
% End of user PostScript
.07447 .88074 m
.02944 .92577 L
s
% Start of user PostScript
0 0.9 -0.0502655 0.950265 MAarrowhead1
% End of user PostScript
.07447 .92553 m
.02381 .97619 L
s
% Start of user PostScript
0 0.95 -0.0565487 1.00655 MAarrowhead1
% End of user PostScript
.11926 .07447 m
.0686 .12513 L
s
% Start of user PostScript
0.05 0 -0.00654867 0.0565487 MAarrowhead1
% End of user PostScript
.11926 .11926 m
.11926 .11926 L
s
% Start of user PostScript
0.05 0.05 MAarrowzero1
% End of user PostScript
.11926 .16405 m
.16992 .1134 L
s
% Start of user PostScript
0.05 0.1 0.106549 0.0434513 MAarrowhead1
% End of user PostScript
.11926 .20885 m
.16429 .16382 L
s
% Start of user PostScript
0.05 0.15 0.100265 0.0997345 MAarrowhead1
% End of user PostScript
.11926 .25364 m
.15866 .21424 L
s
% Start of user PostScript
0.05 0.2 0.0939823 0.156018 MAarrowhead1
% End of user PostScript
.11926 .29843 m
.15303 .26466 L
s
% Start of user PostScript
0.05 0.25 0.0876991 0.212301 MAarrowhead1
% End of user PostScript
.11926 .34323 m
.14741 .31508 L
s
% Start of user PostScript
0.05 0.3 0.0814159 0.268584 MAarrowhead1
% End of user PostScript
.11926 .38802 m
.14178 .3655 L
s
% Start of user PostScript
0.05 0.35 0.0751327 0.324867 MAarrowhead1
% End of user PostScript
.11926 .43281 m
.13615 .41592 L
s
% Start of user PostScript
0.05 0.4 0.0688496 0.38115 MAarrowhead1
% End of user PostScript
.11926 .4776 m
.13052 .46635 L
s
% Start of user PostScript
0.05 0.45 0.0625664 0.437434 MAarrowhead1
% End of user PostScript
.11926 .5224 m
.12489 .51677 L
s
% Start of user PostScript
0.05 0.5 0.0562832 0.493717 MAarrowhead1
% End of user PostScript
.11926 .56719 m
.11926 .56719 L
s
% Start of user PostScript
0.05 0.55 MAarrowzero1
% End of user PostScript
.11926 .61198 m
.11363 .61761 L
s
% Start of user PostScript
0.05 0.6 0.0437168 0.606283 MAarrowhead1
% End of user PostScript
.11926 .65677 m
.108 .66803 L
s
% Start of user PostScript
0.05 0.65 0.0374336 0.662566 MAarrowhead1
% End of user PostScript
.11926 .70157 m
.10238 .71845 L
s
% Start of user PostScript
0.05 0.7 0.0311504 0.71885 MAarrowhead1
% End of user PostScript
.11926 .74636 m
.09675 .76888 L
s
% Start of user PostScript
0.05 0.75 0.0248673 0.775133 MAarrowhead1
% End of user PostScript
.11926 .79115 m
.09112 .8193 L
s
% Start of user PostScript
0.05 0.8 0.0185841 0.831416 MAarrowhead1
% End of user PostScript
.11926 .83595 m
.08549 .86972 L
s
% Start of user PostScript
0.05 0.85 0.0123009 0.887699 MAarrowhead1
% End of user PostScript
.11926 .88074 m
.07986 .92014 L
s
% Start of user PostScript
0.05 0.9 0.0060177 0.943982 MAarrowhead1
% End of user PostScript
.11926 .92553 m
.07423 .97056 L
s
% Start of user PostScript
0.05 0.95 -0.000265482 1.00027 MAarrowhead1
% End of user PostScript
.16405 .07447 m
.11902 .1195 L
s
% Start of user PostScript
0.1 0 0.0497345 0.0502655 MAarrowhead1
% End of user PostScript
.16405 .11926 m
.1134 .16992 L
s
% Start of user PostScript
0.1 0.05 0.0434513 0.106549 MAarrowhead1
% End of user PostScript
.16405 .16405 m
.16405 .16405 L
s
% Start of user PostScript
0.1 0.1 MAarrowzero1
% End of user PostScript
.16405 .20885 m
.21471 .15819 L
s
% Start of user PostScript
0.1 0.15 0.156549 0.0934513 MAarrowhead1
% End of user PostScript
.16405 .25364 m
.20908 .20861 L
s
% Start of user PostScript
0.1 0.2 0.150265 0.149735 MAarrowhead1
% End of user PostScript
.16405 .29843 m
.20346 .25903 L
s
% Start of user PostScript
0.1 0.25 0.143982 0.206018 MAarrowhead1
% End of user PostScript
.16405 .34323 m
.19783 .30945 L
s
% Start of user PostScript
0.1 0.3 0.137699 0.262301 MAarrowhead1
% End of user PostScript
.16405 .38802 m
.1922 .35987 L
s
% Start of user PostScript
0.1 0.35 0.131416 0.318584 MAarrowhead1
% End of user PostScript
.16405 .43281 m
.18657 .4103 L
s
% Start of user PostScript
0.1 0.4 0.125133 0.374867 MAarrowhead1
% End of user PostScript
.16405 .4776 m
.18094 .46072 L
s
% Start of user PostScript
0.1 0.45 0.11885 0.43115 MAarrowhead1
% End of user PostScript
.16405 .5224 m
.17531 .51114 L
s
% Start of user PostScript
0.1 0.5 0.112566 0.487434 MAarrowhead1
% End of user PostScript
.16405 .56719 m
.16968 .56156 L
s
% Start of user PostScript
0.1 0.55 0.106283 0.543717 MAarrowhead1
% End of user PostScript
.16405 .61198 m
.16405 .61198 L
s
% Start of user PostScript
0.1 0.6 MAarrowzero1
% End of user PostScript
.16405 .65677 m
.15843 .6624 L
s
% Start of user PostScript
0.1 0.65 0.0937168 0.656283 MAarrowhead1
% End of user PostScript
.16405 .70157 m
.1528 .71282 L
s
% Start of user PostScript
0.1 0.7 0.0874336 0.712566 MAarrowhead1
% End of user PostScript
.16405 .74636 m
.14717 .76325 L
s
% Start of user PostScript
0.1 0.75 0.0811504 0.76885 MAarrowhead1
% End of user PostScript
.16405 .79115 m
.14154 .81367 L
s
% Start of user PostScript
0.1 0.8 0.0748673 0.825133 MAarrowhead1
% End of user PostScript
.16405 .83595 m
.13591 .86409 L
s
% Start of user PostScript
0.1 0.85 0.0685841 0.881416 MAarrowhead1
% End of user PostScript
.16405 .88074 m
.13028 .91451 L
s
% Start of user PostScript
0.1 0.9 0.0623009 0.937699 MAarrowhead1
% End of user PostScript
.16405 .92553 m
.12465 .96493 L
s
% Start of user PostScript
0.1 0.95 0.0560177 0.993982 MAarrowhead1
% End of user PostScript
.20885 .07447 m
.16945 .11387 L
s
% Start of user PostScript
0.15 0 0.106018 0.0439823 MAarrowhead1
% End of user PostScript
.20885 .11926 m
.16382 .16429 L
s
% Start of user PostScript
0.15 0.05 0.0997345 0.100265 MAarrowhead1
% End of user PostScript
.20885 .16405 m
.15819 .21471 L
s
% Start of user PostScript
0.15 0.1 0.0934513 0.156549 MAarrowhead1
% End of user PostScript
.20885 .20885 m
.20885 .20885 L
s
% Start of user PostScript
0.15 0.15 MAarrowzero1
% End of user PostScript
.20885 .25364 m
.25951 .20298 L
s
% Start of user PostScript
0.15 0.2 0.206549 0.143451 MAarrowhead1
% End of user PostScript
.20885 .29843 m
.25388 .2534 L
s
% Start of user PostScript
0.15 0.25 0.200265 0.199735 MAarrowhead1
% End of user PostScript
.20885 .34323 m
.24825 .30382 L
s
% Start of user PostScript
0.15 0.3 0.193982 0.256018 MAarrowhead1
% End of user PostScript
.20885 .38802 m
.24262 .35425 L
s
% Start of user PostScript
0.15 0.35 0.187699 0.312301 MAarrowhead1
% End of user PostScript
.20885 .43281 m
.23699 .40467 L
s
% Start of user PostScript
0.15 0.4 0.181416 0.368584 MAarrowhead1
% End of user PostScript
.20885 .4776 m
.23136 .45509 L
s
% Start of user PostScript
0.15 0.45 0.175133 0.424867 MAarrowhead1
% End of user PostScript
.20885 .5224 m
.22573 .50551 L
s
% Start of user PostScript
0.15 0.5 0.16885 0.48115 MAarrowhead1
% End of user PostScript
.20885 .56719 m
.2201 .55593 L
s
% Start of user PostScript
0.15 0.55 0.162566 0.537434 MAarrowhead1
% End of user PostScript
.20885 .61198 m
.21448 .60635 L
s
% Start of user PostScript
0.15 0.6 0.156283 0.593717 MAarrowhead1
% End of user PostScript
.20885 .65677 m
.20885 .65677 L
s
% Start of user PostScript
0.15 0.65 MAarrowzero1
% End of user PostScript
.20885 .70157 m
.20322 .7072 L
s
% Start of user PostScript
0.15 0.7 0.143717 0.706283 MAarrowhead1
% End of user PostScript
.20885 .74636 m
.19759 .75762 L
s
% Start of user PostScript
0.15 0.75 0.137434 0.762566 MAarrowhead1
% End of user PostScript
.20885 .79115 m
.19196 .80804 L
s
% Start of user PostScript
0.15 0.8 0.13115 0.81885 MAarrowhead1
% End of user PostScript
.20885 .83595 m
.18633 .85846 L
s
% Start of user PostScript
0.15 0.85 0.124867 0.875133 MAarrowhead1
% End of user PostScript
.20885 .88074 m
.1807 .90888 L
s
% Start of user PostScript
0.15 0.9 0.118584 0.931416 MAarrowhead1
% End of user PostScript
.20885 .92553 m
.17507 .9593 L
s
% Start of user PostScript
0.15 0.95 0.112301 0.987699 MAarrowhead1
% End of user PostScript
.25364 .07447 m
.21987 .10824 L
s
% Start of user PostScript
0.2 0 0.162301 0.0376991 MAarrowhead1
% End of user PostScript
.25364 .11926 m
.21424 .15866 L
s
% Start of user PostScript
0.2 0.05 0.156018 0.0939823 MAarrowhead1
% End of user PostScript
.25364 .16405 m
.20861 .20908 L
s
% Start of user PostScript
0.2 0.1 0.149735 0.150265 MAarrowhead1
% End of user PostScript
.25364 .20885 m
.20298 .25951 L
s
% Start of user PostScript
0.2 0.15 0.143451 0.206549 MAarrowhead1
% End of user PostScript
.25364 .25364 m
.25364 .25364 L
s
% Start of user PostScript
0.2 0.2 MAarrowzero1
% End of user PostScript
.25364 .29843 m
.3043 .24777 L
s
% Start of user PostScript
0.2 0.25 0.256549 0.193451 MAarrowhead1
% End of user PostScript
.25364 .34323 m
.29867 .29819 L
s
% Start of user PostScript
0.2 0.3 0.250265 0.249735 MAarrowhead1
% End of user PostScript
.25364 .38802 m
.29304 .34862 L
s
% Start of user PostScript
0.2 0.35 0.243982 0.306018 MAarrowhead1
% End of user PostScript
.25364 .43281 m
.28741 .39904 L
s
% Start of user PostScript
0.2 0.4 0.237699 0.362301 MAarrowhead1
% End of user PostScript
.25364 .4776 m
.28178 .44946 L
s
% Start of user PostScript
0.2 0.45 0.231416 0.418584 MAarrowhead1
% End of user PostScript
.25364 .5224 m
.27616 .49988 L
s
% Start of user PostScript
0.2 0.5 0.225133 0.474867 MAarrowhead1
% End of user PostScript
.25364 .56719 m
.27053 .5503 L
s
% Start of user PostScript
0.2 0.55 0.21885 0.53115 MAarrowhead1
% End of user PostScript
.25364 .61198 m
.2649 .60072 L
s
% Start of user PostScript
0.2 0.6 0.212566 0.587434 MAarrowhead1
% End of user PostScript
.25364 .65677 m
.25927 .65115 L
s
% Start of user PostScript
0.2 0.65 0.206283 0.643717 MAarrowhead1
% End of user PostScript
.25364 .70157 m
.25364 .70157 L
s
% Start of user PostScript
0.2 0.7 MAarrowzero1
% End of user PostScript
.25364 .74636 m
.24801 .75199 L
s
% Start of user PostScript
0.2 0.75 0.193717 0.756283 MAarrowhead1
% End of user PostScript
.25364 .79115 m
.24238 .80241 L
s
% Start of user PostScript
0.2 0.8 0.187434 0.812566 MAarrowhead1
% End of user PostScript
.25364 .83595 m
.23675 .85283 L
s
% Start of user PostScript
0.2 0.85 0.18115 0.86885 MAarrowhead1
% End of user PostScript
.25364 .88074 m
.23112 .90325 L
s
% Start of user PostScript
0.2 0.9 0.174867 0.925133 MAarrowhead1
% End of user PostScript
.25364 .92553 m
.2255 .95368 L
s
% Start of user PostScript
0.2 0.95 0.168584 0.981416 MAarrowhead1
% End of user PostScript
.29843 .07447 m
.27029 .10261 L
s
% Start of user PostScript
0.25 0 0.218584 0.0314159 MAarrowhead1
% End of user PostScript
.29843 .11926 m
.26466 .15303 L
s
% Start of user PostScript
0.25 0.05 0.212301 0.0876991 MAarrowhead1
% End of user PostScript
.29843 .16405 m
.25903 .20346 L
s
% Start of user PostScript
0.25 0.1 0.206018 0.143982 MAarrowhead1
% End of user PostScript
.29843 .20885 m
.2534 .25388 L
s
% Start of user PostScript
0.25 0.15 0.199735 0.200265 MAarrowhead1
% End of user PostScript
.29843 .25364 m
.24777 .3043 L
s
% Start of user PostScript
0.25 0.2 0.193451 0.256549 MAarrowhead1
% End of user PostScript
.29843 .29843 m
.29843 .29843 L
s
% Start of user PostScript
0.25 0.25 MAarrowzero1
% End of user PostScript
.29843 .34323 m
.34909 .29257 L
s
% Start of user PostScript
0.25 0.3 0.306549 0.243451 MAarrowhead1
% End of user PostScript
.29843 .38802 m
.34346 .34299 L
s
% Start of user PostScript
0.25 0.35 0.300265 0.299735 MAarrowhead1
% End of user PostScript
.29843 .43281 m
.33783 .39341 L
s
% Start of user PostScript
0.25 0.4 0.293982 0.356018 MAarrowhead1
% End of user PostScript
.29843 .4776 m
.33221 .44383 L
s
% Start of user PostScript
0.25 0.45 0.287699 0.412301 MAarrowhead1
% End of user PostScript
.29843 .5224 m
.32658 .49425 L
s
% Start of user PostScript
0.25 0.5 0.281416 0.468584 MAarrowhead1
% End of user PostScript
.29843 .56719 m
.32095 .54467 L
s
% Start of user PostScript
0.25 0.55 0.275133 0.524867 MAarrowhead1
% End of user PostScript
.29843 .61198 m
.31532 .5951 L
s
% Start of user PostScript
0.25 0.6 0.26885 0.58115 MAarrowhead1
% End of user PostScript
.29843 .65677 m
.30969 .64552 L
s
% Start of user PostScript
0.25 0.65 0.262566 0.637434 MAarrowhead1
% End of user PostScript
.29843 .70157 m
.30406 .69594 L
s
% Start of user PostScript
0.25 0.7 0.256283 0.693717 MAarrowhead1
% End of user PostScript
.29843 .74636 m
.29843 .74636 L
s
% Start of user PostScript
0.25 0.75 MAarrowzero1
% End of user PostScript
.29843 .79115 m
.2928 .79678 L
s
% Start of user PostScript
0.25 0.8 0.243717 0.806283 MAarrowhead1
% End of user PostScript
.29843 .83595 m
.28718 .8472 L
s
% Start of user PostScript
0.25 0.85 0.237434 0.862566 MAarrowhead1
% End of user PostScript
.29843 .88074 m
.28155 .89762 L
s
% Start of user PostScript
0.25 0.9 0.23115 0.91885 MAarrowhead1
% End of user PostScript
.29843 .92553 m
.27592 .94805 L
s
% Start of user PostScript
0.25 0.95 0.224867 0.975133 MAarrowhead1
% End of user PostScript
.34323 .07447 m
.32071 .09698 L
s
% Start of user PostScript
0.3 0 0.274867 0.0251327 MAarrowhead1
% End of user PostScript
.34323 .11926 m
.31508 .14741 L
s
% Start of user PostScript
0.3 0.05 0.268584 0.0814159 MAarrowhead1
% End of user PostScript
.34323 .16405 m
.30945 .19783 L
s
% Start of user PostScript
0.3 0.1 0.262301 0.137699 MAarrowhead1
% End of user PostScript
.34323 .20885 m
.30382 .24825 L
s
% Start of user PostScript
0.3 0.15 0.256018 0.193982 MAarrowhead1
% End of user PostScript
.34323 .25364 m
.29819 .29867 L
s
% Start of user PostScript
0.3 0.2 0.249735 0.250265 MAarrowhead1
% End of user PostScript
.34323 .29843 m
.29257 .34909 L
s
% Start of user PostScript
0.3 0.25 0.243451 0.306549 MAarrowhead1
% End of user PostScript
.34323 .34323 m
.34323 .34323 L
s
% Start of user PostScript
0.3 0.3 MAarrowzero1
% End of user PostScript
.34323 .38802 m
.39388 .33736 L
s
% Start of user PostScript
0.3 0.35 0.356549 0.293451 MAarrowhead1
% End of user PostScript
.34323 .43281 m
.38826 .38778 L
s
% Start of user PostScript
0.3 0.4 0.350265 0.349735 MAarrowhead1
% End of user PostScript
.34323 .4776 m
.38263 .4382 L
s
% Start of user PostScript
0.3 0.45 0.343982 0.406018 MAarrowhead1
% End of user PostScript
.34323 .5224 m
.377 .48862 L
s
% Start of user PostScript
0.3 0.5 0.337699 0.462301 MAarrowhead1
% End of user PostScript
.34323 .56719 m
.37137 .53905 L
s
% Start of user PostScript
0.3 0.55 0.331416 0.518584 MAarrowhead1
% End of user PostScript
.34323 .61198 m
.36574 .58947 L
s
% Start of user PostScript
0.3 0.6 0.325133 0.574867 MAarrowhead1
% End of user PostScript
.34323 .65677 m
.36011 .63989 L
s
% Start of user PostScript
0.3 0.65 0.31885 0.63115 MAarrowhead1
% End of user PostScript
.34323 .70157 m
.35448 .69031 L
s
% Start of user PostScript
0.3 0.7 0.312566 0.687434 MAarrowhead1
% End of user PostScript
.34323 .74636 m
.34885 .74073 L
s
% Start of user PostScript
0.3 0.75 0.306283 0.743717 MAarrowhead1
% End of user PostScript
.34323 .79115 m
.34323 .79115 L
s
% Start of user PostScript
0.3 0.8 MAarrowzero1
% End of user PostScript
.34323 .83595 m
.3376 .84157 L
s
% Start of user PostScript
0.3 0.85 0.293717 0.856283 MAarrowhead1
% End of user PostScript
.34323 .88074 m
.33197 .892 L
s
% Start of user PostScript
0.3 0.9 0.287434 0.912566 MAarrowhead1
% End of user PostScript
.34323 .92553 m
.32634 .94242 L
s
% Start of user PostScript
0.3 0.95 0.28115 0.96885 MAarrowhead1
% End of user PostScript
.38802 .07447 m
.37113 .09136 L
s
% Start of user PostScript
0.35 0 0.33115 0.0188496 MAarrowhead1
% End of user PostScript
.38802 .11926 m
.3655 .14178 L
s
% Start of user PostScript
0.35 0.05 0.324867 0.0751327 MAarrowhead1
% End of user PostScript
.38802 .16405 m
.35987 .1922 L
s
% Start of user PostScript
0.35 0.1 0.318584 0.131416 MAarrowhead1
% End of user PostScript
.38802 .20885 m
.35425 .24262 L
s
% Start of user PostScript
0.35 0.15 0.312301 0.187699 MAarrowhead1
% End of user PostScript
.38802 .25364 m
.34862 .29304 L
s
% Start of user PostScript
0.35 0.2 0.306018 0.243982 MAarrowhead1
% End of user PostScript
.38802 .29843 m
.34299 .34346 L
s
% Start of user PostScript
0.35 0.25 0.299735 0.300265 MAarrowhead1
% End of user PostScript
.38802 .34323 m
.33736 .39388 L
s
% Start of user PostScript
0.35 0.3 0.293451 0.356549 MAarrowhead1
% End of user PostScript
.38802 .38802 m
.38802 .38802 L
s
% Start of user PostScript
0.35 0.35 MAarrowzero1
% End of user PostScript
.38802 .43281 m
.43868 .38215 L
s
% Start of user PostScript
0.35 0.4 0.406549 0.343451 MAarrowhead1
% End of user PostScript
.38802 .4776 m
.43305 .43257 L
s
% Start of user PostScript
0.35 0.45 0.400265 0.399735 MAarrowhead1
% End of user PostScript
.38802 .5224 m
.42742 .48299 L
s
% Start of user PostScript
0.35 0.5 0.393982 0.456018 MAarrowhead1
% End of user PostScript
.38802 .56719 m
.42179 .53342 L
s
% Start of user PostScript
0.35 0.55 0.387699 0.512301 MAarrowhead1
% End of user PostScript
.38802 .61198 m
.41616 .58384 L
s
% Start of user PostScript
0.35 0.6 0.381416 0.568584 MAarrowhead1
% End of user PostScript
.38802 .65677 m
.41053 .63426 L
s
% Start of user PostScript
0.35 0.65 0.375133 0.624867 MAarrowhead1
% End of user PostScript
.38802 .70157 m
.4049 .68468 L
s
% Start of user PostScript
0.35 0.7 0.36885 0.68115 MAarrowhead1
% End of user PostScript
.38802 .74636 m
.39928 .7351 L
s
% Start of user PostScript
0.35 0.75 0.362566 0.737434 MAarrowhead1
% End of user PostScript
.38802 .79115 m
.39365 .78552 L
s
% Start of user PostScript
0.35 0.8 0.356283 0.793717 MAarrowhead1
% End of user PostScript
.38802 .83595 m
.38802 .83595 L
s
% Start of user PostScript
0.35 0.85 MAarrowzero1
% End of user PostScript
.38802 .88074 m
.38239 .88637 L
s
% Start of user PostScript
0.35 0.9 0.343717 0.906283 MAarrowhead1
% End of user PostScript
.38802 .92553 m
.37676 .93679 L
s
% Start of user PostScript
0.35 0.95 0.337434 0.962566 MAarrowhead1
% End of user PostScript
.43281 .07447 m
.42155 .08573 L
s
% Start of user PostScript
0.4 0 0.387434 0.0125664 MAarrowhead1
% End of user PostScript
.43281 .11926 m
.41592 .13615 L
s
% Start of user PostScript
0.4 0.05 0.38115 0.0688496 MAarrowhead1
% End of user PostScript
.43281 .16405 m
.4103 .18657 L
s
% Start of user PostScript
0.4 0.1 0.374867 0.125133 MAarrowhead1
% End of user PostScript
.43281 .20885 m
.40467 .23699 L
s
% Start of user PostScript
0.4 0.15 0.368584 0.181416 MAarrowhead1
% End of user PostScript
.43281 .25364 m
.39904 .28741 L
s
% Start of user PostScript
0.4 0.2 0.362301 0.237699 MAarrowhead1
% End of user PostScript
.43281 .29843 m
.39341 .33783 L
s
% Start of user PostScript
0.4 0.25 0.356018 0.293982 MAarrowhead1
% End of user PostScript
.43281 .34323 m
.38778 .38826 L
s
% Start of user PostScript
0.4 0.3 0.349735 0.350265 MAarrowhead1
% End of user PostScript
.43281 .38802 m
.38215 .43868 L
s
% Start of user PostScript
0.4 0.35 0.343451 0.406549 MAarrowhead1
% End of user PostScript
.43281 .43281 m
.43281 .43281 L
s
% Start of user PostScript
0.4 0.4 MAarrowzero1
% End of user PostScript
.43281 .4776 m
.48347 .42694 L
s
% Start of user PostScript
0.4 0.45 0.456549 0.393451 MAarrowhead1
% End of user PostScript
.43281 .5224 m
.47784 .47737 L
s
% Start of user PostScript
0.4 0.5 0.450265 0.449735 MAarrowhead1
% End of user PostScript
.43281 .56719 m
.47221 .52779 L
s
% Start of user PostScript
0.4 0.55 0.443982 0.506018 MAarrowhead1
% End of user PostScript
.43281 .61198 m
.46658 .57821 L
s
% Start of user PostScript
0.4 0.6 0.437699 0.562301 MAarrowhead1
% End of user PostScript
.43281 .65677 m
.46095 .62863 L
s
% Start of user PostScript
0.4 0.65 0.431416 0.618584 MAarrowhead1
% End of user PostScript
.43281 .70157 m
.45533 .67905 L
s
% Start of user PostScript
0.4 0.7 0.425133 0.674867 MAarrowhead1
% End of user PostScript
.43281 .74636 m
.4497 .72947 L
s
% Start of user PostScript
0.4 0.75 0.41885 0.73115 MAarrowhead1
% End of user PostScript
.43281 .79115 m
.44407 .7799 L
s
% Start of user PostScript
0.4 0.8 0.412566 0.787434 MAarrowhead1
% End of user PostScript
.43281 .83595 m
.43844 .83032 L
s
% Start of user PostScript
0.4 0.85 0.406283 0.843717 MAarrowhead1
% End of user PostScript
.43281 .88074 m
.43281 .88074 L
s
% Start of user PostScript
0.4 0.9 MAarrowzero1
% End of user PostScript
.43281 .92553 m
.42718 .93116 L
s
% Start of user PostScript
0.4 0.95 0.393717 0.956283 MAarrowhead1
% End of user PostScript
.4776 .07447 m
.47197 .0801 L
s
% Start of user PostScript
0.45 0 0.443717 0.00628319 MAarrowhead1
% End of user PostScript
.4776 .11926 m
.46635 .13052 L
s
% Start of user PostScript
0.45 0.05 0.437434 0.0625664 MAarrowhead1
% End of user PostScript
.4776 .16405 m
.46072 .18094 L
s
% Start of user PostScript
0.45 0.1 0.43115 0.11885 MAarrowhead1
% End of user PostScript
.4776 .20885 m
.45509 .23136 L
s
% Start of user PostScript
0.45 0.15 0.424867 0.175133 MAarrowhead1
% End of user PostScript
.4776 .25364 m
.44946 .28178 L
s
% Start of user PostScript
0.45 0.2 0.418584 0.231416 MAarrowhead1
% End of user PostScript
.4776 .29843 m
.44383 .33221 L
s
% Start of user PostScript
0.45 0.25 0.412301 0.287699 MAarrowhead1
% End of user PostScript
.4776 .34323 m
.4382 .38263 L
s
% Start of user PostScript
0.45 0.3 0.406018 0.343982 MAarrowhead1
% End of user PostScript
.4776 .38802 m
.43257 .43305 L
s
% Start of user PostScript
0.45 0.35 0.399735 0.400265 MAarrowhead1
% End of user PostScript
.4776 .43281 m
.42694 .48347 L
s
% Start of user PostScript
0.45 0.4 0.393451 0.456549 MAarrowhead1
% End of user PostScript
.4776 .4776 m
.4776 .4776 L
s
% Start of user PostScript
0.45 0.45 MAarrowzero1
% End of user PostScript
.4776 .5224 m
.52826 .47174 L
s
% Start of user PostScript
0.45 0.5 0.506549 0.443451 MAarrowhead1
% End of user PostScript
.4776 .56719 m
.52263 .52216 L
s
% Start of user PostScript
0.45 0.55 0.500265 0.499735 MAarrowhead1
% End of user PostScript
.4776 .61198 m
.51701 .57258 L
s
% Start of user PostScript
0.45 0.6 0.493982 0.556018 MAarrowhead1
% End of user PostScript
.4776 .65677 m
.51138 .623 L
s
% Start of user PostScript
0.45 0.65 0.487699 0.612301 MAarrowhead1
% End of user PostScript
.4776 .70157 m
.50575 .67342 L
s
% Start of user PostScript
0.45 0.7 0.481416 0.668584 MAarrowhead1
% End of user PostScript
.4776 .74636 m
.50012 .72384 L
s
% Start of user PostScript
0.45 0.75 0.475133 0.724867 MAarrowhead1
% End of user PostScript
.4776 .79115 m
.49449 .77427 L
s
% Start of user PostScript
0.45 0.8 0.46885 0.78115 MAarrowhead1
% End of user PostScript
.4776 .83595 m
.48886 .82469 L
s
% Start of user PostScript
0.45 0.85 0.462566 0.837434 MAarrowhead1
% End of user PostScript
.4776 .88074 m
.48323 .87511 L
s
% Start of user PostScript
0.45 0.9 0.456283 0.893717 MAarrowhead1
% End of user PostScript
.4776 .92553 m
.4776 .92553 L
s
% Start of user PostScript
0.45 0.95 MAarrowzero1
% End of user PostScript
.5224 .07447 m
.5224 .07447 L
s
% Start of user PostScript
0.5 0 MAarrowzero1
% End of user PostScript
.5224 .11926 m
.51677 .12489 L
s
% Start of user PostScript
0.5 0.05 0.493717 0.0562832 MAarrowhead1
% End of user PostScript
.5224 .16405 m
.51114 .17531 L
s
% Start of user PostScript
0.5 0.1 0.487434 0.112566 MAarrowhead1
% End of user PostScript
.5224 .20885 m
.50551 .22573 L
s
% Start of user PostScript
0.5 0.15 0.48115 0.16885 MAarrowhead1
% End of user PostScript
.5224 .25364 m
.49988 .27616 L
s
% Start of user PostScript
0.5 0.2 0.474867 0.225133 MAarrowhead1
% End of user PostScript
.5224 .29843 m
.49425 .32658 L
s
% Start of user PostScript
0.5 0.25 0.468584 0.281416 MAarrowhead1
% End of user PostScript
.5224 .34323 m
.48862 .377 L
s
% Start of user PostScript
0.5 0.3 0.462301 0.337699 MAarrowhead1
% End of user PostScript
.5224 .38802 m
.48299 .42742 L
s
% Start of user PostScript
0.5 0.35 0.456018 0.393982 MAarrowhead1
% End of user PostScript
.5224 .43281 m
.47737 .47784 L
s
% Start of user PostScript
0.5 0.4 0.449735 0.450265 MAarrowhead1
% End of user PostScript
.5224 .4776 m
.47174 .52826 L
s
% Start of user PostScript
0.5 0.45 0.443451 0.506549 MAarrowhead1
% End of user PostScript
.5224 .5224 m
.5224 .5224 L
s
% Start of user PostScript
0.5 0.5 MAarrowzero1
% End of user PostScript
.5224 .56719 m
.57306 .51653 L
s
% Start of user PostScript
0.5 0.55 0.556549 0.493451 MAarrowhead1
% End of user PostScript
.5224 .61198 m
.56743 .56695 L
s
% Start of user PostScript
0.5 0.6 0.550265 0.549735 MAarrowhead1
% End of user PostScript
.5224 .65677 m
.5618 .61737 L
s
% Start of user PostScript
0.5 0.65 0.543982 0.606018 MAarrowhead1
% End of user PostScript
.5224 .70157 m
.55617 .66779 L
s
% Start of user PostScript
0.5 0.7 0.537699 0.662301 MAarrowhead1
% End of user PostScript
.5224 .74636 m
.55054 .71822 L
s
% Start of user PostScript
0.5 0.75 0.531416 0.718584 MAarrowhead1
% End of user PostScript
.5224 .79115 m
.54491 .76864 L
s
% Start of user PostScript
0.5 0.8 0.525133 0.774867 MAarrowhead1
% End of user PostScript
.5224 .83595 m
.53928 .81906 L
s
% Start of user PostScript
0.5 0.85 0.51885 0.83115 MAarrowhead1
% End of user PostScript
.5224 .88074 m
.53365 .86948 L
s
% Start of user PostScript
0.5 0.9 0.512566 0.887434 MAarrowhead1
% End of user PostScript
.5224 .92553 m
.52803 .9199 L
s
% Start of user PostScript
0.5 0.95 0.506283 0.943717 MAarrowhead1
% End of user PostScript
.56719 .07447 m
.57282 .06884 L
s
% Start of user PostScript
0.55 0 0.556283 -0.00628319 MAarrowhead1
% End of user PostScript
.56719 .11926 m
.56719 .11926 L
s
% Start of user PostScript
0.55 0.05 MAarrowzero1
% End of user PostScript
.56719 .16405 m
.56156 .16968 L
s
% Start of user PostScript
0.55 0.1 0.543717 0.106283 MAarrowhead1
% End of user PostScript
.56719 .20885 m
.55593 .2201 L
s
% Start of user PostScript
0.55 0.15 0.537434 0.162566 MAarrowhead1
% End of user PostScript
.56719 .25364 m
.5503 .27053 L
s
% Start of user PostScript
0.55 0.2 0.53115 0.21885 MAarrowhead1
% End of user PostScript
.56719 .29843 m
.54467 .32095 L
s
% Start of user PostScript
0.55 0.25 0.524867 0.275133 MAarrowhead1
% End of user PostScript
.56719 .34323 m
.53905 .37137 L
s
% Start of user PostScript
0.55 0.3 0.518584 0.331416 MAarrowhead1
% End of user PostScript
.56719 .38802 m
.53342 .42179 L
s
% Start of user PostScript
0.55 0.35 0.512301 0.387699 MAarrowhead1
% End of user PostScript
.56719 .43281 m
.52779 .47221 L
s
% Start of user PostScript
0.55 0.4 0.506018 0.443982 MAarrowhead1
% End of user PostScript
.56719 .4776 m
.52216 .52263 L
s
% Start of user PostScript
0.55 0.45 0.499735 0.500265 MAarrowhead1
% End of user PostScript
.56719 .5224 m
.51653 .57306 L
s
% Start of user PostScript
0.55 0.5 0.493451 0.556549 MAarrowhead1
% End of user PostScript
.56719 .56719 m
.56719 .56719 L
s
% Start of user PostScript
0.55 0.55 MAarrowzero1
% End of user PostScript
.56719 .61198 m
.61785 .56132 L
s
% Start of user PostScript
0.55 0.6 0.606549 0.543451 MAarrowhead1
% End of user PostScript
.56719 .65677 m
.61222 .61174 L
s
% Start of user PostScript
0.55 0.65 0.600265 0.599735 MAarrowhead1
% End of user PostScript
.56719 .70157 m
.60659 .66217 L
s
% Start of user PostScript
0.55 0.7 0.593982 0.656018 MAarrowhead1
% End of user PostScript
.56719 .74636 m
.60096 .71259 L
s
% Start of user PostScript
0.55 0.75 0.587699 0.712301 MAarrowhead1
% End of user PostScript
.56719 .79115 m
.59533 .76301 L
s
% Start of user PostScript
0.55 0.8 0.581416 0.768584 MAarrowhead1
% End of user PostScript
.56719 .83595 m
.5897 .81343 L
s
% Start of user PostScript
0.55 0.85 0.575133 0.824867 MAarrowhead1
% End of user PostScript
.56719 .88074 m
.58408 .86385 L
s
% Start of user PostScript
0.55 0.9 0.56885 0.88115 MAarrowhead1
% End of user PostScript
.56719 .92553 m
.57845 .91427 L
s
% Start of user PostScript
0.55 0.95 0.562566 0.937434 MAarrowhead1
% End of user PostScript
.61198 .07447 m
.62324 .06321 L
s
% Start of user PostScript
0.6 0 0.612566 -0.0125664 MAarrowhead1
% End of user PostScript
.61198 .11926 m
.61761 .11363 L
s
% Start of user PostScript
0.6 0.05 0.606283 0.0437168 MAarrowhead1
% End of user PostScript
.61198 .16405 m
.61198 .16405 L
s
% Start of user PostScript
0.6 0.1 MAarrowzero1
% End of user PostScript
.61198 .20885 m
.60635 .21448 L
s
% Start of user PostScript
0.6 0.15 0.593717 0.156283 MAarrowhead1
% End of user PostScript
.61198 .25364 m
.60072 .2649 L
s
% Start of user PostScript
0.6 0.2 0.587434 0.212566 MAarrowhead1
% End of user PostScript
.61198 .29843 m
.5951 .31532 L
s
% Start of user PostScript
0.6 0.25 0.58115 0.26885 MAarrowhead1
% End of user PostScript
.61198 .34323 m
.58947 .36574 L
s
% Start of user PostScript
0.6 0.3 0.574867 0.325133 MAarrowhead1
% End of user PostScript
.61198 .38802 m
.58384 .41616 L
s
% Start of user PostScript
0.6 0.35 0.568584 0.381416 MAarrowhead1
% End of user PostScript
.61198 .43281 m
.57821 .46658 L
s
% Start of user PostScript
0.6 0.4 0.562301 0.437699 MAarrowhead1
% End of user PostScript
.61198 .4776 m
.57258 .51701 L
s
% Start of user PostScript
0.6 0.45 0.556018 0.493982 MAarrowhead1
% End of user PostScript
.61198 .5224 m
.56695 .56743 L
s
% Start of user PostScript
0.6 0.5 0.549735 0.550265 MAarrowhead1
% End of user PostScript
.61198 .56719 m
.56132 .61785 L
s
% Start of user PostScript
0.6 0.55 0.543451 0.606549 MAarrowhead1
% End of user PostScript
.61198 .61198 m
.61198 .61198 L
s
% Start of user PostScript
0.6 0.6 MAarrowzero1
% End of user PostScript
.61198 .65677 m
.66264 .60612 L
s
% Start of user PostScript
0.6 0.65 0.656549 0.593451 MAarrowhead1
% End of user PostScript
.61198 .70157 m
.65701 .65654 L
s
% Start of user PostScript
0.6 0.7 0.650265 0.649735 MAarrowhead1
% End of user PostScript
.61198 .74636 m
.65138 .70696 L
s
% Start of user PostScript
0.6 0.75 0.643982 0.706018 MAarrowhead1
% End of user PostScript
.61198 .79115 m
.64575 .75738 L
s
% Start of user PostScript
0.6 0.8 0.637699 0.762301 MAarrowhead1
% End of user PostScript
.61198 .83595 m
.64013 .8078 L
s
% Start of user PostScript
0.6 0.85 0.631416 0.818584 MAarrowhead1
% End of user PostScript
.61198 .88074 m
.6345 .85822 L
s
% Start of user PostScript
0.6 0.9 0.625133 0.874867 MAarrowhead1
% End of user PostScript
.61198 .92553 m
.62887 .90864 L
s
% Start of user PostScript
0.6 0.95 0.61885 0.93115 MAarrowhead1
% End of user PostScript
.65677 .07447 m
.67366 .05758 L
s
% Start of user PostScript
0.65 0 0.66885 -0.0188496 MAarrowhead1
% End of user PostScript
.65677 .11926 m
.66803 .108 L
s
% Start of user PostScript
0.65 0.05 0.662566 0.0374336 MAarrowhead1
% End of user PostScript
.65677 .16405 m
.6624 .15843 L
s
% Start of user PostScript
0.65 0.1 0.656283 0.0937168 MAarrowhead1
% End of user PostScript
.65677 .20885 m
.65677 .20885 L
s
% Start of user PostScript
0.65 0.15 MAarrowzero1
% End of user PostScript
.65677 .25364 m
.65115 .25927 L
s
% Start of user PostScript
0.65 0.2 0.643717 0.206283 MAarrowhead1
% End of user PostScript
.65677 .29843 m
.64552 .30969 L
s
% Start of user PostScript
0.65 0.25 0.637434 0.262566 MAarrowhead1
% End of user PostScript
.65677 .34323 m
.63989 .36011 L
s
% Start of user PostScript
0.65 0.3 0.63115 0.31885 MAarrowhead1
% End of user PostScript
.65677 .38802 m
.63426 .41053 L
s
% Start of user PostScript
0.65 0.35 0.624867 0.375133 MAarrowhead1
% End of user PostScript
.65677 .43281 m
.62863 .46095 L
s
% Start of user PostScript
0.65 0.4 0.618584 0.431416 MAarrowhead1
% End of user PostScript
.65677 .4776 m
.623 .51138 L
s
% Start of user PostScript
0.65 0.45 0.612301 0.487699 MAarrowhead1
% End of user PostScript
.65677 .5224 m
.61737 .5618 L
s
% Start of user PostScript
0.65 0.5 0.606018 0.543982 MAarrowhead1
% End of user PostScript
.65677 .56719 m
.61174 .61222 L
s
% Start of user PostScript
0.65 0.55 0.599735 0.600265 MAarrowhead1
% End of user PostScript
.65677 .61198 m
.60612 .66264 L
s
% Start of user PostScript
0.65 0.6 0.593451 0.656549 MAarrowhead1
% End of user PostScript
.65677 .65677 m
.65677 .65677 L
s
% Start of user PostScript
0.65 0.65 MAarrowzero1
% End of user PostScript
.65677 .70157 m
.70743 .65091 L
s
% Start of user PostScript
0.65 0.7 0.706549 0.643451 MAarrowhead1
% End of user PostScript
.65677 .74636 m
.70181 .70133 L
s
% Start of user PostScript
0.65 0.75 0.700265 0.699735 MAarrowhead1
% End of user PostScript
.65677 .79115 m
.69618 .75175 L
s
% Start of user PostScript
0.65 0.8 0.693982 0.756018 MAarrowhead1
% End of user PostScript
.65677 .83595 m
.69055 .80217 L
s
% Start of user PostScript
0.65 0.85 0.687699 0.812301 MAarrowhead1
% End of user PostScript
.65677 .88074 m
.68492 .85259 L
s
% Start of user PostScript
0.65 0.9 0.681416 0.868584 MAarrowhead1
% End of user PostScript
.65677 .92553 m
.67929 .90302 L
s
% Start of user PostScript
0.65 0.95 0.675133 0.924867 MAarrowhead1
% End of user PostScript
.70157 .07447 m
.72408 .05195 L
s
% Start of user PostScript
0.7 0 0.725133 -0.0251327 MAarrowhead1
% End of user PostScript
.70157 .11926 m
.71845 .10238 L
s
% Start of user PostScript
0.7 0.05 0.71885 0.0311504 MAarrowhead1
% End of user PostScript
.70157 .16405 m
.71282 .1528 L
s
% Start of user PostScript
0.7 0.1 0.712566 0.0874336 MAarrowhead1
% End of user PostScript
.70157 .20885 m
.7072 .20322 L
s
% Start of user PostScript
0.7 0.15 0.706283 0.143717 MAarrowhead1
% End of user PostScript
.70157 .25364 m
.70157 .25364 L
s
% Start of user PostScript
0.7 0.2 MAarrowzero1
% End of user PostScript
.70157 .29843 m
.69594 .30406 L
s
% Start of user PostScript
0.7 0.25 0.693717 0.256283 MAarrowhead1
% End of user PostScript
.70157 .34323 m
.69031 .35448 L
s
% Start of user PostScript
0.7 0.3 0.687434 0.312566 MAarrowhead1
% End of user PostScript
.70157 .38802 m
.68468 .4049 L
s
% Start of user PostScript
0.7 0.35 0.68115 0.36885 MAarrowhead1
% End of user PostScript
.70157 .43281 m
.67905 .45533 L
s
% Start of user PostScript
0.7 0.4 0.674867 0.425133 MAarrowhead1
% End of user PostScript
.70157 .4776 m
.67342 .50575 L
s
% Start of user PostScript
0.7 0.45 0.668584 0.481416 MAarrowhead1
% End of user PostScript
.70157 .5224 m
.66779 .55617 L
s
% Start of user PostScript
0.7 0.5 0.662301 0.537699 MAarrowhead1
% End of user PostScript
.70157 .56719 m
.66217 .60659 L
s
% Start of user PostScript
0.7 0.55 0.656018 0.593982 MAarrowhead1
% End of user PostScript
.70157 .61198 m
.65654 .65701 L
s
% Start of user PostScript
0.7 0.6 0.649735 0.650265 MAarrowhead1
% End of user PostScript
.70157 .65677 m
.65091 .70743 L
s
% Start of user PostScript
0.7 0.65 0.643451 0.706549 MAarrowhead1
% End of user PostScript
.70157 .70157 m
.70157 .70157 L
s
% Start of user PostScript
0.7 0.7 MAarrowzero1
% End of user PostScript
.70157 .74636 m
.75223 .6957 L
s
% Start of user PostScript
0.7 0.75 0.756549 0.693451 MAarrowhead1
% End of user PostScript
.70157 .79115 m
.7466 .74612 L
s
% Start of user PostScript
0.7 0.8 0.750265 0.749735 MAarrowhead1
% End of user PostScript
.70157 .83595 m
.74097 .79654 L
s
% Start of user PostScript
0.7 0.85 0.743982 0.806018 MAarrowhead1
% End of user PostScript
.70157 .88074 m
.73534 .84697 L
s
% Start of user PostScript
0.7 0.9 0.737699 0.862301 MAarrowhead1
% End of user PostScript
.70157 .92553 m
.72971 .89739 L
s
% Start of user PostScript
0.7 0.95 0.731416 0.918584 MAarrowhead1
% End of user PostScript
.74636 .07447 m
.7745 .04632 L
s
% Start of user PostScript
0.75 0 0.781416 -0.0314159 MAarrowhead1
% End of user PostScript
.74636 .11926 m
.76888 .09675 L
s
% Start of user PostScript
0.75 0.05 0.775133 0.0248673 MAarrowhead1
% End of user PostScript
.74636 .16405 m
.76325 .14717 L
s
% Start of user PostScript
0.75 0.1 0.76885 0.0811504 MAarrowhead1
% End of user PostScript
.74636 .20885 m
.75762 .19759 L
s
% Start of user PostScript
0.75 0.15 0.762566 0.137434 MAarrowhead1
% End of user PostScript
.74636 .25364 m
.75199 .24801 L
s
% Start of user PostScript
0.75 0.2 0.756283 0.193717 MAarrowhead1
% End of user PostScript
.74636 .29843 m
.74636 .29843 L
s
% Start of user PostScript
0.75 0.25 MAarrowzero1
% End of user PostScript
.74636 .34323 m
.74073 .34885 L
s
% Start of user PostScript
0.75 0.3 0.743717 0.306283 MAarrowhead1
% End of user PostScript
.74636 .38802 m
.7351 .39928 L
s
% Start of user PostScript
0.75 0.35 0.737434 0.362566 MAarrowhead1
% End of user PostScript
.74636 .43281 m
.72947 .4497 L
s
% Start of user PostScript
0.75 0.4 0.73115 0.41885 MAarrowhead1
% End of user PostScript
.74636 .4776 m
.72384 .50012 L
s
% Start of user PostScript
0.75 0.45 0.724867 0.475133 MAarrowhead1
% End of user PostScript
.74636 .5224 m
.71822 .55054 L
s
% Start of user PostScript
0.75 0.5 0.718584 0.531416 MAarrowhead1
% End of user PostScript
.74636 .56719 m
.71259 .60096 L
s
% Start of user PostScript
0.75 0.55 0.712301 0.587699 MAarrowhead1
% End of user PostScript
.74636 .61198 m
.70696 .65138 L
s
% Start of user PostScript
0.75 0.6 0.706018 0.643982 MAarrowhead1
% End of user PostScript
.74636 .65677 m
.70133 .70181 L
s
% Start of user PostScript
0.75 0.65 0.699735 0.700265 MAarrowhead1
% End of user PostScript
.74636 .70157 m
.6957 .75223 L
s
% Start of user PostScript
0.75 0.7 0.693451 0.756549 MAarrowhead1
% End of user PostScript
.74636 .74636 m
.74636 .74636 L
s
% Start of user PostScript
0.75 0.75 MAarrowzero1
% End of user PostScript
.74636 .79115 m
.79702 .74049 L
s
% Start of user PostScript
0.75 0.8 0.806549 0.743451 MAarrowhead1
% End of user PostScript
.74636 .83595 m
.79139 .79092 L
s
% Start of user PostScript
0.75 0.85 0.800265 0.799735 MAarrowhead1
% End of user PostScript
.74636 .88074 m
.78576 .84134 L
s
% Start of user PostScript
0.75 0.9 0.793982 0.856018 MAarrowhead1
% End of user PostScript
.74636 .92553 m
.78013 .89176 L
s
% Start of user PostScript
0.75 0.95 0.787699 0.912301 MAarrowhead1
% End of user PostScript
.79115 .07447 m
.82493 .0407 L
s
% Start of user PostScript
0.8 0 0.837699 -0.0376991 MAarrowhead1
% End of user PostScript
.79115 .11926 m
.8193 .09112 L
s
% Start of user PostScript
0.8 0.05 0.831416 0.0185841 MAarrowhead1
% End of user PostScript
.79115 .16405 m
.81367 .14154 L
s
% Start of user PostScript
0.8 0.1 0.825133 0.0748673 MAarrowhead1
% End of user PostScript
.79115 .20885 m
.80804 .19196 L
s
% Start of user PostScript
0.8 0.15 0.81885 0.13115 MAarrowhead1
% End of user PostScript
.79115 .25364 m
.80241 .24238 L
s
% Start of user PostScript
0.8 0.2 0.812566 0.187434 MAarrowhead1
% End of user PostScript
.79115 .29843 m
.79678 .2928 L
s
% Start of user PostScript
0.8 0.25 0.806283 0.243717 MAarrowhead1
% End of user PostScript
.79115 .34323 m
.79115 .34323 L
s
% Start of user PostScript
0.8 0.3 MAarrowzero1
% End of user PostScript
.79115 .38802 m
.78552 .39365 L
s
% Start of user PostScript
0.8 0.35 0.793717 0.356283 MAarrowhead1
% End of user PostScript
.79115 .43281 m
.7799 .44407 L
s
% Start of user PostScript
0.8 0.4 0.787434 0.412566 MAarrowhead1
% End of user PostScript
.79115 .4776 m
.77427 .49449 L
s
% Start of user PostScript
0.8 0.45 0.78115 0.46885 MAarrowhead1
% End of user PostScript
.79115 .5224 m
.76864 .54491 L
s
% Start of user PostScript
0.8 0.5 0.774867 0.525133 MAarrowhead1
% End of user PostScript
.79115 .56719 m
.76301 .59533 L
s
% Start of user PostScript
0.8 0.55 0.768584 0.581416 MAarrowhead1
% End of user PostScript
.79115 .61198 m
.75738 .64575 L
s
% Start of user PostScript
0.8 0.6 0.762301 0.637699 MAarrowhead1
% End of user PostScript
.79115 .65677 m
.75175 .69618 L
s
% Start of user PostScript
0.8 0.65 0.756018 0.693982 MAarrowhead1
% End of user PostScript
.79115 .70157 m
.74612 .7466 L
s
% Start of user PostScript
0.8 0.7 0.749735 0.750265 MAarrowhead1
% End of user PostScript
.79115 .74636 m
.74049 .79702 L
s
% Start of user PostScript
0.8 0.75 0.743451 0.806549 MAarrowhead1
% End of user PostScript
.79115 .79115 m
.79115 .79115 L
s
% Start of user PostScript
0.8 0.8 MAarrowzero1
% End of user PostScript
.79115 .83595 m
.84181 .78529 L
s
% Start of user PostScript
0.8 0.85 0.856549 0.793451 MAarrowhead1
% End of user PostScript
.79115 .88074 m
.83618 .83571 L
s
% Start of user PostScript
0.8 0.9 0.850265 0.849735 MAarrowhead1
% End of user PostScript
.79115 .92553 m
.83055 .88613 L
s
% Start of user PostScript
0.8 0.95 0.843982 0.906018 MAarrowhead1
% End of user PostScript
.83595 .07447 m
.87535 .03507 L
s
% Start of user PostScript
0.85 0 0.893982 -0.0439823 MAarrowhead1
% End of user PostScript
.83595 .11926 m
.86972 .08549 L
s
% Start of user PostScript
0.85 0.05 0.887699 0.0123009 MAarrowhead1
% End of user PostScript
.83595 .16405 m
.86409 .13591 L
s
% Start of user PostScript
0.85 0.1 0.881416 0.0685841 MAarrowhead1
% End of user PostScript
.83595 .20885 m
.85846 .18633 L
s
% Start of user PostScript
0.85 0.15 0.875133 0.124867 MAarrowhead1
% End of user PostScript
.83595 .25364 m
.85283 .23675 L
s
% Start of user PostScript
0.85 0.2 0.86885 0.18115 MAarrowhead1
% End of user PostScript
.83595 .29843 m
.8472 .28718 L
s
% Start of user PostScript
0.85 0.25 0.862566 0.237434 MAarrowhead1
% End of user PostScript
.83595 .34323 m
.84157 .3376 L
s
% Start of user PostScript
0.85 0.3 0.856283 0.293717 MAarrowhead1
% End of user PostScript
.83595 .38802 m
.83595 .38802 L
s
% Start of user PostScript
0.85 0.35 MAarrowzero1
% End of user PostScript
.83595 .43281 m
.83032 .43844 L
s
% Start of user PostScript
0.85 0.4 0.843717 0.406283 MAarrowhead1
% End of user PostScript
.83595 .4776 m
.82469 .48886 L
s
% Start of user PostScript
0.85 0.45 0.837434 0.462566 MAarrowhead1
% End of user PostScript
.83595 .5224 m
.81906 .53928 L
s
% Start of user PostScript
0.85 0.5 0.83115 0.51885 MAarrowhead1
% End of user PostScript
.83595 .56719 m
.81343 .5897 L
s
% Start of user PostScript
0.85 0.55 0.824867 0.575133 MAarrowhead1
% End of user PostScript
.83595 .61198 m
.8078 .64013 L
s
% Start of user PostScript
0.85 0.6 0.818584 0.631416 MAarrowhead1
% End of user PostScript
.83595 .65677 m
.80217 .69055 L
s
% Start of user PostScript
0.85 0.65 0.812301 0.687699 MAarrowhead1
% End of user PostScript
.83595 .70157 m
.79654 .74097 L
s
% Start of user PostScript
0.85 0.7 0.806018 0.743982 MAarrowhead1
% End of user PostScript
.83595 .74636 m
.79092 .79139 L
s
% Start of user PostScript
0.85 0.75 0.799735 0.800265 MAarrowhead1
% End of user PostScript
.83595 .79115 m
.78529 .84181 L
s
% Start of user PostScript
0.85 0.8 0.793451 0.856549 MAarrowhead1
% End of user PostScript
.83595 .83595 m
.83595 .83595 L
s
% Start of user PostScript
0.85 0.85 MAarrowzero1
% End of user PostScript
.83595 .88074 m
.8866 .83008 L
s
% Start of user PostScript
0.85 0.9 0.906549 0.843451 MAarrowhead1
% End of user PostScript
.83595 .92553 m
.88098 .8805 L
s
% Start of user PostScript
0.85 0.95 0.900265 0.899735 MAarrowhead1
% End of user PostScript
.88074 .07447 m
.92577 .02944 L
s
% Start of user PostScript
0.9 0 0.950265 -0.0502655 MAarrowhead1
% End of user PostScript
.88074 .11926 m
.92014 .07986 L
s
% Start of user PostScript
0.9 0.05 0.943982 0.0060177 MAarrowhead1
% End of user PostScript
.88074 .16405 m
.91451 .13028 L
s
% Start of user PostScript
0.9 0.1 0.937699 0.0623009 MAarrowhead1
% End of user PostScript
.88074 .20885 m
.90888 .1807 L
s
% Start of user PostScript
0.9 0.15 0.931416 0.118584 MAarrowhead1
% End of user PostScript
.88074 .25364 m
.90325 .23112 L
s
% Start of user PostScript
0.9 0.2 0.925133 0.174867 MAarrowhead1
% End of user PostScript
.88074 .29843 m
.89762 .28155 L
s
% Start of user PostScript
0.9 0.25 0.91885 0.23115 MAarrowhead1
% End of user PostScript
.88074 .34323 m
.892 .33197 L
s
% Start of user PostScript
0.9 0.3 0.912566 0.287434 MAarrowhead1
% End of user PostScript
.88074 .38802 m
.88637 .38239 L
s
% Start of user PostScript
0.9 0.35 0.906283 0.343717 MAarrowhead1
% End of user PostScript
.88074 .43281 m
.88074 .43281 L
s
% Start of user PostScript
0.9 0.4 MAarrowzero1
% End of user PostScript
.88074 .4776 m
.87511 .48323 L
s
% Start of user PostScript
0.9 0.45 0.893717 0.456283 MAarrowhead1
% End of user PostScript
.88074 .5224 m
.86948 .53365 L
s
% Start of user PostScript
0.9 0.5 0.887434 0.512566 MAarrowhead1
% End of user PostScript
.88074 .56719 m
.86385 .58408 L
s
% Start of user PostScript
0.9 0.55 0.88115 0.56885 MAarrowhead1
% End of user PostScript
.88074 .61198 m
.85822 .6345 L
s
% Start of user PostScript
0.9 0.6 0.874867 0.625133 MAarrowhead1
% End of user PostScript
.88074 .65677 m
.85259 .68492 L
s
% Start of user PostScript
0.9 0.65 0.868584 0.681416 MAarrowhead1
% End of user PostScript
.88074 .70157 m
.84697 .73534 L
s
% Start of user PostScript
0.9 0.7 0.862301 0.737699 MAarrowhead1
% End of user PostScript
.88074 .74636 m
.84134 .78576 L
s
% Start of user PostScript
0.9 0.75 0.856018 0.793982 MAarrowhead1
% End of user PostScript
.88074 .79115 m
.83571 .83618 L
s
% Start of user PostScript
0.9 0.8 0.849735 0.850265 MAarrowhead1
% End of user PostScript
.88074 .83595 m
.83008 .8866 L
s
% Start of user PostScript
0.9 0.85 0.843451 0.906549 MAarrowhead1
% End of user PostScript
.88074 .88074 m
.88074 .88074 L
s
% Start of user PostScript
0.9 0.9 MAarrowzero1
% End of user PostScript
.88074 .92553 m
.9314 .87487 L
s
% Start of user PostScript
0.9 0.95 0.956549 0.893451 MAarrowhead1
% End of user PostScript
.92553 .07447 m
.97619 .02381 L
s
% Start of user PostScript
0.95 0 1.00655 -0.0565487 MAarrowhead1
% End of user PostScript
.92553 .11926 m
.97056 .07423 L
s
% Start of user PostScript
0.95 0.05 1.00027 -0.000265482 MAarrowhead1
% End of user PostScript
.92553 .16405 m
.96493 .12465 L
s
% Start of user PostScript
0.95 0.1 0.993982 0.0560177 MAarrowhead1
% End of user PostScript
.92553 .20885 m
.9593 .17507 L
s
% Start of user PostScript
0.95 0.15 0.987699 0.112301 MAarrowhead1
% End of user PostScript
.92553 .25364 m
.95368 .2255 L
s
% Start of user PostScript
0.95 0.2 0.981416 0.168584 MAarrowhead1
% End of user PostScript
.92553 .29843 m
.94805 .27592 L
s
% Start of user PostScript
0.95 0.25 0.975133 0.224867 MAarrowhead1
% End of user PostScript
.92553 .34323 m
.94242 .32634 L
s
% Start of user PostScript
0.95 0.3 0.96885 0.28115 MAarrowhead1
% End of user PostScript
.92553 .38802 m
.93679 .37676 L
s
% Start of user PostScript
0.95 0.35 0.962566 0.337434 MAarrowhead1
% End of user PostScript
.92553 .43281 m
.93116 .42718 L
s
% Start of user PostScript
0.95 0.4 0.956283 0.393717 MAarrowhead1
% End of user PostScript
.92553 .4776 m
.92553 .4776 L
s
% Start of user PostScript
0.95 0.45 MAarrowzero1
% End of user PostScript
.92553 .5224 m
.9199 .52803 L
s
% Start of user PostScript
0.95 0.5 0.943717 0.506283 MAarrowhead1
% End of user PostScript
.92553 .56719 m
.91427 .57845 L
s
% Start of user PostScript
0.95 0.55 0.937434 0.562566 MAarrowhead1
% End of user PostScript
.92553 .61198 m
.90864 .62887 L
s
% Start of user PostScript
0.95 0.6 0.93115 0.61885 MAarrowhead1
% End of user PostScript
.92553 .65677 m
.90302 .67929 L
s
% Start of user PostScript
0.95 0.65 0.924867 0.675133 MAarrowhead1
% End of user PostScript
.92553 .70157 m
.89739 .72971 L
s
% Start of user PostScript
0.95 0.7 0.918584 0.731416 MAarrowhead1
% End of user PostScript
.92553 .74636 m
.89176 .78013 L
s
% Start of user PostScript
0.95 0.75 0.912301 0.787699 MAarrowhead1
% End of user PostScript
.92553 .79115 m
.88613 .83055 L
s
% Start of user PostScript
0.95 0.8 0.906018 0.843982 MAarrowhead1
% End of user PostScript
.92553 .83595 m
.8805 .88098 L
s
% Start of user PostScript
0.95 0.85 0.899735 0.900265 MAarrowhead1
% End of user PostScript
.92553 .88074 m
.87487 .9314 L
s
% Start of user PostScript
0.95 0.9 0.893451 0.956549 MAarrowhead1
% End of user PostScript
.92553 .92553 m
.92553 .92553 L
s
% Start of user PostScript
0.95 0.95 MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooolmooooo`;o00002Oooool001kooooo00?o0000ooooooooool0oooooollooooo`?o
00002Oooool001kooooo0_l0003oooooobcooooo0_l0000=ooooo`Co00002_ooool001kooooo00?o
0000ooooooooool0oooooolZooooo`?o00003?ooool4o`0000_ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo6Oooool2o`0000gooooo1?l0000<ooooo`Go00002oooool001kooooo00?o0000oooo
ooooool0<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000:_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`04_ooool3o`0000cooooo1?l0000>ooooo`Go000000?o410@ooooooooool01oooool0
01kooooo00?o0000ooooooooool0<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01_lQ8B7oV9RHoooooonHV9So8B4Qooooo`;o00003Oooool4o`0000cooooo
1Ol0000=ooooo`05o`000?oooooo0000ooooool000002oooool001kooooo00?o0000ooooooooool0
<_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:oooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol0000[ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000002[ooooo00Go410@oooooooooooooooooa0@400;ooooo`04o`00
0?ooooooooooooooo`Co00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool001kooooo00?o0000ooooooooool0<_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0:_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo0000;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@0Zooooo`04o`000?ooooooooooooooo`;o00002_ooool00olb<S;o
V9RHooooo`04o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`007_ooool00ol0003oooooooooo`0booooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Yooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0000/ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<02[ooooo00?o0000ooooooooool00ol0000:ooooo`03olc<
c?l0003o000000Co00003Oooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo000Nooooo`03o`000?oooooooooo03;ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Sooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000002cooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo01oooooo0_l0000;ooooo`03oa0@4?l0003o000000;o00002oooool00ol@
413o0000o`000003o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool001kooooo00?o0000oooooooo
ool0<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Z
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Mooooo`Co00002oooool5o`0000_ooooo
00?o0000okZj^_l000000ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo000Nooooo`03o`000?oo
oooooooo03;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@2oooool2o`0000gooooo1?l0
000;ooooo`Go000000?ok^k^ooooooooool02Oooool01OnYZJWo0000o`000?l@413o000000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo
00?oEEEEofIVI_l000002oooool001kooooo00?o0000ooooooooool0coooool4o`0000_ooooo1Ol0
000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`2>
ooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co00002oooool6o`0000cooooo00Co0000
oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0003oooooooooo`2>
ooooo`;o0000;Oooool4o`0000_ooooo1Ol0000>ooooo`?o00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001/oooo
o`03o`000?oooooooooo00kooooo1?l0000Looooo`;o00003Oooool4o`0000_ooooo1_l0000=oooo
o`03o`000?oooooo000000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Goooo
o`007_ooool00ol0003oooooooooo`0=ooooo`?o0000K?ooool2o`0000kooooo0ol0000Mooooo`?o
00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Hooooo`001?ooooooo`0006Go0000000>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool4o`0000kooooo0_l0000>ooooo`;o00003_oo
ool2o`0000kooooo00?o0000ooooooooool03?ooool2o`0000gooooo0ol0000=ooooo`?o00003_oo
ool2o`0000oooooo00?o0000ooooooooool02_ooool4o`0000kooooo0ol0000>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo0ol0000;ooooo`007_ooool00ol0003oooooooooo`09ooooo`Go00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000003Oooool0
0ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooo
oooo01_ooooo1Ol0000?ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:_ooool2
o`0000gooooo1Ol0000;ooooo`007_ooool00ol0003oooooooooo`0:ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`?o00003Oooool4o`0000gooooo00?o0000ooooooooool0;Oooool3o`00
07_ooooo0ol0000<ooooo`Co00003Oooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0JOooool2o`0000gooooo1?l0000<ooooo`Go
00003Oooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o0000
3Oooool4o`0000gooooo0_l0002/ooooo`?o00003?ooool4o`0000kooooo0ol0000>ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0
000>ooooo`03o`000?oooooooooo09_ooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o
0000ooooool000003oooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo0ol0000=
ooooo`;o0000[?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0@
ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000<ooooo`?o00003Oooool00ol0
003oooooooooo`2Kooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool04Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003_ooool00ol0003o
ooooooooo`2Zooooo`?o00003?ooool5o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04_ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000000gooooo1Ol0000<ooooo`?o00003_ooool00ol0003ooooo
ooooo`2Kooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`007_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003ooooooooo
o`2Zooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`007_ooool01Ol0003oooooo`000?oo
oooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo02kooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5Oooool001kooooo00Co0000ooooool0003o00003_ooool3o`0000kooooo00?o0000ooooooooool0
Noooool2o`0002gooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5_ooool001kooooo1Ol0000=ooooo`;o00003Oooool2o`0006cooooo00?o0000ooooooooool03_oo
ool4o`0001cooooo0_l0000=ooooo`Co00002oooool6o`0000cooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Gooooo`007_ooool3o`0000kooooo00?o0000ooooooooool03?oo
ool3o`0006cooooo0_l0000>ooooo`?o00007?ooool4o`0000_ooooo1Ol0000>ooooo`?o00003?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo000Nooooo`;o00003Oooool2
o`0000gooooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000>ooooo`Co00003Oooool2o`0000kooooo00?o0000ooooooooool02oooool4
o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Iooooo`007Oooool2o`0000gooooo0ol0000<ooooo`Co00003_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0
003oooooooooo`0Jooooo`Go00003_ooool3o`0007Wooooo000Looooo`03o`000?oooooo000000_o
oooo1?l0000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool4o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo01[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wo
oooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`08ooooo`Co00003_ooool3o`0000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>ooooo`03o`000?oooooooooo02gooooo
0ol0001kooooo`?o00003Oooool001kooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool3o`0000kooooo1Ol0000<ooooo`;o00003_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003_ooool001kooooo00?o0000
ooooooooool02?ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=
ooooo`03o`000?oooooooooo0:_ooooo0ol0000<ooooo`Co00003oooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`00
00cooooo0_l0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000=ooooo`Co00003?ooool5o`00
00oooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000go
oooo1?l0000=ooooo`;o0000[?ooool3o`0000cooooo1?l0000>ooooo`?o00004?ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000<ooooo`;o0000
3_ooool00ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`00
0?oooooo0000017ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Ooo
ool2o`000:cooooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool04_oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000
ooooooooool0Voooool2o`0000gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=
ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool3o`0000kooooo00?o0000oooo
ooooool0Z_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Cooooo000Nooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooo`00000=ooooo`Go00003?ooool3o`0000kooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0^ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`007_ooool01?l0003o
ooooooooool0000>ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Noooool2o`00
02gooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooo000000ko
oooo1?l0000<ooooo`?o00003Oooool2o`0006cooooo00?o0000ooooooooool03_ooool4o`0001co
oooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool001ko
oooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`0:ooooo`Go0000K?ooool2o`0000ko
oooo0ol0000Looooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01So
oooo000Nooooo`;o00003_ooool2o`0000gooooo0_l0000;ooooo`Ko00003_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000;ooooo`Ko00003?ooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool4o`0000[ooooo1_l0000>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo01[ooooo
1Ol0000>ooooo`?o0000JOooool001kooooo00?o0000ooooooooool02_ooool2o`0000cooooo1Ol0
000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0
000=ooooo`;o00003_ooool00ol0003oooooooooo`0Jooooo`Ko00003oooool00ol0003ooooooooo
o`1Xooooo`007_ooool00ol0003oooooooooo`08ooooo`Co00002oooool5o`0000kooooo0ol0000=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`0]
ooooo`?o0000Noooool001kooooo00?o0000ooooooooool01_ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0ol0000>ooooo`Co00003Oooool2o`0000kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`1Yooooo`;o00003oooool001kooooo00?o0000oooooooo
ool01Oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000kooooo0ol0000=oooo
o`?o00003_ooool00ol0003oooooooooo`2Zooooo`Co00003oooool001kooooo00?o0000oooooooo
ool01Oooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo1Ol0000<ooooo`;o
00003_ooool00ol0003oooooooooo`2Kooooo`;o00003?ooool5o`00013ooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000003?ooool4o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo0:[ooooo1?l0000;ooooo`Go00004Oooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0
3?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000<ooooo`Go0000
3?ooool5o`00017ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`00000<ooooo`Co00003Oooool4o`0000gooooo0_l0002[ooooo`Co00002oooool5o`0000kooooo
0ol0000Booooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?oo
ool5o`0000_ooooo0ol0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000<ooooo`Go00003?oo
ool5o`0000gooooo00?o0000ooooool000004oooool001kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
000<ooooo`Co00003Oooool4o`0000gooooo0_l0001[ooooo`03o`000?oooooooooo03gooooo1?l0
000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool05?ooool001kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000oooo
o`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0]ooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o
0000ooooooooool05Oooool001kooooo00Co0000oooooooooooo00003oooool00ol0003ooooooooo
o`0:ooooo`Co00003Oooool4o`0000kooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`0>ooooo`?o0000;?ooool4o`0000_ooooo1_l0000=ooooo`?o00003Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooo000000oooooo00?o0000
ooooooooool02oooool5o`0000cooooo0ol0000=ooooo`;o0000K?ooool00ol0003oooooooooo`0>
ooooo`Co00007?ooool2o`0000_ooooo1Ol0000=ooooo`Co00003Oooool00ol0003oooooo`00000=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool001kooooo0_l0000?oooo
o`03o`000?oooooooooo00_ooooo1?l0000>ooooo`03o`000?oooooooooo00[ooooo1Ol0001Joooo
o`03o`000?oooooooooo00kooooo0ol0000>ooooo`?o00006oooool5o`0000[ooooo1_l0000=oooo
o`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`;o
00002oooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`09ooooo`Ko
00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool001kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0:ooooo`Go00002_ooool6o`0000kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool0000=ooooo`?o00003_ooool3o`0000kooooo00?o0000oooo
ooooool06Oooool6o`0000kooooo0ol0001Iooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o
00002oooool6o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
00003_ooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo01_ooooo1Ol0000?ooooo`03
o`000?oooooooooo05Sooooo000Nooooo`03o`000?oooooooooo01Sooooo1?l0000:ooooo`Ko0000
3_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0000>ooooo`03
o`000?oooooooooo02gooooo0ol0001[ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000
3?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000
3_ooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
J_ooool001kooooo00?o0000ooooooooool01_ooool4o`0000_ooooo1Ol0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooool0000=ooooo`?o00003_ooool3o`0000kooooo00?o0000ooooooooool0
[Oooool001kooooo00?o0000ooooooooool01?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo0ol0000>ooooo`Co00003?ooool3o`0000kooooo00?o0000ooooooooool0Vooo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo1Ol0000>ooooo`?o00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000=ooooo`Co00003Oooool3o`0000kooooo00?o0000ooooooooool0Z_oo
ool4o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo1Ol0000=ooooo`03o`000?oooooo
000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo0ol0000>ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0Voooool2
o`0000cooooo1Ol0000Booooo`007_ooool00ol0003oooooooooo`04ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000cooooo1?l0000=ooooo`Co00003Oooool00ol0003oooooooooo`2Z
ooooo`Co00002oooool5o`0001?ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000;ooooo`?o00003_ooool00ol0
003oooooooooo`2Kooooo`;o00003?ooool5o`0000cooooo1Ol0000Cooooo`007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000003?ooool4o`0000gooooo1?l0000=oooo
o`;o0000J_ooool00ol0003oooooooooo`0nooooo`Co00002oooool5o`0000kooooo0ol0000Doooo
o`007_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000_ooooo0ol0000>oooo
o`03o`000?oooooooooo06[ooooo0_l0000_ooooo`;o00003?ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000001Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`Co00003Oooool4o`0000cooooo0ol0001[ooooo`03o`000?oooooo
oooo00gooooo1?l0000/ooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooo
oooo01Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`Go00003?ooool3o`0000_ooooo1?l0001/ooooo`03o`000?oo
oooooooo00gooooo1Ol0000Kooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool05oooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool4o`0000cooooo0ol0000<ooooo`Co0000Foooool00ol0003ooooooooo
o`0>ooooo`?o00003Oooool4o`0001_ooooo1?l0000;ooooo`Ko00003Oooool3o`0000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`?o00002oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?oo
ool3o`0000kooooo00?o0000ooooooooool02Oooool5o`0000gooooo1?l0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0Zooooo`?o00003?ooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00003Oooool3o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo01Wooooo
1_l0000>ooooo`?o0000BOooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool4o`0000_ooooo1_l0000<ooooo`Co0000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o0000
3_ooool00ol0003oooooooooo`0Kooooo`Co00004?ooool00ol0003oooooooooo`18ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo01Sooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooo`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`0]oooo
o`?o0000Foooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Gooooo`?o00002oooool6o`0000cooooo1?l0000=
ooooo`;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3
o`0000kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Jooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00003?ooool2o`00
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`2Mooooo`007_ooool00ol0
003oooooooooo`05ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?oooooooooo
o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo00?o0000ooooooooool0W_ooool0
01kooooo00?o0000ooooooooool00oooool4o`0000cooooo1Ol0000=ooooo`Co00003?ooool00ol0
003oooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`;o00004oooool0
01kooooo00?o0000ooooooooool00_ooool5o`0000cooooo1?l0000=ooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool03Oooool2o`0000kooooo00?o0000ooooooooool02oooool3
o`0000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`?o00004oooool0
01kooooo00Co0000oooooooooooooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo0_l0000;ooooo`04o`000?ooooooooooo`0000gooooo1?l0
000=ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`;o00003Oooool4o`0001Cooooo000N
ooooo`04o`000?ooooooooooooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000cooooo0ol0000>ooooo`Go0000
2oooool3o`0000kooooo00?o0000ooooooooool0V_ooool3o`0000cooooo1Ol0000Dooooo`007_oo
ool01?l0003oooooooooooooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l0000<ooooo`Co0000
3Oooool4o`0000gooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0^ooooo`;o0000
3Oooool4o`0000cooooo1Ol0000Eooooo`007_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00_ooooo1?l0000=ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0
J_ooool2o`0002kooooo0ol0000<ooooo`Go00003?ooool4o`0001Kooooo000Nooooo`03o`000?oo
oooo000000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo1?l0000=ooooo`Co00002oooool4o`0006[ooooo00?o0000ooooooooool03_oo
ool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000Fooooo`007_ooool2
o`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo1Ol0000;ooooo`?o00003?ooool3o`0006cooooo0_l0000?ooooo`Go00006_ooool3
o`0000cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000Gooooo`007_ooool2
o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo1?l0000<ooooo`?o00002oooool4o`0000kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000gooooo1?l0000=ooooo`Co00003?ooool0
0ol0003oooooooooo`0;ooooo`Co00003?ooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooo
oooo01Wooooo000Nooooo`03o`000?oooooooooo03cooooo0ol0000;ooooo`Co00002oooool5o`00
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`00
00cooooo0_l0000Kooooo`Go00003?ooool4o`00013ooooo00?o0000ooooooooool09oooool001ko
oooo00?o0000ooooooooool0>_ooool3o`0000cooooo1?l0000;ooooo`Go00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000kooooo0ol0000=ooooo`Co00003Oooool00ol0003o
ooooooooo`0Jooooo`Go00003_ooool3o`0003[ooooo000Nooooo`03o`000?oooooooooo03Sooooo
1?l0000;ooooo`Ko00003?ooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo
1Ol0000<ooooo`;o0000;Oooool4o`0000oooooo00?o0000ooooooooool0>Oooool001kooooo00?o
0000ooooooooool0:?ooool2o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`00
0002o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0000=ooooo`03o`000?oo
oooooooo02kooooo0ol0001;ooooo`007_ooool00ol0003oooooooooo`0Vooooo`Co00002oooool6
o`0000cooooo1?l0000<ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0
000<ooooo`;o0000@Oooool00ol0003oooooooooo`1:ooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00002oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>
ooooo`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0S_ooool001kooooo00?o0000oooo
ooooool05Oooool3o`0000_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`;o00003_ooool5o`0000cooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>oooo
o`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0X?ooool001kooooo00?o0000oooooooo
ool00oooool3o`0000cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`;o00003_ooool5o`0000cooooo0_l0002booooo`007_ooool01?l0003oooooooooooooool4o`00
00cooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`00
00gooooo00?o0000ooooooooool0Voooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00Go
00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000<oooo
o`;o0000[?ooool3o`0001Gooooo000Nooooo`03o`000?oooooo000000Co00003Oooool4o`0000co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool000003_ooool4o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0;_ooool2o`0000gooooo1?l0000Fooooo`007_ooool00ol0003ooooo
o`000003o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool2o`0000kooooo1_l0000;ooooo`;o
0000O?ooool2o`0002kooooo0ol0000<ooooo`Go00005_ooool001kooooo00?o0000ooooool00000
0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool2o`0006cooooo
00?o0000ooooooooool03_ooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0001Oooooo
000Nooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1_l0
000;ooooo`;o00003Oooool3o`0006cooooo0_l0000>ooooo`Ko00006_ooool3o`0000cooooo1Ol0
000<ooooo`Co00006?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000;
ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo1?l0000=ooooo`Co00003?ooool00ol0003ooooooooo
o`0;ooooo`Co00003?ooool5o`0000gooooo1?l0000Hooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o00003Oooool3o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool3o`0000kooooo1Ol0000;ooooo`;o00007?ooool5o`0000cooooo1?l0000@
ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000<oooo
o`Co00003?ooool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000=oooo
o`Co00003Oooool4o`0000cooooo00?o0000ooooooooool06oooool5o`0000kooooo0ol0000Zoooo
o`007_ooool00ol0003oooooooooo`18ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002cooooo1?l0000@ooooo`03
o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`Co0000
2oooool5o`0000gooooo00?o0000ooooool000000_l0000;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo
0ol0000=ooooo`Co00003Oooool00ol0003oooooooooo`0]ooooo`?o0000??ooool001kooooo00?o
0000ooooooooool0=_ooool4o`0000_ooooo1_l0000<ooooo`Co00003?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`00043ooooo00?o0000ooooooooool0
>oooool001kooooo00?o0000ooooooooool09_ooool2o`0000gooooo1?l0000;ooooo`Ko00003?oo
ool00ol0003oooooo`000002o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0
000=ooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo02Cooooo1?l0000;
ooooo`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_oo
ool5o`0000cooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00003Oooool4
o`0000_ooooo1_l0000=ooooo`Co00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3
o`0000gooooo00?o0000ooooooooool0T?ooool001kooooo00?o0000ooooooooool04oooool3o`00
00_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5
o`0000cooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool4o`00
00_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`00
00gooooo00?o0000ooooooooool0X_ooool001kooooo00Co0000oooooooooooooooo0ol0000<oooo
o`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000<
ooooo`;o0000]?ooool001kooooo00?o0000ooooool000000ol0000<ooooo`Go00003Oooool4o`00
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
06[ooooo0_l0000_ooooo`;o00005oooool001kooooo1_l0000<ooooo`Co00003Oooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool5o`0000cooooo0_l0001looooo`?o0000;Oooool3o`00
01Oooooo000Nooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000go
oooo0ol0000<ooooo`;o0000K?ooool00ol0003oooooooooo`0>ooooo`Go00006oooool2o`0000go
oooo1?l0000Hooooo`007_ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`Ko00002oooool2o`0000gooooo0ol0001/ooooo`;o00003_ooool4o`0001co
oooo0ol0000<ooooo`Go00006?ooool001kooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool4o`0000_ooooo0_l0000=ooooo`Co00003_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool4o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00006Oooool001kooooo
00?o0000ooooool00000Foooool2o`0000gooooo0ol0000<ooooo`Co00003_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`Ko00002oooool2o`0001cooooo
1Ol0000<ooooo`Co00006_ooool001kooooo00?o0000ooooooooool0FOooool2o`0000gooooo1?l0
000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?oo
ool4o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo01_ooooo1Ol0000>ooooo`?o00006_oo
ool001kooooo00?o0000ooooooooool0F?ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_ooooo0_l0000]ooooo`Co00004?ooool0
0ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00003?ooool4o`00
00cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003Oooool5o`00
00cooooo1?l0000<ooooo`03o`000?oooooooooo02kooooo0ol0000/ooooo`007_ooool00ol0003o
ooooooooo`16ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo0_l0000>ooooo`?o00003_ooool2o`00043ooooo00?o0000ooooooooool0:oooool001kooooo
00?o0000ooooooooool0=_ooool2o`0000gooooo1?l0000;ooooo`Go00003Oooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000kooooo0ol0000=ooooo`?o00003_ooool00ol0003o
ooooooooo`1^ooooo`007_ooool00ol0003oooooooooo`0dooooo`Co00002oooool5o`0000gooooo
1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool00ol0003ooooo
ooooo`1oooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00003Oooool4o`0000_ooooo1_l0
000<ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0ol0000=ooooo`03o`000?oooooooooo083ooooo000Nooooo`03o`000?oooooooooo02;ooooo1?l0
000;ooooo`Go00003_ooool3o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo0ol0
000>ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool04_ooool2o`0000gooooo1?l0000;
ooooo`Ko00003Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000=
ooooo`;o00003_ooool00ol0003oooooooooo`2Booooo`007_ooool00ol0003oooooooooo`0Aoooo
o`?o00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>oooo
o`?o00003_ooool00ol0003oooooooooo`2Sooooo`007_ooool00ol0003oooooooooo`02o`0000go
oooo1?l0000;ooooo`Ko00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000ko
oooo1?l0000=ooooo`;o00003_ooool00ol0003oooooooooo`1Zooooo`;o0000>?ooool001kooooo
00?o0000ooooool000000_l0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo07_ooooo0ol0000gooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool4o`0000gooooo0_l0000=ooooo`;o0000K?ooool2o`0000oooooo1Ol0000Kooooo`;o0000
6Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`?o00003_ooool00ol0003oooooooooo`0<ooooo`?o0000K?ooool3o`0000gooooo
1?l0000Looooo`?o00006Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo0_l0000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0_l0000>ooooo`03o`00
0?oooooooooo00_ooooo1?l0000Jooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`0000co
oooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000go
oooo1?l0000=ooooo`;o00007?ooool4o`0001_ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06Wooooo0_l0000=oooo
o`Co00003?ooool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo
00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0Kooooo`Go00006oooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0J?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`?o00003Oooool4o`0000gooooo0_l0000^ooooo`?o00007?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Eoooool2o`00
00gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`00
0?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool06oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0E_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`?o00003_ooool3o`0000gooooo0_l0001Oooooo`007_ooool00ol0003o
ooooooooo`16ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo05oo
oooo000Nooooo`03o`000?oooooooooo04Cooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo06oooooo
000Nooooo`03o`000?oooooooooo03Cooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo
00?o0000ooooooooool0L?ooool001kooooo00?o0000ooooooooool0<_ooool4o`0000_ooooo1Ol0
000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o
0000ooooooooool0POooool001kooooo00?o0000ooooooooool08_ooool2o`0000gooooo1?l0000;
ooooo`Ko00003?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0
000=ooooo`;o00003_ooool00ol0003oooooooooo`22ooooo`007_ooool00ol0003oooooooooo`0P
ooooo`Co00002oooool5o`0000kooooo0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>
ooooo`?o00003_ooool00ol0003oooooooooo`2Cooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003_ooool4o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool09oooool001kooooo00?o0000ooooooooool03oooool3o`0000_ooooo1Ol0000>ooooo`?o
00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000oooooooo
ool0Noooool2o`0002Sooooo000Nooooo`?o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`00
0?oooooo000000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0000=ooooo`;o0000
K?ooool2o`0000oooooo1?l0000Wooooo`007_ooool3o`0000cooooo1?l0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000>ooooo`03o`000?oo
oooooooo00cooooo0ol0001/ooooo`?o00003Oooool3o`0002Wooooo000Looooo`Co00003?ooool5
o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo0_l0000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooo
oooo01Wooooo000Kooooo`Co00003_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`00
00cooooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`00
00gooooo1?l0000=ooooo`03o`000?oooooooooo02[ooooo000Jooooo`Go00003oooool00ol0003o
ooooooooo`1Yooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo0ol0000>ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0:oooool001_ooooo
1?l0001jooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
0ol0000=ooooo`Co00003Oooool2o`0003gooooo000Looooo`03o`000?oooooo000006Wooooo0_l0
000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0
003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0mooooo`007_ooool0
0ol0003oooooooooo`1Vooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo0ol0000=ooooo`Co00003Oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo
05Gooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`00
0003ooooool0003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`1?oooo
o`007_ooool00ol0003oooooooooo`1Dooooo`?o00003?ooool5o`0000gooooo0ol0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Oooool2o`00067ooooo000Nooooo`03o`00
0?oooooooooo04Cooooo0_l0000<ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooo`00000=ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0
HOooool001kooooo00?o0000ooooooooool0@_ooool4o`0000_ooooo1Ol0000=ooooo`Co00003?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0LOoo
ool001kooooo00?o0000ooooooooool0<_ooool2o`0000gooooo1?l0000;ooooo`Go00003Oooool0
1?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_oo
ool00ol0003oooooooooo`1booooo`007_ooool00ol0003oooooooooo`0`ooooo`Co00002oooool5
o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool0
0ol0003oooooooooo`23ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00003Oooool4o`00
00_ooooo1_l0000<ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4
o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool05oooool0
01kooooo00?o0000ooooooooool07_ooool4o`0000_ooooo1Ol0000>ooooo`?o00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Noooool2o`00
01Sooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000=ooooo`Co00002oooool6o`0000go
oooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`Co00003Oooool2o`0000go
oooo0_l0001/ooooo`03o`000?oooooooooo00kooooo1?l0000Gooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`?o00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool3o`0000kooooo00?o0000ooooooooool03?ooool3o`0006cooooo
0_l0000>ooooo`?o00006Oooool001kooooo0_l0000<ooooo`Co00002oooool6o`0000gooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0
000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`?o00003_ooool4o`0000gooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0:
ooooo`Co00003_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`0000cooooo1?l0000>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>
ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooooooo00Wooooo1Ol0000?oooo
o`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool3o`0000kooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0Koooo
o`007_ooool00ol0003oooooooooo`0:ooooo`?o0000Noooool3o`0000cooooo1?l0000>ooooo`?o
00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`?o00003Oooool4o`0000gooooo00?o0000oooooooo
ool0;?ooool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Yooooo`;o0000
3Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0ol0000>ooooo`Go0000
3?ooool2o`0000kooooo00?o0000ooooooooool0;Oooool001kooooo00?o0000ooooooooool0M_oo
ool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003Ooo
ool4o`0000gooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00003Oooool4
o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<
ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000oooo
ooooool0I?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`?o00003Oooool4o`0000gooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o
00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo
0000ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0DOooool001kooooo
00?o0000ooooooooool0D_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool3o`0000gooooo0_l0001Sooooo`007_ooool00ol0003ooooooooo
o`12ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo06?ooooo000N
ooooo`03o`000?oooooooooo043ooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo07?ooooo000Noooo
o`03o`000?oooooo0000033ooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo00?o0000
ooooooooool0M?ooool001kooooo00Co0000ooooool0003o0000;Oooool4o`0000_ooooo1Ol0000=
ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000
ooooooooool0QOooool001kooooo1Ol0000Looooo`;o00003Oooool4o`0000_ooooo1_l0000<oooo
o`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0000=
ooooo`;o0000K?ooool00ol0003oooooooooo`0Iooooo`007_ooool3o`0001cooooo1?l0000;oooo
o`Go00003_ooool3o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`?o00003_ooool00ol0003oooooooooo`0<ooooo`?o0000K?ooool2o`0001[ooooo000Nooooo`;o
00003_ooool00ol0003oooooooooo`0;ooooo`Co00002oooool6o`0000gooooo00?o0000ooooool0
00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0000=ooooo`;o
00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo1?l0000Iooooo`007Oooool2o`0001_ooooo1Ol0000>ooooo`?o0000
K?ooool00ol0003oooooooooo`0<ooooo`?o00003?ooool4o`0000kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0001_ooooo000Looooo`03o`000?oo
oooo000001[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003?oo
ool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1?l0000=ooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool06_ooool3o`0007_ooooo0ol0000<ooooo`Co00003_ooool3
o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>ooooo`03o`000?oooooo
oooo01cooooo000Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0JOooool2o`00
00gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`00
00cooooo0_l0000>ooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo08Ko
oooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo07Gooooo
0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo
1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0003ooooooooo
o`1dooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0
000=ooooo`Co00003Oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000=
ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003o
oooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`11ooooo`007_ooool00ol0
003oooooooooo`1Rooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00_ooooo0ol0000=ooooo`Co00003Oooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo057o
oooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003
ooooool0003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`1Cooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo0ol0000<ooooo`Go0000
3Oooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo0ol0000=ooooo`;o0000
IOooool001kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`;o00003?oo
ool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003Ooo
ool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo06Gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo00kooooo0ol0000]ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`1eooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0>ooooo`Co00007?ooool2o`0000gooooo1?l0000;ooooo`Go
00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000<oooo
o`?o00003Oooool2o`0007Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Gooooo0ol0000>ooooo`?o00007?ooool4o`0000_ooooo1Ol0000=
ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000>
ooooo`03o`000?oooooooooo00[ooooo1Ol0001Jooooo`03o`000?oooooooooo01_ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo1?l0
000<ooooo`?o00003_ooool00ol0003oooooooooo`0;ooooo`Co00002oooool6o`0000cooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
0_l0000=ooooo`;o00002oooool6o`0000kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000001_ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo0ol0000>ooooo`03o`000?oooooooooo01[o
oooo1Ol0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0;ooooo`Co00002_ooool6o`0000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`?o00007?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Gooooo1?l0000=oooo
o`03o`000?oooooooooo01[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wooooo0_l0000<oooo
o`Go00003?ooool5o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>oooo
o`Co00006oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Gooooo00Co0000oooooooooooo0000;?ooool3o`0007[ooooo1?l0000;ooooo`Go00003_ooool3
o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0000Mooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@0_ooool01Ol0003ooooo
oooooooooooo000002gooooo00?o0000ooooooooool0JOooool2o`0000cooooo1Ol0000<ooooo`Go
00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool4o`0000cooooo0ol0000Nooooo`00
7_ooool00ol0003oooooooooo`2Eooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooo`0000gooooo1?l0000=ooooo`?o00003_ooool00ol0003oooooooooo`0Nooooo`00
7_ooool00ol0003oooooooooo`25ooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`00
0?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo0ol0000>ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0
7oooool001kooooo00?o0000ooooooooool0Poooool4o`0000_ooooo1Ol0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0000=ooooo`Co00003Oooool4o`0000gooooo00?o0000ooooooooool0
<?ooool001kooooo00?o0000ooooooooool0Loooool2o`0000cooooo1Ol0000<ooooo`Go00003Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000_ooooo0ol0000>ooooo`03o`000?oo
oooooooo037ooooo000Nooooo`03o`000?oooooooooo077ooooo1?l0000;ooooo`Go00003_ooool3
o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`Co00003Oooool4o`0000gooooo0_l0
0013ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00003?ooool5o`0000cooooo1Ol0000=
ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00002oooool3
o`0000kooooo00?o0000ooooooooool0@oooool001kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0mooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000003?ooool4o`0000gooooo1?l0000=ooooo`;o0000EOooool001kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0]ooooo`;o00003?ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00002oooool3o`00
00kooooo00?o0000ooooooooool0EOooool001kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`?o0000;?ooool4o`0000_ooooo1_l0000=ooooo`?o00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`Co00003Oooool4o`0000gooooo0_l0001Wooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo1?l0000Looooo`;o00002oooool5o`0000gooooo
1?l0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool5o`0000cooooo
0ol0000=ooooo`;o0000J?ooool001cooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0
000Kooooo`Go00002_ooool6o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool4o`0000kooooo00?o0000ooooooooool02_ooool5o`0006Sooooo000L
ooooo`04o`000?oooooo0000o`0000gooooo1?l0000<ooooo`?o00003_ooool00ol0003ooooooooo
o`09ooooo`Ko00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`;o00002oooool6o`0000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`006oooool4o`0000gooooo0ol0
000>ooooo`03o`000?oooooooooo01Wooooo1_l0000>ooooo`?o0000K?ooool00ol0003ooooooooo
o`0:ooooo`Go00002_ooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool0000Looooo`006oooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo01_ooooo1Ol0
000?ooooo`03o`000?oooooooooo06Wooooo0_l0000;ooooo`Ko00003?ooool5o`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool00ol0003oooooo`00000Mooooo`006_ooool3o`000003ooooool0003o
oooo00_ooooo00?o0000ooooooooool0;Oooool3o`0007[ooooo1?l0000:ooooo`Ko00003_ooool3
o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0001kooooo000Iooooo`?o00000_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0JOooool2
o`0000cooooo1Ol0000<ooooo`Go00003Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
000000kooooo1?l0000Mooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0:Gooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3
o`0000kooooo0ol0000Oooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
09Gooooo0_l0000<ooooo`Go00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`00
00kooooo1?l0000<ooooo`?o00008?ooool001kooooo00?o0000ooooooooool0Toooool4o`0000_o
oooo1Ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`Co00003Oooool3o`00
00kooooo00?o0000ooooooooool08?ooool001kooooo00?o0000ooooooooool0Poooool2o`0000co
oooo1Ol0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_o
oooo0ol0000>ooooo`03o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo087ooooo
1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003Oooool4o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo077ooooo
0_l0000<ooooo`Go00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo
1Ol0000;ooooo`?o00003_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03kooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`00000<ooooo`Co00003Oooool4o`0000gooooo0_l00015ooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`;o0000;oooool2o`0000cooooo1Ol0000<ooooo`Go00003Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000_ooooo0ol0
000>ooooo`03o`000?oooooooooo04Gooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool03Oooool4o`0002cooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02_ooool4o`0000gooooo1?l0000<ooooo`?o0000Eoooool001kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0=ooooo`Go00006oooool2o`0000cooooo1Ol0000<oooo
o`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1Ol0000;oooo
o`?o00003?ooool4o`0005Sooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool3o`0000gooooo1?l0000Kooooo`Co00002oooool6o`0000gooooo0ol0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool4o`0000cooooo0ol0000<ooooo`Co
0000FOooool001kooooo0_l0000<ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o0000
3_ooool00ol0003oooooooooo`09ooooo`Go00003Oooool4o`0000gooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000;ooooo`Co0000
2oooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool00_l0
000<ooooo`?o00003_ooool3o`0000kooooo00?o0000ooooooooool06Oooool6o`0000kooooo0ol0
001Zooooo`?o00003?ooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo000J
ooooo`05o`000?oooooo0000ooooool000003?ooool4o`0000cooooo0ol0000>ooooo`03o`000?oo
oooooooo01_ooooo1?l0000@ooooo`03o`000?oooooooooo06Oooooo1?l0000;ooooo`Ko00003?oo
ool4o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06oooool001Wooooo0ol00002ooooo`03o`000?oooooo
oooo00Wooooo0ol0000>ooooo`03o`000?oooooooooo02gooooo0ol0001Zooooo`;o00003Oooool4
o`0000_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000Nooooo`006Oooool4
o`000003ooooool0003ooooo00Wooooo0ol0000>ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0J?ooool3o`0000_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0
000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo000001oooooo000Hooooo`?o00000oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo09[ooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo0ol0000Pooooo`005oooool3o`0000Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Jooooo`?o00003?ooool5o`0000cooooo1?l0000=
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0001oooooo000G
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Toooool2o`0000gooooo1?l0000<
ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0
000Qooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09;ooooo0ol0000<
ooooo`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1?l0
000<ooooo`?o00008_ooool001kooooo00?o0000ooooooooool0POooool2o`0000gooooo1?l0000<
ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool4o`0000gooooo0ol0
000>ooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo083ooooo0ol0000<
ooooo`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1Ol0
000;ooooo`?o00003_ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo1?l0000=ooooo`Co00003Oooool00ol0003ooooooooo
o`0dooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000;_ooool3o`0000cooooo1Ol0000<
ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_ooooo0ol0
000>ooooo`03o`000?oooooooooo03Gooooo000Nooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool03Oooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool4o`0004Oooooo000Noooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool5o`0001[ooooo0ol0000<oooo
o`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`Go00002oooool3o`0000cooooo0ol00019ooooo`007_ooool2o`0000kooooo00?o0000oooo
ooooool02oooool00ol0003oooooo`00000>ooooo`?o00003Oooool4o`0000cooooo00?o0000oooo
ooooool02oooool4o`0000cooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo1?l0000<ooooo`?o00002oooool4o`0000kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o
00003_ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`0000cooooo0_l0000Kooooo`Go
00003?ooool4o`00013ooooo00?o0000ooooooooool0FOooool3o`0000cooooo1?l0000;ooooo`Go
00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool001cooooo00?o0000ooooool000002oooool00ol0003oooooo`00000>ooooo`?o0000
3_ooool3o`0000gooooo00?o0000ooooooooool06_ooool5o`0000kooooo0ol0001[ooooo`?o0000
3?ooool4o`0000_ooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Kooooo`006oooool01?l0003oooooooooool0000;ooooo`;o0000
3_ooool5o`0000cooooo0_l0000]ooooo`Co00003oooool00ol0003oooooooooo`1Xooooo`Co0000
2oooool6o`0000cooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Looooo`006?ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Sooooo0ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0^ooooo`?o0000J_oo
ool2o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`000002o`0000_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo000H
ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`Go00003?ooool2o`00047ooooo00?o0000
ooooooooool0Ioooool4o`0000_ooooo1_l0000<ooooo`Co00003?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01kooooo000Gooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`?o00003Oooool0
0ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00002oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000Qooooo`005_ooool5o`0000?ooooo00?o0000ooooooooool01_ooool2o`00
0:cooooo0ol0000;ooooo`Ko00003?ooool4o`0000gooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2
o`0002;ooooo000Fooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
09_ooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
00kooooo0ol0000Rooooo`005Oooool2o`0000Oooooo00?o0000ooooooooool0X_ooool3o`0000co
oooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`00
027ooooo000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0TOooool2o`0000go
oooo1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000ko
oooo0ol0000Sooooo`007_ooool00ol0003oooooooooo`2@ooooo`?o00003?ooool5o`0000cooooo
1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002Go
oooo000Nooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0;_ooool2o`0000gooooo
1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0ol0000=ooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000^ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`Ko00002oooool2o`0003Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool03_ooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000go
oooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool2o`0003Wo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03cooooo0_l0000>ooooo`Ko00006_ooool3o`00
00cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo1_l0000;ooooo`;o00003Oooool3o`0003Wooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`Co0000
3Oooool4o`0000cooooo00?o0000ooooooooool02oooool4o`0000cooooo1Ol0000=ooooo`Co0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000;ooooo`;o0000
3Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`;o
00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`Go
00002oooool2o`0001cooooo1Ol0000<ooooo`Co00004?ooool00ol0003oooooooooo`1Iooooo`;o
00003Oooool3o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01?ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003Oooool4o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo01_ooooo1Ol0000>oooo
o`?o0000Joooool2o`0000cooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00?ooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0<ooooo`;o00003_ooool5o`0000cooooo0_l0000/ooooo`Co00004?ooool00ol0003ooooooooo
o`1Xooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000000_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooool0
00003_ooool3o`0000gooooo1?l0000=ooooo`03o`000?oooooooooo02gooooo0ol0001[ooooo`;o
00003Oooool4o`0000_ooooo1Ol0000=ooooo`03o`000?oooooo000000;o00002oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01onYZJWo410@o`000?l@413oZJVYooooool000001?ooool00ol0003oooooooooo`07
ooooo`;o00003_ooool5o`0000cooooo0_l00010ooooo`03o`000?oooooooooo06Sooooo1?l0000;
ooooo`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool07_ooool001Kooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`06ooooo`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0Voooool2
o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`000002o`0000_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo000Foooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`Go00003?ooool2o`000:_ooooo1?l0000;oooo
o`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`005Oooool3o`00
00Kooooo00?o0000ooooooooool01Oooool3o`0000gooooo00?o0000ooooooooool0Voooool2o`00
00gooooo1?l0000;ooooo`Ko00003Oooool4o`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000008oooool001Co
oooo1Ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0002/ooooo`?o00002oooool6o`0000co
oooo1?l0000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000Tooooo`005?ooool3o`0000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000_o
oooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00009?ooool001?ooooo
0_l00009ooooo`03o`000?oooooooooo0:3ooooo0ol0000<ooooo`Go00003?ooool4o`0000gooooo
00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000Sooooo`004_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05kooooo0_l0000_ooooo`;o00003Oooool4o`0000cooooo
1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`0002Gooooo
000Nooooo`03o`000?oooooooooo05kooooo0ol0000]ooooo`?o00003?ooool5o`0000cooooo1?l0
000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo04cooooo0_l0000?ooooo`Go00006oooool2o`0000gooooo1?l0
000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000gooooo0ol0
000<ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0C?ooool3o`0000gooooo1?l0000L
ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool6o`0000_ooooo0_l0000=ooooo`?o0000:Oooool001kooooo0_l0000>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooo
oooo00_ooooo1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`Co00002oooool2o`0000gooooo1?l0000>ooooo`03o`000?oooooo
oooo01Wooooo000Mooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`;o00007?ooool5o`00
00cooooo1?l0000@ooooo`03o`000?oooooooooo05Wooooo0_l0000=ooooo`?o00003?ooool4o`00
00kooooo00?o0000ooooooooool06_ooool001cooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000kooooo0ol0001Zooooo`;o
00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo01_ooooo000Kooooo`04o`00
0?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o
00003_ooool3o`0000gooooo0_l0000]ooooo`Co00004?ooool00ol0003oooooooooo`1Xooooo`?o
00003?ooool5o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo01cooooo000Jooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000go
oooo1Ol0000<ooooo`?o00003Oooool00ol0003oooooooooo`0^ooooo`?o0000Joooool2o`0000co
oooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo01go
oooo000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`1Xooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool07_ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003ooooooooo
o`2Kooooo`;o00003Oooool4o`0000_ooooo1Ol0000=ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`?o00003_ooool00ol0003ooooooooo
o`2Zooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`005?ooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00Cooooo1?l0000=ooooo`;o00003_ooool00ol0003oooooooooo`2K
ooooo`;o00003Oooool4o`0000_ooooo1_l0000<ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo000D
ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`?o00003_ooool00ol0003oooooooooo`2Z
ooooo`Co00002oooool5o`0000kooooo0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo000Coooo
o`Co00001oooool00ol0003oooooooooo`03ooooo`;o00003_ooool00ol0003oooooooooo`2Koooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000009Oooool001;ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Zoooool3o`0000_ooooo1Ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o
00009_ooool001;ooooo0_l0000:ooooo`05o`000?ooooooooooooooool00000K?ooool2o`0002oo
oooo0_l0000=ooooo`Co00002oooool6o`0000gooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`00000>ooooo`Co00009Oooool0017ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1^ooooo`?o0000;Oooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool3o`0002Oooooo000@ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0G?ooool2o`0000oooooo1Ol0000Kooooo`;o00003Oooool4o`0000cooooo1Ol0
000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0
000=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0G?ooool3o`0000gooooo1?l0000L
ooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool3o`0000kooooo00?o0000ooooooooool03?ooool3o`0001Wooooo000Noooo
o`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0_l0000>oooo
o`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000gooooo0_l0000=oooo
o`Co00006_ooool001gooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`Co
00003Oooool2o`0001cooooo1?l0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0<ooooo`?o
00003?ooool4o`0001_ooooo000Looooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000oooooo
00?o0000ooooooooool0JOooool2o`0000gooooo1?l0000<ooooo`Go00006oooool001_ooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`;o0000;_ooool3o`0007_ooooo
0ol0000<ooooo`Co00003_ooool3o`0001cooooo000Jooooo`05o`000?ooooooooooooooool00000
2oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`1Yooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000001gooooo
000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Oooool2o`000:cooooo0ol0
000<ooooo`Go00003Oooool3o`0000gooooo00?o0000ooooooooool07_ooool001Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`;o0000WOooool2o`0000cooooo1?l0000<
ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo01oooooo000Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Z_ooool4o`0000_ooooo1Ol0000=oooo
o`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000>ooooo`Co
00003?ooool3o`0000kooooo00?o0000ooooooooool0Voooool2o`0000gooooo1?l0000;ooooo`Go
00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08Oooool001Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`;o
00003_ooool3o`0000kooooo00?o0000ooooooooool0Z_ooool4o`0000_ooooo1Ol0000=ooooo`Co
00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08_ooool001;ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`Co0000
3Oooool2o`0000kooooo00?o0000ooooooooool0Voooool2o`0000gooooo1?l0000;ooooo`Ko0000
3?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Sooooo`004_ooool2o`0000[ooooo00Co0000oooooooooooo
oooo0ol0000>ooooo`03o`000?oooooooooo0:[ooooo1?l0000;ooooo`Go00003_ooool3o`0000co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09?ooool0017ooooo1?l00009ooooo`04o`000?ooooooooooooooo`;o
00003_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co
00002oooool6o`0000gooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000Wooooo`00
4?ooool3o`0000_ooooo00Co0000oooooooooooo0000OOooool2o`0002kooooo0ol0000;ooooo`Go
00003_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0002Sooooo000@ooooo`;o0000
3?ooool00ol0003oooooo`00001/ooooo`;o00003oooool4o`0001cooooo0_l0000=ooooo`Co0000
2oooool6o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`Co0000
9oooool000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1/ooooo`?o00003Ooo
ool3o`0001gooooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`?o0000:Oooool000kooooo00?o0000ooooooooool03Oooool2
o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5
o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00003Oooool0
0ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2
o`0000kooooo00?o0000ooooooooool06Oooool001gooooo0_l0000>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`03o`000?oooooooooo
01_ooooo1?l0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0Zooooo`007?ooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000oooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0[ooooo`006oooool01?l0003oooooooooool0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo0ol0000=ooooo`Co00003Oooool2o`0002kooooo0ol0002[ooooo`00
6_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Zooooo`00
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o0000
3Oooool2o`000>kooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000oooo
o`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0k_ooool001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool3o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo0?kooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooo000000gooooo1Ol0000<ooooo`?o00003_ooool00ol0003oooooooooo`3ooooo
o`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo0?oooooo4Oooool001Cooooo
00?o0000ooooooooool01oooool01ol0003ooooooooooooooooo0000ooooool000003_ooool4o`00
00cooooo0ol0000>ooooo`03o`000?oooooooooo0?oooooo4_ooool001?ooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooooooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo
0?oooooo8oooool0013ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`04o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo0?oooooo9?ooool0013ooooo0_l00002ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooo`000002o`0000kooooo00?o0000ooooooooool0
ooooooleooooo`003oooool4o`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`00
0?l0000>ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo0ol00005ooooo`03o`000?oo
oooooooo00Gooooo0_l0003oooooodWooooo000>ooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom8ooooo`003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0959237, -0.0895275, \
0.00393125, 0.00393125}}]
}, Open  ]],

Cell["\<\
One can see that particles will be attracted to the mass \
distribution along the diagonal unless they are close to the edge of the box, \
so that they are attracted to the mass distribution in one of the other \
surrounding boxes. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Interpolation of the Force from the Grid to Particle \
Positions\
\>", "Section",
  CellTags->{"i:63", "c:34"}],

Cell[TextData[{
  "Now that we know the force on the grid, we must interpolate the force back \
to the particle positions. One can easily do this by first creating \
interpolating functions for ",
  Cell[BoxData[
      \(TraditionalForm\`F\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_y\)]],
  ", and then evaluating these functions at each particle  position. This is \
set up in the module below:"
}], "Text"],

Cell[BoxData[
    \(Fpart[r_, Fx_, Fy_]\  := 
      Module[{}, \[IndentingNewLine]fxi\  = \ 
          Interpolation[Flatten[Fx, 1], 
            InterpolationOrder \[Rule] 1]; \[IndentingNewLine]fyi\  = \ 
          Interpolation[Flatten[Fy, 1], 
            InterpolationOrder \[Rule] 1]; \[IndentingNewLine]F\  = \ 
          Table[{fxi[r[\([m, 1]\)], r[\([m, 2]\)]], 
              fyi[r[\([m, 1]\)], r[\([m, 2]\)]]}, {m, 1, 
              Length[r]}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.74"],

Cell["\<\
We reduce the order of the interpolation to 1 (linear \
interpolation) from the default of 3 (cubic interpolation) in order to speed \
up the process. Also, we will find that linear interpolation is actually more \
accurate, because the total system momentum is exactly conserved in the \
simulation when linear interpolation is used.\
\>", "Text"],

Cell["\<\
\t To test this module, we evaluate the force on the particles that \
are evenly distributed along the box diagonal:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Fpart[r, Fx, Fy];\)\), "\n", 
    \(F\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.75"],

Cell[BoxData[
    \({{2.969107051673673`*^-16, 8.229602123953836`*^-15}, {0.`, 
        0.`}, {8.881784197001252`*^-15, 
        8.881784197001252`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {3.902877655076609`*^-15, 
        4.623635174044601`*^-15}, {0.`, 0.`}, {0.`, 
        0.`}, {1.1135241121310874`*^-14, 
        1.0181040951492131`*^-14}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 
        0.`}, {\(-3.0756135938911294`*^-15\), \(-1.1876428206694692`*^-15\)}, \
{0.`, 0.`}, {1.4415150379361347`*^-15, 
        8.506083262705283`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 0.`}, {0.`, 0.`}, {0.`, 
        0.`}, {1.4415150379361347`*^-15, 
        8.506083262705283`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 0.`}}\)], "Output"]
}, Open  ]],

Cell["\<\
The forces on the particles vanish because of their even \
distribution.  \
\>", "Text"],

Cell["\<\
\tFor those who might wish to apply the PIC method on a mainframe \
computer, the above module is reproduced below without making use of \
interpolating functions. Rather, the linear interpolation is carried out \
directly. One can see from this module that linear interpolation back to the \
particles is just another form of area weighting:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Fpart1[r_, Fx_, Fy_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({x, y, Npart, 
              area1, \[Delta]x, \[Delta]y, \[Delta]x1, \[Delta]y1, a1, a2, 
              a3, a4, i, i1, j, j1, fx, fy}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Npart\  = \ Length[r]\), ";", 
              "\[IndentingNewLine]", \(\[CapitalDelta]A = \[CapitalDelta]x*\
\[CapitalDelta]y\), ";", "\[IndentingNewLine]", 
              StyleBox[\( (*\ x\ and\ y\ positions\ of\ particle\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(x = 
                Table[r[\([n, 1]\)], {n, 1, Npart}]\), ";", 
              "\[IndentingNewLine]", \(y = 
                Table[r[\([n, 2]\)], {n, 1, Npart}]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  list\ of\ lengths\ of\ the\ rectangle\ sides\ for\ each\ \
particle\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Delta]x = Mod[x, \[CapitalDelta]x]\),
               ";", "\[IndentingNewLine]", \(\[Delta]y = 
                Mod[y, \[CapitalDelta]y]\), ";", 
              "\[IndentingNewLine]", \(\[Delta]x1\  = \ \[CapitalDelta]x - \
\[Delta]x\), ";", 
              "\[IndentingNewLine]", \(\[Delta]y1\  = \ \[CapitalDelta]y - \
\[Delta]y\), ";", "\[IndentingNewLine]", 
              StyleBox[\( (*\ list\ of\ rectangle\ areas\ \ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(a1\  = \ 
                Table[\[Delta]x1[\([n]\)]\ \[Delta]y1[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(a2\  = \ 
                Table[\[Delta]x1[\([n]\)] \[Delta]y[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(a3\  = \ 
                Table[\[Delta]x[\([n]\)] \[Delta]y[\([n]\)], {n, 1, Npart}]\),
               ";", "\[IndentingNewLine]", \(a4\  = \ 
                Table[\[Delta]x[\([n]\)] \[Delta]y1[\([n]\)], {n, 1, 
                    Npart}]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  list\ of\ surrounding\ grid\ points\ for\ all\ particles\ \ \
*) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(i\  = 
                Quotient[x, \[CapitalDelta]x] + 1\), ";", 
              "\[IndentingNewLine]", \(j\  = \ 
                Quotient[y, \[CapitalDelta]y] + 1\), ";", 
              "\[IndentingNewLine]", \(i1\  = \ 1 + Mod[i, Mx]\), ";", 
              "\[IndentingNewLine]", \(j1\  = \ 1 + Mod[j, My]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  linear\ interpolation\ by\ area\ weighting\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(fx\  = 
                Table[Fx[\([i[\([n]\)], j[\([n]\)]]\)]*
                      a1[\([n]\)]\  + \[IndentingNewLine]\ 
                    Fx[\([i[\([n]\)], j1[\([n]\)]]\)]*a2[\([n]\)]\  + \ 
                    Fx[\([i1[\([n]\)], j1[\([n]\)]]\)]*a3[\([n]\)]\  + \ 
                    Fx[\([i1[\([n]\)], j[\([n]\)]]\)]*a4[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(fy\  = 
                Table[\ Fy[\([i[\([n]\)], j[\([n]\)]]\)]*
                      a1[\([n]\)]\  + \[IndentingNewLine]Fy[\([i[\([n]\)], 
                          j1[\([n]\)]]\)]*a2[\([n]\)]\  + \ 
                    Fy[\([i1[\([n]\)], j1[\([n]\)]]\)]*a3[\([n]\)]\  + \ 
                    Fy[\([i1[\([n]\)], j[\([n]\)]]\)]*a4[\([n]\)], {n, 1, 
                    Npart}]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ table\ of\ forces\ for\ each\ particle, \ 
                  paroperly\ normalized\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(F = 
                Table[{fx[\([m]\)], fy[\([m]\)]}, {m, 1, 
                      Npart}]/\[CapitalDelta]A\), ";"}]}], "]"}]}], 
      ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.76"],

Cell[TextData[{
  "We must now put these modules together to create the force function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " used in the leapfrog routine:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(f[r_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*determine\ the\ density\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          RowBox[{\(density[r]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ force\ on\ the\ grid\ and\ the\ potential\ \
matrix\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(fft\[Phi][\[Rho]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ force\ at\ the\ particle\ positions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Fpart[r, Fx, Fy]\)}]}], " ", 
        "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.77"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.5 Examples", "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{

Cell["Code Tests ", "Section",
  CellTags->"c:36"],

Cell[TextData[{
  "It is always very important to test the validity of simulation results  \
One type of test involves running example problems where one already knows \
the answer. These sort of tests are used in the early stages of code \
development, to find errors in the program. For instance, we can take two \
particles a distance ",
  Cell[BoxData[
      \(TraditionalForm\`2  R\)]],
  " apart and orbit the particles around one another. Theoretically, they \
should follow a circular orbit of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " if they are given a velocity  ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " such that the centrifugal force balances the gravitational attraction. \
Since we are solving for the gravitational force in two dimensions only, the \
force of gravitational attraction between particles a distance ",
  Cell[BoxData[
      \(TraditionalForm\`2  R\)]],
  " apart is ",
  Cell[BoxData[
      \(TraditionalForm\`F = G\ m\^2/\ R\)]],
  ". Thus, for circular motion, ",
  Cell[BoxData[
      \(TraditionalForm\`m\ v\^2/R = G\ m\^2/R\)]],
  ", which implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(v\^2 = G\ m\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.78",
    ButtonData:>"Cell 7.78",
    ButtonStyle->"Hyperlink"],
  ", we test this result by running the code for several rotation periods. \
Also, we time the code using a function called ",
  StyleBox["Timing",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", available in the add-on package ",
  StyleBox["Utilities",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Utilities`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(m = 1; M = 40; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t = 0.04;\[IndentingNewLine]\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(R\  = \ 0.1;\)\), "\n", 
    \(\(r0\  = \ {{0.5, \ 0.5 - R}, {0.5, 0.5\  + \ R}};\)\), "\n", 
    \(\(v\  = \ Sqrt[\ G\ m];\)\), "\n", 
    \(\(\(p0\  = \ {{m\ v, 0}, {\(-m\)\ v, 0}};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Timing[leapfrog[r0, p0, 30, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.78"],

Cell[BoxData[
    \({15.08`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["\<\
The code takes quite a while to run, but most of the time is spent \
on the FFT.  Fortunately, the time for the FFT is not affected by an increase \
in the number of particles, so running the code with a thousand particles \
doesn't take much longer than running it with two particles. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 30, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.79"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5 .4 Mdot
.5 .6 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0002Qooooo`;o
0000Z?ooool000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo0:7ooooo0_l0002Xooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000:7ooooo0_l0002Xooooo`000oooool00ol0003ooooooooo
o`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Qooooo`;o0000
Z?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53933 .40684 Mdot
.46067 .59316 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`2^ooooo`;o0000Voooool000?ooooo00?o410@ooooooooool0
2_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0:kooooo0_l0002Kooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0U?ooool2o`000;Gooooo00001?nHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
U?ooool2o`000;Gooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57323 .42634 Mdot
.42677 .57366 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0;Wooooo0_l0002@ooooo`006_ooool00ol0003o
ooooooooo`2iooooo`;o0000T?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo08Wooooo0_l00030ooooo`006_ooool00ol0003oooooooooo`29oooo
o`;o0000`?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59777 .45527 Mdot
.40223 .54473 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`31ooooo`;o0000R?ooool001[o
oooo00?o0000ooooooooool0`Oooool2o`0008Sooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0P?ooool2o`000<Wooooo000Jooooo`03o`000?oooooooooo083ooooo0_l00039oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6108 .48955 Mdot
.3892 .51045 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0aOooool2o`0008Cooooo000Jooooo`03o`00
0?oooooooooo0<Gooooo0_l00024ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`1looooo`;o0000cOooool001[ooooo00?o0000ooooooooool0O?ooool2
o`000<gooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61177 .525 Mdot
.38823 .475 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`1looooo`;o
0000cOooool001[ooooo00?o0000ooooooooool0O?ooool2o`000<gooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0aOoo
ool2o`0008Cooooo000Jooooo`03o`000?oooooooooo0<Gooooo0_l00024ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60134 .55777 Mdot
.39866 .44223 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0003:ooooo`00
6_ooool00ol0003oooooooooo`1oooooo`;o0000b_ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0`_ooool2o`0008Oooooo000Joooo
o`03o`000?oooooooooo0<;ooooo0_l00027ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58105 .58485 Mdot
.41895 .41515 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08Kooooo
0_l00033ooooo`006_ooool00ol0003oooooooooo`26ooooo`;o0000`oooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0^oooool2o`0008kooooo000Jooooo`03o`000?oooooo
oooo0;_ooooo0_l0002>ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55292 .60376 Mdot
.44708 .39624 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08oooooo0_l0002jooooo`000oooool00ol@413oooooooooo`09ooooo`Go00001_ooool3o`0008oo
oooo0_l0002jooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/_ooool2o`0009Oooooo
0003ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`2booooo`;o0000Uoooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51949 .61255 Mdot
.48051 .38745 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2Jooooo`;o0000[oooool0
01[ooooo00?o0000ooooooooool0V_ooool2o`000:oooooo00001?lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom<oooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooo
oom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2Wooooo`;o0000X_ooool001[ooooo00?o0000ooooooooool0Yooo
ool2o`000:;ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48397 .60983 Mdot
.51603 .39017 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0:Kooooo0_l0002Sooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo0_l0002Soooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooo
oom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo09_ooooo0_l0002^ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo09_ooooo0_l0002^ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45028 .59508 Mdot
.54972 .40492 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2aooooo`;o0000V?ooool000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo0;7ooooo0_l0002Hooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo093ooooo
0_l0002iooooo`000oooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2@ooooo`;o0000^Oooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42264 .56907 Mdot
.57736 .43093 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2jooooo`;o0000Soooool001[ooooo00?o
0000ooooooooool0^_ooool2o`0008oooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0Qoooool2o`000<;ooooo000Jooooo`03o`000?oooooooooo08Oooooo0_l0
0032ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40495 .53421 Mdot
.59505 .46579 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`30ooooo`;o0000ROooool001[ooooo00?o0000ooooooooool0`?ooool2
o`0008Wooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0POooool2o`000<Sooooo000Jooooo`03o`00
0?oooooooooo087ooooo0_l00038ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40022 .49463 Mdot
.59978 .50537 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo083ooooo0_l00039ooooo`006_ooool0
0ol0003oooooooooo`20ooooo`;o0000bOooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0<7ooooo0_l00028ooooo`006_ooool00ol0003oooooooooo`31ooooo`;o0000
R?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40943 .4558 Mdot
.59057 .5442 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`23ooooo`;o0000a_ooool001[o
oooo00?o0000ooooooooool0Poooool2o`000<Kooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0__ooool2o`0008_ooooo000Jooooo`03o`000?oooooooooo0;kooooo0_l0002;oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43105 .42313 Mdot
.56895 .57687 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2:
ooooo`;o0000_oooool001[ooooo00?o0000ooooooooool0R_ooool2o`000;oooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0]oooool2o`00
09;ooooo000Jooooo`03o`000?oooooooooo0;Oooooo0_l0002Booooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46158 .40047 Mdot
.53842 .59953 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0002Dooooo`;o
0000]Oooool000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo09Cooooo0_l0002eooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0[Oooool2o`0009cooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000[Oooool2o`0009cooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49674 .38971 Mdot
.50326 .61029 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2Pooooo`;o0000ZOooool0
01[ooooo00?o0000ooooooooool0X?ooool2o`000:Wooooo00001?lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom<oooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooo
oom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0:;ooooo0_l0002Wooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0:;ooooo0_l0002Wooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53228 .39126 Mdot
.46772 .60874 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0:_ooooo0_l0002Nooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo0_l0002Noooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0U_oo
ool2o`000;?ooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0U_ooool2o`000;?ooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56435 .40411 Mdot
.43565 .59589 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2fooooo`;o0000Toooool000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo0;Kooooo0_l0002Cooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo08_ooooo
0_l0002nooooo`000oooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2;ooooo`;o0000__ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58994 .42652 Mdot
.41006 .57348 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0__ooool2o`0008_ooooo000Jooooo`03o`000?oooooooooo0;kooooo0_l0002;ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo08?ooooo0_l00036ooooo`006_ooool00ol0003oooooooooo`23oooo
o`;o0000a_ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6067 .45629 Mdot
.3933 .54371 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`34ooooo`;o0000QOooool001[o
oooo00?o0000ooooooooool0a?ooool2o`0008Gooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0O_ooool2o`000<_ooooo000Jooooo`03o`000?oooooooooo07kooooo0_l0003;oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61281 .49055 Mdot
.38719 .50945 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`36ooooo`;o0000Poooool001[ooooo00?o0000ooooooooool0a_ooool2o`0008?ooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`1looooo`;o0000cOooool001[ooooo00?o0000ooooooooool0O?ooool2
o`000<gooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60714 .52583 Mdot
.39286 .47417 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`1mooooo`;o
0000c?ooool001[ooooo00?o0000ooooooooool0OOooool2o`000<cooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0a?oo
ool2o`0008Gooooo000Jooooo`03o`000?oooooooooo0<Cooooo0_l00025ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58949 .55811 Mdot
.41051 .44189 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo08?ooooo0_l00036ooooo`00
6_ooool00ol0003oooooooooo`23ooooo`;o0000a_ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0__ooool2o`0008_ooooo000Joooo
o`03o`000?oooooooooo0;kooooo0_l0002;ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5611 .58332 Mdot
.4389 .41668 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08gooooo
0_l0002looooo`006_ooool00ol0003oooooooooo`2=ooooo`;o0000_?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0;Gooooo
0_l0002Dooooo`006_ooool00ol0003oooooooooo`2eooooo`;o0000U?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52477 .59775 Mdot
.47523 .40225 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2Hooooo`;o0000/Oooool000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo09Sooooo0_l0002aooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0ZOooool2o`000:3ooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000ZOooool2o`000:3ooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48493 .59873 Mdot
.51507 .40127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0002Vooooo`;o
0000Xoooool000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo0:Kooooo0_l0002Sooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0W?ooool2o`000:gooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000W?ooool2o`000:gooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44722 .58592 Mdot
.55278 .41408 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/_ooool2o`0009Oooooo
00001?lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
/_ooool2o`0009Oooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0Soooool2o`000;[ooooo000Jooooo`03o`000?oooooo
oooo08oooooo0_l0002jooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41687 .56138 Mdot
.58313 .43862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`2looooo`;o0000SOooool001[ooooo00?o0000ooooooooool0_?ooool2o`0008go
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`25ooooo`;o0000a?ooool001[ooooo00?o0000ooooooooool0QOooool2o`000<Co
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tCell ",
  ButtonBox["7.79",
    ButtonData:>"Cell 7.79",
    ButtonStyle->"Hyperlink"],
  " shows that the two particles orbit in  nearly circular motion, as \
expected.  The orbit is not perfectly circular, because  of the influence of \
the periodic boundary conditions: these particles are also attracted to their \
images in the surrounding boxes, causing a slight distortion of the orbit.  "
}], "Text"],

Cell[TextData[{
  "\tIt can also be  useful to test whether constants of the motion are being \
properly evaluated. However, we will see that in the PIC method these \
constants do not always provide us with a good measure of solution accuracy. \
For example, the total momentum should not vary: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["P",
              FontWeight->"Bold",
              FontSlant->"Plain"], "tot"], "=", " ", 
          RowBox[{\(\[Sum]\+i\), 
            StyleBox[
              SubscriptBox["p", 
                StyleBox["i",
                  FontWeight->"Plain",
                  FontSlant->"Italic"]],
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". This is checked in Cell ",
  ButtonBox["7.80",
    ButtonData:>"Cell 7.80",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Ptot[n_]\  := \ 
        Sum[\(p[n]\)[\([m]\)], {m, 1, Length[p[n]]}];\)\), "\n", 
    \(\(ListPlot[Table[Ptot[n], {n, 1/2, 30, 1}], 
        PlotLabel \[Rule] \ "\<momentum\n\>", \ 
        AxesLabel \[Rule] {"\<Px\>", "\<Py\>"}, 
        PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.80"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.699927 6.54831e+13 0.603319 2.57363e+13 [
[.0451 .59082 -21.75 -12.5 ]
[.0451 .59082 21.75 0 ]
[.17606 .59082 -21.75 -12.5 ]
[.17606 .59082 21.75 0 ]
[.30703 .59082 -21.75 -12.5 ]
[.30703 .59082 21.75 0 ]
[.43799 .59082 -21.75 -12.5 ]
[.43799 .59082 21.75 0 ]
[.56896 .59082 -21.75 -12.5 ]
[.56896 .59082 21.75 0 ]
[.83089 .59082 -18.75 -12.5 ]
[.83089 .59082 18.75 0 ]
[.96186 .59082 -18.75 -12.5 ]
[.96186 .59082 18.75 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 16 6 ]
[.68743 .08859 -43.5 -6.25 ]
[.68743 .08859 0 6.25 ]
[.68743 .21727 -55.5 -6.25 ]
[.68743 .21727 0 6.25 ]
[.68743 .34596 -43.5 -6.25 ]
[.68743 .34596 0 6.25 ]
[.68743 .47464 -43.5 -6.25 ]
[.68743 .47464 0 6.25 ]
[.69993 .64303 -8 0 ]
[.69993 .64303 8 12 ]
[.5 .63053 -26.0625 0 ]
[.5 .63053 26.0625 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0451 .60332 m
.0451 .60957 L
s
gsave
.0451 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.17606 .60332 m
.17606 .60957 L
s
gsave
.17606 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.30703 .60332 m
.30703 .60957 L
s
gsave
.30703 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.43799 .60332 m
.43799 .60957 L
s
gsave
.43799 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.56896 .60332 m
.56896 .60957 L
s
gsave
.56896 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.83089 .60332 m
.83089 .60957 L
s
gsave
.83089 .59082 -18.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.96186 .60332 m
.96186 .60957 L
s
gsave
.96186 .59082 -18.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.125 Mabswid
.07784 .60332 m
.07784 .60707 L
s
.11058 .60332 m
.11058 .60707 L
s
.14332 .60332 m
.14332 .60707 L
s
.2088 .60332 m
.2088 .60707 L
s
.24155 .60332 m
.24155 .60707 L
s
.27429 .60332 m
.27429 .60707 L
s
.33977 .60332 m
.33977 .60707 L
s
.37251 .60332 m
.37251 .60707 L
s
.40525 .60332 m
.40525 .60707 L
s
.47074 .60332 m
.47074 .60707 L
s
.50348 .60332 m
.50348 .60707 L
s
.53622 .60332 m
.53622 .60707 L
s
.6017 .60332 m
.6017 .60707 L
s
.63444 .60332 m
.63444 .60707 L
s
.66719 .60332 m
.66719 .60707 L
s
.73267 .60332 m
.73267 .60707 L
s
.76541 .60332 m
.76541 .60707 L
s
.79815 .60332 m
.79815 .60707 L
s
.86364 .60332 m
.86364 .60707 L
s
.89638 .60332 m
.89638 .60707 L
s
.92912 .60332 m
.92912 .60707 L
s
.01235 .60332 m
.01235 .60707 L
s
.9946 .60332 m
.9946 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Px) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.69993 .08859 m
.70618 .08859 L
s
gsave
.68743 .08859 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .21727 m
.70618 .21727 L
s
gsave
.68743 .21727 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .34596 m
.70618 .34596 L
s
gsave
.68743 .34596 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .47464 m
.70618 .47464 L
s
gsave
.68743 .47464 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.125 Mabswid
.69993 .11433 m
.70368 .11433 L
s
.69993 .14007 m
.70368 .14007 L
s
.69993 .1658 m
.70368 .1658 L
s
.69993 .19154 m
.70368 .19154 L
s
.69993 .24301 m
.70368 .24301 L
s
.69993 .26875 m
.70368 .26875 L
s
.69993 .29448 m
.70368 .29448 L
s
.69993 .32022 m
.70368 .32022 L
s
.69993 .37169 m
.70368 .37169 L
s
.69993 .39743 m
.70368 .39743 L
s
.69993 .42317 m
.70368 .42317 L
s
.69993 .4489 m
.70368 .4489 L
s
.69993 .50037 m
.70368 .50037 L
s
.69993 .52611 m
.70368 .52611 L
s
.69993 .55185 m
.70368 .55185 L
s
.69993 .57758 m
.70368 .57758 L
s
.69993 .06286 m
.70368 .06286 L
s
.69993 .03712 m
.70368 .03712 L
s
.69993 .01138 m
.70368 .01138 L
s
.25 Mabswid
.69993 0 m
.69993 .61803 L
s
gsave
.69993 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Py) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(momentum) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.008 w
.75809 .60332 Mdot
.74355 .59618 Mdot
.02381 .25473 Mdot
.10015 .28044 Mdot
.22374 .31759 Mdot
.42003 .20615 Mdot
.51091 .16329 Mdot
.40185 .12615 Mdot
.50364 .20901 Mdot
.65631 .23901 Mdot
.78717 .28759 Mdot
.97619 .32616 Mdot
.7799 .10329 Mdot
.84896 .05186 Mdot
.93984 .16901 Mdot
.95438 .21187 Mdot
.40912 .11758 Mdot
.4382 .18187 Mdot
.56907 .24187 Mdot
.46728 .28759 Mdot
.05289 .33473 Mdot
.1365 .09758 Mdot
.32188 .10901 Mdot
.46728 .17472 Mdot
.63086 .10615 Mdot
.57634 .06615 Mdot
.38731 .01472 Mdot
.55453 .09901 Mdot
.72174 .14472 Mdot
.78717 .10615 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{403.75, 249.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?oo
ooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00;cooooo0ol00029ooooo`?o0000[Oooool0
0;cooooo0ol00029ooooo`03o`000?oooooooooo0:gooooo002looooo`?o0000ROooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?oooooo
BOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooo
oom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo03ko
oooo0ol0001/ooooo`00oooooom9ooooo`03o`000?oooooooooo03kooooo0ol0001/ooooo`00oooo
oom9ooooo`03o`000?oooooooooo03kooooo0ol0001/ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooolAooooo`?o0000=Oooool3o`000:gooooo003ooooooa7ooooo0ol0
000eooooo`03o`000?oooooooooo0:gooooo003ooooooa7ooooo0ol0000eooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooooagooooo0_o^
k^h3ooooo`;ok^k^9Oooool00ol0003oooooooooo`2]ooooo`00oooooolFooooo`Go00000_ooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hFooooo`03o`000?oooooooooo0:gooooo003ooooooaKooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00oooo
ool>ooooo`Ko00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000ooooooooool0
[Oooool00?oooooo6?ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`2]ooooo`00oooooolIooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
5_ooool4o`000:cooooo003ooooooa[ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool00ol0003ooooo
ooooo`2]ooooo`00oooooolFooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool3o`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2]ooooo`00COooool3o`000<Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`00COooool3o`000;Kooooo0ol0000[ooooo`Co00000oooool00ol0003oooooooooo`04o`0000Ko
oooo00?o0000ooooooooool0[Oooool004gooooo0ol0002fooooo`?o0000<_ooool01ol0003ooooo
oooooooooooo0000ooooool000001_ooool00ol0003oooooooooo`2]ooooo`00ooooool7ooooo`?o
0000<_ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`0Pooooo`?o
0000R_ooool00?oooooo:Oooool3o`0000oooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08?ooool6o`0008Oooooo002Oooooo`?o0000Q_ooool3o`0001gooooo00?o
0000ooooooooool08?ooool6o`0008Oooooo002Oooooo`?o0000Q_ooool3o`0001gooooo00?o0000
ooooooooool08oooool3o`0008Oooooo002Oooooo`?o0000Y_ooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`?o0000[Oooool00<Kooooo0ol0001oooooo`03o`000?oooooooooo0:gooooo
0036ooooo`?o0000Ooooool00ol0003oooooooooo`2]ooooo`00a_ooool3o`0007oooooo00?o0000
ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00`_ooool3o`0008?o
oooo00?o0000ooooooooool0[Oooool00<;ooooo0ol00023ooooo`03o`000?oooooooooo0:gooooo
0032ooooo`?o0000Poooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0
002]ooooo`00oooooom9ooooo`03o`000?oooooooooo00Kooooo0ol0002Tooooo`00oooooom9oooo
o`03o`000?oooooooooo00Kooooo0ol0002Tooooo`00oooooom9ooooo`03o`000?oooooooooo00Ko
oooo0ol0002Tooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00??ooooo
0ol0001Booooo`03o`000?oooooooooo0:gooooo003cooooo`?o0000D_ooool00ol0003ooooooooo
o`2]ooooo`00loooool3o`0005;ooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo
06Oooooo0ol00013ooooo`00oooooom9ooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`00
h?ooool3o`0006Gooooo00?o0000ooooooooool0Ioooool3o`0004?ooooo003Pooooo`?o0000IOoo
ool00ol0003oooooooooo`2]ooooo`00h?ooool3o`0006Gooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00doooool3o`0007;ooooo00?o0000oooooooo
ool0[Oooool00=?ooooo0ol0001booooo`03o`000?oooooooooo0:gooooo003Cooooo`?o0000L_oo
ool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooo
odWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00<_o
oooo0ol0001jooooo`03o`000?oooooooooo0:gooooo003;ooooo`?o0000Coooool2onk^kP?ooooo
0_o^k^hTooooo`03o`000?oooooooooo0:gooooo003;ooooo`?o00008_ooool3o`0001Cooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hEooooo`03o`000?oooooooooo0:gooooo003`ooooo`?o00005_ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`00
0?oooooooooo06gooooo0ol0000mooooo`00l?ooool3o`0000_ooooo1_l00005ooooo`03o`000?oo
oooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01Gooooo00?o0000ooooooooool0KOooool3o`00
03gooooo003oooooo`[ooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo06gooooo0ol0000mooooo`00ooooool:ooooo`03o`000?oo
oooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Gooooo
1?l0002/ooooo`00ooooool:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400Eooooo`03o`000?oooooooooo0:gooooo003oooooo`[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:gooooo
003oooooo`Sooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:gooooo003oooooocKooooo1?l00003ooooo`03o`000?oo
oooooooo00Co00001Oooool00ol0003oooooooooo`2]ooooo`00oooooolmooooo`07o`000?oooooo
ooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo0:gooooo003oooooocgooooo00?o
0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0[Oooool00?oooooo??ooool2
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooocGooooo0ol0000Aooooo`03o`000?oooooooooo0:go
oooo003oooooo`kooooo0ol0000Tooooo`?o00004Oooool00ol0003oooooooooo`2]ooooo`00oooo
ool>ooooo`?o00009?ooool3o`00017ooooo00?o0000ooooooooool0[Oooool00?oooooo3_ooool3
o`0003Sooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`006_oo
ool3o`000?oooooo;?ooool00ol0003oooooooooo`2]ooooo`006_ooool3o`000?oooooo;?ooool0
0ol0003oooooooooo`2]ooooo`006_ooool3o`000?oooooo;?ooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0
[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:go
oooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`00??ooool3o`000?oooooo2_ooool00ol0003oooooooooo`2]ooooo`00??ooool3o`00
0?oooooo2_ooool00ol0003oooooooooo`2]ooooo`00??ooool3o`000?oooooo2_ooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003Pooooo`?o0000IOoo
ool00ol0003oooooooooo`0Sooooo`?o0000Qoooool00>3ooooo0ol0001Uooooo`03o`000?oooooo
oooo02?ooooo0ol00027ooooo`00h?ooool3o`0006Gooooo00?o0000ooooooooool08oooool3o`00
08Oooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00Loooool3o`000=;ooooo00?o0000ooooooooool0[Oooool007?ooooo
0ol0003Booooo`03o`000?oooooooooo0:gooooo001cooooo`?o0000d_ooool3o`000:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`1goooo
o`?o0000<oooool00?ooooooBOooool00ol0003oooooooooo`1gooooo`?o0000<oooool00?oooooo
BOooool00ol0003oooooooooo`1gooooo`?o0000<oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`009oooool3o`000?;ooooo0_o^k^h3ooooo`;ok^k^9Oooool00ol0003oooooooooo`2]
ooooo`009oooool3o`000>cooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQKooooo00?o0000
ooooooooool0[Oooool002Oooooo0ol0003^ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Fooooo`03o`000?oooooooooo0:gooooo003oooooo`kooooo1_l00005ooooo`03o`000?oooooo
oooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005_ooool00ol0003oooooooooo`2]ooooo`00oooooolIooooo`03o`000?oooooo
oooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo0:gooooo003ooooooaWooooo00_o
0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`Co0000[?ooool00?oooooo6Oooool0
1?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Fooooo`03o`000?oooooooooo0:gooooo003ooooooaWooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5_ooool00ol0003oooooooooo`2]ooooo`00oooooolGooooo`03oeEEEOmVIVKo000000gooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0ol00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00?oooooo??ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00?oooooo=Oooool4
o`0000?ooooo00?o0000ooooooooool01?l00006ooooo`03o`000?oooooooooo0:gooooo003ooooo
occooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00?o0000ooooooooool0[Ooo
ool00?oooooo??ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`2]
ooooo`00oooooolkooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooo
ooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03
o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOoo
ool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooo
odWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00
oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Ooo
ool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo
0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo00?o0000
ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03
o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOoo
ool00ol0003oooooooooo`2]ooooo`00oooooolMooooo`;ok^k^0oooool2onk^kRGooooo00?o0000
ooooooooool0[Oooool00?oooooo5oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hFooooo`03o`000?oooooooooo0:gooooo003ooooooa[ooooo00WoMgMgoc8b<_oooooooooo
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00ooooool>ooooo`Ko00001oooool01ol0
003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41005_ooool00ol0003oooooooooo`2]ooooo`00oooooolJooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001Kooooo00?o0000ooooooooool0[Oooool00?oooooo5oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`2]
ooooo`00oooooolGooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool4o`000:cooooo003ooooo
oaOooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00oooooolGooooo`Co00003?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l00007
ooooo`03o`000?oooooooooo0:gooooo003ooooooccooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:gooooo003oooooocGooooo1?l00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`00oooooollooooo`03o`000?oooooooooo00?o00001oooool00ol0003oooooooooo`2]ooooo`00
oooooollooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0[Oooool00?oooooo
>oooool2o`0000;ooooo1?l00006ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`00
0?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool0
0ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooo
oom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:go
oooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0
[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo00?o0000oooo
ooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`00
0?oooooooooo0:gooooo000Jooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^<ooo
ool2onk^kP?ooooo0_o^k^hdooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^?_oo
ool00ol0003oooooooooo`0Xooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^A?oo
ool001Cooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kR3ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo1Ol00002
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kRoooooo00?o0000ooooooooool08Oooool5o`0000;ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^7oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^=Oooool001Kooooo00?o
0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qoooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg02oooooo00?o0000ooooooooool08Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Pooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0eoooo
o`002oooool6o`0000Gooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Eooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41005Oooool6o`0000;ooooo00Go0000oooooooooooooooo
o`000004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01Kooooo1_l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Eooooo`Ko00000oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@02oooooo00?o0000ooooooooool08_ooool00onHV9So8B4Qonk^kP05
ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01gooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Gooooo000Fooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00Go
0000oiRHV?ooooooV9RHob4Q8@03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool01?m4A4CogMgMooooool00004
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000;oooool00ol0
003oooooooooo`0Sooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000eooooo`005_ooool02ol0003oooooooooooooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00Goc<c<o`000?l0003o0000olc<c002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Mooooo`05o`000?mEEEGo0000oa0@4?o<c<`00_ooool01oo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_oo
ool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Pooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`0Tooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000007Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000eooooo`005_ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Mooooo`05oa0@4?nj^[[o
oooookZj^_l@41000_ooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Mooooo`03oeEEEOn7QhOooooo00Cooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool00omgMgOo
c<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@027ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100;oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01kooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400eooooo`005_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Mooooo`05o`000?nj^[[ooooookZj^_l000003_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07Oooool00ooMgMgo410@oiRHV00@ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03onk^k_m4A4Co000000oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo00Go0000okZj^_ooooooV9RH
oa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0_ooooo`?o
00008Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=Oooool001Cooooo00?oEEEEofIVI_l000003Oooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000Cooooo00?o
0000ooooooooool02oooool01OnYZJWo410@o`000?l@413oZJVY00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0ol00002ooooo`;o00003oooool01?o<c<co
A4A4o`000?l@410<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`?o00000_ooool2o`00017ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l0000>ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool3o`0000;ooooo0_l0000Pooooo`03o`000?oooooooooo027ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`?o00000_ooool2o`00013ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l0000Vooooo`00>Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
<_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Oooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool08oooool003;ooooo1?l00003ooooo`03o`000?oooooooooo00Co0000;?ooool4
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`Co00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo1?l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool4o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo1?l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool4o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Sooooo`00>Oooool01ol0003ooooooooooooooooo0000ooooool00000<ooo
ool00ol0003oooooooooo`03o`0003Cooooo00?o0000ooooooooool00ol0000eooooo`03o`000?oo
oooooooo00?o0000=?ooool00ol0003oooooooooo`03o`00023ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`03o`0003Cooooo00?o0000ooooooooool00ol0000Vooooo`00>Oooool0
0ol0003oooooooooo`02ooooo`;o0000<oooool01?l0003oooooooooool0000fooooo`04o`000?oo
ooooooooo`0003Oooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000Roooo
o`03o`000?oooooooooo04Oooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0
000Xooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo1?l0000b
ooooo`;o00000_ooool4o`0003?ooooo0_l00002ooooo`Co0000<_ooool2o`0000;ooooo1?l0000O
ooooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`Co0000<_ooool2o`0000;ooooo1?l0000U
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool03oooool3o`0009_ooooo003oooooodWooooo00?o0000ooooooooool03oooool3o`0007oooooo
0ol000000ol@413oooooooooo`02ooooo`;o00000_ooool2o`0000kooooo003oooooodWooooo00?o
0000ooooooooool03oooool3o`00083ooooo00?o0000ooooooooool01?ooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@kooooo003oooooodWooooo00?o0000ooooooooool05_ooool3o`0007Wooooo
00?o0000ooooooooool01Oooool01?oMgMgo0000oa0@4?o<c<`?ooooo`004Oooooooo`000;oo0000
3_ooool3o`000003ob4Q8Oo<c<cooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^3oooool001Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`000?ooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooohN7Qol@41000oooool01?lQ8B7o
MgMgogMgMolb<S8?ooooo`009Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01go
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool2o`0000kooooo000Uooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooon7QhOo410@
01Kooooo003oooooodWooooo00?o0000ooooooooool0TOooool4o`000003ob4Q8Oo<c<cooooo01Go
oooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooom:ooooo`?o000000?o410@oooooooo
ool0ZOooool00?ooooooC?ooool00ol@413o^[Zjooooo`2Zooooo`00oooooom<ooooo`03oiRHV?lb
<S;ooooo0:[ooooo003ooooood?ooooo0ol000000ol@413oooooooooo`03ooooo`03omgMgOl0003o
^[Zj0:[ooooo003oooooodCooooo00?o0000ooooooooool01Oooool00omEEEGoMgMgodA4A02Zoooo
o`00oooooom4ooooo`03o`000?oooooooooo00Cooooo00GogMgMoa0@4?oooooo8B4QomgMg@2Yoooo
o`00oooooom4ooooo`?o000000Wo8B4Qolc<c?ooooooooooofIVI_n7QhOooooooiRHV?mEEED0ZOoo
ool00?ooooooA?ooool02Ol0003ooooooooooon7QhOo410@ooooooo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo0:Oooooo003oooooodCooooo00Oo0000ooooooooooooooooo`000?oooooo410@
00;o000000Coooooo`000?l0003o410@Z?ooool00?ooooooA?ooool01Ol0003ooooooooooon7QhOo
410@0;3ooooo003ooooood?ooooo1?l000000olQ8B7oc<c<ooooo`2_ooooo`00oooooooiooooo`00
oooooooiooooo`00dOooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o
000000?oEEEEonk^k_ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02
o`000005odA4A?nj^[[oooooooooool@41000_l000001?oooooo0000o`000?l@4102ooooo`05oiRH
V?l0003o0000odA4A?nj^[X00oooool01_nHV9So0000o`000?mgMgOo0000oa0@40;o00000_ooool0
1Ol0003oooooooooool0003o410@0>Kooooo003Booooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooomEEEGoMgMg0_ooool01OmgMgOoEEEEoooooooooooo000000;ooooo00_o0000oooooooo
oooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0iOooool00=;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo0>Gooooo003Booooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`00
0?ooool01_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo0>Gooooo003Booooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEE
ogMgM`;ooooo00GoMgMgoeEEEOooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S800oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q0>Oooooo003Aooooo`0;oa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nY
ZJWoooooonk^k_mEEED00_l000003_mEEEGok^k^ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0
003oZJVYooooooo^k^koEEEE0_l000001om4A4Cok^k^oooooooooooo410@o`000?mgMgL00_l00000
0onHV9Sooooooa0@4005o`0000?ooooo00Co410@o`000?oooooooooo0_l000002Ooooooo410@o`00
0?lQ8B7o0000ogMgMol@413o0000ojVYZ@3Wooooo`00noooool00ol0003oooooooooo`3jooooo`00
noooool00ol0003oooooooooo`3jooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00\
\>"],
  ImageRangeCache->{{{0, 503.688}, {310.938, 0}} -> {-1.12924*^-14, \
-2.34425*^-14, 4.29387*^-17, 1.09253*^-16}}]
}, Open  ]],

Cell[TextData[{
  "The error is down at the level of the machine precision. This is an \
excellent check to make sure there are no errors in the code. But the \
accuracy is ",
  StyleBox["too good ",
    FontSlant->"Italic"],
  "to be of any further use!  We can vary the grid spacing and the time step \
size, making them as large as we wish,  and we will find that total momentum \
is ",
  "always conserved",
  ". (Try it.) Thus, evaluation of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["P",
            FontWeight->"Bold",
            FontSlant->"Plain"], "tot"], TraditionalForm]]],
  " tells us nothing about the accuracy of the solution. "
}], "Text"],

Cell[TextData[{
  "\tIt is interesting that this negligible error grows dramatically if a \
second-order interpolation scheme is used in the module ",
  StyleBox["Fpart",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". One might have expected that second-order interpolation would be more \
accurate than first-order interpolation. However, first-order interpolation \
(linear interpolation from the grid to the particles) works best, because the \
area-weighting used to create the density on the grid in the first place is \
also a linear interpolation. In the PIC method, it has been shown that one \
should use the same method to interpolate from the grid to the particle \
positions as one uses to determine the density from these positions [",
  ButtonBox["Birdsall and Langdon (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell[TextData[{
  "\tAnother conserved quantity (in infinite space) is the total angular \
momentum, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(L\_z\),
            FontSlant->"Italic"], "=", 
          RowBox[{
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold"], "^"], "\[CenterDot]", 
            RowBox[{\(\[Sum]\+i\), 
              RowBox[{
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["i",
                      FontWeight->"Plain",
                      FontSlant->"Italic"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Bold"], "\[Times]", 
                StyleBox[
                  SubscriptBox["p", 
                    StyleBox["i",
                      FontWeight->"Plain",
                      FontSlant->"Italic"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ". To evaluate this quantity we require the momentum at the same time as \
the position. This can be obtained by averaging, as shown in Cell ",
  ButtonBox["7.81",
    ButtonData:>"Cell 7.81",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p[n_]\  := \ \((p[n - 1/2]\  + p[n + 1/2])\)/2\  /; \ 
          n \[Element] Integers\  && \ n > \ 0;\)\n\), "\n", 
    \(\(angmom[n_]\  := \ 
        Sum[\(r[n]\)[\([i, 1]\)] \(p[n]\)[\([i, 2]\)] - \(r[n]\)[\([i, 
                  2]\)] \(p[n]\)[\([i, 1]\)], {i, 1, 
            Length[r[n]]}];\)\[IndentingNewLine]\), "\n", 
    \(\(ListPlot[
        Table[{n\ \[CapitalDelta]t, angmom[n] - angmom[0]}, {n, 0, 30}], 
        PlotLabel \[Rule] \ "\<change in angular momentum versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotJoined \[Rule] True];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.81"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.967038 188.859 [
[.18254 .01024 -9 -9 ]
[.18254 .01024 9 0 ]
[.34127 .01024 -9 -9 ]
[.34127 .01024 9 0 ]
[.5 .01024 -9 -9 ]
[.5 .01024 9 0 ]
[.65873 .01024 -9 -9 ]
[.65873 .01024 9 0 ]
[.81746 .01024 -3 -9 ]
[.81746 .01024 3 0 ]
[.97619 .01024 -9 -9 ]
[.97619 .01024 9 0 ]
[1.025 .02274 0 -6 ]
[1.025 .02274 10 6 ]
[.01131 .11717 -42 -4.5 ]
[.01131 .11717 0 4.5 ]
[.01131 .2116 -36 -4.5 ]
[.01131 .2116 0 4.5 ]
[.01131 .30603 -42 -4.5 ]
[.01131 .30603 0 4.5 ]
[.01131 .40046 -36 -4.5 ]
[.01131 .40046 0 4.5 ]
[.01131 .49489 -42 -4.5 ]
[.01131 .49489 0 4.5 ]
[.01131 .58932 -36 -4.5 ]
[.01131 .58932 0 4.5 ]
[.5 .63053 -116.062 0 ]
[.5 .63053 116.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .02274 m
.18254 .02899 L
s
[(0.2)] .18254 .01024 0 1 Mshowa
.34127 .02274 m
.34127 .02899 L
s
[(0.4)] .34127 .01024 0 1 Mshowa
.5 .02274 m
.5 .02899 L
s
[(0.6)] .5 .01024 0 1 Mshowa
.65873 .02274 m
.65873 .02899 L
s
[(0.8)] .65873 .01024 0 1 Mshowa
.81746 .02274 m
.81746 .02899 L
s
[(1)] .81746 .01024 0 1 Mshowa
.97619 .02274 m
.97619 .02899 L
s
[(1.2)] .97619 .01024 0 1 Mshowa
.125 Mabswid
.06349 .02274 m
.06349 .02649 L
s
.10317 .02274 m
.10317 .02649 L
s
.14286 .02274 m
.14286 .02649 L
s
.22222 .02274 m
.22222 .02649 L
s
.2619 .02274 m
.2619 .02649 L
s
.30159 .02274 m
.30159 .02649 L
s
.38095 .02274 m
.38095 .02649 L
s
.42063 .02274 m
.42063 .02649 L
s
.46032 .02274 m
.46032 .02649 L
s
.53968 .02274 m
.53968 .02649 L
s
.57937 .02274 m
.57937 .02649 L
s
.61905 .02274 m
.61905 .02649 L
s
.69841 .02274 m
.69841 .02649 L
s
.7381 .02274 m
.7381 .02649 L
s
.77778 .02274 m
.77778 .02649 L
s
.85714 .02274 m
.85714 .02649 L
s
.89683 .02274 m
.89683 .02649 L
s
.93651 .02274 m
.93651 .02649 L
s
.25 Mabswid
0 .02274 m
1 .02274 L
s
gsave
1.025 .02274 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .11717 m
.03006 .11717 L
s
[(-0.0045)] .01131 .11717 1 0 Mshowa
.02381 .2116 m
.03006 .2116 L
s
[(-0.004)] .01131 .2116 1 0 Mshowa
.02381 .30603 m
.03006 .30603 L
s
[(-0.0035)] .01131 .30603 1 0 Mshowa
.02381 .40046 m
.03006 .40046 L
s
[(-0.003)] .01131 .40046 1 0 Mshowa
.02381 .49489 m
.03006 .49489 L
s
[(-0.0025)] .01131 .49489 1 0 Mshowa
.02381 .58932 m
.03006 .58932 L
s
[(-0.002)] .01131 .58932 1 0 Mshowa
.125 Mabswid
.02381 .04163 m
.02756 .04163 L
s
.02381 .06051 m
.02756 .06051 L
s
.02381 .0794 m
.02756 .0794 L
s
.02381 .09828 m
.02756 .09828 L
s
.02381 .13606 m
.02756 .13606 L
s
.02381 .15494 m
.02756 .15494 L
s
.02381 .17383 m
.02756 .17383 L
s
.02381 .19271 m
.02756 .19271 L
s
.02381 .23049 m
.02756 .23049 L
s
.02381 .24937 m
.02756 .24937 L
s
.02381 .26826 m
.02756 .26826 L
s
.02381 .28714 m
.02756 .28714 L
s
.02381 .32492 m
.02756 .32492 L
s
.02381 .3438 m
.02756 .3438 L
s
.02381 .36269 m
.02756 .36269 L
s
.02381 .38157 m
.02756 .38157 L
s
.02381 .41935 m
.02756 .41935 L
s
.02381 .43823 m
.02756 .43823 L
s
.02381 .45712 m
.02756 .45712 L
s
.02381 .476 m
.02756 .476 L
s
.02381 .51378 m
.02756 .51378 L
s
.02381 .53266 m
.02756 .53266 L
s
.02381 .55155 m
.02756 .55155 L
s
.02381 .57043 m
.02756 .57043 L
s
.02381 .00386 m
.02756 .00386 L
s
.02381 .60821 m
.02756 .60821 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -177.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(change) show
105.000 13.000 moveto
(in) show
123.000 13.000 moveto
(angular) show
171.000 13.000 moveto
(momentum) show
225.125 13.000 moveto
(versus) show
267.125 13.000 moveto
(time) show
291.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04035 .61803 m
.05556 .29717 L
.0873 .26748 L
.11905 .30902 L
.15079 .36754 L
.18254 .3166 L
.21429 .20998 L
.24603 .19089 L
.27778 .27573 L
.30952 .39146 L
.34127 .40656 L
.37302 .29923 L
.40476 .2102 L
.43651 .22381 L
.46825 .25059 L
.5 .20059 L
.53175 .13269 L
.56349 .13039 L
.59524 .15295 L
.62698 .10209 L
.65873 .01472 L
.69048 .04339 L
.72222 .16929 L
.75397 .25549 L
.78571 .21498 L
.81746 .11354 L
.84921 .089 L
.88095 .14909 L
.9127 .18325 L
.94444 .11282 L
.97619 .06697 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Foooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool05oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08_oo
ool4o`000003oa0@4?oooooooooo01oooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool5o`0001;ooooo001Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B409?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04_ooool005_ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00006Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^01?ooooo001Kooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP0Iooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000J
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S809?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h04_ooool005_o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c00Tooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool03Oooool00omgMgOoIVIVooooo`0Aooooo`00Foooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000006_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
6oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Toooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@oooo
o`00>?ooool00ol0003oooooooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000001[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000009?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400B
ooooo`00>?ooool2o`00027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`06Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
6Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Rooooo`03oeEEEOmV
IVKo000002?ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<01;ooooo
000hooooo`03o`000?oooooooooo0?oooooo;_ooool003Sooooo00?o0000ooooooooool0ooooool^
ooooo`00>?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo06cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P04ooooo`00>?ooool00ol0003oooooooooo`2eooooo`;o0000KOooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Cooooo000hooooo`03o`000?oooooooooo0;Cooooo00Co0000oooo
oooooooo0000K?ooool00ol0003oooooooooo`06ooooo`00<Oooooooo`0002Co00002oooool00ol0
003oooooooooo`06ooooo`00>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`00>?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0IOooool00ol@413o0000o`000003o`0000Gooooo000hooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo00Kooooo000hooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Kooooo000hooooo`;o0000/oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo000hooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`00>?ooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool003Sooooo00?o
0000ooooooooool0/Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06cooooo000h
ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1[
ooooo`00>?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Joooool003Sooooo0_l0002aooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Joooool003Sooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool06Oooool003Sooooo00?o0000ooooooooool0/?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool06Ooo
ool003Sooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool06_ooool003Sooooo00?o0000ooooooooool0[oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06oooool003So
oooo0_l0002`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Looooo`00>?ooool00ol0003ooooooooo
o`2^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Mooooo`00>?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool09oooool2o`00023ooooo00?o0000ooooooooool07Oooool003Sooooo00?o0000oooo
ooooool0[Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ool000007oooool00ol0003oooooooooo`0Nooooo`00>?ooool00ol0003oooooooooo`2]ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo0000
01kooooo00?o0000ooooooooool07_ooool003Sooooo0_l0002^ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool08_ooool2o`0000Cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Oooooo`00>?ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o000000?o410@ooooooooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0[?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo0005oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo027ooooo0003o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo1Ol00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02;ooooo0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oM
gMgoooooo`0000Sooooo00?oMgMgoc8b<_ooool01?ooool2o`000:[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Rooooo`001Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?oM
gMgoEEEEooooool00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08oooool000Gooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Cooooo00?oMgMgolc<c?l000001Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0:Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Sooooo`00
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02Cooooo0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo00Cooooo
1?l00006ooooo`03o`000?oooooooooo093ooooo2ol0000<ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool09?ooool003Sooooo0_l0002Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo000h
ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool02_ooool2o`0000Oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Uooooo`00>?ooool00ol0003oooooooooo`2?oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02Kooooo000hooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool03_ooool2o`0000?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`00
>?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Wooooo`00>?ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`00>?ooool2
o`0008kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`00>?ooool00ol0
003oooooooooo`2=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?ooool003So
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wo
oooo000hooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Yooooo`00>?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:_ooool003Sooooo0_l0002<ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:_ooool003Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000]
ooooo`00>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000002gooooo000hooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0;?ooool003Sooooo00?o0000ooooooooool0
ROooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
COooool003Sooooo00?o0000ooooooooool0??ooool2o`0004_ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo000hooooo`;o0000??ooool0
0ol0003oooooo`00001:ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1>ooooo`00>?ooool00ol0003oooooooooo`0iooooo`;o00000oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1>ooooo`00>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Coooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1?ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Coooool000Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`Go00001_ooool2o`0003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yoooo
o`;o00006?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0D?ooool000gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:Oooool01?l0003oooooo`000?l0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1@ooooo`003Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Go
oooo0_l0000@ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Aooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Booooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Doooool003Sooooo0_l0000cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo000hooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0EOooool003Sooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool2o`00
00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Gooooo000hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool003Sooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool0001?ooooo`05o`000?oooooooooooooo
ool00000FOooool003Sooooo0_l0000booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000004oooooo00Co0000oooooooo
oooo0000F_ooool003Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooo000005_ooooo000hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
F_ooool003Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0a?ooool003Sooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0a?ooool0
03Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0a?ooool003Sooooo0_l0000?ooooo`;o00007oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0aOooool003Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooo`00000Oooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`35ooooo`00>?ooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0aOooool003Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo000hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00>?ooool2o`00
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`36ooooo`00>?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0aoooool003Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<Oooooo
0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lb<S;o
c<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`37ooooo`001Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
0<Sooooo0003o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`38ooooo`001Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00onYZJWo
410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0b?ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o410@
o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<Wooooo0005ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0bOooool000Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0<Wooooo0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01?ooool4o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0<[ooooo000hooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo0<[ooooo000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3:ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0b_ooool003Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<_ooooo000hooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3;ooooo`00>?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0boooool003Sooooo
0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0c?ooool003Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0<cooooo000h
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3<
ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0cOooool003Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`05
o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0<gooooo000hooooo`;o00001_ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
02Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3=ooooo`00>?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000:_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo0<gooooo000hooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0c_ooool003Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0c_ooool003Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0c_ooool003Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0coooool003Sooooo0_l00006ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3?ooooo`00
>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3?ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3?ooooo`003Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool2o`0000Wooooo00?o0000oooo
ooooool0d?ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oa0@4?nj
^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04[ooooo
0ol00006ooooo`03o`000?oooooooooo0=3ooooo0005ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001oooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`1=oooo
o`;o00001?ooool00ol0003oooooooooo`3@ooooo`003Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_oo
ool00onYZJWo410@ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Cooo
ool4o`000=?ooooo000=ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03oa0@4?l0003o^[Zj00Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0=7o
oooo000=ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooobOooooo000=ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo9oooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolWooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo9oooool003Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooobOooooo000hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo9oooool003Sooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo9oooool0
03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooobOooooo000hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo9oooool003Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooobOooooo000hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolWooooo`00>?ooool2o`0000Cooooo00?o0000ooooooooool0oooooolXoooo
o`00>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo000hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`00>?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo0_l00004ooooo`03o`000?oooooooooo
0?oooooo:?ooool003Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSo
oooo000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`001Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool0
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooolXooooo`000ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo:?ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`;o00001?ooool00ol0003oooooooooo`3oooooobSooooo
0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolX
ooooo`001Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo
0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolX
ooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`00
>?ooool2o`0000Cooooo00?o0000ooooooooool0oooooolXooooo`00>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3oooooobSooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo:Oooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooobWooooo
000hooooo`;o00000oooool00ol0003oooooooooo`3oooooobWooooo000hooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo:Oooool003Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3oooooobWooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
oooooolYooooo`00>?ooool2o`0000?ooooo00?o0000ooooooooool0oooooolYooooo`00>?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:Oooool003Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3oooooobWooooo000hooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo:Oooool003Sooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooobWooooo000hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolYooooo`003Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0oooooolYooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolYooooo`001Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool000gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0000;o
oooo00?o0000ooooooooool0oooooolZooooo`003Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0omgMgOoIVIVooooo`05ooooo`05o`000?ooooooooooooooool00000ooooool/ooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000ooooool/ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00Go0000ooooooooooooooooo`00003oooooobcooooo000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool01Ol0003ooooooooo
oooooooo00000?oooooo;?ooool003Sooooo0_l00002ooooo`03o`000?oooooooooo0?oooooo:_oo
ool003Sooooo00Go0000ooooooooooooooooo`00003oooooobcooooo000hooooo`05o`000?oooooo
ooooooooool00000ooooool/ooooo`00>?ooool01Ol0003ooooooooooooooooo00000?oooooo;?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool005Gooooo00Go8B4Qo`000?l0003oA4A4omgMg@0fooooo`05ob4Q8Ol0003o0000odA4A?oMgMd0
doooool005Sooooo00?oMgMgoc8b<_ooool0>?ooool00omgMgOo<S8booooo`3Booooo`00FOooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo0=7ooooo000eooooo`05ofIVI_l0003o0000
odA4A?o<c<`00_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?ooooooV9RH00;o000000?o
MgMgoa0@4?l000000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0
003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj2?ooool5o`0000;ooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`05ooooo`06oiRHV?l0003o0000ogMg
Mol@413o00000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o
410@olc<c?l00003ooooo`07oiRHV?l0003o0000ogMgMol0003o410@ooooo`05o`0000?ooooo00So
V9RHo`000?l0003oMgMgoa0@4?l0003ooooooa0@40Go00001_ooool2o`0000;ooooo00Oo0000oooo
oooooooo0000oa0@4?o^k^koEEEE00;o000000?oEEEEonk^k_ooool00_l00002ooooo`07o`000?oo
ooooooooo`000?l@413ok^k^oeEEE@02o`000005odA4A?nj^[[oooooooooool@41000_l000001?oo
oooo0000o`000?l@4102ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool01_nHV9So0000o`00
0?mgMgOo0000oa0@40;o00000_ooool01Ol0003oooooooooool0003o410@00Kooooo00?o8B4Qoc8b
<_ooool00oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0oooool02OnHV9So0000o`000?mgMgOo0000oa0@4?oooooo410@
oc8b<P02o`000003oa0@4?nYZJWooooo00Kooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go
000000?oooooo`000?l000000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l00000
0om4A4Co^[Zjooooo`0Fooooo`00=?ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@2_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool01Ol0003oZJVYoooooon7QhOo0000
00Cooooo00?o0000ooooooooool00oooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooEEEEogMgM`;ooooo
00GoMgMgoeEEEOooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMooo
ooook^k^ogMgMol@41000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@okZj^_o^
k^koMgMgoa0@4003ooooo`05o`000?nYZJWoooooohN7Qol000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Cooooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool01_l0003oZJVYoooooooooooo
^[Zjo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002ooooo`06o`000?nYZJWooooooooooonj
^[[o00001oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMgMoooooook^k^ogMgMol@410Goooo
o`00=?ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@
413oQhN7ooooooo^k^ko000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oo
ooooooooooooooo^k^ko00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000008ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05oa0@4?n7QhOooooo
onk^k_l000001?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00002?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`04oa0@4?nj^[[oV9RHoc8b<P?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4007ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000001cooooo
000dooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03okZj
^_l@413o000000;o00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
ooooooooonk^k_l00002ooooo`Ko00002_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002?ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00onj^[[o410@o`000002o`0000Cooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co
0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Ko00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`06oiRHV?lb
<S;oooooooooool@413o^[Zj0_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0001Oooooo000dooooo`06
ofIVI_mgMgOooooooooooon7QhOo00000oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00?o
c<c<o`000?ooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b2_ooool00ol0003ooooooooo
o`03ooooo`05o`000?n7QhOoooooojVYZOl000002oooool00oo<c<co0000ooooo`03ooooo`05o`00
0?n7QhOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?oc<c<o`000?ooool00ooo
ool00ol0003o<S8bomgMg@08ooooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEE
ogMgM`;ooooo00GoMgMgoeEEEOooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S800oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q00Cooooo00?ok^k^o`000?oMgMd00_ooool02_nHV9So<S8boooooooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00Ko0000okZj^_oo
ooook^k^ogMgMol00003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003o^[Zjoooo
ooo^k^koMgMgo`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`0>
o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S8Goooo
o`00=?ooool01_o^k^koIVIVo`000?l0003oA4A4o`0000?ooooo00Go0000ogMgMol0003o0000oiRH
V003ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9Sooooo
ooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413oooooonk^k_mEEED00_l000000om4A4Cok^k^
ooooo`07ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`07ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9So
ooooooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413ooooooa0@4?l000000_ooool2o`0000Co
oooo00?o0000ooooooooool01?ooool01?lb<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVYob4Q
8Ol0003o8B4Q1Oooool02ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE
00;o000000koEEEEonk^k_oooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^
oeEEE@;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o000000?oV9RHooooool@4100
1Ol00003ooooo`04oa0@4?l0003oooooooooo`;o000000Wooooooa0@4?l0003o8B4Qo`000?mgMgOo
410@o`000?nYZJT01?ooool00ol@413o0000o`000002ooooo`?o000000?oooooonk^k_mEEED00_l0
00001?m4A4Cok^k^ooooooooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00KoZJVYob4Q8Ol0
003o0000oc8b<_l00002ooooo`04oa0@4?l0003oooooooooo`;o00000_ooool01_nYZJWo8B4Qo`00
0?l0003o<S8bo`0000Gooooo00?o410@o`000?l000000ol00004ooooo`03oa0@4?l0003o000000?o
oooo00_o410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000003odA4
A?o^k^kooooo01Kooooo000mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo037ooooo000mooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`00??ooool00ol@
413o0000ooooo`0]ooooo`03oa0@4?oooooooooo033ooooo00?o410@o`000?l00000W?ooool00ol@
413oooooooooo`0Wooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.243838, -0.00541057, \
0.00543053, 2.2821*^-5}}]
}, Open  ]],

Cell["\<\
It is not well conserved, because the periodic boundary conditions \
break the cylindrical symmetry required for angular momentum conservation.  \
Thus, tracking angular momentum is not particularly useful unless the \
boundaries are far from the region of interest.\
\>", "Text"],

Cell["\<\
\tA third conserved quantity is the total energy of the system, \
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_total\  = \[Sum]\+i\ p\_i\%2\/\(2  m\) + 
          1\/2\ \(\[Integral]\[Rho]\ \[Phi]\ \(\(\[DifferentialD]\^2 
                  r\)\(\ \)\)\)\)]],
  ". "
}], "NE3",
  CellTags->"(7.3.9)"],

Cell[TextData[{
  "The second term is the total gravitational potential energy ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". In order to evaluate this quantity  we write the integral as a sum over \
the grid:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"U", " ", "=", " ", 
            
            RowBox[{\(\[Integral]\[Rho]\ \[Phi]\ \[DifferentialD]\^2 r\), 
              "\[TildeEqual]", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], 
                " ", \(\[Sum]\+\(i, j = 0\)\%\(M - 1\)\(\[Rho]\_\(i\ j\)\) \
\[Phi]\_\(\(\ \)\(i\ j\)\)\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(7.3.10)"],

Cell[TextData[{
  "Since the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " and the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " are not saved from step to step, one can either reevaluate them, or  \
modify the previous code to evaluate and store the energy as the positions \
and momenta are updated. We proceed with the former approach below."
}], "Text"],

Cell[TextData[{
  "\tTo evaluate the kinetic energy, we require the momenta at the same time \
step as the positions. We could employ the averaging method that we used to \
determine the angular momentum. However, it is just as accurate, and somewhat \
faster, to write the kinetic energy at ",
  "time step",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(K(t\_n)\), "=", 
          RowBox[{\(\[Sum]\+i\), " ", 
            FractionBox[
              
              RowBox[{\(\(p\_i\)(t\_\(n - 1/2\))\), 
                " ", \(\(p\_i\)(t\_\(n + 1/2\))\), Cell[""]}], \(2  m\)]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.82",
    ButtonData:>"Cell 7.82",
    ButtonStyle->"Hyperlink"],
  ", we evaluate the energy."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(kineticenergy[n_]\  := \ 
        Sum[\(p[n - 1/2]\)[\([i]\)] . \(p[n + 1/2]\)[\([i]\)], {i, 1, 
                Length[p[n + 1/2]]}]/\((2\ m)\) /; 
          n > 0\  && \ n \[Element] Integers;\)\), "\n", 
    \(\(kineticenergy[n_]\  := \ 
        Sum[\(p[n]\)[\([i]\)] . \(p[n]\)[\([i]\)], {i, 1, 
                Length[p[n]]}]/\((2\ m)\) /; 
          n > 0\  && \ n + 1/2 \[Element] Integers;\)\), "\n", 
    \(\(\(kineticenergy[0]\  := \ 
        Sum[\(p[0]\)[\([i]\)] . \(p[0]\)[\([i]\)], {i, 1, 
              Length[p[0]]}]/\((2\ m)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(energy[n_]\  := \(energy[n]\  = 
          Module[{}, \[IndentingNewLine]Npart\  = \ 
              Length[r[n]]; \[IndentingNewLine]density[
              r[n]]; \[IndentingNewLine]fft\[Phi][\[Rho]]; \
\[IndentingNewLine]potentialenergy[n] = 
              1/2\ \[CapitalDelta]x\ \[CapitalDelta]y\ Sum[\[Rho][\([i, 
                        j]\)]\ \[Phi][\([i, j]\)], {i, 1, M}, {j, 1, 
                    M}]; \[IndentingNewLine]kineticenergy[n] + 
              potentialenergy[n]]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, energy[n]}, {n, 0, 30}], 
        PlotJoined \[Rule] True, PlotLabel -> "\<total energy\>", 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.82"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 1.85213 0.238045 [
[.18254 .17332 -9 -9 ]
[.18254 .17332 9 0 ]
[.34127 .17332 -9 -9 ]
[.34127 .17332 9 0 ]
[.5 .17332 -9 -9 ]
[.5 .17332 9 0 ]
[.65873 .17332 -9 -9 ]
[.65873 .17332 9 0 ]
[.81746 .17332 -3 -9 ]
[.81746 .17332 3 0 ]
[.97619 .17332 -9 -9 ]
[.97619 .17332 9 0 ]
[1.025 .18582 0 -6 ]
[1.025 .18582 10 6 ]
[.01131 .06679 -24 -4.5 ]
[.01131 .06679 0 4.5 ]
[.01131 .30484 -24 -4.5 ]
[.01131 .30484 0 4.5 ]
[.01131 .42386 -12 -4.5 ]
[.01131 .42386 0 4.5 ]
[.01131 .54288 -24 -4.5 ]
[.01131 .54288 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .18582 m
.18254 .19207 L
s
[(0.2)] .18254 .17332 0 1 Mshowa
.34127 .18582 m
.34127 .19207 L
s
[(0.4)] .34127 .17332 0 1 Mshowa
.5 .18582 m
.5 .19207 L
s
[(0.6)] .5 .17332 0 1 Mshowa
.65873 .18582 m
.65873 .19207 L
s
[(0.8)] .65873 .17332 0 1 Mshowa
.81746 .18582 m
.81746 .19207 L
s
[(1)] .81746 .17332 0 1 Mshowa
.97619 .18582 m
.97619 .19207 L
s
[(1.2)] .97619 .17332 0 1 Mshowa
.125 Mabswid
.06349 .18582 m
.06349 .18957 L
s
.10317 .18582 m
.10317 .18957 L
s
.14286 .18582 m
.14286 .18957 L
s
.22222 .18582 m
.22222 .18957 L
s
.2619 .18582 m
.2619 .18957 L
s
.30159 .18582 m
.30159 .18957 L
s
.38095 .18582 m
.38095 .18957 L
s
.42063 .18582 m
.42063 .18957 L
s
.46032 .18582 m
.46032 .18957 L
s
.53968 .18582 m
.53968 .18957 L
s
.57937 .18582 m
.57937 .18957 L
s
.61905 .18582 m
.61905 .18957 L
s
.69841 .18582 m
.69841 .18957 L
s
.7381 .18582 m
.7381 .18957 L
s
.77778 .18582 m
.77778 .18957 L
s
.85714 .18582 m
.85714 .18957 L
s
.89683 .18582 m
.89683 .18957 L
s
.93651 .18582 m
.93651 .18957 L
s
.25 Mabswid
0 .18582 m
1 .18582 L
s
gsave
1.025 .18582 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .06679 m
.03006 .06679 L
s
[(-7.5)] .01131 .06679 1 0 Mshowa
.02381 .30484 m
.03006 .30484 L
s
[(-6.5)] .01131 .30484 1 0 Mshowa
.02381 .42386 m
.03006 .42386 L
s
[(-6)] .01131 .42386 1 0 Mshowa
.02381 .54288 m
.03006 .54288 L
s
[(-5.5)] .01131 .54288 1 0 Mshowa
.125 Mabswid
.02381 .0906 m
.02756 .0906 L
s
.02381 .1144 m
.02756 .1144 L
s
.02381 .13821 m
.02756 .13821 L
s
.02381 .16201 m
.02756 .16201 L
s
.02381 .20962 m
.02756 .20962 L
s
.02381 .23343 m
.02756 .23343 L
s
.02381 .25723 m
.02756 .25723 L
s
.02381 .28103 m
.02756 .28103 L
s
.02381 .32864 m
.02756 .32864 L
s
.02381 .35245 m
.02756 .35245 L
s
.02381 .37625 m
.02756 .37625 L
s
.02381 .40006 m
.02756 .40006 L
s
.02381 .44767 m
.02756 .44767 L
s
.02381 .47147 m
.02756 .47147 L
s
.02381 .49527 m
.02756 .49527 L
s
.02381 .51908 m
.02756 .51908 L
s
.02381 .04299 m
.02756 .04299 L
s
.02381 .01918 m
.02756 .01918 L
s
.02381 .56669 m
.02756 .56669 L
s
.02381 .59049 m
.02756 .59049 L
s
.02381 .6143 m
.02756 .6143 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(total) show
99.000 13.000 moveto
(energy) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.05556 .55768 L
.0873 .16915 L
.11905 .34379 L
.15079 .60332 L
.18254 .37449 L
.21429 .37715 L
.24603 .54093 L
.27778 .32113 L
.30952 .54039 L
.34127 .58424 L
.37302 .25141 L
.40476 .3665 L
.43651 .50444 L
.46825 .26156 L
.5 .52564 L
.53175 .35049 L
.56349 .39046 L
.59524 .47097 L
.62698 .54707 L
.65873 .50027 L
.69048 .4178 L
.72222 .4968 L
.75397 .59849 L
.78571 .33887 L
.81746 .5763 L
.84921 .58131 L
.88095 .1323 L
.9127 .40403 L
.94444 .46076 L
.97619 .5797 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo0_l0003ooooo
odKooooo000Qooooo`;o0000oooooom6ooooo`002Oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l0003oooooodKooooo0009ooooo`03oeEE
EOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0003oooooodKooooo
0005o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`02ooooo`;o0000oooo
oom6ooooo`002_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0003o
ooooodGooooo000:ooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`;o0000oooooom6ooooo`002_ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0_l0003oooooodKooooo0007ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0
003oooooooooo`06ooooo`;o0000oooooom6ooooo`001oooool5o`0000cooooo1?l00005ooooo`;o
0000oooooom6ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`?o0000oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooool0
0000oooooom5ooooo`008Oooool00ol0003oooooo`00003oooooodGooooo000Qooooo`03o`000?oo
oooo00000?ooooooAOooool0027ooooo00?o0000ooooool00000oooooom5ooooo`008Oooool00ol0
003oooooo`00003oooooodGooooo000Qooooo`03o`000?oooooo00000?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooo00000?ooooooAOooool0027ooooo00?o0000
ooooool00000oooooom5ooooo`008Oooool00ol0003oooooo`00003oooooodGooooo000Qooooo`03
o`000?oooooo00000?ooooooAOooool0027ooooo00?o0000ooooool00000ooooool:ooooo`03o`00
0?oooooooooo03Sooooo000Qooooo`03o`000?oooooo00000?oooooo2_ooool00ol0003ooooooooo
o`0hooooo`008Oooool3o`000?oooooo2_ooool00ol0003oooooooooo`0hooooo`008Oooool00ol0
003oooooo`00003oooooo`[ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooool0
00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00007Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool06_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
7Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`09Oooool4o`000003oa0@4?oooooooooo00oooooo00?o0000ooooooooool04Oooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00004oooool0027ooooo00?o0000ooooool0
00009?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@07Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q02Oooooo00?o0000ooooooooool04Oooool2o`0001Cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Cooooo`008Oooool0
1?l0003oooooooooool0000Sooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP0Nooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000007Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo017ooooo
0_l0000Dooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h05?ooool0027ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h07Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00007Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Mooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b02Oooooo00?o0000oooo
ooooool04Oooool2o`0001Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP0Coooo
o`008Oooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Looooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool0000Mooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
01gooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`09ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03Ooo
ool00omgMgOoIVIVooooo`0Booooo`008Oooool4o`0002?ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000001gooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41009oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Aooooo`008Oooool01?l0003oooooooooool0000Sooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000001gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH01oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000009oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o
0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo000Qooooo`04o`000?oo
ooooooooo`0002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool07?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@7Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Uooooo`03oeEEEOmVIVKo0000
01;ooooo00?o0000ooooool000004_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`04oooool0027ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`3d
ooooo`03o`000?oooooo000003Wooooo000Qooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool0m?ooool00ol0003oooooo`00000iooooo`008Oooool01?l0003oooooooooool0000@
ooooo`03o`000?oooooooooo0?Cooooo00Co0000oooooooooooo0000;oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo000Qooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0
m?ooool01?l0003oooooooooool0000_ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0027o
oooo00Co0000oooooooooooo00004?ooool2o`000?Gooooo00Co0000oooooooooooo0000;oooool0
0ol0003oooooooooo`06ooooo`006_ooooooo`0003[o00003?ooool00ol0003oooooooooo`06oooo
o`008Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooo`0000oooooo00?o0000
ooooool000007?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo013ooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`0?ooooo`03oa0@4?l0003o000000?o00001Ooo
ool0027ooooo00Co0000oooooooooooo00003oooool00ol0003oooooo`00003eooooo`04o`000?oo
ooooooooo`0002oooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooo0000
3oooool01?l0003oooooooooool0003dooooo`04o`000?ooooooooooo`0002oooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooo00003oooool01?l0003oooooooooool0003c
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`04o`000?ooooooooooo`000??ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0eooooo`008Oooool3o`000003ooooool0003ooooo00gooooo00Co0000
oooooooooooo0000loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo000Q
ooooo`05o`000?ooooooooooooooool000003_ooool01?l0003oooooooooool0003cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooooooooooooooo
o`00000>ooooo`05o`000?ooooooooooooooool00000l_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Gooooo000Qooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003o
oooooooooooooooo00000?;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eoooo
o`008Oooool01Ol0003ooooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00003b
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`05o`000?ooooooooooooooool00000l_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Gooooo000Qooooo`05o`000?ooooooooooooooool000003_oo
ool01Ol0003ooooooooooooooooo00000?;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`008Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=?ooool0027ooooo0ol000000ooooooo0000ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0koooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo000Q
ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`008Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool0027ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0kooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo000Qooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`008Oooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo09Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`008Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0dooooo`008Oooool3o`000003ooooool0003ooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`;o0000V_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057o
oooo0_l0000Looooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`;o00007?ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool0027ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0D?ooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?
ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool0
000Jooooo`03o`000?oooooo000007cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0cooooo`008Oooool3o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04oooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oo
oooo000007cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`008Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1>ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooo`00
001looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0C_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooool00000O?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04kooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooo000007_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00001k
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool000Oooooo00Gok^k^oc8b
<_l0003o410@olc<c005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooool00000Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo0007
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Ooo
ool01?l0003oooooooooool0001kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<_ooool000Go00000_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0
0_ooool3o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool00000N_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;o
oooo0007ooooo`05o`000?nHV9SooooooiRHV?lQ8B403oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03;ooooo0007ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Cooooo00Go0000ooooooooooooooooo`00001jooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0<Oooool000Oooooo00?oEEEEohN7Qoooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`05o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo037ooooo0007ooooo`03omgMgOl@413oV9RH00kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
1Ol0003ooooooooooooooooo000007[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0aooooo`002?ooool01?o<c<coA4A4o`000?l@410<ooooo`Co00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`05o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00001jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool0027ooooo0ol0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0<Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000Ioooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aoooo
o`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo000001Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0M_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo033ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02kooooo00?o0000ooooool000006?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000Qooooo`?o00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03_ooool2o`0004cooooo00?o0000ooooool000005oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo00Go0000oooooooooooo
ooooo`00000Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000Boooool00ol0003o
ooooo`00000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool01Ol0003ooooooooooooooooo000004[ooooo00?o0000ooooool000005oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02co
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`00001:ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`05o`000?oooooooooo
ooooool000005oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0;oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo
000001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooool000005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02oooooo000Qooooo`?o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool04?ooool6o`0001Kooooo00Go0000ooooooooooooooooo`00000G
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_
ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo1Ol0000@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000005Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo047ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`10ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03oooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0;_ooool0027ooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0;_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0;Oooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo000Gooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0/ooooo`005oooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:oooool000oooooo1_l00002ooooo`05o`000?oooooooooo
ooooool000001Oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooo`00000H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02_ooooo000Gooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooool000006?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Zooooo`005oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0:_ooool001Oooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo02Wooooo000Gooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Y
ooooo`006?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0:?ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Xoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo000Qooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09Oooool0
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09?ooool0027ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000001Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`008Oooool3o`0000Gooooo
00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00013ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo000Qooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02?ooooo000Qooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00005_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
1?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00013ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00000@ooooo`05o`000?oooooooooo
ooooool000007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000004Oooool01?l0003oooooooooool0
000Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Kooooo00Co0000
oooooooooooo00005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05oooool2o`0001;ooooo00Co0000oooooooooooo00007_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Qooooo`008Oooool3o`0000Kooooo00Co0000oooooooooooo00005oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool2o`0001;ooooo
00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool0000Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooool000006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000023ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool08Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Hooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo0000
023ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooo0000027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02cooooo0_l0000Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo000Qooooo`?o
00001_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07ooo
ool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooo`00000Aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0
003oooooooooo`07ooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07_ooool000Sooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool01oooool2
o`0001Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01kooooo000;ooooo`03ogMgMolb<S;ooooo00?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool01oooool2o`0001Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Dooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Nooooo`001Ol00007ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool3o`0000Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Cooooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01gooooo000;ooooo`03ogMgMolb<S;ooooo00gooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07Oooool000Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000
ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Ooo
ool000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo0000037ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool07Oooool000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooo
oooo000003;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool07?ooool000Sooooo1?l0000<ooooo`Co00001Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
000booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooooooo02?ooooo00Go0000
ooooooooooooooooo`00000cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooo
oooo02?ooooo00Go0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo000Q
ooooo`?o00009?ooool01?l0003oooooooooool0000eooooo`05o`000?ooooooooooooooool00000
O?ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool00000=oooool01?l0003oooooooooool0001looooo`05o`000?oooooooooooooo
ool000004_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06oooool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000gooooo`04
o`000?ooooooooooo`0007cooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooo000003Sooooo00?o0000ooooool00000OOooool01?l0
003oooooooooool0000Booooo`Ko00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01[ooooo000Qooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool00000>Oooool2o`00
07gooooo00Co0000oooooooooooo00006?ooool5o`0002Oooooo00?o0000ooooooooool06_ooool0
027ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000jooooo`03o`000?oooooooooo
07_ooooo00Co0000oooooooooooo0000HOooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooo`00002iooooo`03o`000?oooooo0000067ooooo000Qooooo`?o00009?ooool00ol0003o
ooooo`00002iooooo`;o0000H_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`2hooooo`;o0000H_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`2iooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0^Oooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo0?oooooo7Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00=Sooooo00Ko8B4Qo`00
0?l0003oA4A4omgMgOooool3o`000003oa0@4?oooooooooo08Cooooo003Kooooo`03ogMgMolb<S;o
oooo00;ooooo00?o410@okZj^_ooool0QOooool00=cooooo00Ko0000oooooooooooooooooiRHV?lb
<S:6ooooo`00Roooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Kok^k^oeEEEOl0003o0000
oeEEEOo^k^h3ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01_nHV9So0000o`000?mgMgOo
410@o`0000;ooooo1Ol00008ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o
0000o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000CoA4A4okZj^_oooooo410@1Ol0
0003ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool00ooMgMgo0000okZj^P25ooooo`00
Roooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo
00?o0000ooooooooool02?ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003ooooo
ooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00omEEEGoMgMgodA4A025oooo
o`00Roooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`05oa0@4?n7QhOoooooonk^k_l000001Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;o
oooo00GogMgMoa0@4?oooooo8B4QomgMg@24ooooo`00Roooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03okZj^_l@413o0000
00;o00001Oooool00ol0003oooooooooo`08ooooo`Ko00000oooool01Ol0003ooooooooooooooooo
000000;ooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooooooonk^
k_l00002ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0Q?ooool008_ooooo00?o0000ooooooooool0
1?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool01oooool00oo<
c<co0000ooooo`04ooooo`03o`000?oooooooooo00Sooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S83ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P?ooooo00?o0000oc8b<_oMgMd01?ooool02_mEEEGoMgMgooooooo^k^koEEEEo`000?ooooook^k^
o`000?o^k^h2ooooo`03o`000?oMgMgooooo08;ooooo0029ooooo`03oa0@4?l0003o000000?o0000
0oooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00004ooooo`04oc8b<_l0003o
0000oiRHV0Gooooo00?o0000ooooooooool02?ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;o
oooo00?o410@o`000?mgMgL00_l000001OnHV9Soooooooooooo^k^koEEEE00;o000000CoA4A4onk^
k_oooooooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000ob4Q8OnYZJWo
00000_l@4102o`000004ooooool0003o0000oa0@48?ooooo002;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2iooooo`00Roooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0^Oooool00:[ooooo00?o
410@o`000?l00000^oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.136823, -7.84456, \
0.00504448, 0.0168185}}]
}, Open  ]],

Cell["\<\
Surprisingly, the energy is not well conserved, although the \
particle dynamics is apparently correct.\
\>", "Text"],

Cell[TextData[{
  "\tAs a further check, the kinetic and potential energies are shown in Cell \
",
  ButtonBox["7.83",
    ButtonData:>"Cell 7.83",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p1 = \ 
        ListPlot[
          Table[{n\ \[CapitalDelta]t, potentialenergy[n]}, {n, 0, 30}], 
          PlotJoined \[Rule] True, PlotStyle \[Rule] RGBColor[0, 0, 1], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(p2 = \ 
        ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 30}], 
          PlotJoined \[Rule] True, PlotStyle \[Rule] RGBColor[1, 0, 0], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[p1, p2, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotLabel \[Rule] \ 
          TableForm[{{StyleForm["\<kinetic\>", 
                  FontColor \[Rule] RGBColor[1, 0, 0]], "\< and \>", 
                StyleForm["\<potential\>", 
                  FontColor \[Rule] RGBColor[0, 0, 1]], "\< energy\>"}}, 
            TableSpacing \[Rule] 0]];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.83"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.542755 0.0605636 [
[.18254 .53026 -9 -9 ]
[.18254 .53026 9 0 ]
[.34127 .53026 -9 -9 ]
[.34127 .53026 9 0 ]
[.5 .53026 -9 -9 ]
[.5 .53026 9 0 ]
[.65873 .53026 -9 -9 ]
[.65873 .53026 9 0 ]
[.81746 .53026 -3 -9 ]
[.81746 .53026 3 0 ]
[.97619 .53026 -9 -9 ]
[.97619 .53026 9 0 ]
[1.025 .54276 0 -6 ]
[1.025 .54276 10 6 ]
[.01131 .05825 -12 -4.5 ]
[.01131 .05825 0 4.5 ]
[.01131 .17937 -12 -4.5 ]
[.01131 .17937 0 4.5 ]
[.01131 .3005 -12 -4.5 ]
[.01131 .3005 0 4.5 ]
[.01131 .42163 -12 -4.5 ]
[.01131 .42163 0 4.5 ]
[.5 .63053 -86 0 ]
[.5 .63053 86 12.3125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .54276 m
.18254 .54901 L
s
[(0.2)] .18254 .53026 0 1 Mshowa
.34127 .54276 m
.34127 .54901 L
s
[(0.4)] .34127 .53026 0 1 Mshowa
.5 .54276 m
.5 .54901 L
s
[(0.6)] .5 .53026 0 1 Mshowa
.65873 .54276 m
.65873 .54901 L
s
[(0.8)] .65873 .53026 0 1 Mshowa
.81746 .54276 m
.81746 .54901 L
s
[(1)] .81746 .53026 0 1 Mshowa
.97619 .54276 m
.97619 .54901 L
s
[(1.2)] .97619 .53026 0 1 Mshowa
.125 Mabswid
.06349 .54276 m
.06349 .54651 L
s
.10317 .54276 m
.10317 .54651 L
s
.14286 .54276 m
.14286 .54651 L
s
.22222 .54276 m
.22222 .54651 L
s
.2619 .54276 m
.2619 .54651 L
s
.30159 .54276 m
.30159 .54651 L
s
.38095 .54276 m
.38095 .54651 L
s
.42063 .54276 m
.42063 .54651 L
s
.46032 .54276 m
.46032 .54651 L
s
.53968 .54276 m
.53968 .54651 L
s
.57937 .54276 m
.57937 .54651 L
s
.61905 .54276 m
.61905 .54651 L
s
.69841 .54276 m
.69841 .54651 L
s
.7381 .54276 m
.7381 .54651 L
s
.77778 .54276 m
.77778 .54651 L
s
.85714 .54276 m
.85714 .54651 L
s
.89683 .54276 m
.89683 .54651 L
s
.93651 .54276 m
.93651 .54651 L
s
.25 Mabswid
0 .54276 m
1 .54276 L
s
gsave
1.025 .54276 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05825 m
.03006 .05825 L
s
[(-8)] .01131 .05825 1 0 Mshowa
.02381 .17937 m
.03006 .17937 L
s
[(-6)] .01131 .17937 1 0 Mshowa
.02381 .3005 m
.03006 .3005 L
s
[(-4)] .01131 .3005 1 0 Mshowa
.02381 .42163 m
.03006 .42163 L
s
[(-2)] .01131 .42163 1 0 Mshowa
.125 Mabswid
.02381 .08853 m
.02756 .08853 L
s
.02381 .11881 m
.02756 .11881 L
s
.02381 .14909 m
.02756 .14909 L
s
.02381 .20966 m
.02756 .20966 L
s
.02381 .23994 m
.02756 .23994 L
s
.02381 .27022 m
.02756 .27022 L
s
.02381 .33078 m
.02756 .33078 L
s
.02381 .36106 m
.02756 .36106 L
s
.02381 .39135 m
.02756 .39135 L
s
.02381 .45191 m
.02756 .45191 L
s
.02381 .48219 m
.02756 .48219 L
s
.02381 .51247 m
.02756 .51247 L
s
.02381 .02797 m
.02756 .02797 L
s
.02381 .57304 m
.02756 .57304 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -147 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.3125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(kinetic) show
105.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
105.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
111.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(and) show
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(potential) show
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
195.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(energy) show
231.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.05556 .1579 L
.0873 .06172 L
.11905 .10936 L
.15079 .17855 L
.18254 .12321 L
.21429 .12589 L
.24603 .16818 L
.27778 .11134 L
.30952 .16499 L
.34127 .17336 L
.37302 .08572 L
.40476 .11196 L
.43651 .14448 L
.46825 .08155 L
.5 .14972 L
.53175 .1077 L
.56349 .12101 L
.59524 .14469 L
.62698 .16682 L
.65873 .15685 L
.69048 .13635 L
.72222 .15545 L
.75397 .17936 L
.78571 .11085 L
.81746 .1684 L
.84921 .16663 L
.88095 .04987 L
.9127 .11795 L
.94444 .13354 L
.97619 .16629 L
s
1 0 0 r
.02381 .60332 m
.05556 .59827 L
.0873 .5956 L
.11905 .5924 L
.15079 .58924 L
.18254 .58635 L
.21429 .58436 L
.24603 .58373 L
.27778 .58465 L
.30952 .58679 L
.34127 .58957 L
.37302 .59254 L
.40476 .59558 L
.43651 .59815 L
.46825 .59928 L
.5 .5983 L
.53175 .59576 L
.56349 .59262 L
.59524 .58942 L
.62698 .58666 L
.65873 .58472 L
.69048 .58424 L
.72222 .58523 L
.75397 .5872 L
.78571 .58965 L
.81746 .59252 L
.84921 .59556 L
.88095 .59808 L
.9127 .59914 L
.94444 .59798 L
.97619 .59548 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o4oooool0
0ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?o
oooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o003oooooooooool0oooooomC
ooooo`004oooool00ol00?ooooooooooo`3ooooooe?ooooo000Cooooo`03o`00oooooooooooo0?oo
ooooDoooool001?ooooo00?o0000o`00ooooool0oooooomCooooo`004oooool00ol0003o003ooooo
o`3ooooooe?ooooo000Cooooo`03o`000?l00?oooooo0?ooooooDoooool001?ooooo00?o0000o`00
ooooool0oooooomCooooo`004oooool00ol0003o003oooooo`3ooooooe?ooooo000Cooooo`03o`00
0?oooooo003o0?ooooooDoooool001?ooooo00?o0000ooooool00?l0oooooomCooooo`004oooool0
0ol0003oooooo`00o`3ooooooe?ooooo000Cooooo`03o`000?oooooo003o0?oooooo5_ooool00ol0
0?ooooooooooo`0jooooo`002?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ool00?l0oooooolFooooo`03o`00oooooooooooo03[ooooo0008ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool01?l0003oooooooooool00?oooooooaGooooo0_l00?lkooooo`001_l00002oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000003o`00oooooooooooo0?oooooo4_ooool0
0ol00?ooooooo`00o`0kooooo`002?ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00Co0000
oooooooooooo003o4?ooool00ol00?ooooooooooo`3oooooo`7ooooo00Co003ooooooooooooo003o
>_ooool000Sooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`04o`000?ooooooooooo`00oa3o
oooo00?o003oooooooooool0ooooool1ooooo`04o`00ooooooooooooo`00oc[ooooo0008ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool01Ol0003ooooooooooooooooo003o00oooooo0_l00?oo
ooooo`7ooooo00Go003oooooooooooooooooo`00o`0jooooo`002?ooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00Go0000ooooooooooooooooo`00o`0>ooooo`04o`00ooooooooooooo`00oooo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0gooooo`002?ooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00Go0000ooooooooooooooooo`00o`0>ooooo`04o`00oooooooooooo
o`00oooooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0gooooo`004oooool01Ol0
003ooooooooooooooooo003o00kooooo00Go003oooooooooooooooooo`00o`3nooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0=_ooool001?ooooo00Go0000ooooooooooooooooo`00
o`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0n_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo03Kooooo000Cooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Kooooo00?o003o
ooooooooool0POooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03Gooooo000Coooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo05Kooooo0_l00?lMooooo`03o`00oooooooooooo087ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0eooooo`004oooool2o`0000?ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05Gooooo00?o003oooooool0
0?l06oooool00ol00?ooooooo`00o`21ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0=Oooool001?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool0Doooool01Ol00?oooooooooooooooooo003o01[o
oooo00?o003oooooool00?l0POooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo03Co
oooo000Cooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Fooooo`05o`00ooooooooooooooooool00?l0P?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo03Cooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo05;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l0P?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo03?ooooo000Cooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo053ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0O?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo03?ooooo
000Cooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0O?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo03;ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04oooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool2o`00of_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0b
ooooo`004oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool01?l00?ooooooo`00ool00?m?ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0booooo`004oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool02_ooool2o`00o`kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo0_l00?m=oooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0aoooo
o`004oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo003o01Wooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`05ooooo`;o003oB_ooool00ol00?ooooooo`00o`0Gooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0<Oooool001?ooooo0_l00005ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0_ooooo`03o`00
oooooooo003o01Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`;o003o
B?ooool00ol00?ooooooo`00o`0Gooooo`03o`00oooooooooooo00gooooo0_l00?laooooo`004ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0@ooooo`Ko003o5oooool01Ol00?oooooooooooooooooo003o01Sooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`;o003oAOooool01Ol00?oooooo
oooooooooooo003o01Gooooo00?o003oooooooooool04?ooool2o`00oboooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool5o`00oa7ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`12ooooo`05o`00ooooooooooooooooool00?l05Oooool00ol00?oo
ooooooooo`0Booooo`?o003o;?ooool001?ooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool2o`00od7ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Gooooo
0_l00?lZooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo03kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Oooooo0_l0
0?lXooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo03cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool09Oooool001?ooooo00?o0000ooooooooool01Oooool01Ol00?oooooooooooooooooo
003o01Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo01Kooooo00Co003ooooooooooooo003o4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01Gooooo0_l00?lPooooo`?o003o6Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Tooooo`004oooool0
0ol0003oooooooooo`06ooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooool00?l04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool06ooo
ool2o`00o`?ooooo0_l00?lFooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02?ooooo000Cooooo`03o`000?oooooo
oooo00Kooooo00Co003ooooooooooooo003o5oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`04o`00oooo
ooooooooo`00oacooooo0_l00?lIooooo`;o003o1oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Nooooo`03o`00
oooooooooooo02;ooooo000Cooooo`03o`000?oooooooooo00Kooooo00?o003oooooool00?l06?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0;?oo
ool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02?oo
ool2o`00oa;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool08Oooool001?ooooo0_l00007ooooo`03o`00oooooooo
003o01Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo02kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Booooo`;o003o3Oooool2
o`00oa3ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool08?ooool001?ooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooo`00o`0Iooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Aooooo`;o003o4?ooool2o`00oa7ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`0Oooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo05Co
oooo00?o003oooooooooool02oooool2o`00oaCooooo0_l00?l<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01ko
oooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`0Aooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0EOooool2o`00o`Sooooo0ol00?lHooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo02Cooooo00?o003oooooooooool07Oooool001?ooooo00?o0000ooooooooool0
9?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Co003ooooooooooooo
003o4_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05Oooooo00?o003ooooooooo
ool00oooool2o`00oacooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Looooo`00
4oooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooo`00o`0Cooooo`?o003o2?ooool00ol00?ooooooooooo`1Iooooo`03o`00
oooooooo003o00;o003o7oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo01_ooooo
000Cooooo`03o`000?oooooooooo02Cooooo00Go003oooooooooooooooooo`00o`0Looooo`03o`00
oooooooooooo01Gooooo0ol00?l5ooooo`03o`00oooooooooooo05[ooooo00?o003oooooooooool0
8Oooool2o`00o`Gooooo00?o003oooooooooool04?ooool;o`00odOooooo0008ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Uooooo`04o`00ooooooooooooo`00ocOo
oooo0ol00?l2ooooo`03o`00oooooooooooo083ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Rooooo`002?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool09Oooool00ol00?ooooooo`00o`0kooooo`;o003oQ?ooool01?l00?ooooooooooool00?mUoooo
o`001_l00002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Voooo
o`03o`00oooooooooooo0<7ooooo00?o003oooooool00?l0IOooool000Sooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000joooool00ol00?ooooooooooo`1Tooooo`002?ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooomCooooo`002?ooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`3ooooooe?ooooo0009ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
01?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooo
ooooo`3ooooooe?ooooo000Cooooo`;o0000oooooomDooooo`004oooool00ol0003oooooooooo`3o
oooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000oooooooo
ool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0
003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000
ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004ooo
ool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
00[ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooDoooool000_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooe?ooooo0006o`0000;ooooo
1Ol00006ooooo`?o0000oooooomCooooo`002?ooool01?m4A4CogMgMooooool00007ooooo`03o`00
0?oooooooooo0?ooooooDoooool000Sooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`3ooooooe?ooooo0009ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooo
oomCooooo`002Oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooDoooool0
00[ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004ooo
ool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
01?ooooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3o
oooooe?ooooo000Cooooo`;o0000oooooomDooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooo
ooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000
ooooooooool0oooooomCooooo`004oooool2o`000?ooooooE?ooool001?ooooo00?o0000oooooooo
ool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0
003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooDoooool000Ko00000oooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?ooooooDoooool000[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000?ooooooDoooool000_ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooo
oe?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooomCooooo`00
2?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0oooooomCooooo`00
2?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooomCooooo`00
4oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDooo
ool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooo
oe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo0_l0003ooooooeCooooo
000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomC
ooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oo
ooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooooooo
o`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000oooo
ooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`;o0000
oooooomDooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooo
oooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003o
ooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o
0000ooooooooool09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
7_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`0:?ooool4o`000003oa0@4?oooooooooo02Gooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool5o`0001Cooooo000Cooooo`03o`000?oooooooooo02Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Noooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@0Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Dooooo`004oooool00ol0003oooooooooo`0Vooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Oooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0001oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000007oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool00onH
V9So8B4Qonk^kP0Eooooo`004oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP0Nooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q01oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S80:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h05?ooool001?ooooo0_l0000Wooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Mooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool0000Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
01oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0:_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool04ooo
ool001?ooooo00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool07?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
8?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool08Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Zooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`004oooool00ol0
003oooooooooo`0Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000023ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH027ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000:_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`004oooool0
0ol0003oooooooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<01kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:?ooool00omEEEGoIVIV
o`00000Yooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Dooooo`00
4oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDooo
ool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooo
odWooooo00GoV9RHo`000?l0003oA4A4okZj^P05ooooo`004oooool00ol0003oooooooooo`3ooooo
odWooooo00Go410@okZj^_o^k^koMgMgoa0@4005ooooo`002oooooooo`0004Wo00002oooool00ol0
003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oo
oooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool001?ooooo00?o
0000ooooooooool0oooooom7ooooo`03oa0@4?l0003o000000?o00001_ooool001?ooooo00?o0000
ooooooooool0oooooom9ooooo`03o`000?oooooooooo00Oooooo000Cooooo`03o`000?oooooooooo
0?ooooooBOooool00ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`;o0000oooooomDoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`0f
ooooob3oo`00LOoooolPool006_ooooo000Cooooo`03o`000?oooooooooo02cooooo2_oo000Poooo
o`[oo`00GOooool:ool0023ooooo2ooo001Pooooo`004oooool00ol0003oooooooooo`0Qooooo`_o
o`00=?ooool;ool004Oooooo2ooo000eooooo`[oo`00E_ooool001?ooooo00?o0000ooooooooool0
5oooool:ool004[ooooo2_oo000cooooo`[oo`00B_ooool:ool004cooooo000Cooooo`03o`000?oo
oooooooo00cooooo2ooo001Nooooo`_oo`007_ooool:ool005kooooo2ooo000Doooooa3oo`007Ooo
ool001?ooooo00?o0000ooooooooool00_ooool:ool007Cooooo7_oo001coooooaCoo`00;Oooool0
01?ooooo1Ooo003ooooooe7ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00X?ooool01?l@4?oo003oo`00ool00?mXooooo`06ob4Q8Ol0003o0000odA4A?oMgMgooooo0ol0
00000ol@413oooooooooo`1@ooooo`00XOooool00ol00?ooooooooooo`1[ooooo`03ogMgMolb<S;o
oooo00;ooooo00?o410@okZj^_ooool0DOooool00:7ooooo00?o003oooooooooool0K?ooool01_l0
003oooooooooooooooooV9RHoc8b<U;ooooo0016ooooo`;oo`000_ooool00ooo413oo`00ool00002
ooooo`Goo`000_ooool01?oo413oo`00ool00?ooool2ool00004ool@4?ooooooonk^oomEE@;oo`00
00?oodA4oonj^_ooool00_ooool01OooV9Soo`00ool00?ooA4CookZj00?ooooo1Ooo0003ooooo`05
oomVI_oo003oo`00oom4A?ooc<`01_ooool01_nHV9So0000o`000?mgMgOo410@o`0000;ooooo00Co
410@o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2o`000003oiRHV?l0003o410@00So
oooo00Wo003oogMgool00?oo003ooeEEooo^k_ooooooonk^oomEEOl00_l00?l00omEEOook^kooooo
o`02ooooo`05oiRHool00?oo003oodA4oonj^_l00_ooool01_o^k_ooEEGoo`00ool00?ooA4CookZj
o`;ooooo00Co413oo`00ool00?oooooo0_l00?l01?l@4?oooooooooooonHV?l2o`00o`03odA4oonj
^_oooooo00;ooooo1Ol00?l2ooooo`06oiRHool00?oo003oogMgool@4?oo003o0_ooool5o`00o`Ko
oooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@4?l0003o0000ooooo`;o000000Co
410@ooooooo^k^koEEEE0_l000001?m4A4Co^[Zjooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0
003o410@olc<c?l00003ooooo`03omgMgOl0003o^[Zj057ooooo0017ooooo`05ool00?ooooooonk^
oolb<_ooc<`01Oooool00ooo003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00000_oo
ool01_ooEEGoogMgooooooook^koogMgool@40?ooooo00Gooa0@oonj^_ook^koogMgool@4005oooo
o`03ool00?oooooooooo00;ooooo00KoofIVoomgMooooooooooooon7Qooo4106ooooo`05o`000?o<
c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00009ooooo`09o`00oomEEOook^kooooooomgMoooEEGooooooomEEOooMgOo00;o
oooo00?oMgOooeEEooooool00_ooool01Ol@4?oo^[[oonk^oomgMooo413o00;ooooo00KoEEGoogMg
ooooooook^koogMgool@4?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol@4?oo^[[o
onk^oomgMooo413o00Gooooo00?o003oooooooooool00_ooool01Ol00?ooc<coonk^oon7Qooo003o
00Gooooo00?o003oooooooooool01_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0
003oooooooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00omEEEGoMgMgodA4
A01Aooooo`00Aoooool01?oo003ooiRHoolb<_ooc<`6ooooo`03ool00?oooooooooo00?ooooo00Go
o`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Wooooo00Go410@ohN7Qooooooo
k^k^o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooooooo
k^k^o`0000Wooooo00?o003oonk^ooooool00_ooool00ol00?ooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00Go413oohN7oooo
ooook^koo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01OoMgMgo410@oooooolQ8B7ogMgM053o
oooo0017ooooo`03ool00?oo413ooiRH00Oooooo00?oo`00ooooooooool00oooool01Ooo003ooooo
ooooooooooooo`0000;ooooo1_oo0003ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`09ooooo`03okZj^_l@413o000000;o00001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00009ooooo`03o`00ooo^
k_oooooo00;ooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Kooooo
1_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00;ooooo00?o^[[ooa0@ool00?l00_l00?l5ooooo`03o`00oooooooooooo00Ko
oooo1_l00003ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000oooo
ooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00GoIVIVohN7QoooooooV9RH
oeEEE@1@ooooo`00Aoooool01?oo003oonk^oomEEOooQhL6ooooo`03ool00?oooooooooo00?ooooo
00Goo`00oon7QoooooooojVYool00002ooooo`06oomEEOooQhOoonk^ooooooooQhOooc8b0oooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo00KoofIVoomgMooooooooooooon7
Qooo0009ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06
ofIVI_mgMgOoooooonk^k_mEEEGo00002Oooool02Ol00?ooEEGoonk^ooooooooMgOoofIVoooooooo
EEGoogMgo`02ooooo`03ogMgoomEEOoooooo00;ooooo00?o003oooooooooool01?ooool01_mEEOoo
QhOoonk^ooooooooQhOooc8bo`?ooooo00Go003oohN7ooooooooZJWoo`00o`03ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01Oooool00oo<c?oo003oooooo`04ooooo`03o`00oooo
oooooooo00Kooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVY
ZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?oo
ool02_mEEEGoMgMgooooooo^k^koEEEEo`000?ooooook^k^o`000?o^k^h2ooooo`03o`000?oMgMgo
oooo04kooooo0017ooooo`05ool00?ooooooodA4ool00?oo41000oooool00ooo413oo`00ool00004
ooooo`03ool@4?oo003oogMg00;oo`0000GooiRHooooooooooooonk^oomEE@02ool00004oom4A?oo
k^koooooool@40Goo`001?ooool00ooo413oo`00ool00004ooooo`06ooo^k_ooIVKoo`00ool00?oo
A4Coo`001oooool01?lb<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o000000WoV9RH
ooooooooooook^k^oeEEEOl0003o410@olc<c?l000002?ooool00ol@4?oo003oogMgo`02o`00o`05
ofIVooo^k_ooooooonk^oomEEOl00_l00?l01?mEEOook^koooooool@4?l5o`00o`?ooooo00Kok^ko
oeEEool00?oo003oodA4ooo^k_l2ooooo`03oa0@ool00?ooMgOo00;o003o00?oV9Soooooool@4?l0
1Ol00?l4ooooo`03oa0@ool00?oo003o00Gooooo00Co<S;oo`00ool00?ooV9So1Oooool00ol00?oo
ooooooooo`06ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool00ol@413o0000ogMgM`02
o`000005oiRHV?ooooooooooonk^k_mEEED00_l000001?m4A4Cok^k^ooooooooool2o`000004ojVY
ZOlQ8B7o0000ob4Q8@;ooooo00Kok^k^oeEEEOl0003o8B4QojVYZOl00002oa0@40;o000000Cooooo
o`000?l0003o410@Coooool004Oooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0]
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo08?ooooo0017ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02?ooooo00?o0000oooo
ooooool05oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`23ooooo`00A_ooool2ool000Wooooo00?ooa0@oooooooo
ool07Oooool00ooo413oooooooooo`0Rooooo`;o0000>oooool00ol@4?ooooooooooo`0:ooooo`03
oa0@ool00?oo003o08Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0742721, -8.96179, \
0.00482121, 0.0631792}}]
}, Open  ]],

Cell[TextData[{
  "The kinetic energy (red curve) varies smoothly and is nearly constant, \
just as one would expect for this nearly circular motion. However, the \
potential energy (blue curve) varies considerably  from step to step. \
Clearly, this potential energy is in error.  The reason for this error can be \
understood by substituting  the discrete Fourier transform representation for \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(i\ j\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(\(\ \)\(i\ j\)\)\)]],
  " into Eq. ",
  ButtonBox["(7.3.10)",
    ButtonData:>{"Chapter7.nb", "(7.3.10)"},
    ButtonStyle->"Hyperlink"],
  " . Using orthogonality of the Fourier modes, one finds"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"U", " ", "=", " ", 
          RowBox[{
            RowBox[{\(M\^2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], 
              " ", \(\[Sum]\+\(m, n = 0\)\%\(M - 1\)\(\[Rho]\&~\_\(m\ n\)\) \
\(\[Phi]\&~\_\(m\ n\)\^*\)\)}], "=", 
            RowBox[{\(-4\), " ", "\[Pi]", " ", \(L\^2\), "G", 
              RowBox[{
                UnderoverscriptBox[
                  StyleBox["\[Sum]",
                    FontSize->9], \(m, 
                  n = 0\), \(M - 
                    1\)], \(\((\(|\)\(\[Rho]\&~\_\(m\ n\)\)\(|\))\)\^2\/\(\(\
\[Kappa]\^2\)(m, \ n)\)\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(7.3.11)"],

Cell[TextData[{
  "where, in the second step, we employed Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>{"Chapter6.nb", "(6.2.43)"},
    ButtonStyle->"Hyperlink"],
  "  (multiplied by the factor ",
  Cell[BoxData[
      \(TraditionalForm\`4\ \[Pi]\ G\)]],
  "), and where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Kappa]\^2\)(m, n)\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Kappa]\^2\)(m, n)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ m/M)\)}], " ", "+", 
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ n/M)\)}]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " approximates the square of the wavenumber, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\^2\), "=", 
          RowBox[{\(\((2\ \[Pi])\)\^2\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(m\^2\), "/", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"]}], "+", 
                RowBox[{\(n\^2\), "/", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}]}], ")"}]}]}], 
        TraditionalForm]]],
  ", provided that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " is small. In this limit Eq. ",
  ButtonBox["(7.3.11)",
    ButtonData:>{"Chapter7.nb", "(7.3.11)"},
    ButtonStyle->"Hyperlink"],
  "  returns to the correct result for the potential energy, ",
  Cell[BoxData[
      \(TraditionalForm\`U = \(-4\)\ \[Pi]\ G \
\(\[Integral]\[DifferentialD]\^2 
                k \((\(|\)\(\[Rho]\&~\)\(|\))\)\^2\/k\^2\)\)]],
  ".   However, for large wavenumbers, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  "deviates considerably from ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2\)]],
  ", and in fact ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " ",
  "goes to zero",
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " approach ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " . This implies that, for a given particle density,  large wavenumber \
contributions to the potential energy are afforded much more weight than they \
deserve. As a result,  large-wavenumber contributions to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " produce dramatic variations in ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tOf course, we already know that large wavenumbers are not properly \
handled by the FFT solution anyway, so the nonconservation of the potential \
energy due to large-wavenumber contributions might be regarded as an \
indicator that the PIC method is breaking down. However, we can see in this \
example that the actual particle dynamics appears to be working well. The \
reason for this apparent contradiction is that the dynamics depends on the \
force, not the energy, and the force is not so heavily weighted toward large \
wavenumbers as is the energy. Recall that we used a centered difference \
method for the force field at the grid points, Eqs. ",
  ButtonBox["(7.3.8)",
    ButtonData:>{"Chapter7.nb", "(7.3.8)"},
    ButtonStyle->"Hyperlink"],
  " . If we write the force in terms of a discrete Fourier transform, we find \
that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], "~"], \(m\ n\)], "=", 
          RowBox[{
            RowBox[{\(-\[ImaginaryI]\), " ", 
              RowBox[{
                StyleBox["K",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(m, n\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], " ", \(\[Phi]\&~\_\(m\ n\)\)}], "=",
             " ", 
            RowBox[{"4", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "G", " ", 
              RowBox[{
                StyleBox["K",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(m, n\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  
                  FontWeight->
                    "Plain"]}], \(\[Rho]\&~\_\(m\ n\)\/\(\(\[Kappa]\^2\)(m, \ 
                    n)\)\), " "}]}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["K",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(m, n\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"(", 
            RowBox[{
              FractionBox[\(sin(2\ \[Pi]\ m/M)\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], ",", 
              FractionBox[\(sin(2\ \[Pi]\ n/M)\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]]]}], ")"}]}], 
        TraditionalForm]]],
  " is a vector that approximates ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at small ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(k\)\(|\)\)\)]],
  ". Thus, large wavenumbers are still weighted too heavily compared to the \
exact expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], "~"], "=", 
            RowBox[{"4", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "G", " ", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\[Rho]\&~\/k\^2\)}]}], ","}], 
        TraditionalForm]]],
  "but ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["K",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(m, n\),
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " ",
  "also becomes small",
  " at large wavenumbers. This greatly reduces the effect that \
large-wavenumber contributions to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " have on the force. In other words, large-wavenumber ripples in the \
density have much less effect on the force than they do on the potential \
energy. As a result, the PIC method can still be working properly, even when \
energy is not well conserved. "
}], "Text"],

Cell[TextData[{
  "\tNote that Eq. (",
  ButtonBox["7.3.12",
    ButtonData:>"(7.3.12)",
    ButtonStyle->"Hyperlink"],
  ") relies on using a finite difference method, Eq. (",
  ButtonBox["7.3.8",
    ButtonData:>"(7.3.8)",
    ButtonStyle->"Hyperlink"],
  "), to determine the force from the potential. If instead we determined the \
force by applying an inverse FFT to the expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["F",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"], "=", 
          RowBox[{\(-\[ImaginaryI]\), " ", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], " ", \(\[Phi]\&~\)}]}], 
        TraditionalForm]]],
  ", large wavenumbers would be weighted too heavily.  This is the main \
reason why Eq. (",
  ButtonBox["7.3.8",
    ButtonData:>"(7.3.8)",
    ButtonStyle->"Hyperlink"],
  ") is the preferred method for force evaluation."
}], "Text"],

Cell["\<\
\tHowever, it can still  useful to keep track of the energy, \
particularly when the density has little or no large-wavenumber \
contributions. This will be true if the density is a reasonably smooth \
function of position. \
\>", "Text"],

Cell["\<\
\tSince energy is not necessarily  a good indicator of the code \
accuracy, and since linear momentum is always exactly conserved, constants of \
the motion are of limited use in accuracy tests. We must therefore fall back \
on the old standby techniques for determining the validity of our results: \
\
\>", "Text"],

Cell[TextData[{
  "\t(1) increase and/or decrease the time step size by  factors of two to \
ensure that results are independent of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(2) increase and/or decrease the grid spacing  by  factors of two to \
ensure that results are independent of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(3) increase and/or decrease the particle number by  factors of two \
(decreasing or increasing  the mass per particle by the same factor so that \
mass density remains the same) to ensure that results are independent of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Gravitational Collapse in a Cold Gas", "Section",
  CellTags->{"i:56", "c:37"}],

Cell[TextData[{
  "A cold uniform gas is unstable to gravitational collapse. Due to the \
attraction of the gas to itself, small density variations grow over time. \
Matter is attracted to maxima in these variations, increasing their size. \
This is called the",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Jeans",
    ButtonData:>{
      URL[ 
      "http://www-history.mcs.st-andrews.ac.uk/history/Mathematicians/Jeans.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" instability",
    FontSlant->"Italic"],
  ". This basic phenomenon is responsible for the formation of all the \
structure we can see in the night sky, including planets, stars,  and \
galaxies. "
}], "Text",
  CellTags->"i:80"],

Cell[TextData[{
  "\tThe instability can also be studied from a different point of view by \
considering the energy of the system. According to Eq. ",
  ButtonBox["(7.3.11)",
    ButtonData:>{"Chapter7.nb", "(7.3.11)"},
    ButtonStyle->"Hyperlink"],
  " , the potential energy is a negative quantity, becoming more negative as \
the gas collapses and the density becomes more concentrated.  In order to \
conserve energy,  kinetic energy must increase. As the gas collapses, it \
heats.   What is the end product of this process?"
}], "Text"],

Cell[TextData[{
  "\tWe can study  gravitational collapse and heating  in a PIC simulation. \
In Cells ",
  ButtonBox["7.84",
    ButtonData:>"Cell 7.84",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["7.85",
    ButtonData:>"Cell 7.85",
    ButtonStyle->"Hyperlink"],
  " we run a simulation of 1000 particles, initially distributed randomly \
throughout the box, and with zero initial momentum. We perform the simulation \
on a rather coarse 10 by 10 spatial grid, since we are not interested in \
quantitative accuracy at this point, only in the qualitative effects \
associated with the collapse."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Utilities`;\)\), "\n", 
    \(m = 1; M = 10; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t\  = \ 0.003;\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(r0\  = \ Table[{Random[], Random[]}, {1000}];\)\), "\n", 
    \(\(p0 = \ Table[{0, 0}, {1000}];\)\), "\n", 
    \(Timing[leapfrog[r0, p0, 60, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.84"],

Cell[BoxData[
    \({31.99`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 60, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.85"],

Cell[TextData[{
  "\tSmall fluctuations in the initial density are amplified by the Jeans \
instability, resulting in collapse of the gas cloud, followed by approach to \
something like an equilibrium state that consists of a single density peak,  \
surrounded by a hot gas of particles.   If one runs the simulation several \
times, one will find that qualitatively similar behavior occurs each time.\n\t\
  In Cell ",
  ButtonBox["7.86",
    ButtonData:>"Cell 7.86",
    ButtonStyle->"Hyperlink"],
  " we calculate the kinetic energy of the cloud."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 60}], 
        PlotJoined \[Rule] True];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.86"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 5.29101 0.0147151 1.78653e-06 [
[.15608 .00222 -15 -9 ]
[.15608 .00222 15 0 ]
[.28836 .00222 -12 -9 ]
[.28836 .00222 12 0 ]
[.42063 .00222 -15 -9 ]
[.42063 .00222 15 0 ]
[.55291 .00222 -9 -9 ]
[.55291 .00222 9 0 ]
[.68519 .00222 -15 -9 ]
[.68519 .00222 15 0 ]
[.81746 .00222 -12 -9 ]
[.81746 .00222 12 0 ]
[.94974 .00222 -15 -9 ]
[.94974 .00222 15 0 ]
[.01131 .10404 -30 -4.5 ]
[.01131 .10404 0 4.5 ]
[.01131 .19337 -36 -4.5 ]
[.01131 .19337 0 4.5 ]
[.01131 .28269 -36 -4.5 ]
[.01131 .28269 0 4.5 ]
[.01131 .37202 -36 -4.5 ]
[.01131 .37202 0 4.5 ]
[.01131 .46135 -36 -4.5 ]
[.01131 .46135 0 4.5 ]
[.01131 .55067 -36 -4.5 ]
[.01131 .55067 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15608 .01472 m
.15608 .02097 L
s
[(0.025)] .15608 .00222 0 1 Mshowa
.28836 .01472 m
.28836 .02097 L
s
[(0.05)] .28836 .00222 0 1 Mshowa
.42063 .01472 m
.42063 .02097 L
s
[(0.075)] .42063 .00222 0 1 Mshowa
.55291 .01472 m
.55291 .02097 L
s
[(0.1)] .55291 .00222 0 1 Mshowa
.68519 .01472 m
.68519 .02097 L
s
[(0.125)] .68519 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(0.15)] .81746 .00222 0 1 Mshowa
.94974 .01472 m
.94974 .02097 L
s
[(0.175)] .94974 .00222 0 1 Mshowa
.125 Mabswid
.05026 .01472 m
.05026 .01847 L
s
.07672 .01472 m
.07672 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.12963 .01472 m
.12963 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.20899 .01472 m
.20899 .01847 L
s
.23545 .01472 m
.23545 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.31481 .01472 m
.31481 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.36772 .01472 m
.36772 .01847 L
s
.39418 .01472 m
.39418 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.47354 .01472 m
.47354 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.52646 .01472 m
.52646 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.60582 .01472 m
.60582 .01847 L
s
.63228 .01472 m
.63228 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.71164 .01472 m
.71164 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76455 .01472 m
.76455 .01847 L
s
.79101 .01472 m
.79101 .01847 L
s
.84392 .01472 m
.84392 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.92328 .01472 m
.92328 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10404 m
.03006 .10404 L
s
[(50000)] .01131 .10404 1 0 Mshowa
.02381 .19337 m
.03006 .19337 L
s
[(100000)] .01131 .19337 1 0 Mshowa
.02381 .28269 m
.03006 .28269 L
s
[(150000)] .01131 .28269 1 0 Mshowa
.02381 .37202 m
.03006 .37202 L
s
[(200000)] .01131 .37202 1 0 Mshowa
.02381 .46135 m
.03006 .46135 L
s
[(250000)] .01131 .46135 1 0 Mshowa
.02381 .55067 m
.03006 .55067 L
s
[(300000)] .01131 .55067 1 0 Mshowa
.125 Mabswid
.02381 .03258 m
.02756 .03258 L
s
.02381 .05045 m
.02756 .05045 L
s
.02381 .06831 m
.02756 .06831 L
s
.02381 .08618 m
.02756 .08618 L
s
.02381 .12191 m
.02756 .12191 L
s
.02381 .13977 m
.02756 .13977 L
s
.02381 .15764 m
.02756 .15764 L
s
.02381 .1755 m
.02756 .1755 L
s
.02381 .21123 m
.02756 .21123 L
s
.02381 .2291 m
.02756 .2291 L
s
.02381 .24696 m
.02756 .24696 L
s
.02381 .26483 m
.02756 .26483 L
s
.02381 .30056 m
.02756 .30056 L
s
.02381 .31842 m
.02756 .31842 L
s
.02381 .33629 m
.02756 .33629 L
s
.02381 .35415 m
.02756 .35415 L
s
.02381 .38989 m
.02756 .38989 L
s
.02381 .40775 m
.02756 .40775 L
s
.02381 .42562 m
.02756 .42562 L
s
.02381 .44348 m
.02756 .44348 L
s
.02381 .47921 m
.02756 .47921 L
s
.02381 .49708 m
.02756 .49708 L
s
.02381 .51494 m
.02756 .51494 L
s
.02381 .53281 m
.02756 .53281 L
s
.02381 .56854 m
.02756 .56854 L
s
.02381 .5864 m
.02756 .5864 L
s
.02381 .60427 m
.02756 .60427 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.03968 .01488 L
.05556 .01562 L
.07143 .01716 L
.0873 .02006 L
.10317 .02542 L
.11905 .03522 L
.13492 .05296 L
.15079 .08422 L
.16667 .13461 L
.18254 .20091 L
.19841 .26528 L
.21429 .31619 L
.23016 .36094 L
.24603 .43214 L
.2619 .54195 L
.27778 .60332 L
.29365 .57446 L
.30952 .51724 L
.3254 .47161 L
.34127 .45509 L
.35714 .46579 L
.37302 .47697 L
.38889 .48823 L
.40476 .4995 L
.42063 .50382 L
.43651 .50557 L
.45238 .50308 L
.46825 .49907 L
.48413 .49101 L
.5 .47922 L
.51587 .46906 L
.53175 .45276 L
.54762 .43595 L
.56349 .43584 L
.57937 .4634 L
.59524 .51085 L
.61111 .55203 L
.62698 .56265 L
.64286 .55028 L
.65873 .52492 L
.6746 .50241 L
.69048 .48597 L
.70635 .48059 L
.72222 .48359 L
.7381 .48699 L
.75397 .48978 L
.76984 .49613 L
.78571 .50514 L
.80159 .52063 L
Mistroke
.81746 .53638 L
.83333 .53504 L
.84921 .52118 L
.86508 .50544 L
.88095 .4963 L
.89683 .4978 L
.9127 .50567 L
.92857 .50688 L
.94444 .49664 L
.96032 .48334 L
.97619 .47593 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00B_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`Co000000?o410@ooooooooool02_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool01Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go
410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM007ooooo001:ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWo
oooo00Oooooo0OmgMgL1oc8b<P7ooooo001:ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool02Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool01?ooool00onYZJWoEEEEooooo`08ooooo`7o00000Oooool004[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001oooool00omgMgOo<S8booooo`06ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0<
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`06ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00Kooooo0OmgMgL1oc8b<P7o
oooo001:ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000001_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<007ooooo001:ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool03Oooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
1Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00?ooooo001:ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`09ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool00oooool004[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Cooooo1?l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`Co00003?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l0
0002ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool002goooooool0000h
o`0000Cooooo000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool003Cooooo00?o0000oooooooo
ool04oooool3o`00013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool003Cooooo00?o0000ooooooooool0
5_ooool2o`000?oooooo6_ooool003Cooooo00?o0000ooooooooool06?ooool2o`000?oooooo6?oo
ool003Cooooo0_l0000Kooooo`03o`000?oooooooooo0?oooooo5Oooool003Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`3ooooooaCooooo000dooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0oooooolDooooo`00=?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo0?oooooo4oooool003Cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`3ooooooa;ooooo000dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolB
ooooo`00=?ooool2o`0001oooooo00?o0000ooooooooool0oooooolAooooo`00=?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo4?ooool003Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`3ooooooa3ooooo000dooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0ooooool?ooooo`00=?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo0?oooooo3oooool003Cooooo0_l0000Rooooo`03o`000?oooooooooo0?oooooo3_ooool003Co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3oooooo`gooooo000dooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0ooooool=ooooo`00=?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo0?oooooo3?ooool003Cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`3oooooo`cooooo000dooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0ooooool;ooooo`00=?ooool2o`0002Gooooo00?o0000ooooooooool0ooooool;ooooo`00
=?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo2oooool003Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000:ooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000=oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000>oooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool3o`0002Kooooo00?o0000ooooooooool0ooooool9ooooo`003Oooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?oooooo2Oooool000[ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?oooooo2Oooool0
00[ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3oooooo`So
oooo000:ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0oooo
ool8ooooo`002_ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0ooooool8oooo
o`00=?ooool2o`0002Wooooo00?o0000ooooooooool0ooooool7ooooo`00=?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0?oooooo1oooool003Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`3oooooo`Oooooo000dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0ooooool6ooooo`00=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
0?oooooo1_ooool003Cooooo0_l0000Zooooo`03o`000?oooooooooo0?oooooo1_ooool003Cooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`Kooooo000dooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0ooooool5ooooo`00=?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0?oooooo1Oooool003Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`3oooooo`Gooooo000dooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0ooooool5ooooo`00=?ooool2o`0002cooooo00?o0000ooooooooool0ooooool4ooooo`00=?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo1?ooool003Cooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`3oooooo`Cooooo000dooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0ooooool4ooooo`00=?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo0?oooooo0oooool003Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`3oooooo`?ooooo000dooooo`;o0000;Oooool00ol0003oooooooooo`3oooooo`?ooooo000d
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0ooooool3ooooo`00=?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo0_ooool000;ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3o
ooooo`;ooooo0004ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo0_ooool000Cooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4006ooooo`?o0000;Oooool00ol0003oooooooooo`3oooooo`;o
oooo0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo0?oooooo0Oooool000Cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0oooo
ool1ooooo`001?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`3oooooo`7ooooo0004ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
0?oooooo0Oooool000;ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0ooooool003Cooooo0_l0000`ooooo`03o`00
0?oooooooooo0?oooooo000dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0oooo
ool003Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3oooooo`00=?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo0?kooooo000dooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0o_ooool003Cooooo0_l0000aooooo`03o`000?oooooooooo0?kooooo
000dooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0o_ooool003Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`3mooooo`00=?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo0?gooooo000dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0oOooool003Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3mooooo`00=?oo
ool2o`0003?ooooo00?o0000ooooooooool0o?ooool003Cooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`3looooo`00=?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
0?cooooo000dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0o?ooool003Cooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`3kooooo`00=?ooool2o`0003Cooooo00?o
0000ooooooooool0noooool003Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`3k
ooooo`00=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0?_ooooo0002ooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`3jooooo`001?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`3jooooo`001?ooool00ol0003oooooooooo`07oooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0?[ooooo0004ooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Cooooo0ol0000eooooo`03o`000?oooooooooo0?Wooooo0004
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo0?Wooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3iooooo`001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0n?oo
ool000;ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0n?ooool003Cooooo0_l0000gooooo`03o`000?oooooooooo0?Sooooo000dooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0moooool003Cooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`3gooooo`00=?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo0?Oooooo000dooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0m_ooool003Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3fooooo`00=?ooool2o`0003Wooooo
00?o0000ooooooooool0m_ooool003Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`3eooooo`00=?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0?Gooooo000doooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0mOooool003Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`3dooooo`00=?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo0?Cooooo000dooooo`;o0000>oooool00ol0003oooooooooo`3dooooo`00=?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0??ooooo000dooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0loooool003Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`3cooooo`00=?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0?;ooooo
000dooooo`;o0000?Oooool00ol0003oooooooooo`3booooo`00=?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo0?;ooooo000dooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0lOooool00003ooooool0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0lOooool00006oooooonHV9So8B4Qonk^k_oo
ooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0lOooool000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0l?ooool000?ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000?_ooool00ol0003oooooooooo`3`ooooo`001?oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3`ooooo`001Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3`ooooo`0000Koooooo`00
0?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3`ooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`3_ooooo`00=?oo
ool2o`00043ooooo00?o0000ooooooooool0koooool003Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`3_ooooo`00=?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
0>oooooo000dooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0k_ooool003Cooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`3^ooooo`00=?ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo0>kooooo000dooooo`;o0000@Oooool00ol0003oooooooooo`3^
ooooo`00=?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0>gooooo000dooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0kOooool003Cooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`3]ooooo`00=?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo0>gooooo000dooooo`;o0000@_ooool00ol0003oooooooooo`3]ooooo`00=?ooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo0>cooooo000dooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0k?ooool003Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`3/ooooo`00=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05_ooooo1_l0
002;ooooo`00=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`29ooooo`00=?ooool2o`0004Cooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo000dooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08Oooooo000dooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Oooooo00000ooooooo0000o`00
0003o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo0_l0000iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Q_oo
ool00006oooooonHV9So8B4Qonk^k_ooooooA4A41oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool06_ooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Q_ooool000;ooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo0ol0
0013ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0QOooool000?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0Q?ooool000Cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05oooo
o`;o0000<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Cooooo0005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool2o`0001Cooooo
00?o0000ooooooooool0Poooool00006ooooool0003o^[ZjoooooonHV9So410@1?ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Xooooo`;o00005_ooool00ol0003oooooooooo`23ooooo`0000Ko
oooooiRHV?l@413o0000ob4Q8Oo<c<`4ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00_ooooo0_l0000Wooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0M_ooool2o`0000_ooooo000dooooo`;o0000AOooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool2o`0001[ooooo00?o
0000ooooooooool08Oooool5o`0004cooooo0ol0000=ooooo`00=?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07_ooool3o`0000Gooooo1Ol00015
ooooo`;o00004?ooool003Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool5o`0003oooooo00?o0000oooo
ooooool04?ooool003Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo0_l0000Mooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Aooooo`?o0000>oooool00ol0003oooooooooo`0Aooooo`00
=?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool2o`0001Wooooo0_l0000Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5Oooool3o`0003Oooooo00?o0000ooooooooool04_ooool003Cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04ooo
ool3o`0002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`;o00007ooo
ool5o`0000oooooo0_l0000Eooooo`00=?ooool2o`0004Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Hooooo`;o00004?ooool3o`0002Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Looooo`;o00006oooool2o`0000Gooooo0ol0000;ooooo`03o`000?oooooo
oooo01Gooooo000dooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Jooooo`?o00002?ooool5o`0002Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool3o`00
00Oooooo00?o0000ooooooooool05_ooool003Cooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01gooooo2?l0000^ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00co
oooo1?l00002ooooo`03o`000?oooooooooo01Oooooo000dooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo
0_l0000Jooooo`00=?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`00=?ooool2o`0004Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02kooooo000doooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02oooooo000dooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool003Cooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
<_ooool003Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<oooool003Cooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool0
03Cooooo0_l00018ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooooooo0ol0000g
ooooo`00=?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo0ol0000joooo
o`00=?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06oooooo00001_ooooooV9RH
oa0@4?l0003o<S8bolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06oooooo00001_oooooo410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo073ooooo0005oooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool3o`0004Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Kooooo0_l0001coooo
o`001?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05gooooo0_l00006ooooo`03
o`000?oooooooooo07?ooooo0003ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
Goooool2o`0000?ooooo00?o0000ooooooooool0M?ooool000Cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooo000007Oooooo00001_oooooo410@oiRHV?oo
oooo^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1fooooo`0000Ko
ooooojVYZOl@413o0000oa0@4?nYZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=cooooo000dooooo`;o0000
B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=cooooo000dooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Mooooo`00=?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0gOooool0
03Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0=gooooo000dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3Nooooo`00=?ooool2o`0004_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3Nooooo`00=?ooool00ol0003oooooooooo`1;ooooo`05o`000?ooooooooooooooool00000
hOooool003Cooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool0003Rooooo`00=?oo
ool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`000>;ooooo000dooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooool00000hoooool003Cooooo00?o0000ooooooooool0C?ooool2
o`000>?ooooo000dooooo`;o0000COooool00ol0003oooooooooo`3Rooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o
0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0318924, -44107.6, \
0.000760081, 2251.07}}]
}, Open  ]],

Cell["\<\
\tAfter a rapid increase, the kinetic energy begins to fluctuate \
about some equilibrium value. Evidently, the heating of the gas results in an \
arrest of the collapse.  The outward thermal pressure of the gas can balance \
the gravitational attraction, allowing a steady state to be achieved. This \
steady state can be thought of as a crude approximation to the nebulae from \
which stars, planets, or galaxies might form. Loss of kinetic energy though \
various mechanisms that are not included in our simulation allows the \
collapse to continue in real clouds, until a compact object forms such as a \
star,  planet, or black hole. These loss mechanisms include the formation of \
collisional shock waves, radiation,  and evaporation (where hot particles \
achieve escape velocity and leave the cloud, lowering the average kinetic \
energy per particle of the remainder).\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Stability of a Hot Gas to Gravitational Collapse", "Section",
  CellTags->{"i:57", "c:38"}],

Cell[TextData[{
  " If a uniform gas is sufficiently hot initially, gravitational collapse \
does not occur, because the gas pressure can balance the force of gravity. \
One can see this in the simulation (Cells ",
  ButtonBox["7.87",
    ButtonData:>"Cell 7.87",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["7.89",
    ButtonData:>"Cell 7.89",
    ButtonStyle->"Hyperlink"],
  ") by giving the particles large random initial velocities:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = 1; M = 10; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t\  = \ 0.0015;\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(r0\  = \ Table[{Random[], Random[]}, {1000}];\)\), "\n", 
    \(\(p0 = \ 
        Table[60 {Random[] -  .5, Random[] -  .5}, {1000}];\)\), "\n", 
    \(Timing[leapfrog[r0, p0, 60, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.87"],

Cell[BoxData[
    \({32.27999999999999`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 60, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.88"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 60}], 
        PlotJoined \[Rule] True, 
        PlotLabel \[Rule] \ "\<kinetic energy versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotRange \[Rule] {0, 400000}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.89"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 10.582 0 1.54508e-06 [
[.23545 -0.0125 -12 -9 ]
[.23545 -0.0125 12 0 ]
[.44709 -0.0125 -12 -9 ]
[.44709 -0.0125 12 0 ]
[.65873 -0.0125 -12 -9 ]
[.65873 -0.0125 12 0 ]
[.87037 -0.0125 -12 -9 ]
[.87037 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -36 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -36 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -36 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -36 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -36 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -36 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 0 m
.23545 .00625 L
s
[(0.02)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(0.04)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(0.06)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(0.08)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.07672 0 m
.07672 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.5 0 m
.5 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(50000)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(100000)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(150000)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(200000)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(250000)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(300000)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(350000)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(400000)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kinetic) show
111.000 13.000 moveto
(energy) show
153.000 13.000 moveto
(versus) show
195.000 13.000 moveto
(time) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .47793 m
.03968 .47783 L
.05556 .47781 L
.07143 .47788 L
.0873 .47802 L
.10317 .47816 L
.11905 .47828 L
.13492 .47847 L
.15079 .47871 L
.16667 .47899 L
.18254 .47927 L
.19841 .47956 L
.21429 .47983 L
.23016 .48007 L
.24603 .48025 L
.2619 .48029 L
.27778 .48019 L
.29365 .48002 L
.30952 .4798 L
.3254 .47954 L
.34127 .47926 L
.35714 .47893 L
.37302 .47866 L
.38889 .47862 L
.40476 .47887 L
.42063 .47939 L
.43651 .48016 L
.45238 .48105 L
.46825 .48185 L
.48413 .48249 L
.5 .48297 L
.51587 .48324 L
.53175 .48329 L
.54762 .48321 L
.56349 .48305 L
.57937 .4827 L
.59524 .48219 L
.61111 .48166 L
.62698 .48121 L
.64286 .48084 L
.65873 .48057 L
.6746 .48043 L
.69048 .48046 L
.70635 .48061 L
.72222 .48077 L
.7381 .48097 L
.75397 .48118 L
.76984 .48127 L
.78571 .48111 L
.80159 .4807 L
Mistroke
.81746 .48009 L
.83333 .47943 L
.84921 .47883 L
.86508 .47835 L
.88095 .47806 L
.89683 .47793 L
.9127 .47798 L
.92857 .47831 L
.94444 .47885 L
.96032 .4793 L
.97619 .47953 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Hoooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool5o`00027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`0Oooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`08_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02gooooo001Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So
8B4Q02gooooo001Sooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooo
oooo410@00Cooooo00?oV9RHob4Q8Oo^k^h08_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@oooooooooooooooooa0@4003ooooo`Go00008Oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool000008_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool00000;Oooool006?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP0Qooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo
00008_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80;Oooool006?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001_ooool0
0omgMgOoIVIVooooo`0Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00CogMgMoeEEEOoooooo00008_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`08_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05
olc<c?l0003o0000o`000?o<c<`0;Oooool006?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0Oooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l00000
8_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oeEEEOn7QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413o^[Zjoooooonj^[[o410@02gooooo001Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oo
ooooV9RHoa0@400Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?ok^k^odA4A?l000008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj
^[[o000002gooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Qooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool08Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04olc<
c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01OnYZJWo410@o`000?l@413oZJVY02gooooo003oooooofWooooo003ooooo
ofWooooo003oooooof3ooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`00oooooomPooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00?ooooooH?ooool00ol0003oooooooooo`06ooooo`00
;Oooooooo`0002So00002oooool00ol0003oooooooooo`06ooooo`00=?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0;Oooool00ol@413o0000o`000003o`0000Gooooo000dooooo`03o`000?oooooooooo
0?oooooo:Oooool00ol0003oooooooooo`06ooooo`00=?ooool00ol0003oooooooooo`3oooooobWo
oooo00?o0000ooooooooool01_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0
003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o
0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`00
0?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`002_ooool01Om4A4Co0000
o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool000gooooo00WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000>ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc;ooooo000=oooo
o`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`?o0000oooooolbooooo`002_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo<_ooool000[ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolb
ooooo`002_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc;ooooo000:ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0
003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`00
0?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooo
oooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003ooooooooo
o`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000
oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo0002ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool000Cooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0?oooooo<_ooool000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooolbooooo`001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`000_ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooooc?ooooo000doooo
o`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00
=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_oo
ool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Co
oooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo
000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000doooo
o`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00
=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool0
0ol0003oooooooooo`3ooooooc;ooooo0002ooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`06
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?o0000ooooooooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_ooool000;ooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooo
oc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolb
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oo
oooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<ooo
ool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooo
oc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo
000dooooo`03o`000?oooooooooo0?oooooo<_ooool00003ooooool0003o000000?o00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool00006oooooonHV9So8B4Q
onk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0?oooooo<_ooool000?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooolbooooo`001?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0oooooolbooooo`001Oooool01Ol0003ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolbooooo`0000Koooooo`000?nj^[[ooooo
oiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`00
00KooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooo
oc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooo
oooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oo
oooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooooooo
o`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooo
oc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolc
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo00000ooooooo0000o`000003o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo00001_ooooooV9RH
ob4Q8Oo^k^koooooodA4A0Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc;ooooo0002oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo<_ooool000?ooooo
00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo<_ooool0
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc;o
oooo00001_oooooo0000okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0oooooolbooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`4ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooooc?o
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo
<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3o
oooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;o
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcoooo
o`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo00001_ooooooV9RHoa0@4?l0003o<S8bolc<
c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo00001_oooooo
410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc;ooooo0005ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool3o`00
0?oooooo<_ooool000Cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo0?oooooo<_ooool000?ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo<_ooool000Cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo<_ooool00006ooooool@413o
V9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
<_ooool00006oooooonYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooooh7o
0000<ooooolQo`0000gooooo=ol0000Kooooo`00=?ooool00ol0003oooooooooo`1noooooc?o0000
8Oooool=o`0005;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooooooo
ool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`00
0?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooooooo
ool0oooooolbooooo`0000KooooooiRHV?l@413o0000oc8b<_o<c<`4ooooo`05odA4A?l0003o0000
oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolbooooo`0000Kooooooa0@4?nj^[[oooooogMgMolb<S87
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`001Oooool00ol0003oooooooooo`06
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?oZJVYoa0@4?ooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc;ooooo0003ooooo`03oa0@4?l0003o^[Zj00Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03okZj^_lQ8B7o
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`0000Kooooooa0@4?nH
V9SooooookZj^_l00004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_ooool00006
oooooonYZJWo410@o`000?l@413oZJVY1?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o0000oooooolcooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o
0000ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`00
0?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2
o`000?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0
003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool000?ooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc;ooooo00000ooooooo0000o`000003o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`3ooooooc;ooooo00001OooooooA4A4omgMgOoooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`000?oooooo<_ooool00005oooooooMgMgoEEEEooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00003ooooooc_ooooo0002ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100oooooolkooooo`000_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo
>oooool000?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3ooooooc_ooooo002l
ooooo`06ob4Q8Ol0003o0000odA4A?oMgMgooooo0ol000000ol@413oooooooooo`2Pooooo`00_ooo
ool00omgMgOo<S8booooo`02ooooo`03oa0@4?nj^[[ooooo0:7ooooo0030ooooo`06o`000?oooooo
oooooooooonHV9So<S8bX_ooool005oooooo0_l00002ooooo`03oa0@4?l0003o000000;ooooo1Ol0
0002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000om4A4Co
^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool5o`0000?ooooo00GoIVIVo`00
0?l0003oA4A4olc<c006ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000
o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000CoA4A4okZj^_oooooo410@1Ol00003
ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool00ooMgMgo0000okZj^P0;ooooo`03ob4Q
8Olb<S;ooooo00?ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00WoV9RHo`000?l0003oMgMgo`000?l@413ooooo
oa0@4?lb<S800_l000000ol@413oZJVYooooo`06ooooo`05oiRHV?l0003o0000odA4A?nj^[X00ooo
ool5o`000003ooooool0003o000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o
000000?oA4A4okZj^_ooool0AOooool0063ooooo00Go0000ooooooo^k^ko<S8bolc<c005ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool0
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4103ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40?ooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00?o
EEEEogMgMom4A4@02_ooool01?nHV9So<S8boa0@4?nj^[X3ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@0oooool00ol0003oooooooooo`04ooooo`06o`000?nYZJWooooooooooonj^[[o00000ooo
ool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Ko0000ojVYZOoooooooooookZj^_l00007oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00So0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@44Kooooo001Pooooo`04
o`000?nHV9So<S8bolc<c0Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00Ko
0000ooooooooooooooooonk^k_l00002ooooo`05omgMgOl@413oooooob4Q8OoMgMd02Oooool01?l@
413o^[ZjoiRHV?lb<S83ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
1Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05okZj
^_n7QhOoIVIVofIVI_l@41001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00001;ooooo`00H?ooool00ol0003o
410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool6o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00000oooool0
0ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01OmVIVKoQhN7
oooooonHV9SoEEEE00Sooooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00000oooool0
0ol0003oooooooooo`04ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h7ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000Go0000A_ooool0063ooooo00Co0000onk^k_mEEEGoQhN71_ooool00ol0003ooooooooo
o`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo00001_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7Qooo
ooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgM
g@04ooooo`0:oeEEEOmgMgOoooooonk^k_mEEEGo0000ooooooo^k^ko0000onk^kP;ooooo00?o0000
omgMgOooool01Oooool00oo^k^ko0000omgMg@02ooooo`0:oiRHV?lb<S;ooooooooooomEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?nj^[[oooooonk^k_mg
MgOo00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00ko0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<TKooooo001Poooo
o`05o`000?ooooooA4A4o`000?l@41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003o
MgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go0000
1?ooool00ol@413o0000o`000004ooooo`06onk^k_mVIVKo0000o`000?m4A4Co00001_ooool01_o^
k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@o`000?mgMgL00_l000001OnHV9Sooooooooo
ooo^k^koEEEE00;o000000CoA4A4onk^k_oooooooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42oooo
o`06onk^k_mEEEGo0000ob4Q8OnYZJWo00000_l@4102o`000004ooooool0003o0000oa0@40Kooooo
00?o410@o`000?l000000_ooool3o`000003ooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo
oooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_oo
ool01?l@413o0000ooooooooool2o`0000;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00005oooo
o`03oa0@4?l0003o000000?o00001?ooool00ol@413o0000o`000003ooooo`0;oa0@4?l0003o8B4Q
o`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`15ooooo`00
H?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
H?ooool0063ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Kooooo001Oooooo`;o00002Oooool00ol@413oooooooooo`0Mooooo`03oa0@4?oooooo
oooo08;ooooo00?o410@ooooooooool0E_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0167958, -39614.6, \
0.000401908, 2752.6}}]
}, Open  ]],

Cell[TextData[{
  "The gas no longer collapses.  To understand this theoretically, consider \
the linearized version of the Navier-Stokes equations ",
  ButtonBox["(7.2.35)",
    ButtonData:>{"Chapter7.nb", "(7.2.35)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.2.37)",
    ButtonData:>{"Chapter7.nb", "(7.2.37)"},
    ButtonStyle->"Hyperlink"],
  "  for the gas, including the effect of gravity. The perturbed mass density \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Rho]\)]],
  ", velocity ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ", and gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Phi]\)]],
  " obey"
}], "Text",
  CellTags->"i:83"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\[Delta]\[Rho]\/\[PartialD]t\), "=", " ", 
          RowBox[{\(-\ \[Rho]\_o\), 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["u",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}]}]}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[Rho]\_o\), 
              FractionBox[
                RowBox[{"\[PartialD]", 
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["u",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]]}], \(\[PartialD]t\)]}], "=", 
            " ", \(\(-\ \[Del]\[Delta]p\) - \(\[Rho]\_o\) \
\[Del]\[Delta]\[Phi]\)}], ","}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\  = \ \[Gamma] \( p\_o\/\[Rho]\_o\) \
\[Delta]\[Rho]\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Del]\^2 \[Delta]\[Phi] = 
        4  \[Pi]\ G\ \[Delta]\[Rho]\)\(,\)\)\)]]
}], "NE3",
  CellTags->"(7.3.13)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o\)]],
  " are the equilibrium density and pressure of the uniform gas, we have \
neglected viscosity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " (our system is assumed to be dissipationless), and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is the ratio of specific heats. If one Fourier-transforms these equations \
in space and time, one finds the following dispersion relation for sound \
waves in the gas (see the exercises):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \(c\^\(\(2\)\(\ \)\)\) k\^2 - 
          4\ \[Pi]\ G\ \[Rho]\_o\)]],
  ","
}], "NE3",
  CellTags->{"i:81", "(7.3.14)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Gamma]\ p\_o/\[Rho]\_o\)\)]],
  " is the speed of sound.  A similar dispersion relation can also be derived \
directly from the collisionless Boltzmann equation, Eq. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  (see the exercises). "
}], "Text"],

Cell[TextData[{
  "\tFor wavenumbers that are sufficiently small, the square of the wave \
frequency is negative; that is, the frequency is imaginary. There are two \
imaginary roots to Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>{"Chapter7.nb", "(7.3.14)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \(\[PlusMinus]\[ImaginaryI]\)\ \@\(4\ \
\[Pi]\ G\ \[Rho]\_o - \(c\^\(\(2\)\(\ \)\)\) k\^2\)\)]],
  ".  Waves of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\
\)]],
  " will then either grow or decay; but over time the growing wave will \
dominate. As a result, the equilibrium is unstable to waves with sufficiently \
small wavenumbers: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`k\  < \ \@\(4  \[Pi]\ G\ \[Rho]\_o/c\^2\)\)]],
  " for instability."
}], "NE3",
  CellTags->"(7.3.15)"],

Cell[TextData[{
  "On the other hand, in our system",
  ",",
  " the minimum wavenumber that fits into our box is ",
  Cell[BoxData[
      \(TraditionalForm\`k\_min = \ 2\ \[Pi]/L\)]],
  ". Therefore, if ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2\ \[Pi]/
            L\)\(\ \)\(>\)\(\@\(4  \[Pi]\ G\ \[Rho]\_o/c\^2\)\)\(\ \)\)\)]],
  ", the system is stable to all waves that can fit into the box.  Written as \
a condition on the sound speed, this becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c\^2 \[GreaterEqual] \ \ \(G\ \[Rho]\_o\ \
L\^2\)\/\(\(\[Pi]\)\(\ \ \)\)\)]],
  " for stability."
}], "NE3",
  CellTags->"(7.3.16)"],

Cell[TextData[{
  "Roughly the same stability criterion holds for any cloud of size ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and mean density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " in free space. Note that the ",
  "right-hand",
  " side is on the order of the escape velocity at the surface of such a \
system. The cloud will not collapse if the sound speed is on the order of the \
escape velocity. Since the sound speed  ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is on the order of the mean thermal speed of gas particles, this implies \
that a stable cloud will be diffuse, with particle speeds on the order of or \
even above the escape velocity.  This sort of final state is what we observed \
in our first simulation. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotation", "Section",
  CellTags->"c:39"],

Cell[TextData[{
  "\tNaturally occurring gas clouds have finite angular momentum, and as they \
collapse they rotate. The smaller the cloud's radius becomes, the faster the \
rotation. This can be understood by considering the angular momentum ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(L\_z\), " ", "=", " ", 
          RowBox[{
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"], "\[CenterDot]", 
            RowBox[{\(\[Sum]\+i\), 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], " ", "\[Times]", 
                SubscriptBox[
                  StyleBox["p",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}]}]}]}], TraditionalForm]]],
  ". For a system rotating with uniform angular speed ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", Cell[""]}], TraditionalForm]]],
  " about the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis, we have ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "i"], "=", 
          RowBox[{"m", " ", "\[Omega]", " ", 
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"], "\[Times]", 
            StyleBox[\(r\_i\),
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and this implies ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z = \ I\ \[Omega]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`I = \[Sum]\+i 
            m\ r\_\(\(\[UpTee]\)\(\ \)\(i\)\)\%2\)]],
  " is the moment of inertia of the cloud, and  where ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{\(r\_\(\(\[UpTee]\)\(\ \)\(i\)\)\), " ", "=", " ", 
            RowBox[{"|", 
              RowBox[{
                OverscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"], "\[Times]", 
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["i",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "|"}]}]}], TraditionalForm]]],
  ". As the cloud collapses, ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " decreases and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " must increase to compensate so that ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z\)]],
  " is conserved.  "
}], "Text"],

Cell[TextData[{
  "\tIf the cloud rotates sufficiently rapidly, it will not collapse, because \
the centrifugal force balances the gravitational attraction. For a uniform \
cylindrical cloud of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " per unit length, an equilibrium will exist if"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \@\(2\ G\ \(\(M/R\^2\)\(\ \)\)\)\)]],
  "."
}], "NE3",
  CellTags->"(7.3.17)"],

Cell[TextData[{
  "In Cells ",
  ButtonBox["7.90",
    ButtonData:>"Cell 7.90",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["7.92",
    ButtonData:>"Cell 7.92",
    ButtonStyle->"Hyperlink"],
  ", we simulate a cloud that is rotating at 70% of this rate.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = 1/2; M = 40; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t = 0.0012;\n\), "\[IndentingNewLine]", 
    \(\(Clear[r, p];\)\), "\n", 
    \(rad\  = \ 0.1; 
    r0 = Table[rp = Sqrt[Random[]]; 
        t = 2  Pi\ Random[]; { .5,  .5} + rad\ rp {Sin[t], Cos[t]}, {n, 1, 
          1000}];\n\), "\[IndentingNewLine]", 
    \(\(\[Omega]\  = \  .7\ Sqrt[2\ G\ \ Npart\ m/rad^2];\)\), "\n", 
    \(\(Npart = Length[r0];\)\), "\n", 
    \(\(vval[x_]\  := \ \[Omega] {\(-x[\([2]\)]\), x[\([1]\)]};\)\), "\n", 
    \(\(p0 = m\ Map[vval, r0];\)\), "\n", 
    \(px\  := \ Sum[\(p0[\([i]\)]\)[\([1]\)], {i, 1, Npart}]\ \), "\n", 
    \(py := \ Sum[\(p0[\([i]\)]\)[\([2]\)], {i, 1, Npart}]\ \), "\n", 
    \(\(mom\  = {px, py}/Npart;\)\), "\n", 
    \(\(\(p0\  = \ 
        Table[p0[\([i]\)]\  - \ mom, {i, 1, Npart}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Timing[leapfrog[r0, p0, 50, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.90"],

Cell[BoxData[
    \({68.76`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 50, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.91"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 50}], 
        PlotJoined \[Rule] True, 
        PlotLabel \[Rule] \ "\<kinetic energy versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.92"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 15.873 -0.268776 5.2679e-06 [
[.18254 .0348 -12 -9 ]
[.18254 .0348 12 0 ]
[.34127 .0348 -12 -9 ]
[.34127 .0348 12 0 ]
[.5 .0348 -12 -9 ]
[.5 .0348 12 0 ]
[.65873 .0348 -12 -9 ]
[.65873 .0348 12 0 ]
[.81746 .0348 -12 -9 ]
[.81746 .0348 12 0 ]
[.97619 .0348 -12 -9 ]
[.97619 .0348 12 0 ]
[1.025 .0473 0 -6 ]
[1.025 .0473 10 6 ]
[.01131 .15266 -30 -4.5 ]
[.01131 .15266 0 4.5 ]
[.01131 .25801 -36 -4.5 ]
[.01131 .25801 0 4.5 ]
[.01131 .36337 -36 -4.5 ]
[.01131 .36337 0 4.5 ]
[.01131 .46873 -36 -4.5 ]
[.01131 .46873 0 4.5 ]
[.01131 .57409 -36 -4.5 ]
[.01131 .57409 0 4.5 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .0473 m
.18254 .05355 L
s
[(0.01)] .18254 .0348 0 1 Mshowa
.34127 .0473 m
.34127 .05355 L
s
[(0.02)] .34127 .0348 0 1 Mshowa
.5 .0473 m
.5 .05355 L
s
[(0.03)] .5 .0348 0 1 Mshowa
.65873 .0473 m
.65873 .05355 L
s
[(0.04)] .65873 .0348 0 1 Mshowa
.81746 .0473 m
.81746 .05355 L
s
[(0.05)] .81746 .0348 0 1 Mshowa
.97619 .0473 m
.97619 .05355 L
s
[(0.06)] .97619 .0348 0 1 Mshowa
.125 Mabswid
.05556 .0473 m
.05556 .05105 L
s
.0873 .0473 m
.0873 .05105 L
s
.11905 .0473 m
.11905 .05105 L
s
.15079 .0473 m
.15079 .05105 L
s
.21429 .0473 m
.21429 .05105 L
s
.24603 .0473 m
.24603 .05105 L
s
.27778 .0473 m
.27778 .05105 L
s
.30952 .0473 m
.30952 .05105 L
s
.37302 .0473 m
.37302 .05105 L
s
.40476 .0473 m
.40476 .05105 L
s
.43651 .0473 m
.43651 .05105 L
s
.46825 .0473 m
.46825 .05105 L
s
.53175 .0473 m
.53175 .05105 L
s
.56349 .0473 m
.56349 .05105 L
s
.59524 .0473 m
.59524 .05105 L
s
.62698 .0473 m
.62698 .05105 L
s
.69048 .0473 m
.69048 .05105 L
s
.72222 .0473 m
.72222 .05105 L
s
.75397 .0473 m
.75397 .05105 L
s
.78571 .0473 m
.78571 .05105 L
s
.84921 .0473 m
.84921 .05105 L
s
.88095 .0473 m
.88095 .05105 L
s
.9127 .0473 m
.9127 .05105 L
s
.94444 .0473 m
.94444 .05105 L
s
.25 Mabswid
0 .0473 m
1 .0473 L
s
gsave
1.025 .0473 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .15266 m
.03006 .15266 L
s
[(80000)] .01131 .15266 1 0 Mshowa
.02381 .25801 m
.03006 .25801 L
s
[(100000)] .01131 .25801 1 0 Mshowa
.02381 .36337 m
.03006 .36337 L
s
[(120000)] .01131 .36337 1 0 Mshowa
.02381 .46873 m
.03006 .46873 L
s
[(140000)] .01131 .46873 1 0 Mshowa
.02381 .57409 m
.03006 .57409 L
s
[(160000)] .01131 .57409 1 0 Mshowa
.125 Mabswid
.02381 .07364 m
.02756 .07364 L
s
.02381 .09998 m
.02756 .09998 L
s
.02381 .12632 m
.02756 .12632 L
s
.02381 .179 m
.02756 .179 L
s
.02381 .20534 m
.02756 .20534 L
s
.02381 .23167 m
.02756 .23167 L
s
.02381 .28435 m
.02756 .28435 L
s
.02381 .31069 m
.02756 .31069 L
s
.02381 .33703 m
.02756 .33703 L
s
.02381 .38971 m
.02756 .38971 L
s
.02381 .41605 m
.02756 .41605 L
s
.02381 .44239 m
.02756 .44239 L
s
.02381 .49507 m
.02756 .49507 L
s
.02381 .52141 m
.02756 .52141 L
s
.02381 .54775 m
.02756 .54775 L
s
.02381 .02096 m
.02756 .02096 L
s
.02381 .60043 m
.02756 .60043 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kinetic) show
111.000 13.000 moveto
(energy) show
153.000 13.000 moveto
(versus) show
195.000 13.000 moveto
(time) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05146 m
.04286 .14674 L
.0619 .34345 L
.08095 .55589 L
.1 .60332 L
.11905 .44224 L
.1381 .23021 L
.15714 .0821 L
.17619 .01472 L
.19524 .02415 L
.21429 .10778 L
.23333 .25784 L
.25238 .42939 L
.27143 .52827 L
.29048 .48481 L
.30952 .34011 L
.32857 .19525 L
.34762 .10723 L
.36667 .08227 L
.38571 .10981 L
.40476 .1748 L
.42381 .2602 L
.44286 .34489 L
.4619 .40302 L
.48095 .40767 L
.5 .35323 L
.51905 .27161 L
.5381 .203 L
.55714 .16601 L
.57619 .15904 L
.59524 .1766 L
.61429 .21288 L
.63333 .25906 L
.65238 .30363 L
.67143 .33429 L
.69048 .34116 L
.70952 .32255 L
.72857 .28628 L
.74762 .24765 L
.76667 .22043 L
.78571 .20936 L
.80476 .21241 L
.82381 .22527 L
.84286 .24189 L
.8619 .25974 L
.88095 .27886 L
.9 .29352 L
.91905 .29713 L
.9381 .29004 L
.95714 .27729 L
Mistroke
.97619 .26268 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo01co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Cooooo1?l000000ol@413oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00004_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnH
V9So410@o`000?lb<S;oc<c<017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`0@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l@413oc<c<00ko
oooo000dooooo`03o`000?oooooooooo01cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A401;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P0A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool04?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000dooooo`03o`000?oooooooooo01cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00Cooooo00?oV9RHob4Q8Oo^k^h04oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool5o`0001;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`0?ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go0000ooooooooooooooooo`00000>ooooo`00=?ooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool000002Oooool3o`0000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?oV9RHob4Q8Oo^k^h04_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03ojVYZOl@413ooooo013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01?m4A4CogMgMooooool0
000Cooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?oMgMgoc8b<_ooool04?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?nHV9SooooooiRHV?lQ8B403_ooool003Cooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000ooooool0003o0000
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`0Aoooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
410@o`000?nj^[X04Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04omgMgOmEEEGoooooo`0001?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003oEEEEo`000?l@413oc<c<00kooooo000dooooo`;o00007Oooool01Ol@413ooooooooooooooooo
410@00Wooooo00Oo0000ooooool@413oooooo`000?oooooo410@00Kooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4007oooo
o`03o`000?oooooooooo013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00onj^[[o8B4Qooooo`0@ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l000004oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooo
oooo01?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00omEEEGoQhN7ooooo`0@ooooo`00=?ooool00ol0003oooooooooo`0Looooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool02?l0003ooooooooooomgMgOoV9RHooooool0003oMgMg1_ooool0
0ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oiRHV?oooooo^[Zjo`00
000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Co
oooo00?ok^k^odA4A?l000004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ooMgMgo410@oiRHV00@ooooo`00=?oo
ool00ol0003oooooooooo`0Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool01Ol0003ooooo
ooooooo^k^ko<S8b00;o000000?ok^k^ooooooooool00_ooool00omEEEGoIVIVo`00000Cooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Aooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool04_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co
00004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`04olc<c?m4A4Co0000oa0@40kooooo000dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3oooooo`00=?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0o_ooool003Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?Gooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`00=?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0mOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo000dooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3eooooo`03
o`000?oooooooooo00Kooooo000]oooooooo0000:?l0000;ooooo`03o`000?oooooooooo00Kooooo
000dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Ko
oooo000dooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`03
oa0@4?l0003o000000?o00001Oooool003Cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01_ooool003Cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0??ooooo00?o
0000ooooooooool01_ooool003Cooooo0_l0000Wooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
o?ooool003Cooooo0_l0000Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0nooo
ool003Cooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0c?ooool003Cooooo00?o0000ooooool000009?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0c?ooool003Co
oooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooool00000cOooool003Cooooo00?o0000ooooool000009?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00003<ooooo`00
=?ooool00ol0003oooooo`00000Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<[ooooo000dooooo`03o`000?oo
oooo000002?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0bOooool003Cooooo0_l000000ooooooo0000ooooo`0Q
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0<Wooooo000dooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0b?ooool003Cooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`37
ooooo`00=?ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<Oooooo000doooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0aoooool003Cooooo00Co0000oooo
oooooooo00008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`36ooooo`00=?ooool01Ol0003ooooooooooooooooo
0000023ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0a_ooool003Cooooo0_l00002ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0a_ooool003Cooooo00Go0000ooooooooooooooooo`00000Poooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0<Gooooo000dooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`35ooooo`00=?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0aOooool003Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0<Cooooo000dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`34ooooo`002Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`34ooooo`002Oooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`34ooooo`002Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0<?ooooo0009ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S800oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0<?o
oooo0009ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002@ooooo`002Oooool01Ol@413o^[Zjoooo
oonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0/ooooo`?o00000oooool00ol0003oooooooooo`2=ooooo`002Oooool01Ol0003o^[Zjoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Z
ooooo`;o00001oooool00ol0003oooooooooo`2<ooooo`002Oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Roooool003Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2:ooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08Wooooo000dooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`29ooooo`00=?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo000dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0R?ooool003Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`27ooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Oooooo
000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Q_ooool003Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`26ooooo`00=?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo08Kooooo000dooooo`;o00001Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`25ooooo`00
=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo1Ol0001@ooooo`00=?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo0_l00005ooooo`?o0000COoo
ool003Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool2
o`0004_ooooo000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0<ooooo`;o0000BOooool003Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool003Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0AOooool003Cooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`14ooooo`00=?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13
ooooo`00=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`12ooooo`00=?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`11ooooo`00
=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`10ooooo`000_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0oooooo`001?ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0?_ooool000Cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03gooooo0004ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03cooooo0004ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool08Oooool2o`0001oooooo0_l0000Kooooo`001?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`001?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`000_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Mooooo`00=?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo000doooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yoooo
o`;o00004oooool2o`00027ooooo000dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo0_l0000Sooooo`00
=?ooool2o`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo0_l0000Uooooo`00=?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o00009ooo
ool003Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo033ooooo1?l00003ooooo`?o0000:Oooool003Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo0ol0000/ooooo`00=?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0I?ooool003Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Cooooo
000dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Uooooo`00=?ooool2o`0000Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1V
ooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0I_ooool003Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06Oooooo000dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1Wooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0J?ooool003Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Wooooo000dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Zooooo`00=?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0^ooooo`?o00001Oooool00ol0003oooooooooo`1[ooooo`00=?ooool2o`0000Wooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo
0ol000000ooooooo0000ooooo`1]ooooo`00=?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo06gooooo000dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:Cooooo000dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:Cooooo000dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0:Gooooo0002ooooo`Co000000?o410@ooooooooool0
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2Uooooo`001?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0YOooool000Cooooo00?o0000ooooooooool00oooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`2Vooooo`001?ooool00ol0003oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o00002Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Y_ooool000Cooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`2Vooooo`001?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo0:Oooooo0004ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`2Wooooo`000_ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Yoooool003Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Z?ooool003Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Z?ooool003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ZOooool003Cooooo0_l0
000:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2Yooooo`00=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Yooooo`00=?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zoooo
o`00=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2Zooooo`00=?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02cooooo1?l00003ooooo`03o`000?oooooooooo0:[ooooo000dooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0<?ooool3o`000:gooooo000dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0h?ooool003Cooooo0_l0000;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0>3ooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0h?ooool003Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`3Pooooo`00=?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0>3ooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0hOooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Qoooo
o`00=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0>7ooooo000dooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0hOooool003Cooooo0_l0000<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0>7ooooo000dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0hOooool0
03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Qooooo`00=?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0>;ooooo000dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0h_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o000000Wo
410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>;ooooo0004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3R
ooooo`001?ooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3Rooooo`001?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3Rooooo`001?ooool00ol0003oooooooooo`02ooooo`04omgMgOmE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0h_ooool000Cooooo00?o0000
ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0>?ooooo0004ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3Sooooo`000_ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0hoooool003Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3Sooooo`00=?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>?ooooo000dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
i?ooool003Cooooo0_l0000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>Cooooo000dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0i?ooool003Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3Uooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo00000>Oooooo000dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`04
o`000?ooooooooooo`000>Sooooo000dooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`000>Sooooo000dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooo00000>Wooooo000dooooo`;o00003_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooool00000jOooool003Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo0_l0003Yooooo`00=?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`3Xooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00=?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolJooooo`00=?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolJooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolJooooo`00=?ooool2o`0000oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000d
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
oooooa[ooooo0002ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o410@olc<c0?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooa_ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolKooooo`001?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo6oooool000Cooooo00?o0000oooooooo
ool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00004?ooool01Ol0003ooooooooooooooooo0000
0?oooooo7Oooool000Cooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00003ooooooagooooo0004ooooo`03
o`000?oooooooooo00;ooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool04Oooool01?l0003ooooo
ooooool0003ooooooagooooo0004ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool04Oooool01?l0003oooooooooool0003ooooooagooooo0002ooooo`03oeEEEOmV
IVKo000000Gooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool04Oooool01?l0003ooooooooo
ool0003ooooooagooooo000dooooo`03o`000?oooooooooo01;ooooo0_l0003ooooooakooooo000d
ooooo`03o`000?oooooooooo01;ooooo0_l0003ooooooakooooo000dooooo`03o`000?oooooooooo
01;ooooo0_l0003ooooooakooooo000dooooo`;o00005?ooool00ol0003oooooooooo`3ooooooaco
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00_?ooool01_lQ8B7o0000o`000?m4A4CogMgM
ooooo`?o000000?o410@ooooooooool0X?ooool00;oooooo00?oMgMgoc8b<_ooool00_ooool00ol@
413o^[Zjooooo`2Qooooo`00`?ooool01_l0003oooooooooooooooooV9RHoc8b<Z;ooooo001Ooooo
o`;o00000_ooool00ol@413o0000o`000002ooooo`Go00000_ooool01?l@413o0000o`000?ooool2
o`000004oa0@4?ooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00?ooooo1Ol00003ooooo`05ofIVI_l0003o0000odA4A?o<c<`01_ooool01_o^k^ko
EEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^
k_mEEED2o`000004odA4A?nj^[[ooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l@413oc<c<
o`0000?ooooo00?ogMgMo`000?nj^[X02oooool00olQ8B7o<S8booooo`03ooooo`08onk^k_mEEEGo
0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3
ooooo`09oiRHV?l0003o0000ogMgMol0003o410@ooooool@413o<S8b00;o000000?o410@ojVYZOoo
ool01_ooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo1Ol000000ooooooo0000o`000002oooo
o`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo04Gooooo001P
ooooo`05o`000?ooooook^k^oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj
^_o^k^koMgMgoa0@4005ooooo`03o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooooooooohN7
Qol@4106ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo
000000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo
00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`03oeEEEOmgMgOoA4A400[ooooo00CoV9RHoc8b
<_l@413o^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool0
1?ooool01_l0003oZJVYoooooooooooo^[Zjo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`06o`000?nYZJWooooooooooonj^[[o00001oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEE
ogMgMoooooook^k^ogMgMol@4116ooooo`00H?ooool01?l0003oV9RHoc8b<_o<c<`6ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_oo
ool01OoMgMgo410@oooooolQ8B7ogMgM00Wooooo00Co410@okZj^_nHV9So<S8b0oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4003oooo
o`05o`000?ooooooooooooooool000000oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool00000Boooool0063ooooo00?o0000oa0@4?nHV9P01oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo1_l00003ooooo`05o`00
0?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooooooooook^k^o`0000;ooooo00GoIVIVohN7QoooooooV9RHoeEEE@08ooooo`06oiRHV?lb
<S;oooooooooool@413o^[Zj0_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0004Kooooo001Pooooo`04
o`000?o^k^koEEEEohN7Q`Kooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo
000000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01_mVIVKoMgMgooooooooooooQhN7o`0000Kooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02_mEEEGoMgMgooooooo^k^ko
EEEEo`000?ooooook^k^o`000?o^k^h2ooooo`03o`000?oMgMgooooo00Gooooo00?ok^k^o`000?oM
gMd00_ooool02_nHV9So<S8booooooooooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`00
0?lb<S;ogMgM00Cooooo00Ko0000okZj^_ooooook^k^ogMgMol00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S96ooooo`00H?ooool01Ol0003oooooodA4A?l0003o410@00?o
oooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooonk^
k_mEEED00_l000001?m4A4Cok^k^ooooool@4105o`0000Cooooo00?o410@o`000?l000001?ooool0
1_o^k^koIVIVo`000?l0003oA4A4o`0000Kooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2oooo
o`03oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000004odA4A?o^k^ko
ooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEEo`000?lQ8B7oZJVYo`00
00;o410@0_l000001?oooooo0000o`000?l@4106ooooo`03oa0@4?l0003o000000;ooooo0ol00000
0oooooook^k^oeEEE@02o`000004odA4A?o^k^koooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q
0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Co410@o`000?oooooooooo0_l00002
ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Oooool00ol@413o0000o`000003o`0000Cooooo
00?o410@o`000?l000000oooool02ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^
k^koEEEE00;o000000?oA4A4onk^k_ooool0AOooool0063ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo063ooooo001Pooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000Wo
oooo00?o410@ooooooooool07Oooool00ol@413oooooooooo`22ooooo`03oa0@4?oooooooooo05Ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0111972, 43891.9, \
0.000267939, 807.341}}]
}, Open  ]],

Cell["\<\
Collapse still occurs to some extent, but is moderated by the \
cloud's rotation. The final state is considerably less dense at the center \
than what one would obtain from the same initial condition without rotation \
(try it). \
\>", "Text"],

Cell[TextData[{
  "\tNote, also, the formation of spiral arms during the evolution. Spiral \
arms can be observed in many galaxies (see Fig. ",
  ButtonBox["7.9",
    ButtonData:>"Fig. 7.9",
    ButtonStyle->"Hyperlink"],
  "). These spiral structures can be understood from conservation of angular \
momentum. During the collapse, filaments of high density are thrown out from \
the core. As these filaments move to larger radius, conservation of angular \
momentum implies that they must slow their rotation. As result, the filaments \
are wound around the core, producing the spiral arms. (The formation of \
spiral arms is still a subject of some debate, and may be influenced by many \
effects beyond the scope of this simple explanation.)"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 7.3", "Subsubtitle",
  CellTags->"c:40"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Using the linearized Navier-Stokes equations ",
  ButtonBox["(7.3.13)",
    ButtonData:>{"Chapter7.nb", "(7.3.13)"},
    ButtonStyle->"Hyperlink"],
  " , derive the dispersion relation for sound waves in a self-gravitating \
gas, Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>{"Chapter7.nb", "(7.3.14)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  "  Solve Poisson's equation for a uniform cylindrical cloud of density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " to find the gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r)\)]],
  "  both inside and outside the cloud. Use this result to prove Eq. ",
  ButtonBox["(7.3.17)",
    ButtonData:>{"Chapter7.nb", "(7.3.17)"},
    ButtonStyle->"Hyperlink"],
  "  for the equilibrium of a rotating cylindrical cloud. As a test of the \
FFT code, simulate this uniform cloud with 1000 particles, radius ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R\)\(\ \)\(=\)\(\ \)\(0.25\)\(\ \)\)\)]],
  "(taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  "), and plot the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " obtained from the FFT vs. radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " from the cloud center, along with the analytic result, for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 0.5\)]],
  ". Discuss reasons for any deviations from the analytic result that you \
observe."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)(a)",
    FontWeight->"Bold"],
  "  The Jeans instability can also be understood from the linearized \
versions of the Poisson-Boltzmann equations ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  " . If we assume that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x, p\_x, \(p\_y\) t)\), "=", 
          RowBox[{\(\(f\_o\)(p\_x, p\_y)\), " ", "+", " ", 
            RowBox[{"\[Delta]", 
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["f",
                      FontSlant->"Italic"], "~"],
                  FontSlant->"Italic"], "(", \(p\_x, p\_y\), ")"}], 
              " ", \(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\  - \ \
\[ImaginaryI]\ \[Omega]\ t\)\)}]}]}], TraditionalForm]]],
  ", then show that Eqs. ",
  ButtonBox["(7.1.31)",
    ButtonData:>{"Chapter7.nb", "(7.1.31)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.32)",
    ButtonData:>{"Chapter7.nb", "(7.1.32)"},
    ButtonStyle->"Hyperlink"],
  "  become"
}], "Text",
  CellTags->"i:82"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{\(\(-\[ImaginaryI]\)\ \[Omega]\), " ", "+", " ", 
                  RowBox[{"\[ImaginaryI]", " ", "k", " ", 
                    StyleBox[
                      FractionBox[
                        StyleBox[
                          SubscriptBox[
                            StyleBox["p",
                              FontSlant->"Italic"], "x"],
                          FontSlant->"Plain"], "m"],
                      FontSlant->"Plain"]}]}], ")"}], "\[Delta]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["f",
                    FontSlant->"Italic"], "~"],
                FontSlant->"Italic"]}], "-", 
            RowBox[{"m", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["\[Phi]",
                    FontSlant->"Plain"], "~"],
                
                FontSlant->
                  "Italic"], \(\[PartialD]f\_o\/\[PartialD]p\_x\)}]}], "=", 
          "0"}], TraditionalForm]]],
  ", \n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Delta] \( \[Phi]\&~\)\), "=", 
          RowBox[{\(-\(\(4  \[Pi]\ G\ m\)\/k\^2\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{"\[Delta]", 
                StyleBox[
                  OverscriptBox[
                    StyleBox["f",
                      FontSlant->"Italic"], "~"],
                  FontSlant->"Italic"], \(\[DifferentialD]\^2 p\)}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Delta]", 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["\[Phi]",
                  FontSlant->"Plain"], "~"],
              FontSlant->"Italic"], "(", \(k, \[Omega]\), ")"}]}], 
        TraditionalForm]]],
  " is the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Phi]\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that Eqs. ",
  ButtonBox["(7.3.18)",
    ButtonData:>{"Chapter7.nb", "(7.3.18)"},
    ButtonStyle->"Hyperlink"],
  "  lead to the following dispersion relation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\  + \ \(\(4  \[Pi]\ G\ m\^3\)\/k\^2\) \
\(\[Integral]\(\(\[PartialD]f\_o/\[PartialD]p\_x\)\/\(p\_x - 
                      m\ \[Omega]/k\)\) \[DifferentialD]\^2 p\) = 0\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " We previously simulated a case where the equilibrium velocity \
distribution is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_o\)(p\_x, p\_y) = \ 
        N\/\((m\ V\ L)\)\^2\ \ for | 
          p\_x | \(\(<\)\(\ \)\(m\ V\ \ and\)\)\  | 
          p\_y | \(\(<\)\(m\ V\)\)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          " ",
          Cell[BoxData[
              \(TraditionalForm\`f\_o = 0\)]],
          " "
        }]], TraditionalForm]]],
  "otherwise.  Show that for this velocity distribution the dispersion \
relation works out to be"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ 
        V\^2\ k\^2 - \ 4\ \[Pi]\ G\ \[Rho]\_o\)]],
  ", "
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o = \ m\ N/L\^2\)]],
  " is the average mass density. What is the minimum value of ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`V\_min\)]],
  ", that allows a stable distribution in our simulation? For the simulation \
run in the above examples,  with ",
  Cell[BoxData[
      \(TraditionalForm\`V = 30\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  ", should the simulation be stable or unstable? "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Repeat the simulation taking ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 0.8\ V\_min\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 1.2\ V\_min\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)(a)",
    FontWeight->"Bold"],
  " Simplify the code so that only motion in one dimension is considered,  \
where ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x, p, t)\)]],
  ". (This requires determination of the correct equivalent of  area \
weighting for a one-dimensional grid.) Test the code by running cases with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(=\)\(1000\)\(\ \)\)\)]],
  "particles distributed randomly on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L = \(m = \(G = 1\)\)\)]],
  ", and\n (i) ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 0.8\ V\_min\)]],
  " (unstable) \n ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((ii)\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`V = 1.2\ V\_min\)]],
  " (stable). \nMake animations of the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t)\)]],
  ", evaluated from your position data. Check energy and momentum \
conservation. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In equilibrium, we expect that the distribution function will be a \
function only of the energy: "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`f = f(p\^2/2  m\  + \ m\ \[Phi])\)]]], "NE3",
  CellTags->"(7.3.19)"],

Cell[TextData[{
  "(in a frame where the center of mass is stationary). This is the same \
equilibrium distribution as we studied for the case of particles in a given \
external field; see Eq. ",
  ButtonBox["(7.1.25)",
    ButtonData:>{"Chapter7.nb", "(7.1.25)"},
    ButtonStyle->"Hyperlink"],
  " . However, now the problem is much more difficult, because the potential \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Phi]\)\)\)]],
  " is determined in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " itself. Nevertheless, we can test whether the final state observed from \
the evolution of an unstable initial condition satisfies this result. To do \
so, make a 2-D histogram in phase space ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " of the end result of the simulation in Exercise (4)(a)(i) using the ",
  StyleBox["BinCounts ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, available in the ",
  StyleBox["Statistics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " add-on package.  The syntax is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"BinCounts", "[", 
          
          RowBox[{\({{x\_1, p\_1}, {x\_2, p\_2}, \(\(...\)\(.\)\), {x\_N, 
                p\_N}}\), ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", "L", ",", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{\(-P\), ",", "P", ",", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["p",
                      FontSlant->"Italic"]}]]}], "}"}]}], "]"}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and \[CapitalDelta]",
  Cell[BoxData[
      StyleBox["p",
        FontSlant->"Italic"]]],
  " are the sizes of the bins in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " respectively, and where ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " is a maximum momentum, chosen from your data to capture all (or at least  \
most) of the distribution function. The result  is a list of the number of \
points in each bin. This number is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_\(i\ j\)\), "\[Congruent]", 
          RowBox[{\(f(x\_i, \ p\_j)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["p",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_i, p\_j)\)\)]],
  " is the center of a bin.  Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(\(L/10\)\(\ \)\)}], 
        TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], " ", "=", " ", \(P/10\)}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAccording to Eq. ",
  ButtonBox["(7.3.19)",
    ButtonData:>{"Chapter7.nb", "(7.3.19)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is a function only of ",
  Cell[BoxData[
      \(TraditionalForm\`E = \ p\^2/2  m\  + \ m\ \(\[Phi](x)\)\)]],
  " in equilibrium. Test this for your final state by evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(i\ j\) = 
        p\_j\^2/2  m\  + \ m\ \(\[Phi](x\_i)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is determined from ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " using the FFT. Make a data table of ",
  Cell[BoxData[
      \(TraditionalForm\`{E\_\(i\ j\), \ f\_\(i\ j\)}\)]],
  " values, and plot them via a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If you have achieved an equilibrium, the points should all fall on a \
single curve, which defines the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(E)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " ",
  StyleBox["SIMULATION PROJECT: 2D FLUID DYNAMICS",
    FontSlant->"Italic"],
  " . The PIC method is also used in the study of 2-dimensional  \
incompressible fluids.  Two examples of  fluids that are approximately 2D are \
soap films, and planetary atmospheres and oceans (for flows whose horizontal \
scale is large compared to the atmosphere's thickness or the ocean's depth, \
such as the jet stream or large scale ocean currents).  The following project \
allows a student to  study several aspects of 2D fluid flows. "
}], "Text",
  CellTags->"i:65"],

Cell["\<\
\tThe equations of motion for such fluids are the momentum \
equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "+", 
            RowBox[{
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              RowBox[{"\[Del]", 
                StyleBox["u",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}], " ", "=", 
          " ", \(\(-\(1\/\[Rho]\)\) \[Del]p\)}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.20)"],

Cell["\<\
(assuming the flow is unforced) and the constraint equation for \
incompressible flow,\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              RowBox[{
                StyleBox["u",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(x, y, t\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(7.3.21)"],

Cell[TextData[{
  "  In order to solve these equations,  we note that Eq. ",
  ButtonBox["(7.3.21)",
    ButtonData:>{"Chapter7.nb", "(7.3.21)"},
    ButtonStyle->"Hyperlink"],
  "  implies that ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can be written in terms of a ",
  StyleBox["stream function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi](x, y, t)\)\(:\)\)\)]]
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Plain"], "^"], "\[Times]", \(\[Del]\[Psi]\)}],
            FontWeight->"Plain"]}], TraditionalForm]]]
}], "NE3",
  CellTags->"(7.3.22)"],

Cell[TextData[{
  "(The divergence of ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is then guaranteed to equal zero.) At any given instant of time, ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " points along contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ". In order to solve for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ", we take the curl of Eq. ",
  ButtonBox["(7.3.20)",
    ButtonData:>{"Chapter7.nb", "(7.3.20)"},
    ButtonStyle->"Hyperlink"],
  " , and then dot the result with ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "^"], TraditionalForm]]],
  ". After some work with vector identities, one obtains"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[PartialD]\/\[PartialD]t\) \[Zeta]\), "+", 
            RowBox[{
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", \(\[Del]\[Zeta]\)}]}], 
          " ", "=", "0"}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.23)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Zeta]",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], "\[Times]", 
            
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " is the ",
  StyleBox["vorticity ",
    FontSlant->"Italic"],
  " of the flow. The vorticity  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "(", \(x, y, t\), 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " can be thought of as a measure of the rotation rate of a fluid element at \
",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " about its own center. According to Eq. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  " , vorticity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " is transported without change along characteristics given by ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:66"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = \ \(\(u\_x\)(
            x, y, t) = \(-\(\[PartialD]\[Psi]\/\[PartialD]y\)\)\)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\/\[DifferentialD]t = \(\(u\_y\)(x, 
            y, t) = \ \ \(\(\[PartialD]\[Psi]\/\[PartialD]x\)\(\ \
\)\(.\)\)\)\)]]
}], "NE3",
  CellTags->"(7.3.24)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  is analogous to the Boltzmann equation. If we know the flow field ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", then we can take the curl of this field to determine the vorticity, and \
populate a 2D area with a collection of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles (\"point vortices\") that are distributed according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  ".  We can follow the resulting motion of these particles by solving Eqs. \
",
  ButtonBox["(7.3.24)",
    ButtonData:>{"Chapter7.nb", "(7.3.24)"},
    ButtonStyle->"Hyperlink"],
  " .  Since vorticity has dimensions of frequency, we assign a quantity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " to each particle (analogous to mass), with dimensions of ",
  Cell[BoxData[
      \(TraditionalForm\`area\ per\ unit\ time\)]],
  ". This quantity is called the ",
  StyleBox["circulation",
    FontSlant->"Italic"],
  " of the point vortex.  Then the mean circulation of the particles per unit \
area equals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " ; i.e.  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Zeta]\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ \[Times]\((number\ or\ particles\ per\ \
unit\ area)\)\)]],
  ".  The total circulation of the flow is defined to be ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", " ", "=", " ", 
          RowBox[{
            RowBox[{"\[Integral]", 
              RowBox[{"\[Zeta]", 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}], "=", " ", \(N\ \[Gamma]\)}]}], 
        TraditionalForm]]],
  ". Clearly, \[CapitalGamma] is a conserved quantity in this dynamics, \
because ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " is fixed."
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  "\tThe stream function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " is determined by the vorticity. This can be seen by taking the curl of \
Eq. ",
  ButtonBox["(7.3.22)",
    ButtonData:>{"Chapter7.nb", "(7.3.22)"},
    ButtonStyle->"Hyperlink"],
  " : "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["z",
                      FontWeight->"Plain"], "^"],
                  FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], 
              "\[Times]", 
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "=", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[
                    OverscriptBox[
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"],
                    FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], 
                "\[Times]", 
                RowBox[{"(", 
                  StyleBox[
                    RowBox[{
                      OverscriptBox[
                        StyleBox["z",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"], 
                      "\[Times]", \(\[Del]\[Psi]\)}],
                    FontWeight->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["=",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[\(\[Del]\^2 \[Psi]\),
                FontWeight->"Plain"]}]}]}], TraditionalForm]]]
}], "NE3",
  CellTags->"(7.3.25)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  "  are coupled equations for the vorticity and stream function, called the \
",
  StyleBox["Euler equations",
    FontSlant->"Italic"],
  " for 2D flow. Note Eq. ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  "  is merely Poisson's equation. Therefore, we can follow the same \
procedure as we used for the PIC method in gravitational systems (see Table \
",
  ButtonBox["7.1",
    ButtonData:>"Table 7.1",
    ButtonStyle->"Hyperlink"],
  "). Starting with a collection of identical point vortices  that model an \
initial vorticity distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y, t = 0)\)]],
  ", we solve Poissons equation using our FFT and interpolation codes in \
order to determine the stream function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, y, t)\)]],
  " and the flow field ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". We then move the point vortices according to Eq. ",
  ButtonBox["(7.3.24)",
    ButtonData:>{"Chapter7.nb", "(7.3.24)"},
    ButtonStyle->"Hyperlink"],
  " , and repeat the procedure. "
}], "Text",
  CellTags->"i:84"],

Cell[TextData[{
  "Table 7.1 Analogous Quantities  in  2D Fluids  and Gravitational Dynamics\n\
",
  Cell[BoxData[GridBox[{
          {"gravity", \(2  D\ fluids\)},
          {"\[Phi]", "\[Psi]"},
          {"\[Rho]", "\[Zeta]"},
          {
            StyleBox["m",
              FontSlant->"Italic"], "\[Gamma]"},
          {
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "\n"
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  Background->GrayLevel[0.900008],
  CellTags->"Table 7.1"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Modify the previous PIC code to solve these 2D fluid equations.  Part of \
the job is done for you below, since the leapfrog technique for moving the \
particles will no longer work. Instead, we use the Adams-Bashforth scheme \
discussed in Chapter 1: see Eq. ",
  ButtonBox["(1.4.29)",
    ButtonData:>{"Chapter1.nb", "(1.4.29)"},
    ButtonStyle->"Hyperlink"],
  "  . The following module implements this method, including a few extra \
tricks in order to save memory. First,  the code keeps  memory  of only one  \
previous velocity field evaluation in the variable ",
  StyleBox["u0",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  ", by updating ",
  StyleBox["u0",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " after each step.  Second,  an ",
  StyleBox["Unset",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is used to clear previous position evaluations (again, in order \
to save memory space), and for this reason the plots of the flow are created \
inside the routine. [This ",
  StyleBox["Unset",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command can be disabled if you wish by surrounding the command with \
comment marks ",
  StyleBox["(* *)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ]"
}], "Text",
  CellTags->"i:68"],

Cell[TextData[{
  "\tAlso, for long runs, it is not a bad idea to save data to a file \
periodically. This is implemented using the ",
  StyleBox["Export",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement to open a datafile named ",
  StyleBox["r_n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the default directory, and to  write positions to the file every 100 \
steps. The module is"
}], "Text",
  CellTags->"i:67"],

Cell[BoxData[
    RowBox[{\(adbash[r0_, \ Nstep_, \[CapitalDelta]t_, \ \[CapitalDelta]N_]\),
       " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({}\), ",", "\[IndentingNewLine]", 
          StyleBox[
            RowBox[{"(*", " ", 
              RowBox[{
                RowBox[{"second", "-", 
                  RowBox[{
                  "order", " ", "Adams", " ", "Bashforth", " ", "method", " ",
                     "for", " ", "the", " ", "ODE", 
                    RowBox[{
                    Cell["dr/dt =  u"], ".", " ", 
                      "\[IndentingNewLine]", \((Requires\ a\ function\ u[
                            r])\), ".", " ", "r0"}], " ", "is", " ", "the", 
                    " ", "initial", " ", "condition"}]}], ",", 
                " ", \(Nstep\ is\ the\ number\ of\ timsteps\), ",", 
                " ", \(\[CapitalDelta]t\ is\ the\ step\ size\), ",", 
                " ", \(\[CapitalDelta]N\ is\ a\ parameter\ in\ the\ plots\)}],
               " ", "*)"}],
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          RowBox[{\(md[x_]\  := \ Mod[x, L]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ initial\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(r[0]\  = \ Map[r0, L]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{\(r[n_]\), " ", ":=", 
              RowBox[{
                RowBox[{"(", " ", 
                  RowBox[{\(r[n]\), " ", "=", 
                    RowBox[{
                      StyleBox["(",
                        FontSize->16,
                        FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
                      
                      RowBox[{
                        StyleBox["(*",
                          FontColor->RGBColor[1, 0, 0]], 
                        StyleBox[" ",
                          FontColor->RGBColor[1, 0, 0]], 
                        
                        StyleBox[\(write\ n - 
                            1\ position\ data\ to\ file\ if\ n - 
                            1\ a\ multiple\ of\ 100\),
                          FontColor->RGBColor[1, 0, 0]], " ", 
                        StyleBox["*)",
                          FontColor->RGBColor[1, 0, 0]]}], 
                      "\[IndentingNewLine]", 
                      
                      RowBox[{\(If[Mod[n - 1, 100]\  == 0, 
                          Export["\<r_\>" <> ToString[n - 1], 
                            r[n - 1], "\<Table\>"]]\), ";", 
                        "\[IndentingNewLine]", 
                        
                        StyleBox[\( (*\ 
                            account\ for\ periodic\ boundary\ conditions\ *) \
\),
                          FontColor->RGBColor[1, 0, 0]], 
                        "\[IndentingNewLine]", " ", \(Map[md, \ r1[n]]\)}], 
                      StyleBox[")",
                        FontSize->16,
                        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", "/;", 
                " ", \(n \[GreaterEqual] \ 1\)}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            StyleBox[\( (*\ predictor\ step\ for\ n = 1\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(u0\  = \ \ u[r[0]]\), ";", " ", 
            "\[IndentingNewLine]", \(rp\  = \ 
              Map[md, r[0]\  + \ u0\ \ \[CapitalDelta]t]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            StyleBox[\( (*\ corrector\ step\ for\ n = 1*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(u1\  = \ u[rp]\), ";", 
            "\[IndentingNewLine]", \(r1[1]\  := 
              r[0]\  + \ \[CapitalDelta]t \((u0\  + \ u1)\)/2\), " ", ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\(second - order\ Adams - 
                    Bashforth\ step\ for\ n\  \[GreaterEqual] \ 2\),
                FontColor->RGBColor[1, 0, 0]], " ", 
              StyleBox["*)",
                FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
            RowBox[{\(r1[n_]\), " ", ":=", 
              RowBox[{
                RowBox[{"(", 
                  
                  RowBox[{\(u1\  = \ u[r[n - 1]]\), ";", 
                    "\[IndentingNewLine]", 
                    "                ", \(rnew = \ 
                      r[n - 1]\  + \ \[CapitalDelta]t\ \((1.5\ u1 - 
                              0.5  u0)\)\), ";", "\[IndentingNewLine]", 
                    "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[\(update\ the\ old\ velocity\ field\),
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", "                ", \(u0 = u1\), 
                    ";", "\[IndentingNewLine]", "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      
                      StyleBox[\(un - 
                          memorize\ \((Unset)\)\ r[n - 2]\ to\ save\ memory\),
                        
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", 
                    "                ", \(Unset[r[n - 2]]\), ";", 
                    "\[IndentingNewLine]", "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[\(return\ new\ position\),
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", "                ", "rnew"}], 
                  ")"}], "  ", "/;", \(n \[GreaterEqual] \ 2\)}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ plot\ solution\ up\ to\ time\ step\ Nstep, \ 
                showing\ every\ \[CapitalDelta]N\ th\ step\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Table[
              ListPlot[r[n], PlotRange \[Rule] {{0, L}, {0, L}}, 
                AspectRatio \[Rule] 1, 
                PlotLabel -> "\<n= \>" <> ToString[n\ ]], {n, 0, 
                Nstep, \ \[CapitalDelta]N}]\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.93"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Code tests.\n\t(",
    FontSlant->"Italic"],
  "i) Show that a circular patch of vorticity with radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and vorticity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " causes fluid rotation of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{\(\[Omega](r)\), " ", "r", " ", 
              OverscriptBox[
                StyleBox["\[Theta]",
                  FontWeight->"Bold"], "^"]}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where the rotation frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\)]],
  " is  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\  = \ \[Zeta]\ /2\)]],
  " inside the patch, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\  = \ \[Zeta]\ R\^2/2\ r\^2\)]],
  " outside the patch.  (This sort of flow can be set up by stirring the \
fluid with a rotating disk of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", then removing the disk.)"
}], "Text"],

Cell[TextData[{
  "\t(ii) Create such a uniform circular patch with radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.3\)]],
  ", using ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " point vortices  each with circulation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1/N\)]],
  ". Evaluate the rotation frequency of the patch numerically as a function \
of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", and compare with part (i)"
}], "Text"],

Cell[TextData[{
  "\t(iii) Show analytically that two isolated point vortices, each with \
circulation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Gamma]\)\(,\)\)\)]],
  " and separated by a distance ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", will rotate around one another with rotation rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \[Gamma]/R\^2\)]],
  ". Test this result in your code, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.25\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(iv) Show analytically that the total kinetic energy ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " of the flow is conserved, where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"K", " ", "=", " ", 
          RowBox[{"\[Rho]", 
            RowBox[{"\[Integral]", 
              RowBox[{\(u\^2\/2\), 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ". Test this result for the simulations done in parts ii) and iii). Comment \
on whether the PIC method does an adequate job of evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ". [Hint: First show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"K", " ", "=", 
          RowBox[{\(-\(\[Rho]\/2\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{"\[Zeta]", "  ", "\[Psi]", 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], " "}]}]}]}]}], TraditionalForm]]],
  ". Take a time derivative of this quantity and apply Eqs. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  " . ]"
}], "Text"],

Cell[TextData[{
  "\t(v) Show analytically that, for an unbounded flow where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[Rule]", "0"}], TraditionalForm]]],
  " at infinity,  the total angular momentum ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z\)]],
  " of the flow is conserved, where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\(L\)\(\ \)\)\_z\), "=", " ", 
          RowBox[{"\[Rho]", 
            RowBox[{"\[Integral]", 
              RowBox[{\((x\ u\_y - y\ u\_x)\), 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ". Test this result for the simulations done in parts (ii) and (iii). \
Comment. "
}], "Text"],

Cell[TextData[{
  "\t ",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Fluid turbulence",
    FontSlant->"Italic"],
  ". \t(i) Run your code for a random collection of ",
  Cell[BoxData[
      \(TraditionalForm\`N = 500\)]],
  " point vortices, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", "=", " ", "0.3"}],
            "TraditionalForm"], ","}], TraditionalForm]]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1/N\)]],
  ". These vortices create a complicated flow field, which has been used by \
researchers as a model of fluid turbulence.   Run the code for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  " steps.  Does anything like gravitational collapse happen here?  Describe \
the motion of the fluid in a few words."
}], "Text",
  CellTags->"i:72"],

Cell[TextData[{
  "\t \t\t         \t(ii) Higher-kinetic-energy initial conditions do go \
through a process somewhat akin to gravitational collapse: there is an \
instability that results in a final (rotating) equilibrium state. Repeat the \
simulation, now confining the initial random positions of the point vortices \
to the region ",
  Cell[BoxData[
      \(TraditionalForm\`0.4 < y < 0.5\)]],
  ".  Sheets of vorticity such as this create shear flows that are unstable \
and that can be analyzed in much the same way as for the Jeans instability. \
(This instability is called the Kelvin-Helmholtz instability.) Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N = 500\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.03"}], TraditionalForm]]],
  ". Now describe the state that develops after 300 steps. "
}], "Text"],

Cell[TextData[{
  "\t ",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vortex merger.\t (",
    FontSlant->"Italic"],
  "i)",
  StyleBox[" ",
    FontSlant->"Italic"],
  " In part (c)(ii), it should have become apparent that merger between \
vortex patches is an important process in the equilibration of initially \
unstable flows.  To study this process, create an initial condition \
consisting of two identical uniform circular vortex patches of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.1\)]],
  ", with centers separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.25\)]],
  ".  Take ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " (500 in each patch),  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 2/N\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ".  (This run requires fine resolution; take ",
  Cell[BoxData[
      \(TraditionalForm\`M > 30\)]],
  "). How long would you estimate that it takes the two vortices to merge, \
becoming one vortex?"
}], "Text",
  CellTags->"i:70"],

Cell[TextData[{
  "\t \t\t         (ii) Repeat the simulation for ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.5\)]],
  ". Now what happens? Do the vortices merge? The time required to merge is \
in fact  a sensitive function of the ratio ",
  Cell[BoxData[
      \(TraditionalForm\`D/R\)]],
  ".  [See ",
  ButtonBox["Driscoll and Fine (1990)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vortex crystals",
    FontSlant->"Italic"],
  ". The following code will create an initial condition consisting of a thin \
vortex ring of thickness ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " surrounding a low vorticity center. Such vortex rings can occur \
naturally, for example, in the eye-walls of hurricanes.  These rings are \
unstable because the flow field is highly sheared.  Follow the dynamics of \
the ring for 1000-1500 time steps.  Often, through chaotic vortex merger \
processes, an equilibrium state will develop  called a v",
  StyleBox["ortex crystal",
    FontSlant->"Italic"],
  ", that consists of several strong vortices in a stable regular pattern \
[\"a phalanx of tornadoes\", in the words of  ",
  ButtonBox["James Glanz (1998)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "].  (This simulation will take up to several hours. It might be best to \
run the code overnight.) See ",
  ButtonBox["Fine et. al (1995)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:71"],

Cell[BoxData[{
    \(M = 50; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[Gamma] = \ 1. /6000; \[CapitalDelta]t\  = \ 0.018;\), "\n", 
    \(\(\(Clear[r];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(d\  = \ 0.025; R\  = \ 0.2;\), "\n", 
    \(\(r0\  = \ 
        Table[\((rr = d\ Random[] + R; \[Theta]\  = \ 
              2\ Pi\ Random[]; {rr\ Cos[\[Theta]]\  + \  .5, 
              rr\ Sin[\[Theta]] + \  .5})\), {5000}];\)\), "\n", 
    \(\(rc = 
        Table[\((rr = \((Random[Real, {0, R^3}])\)^\((1/3)\); \[Theta]\  = \ 
              2\ Pi\ Random[]; {rr\ Cos[\[Theta]]\  + \  .5, 
              rr\ Sin[\[Theta]] + \  .5})\), {1000}];\)\), "\n", 
    \(\(r0\  = \ Join[r0, rc];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.94"],

Cell[TextData[{
  "The results of one such simulation are shown in Cell ",
  ButtonBox["7.95",
    ButtonData:>"Cell 7.95",
    ButtonStyle->"Hyperlink"],
  ". Your results may differ substantially because even small differences in \
the initial conditions can lead to large differences in the final state.  \
However,  from this initial condition roughly the same number of vortices in \
the final crystal should appear almost every time. "
}], "Text"],

Cell[TextData[{
  "\t(i) Show, using Eq. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  " , that equilibrium vorticity distributions satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y)\  = \ \[Zeta](\[Psi])\)]],
  ": contours of vorticity lie along contours of the stream function."
}], "Text"],

Cell[TextData[{
  "\t(ii)   Test whether your final state is an equilibrium by plotting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, y)\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y)\)]],
  " for all points ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " on the grid. (Make a table of data pairs ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({\[Psi]\_\(i\ j\), \ \[Rho]\_\(i\ \
j\)}\)\(,\)\)\)]],
  " and plot them with a list plot.)  Smooth your data by evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " from the  position data taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ". Does the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  "-vs.- ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " data fall on one (or more) lines? Comment on the scatter. Repeat this for \
an intermediate value of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " where the system has not yet achieved equilibrium.  "
}], "Text"],

Cell[TextData[{
  "\t(iii) ",
  StyleBox["Other possible runs:",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell["\<\
\tRemove the low-vorticity region in the center. How does this \
affect the number of vortices in the final state? \
\>", "Text"],

Cell[TextData[{
  "\tIncrease the thickness ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " of the ring by a factor of two. How does this affect the number of \
vortices observed in the final state?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Utilities`;\)\), "\n", 
    \(Timing[adbash[r0, 1500, \[CapitalDelta]t, 6]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.95"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65997 .37116 Mdot
.59727 .31797 Mdot
.37533 .3389 Mdot
.46646 .71221 Mdot
.43511 .70589 Mdot
.3822 .33037 Mdot
.55783 .29986 Mdot
.49982 .28502 Mdot
.28413 .43997 Mdot
.45241 .71015 Mdot
.40862 .30653 Mdot
.70211 .57872 Mdot
.54892 .29725 Mdot
.52506 .70901 Mdot
.62809 .65988 Mdot
.71231 .43985 Mdot
.61906 .32219 Mdot
.43042 .70253 Mdot
.69594 .5625 Mdot
.28805 .42699 Mdot
.29354 .49224 Mdot
.47729 .70746 Mdot
.60027 .30683 Mdot
.55623 .70938 Mdot
.70299 .55011 Mdot
.70418 .4706 Mdot
.66216 .37587 Mdot
.70876 .52794 Mdot
.70379 .56922 Mdot
.45647 .28285 Mdot
.70953 .50391 Mdot
.61231 .69185 Mdot
.29708 .50384 Mdot
.6715 .37267 Mdot
.39959 .3152 Mdot
.4185 .29371 Mdot
.36435 .35136 Mdot
.45018 .29032 Mdot
.48084 .27881 Mdot
.42661 .3087 Mdot
.41684 .31067 Mdot
.70547 .46505 Mdot
.40685 .29824 Mdot
.5746 .3025 Mdot
.58813 .70078 Mdot
.68722 .37973 Mdot
.29179 .48245 Mdot
.53884 .69692 Mdot
.65242 .35888 Mdot
.28996 .4919 Mdot
.62927 .66639 Mdot
.58086 .31129 Mdot
.30225 .54979 Mdot
.62035 .3136 Mdot
.5382 .29686 Mdot
.70603 .54438 Mdot
.32461 .38015 Mdot
.65112 .65044 Mdot
.67705 .60028 Mdot
.67625 .38125 Mdot
.56703 .71033 Mdot
.33669 .61943 Mdot
.69717 .57242 Mdot
.30895 .3869 Mdot
.32972 .38384 Mdot
.49224 .30001 Mdot
.59003 .29442 Mdot
.44677 .29233 Mdot
.53935 .70832 Mdot
.32714 .39715 Mdot
.63466 .65921 Mdot
.40878 .30683 Mdot
.69651 .41841 Mdot
.46004 .70749 Mdot
.64894 .36248 Mdot
.42768 .29828 Mdot
.45022 .71593 Mdot
.70424 .4356 Mdot
.28168 .54112 Mdot
.51225 .72444 Mdot
.49989 .71015 Mdot
.37535 .31434 Mdot
.65388 .63028 Mdot
.70764 .4686 Mdot
.59775 .69021 Mdot
.42532 .28913 Mdot
.44351 .70344 Mdot
.70941 .50082 Mdot
.71434 .50949 Mdot
.7098 .56706 Mdot
.28836 .45035 Mdot
.57848 .29395 Mdot
.45277 .70178 Mdot
.62812 .68113 Mdot
.5936 .68307 Mdot
.59511 .68931 Mdot
.71676 .50045 Mdot
.28851 .52662 Mdot
.4454 .30176 Mdot
.29794 .52623 Mdot
.43346 .29442 Mdot
.31123 .58851 Mdot
.61566 .69146 Mdot
.34686 .35196 Mdot
.65488 .3488 Mdot
.28762 .54012 Mdot
.43754 .29863 Mdot
.44378 .69638 Mdot
.43467 .29089 Mdot
.58496 .30129 Mdot
.71334 .49273 Mdot
.39208 .68289 Mdot
.43877 .71379 Mdot
.66835 .38501 Mdot
.65222 .66392 Mdot
.45646 .71144 Mdot
.49483 .70719 Mdot
.5854 .29212 Mdot
.29023 .42915 Mdot
.28089 .47558 Mdot
.61897 .33633 Mdot
.44097 .30436 Mdot
.63157 .33138 Mdot
.35294 .65956 Mdot
.29925 .41896 Mdot
.29234 .54794 Mdot
.30284 .59252 Mdot
.59265 .70202 Mdot
.59417 .68831 Mdot
.34816 .66266 Mdot
.34798 .3492 Mdot
.62067 .33794 Mdot
.53224 .29068 Mdot
.63258 .67893 Mdot
.69457 .39122 Mdot
.53853 .29795 Mdot
.37063 .66085 Mdot
.41221 .69907 Mdot
.69193 .40617 Mdot
.64618 .66483 Mdot
.50183 .29691 Mdot
.52097 .27819 Mdot
.64931 .65326 Mdot
.68868 .38541 Mdot
.37835 .66149 Mdot
.52048 .27788 Mdot
.31311 .58243 Mdot
.71635 .47905 Mdot
.69786 .60251 Mdot
.3899 .30402 Mdot
.62461 .66805 Mdot
.30017 .45665 Mdot
.33555 .62425 Mdot
.52461 .29479 Mdot
.47286 .71544 Mdot
.63018 .33404 Mdot
.68651 .39313 Mdot
.67884 .61544 Mdot
.29046 .52206 Mdot
.67287 .63688 Mdot
.3223 .61717 Mdot
.2958 .58375 Mdot
.48878 .70334 Mdot
.67811 .3774 Mdot
.64373 .33011 Mdot
.63853 .65724 Mdot
.32784 .38797 Mdot
.45921 .71988 Mdot
.40174 .30828 Mdot
.58009 .69495 Mdot
.57379 .69098 Mdot
.68773 .60533 Mdot
.54611 .28807 Mdot
.36361 .32795 Mdot
.28946 .46621 Mdot
.4863 .29714 Mdot
.38854 .31533 Mdot
.32647 .36677 Mdot
.68929 .59164 Mdot
.40004 .69614 Mdot
.32447 .63242 Mdot
.63643 .65883 Mdot
.55896 .70689 Mdot
.70584 .5751 Mdot
.30322 .60544 Mdot
.30863 .6175 Mdot
.66706 .37273 Mdot
.39721 .30409 Mdot
.52364 .71803 Mdot
.6838 .58492 Mdot
.61082 .67721 Mdot
.49202 .29283 Mdot
.5187 .28668 Mdot
.32541 .36135 Mdot
.29076 .42003 Mdot
.3066 .43563 Mdot
.63145 .65174 Mdot
.63141 .65639 Mdot
.51355 .71532 Mdot
.29679 .54452 Mdot
.72121 .51 Mdot
.33617 .62416 Mdot
.62065 .32516 Mdot
.37212 .31702 Mdot
.69415 .61029 Mdot
.69195 .55721 Mdot
.27828 .46614 Mdot
.27865 .50701 Mdot
.32981 .64492 Mdot
.3656 .67062 Mdot
.62451 .66635 Mdot
.66159 .3672 Mdot
.63416 .66331 Mdot
.29656 .50803 Mdot
.43833 .71527 Mdot
.61091 .32717 Mdot
.54722 .695 Mdot
.55685 .30298 Mdot
.42361 .3137 Mdot
.43586 .69849 Mdot
.43692 .69276 Mdot
.70294 .42485 Mdot
.62641 .6801 Mdot
.69584 .5678 Mdot
.70808 .51579 Mdot
.31033 .42584 Mdot
.45765 .29456 Mdot
.45611 .28106 Mdot
.29101 .49283 Mdot
.69371 .39947 Mdot
.58537 .31058 Mdot
.35089 .35264 Mdot
.29623 .47807 Mdot
.40771 .30224 Mdot
.36172 .65792 Mdot
.35314 .34852 Mdot
.37927 .66099 Mdot
.68861 .58608 Mdot
.3566 .33784 Mdot
.37753 .66939 Mdot
.6426 .65053 Mdot
.30723 .59698 Mdot
.41482 .70781 Mdot
.56586 .30465 Mdot
.56108 .28902 Mdot
.65407 .64696 Mdot
.31001 .58884 Mdot
.29822 .50789 Mdot
.68398 .59812 Mdot
.30393 .59892 Mdot
.29663 .57581 Mdot
.68702 .59679 Mdot
.41804 .69301 Mdot
.37102 .32203 Mdot
.71008 .50264 Mdot
.62387 .32594 Mdot
.55731 .7077 Mdot
.47133 .30134 Mdot
.53443 .29717 Mdot
.52328 .72257 Mdot
.42972 .28919 Mdot
.5725 .30913 Mdot
.49282 .70505 Mdot
.47501 .28284 Mdot
.70585 .42098 Mdot
.69505 .60975 Mdot
.69545 .42213 Mdot
.52223 .70898 Mdot
.47588 .28139 Mdot
.29071 .49218 Mdot
.70598 .4412 Mdot
.47028 .70855 Mdot
.49051 .71678 Mdot
.29856 .54535 Mdot
.7118 .50185 Mdot
.47729 .28833 Mdot
.70126 .57928 Mdot
.37572 .32569 Mdot
.65005 .64102 Mdot
.32237 .60016 Mdot
.33952 .63697 Mdot
.68703 .38514 Mdot
.29827 .59215 Mdot
.3667 .33925 Mdot
.59315 .68238 Mdot
.5918 .68033 Mdot
.60084 .69326 Mdot
.29959 .57635 Mdot
.65234 .63216 Mdot
.55062 .30611 Mdot
.72059 .49122 Mdot
.34602 .65918 Mdot
.33516 .37027 Mdot
.30435 .55022 Mdot
.59751 .68936 Mdot
.59313 .30271 Mdot
.70819 .49931 Mdot
.36787 .32936 Mdot
.59892 .30888 Mdot
.55852 .69266 Mdot
.44987 .29244 Mdot
.3287 .60509 Mdot
.45733 .28646 Mdot
.69805 .55093 Mdot
.65817 .63507 Mdot
.32257 .40239 Mdot
.70361 .41667 Mdot
.51295 .29106 Mdot
.69629 .42042 Mdot
.66417 .64422 Mdot
.66834 .64412 Mdot
.68456 .38554 Mdot
.33135 .62187 Mdot
.2838 .50105 Mdot
.41054 .30416 Mdot
.29522 .55373 Mdot
.31204 .41254 Mdot
.6517 .35594 Mdot
.35577 .34419 Mdot
.66463 .65317 Mdot
.42905 .31247 Mdot
.70626 .50589 Mdot
.32116 .40205 Mdot
.67872 .61803 Mdot
.59485 .69942 Mdot
.31455 .37621 Mdot
.2945 .50318 Mdot
.64019 .65804 Mdot
.7009 .40272 Mdot
.49315 .70194 Mdot
.43851 .70173 Mdot
.63262 .65261 Mdot
.33348 .37141 Mdot
.64956 .66249 Mdot
.70396 .53218 Mdot
.70058 .54975 Mdot
.61902 .32619 Mdot
.30364 .57067 Mdot
.3815 .66744 Mdot
.41745 .70655 Mdot
.31881 .59992 Mdot
.7073 .5748 Mdot
.65853 .65401 Mdot
.69053 .39366 Mdot
.29072 .47616 Mdot
.55175 .28375 Mdot
.29604 .50879 Mdot
.49823 .28431 Mdot
.36891 .3252 Mdot
.43151 .69535 Mdot
.43462 .7031 Mdot
.70938 .491 Mdot
.65029 .35847 Mdot
.69817 .41871 Mdot
.50935 .28979 Mdot
.71941 .52642 Mdot
.51549 .72426 Mdot
.52568 .72216 Mdot
.49429 .27943 Mdot
.29324 .52218 Mdot
.66481 .61706 Mdot
.58633 .68145 Mdot
.56444 .29615 Mdot
.58448 .69919 Mdot
.68104 .39892 Mdot
.50239 .70216 Mdot
.6167 .68877 Mdot
.52707 .70439 Mdot
.69654 .39649 Mdot
.70751 .49655 Mdot
.58925 .68065 Mdot
.27632 .47976 Mdot
.69749 .60644 Mdot
.38611 .69248 Mdot
.46062 .70684 Mdot
.62303 .66683 Mdot
.3695 .65576 Mdot
.66652 .38023 Mdot
.56483 .69583 Mdot
.39424 .3026 Mdot
.46564 .7063 Mdot
.40098 .30757 Mdot
.66852 .62131 Mdot
.61618 .68307 Mdot
.70656 .52692 Mdot
.599 .30559 Mdot
.48696 .27763 Mdot
.40555 .31146 Mdot
.34025 .65061 Mdot
.53261 .29684 Mdot
.59012 .6933 Mdot
.66451 .62533 Mdot
.66832 .38452 Mdot
.30553 .59263 Mdot
.57502 .29161 Mdot
.47302 .72195 Mdot
.54568 .29177 Mdot
.30704 .57044 Mdot
.70736 .55839 Mdot
.52505 .2819 Mdot
.38637 .31059 Mdot
.71356 .49043 Mdot
.29352 .52157 Mdot
.65885 .36733 Mdot
.32117 .40294 Mdot
.29023 .55385 Mdot
.53128 .29539 Mdot
.57929 .70306 Mdot
.71836 .48595 Mdot
.49528 .28748 Mdot
.69183 .43241 Mdot
.71601 .47031 Mdot
.45845 .70331 Mdot
.7034 .48127 Mdot
.56769 .28551 Mdot
.68296 .62625 Mdot
.54216 .71739 Mdot
.36504 .34473 Mdot
.29806 .57217 Mdot
.29967 .5716 Mdot
.2879 .56076 Mdot
.43684 .31006 Mdot
.28315 .48703 Mdot
.46202 .29639 Mdot
.52965 .70762 Mdot
.48124 .29801 Mdot
.31085 .5908 Mdot
.3681 .34233 Mdot
.55403 .70642 Mdot
.7248 .50425 Mdot
.51951 .27692 Mdot
.30166 .42486 Mdot
.4272 .68981 Mdot
.63378 .33562 Mdot
.56368 .29878 Mdot
.63245 .65623 Mdot
.31857 .41273 Mdot
.33454 .6158 Mdot
.63528 .66905 Mdot
.51902 .27942 Mdot
.68558 .41737 Mdot
.51486 .27894 Mdot
.59901 .67862 Mdot
.5609 .70041 Mdot
.6292 .34612 Mdot
.37571 .68457 Mdot
.69858 .58207 Mdot
.5591 .70952 Mdot
.2868 .51204 Mdot
.57107 .2963 Mdot
.37128 .68089 Mdot
.71254 .5542 Mdot
.31154 .6113 Mdot
.45955 .71909 Mdot
.50586 .71457 Mdot
.68947 .59805 Mdot
.34013 .64185 Mdot
.47521 .28561 Mdot
.402 .70126 Mdot
.27972 .46449 Mdot
.60259 .3164 Mdot
.46372 .29581 Mdot
.28796 .52318 Mdot
.41205 .30596 Mdot
.69995 .59038 Mdot
.32334 .62297 Mdot
.58942 .31577 Mdot
.40584 .67861 Mdot
.30043 .58278 Mdot
.32581 .38077 Mdot
.66265 .64395 Mdot
.69265 .59079 Mdot
.45587 .70212 Mdot
.38117 .66777 Mdot
.56956 .29278 Mdot
.39022 .31219 Mdot
.47747 .27698 Mdot
.48401 .70167 Mdot
.68673 .38486 Mdot
.68409 .42086 Mdot
.29926 .53227 Mdot
.38535 .68104 Mdot
.36612 .66324 Mdot
.47507 .69977 Mdot
.68191 .59285 Mdot
.69454 .3957 Mdot
.46892 .70834 Mdot
.49252 .70305 Mdot
.29502 .44793 Mdot
.70071 .4915 Mdot
.34894 .34406 Mdot
.68739 .57133 Mdot
.6225 .67522 Mdot
.45786 .29303 Mdot
.55479 .30487 Mdot
.30109 .56702 Mdot
.45601 .28093 Mdot
.28883 .46437 Mdot
.29984 .57222 Mdot
.47258 .70918 Mdot
.66671 .38717 Mdot
.46391 .70696 Mdot
.46368 .70601 Mdot
.53979 .70577 Mdot
.65597 .65572 Mdot
.27664 .49781 Mdot
.39355 .68993 Mdot
.70162 .57014 Mdot
.33357 .35722 Mdot
.27883 .46257 Mdot
.60179 .67966 Mdot
.49205 .7132 Mdot
.4837 .70454 Mdot
.7014 .47256 Mdot
.72001 .47905 Mdot
.51216 .28166 Mdot
.62788 .34544 Mdot
.48991 .72008 Mdot
.29549 .46271 Mdot
.55894 .69826 Mdot
.68443 .39226 Mdot
.4085 .31374 Mdot
.49726 .29291 Mdot
.30701 .6039 Mdot
.29895 .5187 Mdot
.29781 .57576 Mdot
.29409 .49955 Mdot
.41057 .29655 Mdot
.36947 .34153 Mdot
.31906 .58964 Mdot
.66992 .64353 Mdot
.53745 .71688 Mdot
.56978 .69682 Mdot
.29605 .44011 Mdot
.309 .56489 Mdot
.65533 .65351 Mdot
.71864 .44771 Mdot
.41507 .3162 Mdot
.28722 .55138 Mdot
.7052 .49616 Mdot
.59331 .30787 Mdot
.31616 .41317 Mdot
.44667 .29052 Mdot
.38033 .6704 Mdot
.29353 .48107 Mdot
.5708 .29101 Mdot
.68783 .58364 Mdot
.4115 .31812 Mdot
.66338 .62515 Mdot
.72476 .4955 Mdot
.36672 .33526 Mdot
.71957 .49971 Mdot
.59481 .29781 Mdot
.30458 .59261 Mdot
.66006 .6315 Mdot
.68094 .60264 Mdot
.31398 .37375 Mdot
.46003 .70857 Mdot
.28424 .46132 Mdot
.33176 .37416 Mdot
.31035 .59784 Mdot
.33416 .37069 Mdot
.5408 .30268 Mdot
.33005 .36713 Mdot
.69762 .45278 Mdot
.60059 .70067 Mdot
.6335 .32384 Mdot
.67984 .62045 Mdot
.48846 .72092 Mdot
.57962 .31209 Mdot
.47478 .29957 Mdot
.55236 .71263 Mdot
.42653 .70058 Mdot
.33605 .37088 Mdot
.29018 .46889 Mdot
.71796 .50078 Mdot
.30611 .42216 Mdot
.5986 .30503 Mdot
.44389 .29463 Mdot
.47543 .29946 Mdot
.29424 .56793 Mdot
.69319 .3887 Mdot
.45868 .28934 Mdot
.44339 .30404 Mdot
.32805 .6042 Mdot
.67898 .62843 Mdot
.66473 .36349 Mdot
.6648 .61737 Mdot
.40225 .68021 Mdot
.46866 .70648 Mdot
.34319 .34984 Mdot
.30082 .44433 Mdot
.594 .67702 Mdot
.35378 .35088 Mdot
.29831 .56116 Mdot
.68035 .4028 Mdot
.70316 .55195 Mdot
.59192 .31164 Mdot
.62978 .67858 Mdot
.46599 .29555 Mdot
.59293 .3053 Mdot
.28761 .56932 Mdot
.57001 .71239 Mdot
.68022 .37985 Mdot
.72 .53771 Mdot
.46126 .7041 Mdot
.31003 .40489 Mdot
.37213 .6575 Mdot
.30187 .45697 Mdot
.28736 .45068 Mdot
.34555 .63781 Mdot
.58076 .30504 Mdot
.30056 .4164 Mdot
.3617 .66148 Mdot
.35727 .66427 Mdot
.28726 .55992 Mdot
.38614 .68755 Mdot
.59509 .69089 Mdot
.51683 .29373 Mdot
.58709 .30848 Mdot
.52696 .70242 Mdot
.45711 .71283 Mdot
.62476 .31611 Mdot
.29778 .53971 Mdot
.45925 .70189 Mdot
.67142 .63544 Mdot
.68555 .3947 Mdot
.36938 .31993 Mdot
.30882 .39331 Mdot
.29367 .53445 Mdot
.58791 .3071 Mdot
.37508 .31431 Mdot
.32396 .38963 Mdot
.35468 .64697 Mdot
.49241 .28957 Mdot
.66589 .3872 Mdot
.30103 .54769 Mdot
.56219 .30242 Mdot
.29222 .44004 Mdot
.62493 .6684 Mdot
.71656 .44973 Mdot
.40869 .32151 Mdot
.62824 .66671 Mdot
.70027 .52401 Mdot
.31008 .42958 Mdot
.36503 .32625 Mdot
.58273 .2994 Mdot
.48612 .28103 Mdot
.37549 .67207 Mdot
.69804 .42358 Mdot
.57488 .29193 Mdot
.55404 .30475 Mdot
.62145 .31199 Mdot
.64884 .6367 Mdot
.42849 .29884 Mdot
.66268 .61702 Mdot
.63534 .66179 Mdot
.30301 .5581 Mdot
.3983 .69389 Mdot
.45324 .29427 Mdot
.70443 .4705 Mdot
.53228 .27864 Mdot
.5988 .68578 Mdot
.71938 .47238 Mdot
.39699 .68482 Mdot
.64155 .33286 Mdot
.35276 .33239 Mdot
.51728 .28205 Mdot
.2879 .50512 Mdot
.4237 .69914 Mdot
.606 .69074 Mdot
.33184 .38756 Mdot
.57534 .69781 Mdot
.58756 .31621 Mdot
.69969 .52507 Mdot
.61192 .32532 Mdot
.41966 .30094 Mdot
.71156 .47173 Mdot
.70437 .57164 Mdot
.54624 .71489 Mdot
.30879 .42774 Mdot
.67301 .38717 Mdot
.33879 .63642 Mdot
.41979 .68786 Mdot
.57453 .71179 Mdot
.29948 .50823 Mdot
.59977 .69974 Mdot
.37483 .32124 Mdot
.29206 .5166 Mdot
.4058 .31817 Mdot
.30154 .58786 Mdot
.29741 .55521 Mdot
.65145 .35074 Mdot
.30638 .43759 Mdot
.29913 .51526 Mdot
.52054 .72322 Mdot
.44759 .69501 Mdot
.48867 .27681 Mdot
.65234 .63518 Mdot
.67388 .60906 Mdot
.34754 .3413 Mdot
.3273 .6018 Mdot
.56934 .69081 Mdot
.70788 .44324 Mdot
.4103 .69582 Mdot
.32242 .61593 Mdot
.60357 .31281 Mdot
.59956 .68819 Mdot
.29422 .44903 Mdot
.30563 .59054 Mdot
.3155 .59676 Mdot
.3863 .67557 Mdot
.55942 .29518 Mdot
.68668 .40669 Mdot
.33023 .37598 Mdot
.71399 .4573 Mdot
.45603 .71541 Mdot
.30867 .42327 Mdot
.30352 .56164 Mdot
.33347 .64105 Mdot
.68701 .38617 Mdot
.6966 .44626 Mdot
.28983 .51342 Mdot
.33623 .35365 Mdot
.42458 .29086 Mdot
.42215 .30396 Mdot
.67578 .61866 Mdot
.46079 .28583 Mdot
.58307 .29928 Mdot
.61284 .67899 Mdot
.36445 .66211 Mdot
.53052 .28379 Mdot
.29418 .56995 Mdot
.58494 .30299 Mdot
.69963 .44607 Mdot
.56963 .70859 Mdot
.48279 .70875 Mdot
.29136 .48834 Mdot
.60885 .69391 Mdot
.55075 .2898 Mdot
.37312 .6612 Mdot
.35733 .35327 Mdot
.71874 .49353 Mdot
.62942 .33297 Mdot
.30743 .44084 Mdot
.71475 .55532 Mdot
.31411 .38296 Mdot
.60966 .33053 Mdot
.403 .68648 Mdot
.39202 .68925 Mdot
.61657 .67807 Mdot
.30629 .44397 Mdot
.56618 .30314 Mdot
.69289 .39011 Mdot
.57411 .2994 Mdot
.69457 .58084 Mdot
.48815 .71207 Mdot
.71178 .5302 Mdot
.39445 .30956 Mdot
.58892 .69252 Mdot
.38539 .67302 Mdot
.62728 .32157 Mdot
.58679 .70183 Mdot
.42786 .70522 Mdot
.34207 .64146 Mdot
.33347 .64457 Mdot
.30272 .39567 Mdot
.40645 .68783 Mdot
.41201 .69152 Mdot
.43041 .70967 Mdot
.37084 .32434 Mdot
.65237 .64284 Mdot
.42748 .69761 Mdot
.47142 .71277 Mdot
.65674 .64833 Mdot
.71752 .45488 Mdot
.4832 .29691 Mdot
.32408 .4015 Mdot
.61078 .67322 Mdot
.48953 .71653 Mdot
.61885 .31505 Mdot
.71274 .44064 Mdot
.57215 .68847 Mdot
.61001 .31876 Mdot
.66301 .3578 Mdot
.29627 .41096 Mdot
.51915 .3004 Mdot
.33667 .38425 Mdot
.71822 .5393 Mdot
.72231 .52368 Mdot
.64686 .34145 Mdot
.51194 .29356 Mdot
.71786 .53874 Mdot
.56832 .30046 Mdot
.61314 .31195 Mdot
.71871 .45208 Mdot
.69335 .43767 Mdot
.33686 .61838 Mdot
.58031 .68604 Mdot
.5646 .30926 Mdot
.61382 .67159 Mdot
.54435 .30209 Mdot
.44937 .70873 Mdot
.71812 .5358 Mdot
.48647 .71809 Mdot
.53497 .70719 Mdot
.30124 .60339 Mdot
.48977 .71097 Mdot
.28221 .53689 Mdot
.6312 .33648 Mdot
.44817 .71201 Mdot
.69567 .57134 Mdot
.64402 .65604 Mdot
.47354 .70374 Mdot
.62335 .31475 Mdot
.50701 .7093 Mdot
.32347 .39764 Mdot
.7223 .52991 Mdot
.60989 .67307 Mdot
.51815 .28769 Mdot
.41897 .30722 Mdot
.66894 .38667 Mdot
.32655 .62851 Mdot
.62976 .32214 Mdot
.47812 .70234 Mdot
.31169 .39685 Mdot
.31729 .59506 Mdot
.3954 .67664 Mdot
.6082 .32954 Mdot
.41961 .68965 Mdot
.40559 .2992 Mdot
.29287 .43236 Mdot
.71258 .49115 Mdot
.36779 .33114 Mdot
.31637 .37543 Mdot
.55981 .28902 Mdot
.39754 .69285 Mdot
.54563 .69943 Mdot
.675 .37958 Mdot
.66265 .34555 Mdot
.6937 .58247 Mdot
.29981 .41291 Mdot
.34063 .64228 Mdot
.69952 .51895 Mdot
.34472 .62743 Mdot
.35483 .65306 Mdot
.55785 .3044 Mdot
.3081 .39943 Mdot
.29364 .54201 Mdot
.36214 .66116 Mdot
.29462 .41271 Mdot
.28836 .522 Mdot
.28736 .50013 Mdot
.69111 .39211 Mdot
.66719 .64907 Mdot
.67972 .37477 Mdot
.46545 .27957 Mdot
.2962 .458 Mdot
.698 .40606 Mdot
.70803 .4403 Mdot
.29753 .55001 Mdot
.32948 .38739 Mdot
.66825 .37367 Mdot
.66741 .6374 Mdot
.32178 .63364 Mdot
.58024 .70711 Mdot
.45572 .71934 Mdot
.45193 .69729 Mdot
.31185 .43032 Mdot
.50786 .28017 Mdot
.35579 .35221 Mdot
.5631 .30648 Mdot
.61288 .69224 Mdot
.55947 .71617 Mdot
.47601 .71118 Mdot
.66958 .61981 Mdot
.64742 .34381 Mdot
.67539 .38356 Mdot
.31667 .38575 Mdot
.3476 .35924 Mdot
.71097 .54334 Mdot
.63851 .33886 Mdot
.32702 .61709 Mdot
.69287 .58036 Mdot
.51351 .71051 Mdot
.62914 .33473 Mdot
.71991 .46062 Mdot
.50973 .29812 Mdot
.6677 .62411 Mdot
.62835 .32553 Mdot
.28308 .48266 Mdot
.52326 .70783 Mdot
.29929 .52478 Mdot
.34903 .66228 Mdot
.69446 .59932 Mdot
.42616 .69948 Mdot
.60597 .32171 Mdot
.30663 .56167 Mdot
.63678 .34197 Mdot
.42983 .31181 Mdot
.51529 .30021 Mdot
.61461 .32492 Mdot
.50071 .70776 Mdot
.34579 .37245 Mdot
.52448 .29594 Mdot
.51185 .70314 Mdot
.4267 .3009 Mdot
.69765 .41344 Mdot
.62903 .34101 Mdot
.28833 .5221 Mdot
.72064 .493 Mdot
.55303 .29477 Mdot
.52377 .71909 Mdot
.69199 .43493 Mdot
.71146 .47779 Mdot
.3936 .6724 Mdot
.54602 .70192 Mdot
.68353 .62861 Mdot
.28188 .47177 Mdot
.60832 .67795 Mdot
.38697 .31689 Mdot
.40553 .30075 Mdot
.39072 .30972 Mdot
.66009 .36636 Mdot
.29481 .58998 Mdot
.69199 .42579 Mdot
.29856 .56422 Mdot
.33808 .37716 Mdot
.51726 .7036 Mdot
.29601 .49229 Mdot
.45568 .29535 Mdot
.37815 .68414 Mdot
.70668 .57305 Mdot
.39642 .32857 Mdot
.32949 .64647 Mdot
.53284 .28575 Mdot
.69198 .44136 Mdot
.60497 .31705 Mdot
.28571 .49739 Mdot
.52653 .70598 Mdot
.47972 .70899 Mdot
.4664 .29925 Mdot
.30898 .43881 Mdot
.34806 .64167 Mdot
.29373 .50613 Mdot
.45738 .29698 Mdot
.66063 .62989 Mdot
.70194 .42422 Mdot
.61527 .67054 Mdot
.65782 .63048 Mdot
.37656 .32209 Mdot
.66222 .34831 Mdot
.34245 .6336 Mdot
.62086 .68208 Mdot
.60897 .3252 Mdot
.5345 .29204 Mdot
.37555 .687 Mdot
.6895 .57379 Mdot
.52021 .71711 Mdot
.65843 .64187 Mdot
.68606 .60202 Mdot
.70773 .5082 Mdot
.30255 .59849 Mdot
.64818 .64994 Mdot
.70792 .55102 Mdot
.71321 .45823 Mdot
.56483 .69774 Mdot
.57232 .69338 Mdot
.62893 .33618 Mdot
.63532 .65145 Mdot
.34379 .35165 Mdot
.7141 .52393 Mdot
.3035 .44814 Mdot
.707 .5149 Mdot
.65596 .63698 Mdot
.66678 .35388 Mdot
.69379 .60091 Mdot
.67683 .39733 Mdot
.65047 .35295 Mdot
.46268 .28012 Mdot
.70021 .5262 Mdot
.31379 .38299 Mdot
.32904 .62451 Mdot
.31584 .4111 Mdot
.63149 .33849 Mdot
.29371 .41811 Mdot
.49249 .29945 Mdot
.40872 .3218 Mdot
.39749 .31993 Mdot
.51161 .27957 Mdot
.55625 .28544 Mdot
.71731 .54877 Mdot
.52769 .28186 Mdot
.30883 .56768 Mdot
.35708 .65166 Mdot
.65717 .34137 Mdot
.3004 .48552 Mdot
.42106 .68523 Mdot
.5246 .27692 Mdot
.37127 .34546 Mdot
.67587 .62751 Mdot
.65069 .36043 Mdot
.42009 .70543 Mdot
.61777 .32894 Mdot
.30544 .45141 Mdot
.33416 .62031 Mdot
.6062 .68941 Mdot
.29614 .46659 Mdot
.38045 .31888 Mdot
.54887 .69933 Mdot
.66736 .36095 Mdot
.31659 .41048 Mdot
.5496 .30589 Mdot
.41919 .29141 Mdot
.29657 .52469 Mdot
.62167 .3215 Mdot
.69089 .42695 Mdot
.3013 .57139 Mdot
.53078 .29 Mdot
.67879 .40061 Mdot
.66426 .64669 Mdot
.44083 .28362 Mdot
.53 .70041 Mdot
.64538 .66542 Mdot
.31358 .57855 Mdot
.29201 .57625 Mdot
.71383 .43898 Mdot
.33288 .38041 Mdot
.71714 .51905 Mdot
.62472 .68046 Mdot
.51193 .70538 Mdot
.52089 .71379 Mdot
.64908 .64861 Mdot
.2876 .46364 Mdot
.66692 .37614 Mdot
.32876 .63855 Mdot
.30031 .54879 Mdot
.71175 .42774 Mdot
.29195 .49201 Mdot
.37305 .67752 Mdot
.28503 .51057 Mdot
.57576 .71067 Mdot
.49814 .70949 Mdot
.70268 .44872 Mdot
.65672 .66003 Mdot
.30019 .58859 Mdot
.52942 .71412 Mdot
.71563 .55804 Mdot
.52166 .29055 Mdot
.68638 .62527 Mdot
.48692 .70194 Mdot
.494 .29376 Mdot
.52409 .28923 Mdot
.30283 .43551 Mdot
.29847 .47878 Mdot
.31121 .3806 Mdot
.34306 .62978 Mdot
.61387 .67024 Mdot
.61187 .68068 Mdot
.65547 .63591 Mdot
.34015 .6234 Mdot
.70528 .52613 Mdot
.64844 .66853 Mdot
.4689 .69819 Mdot
.35756 .65761 Mdot
.46514 .28463 Mdot
.6236 .33048 Mdot
.64565 .6646 Mdot
.30025 .55098 Mdot
.71303 .47109 Mdot
.43445 .70858 Mdot
.63708 .34293 Mdot
.67775 .37607 Mdot
.61229 .33264 Mdot
.52453 .28428 Mdot
.31781 .41527 Mdot
.33362 .6192 Mdot
.61658 .32804 Mdot
.29123 .43101 Mdot
.44718 .29369 Mdot
.68005 .61516 Mdot
.47425 .27851 Mdot
.55754 .28756 Mdot
.64424 .34123 Mdot
.65591 .36937 Mdot
.71069 .53109 Mdot
.65313 .64558 Mdot
.29674 .56039 Mdot
.46118 .29706 Mdot
.34195 .37056 Mdot
.60302 .68499 Mdot
.67429 .37186 Mdot
.69639 .60567 Mdot
.60815 .68968 Mdot
.45391 .69762 Mdot
.43683 .69379 Mdot
.32048 .63485 Mdot
.46378 .7128 Mdot
.46468 .71029 Mdot
.59001 .31714 Mdot
.30629 .4281 Mdot
.55093 .71867 Mdot
.33286 .64287 Mdot
.41794 .69134 Mdot
.41979 .70687 Mdot
.62959 .67137 Mdot
.71678 .53071 Mdot
.62058 .32682 Mdot
.34478 .34491 Mdot
.30077 .4063 Mdot
.38044 .66799 Mdot
.49615 .28369 Mdot
.55842 .28316 Mdot
.28798 .45459 Mdot
.33111 .61564 Mdot
.54025 .70471 Mdot
.67145 .61744 Mdot
.69668 .59581 Mdot
.69166 .59491 Mdot
.53205 .70526 Mdot
.29206 .5701 Mdot
.38093 .32389 Mdot
.67268 .62513 Mdot
.68546 .37937 Mdot
.42394 .69969 Mdot
.35579 .64487 Mdot
.67171 .38087 Mdot
.62348 .68302 Mdot
.57157 .31199 Mdot
.67491 .60106 Mdot
.47963 .28868 Mdot
.63767 .32935 Mdot
.45053 .71217 Mdot
.56057 .6976 Mdot
.57931 .68862 Mdot
.442 .70228 Mdot
.65623 .35094 Mdot
.68042 .40052 Mdot
.70445 .46797 Mdot
.51882 .2906 Mdot
.60209 .67866 Mdot
.41238 .31109 Mdot
.30079 .58968 Mdot
.59455 .30804 Mdot
.62173 .65944 Mdot
.34904 .35792 Mdot
.71389 .44446 Mdot
.39835 .69722 Mdot
.67918 .59972 Mdot
.32076 .62028 Mdot
.67581 .63737 Mdot
.37061 .34021 Mdot
.70116 .41769 Mdot
.71566 .44577 Mdot
.27625 .49225 Mdot
.63489 .65884 Mdot
.35844 .67268 Mdot
.30017 .47759 Mdot
.33654 .61919 Mdot
.57274 .69081 Mdot
.40677 .70174 Mdot
.54798 .29211 Mdot
.55117 .7182 Mdot
.62791 .66369 Mdot
.46745 .7042 Mdot
.58519 .69235 Mdot
.5256 .2937 Mdot
.69372 .55719 Mdot
.32278 .61191 Mdot
.30218 .46494 Mdot
.70684 .51383 Mdot
.38609 .6902 Mdot
.42479 .30387 Mdot
.30176 .43589 Mdot
.29101 .52856 Mdot
.33384 .6124 Mdot
.55914 .69541 Mdot
.53807 .71184 Mdot
.29771 .58968 Mdot
.59561 .69062 Mdot
.70943 .53078 Mdot
.37314 .32971 Mdot
.70373 .51617 Mdot
.41783 .69938 Mdot
.40553 .69793 Mdot
.51619 .29334 Mdot
.6144 .32583 Mdot
.37118 .66163 Mdot
.3691 .34325 Mdot
.64274 .66271 Mdot
.55716 .69993 Mdot
.69661 .4487 Mdot
.59112 .70164 Mdot
.41892 .70004 Mdot
.60467 .68997 Mdot
.7002 .49883 Mdot
.62966 .31909 Mdot
.51828 .71713 Mdot
.71402 .50872 Mdot
.65355 .35496 Mdot
.35896 .65556 Mdot
.49191 .28038 Mdot
.6066 .67162 Mdot
.54693 .28858 Mdot
.70399 .47304 Mdot
.30206 .5333 Mdot
.57778 .30078 Mdot
.30206 .53211 Mdot
.70959 .44656 Mdot
.51593 .70701 Mdot
.69363 .44214 Mdot
.36076 .67214 Mdot
.31422 .38765 Mdot
.348 .36751 Mdot
.30835 .59761 Mdot
.60044 .3155 Mdot
.30264 .56974 Mdot
.37079 .66472 Mdot
.35599 .33309 Mdot
.65353 .35845 Mdot
.40895 .31727 Mdot
.37537 .34205 Mdot
.46544 .30091 Mdot
.45478 .69974 Mdot
.63778 .65842 Mdot
.40362 .32116 Mdot
.44673 .28668 Mdot
.61915 .31734 Mdot
.48004 .70961 Mdot
.29205 .51817 Mdot
.35119 .34467 Mdot
.32199 .36251 Mdot
.70142 .43732 Mdot
.71703 .44572 Mdot
.52704 .70713 Mdot
.4013 .30459 Mdot
.68657 .62384 Mdot
.71569 .50573 Mdot
.34932 .63761 Mdot
.61667 .68967 Mdot
.66198 .64665 Mdot
.4042 .30871 Mdot
.29711 .51444 Mdot
.69282 .59286 Mdot
.28831 .45029 Mdot
.66551 .6377 Mdot
.42644 .69516 Mdot
.29689 .58807 Mdot
.54688 .70432 Mdot
.31359 .58677 Mdot
.60117 .32105 Mdot
.47598 .70655 Mdot
.45347 .29311 Mdot
.31682 .37996 Mdot
.53122 .70631 Mdot
.29677 .47317 Mdot
.41964 .29928 Mdot
.3184 .61453 Mdot
.34683 .64021 Mdot
.71575 .46661 Mdot
.60999 .69401 Mdot
.29571 .44078 Mdot
.3881 .68646 Mdot
.46609 .70193 Mdot
.35137 .35824 Mdot
.41527 .30703 Mdot
.32468 .63575 Mdot
.60667 .67595 Mdot
.44358 .30237 Mdot
.50382 .28397 Mdot
.40042 .69939 Mdot
.53795 .2805 Mdot
.62545 .6866 Mdot
.52326 .70876 Mdot
.58804 .31222 Mdot
.69745 .44379 Mdot
.56418 .69153 Mdot
.47015 .7175 Mdot
.56759 .30618 Mdot
.66604 .63465 Mdot
.68374 .62941 Mdot
.3628 .67543 Mdot
.53025 .30041 Mdot
.30178 .39363 Mdot
.35113 .36344 Mdot
.37804 .67695 Mdot
.56572 .29044 Mdot
.33833 .63343 Mdot
.3238 .37227 Mdot
.65819 .64572 Mdot
.56107 .29661 Mdot
.7009 .51268 Mdot
.43273 .29831 Mdot
.38493 .33206 Mdot
.68767 .40412 Mdot
.68084 .59359 Mdot
.42722 .69562 Mdot
.47316 .28798 Mdot
.2862 .48881 Mdot
.39088 .67247 Mdot
.68586 .37956 Mdot
.53838 .71055 Mdot
.65938 .63538 Mdot
.55125 .70645 Mdot
.31056 .61478 Mdot
.30407 .42684 Mdot
.2898 .51525 Mdot
.29596 .52464 Mdot
.58396 .68376 Mdot
.50124 .28319 Mdot
.40151 .31121 Mdot
.31959 .6127 Mdot
.52034 .28449 Mdot
.58257 .70791 Mdot
.38121 .33005 Mdot
.70907 .47166 Mdot
.51376 .7104 Mdot
.3221 .59536 Mdot
.50142 .29991 Mdot
.70619 .41958 Mdot
.29778 .40586 Mdot
.5754 .6901 Mdot
.66674 .37213 Mdot
.53897 .28675 Mdot
.64878 .66024 Mdot
.31509 .38438 Mdot
.29071 .52913 Mdot
.34074 .36761 Mdot
.51462 .69992 Mdot
.57712 .69021 Mdot
.30029 .51603 Mdot
.50278 .70891 Mdot
.67598 .40023 Mdot
.69101 .57283 Mdot
.71509 .52998 Mdot
.46119 .70906 Mdot
.67323 .35877 Mdot
.41953 .29573 Mdot
.31862 .61014 Mdot
.68624 .60223 Mdot
.59641 .68853 Mdot
.66064 .36913 Mdot
.41911 .30469 Mdot
.36129 .32504 Mdot
.52568 .29248 Mdot
.31186 .3882 Mdot
.49667 .28309 Mdot
.42878 .69353 Mdot
.63541 .32861 Mdot
.34198 .35918 Mdot
.30674 .57196 Mdot
.28149 .44978 Mdot
.47454 .71799 Mdot
.36674 .32874 Mdot
.31829 .39862 Mdot
.71872 .50199 Mdot
.58428 .29248 Mdot
.30564 .61312 Mdot
.69061 .58084 Mdot
.6685 .63937 Mdot
.55647 .70602 Mdot
.29314 .50763 Mdot
.51842 .29342 Mdot
.70066 .44602 Mdot
.28715 .50583 Mdot
.41627 .69889 Mdot
.67609 .39533 Mdot
.4157 .70544 Mdot
.66406 .62438 Mdot
.67629 .36478 Mdot
.71701 .55485 Mdot
.54549 .30163 Mdot
.60355 .31707 Mdot
.44256 .71394 Mdot
.68467 .58383 Mdot
.39287 .68493 Mdot
.30685 .40585 Mdot
.72115 .52815 Mdot
.38474 .32444 Mdot
.44782 .30603 Mdot
.30762 .4317 Mdot
.57773 .31172 Mdot
.29559 .48081 Mdot
.69742 .5331 Mdot
.40995 .29916 Mdot
.48044 .29728 Mdot
.33708 .3562 Mdot
.32522 .6251 Mdot
.69512 .55392 Mdot
.3409 .64757 Mdot
.33658 .64339 Mdot
.39923 .3088 Mdot
.60401 .31381 Mdot
.63592 .33673 Mdot
.416 .69024 Mdot
.60696 .31665 Mdot
.3575 .34188 Mdot
.66926 .62194 Mdot
.71912 .52512 Mdot
.43012 .29279 Mdot
.71549 .46623 Mdot
.41729 .68394 Mdot
.33045 .39257 Mdot
.37039 .33408 Mdot
.51175 .28788 Mdot
.54725 .28196 Mdot
.30865 .57213 Mdot
.70048 .43474 Mdot
.57895 .29826 Mdot
.61943 .33682 Mdot
.55659 .28628 Mdot
.6201 .67048 Mdot
.5817 .31421 Mdot
.60537 .32199 Mdot
.53032 .69996 Mdot
.58068 .70609 Mdot
.28974 .5439 Mdot
.31409 .62355 Mdot
.7078 .53239 Mdot
.29541 .55703 Mdot
.54737 .71348 Mdot
.33489 .36996 Mdot
.30228 .60223 Mdot
.30678 .55764 Mdot
.32912 .36202 Mdot
.33866 .35077 Mdot
.33961 .64675 Mdot
.29891 .59745 Mdot
.67427 .39668 Mdot
.69841 .52701 Mdot
.66761 .36172 Mdot
.30455 .41571 Mdot
.39844 .30078 Mdot
.69587 .4479 Mdot
.49885 .70102 Mdot
.29905 .49398 Mdot
.37126 .33868 Mdot
.65556 .36454 Mdot
.48558 .71352 Mdot
.29945 .55447 Mdot
.38017 .67417 Mdot
.30885 .58094 Mdot
.28931 .56021 Mdot
.65187 .3412 Mdot
.54232 .2836 Mdot
.6853 .38697 Mdot
.28437 .45912 Mdot
.31904 .61795 Mdot
.66161 .36113 Mdot
.29228 .47098 Mdot
.34284 .34028 Mdot
.68566 .57938 Mdot
.45966 .70881 Mdot
.3479 .34196 Mdot
.59882 .30507 Mdot
.50931 .27558 Mdot
.7146 .5608 Mdot
.61534 .32743 Mdot
.29723 .48196 Mdot
.30087 .58512 Mdot
.34965 .34563 Mdot
.67711 .39318 Mdot
.71641 .50111 Mdot
.61973 .33371 Mdot
.46237 .29976 Mdot
.53781 .70714 Mdot
.6667 .37197 Mdot
.29423 .54644 Mdot
.62665 .32982 Mdot
.35253 .35994 Mdot
.3908 .67769 Mdot
.58389 .6945 Mdot
.44657 .28858 Mdot
.47231 .70311 Mdot
.4496 .30474 Mdot
.32332 .5939 Mdot
.72241 .4851 Mdot
.56503 .70442 Mdot
.67699 .618 Mdot
.48251 .29718 Mdot
.51037 .70032 Mdot
.64982 .63278 Mdot
.67877 .37696 Mdot
.69319 .40943 Mdot
.57791 .70996 Mdot
.38687 .32501 Mdot
.27888 .52278 Mdot
.51777 .70753 Mdot
.27576 .50803 Mdot
.71338 .5483 Mdot
.32821 .62364 Mdot
.43464 .70504 Mdot
.61427 .67747 Mdot
.587 .69663 Mdot
.49327 .71895 Mdot
.4956 .70161 Mdot
.7039 .58287 Mdot
.31932 .37752 Mdot
.30328 .3954 Mdot
.36778 .66313 Mdot
.69339 .61189 Mdot
.4043 .69388 Mdot
.41317 .30685 Mdot
.69876 .53002 Mdot
.30155 .47009 Mdot
.61324 .32197 Mdot
.47549 .70518 Mdot
.32096 .39153 Mdot
.55584 .70403 Mdot
.71577 .48898 Mdot
.3534 .34447 Mdot
.36225 .34674 Mdot
.29371 .43834 Mdot
.42028 .69951 Mdot
.63312 .34603 Mdot
.45121 .7082 Mdot
.39168 .67151 Mdot
.30851 .56694 Mdot
.69972 .59511 Mdot
.63906 .33144 Mdot
.63692 .34121 Mdot
.63664 .3506 Mdot
.52279 .71976 Mdot
.52163 .72034 Mdot
.4211 .31011 Mdot
.6834 .40499 Mdot
.59046 .31928 Mdot
.35839 .33464 Mdot
.27686 .52221 Mdot
.57807 .70017 Mdot
.32624 .60502 Mdot
.39211 .69327 Mdot
.29242 .43223 Mdot
.28696 .55026 Mdot
.40953 .70319 Mdot
.52969 .7205 Mdot
.35095 .34258 Mdot
.42714 .70328 Mdot
.57334 .29821 Mdot
.38938 .3061 Mdot
.4067 .69421 Mdot
.29385 .53044 Mdot
.67777 .38371 Mdot
.62928 .66806 Mdot
.36295 .67089 Mdot
.41024 .30117 Mdot
.71436 .55634 Mdot
.28857 .56314 Mdot
.32598 .60806 Mdot
.62133 .66489 Mdot
.3309 .36699 Mdot
.29491 .52388 Mdot
.45126 .71933 Mdot
.72299 .50685 Mdot
.34804 .64819 Mdot
.63376 .33674 Mdot
.71657 .52656 Mdot
.59681 .69523 Mdot
.71954 .47018 Mdot
.46237 .28096 Mdot
.30218 .4115 Mdot
.30548 .4026 Mdot
.69551 .45095 Mdot
.67653 .61569 Mdot
.40956 .3195 Mdot
.68162 .61121 Mdot
.43486 .70451 Mdot
.52757 .70002 Mdot
.45897 .71761 Mdot
.69816 .56641 Mdot
.42897 .71337 Mdot
.39969 .68648 Mdot
.47936 .29286 Mdot
.50642 .28089 Mdot
.53016 .29562 Mdot
.39106 .32264 Mdot
.66767 .61743 Mdot
.30375 .40018 Mdot
.56409 .29471 Mdot
.3754 .67921 Mdot
.28285 .47464 Mdot
.44132 .70088 Mdot
.54455 .71416 Mdot
.71767 .45376 Mdot
.2906 .52223 Mdot
.54806 .69756 Mdot
.44908 .30248 Mdot
.29046 .43237 Mdot
.32956 .35423 Mdot
.6975 .46846 Mdot
.58242 .30771 Mdot
.3567 .351 Mdot
.43863 .70666 Mdot
.38933 .69298 Mdot
.69534 .60514 Mdot
.35 .66761 Mdot
.32558 .38079 Mdot
.62552 .68263 Mdot
.65598 .36347 Mdot
.34043 .37707 Mdot
.47009 .70586 Mdot
.36182 .35345 Mdot
.28375 .55768 Mdot
.71968 .50217 Mdot
.60871 .6776 Mdot
.39135 .30614 Mdot
.68263 .60645 Mdot
.42798 .71031 Mdot
.30039 .51435 Mdot
.61964 .66113 Mdot
.32622 .36865 Mdot
.2842 .43896 Mdot
.39887 .68383 Mdot
.69123 .3856 Mdot
.64591 .34758 Mdot
.67329 .394 Mdot
.44828 .30393 Mdot
.50785 .70576 Mdot
.34696 .34703 Mdot
.69463 .42493 Mdot
.6416 .66346 Mdot
.55558 .29965 Mdot
.28146 .45349 Mdot
.50106 .70865 Mdot
.56175 .7045 Mdot
.39269 .68146 Mdot
.40039 .67644 Mdot
.31655 .59733 Mdot
.33887 .34318 Mdot
.58769 .68171 Mdot
.70844 .49723 Mdot
.51777 .71743 Mdot
.64002 .33395 Mdot
.30266 .57251 Mdot
.39687 .69294 Mdot
.56857 .68957 Mdot
.64525 .64488 Mdot
.6373 .33355 Mdot
.55406 .30481 Mdot
.30779 .57975 Mdot
.59747 .67772 Mdot
.48838 .70601 Mdot
.60286 .6936 Mdot
.71116 .5293 Mdot
.42471 .68748 Mdot
.32094 .40449 Mdot
.70702 .47734 Mdot
.35046 .63483 Mdot
.62733 .34178 Mdot
.2917 .46908 Mdot
.68414 .57948 Mdot
.6736 .60422 Mdot
.67583 .36307 Mdot
.60296 .30429 Mdot
.46488 .29942 Mdot
.57061 .30439 Mdot
.32868 .60626 Mdot
.52934 .70291 Mdot
.30303 .59422 Mdot
.61333 .33078 Mdot
.3059 .40696 Mdot
.40657 .69706 Mdot
.28548 .49152 Mdot
.52108 .71458 Mdot
.33433 .36012 Mdot
.31669 .62068 Mdot
.66357 .36326 Mdot
.33063 .37332 Mdot
.29051 .52976 Mdot
.35394 .64595 Mdot
.70817 .56555 Mdot
.30106 .46057 Mdot
.29904 .52872 Mdot
.55129 .70335 Mdot
.70981 .4615 Mdot
.71668 .46744 Mdot
.35934 .67108 Mdot
.29609 .40573 Mdot
.29533 .5386 Mdot
.7085 .45575 Mdot
.72146 .48996 Mdot
.32667 .38745 Mdot
.69108 .43018 Mdot
.68929 .57565 Mdot
.3039 .54147 Mdot
.62862 .32259 Mdot
.28795 .50571 Mdot
.64016 .35731 Mdot
.64139 .66283 Mdot
.43253 .68867 Mdot
.39542 .32094 Mdot
.38861 .68064 Mdot
.40209 .31345 Mdot
.49521 .2945 Mdot
.47252 .29458 Mdot
.42079 .3145 Mdot
.48442 .70622 Mdot
.60671 .32195 Mdot
.52244 .28147 Mdot
.70178 .45136 Mdot
.36041 .3512 Mdot
.38646 .32668 Mdot
.71608 .45058 Mdot
.40665 .69918 Mdot
.44607 .70397 Mdot
.30802 .4045 Mdot
.31168 .42227 Mdot
.66192 .36205 Mdot
.43102 .71093 Mdot
.69438 .56554 Mdot
.30236 .4571 Mdot
.68837 .61855 Mdot
.68377 .37331 Mdot
.30415 .58961 Mdot
.68727 .42548 Mdot
.66809 .64256 Mdot
.37175 .32673 Mdot
.30001 .45068 Mdot
.68145 .6093 Mdot
.37258 .32278 Mdot
.54818 .29056 Mdot
.32681 .37577 Mdot
.49737 .71265 Mdot
.28483 .48697 Mdot
.37611 .67504 Mdot
.67667 .59415 Mdot
.32147 .61599 Mdot
.70013 .45655 Mdot
.51356 .27808 Mdot
.29902 .59847 Mdot
.40258 .31339 Mdot
.53433 .29736 Mdot
.66769 .35667 Mdot
.59542 .69533 Mdot
.36295 .34362 Mdot
.40061 .32434 Mdot
.44908 .71247 Mdot
.32984 .39182 Mdot
.6491 .35846 Mdot
.34229 .34397 Mdot
.65232 .642 Mdot
.57337 .71063 Mdot
.28996 .57414 Mdot
.30943 .60485 Mdot
.31138 .4273 Mdot
.50972 .69988 Mdot
.6941 .39813 Mdot
.30055 .39961 Mdot
.36787 .3489 Mdot
.72055 .47787 Mdot
.509 .28004 Mdot
.35677 .67327 Mdot
.36197 .33923 Mdot
.60457 .67255 Mdot
.57746 .69965 Mdot
.49124 .29093 Mdot
.35736 .34315 Mdot
.29087 .49859 Mdot
.44512 .28923 Mdot
.68897 .40648 Mdot
.69414 .59711 Mdot
.7005 .42463 Mdot
.40891 .70237 Mdot
.314 .39339 Mdot
.41084 .30983 Mdot
.31396 .60295 Mdot
.27964 .51508 Mdot
.40906 .31809 Mdot
.62965 .33624 Mdot
.59936 .69543 Mdot
.63015 .67248 Mdot
.50225 .70838 Mdot
.70066 .59955 Mdot
.42509 .706 Mdot
.5076 .29807 Mdot
.46501 .29821 Mdot
.69291 .59946 Mdot
.42885 .7052 Mdot
.3108 .38547 Mdot
.35063 .34702 Mdot
.47346 .28937 Mdot
.29044 .56554 Mdot
.30813 .38987 Mdot
.56086 .70223 Mdot
.27818 .48656 Mdot
.67391 .37023 Mdot
.50505 .2799 Mdot
.59598 .68924 Mdot
.41108 .31738 Mdot
.65278 .3417 Mdot
.67386 .61226 Mdot
.50612 .7061 Mdot
.35872 .66819 Mdot
.55715 .29624 Mdot
.53947 .28009 Mdot
.3308 .39256 Mdot
.47651 .69982 Mdot
.4258 .30521 Mdot
.29487 .48064 Mdot
.27997 .47672 Mdot
.60558 .32671 Mdot
.37624 .34129 Mdot
.49423 .27911 Mdot
.32252 .63011 Mdot
.34929 .63346 Mdot
.33594 .37141 Mdot
.34078 .37426 Mdot
.707 .52056 Mdot
.39434 .67179 Mdot
.3997 .70093 Mdot
.59742 .30203 Mdot
.57116 .30954 Mdot
.71685 .48045 Mdot
.60578 .67216 Mdot
.51414 .72131 Mdot
.51688 .2937 Mdot
.63533 .32598 Mdot
.62309 .6866 Mdot
.50163 .71755 Mdot
.63588 .6673 Mdot
.68303 .38553 Mdot
.58918 .30332 Mdot
.68722 .61597 Mdot
.71214 .51448 Mdot
.66188 .62166 Mdot
.6222 .32851 Mdot
.63385 .34374 Mdot
.67488 .60423 Mdot
.71006 .50995 Mdot
.68461 .41077 Mdot
.51193 .28259 Mdot
.54931 .29122 Mdot
.61625 .33497 Mdot
.71939 .45695 Mdot
.51221 .29372 Mdot
.70375 .44538 Mdot
.38721 .32985 Mdot
.65456 .62751 Mdot
.56111 .28513 Mdot
.71921 .53365 Mdot
.54854 .29251 Mdot
.67856 .62283 Mdot
.71699 .53836 Mdot
.42676 .68848 Mdot
.59281 .6978 Mdot
.39107 .67205 Mdot
.31386 .60116 Mdot
.3399 .6475 Mdot
.51816 .29308 Mdot
.47042 .7153 Mdot
.70557 .46056 Mdot
.50348 .72052 Mdot
.59007 .70206 Mdot
.61815 .66608 Mdot
.61248 .66643 Mdot
.6108 .33156 Mdot
.70488 .46786 Mdot
.27705 .49611 Mdot
.29226 .42599 Mdot
.64853 .64171 Mdot
.55362 .29405 Mdot
.62467 .32734 Mdot
.58745 .31626 Mdot
.32576 .36996 Mdot
.36533 .34245 Mdot
.29667 .56543 Mdot
.29492 .52326 Mdot
.33485 .3671 Mdot
.27619 .49045 Mdot
.66904 .63124 Mdot
.69442 .43995 Mdot
.70763 .4788 Mdot
.61351 .68338 Mdot
.64673 .66492 Mdot
.3851 .67836 Mdot
.30083 .4591 Mdot
.44116 .30372 Mdot
.68699 .60555 Mdot
.53965 .71997 Mdot
.29997 .53304 Mdot
.4508 .28096 Mdot
.35479 .65684 Mdot
.51736 .27966 Mdot
.34615 .63552 Mdot
.33442 .37853 Mdot
.49896 .70928 Mdot
.48679 .71779 Mdot
.45957 .29805 Mdot
.29979 .42649 Mdot
.35881 .33623 Mdot
.39139 .68529 Mdot
.61118 .68225 Mdot
.34266 .35309 Mdot
.56127 .28376 Mdot
.63658 .32849 Mdot
.31532 .61904 Mdot
.49153 .71372 Mdot
.61489 .67632 Mdot
.72065 .49537 Mdot
.31009 .57583 Mdot
.30683 .57556 Mdot
.56943 .29836 Mdot
.6709 .63478 Mdot
.35667 .32685 Mdot
.29832 .51685 Mdot
.61348 .33528 Mdot
.35723 .34855 Mdot
.31051 .57901 Mdot
.34654 .65659 Mdot
.4601 .71621 Mdot
.34022 .65634 Mdot
.61483 .3178 Mdot
.69892 .41551 Mdot
.69675 .54623 Mdot
.60741 .30403 Mdot
.33875 .62222 Mdot
.37796 .68436 Mdot
.3079 .43656 Mdot
.45141 .29266 Mdot
.66778 .64538 Mdot
.38284 .68468 Mdot
.60246 .32574 Mdot
.71431 .4496 Mdot
.71167 .49347 Mdot
.70107 .53466 Mdot
.70253 .44577 Mdot
.56674 .69443 Mdot
.308 .42176 Mdot
.62767 .33393 Mdot
.70454 .51393 Mdot
.64018 .67152 Mdot
.6661 .37478 Mdot
.56385 .3075 Mdot
.69015 .57889 Mdot
.60875 .32311 Mdot
.69968 .59016 Mdot
.57563 .31095 Mdot
.66209 .63262 Mdot
.33102 .3544 Mdot
.30685 .44051 Mdot
.51191 .28675 Mdot
.2838 .44919 Mdot
.33985 .35348 Mdot
.36308 .33544 Mdot
.58751 .30443 Mdot
.31566 .4032 Mdot
.70485 .47311 Mdot
.28626 .48728 Mdot
.59929 .67706 Mdot
.33417 .61998 Mdot
.30738 .43001 Mdot
.6219 .33821 Mdot
.56244 .29284 Mdot
.41717 .68805 Mdot
.59721 .70214 Mdot
.40354 .30627 Mdot
.3644 .6604 Mdot
.66881 .62186 Mdot
.34956 .63694 Mdot
.31506 .38254 Mdot
.54519 .69528 Mdot
.57926 .69922 Mdot
.37991 .31508 Mdot
.38992 .68098 Mdot
.63184 .34415 Mdot
.70456 .52707 Mdot
.4164 .313 Mdot
.37979 .67817 Mdot
.40468 .69805 Mdot
.50656 .70663 Mdot
.70063 .41899 Mdot
.38036 .3242 Mdot
.46638 .28671 Mdot
.28209 .54848 Mdot
.70131 .5898 Mdot
.64646 .65245 Mdot
.5603 .70772 Mdot
.66024 .62796 Mdot
.29054 .47094 Mdot
.51726 .28557 Mdot
.56624 .70629 Mdot
.29292 .4767 Mdot
.48538 .69977 Mdot
.64382 .33254 Mdot
.29611 .45239 Mdot
.32183 .63329 Mdot
.28991 .54044 Mdot
.47408 .7095 Mdot
.47946 .7217 Mdot
.60783 .67557 Mdot
.4904 .28904 Mdot
.32567 .6274 Mdot
.28816 .44247 Mdot
.65281 .35958 Mdot
.45814 .71517 Mdot
.71031 .52494 Mdot
.49218 .29031 Mdot
.34472 .35233 Mdot
.46636 .71831 Mdot
.37911 .66331 Mdot
.72283 .5135 Mdot
.58297 .70607 Mdot
.47756 .71087 Mdot
.55069 .3001 Mdot
.46551 .2852 Mdot
.6872 .37754 Mdot
.2903 .57686 Mdot
.66244 .36392 Mdot
.43404 .29693 Mdot
.47486 .7212 Mdot
.30567 .59796 Mdot
.68999 .39019 Mdot
.31043 .61042 Mdot
.4687 .27992 Mdot
.62272 .6671 Mdot
.69988 .41793 Mdot
.30893 .59808 Mdot
.71348 .54099 Mdot
.7148 .47346 Mdot
.6298 .65928 Mdot
.46145 .69923 Mdot
.64527 .35134 Mdot
.62861 .33362 Mdot
.70552 .44249 Mdot
.29991 .58115 Mdot
.52835 .71425 Mdot
.44876 .70221 Mdot
.44895 .69342 Mdot
.64469 .33584 Mdot
.48581 .70718 Mdot
.65144 .36572 Mdot
.64764 .63813 Mdot
.32188 .36339 Mdot
.50477 .71928 Mdot
.49918 .28583 Mdot
.44883 .69946 Mdot
.41688 .70721 Mdot
.69927 .58021 Mdot
.71276 .52853 Mdot
.5267 .2869 Mdot
.6227 .68361 Mdot
.29323 .48835 Mdot
.47032 .71642 Mdot
.34273 .63136 Mdot
.39159 .30975 Mdot
.63145 .66451 Mdot
.67832 .39928 Mdot
.62312 .33652 Mdot
.33878 .37091 Mdot
.55582 .29253 Mdot
.31419 .38815 Mdot
.69818 .52757 Mdot
.3 .59411 Mdot
.28274 .48216 Mdot
.61037 .6699 Mdot
.65181 .64953 Mdot
.29172 .51212 Mdot
.70108 .476 Mdot
.31699 .41024 Mdot
.65423 .66086 Mdot
.71698 .45167 Mdot
.39241 .67802 Mdot
.35125 .64167 Mdot
.418 .69106 Mdot
.69867 .43389 Mdot
.56831 .29623 Mdot
.55214 .29989 Mdot
.41141 .31864 Mdot
.43128 .71231 Mdot
.42613 .28818 Mdot
.46875 .28291 Mdot
.31676 .41623 Mdot
.5169 .27862 Mdot
.52503 .71704 Mdot
.33911 .64502 Mdot
.68271 .39533 Mdot
.31015 .58305 Mdot
.66485 .64667 Mdot
.37596 .34256 Mdot
.29756 .58305 Mdot
.38738 .66802 Mdot
.4882 .28083 Mdot
.34552 .36079 Mdot
.60116 .69311 Mdot
.62887 .33302 Mdot
.70951 .41929 Mdot
.28422 .53925 Mdot
.71147 .5325 Mdot
.7064 .54886 Mdot
.68325 .38135 Mdot
.33423 .63162 Mdot
.27935 .54135 Mdot
.69946 .56372 Mdot
.47312 .29676 Mdot
.31641 .58292 Mdot
.30093 .42709 Mdot
.30976 .39871 Mdot
.34009 .36009 Mdot
.6735 .63722 Mdot
.31137 .38008 Mdot
.68947 .58844 Mdot
.41446 .31345 Mdot
.40065 .30099 Mdot
.54984 .6996 Mdot
.35136 .3474 Mdot
.30056 .52267 Mdot
.57215 .6989 Mdot
.6911 .40431 Mdot
.33579 .35199 Mdot
.42391 .6863 Mdot
.2756 .48553 Mdot
.464 .30051 Mdot
.29902 .57849 Mdot
.7155 .55535 Mdot
.51978 .28256 Mdot
.60318 .30937 Mdot
.63349 .65598 Mdot
.37637 .67716 Mdot
.70471 .42298 Mdot
.32219 .59651 Mdot
.3977 .69776 Mdot
.65562 .62734 Mdot
.58942 .29594 Mdot
.3301 .645 Mdot
.35362 .6464 Mdot
.38446 .66431 Mdot
.33582 .36322 Mdot
.29232 .47564 Mdot
.29456 .53492 Mdot
.60312 .69215 Mdot
.28926 .45914 Mdot
.50102 .28425 Mdot
.5612 .7082 Mdot
.36483 .33321 Mdot
.33218 .64103 Mdot
.49449 .71625 Mdot
.71139 .51836 Mdot
.67934 .38059 Mdot
.31655 .62766 Mdot
.34273 .63359 Mdot
.69466 .40845 Mdot
.5448 .70852 Mdot
.33816 .61827 Mdot
.28267 .54777 Mdot
.57054 .69615 Mdot
.59314 .3142 Mdot
.57419 .29902 Mdot
.30404 .40793 Mdot
.55331 .30511 Mdot
.39591 .32798 Mdot
.34377 .63048 Mdot
.46499 .71691 Mdot
.29353 .55409 Mdot
.69234 .57497 Mdot
.6982 .57798 Mdot
.32617 .38411 Mdot
.63489 .34624 Mdot
.52473 .30045 Mdot
.70101 .57715 Mdot
.56511 .6992 Mdot
.47883 .71221 Mdot
.2969 .45282 Mdot
.64974 .35318 Mdot
.48542 .7133 Mdot
.3079 .60981 Mdot
.56195 .69788 Mdot
.36958 .6624 Mdot
.32617 .35961 Mdot
.29645 .50885 Mdot
.61737 .31114 Mdot
.30425 .58506 Mdot
.36311 .33709 Mdot
.5976 .67477 Mdot
.6634 .62261 Mdot
.44332 .70787 Mdot
.61728 .31922 Mdot
.655 .34502 Mdot
.36721 .33973 Mdot
.29034 .47709 Mdot
.70554 .54156 Mdot
.70477 .53143 Mdot
.57411 .69899 Mdot
.31494 .38341 Mdot
.28848 .42463 Mdot
.30812 .60464 Mdot
.28967 .56539 Mdot
.64072 .64644 Mdot
.34258 .36904 Mdot
.49585 .70886 Mdot
.71785 .45923 Mdot
.48018 .27789 Mdot
.69646 .4205 Mdot
.44843 .29042 Mdot
.49371 .2755 Mdot
.65986 .65419 Mdot
.5724 .68648 Mdot
.43903 .3058 Mdot
.4859 .29571 Mdot
.3205 .41078 Mdot
.63819 .64459 Mdot
.40748 .6958 Mdot
.61107 .67036 Mdot
.31147 .38943 Mdot
.54156 .71241 Mdot
.64137 .3547 Mdot
.2861 .53566 Mdot
.5009 .29438 Mdot
.45584 .71227 Mdot
.69253 .56137 Mdot
.29587 .44263 Mdot
.30072 .53066 Mdot
.31749 .60793 Mdot
.61759 .67408 Mdot
.49088 .70846 Mdot
.30469 .40655 Mdot
.71115 .55099 Mdot
.43165 .29743 Mdot
.31562 .42157 Mdot
.69694 .43258 Mdot
.45917 .70452 Mdot
.66549 .37719 Mdot
.48298 .27913 Mdot
.31919 .59545 Mdot
.40754 .68798 Mdot
.47627 .7181 Mdot
.68392 .58068 Mdot
.43275 .3086 Mdot
.70538 .53662 Mdot
.71407 .49733 Mdot
.29703 .54661 Mdot
.69564 .56425 Mdot
.59219 .70491 Mdot
.62974 .68364 Mdot
.30886 .56888 Mdot
.47157 .28145 Mdot
.65732 .65188 Mdot
.30465 .54734 Mdot
.7043 .5756 Mdot
.52231 .27799 Mdot
.70592 .53704 Mdot
.5235 .29228 Mdot
.31518 .42106 Mdot
.45872 .30112 Mdot
.35195 .63636 Mdot
.3136 .4189 Mdot
.70563 .41343 Mdot
.60684 .32167 Mdot
.58047 .31206 Mdot
.35487 .64744 Mdot
.5106 .28866 Mdot
.33733 .36917 Mdot
.4742 .29927 Mdot
.62025 .31017 Mdot
.60208 .67362 Mdot
.65918 .65415 Mdot
.54227 .30439 Mdot
.2956 .42331 Mdot
.61594 .33456 Mdot
.46216 .29301 Mdot
.71784 .54569 Mdot
.38299 .66654 Mdot
.4671 .7084 Mdot
.48576 .28068 Mdot
.29978 .44147 Mdot
.6779 .37043 Mdot
.34909 .64196 Mdot
.53825 .2798 Mdot
.32947 .38256 Mdot
.53814 .70161 Mdot
.49832 .29497 Mdot
.28024 .50135 Mdot
.45576 .29731 Mdot
.62539 .67615 Mdot
.29362 .5804 Mdot
.31166 .61645 Mdot
.66871 .37017 Mdot
.29922 .48477 Mdot
.29531 .47967 Mdot
.48051 .29808 Mdot
.69582 .39197 Mdot
.27824 .47983 Mdot
.60403 .69227 Mdot
.70197 .51962 Mdot
.29714 .55856 Mdot
.63886 .34021 Mdot
.71378 .51939 Mdot
.29446 .56394 Mdot
.64814 .637 Mdot
.69885 .42119 Mdot
.32366 .36667 Mdot
.55854 .70276 Mdot
.40945 .29684 Mdot
.42249 .30122 Mdot
.29677 .48439 Mdot
.40495 .31225 Mdot
.7039 .57622 Mdot
.58439 .29278 Mdot
.69581 .55361 Mdot
.36756 .66102 Mdot
.67859 .40723 Mdot
.30784 .60627 Mdot
.41181 .68526 Mdot
.54634 .70334 Mdot
.36503 .34207 Mdot
.2822 .4676 Mdot
.64397 .64442 Mdot
.62124 .32884 Mdot
.69208 .58792 Mdot
.70547 .54802 Mdot
.70549 .53358 Mdot
.41032 .31842 Mdot
.66588 .62378 Mdot
.49036 .70771 Mdot
.53945 .3021 Mdot
.71622 .55995 Mdot
.63548 .67212 Mdot
.29735 .47499 Mdot
.71365 .52511 Mdot
.39604 .30675 Mdot
.69402 .43737 Mdot
.36208 .34373 Mdot
.69631 .39923 Mdot
.69875 .4462 Mdot
.594 .3081 Mdot
.43182 .2877 Mdot
.70484 .5542 Mdot
.37723 .31312 Mdot
.67404 .36898 Mdot
.64202 .66725 Mdot
.64662 .36 Mdot
.27998 .547 Mdot
.70156 .40262 Mdot
.60622 .31128 Mdot
.70313 .50491 Mdot
.64769 .3498 Mdot
.58967 .69486 Mdot
.59878 .68834 Mdot
.62896 .65626 Mdot
.28696 .47902 Mdot
.50937 .70955 Mdot
.34209 .65269 Mdot
.36386 .65597 Mdot
.68634 .38365 Mdot
.3085 .58167 Mdot
.67826 .59738 Mdot
.31343 .58495 Mdot
.55947 .70919 Mdot
.49914 .7155 Mdot
.70048 .5419 Mdot
.66366 .63616 Mdot
.28552 .47677 Mdot
.63677 .3498 Mdot
.64146 .6699 Mdot
.27895 .49536 Mdot
.52734 .69954 Mdot
.69405 .58762 Mdot
.63265 .6796 Mdot
.363 .34361 Mdot
.69267 .42766 Mdot
.33704 .64391 Mdot
.66973 .39235 Mdot
.46874 .70211 Mdot
.3356 .63107 Mdot
.33213 .61123 Mdot
.49545 .71413 Mdot
.6687 .38305 Mdot
.71014 .53335 Mdot
.61185 .31362 Mdot
.65291 .34957 Mdot
.56407 .69941 Mdot
.69072 .41527 Mdot
.58701 .30116 Mdot
.70546 .53045 Mdot
.29456 .44557 Mdot
.34827 .33732 Mdot
.64028 .65782 Mdot
.35073 .64526 Mdot
.52474 .70438 Mdot
.36803 .67666 Mdot
.33145 .63107 Mdot
.29636 .53119 Mdot
.56999 .69169 Mdot
.28551 .44154 Mdot
.34669 .64646 Mdot
.28691 .47454 Mdot
.6172 .30852 Mdot
.66591 .35989 Mdot
.43799 .29586 Mdot
.29165 .48528 Mdot
.29568 .53601 Mdot
.61533 .67951 Mdot
.69355 .60238 Mdot
.41562 .3106 Mdot
.65953 .35603 Mdot
.63291 .66263 Mdot
.29722 .49425 Mdot
.34124 .34708 Mdot
.39879 .32361 Mdot
.47913 .2978 Mdot
.70955 .45182 Mdot
.53784 .71611 Mdot
.29273 .51069 Mdot
.68996 .5798 Mdot
.31659 .60946 Mdot
.33693 .65312 Mdot
.28059 .45641 Mdot
.51468 .71315 Mdot
.71774 .53688 Mdot
.33816 .3536 Mdot
.36179 .66791 Mdot
.6598 .35623 Mdot
.33958 .62351 Mdot
.38298 .31305 Mdot
.68092 .375 Mdot
.32464 .37645 Mdot
.29414 .51372 Mdot
.54352 .71139 Mdot
.7005 .4461 Mdot
.70035 .47294 Mdot
.69246 .41164 Mdot
.36521 .65965 Mdot
.30269 .40427 Mdot
.28306 .52991 Mdot
.59684 .69403 Mdot
.59157 .29619 Mdot
.46867 .71972 Mdot
.53976 .7051 Mdot
.54457 .28903 Mdot
.71808 .50252 Mdot
.59436 .31462 Mdot
.71363 .53137 Mdot
.67347 .36269 Mdot
.39087 .32413 Mdot
.41225 .68187 Mdot
.58654 .69462 Mdot
.62852 .66617 Mdot
.3569 .65987 Mdot
.64849 .34711 Mdot
.62431 .66381 Mdot
.68821 .61869 Mdot
.63043 .66782 Mdot
.48034 .71359 Mdot
.65999 .65337 Mdot
.34942 .658 Mdot
.29209 .55334 Mdot
.7059 .56637 Mdot
.46643 .69884 Mdot
.67015 .38343 Mdot
.67937 .38682 Mdot
.7138 .54319 Mdot
.51779 .29431 Mdot
.70622 .4216 Mdot
.33938 .35127 Mdot
.4094 .31485 Mdot
.27775 .50384 Mdot
.42614 .69965 Mdot
.70199 .54812 Mdot
.49058 .72134 Mdot
.51371 .29447 Mdot
.37088 .67228 Mdot
.62887 .32306 Mdot
.4046 .70065 Mdot
.68186 .6098 Mdot
.35442 .63939 Mdot
.28599 .54423 Mdot
.43305 .28999 Mdot
.71741 .45897 Mdot
.33641 .62774 Mdot
.69501 .41282 Mdot
.63682 .66064 Mdot
.59716 .68349 Mdot
.54863 .28471 Mdot
.4062 .69205 Mdot
.28192 .54915 Mdot
.51786 .7005 Mdot
.69017 .61452 Mdot
.52383 .29361 Mdot
.34848 .63294 Mdot
.56281 .29803 Mdot
.71866 .48748 Mdot
.64729 .3327 Mdot
.6256 .33419 Mdot
.42378 .29867 Mdot
.69331 .58775 Mdot
.36195 .64684 Mdot
.32955 .37101 Mdot
.63315 .64957 Mdot
.28446 .47711 Mdot
.35522 .66229 Mdot
.64587 .6582 Mdot
.31251 .41471 Mdot
.64038 .6709 Mdot
.43951 .3009 Mdot
.4504 .70731 Mdot
.71732 .51457 Mdot
.53819 .6972 Mdot
.36273 .33287 Mdot
.34218 .35828 Mdot
.28414 .49141 Mdot
.67859 .62909 Mdot
.64206 .67259 Mdot
.70108 .45923 Mdot
.3046 .40435 Mdot
.59792 .31536 Mdot
.64281 .34676 Mdot
.28617 .44476 Mdot
.63678 .33197 Mdot
.40549 .69864 Mdot
.5398 .6964 Mdot
.44104 .30067 Mdot
.4503 .29662 Mdot
.33177 .37016 Mdot
.31007 .4085 Mdot
.36431 .34323 Mdot
.71826 .49864 Mdot
.58071 .29176 Mdot
.6433 .65185 Mdot
.47637 .70111 Mdot
.47161 .71527 Mdot
.6965 .43332 Mdot
.70498 .57045 Mdot
.50889 .72446 Mdot
.38796 .67451 Mdot
.36385 .33734 Mdot
.52692 .28008 Mdot
.70476 .50339 Mdot
.52596 .29837 Mdot
.57141 .6937 Mdot
.3609 .3302 Mdot
.68183 .4076 Mdot
.36157 .64761 Mdot
.71919 .46844 Mdot
.41368 .69212 Mdot
.4771 .27937 Mdot
.701 .46993 Mdot
.67384 .61727 Mdot
.55518 .69917 Mdot
.67174 .61177 Mdot
.31254 .57888 Mdot
.67915 .36643 Mdot
.55934 .29973 Mdot
.71632 .46276 Mdot
.31544 .59266 Mdot
.72296 .49387 Mdot
.67131 .63945 Mdot
.48473 .70065 Mdot
.64661 .66087 Mdot
.60713 .68818 Mdot
.68822 .40467 Mdot
.68807 .59704 Mdot
.29291 .51463 Mdot
.59345 .69159 Mdot
.42149 .2905 Mdot
.56113 .70995 Mdot
.47687 .71598 Mdot
.55583 .71344 Mdot
.62065 .68554 Mdot
.70743 .42854 Mdot
.70098 .53295 Mdot
.53747 .30064 Mdot
.67572 .62848 Mdot
.43806 .29284 Mdot
.33958 .36437 Mdot
.29965 .46699 Mdot
.68441 .39676 Mdot
.40957 .68885 Mdot
.3732 .32128 Mdot
.66316 .6381 Mdot
.27737 .50903 Mdot
.61215 .68853 Mdot
.28535 .5442 Mdot
.33757 .64316 Mdot
.36468 .64927 Mdot
.41616 .3181 Mdot
.50747 .28372 Mdot
.62459 .68403 Mdot
.6063 .32464 Mdot
.60743 .31625 Mdot
.58384 .69355 Mdot
.46135 .27927 Mdot
.42329 .30117 Mdot
.30865 .42725 Mdot
.536 .71598 Mdot
.59941 .68861 Mdot
.63493 .32943 Mdot
.28739 .51132 Mdot
.66192 .61923 Mdot
.38876 .68477 Mdot
.48018 .72012 Mdot
.2972 .49739 Mdot
.68451 .60045 Mdot
.53772 .29979 Mdot
.33081 .64368 Mdot
.53947 .72051 Mdot
.60418 .67424 Mdot
.7009 .5639 Mdot
.42531 .69683 Mdot
.29147 .42123 Mdot
.55628 .70175 Mdot
.53726 .70386 Mdot
.69962 .42445 Mdot
.46066 .2994 Mdot
.63262 .34584 Mdot
.68638 .42558 Mdot
.29613 .53214 Mdot
.45939 .30246 Mdot
.42409 .68868 Mdot
.39449 .3117 Mdot
.71781 .50432 Mdot
.66684 .64022 Mdot
.55997 .30041 Mdot
.66236 .3657 Mdot
.63377 .32538 Mdot
.59843 .68129 Mdot
.71627 .48771 Mdot
.52411 .70418 Mdot
.2908 .4791 Mdot
.29681 .48264 Mdot
.55775 .69864 Mdot
.61961 .32366 Mdot
.56381 .70428 Mdot
.47738 .28103 Mdot
.32969 .61518 Mdot
.6162 .32576 Mdot
.30022 .43325 Mdot
.40525 .3203 Mdot
.29655 .41893 Mdot
.29232 .58 Mdot
.70066 .55762 Mdot
.69658 .40433 Mdot
.60769 .32921 Mdot
.67819 .60247 Mdot
.36196 .33792 Mdot
.37692 .67066 Mdot
.52292 .70602 Mdot
.29916 .49264 Mdot
.40694 .29882 Mdot
.61107 .30684 Mdot
.64712 .63936 Mdot
.34444 .62612 Mdot
.69428 .60082 Mdot
.29873 .54677 Mdot
.51817 .71621 Mdot
.35289 .6371 Mdot
.3341 .38116 Mdot
.71156 .54196 Mdot
.3517 .6649 Mdot
.28801 .46598 Mdot
.42113 .31608 Mdot
.42305 .29723 Mdot
.29574 .41186 Mdot
.43216 .70572 Mdot
.29693 .51451 Mdot
.6092 .32064 Mdot
.49735 .7116 Mdot
.29888 .55646 Mdot
.38126 .32978 Mdot
.3054 .59873 Mdot
.4521 .70524 Mdot
.66461 .38033 Mdot
.33034 .37516 Mdot
.55561 .70419 Mdot
.70771 .54797 Mdot
.68349 .37861 Mdot
.29966 .4384 Mdot
.69007 .58936 Mdot
.43714 .71394 Mdot
.34788 .36841 Mdot
.36522 .33193 Mdot
.57869 .69245 Mdot
.3736 .66099 Mdot
.45132 .69853 Mdot
.50684 .28107 Mdot
.69045 .60563 Mdot
.45996 .29807 Mdot
.60286 .6976 Mdot
.60493 .69481 Mdot
.66918 .62898 Mdot
.65876 .34299 Mdot
.2888 .51306 Mdot
.52156 .70673 Mdot
.43469 .69293 Mdot
.64592 .35864 Mdot
.72345 .51924 Mdot
.65012 .64559 Mdot
.68851 .41571 Mdot
.33281 .6156 Mdot
.5124 .29164 Mdot
.52291 .70572 Mdot
.37669 .31661 Mdot
.37057 .66373 Mdot
.60588 .68064 Mdot
.6438 .64024 Mdot
.63474 .34457 Mdot
.50633 .72261 Mdot
.62133 .333 Mdot
.65298 .64903 Mdot
.69497 .38785 Mdot
.45956 .29362 Mdot
.61874 .68067 Mdot
.29738 .51677 Mdot
.2798 .49769 Mdot
.64994 .66046 Mdot
.39149 .68075 Mdot
.71851 .51015 Mdot
.29796 .53542 Mdot
.51653 .27957 Mdot
.33923 .34444 Mdot
.36674 .34097 Mdot
.43818 .28493 Mdot
.69455 .39271 Mdot
.30178 .43834 Mdot
.30028 .58952 Mdot
.70344 .56095 Mdot
.4273 .71214 Mdot
.45022 .30469 Mdot
.44247 .69729 Mdot
.51681 .72079 Mdot
.2951 .45656 Mdot
.33342 .35216 Mdot
.65901 .37547 Mdot
.68913 .38009 Mdot
.70216 .46728 Mdot
.35993 .6649 Mdot
.29621 .44558 Mdot
.41812 .68682 Mdot
.51464 .71117 Mdot
.34041 .37547 Mdot
.69347 .42873 Mdot
.3613 .65231 Mdot
.31237 .61813 Mdot
.50266 .29174 Mdot
.2814 .47751 Mdot
.61434 .32465 Mdot
.29243 .44412 Mdot
.28376 .52747 Mdot
.70403 .50041 Mdot
.60992 .68362 Mdot
.51547 .2832 Mdot
.30265 .42374 Mdot
.58692 .30755 Mdot
.57432 .69167 Mdot
.32118 .61836 Mdot
.29378 .583 Mdot
.66982 .36063 Mdot
.32548 .37795 Mdot
.38094 .66655 Mdot
.66295 .64779 Mdot
.38361 .66351 Mdot
.6971 .44016 Mdot
.32209 .39156 Mdot
.32714 .63513 Mdot
.5273 .2795 Mdot
.56188 .70468 Mdot
.36493 .65783 Mdot
.51926 .28433 Mdot
.29023 .53724 Mdot
.60137 .67654 Mdot
.64891 .64568 Mdot
.69846 .56421 Mdot
.53222 .2949 Mdot
.66634 .61567 Mdot
.58559 .70729 Mdot
.43854 .30108 Mdot
.3241 .59949 Mdot
.28064 .50133 Mdot
.70619 .57484 Mdot
.48074 .29808 Mdot
.32137 .39679 Mdot
.29579 .4073 Mdot
.28398 .55528 Mdot
.28571 .47563 Mdot
.41488 .30217 Mdot
.31244 .60111 Mdot
.28393 .50319 Mdot
.46035 .299 Mdot
.68782 .6026 Mdot
.53949 .70677 Mdot
.71714 .53321 Mdot
.29323 .51941 Mdot
.30124 .57758 Mdot
.6809 .3965 Mdot
.71379 .47387 Mdot
.32444 .6288 Mdot
.44382 .69196 Mdot
.70271 .47174 Mdot
.56163 .30038 Mdot
.48736 .72444 Mdot
.45621 .2845 Mdot
.70789 .55196 Mdot
.43091 .31206 Mdot
.30512 .43139 Mdot
.49579 .71184 Mdot
.35408 .33111 Mdot
.46876 .71929 Mdot
.51634 .7048 Mdot
.71922 .46839 Mdot
.48818 .70043 Mdot
.59106 .69208 Mdot
.70099 .50053 Mdot
.28869 .55221 Mdot
.70552 .4492 Mdot
.52388 .28389 Mdot
.32853 .61254 Mdot
.29529 .48149 Mdot
.52718 .29489 Mdot
.51072 .70878 Mdot
.30303 .45773 Mdot
.48049 .71167 Mdot
.46952 .69835 Mdot
.6936 .61464 Mdot
.46646 .72217 Mdot
.35214 .35466 Mdot
.4186 .69681 Mdot
.6329 .33112 Mdot
.67183 .38299 Mdot
.38587 .67551 Mdot
.63396 .64982 Mdot
.66211 .61766 Mdot
.31856 .36775 Mdot
.60863 .31709 Mdot
.39716 .69882 Mdot
.50028 .28726 Mdot
.71224 .57211 Mdot
.6438 .64668 Mdot
.48636 .28927 Mdot
.47237 .71373 Mdot
.60333 .32493 Mdot
.68581 .4107 Mdot
.43866 .30721 Mdot
.59778 .31886 Mdot
.66352 .61995 Mdot
.71793 .49107 Mdot
.5316 .29851 Mdot
.50868 .70518 Mdot
.46496 .29822 Mdot
.66715 .65055 Mdot
.71737 .47659 Mdot
.61906 .32769 Mdot
.62868 .67266 Mdot
.6766 .39931 Mdot
.29865 .56951 Mdot
.68874 .61772 Mdot
.38036 .67285 Mdot
.6688 .61515 Mdot
.31427 .4103 Mdot
.63392 .32048 Mdot
.61736 .33625 Mdot
.47936 .27694 Mdot
.63846 .34501 Mdot
.66454 .36228 Mdot
.45653 .28689 Mdot
.70792 .46244 Mdot
.47324 .70273 Mdot
.65844 .35638 Mdot
.69507 .39987 Mdot
.54894 .29628 Mdot
.37166 .67 Mdot
.6935 .417 Mdot
.28851 .49475 Mdot
.56512 .70126 Mdot
.36809 .34476 Mdot
.41686 .7058 Mdot
.68504 .39816 Mdot
.38762 .6782 Mdot
.37748 .33349 Mdot
.28631 .55954 Mdot
.46613 .29026 Mdot
.39682 .31444 Mdot
.34472 .66207 Mdot
.47939 .29929 Mdot
.64343 .34267 Mdot
.28952 .455 Mdot
.52655 .70749 Mdot
.53764 .71501 Mdot
.41816 .7074 Mdot
.65387 .36064 Mdot
.38503 .31686 Mdot
.31153 .59436 Mdot
.68765 .42056 Mdot
.50968 .27675 Mdot
.31231 .41925 Mdot
.71934 .53217 Mdot
.42928 .29545 Mdot
.29398 .51342 Mdot
.29712 .54231 Mdot
.47697 .71193 Mdot
.61495 .67489 Mdot
.34634 .63657 Mdot
.282 .50455 Mdot
.71228 .44298 Mdot
.30098 .4206 Mdot
.56662 .71109 Mdot
.70987 .4944 Mdot
.59799 .70217 Mdot
.43413 .70835 Mdot
.41779 .29787 Mdot
.60347 .3158 Mdot
.31954 .59732 Mdot
.40717 .32061 Mdot
.71844 .55162 Mdot
.59214 .68752 Mdot
.68014 .59711 Mdot
.33697 .35278 Mdot
.64945 .3549 Mdot
.34815 .35534 Mdot
.43451 .30191 Mdot
.40499 .69421 Mdot
.71495 .51442 Mdot
.29539 .51164 Mdot
.32191 .38796 Mdot
.58289 .31475 Mdot
.3004 .43174 Mdot
.36002 .33156 Mdot
.2965 .53387 Mdot
.72206 .53196 Mdot
.31668 .37304 Mdot
.3251 .62439 Mdot
.67119 .371 Mdot
.69632 .60665 Mdot
.66941 .35357 Mdot
.31425 .38498 Mdot
.43762 .70421 Mdot
.52873 .2864 Mdot
.49331 .29753 Mdot
.64997 .66302 Mdot
.4709 .71936 Mdot
.67217 .6404 Mdot
.39811 .30131 Mdot
.44495 .29989 Mdot
.53574 .29415 Mdot
.35501 .3493 Mdot
.66249 .36695 Mdot
.70892 .5534 Mdot
.31573 .37711 Mdot
.47673 .69876 Mdot
.62741 .32199 Mdot
.6328 .65433 Mdot
.3035 .39536 Mdot
.70324 .53618 Mdot
.68419 .37192 Mdot
.4037 .70212 Mdot
.65143 .65321 Mdot
.42433 .299 Mdot
.51916 .70451 Mdot
.37155 .31633 Mdot
.36837 .33777 Mdot
.3326 .64886 Mdot
.55693 .29267 Mdot
.50359 .72039 Mdot
.54773 .71207 Mdot
.54093 .71003 Mdot
.41786 .70197 Mdot
.67289 .37205 Mdot
.57983 .68623 Mdot
.55479 .69268 Mdot
.71151 .43188 Mdot
.30988 .43419 Mdot
.42286 .69886 Mdot
.59882 .67637 Mdot
.27787 .47725 Mdot
.68199 .40189 Mdot
.43455 .69524 Mdot
.43523 .29208 Mdot
.71247 .48664 Mdot
.56666 .30859 Mdot
.57056 .30191 Mdot
.33439 .38371 Mdot
.62958 .33087 Mdot
.6934 .55539 Mdot
.28422 .43708 Mdot
.65907 .34228 Mdot
.69816 .53639 Mdot
.70838 .43856 Mdot
.46882 .28166 Mdot
.49657 .72445 Mdot
.48361 .29299 Mdot
.28945 .56974 Mdot
.70295 .40908 Mdot
.63083 .32383 Mdot
.68411 .59959 Mdot
.57685 .29572 Mdot
.29514 .45588 Mdot
.69931 .40863 Mdot
.29202 .49365 Mdot
.69994 .47119 Mdot
.53645 .29062 Mdot
.46806 .30001 Mdot
.69843 .55096 Mdot
.46692 .70306 Mdot
.6623 .62926 Mdot
.31231 .59706 Mdot
.71969 .53924 Mdot
.33806 .354 Mdot
.28652 .50756 Mdot
.41136 .29452 Mdot
.70508 .48646 Mdot
.44209 .28591 Mdot
.55145 .71184 Mdot
.71803 .47685 Mdot
.60024 .68809 Mdot
.44361 .29406 Mdot
.68872 .58171 Mdot
.45784 .69778 Mdot
.70193 .54768 Mdot
.39539 .31885 Mdot
.28889 .4422 Mdot
.70897 .47556 Mdot
.29838 .43023 Mdot
.46855 .71129 Mdot
.38083 .68534 Mdot
.44498 .71235 Mdot
.60111 .68087 Mdot
.32145 .39758 Mdot
.66016 .62237 Mdot
.43773 .69386 Mdot
.69998 .58945 Mdot
.35264 .33741 Mdot
.30215 .46943 Mdot
.37856 .32985 Mdot
.70843 .4621 Mdot
.34139 .65307 Mdot
.35222 .34178 Mdot
.67145 .60503 Mdot
.29678 .55006 Mdot
.27986 .49365 Mdot
.36989 .66194 Mdot
.56027 .70806 Mdot
.44585 .70668 Mdot
.30036 .40249 Mdot
.52193 .28767 Mdot
.6874 .39846 Mdot
.55625 .30639 Mdot
.29024 .4417 Mdot
.60744 .68057 Mdot
.29171 .55957 Mdot
.44157 .30787 Mdot
.71104 .43301 Mdot
.37708 .68015 Mdot
.4948 .29526 Mdot
.69255 .56866 Mdot
.59583 .68419 Mdot
.44874 .70979 Mdot
.49631 .71945 Mdot
.28585 .50925 Mdot
.44925 .30471 Mdot
.40323 .67986 Mdot
.49489 .71007 Mdot
.35665 .35567 Mdot
.43041 .70207 Mdot
.46027 .70654 Mdot
.30426 .42698 Mdot
.53128 .70351 Mdot
.35054 .63483 Mdot
.69862 .41786 Mdot
.64109 .6512 Mdot
.31151 .56859 Mdot
.31973 .59768 Mdot
.66521 .64731 Mdot
.60943 .69074 Mdot
.28247 .5132 Mdot
.63568 .34475 Mdot
.55149 .70112 Mdot
.42146 .70793 Mdot
.70073 .48024 Mdot
.69645 .39881 Mdot
.70268 .56137 Mdot
.55819 .29389 Mdot
.33099 .37337 Mdot
.35415 .64989 Mdot
.28594 .51828 Mdot
.55884 .706 Mdot
.72184 .49454 Mdot
.38697 .67467 Mdot
.54803 .29114 Mdot
.70602 .54459 Mdot
.56771 .29847 Mdot
.66584 .63653 Mdot
.50604 .29925 Mdot
.41936 .68372 Mdot
.62348 .67558 Mdot
.70277 .42411 Mdot
.38679 .30577 Mdot
.48386 .29838 Mdot
.40217 .32223 Mdot
.32605 .6334 Mdot
.6593 .35769 Mdot
.36518 .65895 Mdot
.67468 .59944 Mdot
.4968 .71859 Mdot
.40625 .67685 Mdot
.70086 .41532 Mdot
.59542 .68764 Mdot
.7013 .49177 Mdot
.28965 .48794 Mdot
.49125 .72403 Mdot
.61044 .324 Mdot
.631 .34233 Mdot
.71057 .43916 Mdot
.27846 .50225 Mdot
.65219 .34367 Mdot
.50503 .70288 Mdot
.29075 .4388 Mdot
.42326 .69544 Mdot
.3578 .65112 Mdot
.41593 .6908 Mdot
.64251 .33002 Mdot
.69468 .57685 Mdot
.71202 .5293 Mdot
.56374 .69411 Mdot
.70087 .58937 Mdot
.43719 .30197 Mdot
.56979 .68921 Mdot
.30329 .55706 Mdot
.37574 .33238 Mdot
.63418 .67415 Mdot
.46441 .69798 Mdot
.6012 .31444 Mdot
.32266 .60151 Mdot
.52485 .29947 Mdot
.32955 .63153 Mdot
.29852 .40501 Mdot
.39529 .69399 Mdot
.64619 .34235 Mdot
.64466 .66412 Mdot
.31981 .6082 Mdot
.29063 .51774 Mdot
.47514 .71389 Mdot
.5542 .70182 Mdot
.31085 .57633 Mdot
.55211 .30211 Mdot
.40198 .32348 Mdot
.33016 .63074 Mdot
.66576 .61918 Mdot
.69988 .58921 Mdot
.52656 .71251 Mdot
.68201 .41684 Mdot
.58252 .31345 Mdot
.29761 .57251 Mdot
.29593 .43671 Mdot
.5168 .70532 Mdot
.66247 .63255 Mdot
.3101 .567 Mdot
.30702 .57699 Mdot
.70148 .56608 Mdot
.39049 .67166 Mdot
.71701 .4776 Mdot
.6651 .63686 Mdot
.70659 .56977 Mdot
.4427 .70252 Mdot
.3408 .37394 Mdot
.49445 .27826 Mdot
.34841 .66227 Mdot
.36183 .33905 Mdot
.69572 .39804 Mdot
.56617 .69334 Mdot
.64579 .35074 Mdot
.62516 .34306 Mdot
.6656 .36212 Mdot
.496 .28876 Mdot
.61641 .31046 Mdot
.30784 .55832 Mdot
.52603 .71781 Mdot
.44566 .30337 Mdot
.64329 .33004 Mdot
.69625 .59233 Mdot
.68647 .42333 Mdot
.64788 .34734 Mdot
.70016 .5863 Mdot
.71082 .52036 Mdot
.5916 .68059 Mdot
.47695 .6992 Mdot
.39271 .67475 Mdot
.58955 .2939 Mdot
.6652 .63077 Mdot
.67169 .63869 Mdot
.50659 .71329 Mdot
.698 .5484 Mdot
.42556 .69826 Mdot
.60929 .68665 Mdot
.51048 .71856 Mdot
.61981 .66571 Mdot
.69739 .5885 Mdot
.65045 .36229 Mdot
.4728 .29049 Mdot
.68652 .58323 Mdot
.35631 .36007 Mdot
.70154 .44643 Mdot
.34735 .64736 Mdot
.6797 .40194 Mdot
.68098 .58605 Mdot
.50644 .28667 Mdot
.59754 .31789 Mdot
.33446 .37253 Mdot
.5151 .28526 Mdot
.46464 .2981 Mdot
.69997 .54039 Mdot
.38781 .33355 Mdot
.32903 .61026 Mdot
.42895 .29476 Mdot
.71217 .5419 Mdot
.53517 .29046 Mdot
.70922 .44683 Mdot
.72198 .5304 Mdot
.6412 .65446 Mdot
.31333 .60691 Mdot
.34912 .65874 Mdot
.42859 .30237 Mdot
.38567 .68208 Mdot
.70309 .55106 Mdot
.69165 .41041 Mdot
.38103 .68175 Mdot
.67771 .36981 Mdot
.31249 .41776 Mdot
.68958 .42352 Mdot
.30215 .4437 Mdot
.57697 .29374 Mdot
.65061 .65425 Mdot
.31495 .57886 Mdot
.31297 .58503 Mdot
.67341 .62049 Mdot
.32716 .63779 Mdot
.61281 .69421 Mdot
.69358 .56376 Mdot
.47837 .70316 Mdot
.27696 .52128 Mdot
.39427 .69847 Mdot
.70339 .42056 Mdot
.29706 .47299 Mdot
.57916 .31333 Mdot
.67511 .60382 Mdot
.33628 .65039 Mdot
.71685 .48434 Mdot
.70078 .48593 Mdot
.59555 .30426 Mdot
.70592 .41581 Mdot
.2993 .42717 Mdot
.28611 .56453 Mdot
.5301 .7115 Mdot
.29559 .48374 Mdot
.44354 .29887 Mdot
.43603 .30808 Mdot
.35144 .35825 Mdot
.41618 .68707 Mdot
.35695 .3423 Mdot
.40391 .67962 Mdot
.58162 .29559 Mdot
.34112 .63151 Mdot
.49343 .70649 Mdot
.69156 .41936 Mdot
.7147 .53756 Mdot
.31993 .59325 Mdot
.40966 .68853 Mdot
.46883 .30196 Mdot
.43687 .3063 Mdot
.31525 .62035 Mdot
.69691 .58833 Mdot
.69001 .60435 Mdot
.49078 .72052 Mdot
.42246 .30427 Mdot
.71411 .50213 Mdot
.50431 .29735 Mdot
.71822 .46406 Mdot
.39235 .69748 Mdot
.37848 .32616 Mdot
.32204 .36325 Mdot
.69937 .43941 Mdot
.56767 .69238 Mdot
.66403 .35709 Mdot
.65805 .64154 Mdot
.34741 .33897 Mdot
.31963 .59011 Mdot
.35563 .35065 Mdot
.39569 .30185 Mdot
.37964 .32602 Mdot
.3759 .6865 Mdot
.72445 .5011 Mdot
.48473 .27593 Mdot
.70643 .56383 Mdot
.28736 .4411 Mdot
.61763 .69006 Mdot
.31319 .59258 Mdot
.30251 .45909 Mdot
.70686 .50065 Mdot
.68095 .37671 Mdot
.40256 .68369 Mdot
.49852 .7074 Mdot
.70788 .47927 Mdot
.49953 .70795 Mdot
.50657 .70922 Mdot
.5636 .70734 Mdot
.43653 .29597 Mdot
.71121 .55541 Mdot
.46761 .70261 Mdot
.28362 .48868 Mdot
.46544 .72063 Mdot
.32275 .36515 Mdot
.7036 .42972 Mdot
.37086 .67228 Mdot
.7009 .45234 Mdot
.6662 .624 Mdot
.45552 .28234 Mdot
.67384 .37268 Mdot
.70744 .52082 Mdot
.64003 .32758 Mdot
.48811 .29705 Mdot
.37899 .66603 Mdot
.2997 .54351 Mdot
.49573 .29231 Mdot
.28692 .47464 Mdot
.32874 .63395 Mdot
.30462 .42837 Mdot
.44477 .70268 Mdot
.61079 .32049 Mdot
.32824 .63681 Mdot
.5886 .31795 Mdot
.28271 .4523 Mdot
.69548 .60972 Mdot
.58725 .69871 Mdot
.33599 .35458 Mdot
.30669 .58019 Mdot
.66807 .6167 Mdot
.70897 .55796 Mdot
.28568 .44402 Mdot
.50094 .29321 Mdot
.43828 .29868 Mdot
.36704 .66538 Mdot
.6522 .35808 Mdot
.59554 .30769 Mdot
.56351 .30095 Mdot
.35721 .32908 Mdot
.58688 .69638 Mdot
.56364 .70372 Mdot
.67942 .60936 Mdot
.62019 .68614 Mdot
.29542 .43853 Mdot
.32009 .61733 Mdot
.61286 .33121 Mdot
.69257 .5629 Mdot
.7141 .44965 Mdot
.53083 .71061 Mdot
.60846 .681 Mdot
.31666 .38744 Mdot
.71959 .47277 Mdot
.34802 .63261 Mdot
.6654 .36876 Mdot
.52945 .703 Mdot
.37285 .68263 Mdot
.59052 .3046 Mdot
.28055 .49587 Mdot
.52506 .28872 Mdot
.28242 .44449 Mdot
.28285 .44143 Mdot
.34836 .65035 Mdot
.70118 .44059 Mdot
.32806 .63283 Mdot
.31089 .41321 Mdot
.29389 .49732 Mdot
.38974 .67038 Mdot
.61695 .67273 Mdot
.2895 .47022 Mdot
.37664 .32499 Mdot
.50505 .27522 Mdot
.66314 .63937 Mdot
.55368 .71843 Mdot
.4834 .29966 Mdot
.49006 .71492 Mdot
.38645 .67517 Mdot
.42241 .308 Mdot
.60799 .32855 Mdot
.38266 .66705 Mdot
.41199 .29943 Mdot
.59842 .30711 Mdot
.70081 .54081 Mdot
.6952 .59413 Mdot
.68831 .39553 Mdot
.63804 .33285 Mdot
.58814 .69536 Mdot
.33876 .37892 Mdot
.61125 .32714 Mdot
.68802 .38662 Mdot
.70293 .50197 Mdot
.30294 .41299 Mdot
.4142 .69048 Mdot
.48746 .27648 Mdot
.45494 .69896 Mdot
.39971 .31874 Mdot
.35764 .65932 Mdot
.57891 .29961 Mdot
.591 .70504 Mdot
.5568 .70605 Mdot
.37988 .68284 Mdot
.44077 .71102 Mdot
.38326 .68153 Mdot
.47113 .29829 Mdot
.70464 .53057 Mdot
.70414 .48238 Mdot
.48491 .29765 Mdot
.40933 .70345 Mdot
.3513 .65425 Mdot
.29283 .49085 Mdot
.58091 .69911 Mdot
.43265 .70801 Mdot
.62553 .31792 Mdot
.72429 .50886 Mdot
.29477 .49342 Mdot
.46014 .71707 Mdot
.27808 .52591 Mdot
.44291 .70811 Mdot
.49079 .27968 Mdot
.71556 .46709 Mdot
.35762 .64923 Mdot
.29333 .54096 Mdot
.58878 .69728 Mdot
.60572 .68956 Mdot
.38598 .68836 Mdot
.6134 .6857 Mdot
.60531 .31273 Mdot
.66537 .35206 Mdot
.37276 .67507 Mdot
.32685 .38823 Mdot
.32688 .36277 Mdot
.34051 .35877 Mdot
.51965 .71375 Mdot
.62252 .66103 Mdot
.71118 .57262 Mdot
.70819 .47032 Mdot
.45703 .30146 Mdot
.5861 .30004 Mdot
.65959 .35849 Mdot
.70031 .40707 Mdot
.28333 .45225 Mdot
.38536 .68157 Mdot
.68066 .41198 Mdot
.46755 .30093 Mdot
.42523 .30236 Mdot
.30192 .39464 Mdot
.36395 .33612 Mdot
.32709 .37381 Mdot
.68616 .40314 Mdot
.54914 .28416 Mdot
.71491 .55388 Mdot
.62267 .34136 Mdot
.2754 .49355 Mdot
.29014 .48 Mdot
.30177 .39628 Mdot
.55307 .29774 Mdot
.65871 .35881 Mdot
.54828 .70412 Mdot
.50767 .7243 Mdot
.33237 .35647 Mdot
.40752 .69362 Mdot
.60443 .30147 Mdot
.45669 .71367 Mdot
.72041 .46126 Mdot
.53721 .28487 Mdot
.29468 .5566 Mdot
.56715 .70907 Mdot
.39772 .32365 Mdot
.41623 .68948 Mdot
.29024 .56335 Mdot
.68702 .59044 Mdot
.62046 .31182 Mdot
.50105 .28183 Mdot
.7233 .51906 Mdot
.30364 .53882 Mdot
.69364 .55133 Mdot
.42589 .30689 Mdot
.31658 .39299 Mdot
.28808 .5118 Mdot
.68123 .39693 Mdot
.59323 .68266 Mdot
.29098 .54758 Mdot
.6772 .63428 Mdot
.34612 .34851 Mdot
.37748 .66332 Mdot
.33311 .36157 Mdot
.65175 .36365 Mdot
.30351 .4091 Mdot
.57942 .70749 Mdot
.70323 .48068 Mdot
.43598 .30008 Mdot
.70127 .59044 Mdot
.29784 .46696 Mdot
.3353 .3758 Mdot
.31656 .59701 Mdot
.71349 .47177 Mdot
.68391 .58674 Mdot
.34815 .66403 Mdot
.58697 .70679 Mdot
.56385 .30307 Mdot
.70206 .49342 Mdot
.58056 .31379 Mdot
.44052 .70894 Mdot
.4971 .29279 Mdot
.52444 .28901 Mdot
.62322 .65873 Mdot
.38401 .6689 Mdot
.60622 .68185 Mdot
.46767 .69894 Mdot
.56172 .2971 Mdot
.67141 .60728 Mdot
.70502 .49626 Mdot
.66603 .6116 Mdot
.58365 .68405 Mdot
.56428 .30239 Mdot
.29852 .58819 Mdot
.71605 .5436 Mdot
.44635 .71231 Mdot
.41555 .30172 Mdot
.6487 .64598 Mdot
.31914 .61434 Mdot
.39763 .69621 Mdot
.40831 .69088 Mdot
.39649 .68987 Mdot
.53038 .70952 Mdot
.62873 .67107 Mdot
.31715 .59024 Mdot
.4495 .28674 Mdot
.33498 .62743 Mdot
.32245 .59244 Mdot
.44503 .28906 Mdot
.43292 .70615 Mdot
.43799 .69436 Mdot
.71744 .46351 Mdot
.71516 .46991 Mdot
.37392 .33934 Mdot
.50103 .29445 Mdot
.28491 .50437 Mdot
.40985 .68038 Mdot
.54654 .28398 Mdot
.69646 .40516 Mdot
.35906 .66998 Mdot
.53876 .69638 Mdot
.68965 .57524 Mdot
.69369 .39325 Mdot
.67844 .60793 Mdot
.69049 .42727 Mdot
.30888 .57225 Mdot
.58071 .70826 Mdot
.70184 .42835 Mdot
.6491 .33592 Mdot
.61467 .68564 Mdot
.68877 .42385 Mdot
.57105 .28927 Mdot
.46187 .30023 Mdot
.48854 .28194 Mdot
.56422 .30298 Mdot
.38214 .32641 Mdot
.62782 .34189 Mdot
.54785 .69985 Mdot
.39794 .32225 Mdot
.47709 .7151 Mdot
.56393 .30179 Mdot
.67634 .6367 Mdot
.63117 .34283 Mdot
.43415 .68962 Mdot
.62765 .65569 Mdot
.30795 .42179 Mdot
.38196 .6846 Mdot
.68522 .37663 Mdot
.28553 .52389 Mdot
.42505 .2963 Mdot
.58409 .30666 Mdot
.32002 .58888 Mdot
.70159 .51987 Mdot
.41138 .6822 Mdot
.62532 .68428 Mdot
.70047 .52386 Mdot
.72063 .51981 Mdot
.28833 .55819 Mdot
.40665 .32041 Mdot
.28925 .43032 Mdot
.5762 .6974 Mdot
.62756 .33962 Mdot
.35708 .64101 Mdot
.31527 .58702 Mdot
.35726 .67159 Mdot
.65701 .62642 Mdot
.55531 .69256 Mdot
.69044 .61925 Mdot
.57357 .69009 Mdot
.36119 .3489 Mdot
.29979 .47788 Mdot
.68187 .60136 Mdot
.40109 .6907 Mdot
.53308 .70057 Mdot
.70361 .43395 Mdot
.56123 .28444 Mdot
.31749 .38474 Mdot
.41312 .29516 Mdot
.33909 .64337 Mdot
.3174 .37233 Mdot
.57428 .69822 Mdot
.71249 .45303 Mdot
.40505 .31241 Mdot
.65661 .36098 Mdot
.37125 .67892 Mdot
.39007 .32563 Mdot
.33366 .62214 Mdot
.63831 .34593 Mdot
.57877 .2994 Mdot
.58889 .68975 Mdot
.29928 .60166 Mdot
.31652 .39434 Mdot
.52348 .71202 Mdot
.3382 .35225 Mdot
.30983 .42879 Mdot
.47807 .29146 Mdot
.55448 .70037 Mdot
.68261 .58995 Mdot
.57239 .31219 Mdot
.55991 .71327 Mdot
.71076 .49868 Mdot
.70913 .53466 Mdot
.31138 .40595 Mdot
.31246 .57022 Mdot
.37943 .68694 Mdot
.59382 .31644 Mdot
.54671 .28565 Mdot
.68557 .62086 Mdot
.31219 .40222 Mdot
.71634 .526 Mdot
.52355 .29085 Mdot
.58487 .29554 Mdot
.52655 .27687 Mdot
.54758 .29609 Mdot
.57218 .70139 Mdot
.38409 .67407 Mdot
.63168 .32816 Mdot
.29836 .47671 Mdot
.70102 .59446 Mdot
.31516 .59211 Mdot
.28981 .50857 Mdot
.32153 .61741 Mdot
.46575 .27772 Mdot
.32014 .37815 Mdot
.69288 .44635 Mdot
.57444 .30593 Mdot
.51537 .2893 Mdot
.28173 .54909 Mdot
.68371 .37938 Mdot
.70838 .42717 Mdot
.61648 .31023 Mdot
.28748 .47306 Mdot
.38167 .67626 Mdot
.65239 .63045 Mdot
.34374 .35614 Mdot
.29297 .47661 Mdot
.38811 .3197 Mdot
.44968 .30593 Mdot
.66257 .38191 Mdot
.50655 .70166 Mdot
.70593 .49026 Mdot
.43838 .69659 Mdot
.61734 .67235 Mdot
.53831 .28661 Mdot
.58242 .29472 Mdot
.39064 .31349 Mdot
.57401 .69526 Mdot
.6246 .66636 Mdot
.2825 .45747 Mdot
.30814 .57867 Mdot
.34967 .33844 Mdot
.57178 .69265 Mdot
.36144 .33623 Mdot
.67735 .36225 Mdot
.2951 .52148 Mdot
.65444 .63898 Mdot
.40195 .31451 Mdot
.29361 .5656 Mdot
.30055 .52485 Mdot
.43136 .6971 Mdot
.69419 .43628 Mdot
.63341 .34918 Mdot
.41256 .68949 Mdot
.39612 .3052 Mdot
.40739 .30136 Mdot
.53752 .28201 Mdot
.56944 .70153 Mdot
.38621 .31943 Mdot
.29908 .46872 Mdot
.55587 .71472 Mdot
.69456 .55561 Mdot
.67715 .38146 Mdot
.68459 .62506 Mdot
.70485 .55381 Mdot
.5348 .28857 Mdot
.35325 .65854 Mdot
.68173 .62417 Mdot
.31568 .3802 Mdot
.66605 .37648 Mdot
.68743 .41355 Mdot
.35727 .6452 Mdot
.46299 .29376 Mdot
.40379 .67677 Mdot
.58867 .29715 Mdot
.5197 .70233 Mdot
.5324 .29294 Mdot
.29319 .55505 Mdot
.31858 .62188 Mdot
.3571 .66584 Mdot
.58772 .29419 Mdot
.29315 .54626 Mdot
.66111 .35415 Mdot
.67497 .61313 Mdot
.61005 .67625 Mdot
.51563 .29349 Mdot
.38054 .67442 Mdot
.29921 .465 Mdot
.31786 .41307 Mdot
.695 .59008 Mdot
.60599 .67928 Mdot
.43928 .28762 Mdot
.37588 .66883 Mdot
.51221 .70858 Mdot
.28715 .54339 Mdot
.61857 .66178 Mdot
.4268 .69623 Mdot
.33404 .64208 Mdot
.71645 .44623 Mdot
.63667 .33447 Mdot
.32922 .6406 Mdot
.55725 .28255 Mdot
.53284 .7104 Mdot
.67537 .60415 Mdot
.64334 .35569 Mdot
.62322 .3177 Mdot
.32425 .61708 Mdot
.426 .29339 Mdot
.66348 .61821 Mdot
.42843 .68781 Mdot
.63143 .65564 Mdot
.29981 .5677 Mdot
.49741 .29252 Mdot
.38349 .32353 Mdot
.28267 .46885 Mdot
.31328 .40949 Mdot
.37097 .32658 Mdot
.46972 .28971 Mdot
.51066 .7047 Mdot
.71362 .54351 Mdot
.6275 .65828 Mdot
.46475 .28586 Mdot
.72448 .5052 Mdot
.46663 .70297 Mdot
.49227 .7169 Mdot
.33906 .35113 Mdot
.4763 .27878 Mdot
.70258 .56158 Mdot
.67771 .60483 Mdot
.40485 .70309 Mdot
.61118 .33213 Mdot
.45153 .7005 Mdot
.43242 .28738 Mdot
.30269 .41649 Mdot
.42737 .28856 Mdot
.45095 .70271 Mdot
.30719 .57401 Mdot
.39555 .31285 Mdot
.4463 .29797 Mdot
.35409 .35946 Mdot
.35561 .35771 Mdot
.4344 .69244 Mdot
.53864 .30237 Mdot
.72111 .52025 Mdot
.67831 .5976 Mdot
.30206 .5632 Mdot
.34871 .6379 Mdot
.61653 .69157 Mdot
.70787 .41876 Mdot
.29025 .50786 Mdot
.5241 .71277 Mdot
.64382 .35069 Mdot
.33561 .36707 Mdot
.31527 .41345 Mdot
.59827 .31437 Mdot
.30537 .42965 Mdot
.49712 .29325 Mdot
.67766 .63672 Mdot
.36598 .65122 Mdot
.70986 .41899 Mdot
.3185 .59288 Mdot
.29661 .56988 Mdot
.5757 .70097 Mdot
.31508 .40533 Mdot
.32462 .3971 Mdot
.70362 .50713 Mdot
.50954 .28191 Mdot
.28891 .56805 Mdot
.71118 .51218 Mdot
.37374 .68335 Mdot
.37032 .3355 Mdot
.31615 .62561 Mdot
.53975 .70171 Mdot
.70017 .44494 Mdot
.71288 .53559 Mdot
.33419 .65189 Mdot
.3015 .57584 Mdot
.34229 .65497 Mdot
.4129 .29885 Mdot
.70052 .39945 Mdot
.40664 .3145 Mdot
.32327 .40278 Mdot
.71869 .54462 Mdot
.59213 .68206 Mdot
.58391 .29922 Mdot
.544 .71702 Mdot
.54603 .30355 Mdot
.61422 .31013 Mdot
.37988 .67744 Mdot
.3059 .5501 Mdot
.38179 .31437 Mdot
.30337 .45763 Mdot
.71133 .47863 Mdot
.71502 .43567 Mdot
.70451 .43628 Mdot
.53898 .28308 Mdot
.6424 .66979 Mdot
.29184 .41738 Mdot
.36824 .67596 Mdot
.46701 .30032 Mdot
.70531 .50979 Mdot
.48208 .70112 Mdot
.37863 .67195 Mdot
.47529 .30075 Mdot
.35369 .66837 Mdot
.53354 .30147 Mdot
.32231 .60975 Mdot
.70593 .49785 Mdot
.46942 .71004 Mdot
.30842 .57836 Mdot
.691 .39611 Mdot
.45444 .30053 Mdot
.6811 .39001 Mdot
.30719 .56249 Mdot
.31531 .41965 Mdot
.46186 .30173 Mdot
.56108 .69396 Mdot
.6879 .42984 Mdot
.55393 .28722 Mdot
.70654 .42532 Mdot
.29386 .47856 Mdot
.28754 .49121 Mdot
.32292 .37838 Mdot
.55466 .29928 Mdot
.41666 .31497 Mdot
.38759 .67185 Mdot
.64919 .63548 Mdot
.35385 .35848 Mdot
.69273 .38748 Mdot
.41284 .3168 Mdot
.64275 .64526 Mdot
.4798 .29273 Mdot
.3293 .35898 Mdot
.53045 .7185 Mdot
.70578 .51829 Mdot
.30456 .58363 Mdot
.40025 .67756 Mdot
.67252 .61481 Mdot
.54518 .69702 Mdot
.29958 .53692 Mdot
.43914 .69467 Mdot
.55203 .30594 Mdot
.59446 .67663 Mdot
.70378 .57649 Mdot
.31136 .42263 Mdot
.60598 .30487 Mdot
.28767 .43419 Mdot
.33567 .6299 Mdot
.54586 .71378 Mdot
.4374 .69231 Mdot
.71649 .50306 Mdot
.60652 .30356 Mdot
.43945 .29627 Mdot
.71643 .55181 Mdot
.29209 .45738 Mdot
.7033 .47464 Mdot
.70472 .46127 Mdot
.62103 .66895 Mdot
.31354 .59887 Mdot
.51055 .2769 Mdot
.5593 .70917 Mdot
.28675 .55843 Mdot
.55752 .69249 Mdot
.34591 .33928 Mdot
.28664 .50031 Mdot
.33169 .39176 Mdot
.69697 .45932 Mdot
.33094 .35886 Mdot
.71775 .49637 Mdot
.29439 .55327 Mdot
.31577 .40622 Mdot
.43659 .29556 Mdot
.35437 .65723 Mdot
.50726 .71782 Mdot
.6085 .68377 Mdot
.33599 .35293 Mdot
.39855 .32758 Mdot
.71739 .53497 Mdot
.42782 .28802 Mdot
.3066 .61491 Mdot
.43681 .30377 Mdot
.70413 .44073 Mdot
.65822 .65917 Mdot
.49594 .72348 Mdot
.50867 .29007 Mdot
.7053 .51058 Mdot
.3139 .3795 Mdot
.33643 .63214 Mdot
.69818 .40074 Mdot
.35628 .66003 Mdot
.53023 .72066 Mdot
.70533 .43582 Mdot
.28675 .46221 Mdot
.70253 .49588 Mdot
.3224 .62493 Mdot
.49214 .2961 Mdot
.374 .33573 Mdot
.47991 .27742 Mdot
.69816 .57051 Mdot
.38147 .67721 Mdot
.64792 .6542 Mdot
.72086 .46837 Mdot
.6747 .37304 Mdot
.7053 .53328 Mdot
.34429 .66156 Mdot
.70206 .53698 Mdot
.70349 .4607 Mdot
.45615 .69653 Mdot
.41048 .67909 Mdot
.30676 .4382 Mdot
.47392 .7133 Mdot
.55932 .70632 Mdot
.62722 .65588 Mdot
.52973 .71452 Mdot
.51178 .70992 Mdot
.56133 .69937 Mdot
.64339 .3454 Mdot
.59372 .68027 Mdot
.66426 .37968 Mdot
.65449 .37014 Mdot
.31912 .40697 Mdot
.38062 .68946 Mdot
.42611 .70032 Mdot
.63932 .65614 Mdot
.60786 .68286 Mdot
.68079 .37873 Mdot
.67951 .40726 Mdot
.43972 .29977 Mdot
.70337 .57336 Mdot
.29766 .46171 Mdot
.61869 .67636 Mdot
.3709 .3419 Mdot
.31677 .39909 Mdot
.43473 .69451 Mdot
.46702 .71819 Mdot
.60948 .69187 Mdot
.66164 .63149 Mdot
.48532 .70269 Mdot
.58244 .68913 Mdot
.2953 .42185 Mdot
.64777 .65634 Mdot
.70982 .53768 Mdot
.6998 .46676 Mdot
.34122 .63601 Mdot
.3286 .6353 Mdot
.67502 .60461 Mdot
.66255 .65221 Mdot
.68115 .39782 Mdot
.7138 .51491 Mdot
.38678 .32938 Mdot
.59618 .31556 Mdot
.67142 .62244 Mdot
.4288 .29408 Mdot
.70105 .59527 Mdot
.46399 .28769 Mdot
.41299 .30513 Mdot
.39353 .69478 Mdot
.32853 .37961 Mdot
.55599 .71718 Mdot
.41323 .31811 Mdot
.56643 .69917 Mdot
.71957 .53111 Mdot
.35968 .64524 Mdot
.6873 .40262 Mdot
.40536 .31358 Mdot
.62908 .32978 Mdot
.70885 .435 Mdot
.59635 .67551 Mdot
.34062 .34581 Mdot
.3064 .40489 Mdot
.3103 .61622 Mdot
.668 .36716 Mdot
.54798 .70703 Mdot
.64993 .34256 Mdot
.61449 .32329 Mdot
.69515 .43307 Mdot
.60119 .67424 Mdot
.68068 .62139 Mdot
.54623 .70255 Mdot
.69317 .40013 Mdot
.32323 .38479 Mdot
.38 .66219 Mdot
.59163 .69287 Mdot
.29482 .55563 Mdot
.69635 .45695 Mdot
.31173 .38584 Mdot
.65316 .65153 Mdot
.36298 .33578 Mdot
.70651 .44404 Mdot
.28765 .43805 Mdot
.49171 .29397 Mdot
.35247 .35948 Mdot
.62755 .67949 Mdot
.47501 .70043 Mdot
.70354 .46417 Mdot
.58127 .3016 Mdot
.70548 .50854 Mdot
.53412 .71655 Mdot
.65914 .35513 Mdot
.32377 .39459 Mdot
.67907 .40816 Mdot
.70238 .5528 Mdot
.59246 .69967 Mdot
.32032 .59953 Mdot
.72104 .54117 Mdot
.61983 .66438 Mdot
.70431 .57653 Mdot
.38775 .68222 Mdot
.70194 .56622 Mdot
.66692 .643 Mdot
.60958 .69343 Mdot
.28862 .46386 Mdot
.50918 .72087 Mdot
.29546 .5176 Mdot
.68576 .57682 Mdot
.70534 .5917 Mdot
.69684 .54154 Mdot
.69209 .38978 Mdot
.70565 .46883 Mdot
.31773 .40095 Mdot
.69685 .40068 Mdot
.29205 .54446 Mdot
.51075 .27708 Mdot
.70728 .41722 Mdot
.2987 .48189 Mdot
.29146 .56316 Mdot
.30803 .55989 Mdot
.33525 .64278 Mdot
.30375 .60988 Mdot
.28257 .54253 Mdot
.29699 .57642 Mdot
.66499 .36356 Mdot
.27984 .4763 Mdot
.32134 .59309 Mdot
.51318 .27714 Mdot
.29776 .52037 Mdot
.50678 .72103 Mdot
.70643 .54049 Mdot
.55907 .28804 Mdot
.36623 .3287 Mdot
.34485 .65614 Mdot
.59996 .69688 Mdot
.68483 .41556 Mdot
.45466 .70166 Mdot
.3222 .60557 Mdot
.63246 .34322 Mdot
.38314 .32729 Mdot
.35484 .64045 Mdot
.32052 .61358 Mdot
.37623 .67778 Mdot
.33873 .35427 Mdot
.43381 .28572 Mdot
.51052 .72199 Mdot
.29947 .46553 Mdot
.41852 .70331 Mdot
.51129 .72148 Mdot
.66848 .3709 Mdot
.34193 .64798 Mdot
.51201 .70337 Mdot
.71452 .50353 Mdot
.6047 .3107 Mdot
.37565 .31497 Mdot
.55097 .71809 Mdot
.71418 .43559 Mdot
.69839 .46344 Mdot
.30293 .59821 Mdot
.38907 .3244 Mdot
.58934 .70477 Mdot
.5199 .28045 Mdot
.5692 .30503 Mdot
.28569 .46775 Mdot
.56931 .29402 Mdot
.43018 .31216 Mdot
.63356 .67407 Mdot
.30018 .52536 Mdot
.57824 .70641 Mdot
.27566 .48743 Mdot
.52003 .30045 Mdot
.62597 .32331 Mdot
.32372 .40107 Mdot
.69127 .61181 Mdot
.53735 .28293 Mdot
.30975 .4241 Mdot
.70052 .46883 Mdot
.63716 .34841 Mdot
.60002 .31703 Mdot
.34592 .63218 Mdot
.36159 .33838 Mdot
.64666 .3592 Mdot
.6466 .34655 Mdot
.70765 .53916 Mdot
.44779 .70349 Mdot
.70228 .42785 Mdot
.28588 .48267 Mdot
.34247 .63878 Mdot
.29393 .45068 Mdot
.29581 .4768 Mdot
.44667 .30375 Mdot
.63783 .64836 Mdot
.69478 .59238 Mdot
.49632 .72416 Mdot
.56391 .69305 Mdot
.53601 .70981 Mdot
.68366 .38206 Mdot
.46168 .7198 Mdot
.33824 .62338 Mdot
.6663 .36662 Mdot
.63689 .3322 Mdot
.3537 .64739 Mdot
.62408 .67336 Mdot
.5083 .705 Mdot
.69463 .60804 Mdot
.70565 .48829 Mdot
.66127 .35146 Mdot
.52462 .28329 Mdot
.69797 .4653 Mdot
.28039 .51307 Mdot
.30241 .39761 Mdot
.33126 .38042 Mdot
.45783 .29838 Mdot
.53685 .7211 Mdot
.30069 .41218 Mdot
.71727 .47277 Mdot
.28074 .52017 Mdot
.7125 .48557 Mdot
.34036 .37798 Mdot
.53957 .71629 Mdot
.34755 .3346 Mdot
.47275 .27677 Mdot
.69027 .56903 Mdot
.64672 .66133 Mdot
.38348 .68827 Mdot
.68397 .38134 Mdot
.52825 .29835 Mdot
.70273 .40253 Mdot
.4523 .7029 Mdot
.69681 .42131 Mdot
.41506 .31068 Mdot
.457 .28723 Mdot
.69683 .56588 Mdot
.71653 .48309 Mdot
.7051 .49486 Mdot
.63742 .32296 Mdot
.38573 .32531 Mdot
.69359 .43198 Mdot
.65443 .36498 Mdot
.704 .52259 Mdot
.31975 .37093 Mdot
.69253 .60285 Mdot
.68506 .39215 Mdot
.37192 .65517 Mdot
.63627 .34468 Mdot
.3548 .65035 Mdot
.63662 .35194 Mdot
.29132 .47739 Mdot
.55308 .71115 Mdot
.3153 .41174 Mdot
.40331 .68933 Mdot
.28805 .4261 Mdot
.4679 .28651 Mdot
.2963 .53186 Mdot
.57452 .31257 Mdot
.65334 .63601 Mdot
.70734 .42625 Mdot
.49063 .27925 Mdot
.69351 .60169 Mdot
.5316 .70867 Mdot
.63398 .35033 Mdot
.38416 .32924 Mdot
.29376 .44559 Mdot
.66603 .62342 Mdot
.58808 .29578 Mdot
.35937 .35681 Mdot
.72061 .50635 Mdot
.2798 .48482 Mdot
.68702 .57264 Mdot
.52495 .27662 Mdot
.70571 .47658 Mdot
.29355 .44474 Mdot
.65399 .63706 Mdot
.65684 .36432 Mdot
.3057 .40146 Mdot
.54344 .30426 Mdot
.5137 .27997 Mdot
.62245 .68854 Mdot
.50751 .27537 Mdot
.37733 .33689 Mdot
.42588 .28849 Mdot
.64865 .35983 Mdot
.45184 .28833 Mdot
.38673 .68344 Mdot
.3283 .37748 Mdot
.30137 .56242 Mdot
.71561 .53268 Mdot
.39628 .32005 Mdot
.48038 .72175 Mdot
.2924 .48896 Mdot
.27748 .48778 Mdot
.63098 .34386 Mdot
.58546 .29322 Mdot
.72296 .47385 Mdot
.66872 .61934 Mdot
.37029 .33625 Mdot
.27927 .50091 Mdot
.57172 .68744 Mdot
.29975 .53119 Mdot
.2847 .46583 Mdot
.54929 .69903 Mdot
.70896 .52186 Mdot
.43924 .30192 Mdot
.61542 .67099 Mdot
.66083 .36739 Mdot
.59495 .68372 Mdot
.55297 .30529 Mdot
.28123 .45726 Mdot
.44509 .69861 Mdot
.38227 .68846 Mdot
.58373 .31463 Mdot
.57971 .31198 Mdot
.32452 .36182 Mdot
.56407 .29046 Mdot
.67765 .37685 Mdot
.36613 .33456 Mdot
.70699 .5173 Mdot
.29823 .5416 Mdot
.53732 .70252 Mdot
.69198 .41968 Mdot
.70229 .40179 Mdot
.32789 .37813 Mdot
.67016 .64175 Mdot
.54412 .29809 Mdot
.27696 .49386 Mdot
.71185 .48267 Mdot
.33322 .37746 Mdot
.37334 .68565 Mdot
.30886 .38273 Mdot
.65721 .34793 Mdot
.354 .66231 Mdot
.69618 .42334 Mdot
.29765 .5823 Mdot
.37644 .68772 Mdot
.39555 .69586 Mdot
.29646 .42176 Mdot
.59986 .29965 Mdot
.31483 .41088 Mdot
.53697 .71372 Mdot
.53077 .70345 Mdot
.35622 .33659 Mdot
.37703 .67274 Mdot
.47388 .72281 Mdot
.33148 .61031 Mdot
.59925 .31961 Mdot
.68504 .58022 Mdot
.2911 .49727 Mdot
.29157 .49123 Mdot
.40875 .31079 Mdot
.68656 .41969 Mdot
.29022 .55989 Mdot
.44361 .28492 Mdot
.58604 .31889 Mdot
.3652 .66143 Mdot
.30948 .43542 Mdot
.69985 .43918 Mdot
.46139 .28313 Mdot
.65789 .36579 Mdot
.53975 .70759 Mdot
.33587 .65185 Mdot
.30548 .44822 Mdot
.29214 .57354 Mdot
.6787 .60669 Mdot
.48136 .27764 Mdot
.48036 .70669 Mdot
.34861 .64958 Mdot
.45251 .29909 Mdot
.3195 .59488 Mdot
.71084 .4882 Mdot
.28367 .45151 Mdot
.52988 .27718 Mdot
.62665 .68366 Mdot
.52828 .72172 Mdot
.44719 .3044 Mdot
.63292 .66948 Mdot
.70116 .46339 Mdot
.65063 .35689 Mdot
.32112 .37779 Mdot
.60138 .67394 Mdot
.59963 .68794 Mdot
.59778 .69165 Mdot
.35952 .3359 Mdot
.32289 .62249 Mdot
.28326 .52268 Mdot
.59978 .6925 Mdot
.53418 .28741 Mdot
.69793 .53742 Mdot
.57021 .30118 Mdot
.62779 .67744 Mdot
.55633 .71185 Mdot
.71633 .47907 Mdot
.70117 .54659 Mdot
.57412 .31189 Mdot
.32656 .62786 Mdot
.32402 .61793 Mdot
.69191 .3873 Mdot
.52463 .71864 Mdot
.63198 .65977 Mdot
.5644 .70888 Mdot
.38601 .68978 Mdot
.71314 .57184 Mdot
.64074 .64514 Mdot
.68942 .58494 Mdot
.68541 .61968 Mdot
.49051 .70519 Mdot
.42726 .30812 Mdot
.62993 .32425 Mdot
.53485 .2953 Mdot
.33625 .34782 Mdot
.36911 .34824 Mdot
.32244 .60237 Mdot
.43617 .69379 Mdot
.36439 .65378 Mdot
.59367 .67881 Mdot
.43401 .71244 Mdot
.67943 .60156 Mdot
.71003 .55474 Mdot
.34543 .62846 Mdot
.58323 .7074 Mdot
.33425 .35789 Mdot
.29653 .40411 Mdot
.71546 .46736 Mdot
.62555 .68062 Mdot
.4034 .30916 Mdot
.55123 .29126 Mdot
.28799 .49703 Mdot
.28291 .51315 Mdot
.31945 .59888 Mdot
.30945 .56219 Mdot
.7011 .53917 Mdot
.48664 .70153 Mdot
.31604 .60444 Mdot
.42615 .31195 Mdot
.29586 .57824 Mdot
.29854 .45215 Mdot
.52096 .29634 Mdot
.49837 .28287 Mdot
.48074 .71684 Mdot
.4881 .72433 Mdot
.61779 .32393 Mdot
.58075 .29085 Mdot
.58006 .30915 Mdot
.28784 .43384 Mdot
.3255 .63466 Mdot
.63786 .32829 Mdot
.6933 .44206 Mdot
.40858 .69253 Mdot
.5852 .70507 Mdot
.30108 .40372 Mdot
.68105 .4052 Mdot
.41425 .70407 Mdot
.69102 .60407 Mdot
.27794 .49348 Mdot
.47864 .70948 Mdot
.71659 .43937 Mdot
.64804 .34388 Mdot
.66645 .61918 Mdot
.68507 .39385 Mdot
.53837 .28684 Mdot
.47262 .28545 Mdot
.55941 .71244 Mdot
.57375 .30133 Mdot
.6757 .36067 Mdot
.46865 .28286 Mdot
.34541 .63016 Mdot
.29741 .55066 Mdot
.31598 .58371 Mdot
.31553 .38256 Mdot
.38899 .69276 Mdot
.40461 .31817 Mdot
.30623 .4305 Mdot
.70061 .42536 Mdot
.37833 .67148 Mdot
.632 .65307 Mdot
.29738 .55898 Mdot
.32491 .61178 Mdot
.69108 .58455 Mdot
.71231 .42889 Mdot
.36252 .34554 Mdot
.37085 .65949 Mdot
.43396 .69865 Mdot
.41097 .29348 Mdot
.49523 .29657 Mdot
.48929 .28942 Mdot
.32504 .63041 Mdot
.33521 .37189 Mdot
.69411 .42754 Mdot
.56737 .68938 Mdot
.65966 .34397 Mdot
.50375 .70207 Mdot
.51007 .71623 Mdot
.66981 .35719 Mdot
.69329 .42558 Mdot
.56395 .71257 Mdot
.56869 .6917 Mdot
.29499 .55048 Mdot
.56147 .29876 Mdot
.62546 .34117 Mdot
.6236 .33868 Mdot
.39294 .32942 Mdot
.70289 .47076 Mdot
.30784 .61568 Mdot
.47941 .28747 Mdot
.30009 .46828 Mdot
.55524 .30113 Mdot
.41072 .68501 Mdot
.33439 .38302 Mdot
.63976 .33101 Mdot
.56807 .29359 Mdot
.71684 .50487 Mdot
.70219 .42956 Mdot
.38137 .67991 Mdot
.70528 .46007 Mdot
.69506 .40674 Mdot
.52104 .7196 Mdot
.32394 .6213 Mdot
.30001 .57675 Mdot
.68105 .60316 Mdot
.61753 .32422 Mdot
.53687 .71088 Mdot
.71112 .55862 Mdot
.54318 .71795 Mdot
.66848 .61677 Mdot
.64715 .35486 Mdot
.65417 .65815 Mdot
.70367 .42966 Mdot
.65607 .37453 Mdot
.30567 .44606 Mdot
.29906 .56452 Mdot
.28833 .5534 Mdot
.32406 .36039 Mdot
.51511 .70366 Mdot
.31072 .41999 Mdot
.70551 .5251 Mdot
.30374 .54103 Mdot
.62453 .65694 Mdot
.39017 .67267 Mdot
.56963 .69798 Mdot
.30646 .56567 Mdot
.38091 .32924 Mdot
.7183 .49641 Mdot
.57607 .70097 Mdot
.33091 .63876 Mdot
.702 .44021 Mdot
.59916 .31122 Mdot
.6868 .41896 Mdot
.36462 .66411 Mdot
.55254 .30363 Mdot
.70652 .52558 Mdot
.31969 .37674 Mdot
.31659 .41132 Mdot
.69658 .42551 Mdot
.31212 .40532 Mdot
.49992 .27966 Mdot
.5877 .69811 Mdot
.55944 .29893 Mdot
.37362 .65939 Mdot
.63223 .34198 Mdot
.71564 .49582 Mdot
.68385 .58551 Mdot
.70547 .4705 Mdot
.29346 .53424 Mdot
.33095 .61392 Mdot
.28024 .45593 Mdot
.60684 .30944 Mdot
.54014 .30019 Mdot
.37899 .3385 Mdot
.71826 .48049 Mdot
.44313 .71603 Mdot
.65075 .65059 Mdot
.44324 .69981 Mdot
.6976 .57202 Mdot
.4185 .68279 Mdot
.32499 .40124 Mdot
.68767 .38275 Mdot
.69183 .56269 Mdot
.67786 .59748 Mdot
.47383 .72147 Mdot
.31698 .58314 Mdot
.45814 .69954 Mdot
.62801 .65708 Mdot
.61792 .68074 Mdot
.62603 .31978 Mdot
.66443 .62325 Mdot
.28421 .45831 Mdot
.29717 .4736 Mdot
.33636 .34778 Mdot
.30079 .53757 Mdot
.28608 .44586 Mdot
.56128 .69532 Mdot
.67158 .63713 Mdot
.67519 .40182 Mdot
.71213 .45418 Mdot
.51412 .29045 Mdot
.66284 .65104 Mdot
.38861 .32846 Mdot
.32826 .39305 Mdot
.64586 .6713 Mdot
.70007 .46105 Mdot
.38976 .307 Mdot
.31168 .5887 Mdot
.28745 .5464 Mdot
.40591 .69167 Mdot
.29269 .43681 Mdot
.36262 .67374 Mdot
.54684 .29867 Mdot
.51766 .7237 Mdot
.6402 .64566 Mdot
.36814 .32132 Mdot
.70181 .48769 Mdot
.40636 .30287 Mdot
.40939 .68379 Mdot
.50069 .71008 Mdot
.63236 .33394 Mdot
.69857 .40171 Mdot
.41876 .70513 Mdot
.31917 .41441 Mdot
.28842 .46835 Mdot
.40014 .67406 Mdot
.3322 .62917 Mdot
.41806 .31362 Mdot
.32645 .61749 Mdot
.71027 .50616 Mdot
.67785 .60127 Mdot
.50653 .29983 Mdot
.53362 .71469 Mdot
.59628 .32047 Mdot
.69099 .38748 Mdot
.48979 .7034 Mdot
.33858 .63076 Mdot
.68091 .40794 Mdot
.72091 .49452 Mdot
.51268 .72403 Mdot
.32206 .38586 Mdot
.51835 .71324 Mdot
.29355 .48911 Mdot
.28774 .52525 Mdot
.45572 .70981 Mdot
.37956 .32792 Mdot
.3531 .66075 Mdot
.33706 .62667 Mdot
.70768 .46871 Mdot
.30027 .53843 Mdot
.71238 .47337 Mdot
.52717 .70219 Mdot
.34437 .62977 Mdot
.71473 .48974 Mdot
.66197 .34979 Mdot
.29928 .48579 Mdot
.33137 .38086 Mdot
.63616 .33208 Mdot
.52671 .71203 Mdot
.29566 .54756 Mdot
.49506 .70363 Mdot
.70625 .49204 Mdot
.46814 .71227 Mdot
.5192 .29852 Mdot
.65844 .35913 Mdot
.53022 .28974 Mdot
.71606 .50453 Mdot
.48479 .71064 Mdot
.32629 .61735 Mdot
.31958 .62589 Mdot
.59982 .69709 Mdot
.69516 .42193 Mdot
.69137 .39718 Mdot
.69199 .43166 Mdot
.37868 .33774 Mdot
.58523 .68247 Mdot
.51825 .28518 Mdot
.32099 .61722 Mdot
.51431 .27597 Mdot
.62302 .6612 Mdot
.36862 .67 Mdot
.49114 .29241 Mdot
.59405 .69769 Mdot
.57379 .29001 Mdot
.49013 .70143 Mdot
.63756 .32986 Mdot
.32732 .3572 Mdot
.40468 .30462 Mdot
.61879 .32867 Mdot
.47447 .70181 Mdot
.67899 .60789 Mdot
.64296 .64078 Mdot
.47475 .28232 Mdot
.34066 .64857 Mdot
.31049 .43539 Mdot
.30486 .39781 Mdot
.4383 .71486 Mdot
.46047 .30243 Mdot
.41024 .29426 Mdot
.70226 .55303 Mdot
.61348 .31623 Mdot
.52678 .29607 Mdot
.50222 .29302 Mdot
.37638 .33642 Mdot
.71116 .52679 Mdot
.47812 .71105 Mdot
.29171 .54274 Mdot
.41973 .2985 Mdot
.59924 .6897 Mdot
.71187 .46109 Mdot
.28592 .51514 Mdot
.68684 .41249 Mdot
.36937 .31849 Mdot
.60804 .66907 Mdot
.67447 .37158 Mdot
.28008 .4827 Mdot
.64761 .3595 Mdot
.50517 .70835 Mdot
.31668 .61452 Mdot
.29693 .42488 Mdot
.51542 .70148 Mdot
.32709 .39731 Mdot
.49878 .28756 Mdot
.37647 .31821 Mdot
.67426 .62389 Mdot
.28094 .50618 Mdot
.56952 .71102 Mdot
.72228 .47618 Mdot
.40648 .69736 Mdot
.48239 .28559 Mdot
.67028 .39088 Mdot
.59449 .70268 Mdot
.40517 .32371 Mdot
.31618 .3746 Mdot
.68792 .4003 Mdot
.68862 .42568 Mdot
.6004 .29986 Mdot
.30385 .57095 Mdot
.35704 .35767 Mdot
.29601 .55 Mdot
.43039 .69637 Mdot
.46531 .28286 Mdot
.33721 .6264 Mdot
.28721 .43932 Mdot
.46584 .29693 Mdot
.71234 .42943 Mdot
.56888 .29296 Mdot
.72069 .51203 Mdot
.71702 .46857 Mdot
.30446 .41697 Mdot
.36942 .674 Mdot
.66211 .62119 Mdot
.69967 .56245 Mdot
.35109 .64452 Mdot
.38406 .33323 Mdot
.60543 .31696 Mdot
.70094 .40519 Mdot
.6587 .35872 Mdot
.64083 .64757 Mdot
.6536 .34749 Mdot
.62154 .67089 Mdot
.42293 .6889 Mdot
.566 .29312 Mdot
.55077 .69512 Mdot
.50118 .29206 Mdot
.60809 .30941 Mdot
.66752 .61788 Mdot
.70787 .49861 Mdot
.6026 .68054 Mdot
.6656 .64545 Mdot
.69758 .54945 Mdot
.51391 .70347 Mdot
.66644 .35771 Mdot
.70198 .40103 Mdot
.67156 .60628 Mdot
.4554 .28119 Mdot
.3858 .68672 Mdot
.65392 .36582 Mdot
.51374 .71359 Mdot
.66779 .35568 Mdot
.68561 .59023 Mdot
.52799 .30104 Mdot
.69837 .54171 Mdot
.28281 .45416 Mdot
.62735 .66539 Mdot
.32508 .36322 Mdot
.69366 .57289 Mdot
.67025 .35483 Mdot
.45998 .29075 Mdot
.71953 .5024 Mdot
.27773 .52786 Mdot
.66764 .64741 Mdot
.31762 .61876 Mdot
.37789 .68578 Mdot
.34788 .65183 Mdot
.5731 .31347 Mdot
.52637 .7045 Mdot
.55816 .6948 Mdot
.6052 .69807 Mdot
.41736 .68712 Mdot
.29816 .56228 Mdot
.41726 .69303 Mdot
.70899 .46314 Mdot
.56587 .70128 Mdot
.29798 .41396 Mdot
.63369 .3323 Mdot
.57662 .68977 Mdot
.70459 .56318 Mdot
.71621 .44353 Mdot
.61724 .32478 Mdot
.55172 .28186 Mdot
.29684 .46433 Mdot
.39196 .68353 Mdot
.55069 .71537 Mdot
.36965 .65268 Mdot
.70871 .51781 Mdot
.56172 .30328 Mdot
.62202 .68307 Mdot
.34429 .37208 Mdot
.65965 .63 Mdot
.38076 .33564 Mdot
.47941 .7191 Mdot
.63295 .34545 Mdot
.48289 .28689 Mdot
.28752 .4617 Mdot
.28493 .46726 Mdot
.60845 .68582 Mdot
.29238 .48629 Mdot
.35932 .65453 Mdot
.3704 .66913 Mdot
.51052 .29281 Mdot
.50612 .7071 Mdot
.65914 .62826 Mdot
.71052 .47393 Mdot
.50643 .70042 Mdot
.50963 .72312 Mdot
.45621 .295 Mdot
.46029 .29808 Mdot
.29151 .43141 Mdot
.55729 .71522 Mdot
.58596 .69216 Mdot
.62801 .33397 Mdot
.31909 .59221 Mdot
.34339 .3717 Mdot
.40858 .70412 Mdot
.35147 .34411 Mdot
.70061 .59768 Mdot
.33659 .64277 Mdot
.36849 .6682 Mdot
.39434 .31712 Mdot
.57422 .29394 Mdot
.29389 .55566 Mdot
.34978 .35539 Mdot
.33775 .37659 Mdot
.56717 .69417 Mdot
.70126 .49273 Mdot
.65074 .35842 Mdot
.36001 .65797 Mdot
.57421 .30497 Mdot
.7173 .47213 Mdot
.28967 .56506 Mdot
.41976 .69176 Mdot
.37896 .33936 Mdot
.63452 .3267 Mdot
.71489 .53439 Mdot
.49789 .71552 Mdot
.60017 .31297 Mdot
.49017 .71391 Mdot
.69461 .43442 Mdot
.65799 .37244 Mdot
.64087 .67117 Mdot
.67798 .39047 Mdot
.42364 .3135 Mdot
.33665 .38269 Mdot
.69379 .55096 Mdot
.4923 .29341 Mdot
.70675 .52042 Mdot
.28403 .51017 Mdot
.58453 .70376 Mdot
.51876 .7012 Mdot
.51468 .71474 Mdot
.37607 .6866 Mdot
.67783 .62705 Mdot
.30481 .5902 Mdot
.31634 .61562 Mdot
.60538 .31385 Mdot
.35204 .65825 Mdot
.67636 .60871 Mdot
.37303 .66586 Mdot
.32169 .37815 Mdot
.60675 .68465 Mdot
.36345 .66464 Mdot
.70026 .40179 Mdot
.71368 .52277 Mdot
.59706 .32 Mdot
.30702 .38457 Mdot
.31503 .60454 Mdot
.50505 .2891 Mdot
.71066 .56622 Mdot
.39725 .32402 Mdot
.42756 .30082 Mdot
.69228 .5912 Mdot
.27978 .46098 Mdot
.4447 .28302 Mdot
.33806 .38161 Mdot
.42721 .30406 Mdot
.53015 .28096 Mdot
.66315 .63087 Mdot
.37354 .66594 Mdot
.36454 .6774 Mdot
.4277 .70015 Mdot
.41654 .29708 Mdot
.34578 .37129 Mdot
.34711 .36104 Mdot
.67548 .6005 Mdot
.67332 .38556 Mdot
.29963 .52236 Mdot
.55053 .71789 Mdot
.44957 .30077 Mdot
.66855 .63268 Mdot
.36193 .67368 Mdot
.50319 .28371 Mdot
.69812 .56676 Mdot
.70394 .58742 Mdot
.30593 .57538 Mdot
.29652 .57032 Mdot
.37046 .66013 Mdot
.2989 .44847 Mdot
.64536 .35636 Mdot
.40376 .68544 Mdot
.61346 .69296 Mdot
.54105 .71554 Mdot
.57259 .31152 Mdot
.30106 .54093 Mdot
.50928 .28229 Mdot
.33073 .61778 Mdot
.41581 .69208 Mdot
.7078 .44133 Mdot
.69652 .44623 Mdot
.31983 .6046 Mdot
.69558 .61 Mdot
.6894 .62036 Mdot
.67334 .39915 Mdot
.64037 .35061 Mdot
.67437 .63993 Mdot
.33494 .61624 Mdot
.37823 .66574 Mdot
.72067 .49875 Mdot
.71559 .54834 Mdot
.69735 .55451 Mdot
.69188 .60177 Mdot
.34503 .34187 Mdot
.71774 .49462 Mdot
.28381 .44952 Mdot
.69043 .60458 Mdot
.39125 .3122 Mdot
.71538 .46213 Mdot
.48094 .71429 Mdot
.34605 .35277 Mdot
.47932 .71849 Mdot
.31409 .38792 Mdot
.53741 .71144 Mdot
.27546 .48767 Mdot
.31984 .37669 Mdot
.29358 .48354 Mdot
.70627 .5802 Mdot
.30408 .58811 Mdot
.34052 .62768 Mdot
.28566 .5544 Mdot
.64813 .65467 Mdot
.6104 .32358 Mdot
.64365 .33377 Mdot
.49641 .71601 Mdot
.37063 .34101 Mdot
.49174 .284 Mdot
.70298 .56003 Mdot
.52458 .70763 Mdot
.71461 .48208 Mdot
.5658 .29084 Mdot
.32483 .38226 Mdot
.38274 .68983 Mdot
.28322 .54739 Mdot
.28499 .50125 Mdot
.33817 .37877 Mdot
.50502 .72392 Mdot
.7156 .44614 Mdot
.29221 .49671 Mdot
.68142 .39313 Mdot
.47019 .72174 Mdot
.69837 .40441 Mdot
.29852 .53483 Mdot
.39428 .68045 Mdot
.63676 .65451 Mdot
.64392 .34401 Mdot
.35757 .33718 Mdot
.47856 .70895 Mdot
.33324 .6394 Mdot
.42762 .70013 Mdot
.65862 .36309 Mdot
.34419 .62897 Mdot
.34223 .3602 Mdot
.29899 .5497 Mdot
.62886 .66113 Mdot
.65555 .65968 Mdot
.7247 .51123 Mdot
.48878 .71038 Mdot
.35495 .64999 Mdot
.7004 .49019 Mdot
.71509 .47714 Mdot
.41791 .30365 Mdot
.66993 .61781 Mdot
.4387 .70143 Mdot
.28058 .52621 Mdot
.60424 .32523 Mdot
.38677 .68237 Mdot
.44702 .30137 Mdot
.396 .68781 Mdot
.29086 .56791 Mdot
.69895 .44645 Mdot
.2884 .55743 Mdot
.71208 .46642 Mdot
.52695 .29533 Mdot
.65026 .35625 Mdot
.2821 .53617 Mdot
.33054 .62732 Mdot
.35957 .33405 Mdot
.70719 .58055 Mdot
.6915 .40946 Mdot
.47207 .29427 Mdot
.28484 .52762 Mdot
.52574 .30006 Mdot
.72057 .53049 Mdot
.55958 .29668 Mdot
.49861 .71623 Mdot
.67672 .39823 Mdot
.53748 .28287 Mdot
.28465 .47363 Mdot
.63037 .65555 Mdot
.28711 .55412 Mdot
.55471 .7091 Mdot
.47587 .28934 Mdot
.47132 .27763 Mdot
.70431 .44956 Mdot
.44709 .30553 Mdot
.61247 .69323 Mdot
.29743 .55652 Mdot
.50102 .71965 Mdot
.40785 .30579 Mdot
.47443 .29893 Mdot
.29482 .44662 Mdot
.47458 .70647 Mdot
.39209 .69272 Mdot
.28516 .44822 Mdot
.32204 .36785 Mdot
.31311 .40304 Mdot
.67302 .36392 Mdot
.32099 .61351 Mdot
.30629 .58061 Mdot
.61552 .68407 Mdot
.51069 .28041 Mdot
.30527 .59025 Mdot
.54249 .70345 Mdot
.60913 .67543 Mdot
.65987 .36082 Mdot
.34995 .35221 Mdot
.45391 .71031 Mdot
.69118 .55898 Mdot
.32999 .63992 Mdot
.36166 .3379 Mdot
.70133 .43899 Mdot
.28156 .53212 Mdot
.57246 .70298 Mdot
.69767 .55856 Mdot
.70574 .47164 Mdot
.66789 .35086 Mdot
.6847 .62084 Mdot
.48574 .71348 Mdot
.57306 .30801 Mdot
.53788 .65996 Mdot
.37101 .57361 Mdot
.44407 .47131 Mdot
.30536 .54441 Mdot
.59511 .5679 Mdot
.48296 .64306 Mdot
.68607 .56414 Mdot
.47952 .57838 Mdot
.5971 .67257 Mdot
.53942 .61745 Mdot
.6246 .41851 Mdot
.45732 .53504 Mdot
.43545 .32131 Mdot
.66736 .47148 Mdot
.6373 .62795 Mdot
.33 .49055 Mdot
.66971 .52222 Mdot
.50786 .62458 Mdot
.67178 .46487 Mdot
.60658 .46484 Mdot
.55439 .33067 Mdot
.50101 .30415 Mdot
.60295 .41661 Mdot
.37589 .6496 Mdot
.54964 .64298 Mdot
.39771 .58783 Mdot
.6497 .57918 Mdot
.62746 .37765 Mdot
.68621 .5693 Mdot
.40132 .3833 Mdot
.61441 .57141 Mdot
.45168 .38018 Mdot
.45864 .66387 Mdot
.62798 .44762 Mdot
.39133 .58137 Mdot
.36862 .42996 Mdot
.5582 .68256 Mdot
.53439 .58825 Mdot
.59254 .59076 Mdot
.44273 .63798 Mdot
.62116 .55403 Mdot
.40936 .32395 Mdot
.6971 .47251 Mdot
.67691 .48365 Mdot
.4454 .36558 Mdot
.63739 .54194 Mdot
.47915 .57934 Mdot
.30652 .53791 Mdot
.59702 .56158 Mdot
.46641 .68659 Mdot
.69006 .45946 Mdot
.64804 .46763 Mdot
.63825 .39928 Mdot
.46016 .64967 Mdot
.65202 .41872 Mdot
.43692 .67156 Mdot
.51338 .62672 Mdot
.4918 .64625 Mdot
.60744 .4593 Mdot
.53741 .35316 Mdot
.61994 .33996 Mdot
.33333 .48808 Mdot
.5656 .44275 Mdot
.39848 .47007 Mdot
.65345 .48648 Mdot
.49533 .67614 Mdot
.67195 .57333 Mdot
.68431 .43772 Mdot
.58014 .35617 Mdot
.43978 .35004 Mdot
.60962 .4076 Mdot
.57303 .4466 Mdot
.63969 .53231 Mdot
.37812 .60324 Mdot
.5772 .60677 Mdot
.57822 .38096 Mdot
.59629 .66133 Mdot
.3507 .40746 Mdot
.53745 .52728 Mdot
.38396 .35942 Mdot
.48141 .65264 Mdot
.6167 .46285 Mdot
.43532 .56016 Mdot
.59778 .53275 Mdot
.39974 .64837 Mdot
.41125 .35356 Mdot
.55191 .64198 Mdot
.55534 .38382 Mdot
.66599 .53151 Mdot
.51845 .66662 Mdot
.65166 .42824 Mdot
.34265 .39695 Mdot
.4451 .41305 Mdot
.39343 .36897 Mdot
.48639 .5723 Mdot
.36911 .41705 Mdot
.62711 .44503 Mdot
.66883 .41612 Mdot
.48887 .30721 Mdot
.63057 .60241 Mdot
.46759 .3705 Mdot
.63917 .35803 Mdot
.53482 .32527 Mdot
.47933 .60433 Mdot
.62029 .61429 Mdot
.39551 .37401 Mdot
.58737 .36481 Mdot
.583 .52692 Mdot
.59549 .43622 Mdot
.5895 .58761 Mdot
.56698 .61402 Mdot
.67434 .51918 Mdot
.30865 .55625 Mdot
.60928 .63913 Mdot
.43894 .38346 Mdot
.6062 .37628 Mdot
.33082 .44237 Mdot
.53358 .69673 Mdot
.47195 .38802 Mdot
.58997 .6717 Mdot
.50974 .47277 Mdot
.66607 .55382 Mdot
.38536 .36284 Mdot
.69524 .54035 Mdot
.57158 .66456 Mdot
.60212 .41378 Mdot
.34855 .48903 Mdot
.67991 .52908 Mdot
.67374 .45452 Mdot
.5591 .32707 Mdot
.50172 .66202 Mdot
.36952 .36239 Mdot
.34831 .55607 Mdot
.39947 .44527 Mdot
.56268 .32403 Mdot
.38867 .4662 Mdot
.43399 .4382 Mdot
.39507 .33803 Mdot
.63503 .60922 Mdot
.43004 .42263 Mdot
.61577 .65725 Mdot
.57019 .37344 Mdot
.61949 .41397 Mdot
.54859 .654 Mdot
.31597 .55093 Mdot
.39955 .40327 Mdot
.45615 .43755 Mdot
.59297 .54744 Mdot
.69333 .54043 Mdot
.39185 .56252 Mdot
.62022 .43833 Mdot
.51956 .40869 Mdot
.52312 .35731 Mdot
.67173 .44775 Mdot
.6403 .3595 Mdot
.5012 .38373 Mdot
.41709 .54705 Mdot
.63039 .63822 Mdot
.50719 .42534 Mdot
.66847 .56011 Mdot
.49016 .41104 Mdot
.39923 .38131 Mdot
.56555 .32785 Mdot
.58756 .38621 Mdot
.64478 .52983 Mdot
.64083 .39955 Mdot
.58261 .62567 Mdot
.59032 .6239 Mdot
.49109 .36393 Mdot
.66669 .52117 Mdot
.62666 .47938 Mdot
.68701 .45889 Mdot
.50573 .61162 Mdot
.43064 .63082 Mdot
.36592 .55909 Mdot
.435 .51105 Mdot
.3376 .61552 Mdot
.36864 .43634 Mdot
.50608 .66516 Mdot
.32721 .59208 Mdot
.3745 .49641 Mdot
.38547 .58106 Mdot
.30471 .46244 Mdot
.35698 .56039 Mdot
.45548 .68093 Mdot
.56135 .54999 Mdot
.59107 .38178 Mdot
.46092 .45533 Mdot
.35607 .54392 Mdot
.65848 .56715 Mdot
.54881 .68395 Mdot
.38834 .36202 Mdot
.45172 .33698 Mdot
.50911 .64116 Mdot
.57891 .65233 Mdot
.56318 .31859 Mdot
.64098 .37655 Mdot
.43595 .32377 Mdot
.64541 .52875 Mdot
.67294 .56711 Mdot
.32478 .40624 Mdot
.60866 .49667 Mdot
.43282 .57201 Mdot
.4065 .62307 Mdot
.41919 .36276 Mdot
.57192 .56233 Mdot
.30907 .51036 Mdot
.45521 .61246 Mdot
.4415 .45413 Mdot
.39017 .40219 Mdot
.34598 .4218 Mdot
.342 .44099 Mdot
.67437 .49624 Mdot
.35929 .44247 Mdot
.3861 .38306 Mdot
.55134 .69174 Mdot
.56575 .48391 Mdot
.6581 .60701 Mdot
.39221 .52026 Mdot
.5371 .33094 Mdot
.56386 .42718 Mdot
.56172 .60993 Mdot
.46152 .65058 Mdot
.36764 .38811 Mdot
.45004 .67931 Mdot
.61338 .53678 Mdot
.43563 .38934 Mdot
.56706 .39657 Mdot
.46566 .38358 Mdot
.49718 .35719 Mdot
.50783 .57729 Mdot
.67399 .4582 Mdot
.36624 .64363 Mdot
.54222 .35083 Mdot
.63704 .57481 Mdot
.57719 .67012 Mdot
.53954 .32955 Mdot
.6139 .62484 Mdot
.60799 .60158 Mdot
.46368 .6388 Mdot
.40183 .55741 Mdot
.4675 .49081 Mdot
.54155 .59103 Mdot
.38474 .43531 Mdot
.54324 .39563 Mdot
.54376 .31776 Mdot
.48102 .32306 Mdot
.46853 .47549 Mdot
.56166 .47855 Mdot
.35419 .52496 Mdot
.57924 .34822 Mdot
.52714 .5599 Mdot
.37081 .58108 Mdot
.45959 .45213 Mdot
.51801 .63536 Mdot
.66958 .56348 Mdot
.41055 .55182 Mdot
.47624 .69301 Mdot
.43853 .36166 Mdot
.40045 .3336 Mdot
.48775 .35329 Mdot
.5576 .64867 Mdot
.65497 .40187 Mdot
.65538 .50868 Mdot
.36209 .50056 Mdot
.39551 .61061 Mdot
.49456 .54215 Mdot
.43111 .66351 Mdot
.61611 .3483 Mdot
.67705 .5502 Mdot
.57272 .63332 Mdot
.36112 .63077 Mdot
.43798 .5274 Mdot
.55358 .63195 Mdot
.37255 .48094 Mdot
.5822 .67393 Mdot
.69362 .52975 Mdot
.55574 .35728 Mdot
.50473 .30484 Mdot
.31824 .5048 Mdot
.56278 .45432 Mdot
.31087 .55906 Mdot
.47794 .33083 Mdot
.58477 .54123 Mdot
.45284 .66016 Mdot
.63473 .37884 Mdot
.51869 .36532 Mdot
.44558 .31825 Mdot
.4979 .35584 Mdot
.61651 .40896 Mdot
.65253 .49408 Mdot
.36052 .60317 Mdot
.62099 .58105 Mdot
.66617 .44231 Mdot
.37938 .63755 Mdot
.61747 .38219 Mdot
.60318 .54777 Mdot
.68783 .48977 Mdot
.44438 .68261 Mdot
.45347 .69301 Mdot
.34935 .45171 Mdot
.3698 .60336 Mdot
.43063 .47475 Mdot
.69451 .49336 Mdot
.33055 .54169 Mdot
.61893 .53679 Mdot
.65824 .61051 Mdot
.58124 .65457 Mdot
.67608 .53133 Mdot
.57839 .67113 Mdot
.47744 .31223 Mdot
.64927 .38269 Mdot
.55876 .6282 Mdot
.36899 .49936 Mdot
.40592 .40467 Mdot
.35789 .49445 Mdot
.58808 .64775 Mdot
.40511 .52534 Mdot
.66472 .57426 Mdot
.46604 .64979 Mdot
.55462 .5138 Mdot
.63546 .60351 Mdot
.45972 .60478 Mdot
.54563 .67705 Mdot
.63118 .63421 Mdot
.4601 .34825 Mdot
.33857 .49922 Mdot
.52905 .59521 Mdot
.4007 .66475 Mdot
.49881 .46609 Mdot
.48733 .60607 Mdot
.34137 .54187 Mdot
.51299 .60048 Mdot
.38016 .65435 Mdot
.67314 .40639 Mdot
.56761 .58741 Mdot
.52762 .40334 Mdot
.33764 .56888 Mdot
.45441 .66252 Mdot
.51731 .66418 Mdot
.67212 .45257 Mdot
.33579 .5115 Mdot
.4377 .34748 Mdot
.53488 .50664 Mdot
.3542 .53865 Mdot
.46201 .42559 Mdot
.34821 .46342 Mdot
.30995 .46418 Mdot
.49411 .35933 Mdot
.60025 .56676 Mdot
.32742 .5563 Mdot
.61096 .36627 Mdot
.43381 .50308 Mdot
.43624 .56675 Mdot
.55232 .35271 Mdot
.45082 .576 Mdot
.45883 .56012 Mdot
.47289 .45313 Mdot
.55912 .34481 Mdot
.56357 .57385 Mdot
.61155 .54793 Mdot
.68578 .55192 Mdot
.38272 .39689 Mdot
.55078 .61369 Mdot
.60943 .60561 Mdot
.53959 .4032 Mdot
.41835 .67978 Mdot
.42746 .51366 Mdot
.69115 .46637 Mdot
.52072 .4411 Mdot
.57164 .62002 Mdot
.40323 .33169 Mdot
.57937 .55749 Mdot
.46294 .4636 Mdot
.32826 .51625 Mdot
.32892 .5672 Mdot
.42361 .58909 Mdot
.38138 .3758 Mdot
.61933 .53464 Mdot
.59104 .64009 Mdot
.62353 .56069 Mdot
.39986 .63002 Mdot
.66686 .39163 Mdot
.43412 .34095 Mdot
.56859 .32207 Mdot
.65699 .56668 Mdot
.44573 .6089 Mdot
.36509 .36763 Mdot
.55523 .4861 Mdot
.61897 .49614 Mdot
.65916 .40696 Mdot
.58861 .35344 Mdot
.58511 .37154 Mdot
.41605 .50948 Mdot
.64293 .43794 Mdot
.542 .35408 Mdot
.61874 .62061 Mdot
.47736 .31437 Mdot
.54711 .36289 Mdot
.65493 .62363 Mdot
.57751 .38103 Mdot
.63905 .61855 Mdot
.64866 .42554 Mdot
.48345 .60118 Mdot
.58486 .54873 Mdot
.52115 .42493 Mdot
.60314 .63856 Mdot
.67069 .49904 Mdot
.5667 .50924 Mdot
.47852 .68475 Mdot
.5334 .67065 Mdot
.59952 .65952 Mdot
.40401 .59321 Mdot
.5779 .5247 Mdot
.3287 .55418 Mdot
.52821 .30658 Mdot
.38537 .62474 Mdot
.68963 .47525 Mdot
.53686 .69407 Mdot
.62545 .48434 Mdot
.56231 .68467 Mdot
.46363 .35131 Mdot
.62784 .48301 Mdot
.33822 .44677 Mdot
.3411 .38205 Mdot
.33622 .49822 Mdot
.5732 .60125 Mdot
.47727 .33138 Mdot
.53445 .33149 Mdot
.49924 .31898 Mdot
.3379 .43348 Mdot
.51886 .34357 Mdot
.38105 .63705 Mdot
.56437 .52422 Mdot
.38276 .60363 Mdot
.34998 .4937 Mdot
.53307 .34364 Mdot
.69112 .50595 Mdot
.41356 .40465 Mdot
.47907 .62561 Mdot
.60141 .3617 Mdot
.34182 .47296 Mdot
.45251 .69136 Mdot
.50298 .43963 Mdot
.60607 .44592 Mdot
.43916 .3104 Mdot
.32546 .455 Mdot
.55704 .65506 Mdot
.50532 .37905 Mdot
.56615 .66388 Mdot
.63998 .63858 Mdot
.62897 .42114 Mdot
.47977 .63599 Mdot
.35377 .62776 Mdot
.64251 .48634 Mdot
.36654 .36168 Mdot
.60011 .53951 Mdot
.67333 .41477 Mdot
.35092 .48148 Mdot
.48548 .36159 Mdot
.50934 .38302 Mdot
.33372 .45234 Mdot
.41912 .40412 Mdot
.41893 .41173 Mdot
.37131 .64604 Mdot
.50332 .63384 Mdot
.38006 .61238 Mdot
.39035 .39933 Mdot
.43701 .63311 Mdot
.442 .35093 Mdot
.56209 .31162 Mdot
.60786 .47055 Mdot
.67838 .54342 Mdot
.36185 .58389 Mdot
.36961 .59533 Mdot
.52659 .3669 Mdot
.66518 .53644 Mdot
.45458 .48975 Mdot
.45838 .43926 Mdot
.64635 .41606 Mdot
.41268 .6497 Mdot
.5133 .5882 Mdot
.32838 .46348 Mdot
.47736 .69277 Mdot
.30686 .50562 Mdot
.5896 .38516 Mdot
.61885 .5817 Mdot
.57494 .53764 Mdot
.66989 .56886 Mdot
.42355 .48101 Mdot
.35054 .59899 Mdot
.38848 .3931 Mdot
.57376 .53634 Mdot
.38608 .58784 Mdot
.35784 .46398 Mdot
.60774 .61028 Mdot
.65191 .54323 Mdot
.48886 .58237 Mdot
.59282 .46873 Mdot
.56495 .68902 Mdot
.60662 .40835 Mdot
.39366 .33571 Mdot
.33013 .52136 Mdot
.65199 .53592 Mdot
.36255 .59062 Mdot
.44071 .42696 Mdot
.57372 .41922 Mdot
.32784 .48413 Mdot
.57813 .3433 Mdot
.50707 .66609 Mdot
.61636 .38412 Mdot
.65955 .54735 Mdot
.61783 .49135 Mdot
.3691 .61202 Mdot
.33354 .49136 Mdot
.43555 .58824 Mdot
.54452 .53278 Mdot
.48012 .42471 Mdot
.51992 .68897 Mdot
.55108 .63991 Mdot
.40364 .56143 Mdot
.67977 .4429 Mdot
.33226 .46323 Mdot
.60599 .42811 Mdot
.35566 .45708 Mdot
.33022 .48093 Mdot
.684 .54448 Mdot
.57659 .63408 Mdot
.67308 .42733 Mdot
.35748 .53804 Mdot
.44292 .31048 Mdot
.48226 .69842 Mdot
.44995 .67739 Mdot
.45899 .59788 Mdot
.50628 .394 Mdot
.33907 .60499 Mdot
.54089 .67477 Mdot
.59889 .41839 Mdot
.58613 .6708 Mdot
.46838 .31679 Mdot
.50505 .57255 Mdot
.48674 .64702 Mdot
.41635 .48103 Mdot
.64905 .50011 Mdot
.50693 .63314 Mdot
.45048 .38155 Mdot
.39521 .5117 Mdot
.47382 .64218 Mdot
.48222 .64916 Mdot
.42571 .56243 Mdot
.63645 .59051 Mdot
.43175 .38295 Mdot
.59677 .37407 Mdot
.34208 .61222 Mdot
.43718 .6362 Mdot
.37111 .59174 Mdot
.58865 .54662 Mdot
.47293 .38041 Mdot
.33557 .38863 Mdot
.32566 .57467 Mdot
.42457 .64607 Mdot
.67302 .55241 Mdot
.50407 .53721 Mdot
.38963 .60257 Mdot
.38495 .61026 Mdot
.65932 .47902 Mdot
.58152 .53204 Mdot
.44924 .47308 Mdot
.696 .47841 Mdot
.62071 .35962 Mdot
.34874 .62871 Mdot
.32406 .58628 Mdot
.63902 .55699 Mdot
.41415 .58 Mdot
.5714 .36869 Mdot
.68366 .49976 Mdot
.31524 .5589 Mdot
.62588 .51641 Mdot
.35435 .61851 Mdot
.3849 .54306 Mdot
.33965 .60353 Mdot
.36682 .4268 Mdot
.6907 .52526 Mdot
.59113 .62975 Mdot
.64994 .46054 Mdot
.51832 .36794 Mdot
.55001 .5531 Mdot
.52233 .34054 Mdot
.45546 .40703 Mdot
.50122 .37136 Mdot
.46834 .63151 Mdot
.4767 .56052 Mdot
.61015 .39505 Mdot
.47735 .33328 Mdot
.60279 .37234 Mdot
.41835 .45778 Mdot
.57061 .44791 Mdot
.56184 .32487 Mdot
.50789 .43448 Mdot
.62807 .526 Mdot
.66286 .60361 Mdot
.49112 .54601 Mdot
.5544 .34137 Mdot
.69548 .46508 Mdot
.59416 .45108 Mdot
.50606 .64517 Mdot
.65437 .56778 Mdot
.43462 .38553 Mdot
.57984 .63897 Mdot
.60276 .38104 Mdot
.37463 .59359 Mdot
.55794 .39694 Mdot
.4408 .6559 Mdot
.3902 .46344 Mdot
.30077 .49351 Mdot
.39475 .44276 Mdot
.33542 .40756 Mdot
.40333 .66133 Mdot
.37601 .48781 Mdot
.41995 .35757 Mdot
.39558 .64644 Mdot
.52651 .42652 Mdot
.61975 .46163 Mdot
.68707 .46869 Mdot
.39097 .36324 Mdot
.34619 .5815 Mdot
.61398 .6338 Mdot
.58433 .3728 Mdot
.3231 .43473 Mdot
.3303 .49226 Mdot
.66287 .54254 Mdot
.54312 .43086 Mdot
.43206 .32164 Mdot
.53919 .50841 Mdot
.49082 .32966 Mdot
.59989 .53957 Mdot
.6602 .61417 Mdot
.39725 .37958 Mdot
.62583 .46841 Mdot
.52049 .42847 Mdot
.37489 .5855 Mdot
.46485 .64785 Mdot
.37622 .64232 Mdot
.36377 .54579 Mdot
.40666 .32543 Mdot
.37731 .57281 Mdot
.6276 .44037 Mdot
.42753 .59375 Mdot
.57236 .37197 Mdot
.4634 .32519 Mdot
.56886 .42761 Mdot
.65407 .41873 Mdot
.32721 .53699 Mdot
.42026 .40886 Mdot
.65155 .6138 Mdot
.57285 .67496 Mdot
.32617 .58093 Mdot
.52213 .34412 Mdot
.33794 .49976 Mdot
.38627 .56466 Mdot
.44972 .41074 Mdot
.44939 .34232 Mdot
.51252 .45915 Mdot
.53367 .30935 Mdot
.43342 .61951 Mdot
.61048 .6374 Mdot
.52104 .65397 Mdot
.6808 .44749 Mdot
.54949 .33993 Mdot
.55774 .62803 Mdot
.47752 .57309 Mdot
.50754 .41936 Mdot
.36601 .35885 Mdot
.64584 .56233 Mdot
.59535 .33113 Mdot
.46188 .66352 Mdot
.3321 .49904 Mdot
.61938 .65237 Mdot
.48598 .59835 Mdot
.53107 .57736 Mdot
.3397 .5256 Mdot
.67961 .5075 Mdot
.56901 .64042 Mdot
.50897 .67387 Mdot
.34289 .45095 Mdot
.54785 .59771 Mdot
.46373 .33099 Mdot
.62843 .3952 Mdot
.51628 .57379 Mdot
.49654 .32566 Mdot
.68289 .43144 Mdot
.3431 .44057 Mdot
.35599 .52924 Mdot
.31919 .44002 Mdot
.4507 .68801 Mdot
.45719 .60978 Mdot
.49343 .35781 Mdot
.54762 .55178 Mdot
.6764 .52941 Mdot
.50921 .65569 Mdot
.56499 .33836 Mdot
.3136 .50732 Mdot
.62153 .36715 Mdot
.61133 .45276 Mdot
.38795 .58161 Mdot
.3935 .59372 Mdot
.61555 .59437 Mdot
.59489 .54908 Mdot
.44936 .55647 Mdot
.58971 .46726 Mdot
.42519 .61779 Mdot
.45071 .33534 Mdot
.3272 .46792 Mdot
.54666 .68154 Mdot
.39603 .33321 Mdot
.47481 .66699 Mdot
.48774 .66974 Mdot
.59579 .41941 Mdot
.56737 .59583 Mdot
.53477 .41639 Mdot
.52372 .3973 Mdot
.63472 .35364 Mdot
.3244 .56188 Mdot
.57192 .6211 Mdot
.58738 .44969 Mdot
.65496 .45471 Mdot
.49605 .61267 Mdot
.41807 .32327 Mdot
.66504 .49389 Mdot
.54609 .33039 Mdot
.57762 .38043 Mdot
.66597 .47851 Mdot
.61273 .54099 Mdot
.62938 .60853 Mdot
.38528 .40578 Mdot
.61934 .4582 Mdot
.45375 .37746 Mdot
.67956 .49056 Mdot
.41386 .53601 Mdot
.43079 .67251 Mdot
.34764 .55716 Mdot
.40091 .48843 Mdot
.40975 .43335 Mdot
.34217 .46054 Mdot
.31074 .44407 Mdot
.32408 .58563 Mdot
.65108 .43609 Mdot
.32501 .52041 Mdot
.50509 .62933 Mdot
.30332 .51252 Mdot
.53862 .39632 Mdot
.54617 .59677 Mdot
.38748 .62944 Mdot
.46693 .44741 Mdot
.5122 .34676 Mdot
.61394 .60926 Mdot
.53262 .65463 Mdot
.44311 .34575 Mdot
.46253 .69241 Mdot
.5449 .68572 Mdot
.67038 .54019 Mdot
.46645 .30875 Mdot
.5198 .65763 Mdot
.32409 .45103 Mdot
.62739 .35773 Mdot
.6333 .37879 Mdot
.61882 .59048 Mdot
.50849 .37612 Mdot
.64742 .37276 Mdot
.66076 .57214 Mdot
.34376 .37713 Mdot
.61425 .35249 Mdot
.37709 .44293 Mdot
.62978 .64267 Mdot
.40102 .65798 Mdot
.41297 .4453 Mdot
.30698 .53325 Mdot
.4603 .35749 Mdot
.39024 .61796 Mdot
.60349 .46337 Mdot
.33234 .5184 Mdot
.61342 .39178 Mdot
.62163 .3807 Mdot
.67302 .52612 Mdot
.45242 .62627 Mdot
.64239 .38418 Mdot
.65531 .46862 Mdot
.44475 .66299 Mdot
.33541 .50474 Mdot
.3984 .43071 Mdot
.54598 .54665 Mdot
.45198 .43443 Mdot
.40601 .38108 Mdot
.52165 .33409 Mdot
.51995 .31408 Mdot
.49611 .30582 Mdot
.34531 .54007 Mdot
.56433 .41758 Mdot
.45331 .50253 Mdot
.34957 .44746 Mdot
.65376 .49611 Mdot
.62533 .46632 Mdot
.60238 .39073 Mdot
.45732 .61015 Mdot
.52955 .69674 Mdot
.33429 .45947 Mdot
.39342 .52789 Mdot
.54574 .328 Mdot
.67387 .49956 Mdot
.65183 .4353 Mdot
.32749 .49109 Mdot
.44336 .5516 Mdot
.38546 .49118 Mdot
.33618 .58453 Mdot
.38531 .35701 Mdot
.62465 .61039 Mdot
.34049 .5928 Mdot
.32567 .40815 Mdot
.66418 .45439 Mdot
.52817 .37691 Mdot
.69032 .44765 Mdot
.6038 .35699 Mdot
.37055 .5429 Mdot
.3318 .53481 Mdot
.59285 .46108 Mdot
.68251 .55096 Mdot
.46089 .63648 Mdot
.61675 .44324 Mdot
.6198 .38504 Mdot
.41928 .60992 Mdot
.67335 .40668 Mdot
.42604 .468 Mdot
.69445 .45541 Mdot
.46859 .35915 Mdot
.32531 .48342 Mdot
.50278 .68106 Mdot
.35572 .42276 Mdot
.55461 .6846 Mdot
.47576 .61241 Mdot
.47203 .66807 Mdot
.35879 .59528 Mdot
.61962 .43946 Mdot
.32638 .51737 Mdot
.42097 .59499 Mdot
.32623 .47805 Mdot
.38377 .34944 Mdot
.69965 .5062 Mdot
.42145 .55874 Mdot
.36286 .56802 Mdot
.5423 .61429 Mdot
.57939 .59961 Mdot
.64709 .41591 Mdot
.48634 .32815 Mdot
.6347 .49314 Mdot
.49595 .69837 Mdot
.44389 .43914 Mdot
.48586 .36616 Mdot
.61857 .48961 Mdot
.48164 .36612 Mdot
.42303 .45231 Mdot
.43942 .68029 Mdot
.34956 .61715 Mdot
.59165 .64181 Mdot
.37386 .51807 Mdot
.32626 .59368 Mdot
.30408 .51795 Mdot
.59799 .67319 Mdot
.61656 .34777 Mdot
.33866 .57006 Mdot
.61813 .37084 Mdot
.46118 .36153 Mdot
.46918 .66367 Mdot
.36774 .58999 Mdot
.63384 .3819 Mdot
.50459 .69375 Mdot
.37166 .58423 Mdot
.58914 .32486 Mdot
.64013 .42536 Mdot
.3909 .33531 Mdot
.6551 .57075 Mdot
.52293 .62937 Mdot
.5605 .687 Mdot
.307 .48104 Mdot
.62625 .43119 Mdot
.61315 .59441 Mdot
.66984 .5387 Mdot
.60386 .38135 Mdot
.41778 .41453 Mdot
.65801 .54005 Mdot
.45132 .32851 Mdot
.37671 .61201 Mdot
.44219 .43199 Mdot
.57089 .61256 Mdot
.40405 .53962 Mdot
.41099 .38531 Mdot
.31788 .48036 Mdot
.30577 .4575 Mdot
.40555 .51107 Mdot
.42378 .36168 Mdot
.61672 .34626 Mdot
.36567 .35634 Mdot
.56921 .59202 Mdot
.50207 .64398 Mdot
.40673 .49443 Mdot
.57326 .54469 Mdot
.67767 .58611 Mdot
.33428 .56297 Mdot
.39102 .46097 Mdot
.64967 .40226 Mdot
.5792 .53929 Mdot
.50906 .62069 Mdot
.52149 .61241 Mdot
.39916 .41896 Mdot
.67936 .58796 Mdot
.37701 .64862 Mdot
.32223 .42561 Mdot
.47323 .68515 Mdot
.3049 .51074 Mdot
.54813 .41329 Mdot
.66659 .42978 Mdot
.63118 .43077 Mdot
.61323 .36862 Mdot
.4544 .39527 Mdot
.40372 .37862 Mdot
.67198 .59023 Mdot
.35976 .43325 Mdot
.48912 .44847 Mdot
.666 .50797 Mdot
.39023 .54028 Mdot
.32844 .48227 Mdot
.43535 .44416 Mdot
.33055 .40701 Mdot
.43625 .33702 Mdot
.47378 .37667 Mdot
.65688 .50594 Mdot
.66528 .58211 Mdot
.64948 .42865 Mdot
.36359 .4977 Mdot
.5385 .65925 Mdot
.31889 .50564 Mdot
.51611 .35999 Mdot
.59272 .48749 Mdot
.57294 .60711 Mdot
.40596 .56943 Mdot
.33538 .53768 Mdot
.41868 .32106 Mdot
.40519 .52551 Mdot
.41519 .43098 Mdot
.33883 .47026 Mdot
.6487 .61692 Mdot
.49345 .51468 Mdot
.42829 .43991 Mdot
.3347 .44795 Mdot
.36525 .35221 Mdot
.3864 .58961 Mdot
.51914 .6847 Mdot
.6661 .42122 Mdot
.32028 .43979 Mdot
.32883 .53115 Mdot
.66523 .43783 Mdot
.58905 .46623 Mdot
.59783 .33848 Mdot
.43299 .43254 Mdot
.52753 .67874 Mdot
.63637 .57163 Mdot
.34937 .39992 Mdot
.46517 .42185 Mdot
.37538 .65108 Mdot
.50317 .3659 Mdot
.53186 .41699 Mdot
.46508 .66909 Mdot
.59787 .38982 Mdot
.4129 .63707 Mdot
.66198 .52976 Mdot
.46672 .353 Mdot
.56143 .32325 Mdot
.37146 .34933 Mdot
.52145 .58333 Mdot
.6847 .44547 Mdot
.56119 .41592 Mdot
.55132 .65981 Mdot
.57242 .51948 Mdot
.67103 .40335 Mdot
.57758 .65517 Mdot
.36869 .4299 Mdot
.55475 .57272 Mdot
.63014 .34952 Mdot
.42751 .60804 Mdot
.50714 .54676 Mdot
.57725 .58669 Mdot
.48665 .59786 Mdot
.48386 .57437 Mdot
.64594 .56983 Mdot
.5013 .52659 Mdot
.59566 .63682 Mdot
.62896 .55677 Mdot
.40137 .44987 Mdot
.6107 .43796 Mdot
.4726 .38938 Mdot
.32279 .4102 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo09Kooooo2Ol000000ooooooo0000o`000007o`000:3ooooo
000Looooo`03o`000?oooooooooo09;ooooo6ol0002Looooo`007?ooool00ol0003oooooooooo`2=
ooooob3o000000?oooooo`000?l000001?l0002Eooooo`007?ooool00ol0003oooooooooo`29oooo
obko0000T_ooool001cooooo00?o0000ooooooooool0Q_oooolbo`00097ooooo000Looooo`03o`00
0?oooooooooo08Cooooo>?l0002=ooooo`007?ooool00ol0003oooooooooo`22ooooob[o000000?o
ooooo`000?l000003ol0002;ooooo`007?ooool00ol0003oooooooooo`20ooooocoo0000R_ooool0
01cooooo0_l0001oooooodGo0000Q_ooool001cooooo00?o0000ooooooooool0NooooolPo`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?l000007_l00025ooooo`007?ooool00ol0003o
ooooooooo`1joooooaKo000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo1ol00006oooo
o`;o000000?oooooo`000?l000006?l00024ooooo`007?ooool00ol0003oooooooooo`1joooooaKo
00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`000006ooooo`Co00000ooooolIo`00087o
oooo000Looooo`03o`000?oooooooooo07Oooooo5ol00006ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0000Oooooo5Ol00021ooooo`007?ooool00ol0003oooooooooo`1eoooooaGo00002_oo
ool2o`000003ooooool0003o000000cooooo0_l0000<ooooo`;o000000?oooooo`000?l000004Ol0
0020ooooo`007?ooool00ol0003oooooooooo`1doooooa?o00001_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001?oooolB
o`0007kooooo000Looooo`03o`000?oooooooooo07Cooooo4_l00003ooooo`?o000000?oooooo`00
0?l000002Oooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool4o`0000Cooooo4_l0001loooo
o`007?ooool00ol0003oooooooooo`1boooooa7o000000?oooooo`000?l000000oooool3o`0000Oo
oooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`Co00001OoooolAo`0007co
oooo000Looooo`03o`000?oooooooooo073ooooo4ol000000ooooooo0000o`000004ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o0000
0_ooool4o`0000Kooooo0_l00002ooooo`ko0000Noooool001cooooo00?o0000ooooooooool0Kooo
oolBo`0000kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00003?oo
ool3o`000003ooooool0003o000000Ko00002?ooool2o`000003ooooool0003o000000co0000N_oo
ool001cooooo00?o0000ooooooooool0KOoooolDo`0000kooooo0_l00002ooooo`;o00000_ooool2
o`0000?ooooo0_l00008ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00003?ooool2
o`0000;ooooo3_l0001iooooo`007?ooool00ol0003oooooooooo`1]oooooa?o00002_ooool2o`00
00?ooooo0_l00006ooooo`;o00003Oooool2o`0000cooooo0_l00008ooooo`;o00000oooool>o`00
07Sooooo000Looooo`03o`000?oooooooooo06cooooo3_l00002ooooo`?o00002_ooool3o`0000?o
oooo0_l0000Eooooo`;o00001oooool3o`0000;ooooo0_l00008ooooo`;o00001Oooool?o`0007Go
oooo000Looooo`03o`000?oooooooooo06[ooooo3ol0000@ooooo`;o00000oooool2o`0001Gooooo
0ol000000ooooooo0000o`000004ooooo`Go00001?ooool2o`0000cooooo3_l0001eooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`oo00004_ooool6o`0001?ooooo1Ol000000ooooooo0000o`00
0007ooooo`;o00001?ooool2o`0000[ooooo4Ol0001dooooo`007?ooool2o`0006[ooooo3_l00002
ooooo`;o00003oooool4o`0000Cooooo0_l0000?ooooo`;o00001oooool2o`0000[ooooo0_l0000:
ooooo`?o000000?oooooo`000?l000003Ol0001booooo`007?ooool00ol0003oooooooooo`1Yoooo
o`ko00000_ooool2o`0000Oooooo0_l00007ooooo`?o00001?ooool4o`0000Gooooo0_l0000>oooo
o`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool?o`00
077ooooo000Looooo`03o`000?oooooooooo06Oooooo3_l00004ooooo`;o00001oooool2o`0000oo
oooo0ol00005ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo0_l00007ooooo`Co
00000oooool2o`0000;ooooo0_l00004ooooo`ko0000LOooool001cooooo00?o0000ooooooooool0
I_ooool?o`0000Cooooo0_l0000:ooooo`;o00002oooool4o`0000Oooooo0ol00004ooooo`Co0000
1?ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`go0000
L?ooool001cooooo00?o0000ooooooooool0IOooool=o`000004ooooool0003o0000o`0000?ooooo
1?l00007ooooo`Co00000oooool2o`0000Gooooo1?l00004ooooo`;o000000Coooooo`000?l0003o
00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool4o`0000;o
oooo3_l0001_ooooo`007?ooool00ol0003oooooooooo`1Uooooo`_o00000oooool3o`0000?ooooo
1?l00007ooooo`Co00000oooool4o`0000?ooooo0_l00005ooooo`Go00000_ooool2o`0000?ooooo
0_l00007ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`_o0000
Koooool001cooooo00?o0000ooooooooool0I?ooool<o`0000?ooooo0_l00007ooooo`;o00003ooo
ool2o`0000[ooooo1Ol00002ooooo`;o00000oooool4o`0000gooooo0_l00003ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Sooooo2ol0001^ooooo`007?ooool00ol0003oooooooooo`1S
ooooo`co00001?ooool2o`0000Oooooo0_l0000Fooooo`;o00002Oooool2o`0000Cooooo1?l0000=
ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Wooooo2ol0001]
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`go00003_ooool2o`0001Gooooo0_l00009oooo
o`;o00005?ooool3o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0000Sooooo3Ol0001]oooo
o`007?ooool00ol0003oooooooooo`1Rooooo`co00002_ooool2o`0000?ooooo1?l0000?ooooo`;o
00001?ooool2o`0000Wooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000<o`0006co
oooo000Looooo`03o`000?oooooooooo067ooooo3Ol0000:ooooo`;o00000oooool5o`0000gooooo
0ol00004ooooo`;o00002?ooool3o`0000Gooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo
0ol00003ooooo`So00001Oooool;o`0006_ooooo000Looooo`03o`000?oooooooooo063ooooo3Ol0
000=ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo1?l00007ooooo`Go00003Oooool2o`0000Gooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`_o0000Jooo
ool001cooooo00?o0000ooooooooool0H?ooool=o`0000gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool5o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2
o`0000Sooooo0ol00006ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool=
o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo2ol00009ooooo`;o00003?ooool2o`00
00Gooooo0ol0000:ooooo`;o00008oooool7o`0000Cooooo0_l0000=ooooo`_o0000JOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo05kooooo3Ol00009ooooo`;o00001?ooool2o`0000kooooo0_l0000:
ooooo`;o00002Oooool2o`0001_ooooo1?l000000ooooooo0000o`00000@ooooo`_o0000JOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Nooooo`co00000_ooool2o`0000_ooooo0ol0000Dooooo`;o00003ooo
ool2o`0000Sooooo1?l00002ooooo`;o000000?oooooo`000?l000003?ooool3o`0000?ooooo0_l0
000;ooooo`_o0000JOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0G_ooool;o`0000?ooooo1?l00009ooooo`Co00004oooool2
o`0001Cooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000cooooo0_l00004
ooooo`;o00000_ooool2o`0000Wooooo2ol0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001Nooooo`_o00001Oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Vooooo`Co00000_ooool2o`0001kooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo3?l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0G?ooool<
o`00017ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0002;ooooo0_l0
0002ooooo`;o00008Oooool4o`0000?ooooo3?l0001Wooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0G?ooool?
o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00002Oooool2
o`0001?ooooo0_l0000Jooooo`Go00003?ooool2o`0000?ooooo3?l0001Vooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0G?oo
ool?o`0000?ooooo0_l0000Dooooo`?o00001oooool4o`0000Wooooo0_l00008ooooo`;o00006_oo
ool5o`0000cooooo0_l00003ooooo`co0000I_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05cooooo2ol0000Mooooo`;o0000
1oooool3o`0000_ooooo0_l0000Aooooo`;o00004?ooool2o`0000?ooooo0_l0000@ooooo`co0000
I_ooool001cooooo00?o0000ooooooooool0Foooool;o`0000kooooo0_l0000>ooooo`;o00001ooo
ool2o`0001[ooooo0ol00002ooooo`;o00000oooool3o`0000Wooooo0ol00003ooooo`Co00001Ooo
ool5o`0000;ooooo1?l000000ooooooo0000o`000008o`0006Gooooo000Looooo`03o`000?oooooo
oooo05_ooooo2_l00008ooooo`;o00001Oooool2o`0000Sooooo0_l0000Qooooo`;o00001_ooool3
o`0000Oooooo0ol000000ooooooo0000o`000005ooooo`Co00001Oooool4o`0000?ooooo1Ol00002
ooooo`;o00000oooool;o`0006Cooooo000Looooo`03o`000?oooooooooo05[ooooo2ol00008oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l00009ooooo`;o00000oooool2o`00
00Oooooo0_l0000Dooooo`;o00001Oooool2o`0000Wooooo0_l0000:ooooo`;o00000oooool;o`00
06Cooooo000Looooo`03o`000?oooooooooo05[ooooo2_l000000ooooooo0000o`000009ooooo`;o
000000?oooooo`000?l000004oooool2o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o
00001oooool2o`0000?ooooo0ol0000:ooooo`Co00005Oooool2o`000003ooooool0003o000000Ko
oooo0_l00002ooooo`[o0000I?ooool001cooooo00?o0000ooooooooool0F_ooool:o`000003oooo
ool0003o000000cooooo0ol00008ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o0000
3Oooool2o`0000;ooooo1?l00004ooooo`;o00001?ooool4o`0000[ooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00003ooooo`Co00000_ooool;o`0006?ooooo000Looooo`03o`00
0?oooooooooo05[ooooo2_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00000Gooooo`;o0000
1_ooool2o`0001;ooooo0_l00005ooooo`?o00001?ooool3o`0000?ooooo0_l00003ooooo`co0000
Hoooool001cooooo00?o0000ooooooooool0FOooool:o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0
003o0000ooooo`;o00004?ooool2o`0001_ooooo0_l00008ooooo`;o00001_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000007o`0006?ooooo000Looooo`03o`000?oooooooooo05Wooooo2_l0
00001?oooooo0000o`000?l0000=ooooo`;o00000oooool2o`0000cooooo1?l000001?oooooo0000
o`000?ooool4o`0000gooooo0ol0000Kooooo`;o00000oooool5o`0000Gooooo0_l000000ooooooo
0000o`000002ooooo`;o00001?ooool2o`000003ooooool0003o000000So0000H_ooool001cooooo
00?o0000ooooooooool0F?ooool;o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l0
00000_ooool3o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0000gooooo1ol00003ooooo`;o
00001Oooool3o`0000;ooooo0ol000000ooooooo0000o`000008o`0006;ooooo000Looooo`03o`00
0?oooooooooo05Sooooo2ol00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Co
oooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l0000Iooooo`;o00003Oooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo3_l0001Rooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`_o00001_ooool3o`0000;ooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`0001Wooooo0_l00009ooooo`;o0000
1Oooool2o`0000cooooo0_l000000ooooooo0000o`00000=o`00067ooooo000Looooo`;o0000FOoo
ool:o`0000Cooooo0_l000000ooooooo0000o`000005o`0000oooooo0_l00005ooooo`;o00002_oo
ool4o`0000Gooooo0_l0000Iooooo`;o00000oooool4o`0000Wooooo0_l0000<ooooo`Go000000?o
ooooo`000?l000002_l0001Qooooo`007?ooool00ol0003oooooooooo`1Hooooo`Wo00001Oooool2
o`000004ooooool0003o0000ooooo`Co00003oooool2o`0000Gooooo0_l00004ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Kooooo`;o00001_ooool4o`0000Cooooo0_l0000<ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`Co000000?oooooo`000?l000000ol0001Qooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`_o00001?ooool2o`0000Sooooo0_l0000Booooo`;o00001_oo
ool2o`0000Cooooo0_l00002ooooo`;o00006oooool2o`0000kooooo1?l0000:ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`[o0000HOooool001cooooo00?o0000ooooooooool0Eooo
ool;o`0000Oooooo1?l00003ooooo`;o00002Oooool2o`0000Oooooo0_l0000Mooooo`;o00006?oo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool2o`0000;ooooo
3Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Gooooo`co00001?ooool8o`0000;ooooo0_l0
0008ooooo`;o00005_ooool2o`0000kooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?l00007ooooo`;o00001Oooool2o`0000?ooooo0ol000000ooooooo0000
o`000007o`00067ooooo000Looooo`03o`000?oooooooooo05Oooooo3?l00004ooooo`?o00000ooo
ool2o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`0000[ooooo0_l00009ooooo`;o00007?oo
ool2o`0000;ooooo0ol00002ooooo`Co00001_ooool2o`0000Gooooo0_l00005ooooo`[o0000H_oo
ool001cooooo00?o0000ooooooooool0Eoooool9o`0000Oooooo0_l000000ooooooo0000o`00000?
ooooo`;o000000?oooooo`000?l000001oooool2o`0001Gooooo0_l0000Looooo`?o00000oooool2
o`0000?ooooo0ol00005ooooo`Co00002?ooool=o`00067ooooo000Looooo`03o`000?oooooooooo
05Sooooo2?l0000:ooooo`?o00004Oooool2o`0000cooooo1?l0000Booooo`;o00006Oooool2o`00
00?ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool:o`00
063ooooo000Looooo`03o`000?oooooooooo05Oooooo2?l0000<ooooo`;o00006oooool2o`0000;o
oooo1?l00004ooooo`;o00003?ooool2o`00037ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002?l0001Pooooo`007?ooool00ol0003oooooooooo`1Fooooo`[o00001?ooool4o`00023ooooo
0_l0000:ooooo`;o00007Oooool2o`0001?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool=o`00063ooooo000Looooo`03o`000?oooooooooo05Kooooo3?l00002ooooo`Ko00001?oo
ool2o`0000Gooooo0_l0000=ooooo`Co0000:oooool2o`0001?ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001oooool:o`00067ooooo000Looooo`03o`000?oooooooooo05Kooooo3?l00004
ooooo`Co00001?ooool2o`0000Gooooo0_l0000=ooooo`Co0000:Oooool2o`000003ooooool0003o
0000017ooooo0ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo2Ol0001P
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`[o00001oooool4o`0000;ooooo0_l00007oooo
o`;o00001_ooool2o`00037ooooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool9o`00063ooooo000Looooo`03
o`000?oooooooooo05Kooooo2Ol00008ooooo`Co00000_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000003ooooo`;o00004?ooool2o`0000;ooooo0_l0000Wooooo`;o00001_ooool2o`0001;o
oooo0_l000000ooooooo0000o`000002ooooo`Wo0000H?ooool001cooooo00?o0000ooooooooool0
E_ooool:o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo
0_l0000>ooooo`;o00000_ooool2o`0002oooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000003?l0001Oooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`[o00002Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
2?ooool2o`00043ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`;o00001Oooool<o`0005oooooo000Looooo`;o0000Eoooool9o`0000Wooooo
1?l00006ooooo`Ko0000B_ooool2o`000003ooooool0003o000000Sooooo1?l00003ooooo`?o0000
00?oooooo`000?l000001?ooool:o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo2?l0
0005ooooo`;o00000_ooool4o`0000Kooooo1?l0000Cooooo`;o00001?ooool2o`0003kooooo0_l0
0005ooooo`?o000000?oooooo`000?l000001?ooool:o`0005oooooo000Looooo`03o`000?oooooo
oooo05Kooooo2Ol000000ooooooo0000o`000004o`0000?ooooo0_l0000Nooooo`;o00001?ooool2
o`0001Wooooo0_l0000Vooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo3Ol0001O
ooooo`007?ooool00ol0003oooooooooo`1Foooooa3o00006_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Nooooo`?o00001oooool2o`0001_ooooo0ol000000ooooooo0000o`000002oooo
o`;o00000_ooool=o`0005oooooo000Looooo`03o`000?oooooooooo05Kooooo3Ol00006ooooo`;o
00004_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o0000
01oooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l0000=ooooo`[o0000Goooool001co
oooo00?o0000ooooooooool0Eoooool:o`0000Kooooo1?l0000Booooo`;o00002?ooool2o`0001Co
oooo0_l0000Aooooo`;o00005_ooool2o`0001Kooooo2_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`[o00001Oooool4o`0000cooooo0_l00004ooooo`;o00007oooool2o`0001Oooooo
0_l0000@ooooo`;o00003Oooool2o`0000Kooooo2_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`_o00001Oooool4o`0000cooooo0_l00004ooooo`;o0000>?ooool2o`0001gooooo1?l0
0006ooooo`[o0000H?ooool001cooooo00?o0000ooooooooool0E_ooool:o`0000Sooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003oooool2o`0003;ooooo0_l00002ooooo`;o00003_ooool2
o`0000_ooooo1?l00004ooooo`co0000H?ooool001cooooo00?o0000ooooooooool0Eoooool9o`00
00_ooooo0_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l00009ooooo`;o00004_ooool2o`00
00[ooooo0_l00007ooooo`;o00000_ooool4o`0000cooooo0_l00004ooooo`;o00001oooool4o`00
00;ooooo3?l0001Pooooo`007?ooool00ol0003oooooooooo`1Gooooo`Wo00001oooool2o`0000Oo
oooo0_l0000:ooooo`;o00003Oooool2o`0001;ooooo0_l0000:ooooo`;o00003?ooool3o`00013o
oooo1?l00003ooooo`Co000000Coooooo`000?l0003o00000oooool;o`00063ooooo000Looooo`03
o`000?oooooooooo05Sooooo2_l00005ooooo`?o00009oooool2o`0001[ooooo0_l0000:ooooo`;o
00000oooool2o`0000Gooooo0_l00005ooooo`Co00000oooool4o`000003ooooool0003o000000Co
oooo2ol0001Pooooo`007?ooool00ol0003oooooooooo`1Hooooo`[o00001Oooool4o`0000Cooooo
0ol0000Aooooo`;o00003?ooool2o`0000gooooo0_l0000;ooooo`;o00002?ooool2o`0000Gooooo
0_l00003ooooo`Co00002Oooool2o`0000;ooooo1?l00007ooooo`Wo0000HOooool001cooooo00?o
0000ooooooooool0Eoooool;o`0000Gooooo1ol000001?oooooo0000o`000?l00009ooooo`;o0000
0oooool2o`000003ooooool0003o000001_ooooo0_l0000Eooooo`Go00000oooool2o`0000;ooooo
1?l00004ooooo`;o00000oooool8o`0000Gooooo2ol0001Qooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`[o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o0000
0_ooool4o`0000?ooooo0_l0000Kooooo`;o00005oooool6o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000?ooooo2?l000001Ooooooo0000o`000?l0003ooooo00_o0000HOooool001cooooo
00?o0000ooooooooool0Eoooool:o`0000oooooo1?l000000ooooooo0000o`000002ooooo`;o0000
2Oooool2o`0001Kooooo0ol00002ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0000;ooooo`Ko00000oooool3o`0000?ooooo2Ol0001Qooooo`00
7?ooool2o`0005Sooooo2ol000000ooooooo0000o`00000=ooooo`;o00004?ooool2o`0001Kooooo
0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`Go000000Coooooo`000?l0003o
oooo0_l0000=ooooo`;o00001?ooool4o`0000;ooooo2Ol0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`[o000000?oooooo`000?l000000_ooool2o`0001Wooooo0_l00008ooooo`;o0000
8?ooool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo
2?l000000ooooooo0000o`000008o`00067ooooo000Looooo`03o`000?oooooooooo05Wooooo2_l0
0004ooooo`;o00001?ooool2o`0001?ooooo0_l00008ooooo`Co00007_ooool3o`0001Gooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Oooooo1?l00002ooooo`go0000HOooool001cooooo00?o
0000ooooooooool0F?ooool=o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
5?ooool2o`0000oooooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo
2_l0001Rooooo`007?ooool00ol0003oooooooooo`1Hooooo`go000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Cooooo
1?l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000kooooo0_l0000=ooooo`Co0000
1?ooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool3o`0000Gooooo2_l0001Rooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`[o00000oooool2o`000003ooooool0003o000000oooooo1?l0
00000ooooooo0000o`000006ooooo`;o00003_ooool2o`0001gooooo0_l00006ooooo`;o00001ooo
ool2o`0000Gooooo0_l00006ooooo`;o00000oooool;o`0006?ooooo000Looooo`03o`000?oooooo
oooo05Wooooo2_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00004
ooooo`;o00002?ooool2o`0003;ooooo0ol0000@ooooo`?o00000_ooool3o`0000;ooooo2_l0001T
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`[o00000oooool2o`000003ooooool0003o0000
00Kooooo0_l0000<ooooo`;o00001oooool3o`0000kooooo0_l00004ooooo`;o00003_ooool2o`00
00cooooo0ol00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Co000000Cooooo
o`000?l0003o00000_ooool;o`0006?ooooo000Looooo`03o`000?oooooooooo05[ooooo2_l00002
ooooo`;o00000_ooool2o`0000Wooooo1?l0000@ooooo`;o00003?ooool5o`0000Cooooo0_l00002
ooooo`;o00002_ooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo1ol00003ooooo`_o0000Hoooool001cooooo00?o0000ooooooooool0F_ooool;
o`000003ooooool0003o000000gooooo1?l0000Fooooo`;o00001_ooool4o`0000Kooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002?ooool2o`0001Kooooo0_l00007ooooo`Co00000oooool9
o`0006Gooooo000Looooo`03o`000?oooooooooo05_ooooo2_l000000ooooooo0000o`000005oooo
o`;o00001_ooool2o`0000;ooooo1?l00006ooooo`;o00002_ooool2o`0000Oooooo0_l00007oooo
o`;o00001_ooool2o`0001[ooooo0ol00007ooooo`;o00002Oooool:o`0006Gooooo000Looooo`03
o`000?oooooooooo05_ooooo2_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000002Oooool2o`0001gooooo0ol00007ooooo`;o00000oooool2o`0000Cooooo2_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Looooo`Wo000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000001cooooo0_l00009
ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o00000_ooool;
o`0006Kooooo000Looooo`03o`000?oooooooooo05cooooo3?l0000:ooooo`Ko00000_ooool2o`00
0003ooooool0003o000000Oooooo0_l00002ooooo`;o00005oooool2o`0000Gooooo1?l00007oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo0_l00004ooooo`;o00002Oooool=o`00
06Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Looooo`go00000_ooool2o`0000Gooooo1_l0
0002ooooo`Co000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000001Oooooo0_l0
0005ooooo`Co00001oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo3Ol0
001Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0GOooool<o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000001?ooool4o`0001oo
oooo0_l00004ooooo`;o00001Oooool2o`0000cooooo0ol0000Booooo`_o0000I_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0GOooool;o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00
00oooooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000009ooooo`?o00004Oooool;o`0006Oooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o0000GOooool<o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0001Cooooo0_l00006ooooo`?o00001oooool2o`0000Wooooo0_l0
0006ooooo`Co00002?ooool2o`0000Gooooo1?l0000:ooooo`_o0000Ioooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0GOooool<o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000
o`000?ooool6o`0001Gooooo0_l00004ooooo`Go00006Oooool2o`0000[ooooo0_l00005ooooo`Co
00001oooool=o`0006Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Oooooo`[o000000?oooooo`000?l00000
3Oooool2o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Iooooo`Co00002?ooool4o`0000?ooooo0ol00006ooooo`oo0000J?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05oo
oooo3_l00007ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2o`000003
ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000;o00002?ooool4o`00
0003ooooool0003o000000?o00001_ooool2o`000003ooooool0003o000000Go000000Coooooo`00
0?l0003o0000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo05oooooo3_l00007ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00001Oooool2o`0000[ooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1Ol0000:ooooo`;o0000
0_ooool3o`0000Oooooo4?l0001Yooooo`007?ooool00ol0003oooooooooo`1Pooooo`co00000_oo
ool3o`0000[ooooo0_l00009ooooo`;o00008oooool3o`000003ooooool0003o000000?ooooo0_l0
000@ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool03Ol0001Yooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`_o00000_ooool3o`0000[ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000005oooool2o`0000Oooooo0_l00009ooooo`;o00003Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`_o0000Joooool001cooooo00?o0000ooooooooool0H_ooool;
o`0000cooooo0_l00005ooooo`;o00001oooool2o`0001Kooooo0ol0000Booooo`;o00001?ooool2
o`0000Kooooo0ol0000:ooooo`go0000Joooool001cooooo00?o0000ooooooooool0H_ooool<o`00
0003ooooool0003o000000Sooooo0_l00005ooooo`;o00003Oooool2o`0000Oooooo0_l00007oooo
o`Co00003?ooool3o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`00
00Cooooo3?l0001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`ko000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`?o00001Oooool2o`000003ooooool0003o0000
00gooooo0_l00003ooooo`go0000K?ooool001cooooo00?o0000ooooooooool0IOooool;o`0000;o
oooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo1?l00008ooooo`;o00002_ooool3o`0000?o
oooo0_l00008ooooo`;o00001?ooool4o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Co
oooo3Ol0001]ooooo`007?ooool00ol0003oooooooooo`1Tooooo`go00001oooool2o`0000Sooooo
0_l00006ooooo`;o00001_ooool4o`0000;ooooo0_l00006ooooo`?o00000_ooool2o`0000Wooooo
0_l00004ooooo`Co00001?ooool2o`0000?ooooo0ol00003ooooo`;o00001?ooool;o`0006oooooo
000Looooo`03o`000?oooooooooo06Cooooo3_l00005ooooo`?o00002?ooool2o`0000Kooooo1?l0
0004ooooo`?o00000oooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000007o`0000Cooooo0_l000000ooooooo0000o`00000<o`0006oooooo000L
ooooo`03o`000?oooooooooo06Oooooo2ol000001?oooooo0000o`000?ooool3o`0001?ooooo0_l0
0005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002oooool3o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l000000ooooooo0000
o`00000;o`00073ooooo000Looooo`03o`000?oooooooooo06Oooooo4Ol00005ooooo`;o00001ooo
ool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o0000
2oooool3o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002_l0001aooooo`007?oo
ool00ol0003oooooooooo`1Woooooa;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00002_oo
ool4o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000kooooo0_l00008ooooo`;o00003Ooo
ool=o`0007;ooooo000Looooo`;o0000JOoooolAo`0000Gooooo0_l00002ooooo`;o00003_ooool4
o`0000?ooooo0ol0000Eooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`ko0000L_ooool001cooooo00?o0000ooooooooool0JOoooolAo`00017ooooo0_l00005oooo
o`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00
0003ooooool0003o000000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000003Ol0001boooo
o`007?ooool00ol0003oooooooooo`1Zooooo`go000000?oooooo`000?l000001Oooool2o`0000[o
oooo0_l0000Eooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`?o00002Oooool2o`000003ooooool0003o000000go0000Loooool001cooooo
00?o0000ooooooooool0Joooool>o`0000Kooooo0_l0000>ooooo`;o00003_ooool2o`0000Cooooo
0_l00004ooooo`;o00000_ooool2o`0000gooooo0ol00003oooooa3o0000MOooool001cooooo00?o
0000ooooooooool0K?ooool?o`0000?ooooo0ol00007ooooo`;o00000oooool7o`000003ooooool0
003o000000Sooooo1?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000?ooooo1?l0
0006ooooo`?o00001?ooool?o`0007Gooooo000Looooo`03o`000?oooooooooo06gooooo3ol00002
ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0000Wooooo0_l000001?oooooo0000o`000?l0000=ooooo`Co00002oooool?o`0007Oooooo
000Looooo`03o`000?oooooooooo06kooooo3ol0000Fooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0005ooooo`oo0000N?ooool001cooooo00?o0000ooooooooool0KooooolAo`0000Sooooo1?l00007
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003OoooolIo`0007Sooooo000Loooo
o`03o`000?oooooooooo073ooooo4_l00006ooooo`Co00000_ooool2o`0000gooooo0_l00003oooo
o`;o00002?ooool3o`0000Oooooo0_l000001?oooooo0000o`000?oooolCo`0007[ooooo000Loooo
o`03o`000?oooooooooo07;ooooo5?l00005ooooo`;o000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l00002ooooo`?o00001oooool2o`0000Cooooo4?l0001mooooo`007?ooool00ol0003o
ooooooooo`1eoooooa7o00001Oooool7o`0000kooooo0_l00006ooooo`;o00001?ooool2o`0000;o
oooo0_l00006oooooa;o0000OOooool001cooooo00?o0000ooooooooool0MOoooolCo`0000Gooooo
0_l000000ooooooo0000o`000002ooooo`Ko00001_ooool2o`0000?ooooo0_l00006ooooo`So0000
00Coooooo`000?l0003ooooo4_l0001nooooo`007?ooool00ol0003oooooooooo`1foooooaGo0000
1?ooool2o`0000?ooooo1_l0000;ooooo`;o00001_oooolLo`00083ooooo000Looooo`03o`000?oo
oooooooo07Kooooo6?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000<ooooo`;o0000
2?oooolIo`00087ooooo000Looooo`03o`000?oooooooooo07[ooooo6_l00003ooooo`;o00001ooo
ool2o`0000Wooooo7?l00022ooooo`007?ooool00ol0003oooooooooo`1kooooob3o00000_ooool2
o`000003ooooool0003o000000Kooooo7Ol00024ooooo`007?ooool2o`0007gooooo:ol000000ooo
oooo0000o`00000Io`0008Kooooo000Looooo`03o`000?oooooooooo07kooooo@ol00028ooooo`00
7?ooool00ol0003oooooooooo`20oooood3o0000ROooool001cooooo00?o0000ooooooooool0Pooo
ooljo`0008cooooo000Looooo`03o`000?oooooooooo08Oooooo<ol0002?ooooo`007?ooool00ol0
003oooooooooo`27oooooc;o0000T?ooool001cooooo00?o0000ooooooooool0RooooolYo`0009Go
oooo000Looooo`03o`000?oooooooooo08oooooo8ol0002Gooooo`007?ooool00ol0003ooooooooo
o`2Dooooo`Ko000000?oooooo`000?l000003Ol000000ooooooo0000o`00002Looooo`007?ooool0
0ol0003oooooooooo`2Kooooo`_o0000Xoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002]oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^09Sooooo002^ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`2Hooooo`00[_ooool01Ol0003ooooooooooooooooo000001Sooooo
00Go410@oooooooooooooooooa0@402Hooooo`00[_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l00009ooooo`05o`000?ooooooooooooooool00000V?ooool00:kooooo00Go0000ohN7Qooo
ooooZJVYo`00000Hooooo`05o`000?ooooooooooooooool00000V?ooool00:gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100V?ooool0
0<_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Hooooo`00boooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^09Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6883 .64417 Mdot
.66437 .61218 Mdot
.64335 .33236 Mdot
.327 .52348 Mdot
.34962 .35053 Mdot
.6348 .32326 Mdot
.70713 .52858 Mdot
.70981 .49559 Mdot
.65224 .36212 Mdot
.36998 .51534 Mdot
.69389 .4098 Mdot
.38187 .6833 Mdot
.70454 .51886 Mdot
.36006 .51571 Mdot
.32901 .67393 Mdot
.48448 .70053 Mdot
.6893 .62878 Mdot
.34754 .34798 Mdot
.47298 .7223 Mdot
.64753 .36981 Mdot
.45362 .35531 Mdot
.34537 .5276 Mdot
.69496 .61462 Mdot
.36226 .52133 Mdot
.47601 .72249 Mdot
.57772 .69963 Mdot
.69177 .64367 Mdot
.48108 .71827 Mdot
.38109 .69112 Mdot
.69334 .49805 Mdot
.49416 .70624 Mdot
.32983 .62402 Mdot
.43962 .29771 Mdot
.58196 .66489 Mdot
.69833 .44131 Mdot
.68644 .40422 Mdot
.64433 .31455 Mdot
.69548 .40078 Mdot
.70388 .48347 Mdot
.69957 .43732 Mdot
.69725 .43646 Mdot
.5817 .69998 Mdot
.68411 .40937 Mdot
.68244 .52093 Mdot
.29915 .62744 Mdot
.61744 .66502 Mdot
.53442 .26034 Mdot
.28343 .61476 Mdot
.67789 .6433 Mdot
.55118 .26436 Mdot
.32037 .59768 Mdot
.72072 .52963 Mdot
.43241 .32879 Mdot
.60973 .70698 Mdot
.70038 .50854 Mdot
.47858 .72507 Mdot
.62329 .34711 Mdot
.30934 .58376 Mdot
.38253 .70032 Mdot
.59757 .66056 Mdot
.35571 .53759 Mdot
.30971 .34433 Mdot
.50471 .68682 Mdot
.61534 .35 Mdot
.65017 .34554 Mdot
.71237 .4034 Mdot
.67411 .59151 Mdot
.71088 .41196 Mdot
.33599 .50177 Mdot
.52854 .2683 Mdot
.28489 .60355 Mdot
.6935 .41018 Mdot
.59378 .68209 Mdot
.33686 .51381 Mdot
.66669 .64603 Mdot
.70798 .41857 Mdot
.35385 .35629 Mdot
.58195 .6928 Mdot
.56863 .27682 Mdot
.35275 .47354 Mdot
.34242 .53467 Mdot
.73746 .49787 Mdot
.38974 .71564 Mdot
.61093 .68794 Mdot
.31143 .62834 Mdot
.73846 .53236 Mdot
.32967 .5545 Mdot
.48985 .70402 Mdot
.48522 .7216 Mdot
.37117 .68092 Mdot
.6082 .28768 Mdot
.68494 .59969 Mdot
.34644 .51566 Mdot
.34245 .4959 Mdot
.31584 .60111 Mdot
.31636 .62747 Mdot
.4879 .72293 Mdot
.4113 .30891 Mdot
.69898 .4258 Mdot
.44519 .32332 Mdot
.71009 .41433 Mdot
.43279 .33641 Mdot
.32127 .51848 Mdot
.61755 .31976 Mdot
.56648 .7067 Mdot
.41763 .3031 Mdot
.70584 .42351 Mdot
.34636 .51268 Mdot
.68858 .40165 Mdot
.68482 .60335 Mdot
.49928 .71013 Mdot
.32271 .37664 Mdot
.35603 .37868 Mdot
.70653 .62518 Mdot
.32635 .49462 Mdot
.33767 .56011 Mdot
.35126 .53215 Mdot
.67771 .59162 Mdot
.64894 .36215 Mdot
.57894 .28863 Mdot
.67262 .61078 Mdot
.69709 .42881 Mdot
.68589 .63418 Mdot
.45815 .30773 Mdot
.65092 .35322 Mdot
.44073 .30797 Mdot
.4056 .32805 Mdot
.32772 .58452 Mdot
.31978 .62483 Mdot
.44327 .3476 Mdot
.61547 .31685 Mdot
.6702 .61207 Mdot
.70744 .51092 Mdot
.34606 .49377 Mdot
.60957 .68466 Mdot
.69865 .51058 Mdot
.33992 .3771 Mdot
.33053 .38994 Mdot
.59837 .68352 Mdot
.32053 .50457 Mdot
.69575 .39868 Mdot
.7182 .49147 Mdot
.31629 .58579 Mdot
.61192 .679 Mdot
.34916 .35806 Mdot
.71682 .48846 Mdot
.41723 .28715 Mdot
.50222 .71527 Mdot
.27824 .65775 Mdot
.73575 .49974 Mdot
.31734 .5944 Mdot
.47221 .34104 Mdot
.3038 .35362 Mdot
.69944 .50361 Mdot
.32613 .53733 Mdot
.67432 .63114 Mdot
.60648 .67984 Mdot
.41293 .70722 Mdot
.42483 .29898 Mdot
.31741 .57588 Mdot
.43531 .34045 Mdot
.40613 .32226 Mdot
.35743 .51376 Mdot
.60844 .66029 Mdot
.55868 .6941 Mdot
.29227 .59452 Mdot
.65359 .32771 Mdot
.349 .34753 Mdot
.68785 .41224 Mdot
.31135 .62038 Mdot
.31304 .60134 Mdot
.40891 .69797 Mdot
.7212 .49698 Mdot
.70849 .45127 Mdot
.55488 .28147 Mdot
.71584 .41127 Mdot
.70042 .45047 Mdot
.60962 .33081 Mdot
.3929 .69196 Mdot
.31625 .37694 Mdot
.41763 .32521 Mdot
.29596 .59128 Mdot
.31942 .63645 Mdot
.3731 .68006 Mdot
.44897 .35621 Mdot
.47864 .33101 Mdot
.64266 .62892 Mdot
.68395 .4226 Mdot
.33192 .54214 Mdot
.49631 .73279 Mdot
.32508 .60953 Mdot
.7105 .46386 Mdot
.71147 .50881 Mdot
.63236 .37182 Mdot
.64412 .37146 Mdot
.55222 .27176 Mdot
.42548 .71714 Mdot
.4175 .69826 Mdot
.33428 .53375 Mdot
.43842 .31973 Mdot
.50737 .68824 Mdot
.30521 .35091 Mdot
.68335 .63032 Mdot
.73673 .49386 Mdot
.27468 .6194 Mdot
.46683 .71686 Mdot
.66019 .32936 Mdot
.60643 .28415 Mdot
.41224 .33774 Mdot
.31502 .35648 Mdot
.304 .58799 Mdot
.70341 .62485 Mdot
.31854 .59312 Mdot
.44309 .30075 Mdot
.35707 .38009 Mdot
.6818 .61164 Mdot
.28026 .62321 Mdot
.70146 .51996 Mdot
.60443 .29773 Mdot
.32958 .55481 Mdot
.34262 .51008 Mdot
.58447 .69285 Mdot
.33331 .49851 Mdot
.4839 .73186 Mdot
.4927 .71137 Mdot
.54806 .27326 Mdot
.71355 .42547 Mdot
.69234 .49438 Mdot
.53268 .26012 Mdot
.59488 .69097 Mdot
.70674 .64426 Mdot
.62487 .32952 Mdot
.4368 .3624 Mdot
.69385 .40595 Mdot
.33537 .36165 Mdot
.62271 .3226 Mdot
.34415 .34773 Mdot
.38021 .70142 Mdot
.61029 .31032 Mdot
.33034 .3776 Mdot
.34414 .67389 Mdot
.40811 .32621 Mdot
.33453 .39597 Mdot
.7071 .531 Mdot
.65556 .62314 Mdot
.30075 .58576 Mdot
.42629 .32903 Mdot
.44761 .3077 Mdot
.39569 .69534 Mdot
.40554 .34254 Mdot
.42213 .30513 Mdot
.39915 .69571 Mdot
.33693 .3392 Mdot
.72266 .47083 Mdot
.49516 .70688 Mdot
.68694 .63138 Mdot
.32949 .5052 Mdot
.71323 .43637 Mdot
.69838 .5089 Mdot
.34702 .55491 Mdot
.7379 .51853 Mdot
.70763 .53327 Mdot
.35861 .52254 Mdot
.69974 .48833 Mdot
.60976 .68739 Mdot
.27576 .61549 Mdot
.5964 .67758 Mdot
.3604 .51861 Mdot
.70084 .48577 Mdot
.54066 .2605 Mdot
.58618 .69848 Mdot
.34417 .52001 Mdot
.33002 .52514 Mdot
.43607 .32176 Mdot
.49693 .71166 Mdot
.71201 .55052 Mdot
.38313 .68411 Mdot
.60447 .33246 Mdot
.41339 .71704 Mdot
.2971 .36314 Mdot
.41685 .28649 Mdot
.61144 .67824 Mdot
.40359 .34089 Mdot
.6299 .3262 Mdot
.31067 .59287 Mdot
.27703 .63244 Mdot
.30331 .62719 Mdot
.42207 .30753 Mdot
.39144 .71726 Mdot
.70439 .54041 Mdot
.49798 .72637 Mdot
.43774 .349 Mdot
.62824 .34705 Mdot
.43903 .33269 Mdot
.31417 .62881 Mdot
.69273 .60875 Mdot
.47108 .70847 Mdot
.60411 .31963 Mdot
.69215 .61687 Mdot
.28552 .60878 Mdot
.71194 .41366 Mdot
.29317 .35214 Mdot
.70107 .54091 Mdot
.47715 .71163 Mdot
.41331 .71471 Mdot
.53106 .26858 Mdot
.59442 .69658 Mdot
.70373 .4975 Mdot
.59474 .68031 Mdot
.31928 .58059 Mdot
.31862 .56501 Mdot
.61164 .67451 Mdot
.31403 .38639 Mdot
.56911 .28454 Mdot
.69765 .40893 Mdot
.43817 .31125 Mdot
.52732 .27655 Mdot
.68313 .64212 Mdot
.62144 .31746 Mdot
.31564 .5107 Mdot
.60122 .29852 Mdot
.46934 .70998 Mdot
.52618 .27285 Mdot
.41393 .70099 Mdot
.30479 .63275 Mdot
.6156 .35428 Mdot
.41805 .30064 Mdot
.30988 .58562 Mdot
.60797 .68773 Mdot
.33065 .62594 Mdot
.36779 .53176 Mdot
.42399 .71509 Mdot
.62666 .34607 Mdot
.3182 .5091 Mdot
.48633 .71101 Mdot
.47681 .71486 Mdot
.68012 .6275 Mdot
.42994 .31441 Mdot
.34332 .38019 Mdot
.33287 .39375 Mdot
.39495 .30234 Mdot
.36466 .6781 Mdot
.31542 .54173 Mdot
.60062 .68814 Mdot
.5524 .26643 Mdot
.65295 .63309 Mdot
.44199 .29977 Mdot
.71044 .49554 Mdot
.7085 .45358 Mdot
.32787 .55141 Mdot
.29022 .34181 Mdot
.46208 .71657 Mdot
.67008 .64228 Mdot
.5904 .68481 Mdot
.70493 .49636 Mdot
.39478 .72537 Mdot
.36518 .49193 Mdot
.34488 .55484 Mdot
.71492 .49509 Mdot
.44359 .30431 Mdot
.38686 .70284 Mdot
.28748 .6601 Mdot
.68704 .47825 Mdot
.30141 .61828 Mdot
.58281 .66896 Mdot
.29553 .62998 Mdot
.32686 .582 Mdot
.29453 .61354 Mdot
.60341 .69003 Mdot
.45757 .73085 Mdot
.28178 .6531 Mdot
.64886 .30704 Mdot
.27325 .6244 Mdot
.31711 .38589 Mdot
.34128 .5146 Mdot
.30083 .58891 Mdot
.34785 .36215 Mdot
.70502 .62729 Mdot
.31185 .60404 Mdot
.72345 .47754 Mdot
.34653 .52135 Mdot
.68732 .41165 Mdot
.39845 .71003 Mdot
.33046 .6003 Mdot
.48635 .71343 Mdot
.69462 .61235 Mdot
.70736 .48384 Mdot
.6891 .42354 Mdot
.4249 .34833 Mdot
.69831 .50821 Mdot
.30919 .62465 Mdot
.3968 .71147 Mdot
.70677 .62405 Mdot
.40869 .32399 Mdot
.68321 .59829 Mdot
.27268 .3571 Mdot
.71167 .52819 Mdot
.4317 .33398 Mdot
.42028 .72404 Mdot
.7187 .52009 Mdot
.71997 .47199 Mdot
.49964 .70952 Mdot
.44408 .30503 Mdot
.69174 .64143 Mdot
.52838 .27067 Mdot
.43204 .30137 Mdot
.70065 .50495 Mdot
.29837 .62727 Mdot
.49423 .72209 Mdot
.702 .4942 Mdot
.57767 .67567 Mdot
.50558 .71199 Mdot
.34842 .51973 Mdot
.57991 .70288 Mdot
.6771 .59558 Mdot
.30998 .5766 Mdot
.33751 .55017 Mdot
.63609 .33779 Mdot
.42643 .3055 Mdot
.42639 .30721 Mdot
.40397 .32481 Mdot
.60098 .31043 Mdot
.56497 .28675 Mdot
.71073 .43079 Mdot
.33109 .59652 Mdot
.71735 .42476 Mdot
.42639 .33214 Mdot
.63711 .33654 Mdot
.29836 .63035 Mdot
.38392 .72095 Mdot
.70878 .47827 Mdot
.56197 .29108 Mdot
.32267 .53777 Mdot
.67625 .63478 Mdot
.72267 .52054 Mdot
.4038 .68839 Mdot
.54487 .26836 Mdot
.30441 .34584 Mdot
.31759 .51808 Mdot
.72144 .51017 Mdot
.56724 .68752 Mdot
.72111 .50919 Mdot
.29638 .59367 Mdot
.3093 .60989 Mdot
.65903 .62758 Mdot
.31567 .38522 Mdot
.38669 .68612 Mdot
.36155 .52638 Mdot
.55768 .26816 Mdot
.65357 .63618 Mdot
.32819 .39592 Mdot
.3779 .69413 Mdot
.40686 .33696 Mdot
.33428 .33656 Mdot
.33527 .53011 Mdot
.40431 .69695 Mdot
.4524 .3348 Mdot
.69506 .50183 Mdot
.32206 .38918 Mdot
.65752 .32203 Mdot
.68791 .6154 Mdot
.71273 .42932 Mdot
.4029 .34526 Mdot
.69612 .41086 Mdot
.35541 .6757 Mdot
.4226 .33876 Mdot
.69687 .46801 Mdot
.28717 .41834 Mdot
.41499 .31206 Mdot
.62751 .35139 Mdot
.31706 .58151 Mdot
.39594 .69126 Mdot
.3489 .51877 Mdot
.34137 .38157 Mdot
.66793 .60611 Mdot
.69512 .44531 Mdot
.6973 .48089 Mdot
.35269 .50723 Mdot
.61173 .67756 Mdot
.65855 .59654 Mdot
.44105 .32698 Mdot
.32415 .36772 Mdot
.33398 .36436 Mdot
.34782 .50424 Mdot
.3845 .71627 Mdot
.60012 .69091 Mdot
.34416 .5193 Mdot
.34787 .50352 Mdot
.54336 .28033 Mdot
.58138 .70557 Mdot
.60918 .31375 Mdot
.46805 .72148 Mdot
.31782 .53836 Mdot
.71393 .41788 Mdot
.69804 .52299 Mdot
.4299 .31066 Mdot
.69223 .49431 Mdot
.55231 .2835 Mdot
.4258 .30736 Mdot
.34357 .52029 Mdot
.70199 .63778 Mdot
.34469 .51785 Mdot
.34636 .51994 Mdot
.29468 .61886 Mdot
.3158 .5433 Mdot
.62268 .28814 Mdot
.31843 .36952 Mdot
.37919 .69858 Mdot
.60704 .33031 Mdot
.66064 .33633 Mdot
.31739 .60205 Mdot
.33786 .52395 Mdot
.35426 .52756 Mdot
.57341 .69555 Mdot
.49872 .7231 Mdot
.71677 .51488 Mdot
.65873 .62757 Mdot
.33106 .55371 Mdot
.52855 .26142 Mdot
.31031 .60325 Mdot
.60921 .67356 Mdot
.70605 .4428 Mdot
.72916 .54996 Mdot
.40887 .34873 Mdot
.44902 .31539 Mdot
.42276 .30578 Mdot
.40357 .32254 Mdot
.68539 .40669 Mdot
.63812 .33624 Mdot
.29441 .36542 Mdot
.31745 .55941 Mdot
.3348 .54651 Mdot
.31188 .61293 Mdot
.53712 .28208 Mdot
.45263 .30041 Mdot
.32183 .57745 Mdot
.51349 .70114 Mdot
.61499 .29925 Mdot
.40994 .3116 Mdot
.61967 .64838 Mdot
.68825 .60876 Mdot
.54084 .26953 Mdot
.69604 .40107 Mdot
.33112 .38016 Mdot
.50174 .2899 Mdot
.67836 .59934 Mdot
.52126 .68969 Mdot
.62268 .30249 Mdot
.3943 .71002 Mdot
.46101 .69863 Mdot
.62526 .31479 Mdot
.49883 .7273 Mdot
.67642 .59086 Mdot
.40712 .32615 Mdot
.40261 .716 Mdot
.39797 .69819 Mdot
.64242 .37701 Mdot
.33085 .51668 Mdot
.59942 .28738 Mdot
.62843 .34913 Mdot
.42397 .31564 Mdot
.62672 .34574 Mdot
.70242 .53854 Mdot
.61473 .32729 Mdot
.5737 .68251 Mdot
.34549 .50011 Mdot
.6045 .70988 Mdot
.31981 .67521 Mdot
.33829 .55774 Mdot
.71581 .53541 Mdot
.71219 .43538 Mdot
.34735 .54479 Mdot
.35236 .35676 Mdot
.63233 .35005 Mdot
.55689 .27655 Mdot
.48973 .7263 Mdot
.53024 .27606 Mdot
.69446 .61068 Mdot
.712 .42212 Mdot
.71251 .4351 Mdot
.42837 .3029 Mdot
.61212 .68129 Mdot
.68199 .40842 Mdot
.69787 .42993 Mdot
.29249 .35308 Mdot
.30678 .57966 Mdot
.56693 .67886 Mdot
.38733 .70284 Mdot
.34447 .34605 Mdot
.34673 .52362 Mdot
.60883 .31689 Mdot
.5529 .27582 Mdot
.32537 .673 Mdot
.62668 .33132 Mdot
.43342 .31029 Mdot
.56462 .70015 Mdot
.47727 .72566 Mdot
.67103 .60651 Mdot
.33932 .49545 Mdot
.71404 .42793 Mdot
.69097 .61032 Mdot
.44227 .36007 Mdot
.35711 .54007 Mdot
.61361 .664 Mdot
.37489 .69153 Mdot
.34847 .52129 Mdot
.6478 .35459 Mdot
.34844 .36089 Mdot
.41921 .36135 Mdot
.6336 .29611 Mdot
.31708 .34781 Mdot
.66309 .65367 Mdot
.64887 .35613 Mdot
.32807 .35406 Mdot
.39904 .29717 Mdot
.40128 .33715 Mdot
.31828 .36286 Mdot
.31152 .6274 Mdot
.69797 .5039 Mdot
.65965 .61733 Mdot
.30113 .60497 Mdot
.34334 .46382 Mdot
.59244 .71521 Mdot
.43815 .3234 Mdot
.3512 .52153 Mdot
.31139 .5793 Mdot
.60772 .67582 Mdot
.73413 .48665 Mdot
.6189 .35081 Mdot
.44364 .31502 Mdot
.67502 .60407 Mdot
.73775 .49859 Mdot
.64801 .35043 Mdot
.33777 .35761 Mdot
.69381 .51664 Mdot
.70158 .63962 Mdot
.43318 .32618 Mdot
.70699 .52982 Mdot
.62728 .29315 Mdot
.31965 .5982 Mdot
.51156 .70474 Mdot
.63043 .30708 Mdot
.31963 .5969 Mdot
.46452 .71533 Mdot
.55104 .27075 Mdot
.71303 .45845 Mdot
.68407 .60239 Mdot
.70848 .48885 Mdot
.32953 .36813 Mdot
.59209 .68136 Mdot
.68288 .59864 Mdot
.69784 .52331 Mdot
.57771 .71549 Mdot
.3972 .71999 Mdot
.70723 .41936 Mdot
.38351 .70911 Mdot
.31459 .58821 Mdot
.43105 .32525 Mdot
.3168 .37452 Mdot
.71323 .42394 Mdot
.57832 .70004 Mdot
.68976 .54613 Mdot
.32439 .62175 Mdot
.50324 .71984 Mdot
.32655 .38356 Mdot
.64082 .6367 Mdot
.71356 .45624 Mdot
.71614 .518 Mdot
.55689 .26794 Mdot
.35332 .36195 Mdot
.30821 .63102 Mdot
.53138 .28552 Mdot
.30894 .61732 Mdot
.72446 .5197 Mdot
.4623 .71847 Mdot
.68373 .61785 Mdot
.7049 .41411 Mdot
.46712 .71046 Mdot
.38033 .68564 Mdot
.34064 .54736 Mdot
.54732 .27406 Mdot
.67737 .58708 Mdot
.44234 .28886 Mdot
.33474 .56195 Mdot
.36152 .53459 Mdot
.44947 .30836 Mdot
.33038 .59467 Mdot
.71585 .46354 Mdot
.43034 .29819 Mdot
.61674 .30115 Mdot
.40921 .31966 Mdot
.43608 .31313 Mdot
.69844 .62975 Mdot
.55069 .26786 Mdot
.4497 .31214 Mdot
.35433 .55007 Mdot
.35128 .5121 Mdot
.70634 .48203 Mdot
.39598 .71741 Mdot
.39395 .6995 Mdot
.60572 .33552 Mdot
.2904 .35416 Mdot
.30421 .59371 Mdot
.61087 .68708 Mdot
.33363 .38993 Mdot
.44111 .33909 Mdot
.69039 .6208 Mdot
.31671 .62919 Mdot
.54301 .28077 Mdot
.41131 .32006 Mdot
.4519 .32563 Mdot
.32778 .38048 Mdot
.72146 .49642 Mdot
.60282 .66783 Mdot
.6285 .35002 Mdot
.50164 .70277 Mdot
.28036 .34843 Mdot
.53939 .27259 Mdot
.43063 .32408 Mdot
.41877 .34079 Mdot
.61022 .67957 Mdot
.57734 .67823 Mdot
.40777 .35406 Mdot
.60637 .33098 Mdot
.68652 .43333 Mdot
.69954 .41509 Mdot
.41253 .709 Mdot
.69288 .52122 Mdot
.68494 .60262 Mdot
.3273 .5897 Mdot
.3337 .36141 Mdot
.71733 .52305 Mdot
.42565 .30269 Mdot
.68073 .60269 Mdot
.58377 .67788 Mdot
.3627 .52481 Mdot
.34322 .52827 Mdot
.5351 .26016 Mdot
.32332 .63177 Mdot
.71239 .48031 Mdot
.34396 .37577 Mdot
.64117 .3427 Mdot
.49091 .72477 Mdot
.67554 .63175 Mdot
.49315 .31001 Mdot
.3732 .6843 Mdot
.613 .34017 Mdot
.66358 .61465 Mdot
.3417 .38709 Mdot
.31872 .36797 Mdot
.32285 .56898 Mdot
.47646 .33658 Mdot
.71231 .53323 Mdot
.608 .68543 Mdot
.65825 .65051 Mdot
.38321 .6927 Mdot
.3395 .52376 Mdot
.48994 .72987 Mdot
.68565 .42494 Mdot
.31176 .62498 Mdot
.33336 .38329 Mdot
.67793 .58883 Mdot
.30184 .63164 Mdot
.35235 .3797 Mdot
.44318 .28923 Mdot
.4158 .33837 Mdot
.62115 .35897 Mdot
.34881 .37985 Mdot
.35205 .37327 Mdot
.3512 .38531 Mdot
.70835 .45393 Mdot
.39821 .68578 Mdot
.27619 .35395 Mdot
.33088 .51803 Mdot
.31716 .58374 Mdot
.51283 .70739 Mdot
.71703 .41583 Mdot
.53281 .26738 Mdot
.30143 .58978 Mdot
.33039 .5241 Mdot
.66842 .59155 Mdot
.49044 .69965 Mdot
.28893 .60286 Mdot
.68623 .62462 Mdot
.56726 .67386 Mdot
.63585 .36831 Mdot
.73625 .50922 Mdot
.52084 .27777 Mdot
.37575 .69821 Mdot
.37419 .7014 Mdot
.69665 .59989 Mdot
.69524 .51024 Mdot
.37619 .70305 Mdot
.72266 .50002 Mdot
.68591 .59058 Mdot
.51482 .7041 Mdot
.5763 .67739 Mdot
.31062 .34333 Mdot
.29411 .59685 Mdot
.7003 .52893 Mdot
.30055 .58974 Mdot
.69673 .52431 Mdot
.35029 .47048 Mdot
.37781 .70996 Mdot
.32728 .5373 Mdot
.31054 .63658 Mdot
.45836 .3512 Mdot
.34022 .52725 Mdot
.56711 .27608 Mdot
.67163 .6283 Mdot
.30359 .336 Mdot
.5185 .7184 Mdot
.31278 .58548 Mdot
.35261 .5266 Mdot
.5891 .71592 Mdot
.35066 .53447 Mdot
.52481 .27985 Mdot
.37343 .6921 Mdot
.29125 .59761 Mdot
.71064 .50561 Mdot
.69283 .41697 Mdot
.70699 .62459 Mdot
.42207 .34003 Mdot
.64248 .63071 Mdot
.35751 .52015 Mdot
.63044 .35907 Mdot
.37499 .35148 Mdot
.3506 .37118 Mdot
.66096 .6178 Mdot
.29728 .42688 Mdot
.68448 .40924 Mdot
.6574 .33562 Mdot
.49773 .70649 Mdot
.61117 .30665 Mdot
.61194 .34617 Mdot
.65301 .6368 Mdot
.31719 .37374 Mdot
.30411 .59742 Mdot
.59333 .66205 Mdot
.54767 .69142 Mdot
.38429 .69173 Mdot
.64058 .36531 Mdot
.45348 .3328 Mdot
.47377 .74335 Mdot
.3288 .34308 Mdot
.32134 .35058 Mdot
.70019 .52057 Mdot
.62859 .35954 Mdot
.44193 .31428 Mdot
.33058 .35575 Mdot
.6382 .3701 Mdot
.40067 .3407 Mdot
.56112 .27413 Mdot
.6023 .68818 Mdot
.31338 .52881 Mdot
.61457 .66044 Mdot
.69414 .48696 Mdot
.54909 .26499 Mdot
.59101 .69339 Mdot
.61549 .68122 Mdot
.43693 .31711 Mdot
.64382 .30836 Mdot
.57779 .71271 Mdot
.30553 .58219 Mdot
.40953 .33337 Mdot
.3633 .51781 Mdot
.35537 .35869 Mdot
.35278 .51515 Mdot
.5352 .26163 Mdot
.71864 .51142 Mdot
.63295 .34059 Mdot
.70096 .524 Mdot
.3315 .60607 Mdot
.35757 .54204 Mdot
.34048 .51793 Mdot
.39853 .70913 Mdot
.7018 .61876 Mdot
.58359 .66648 Mdot
.61819 .34426 Mdot
.63132 .34356 Mdot
.51909 .71579 Mdot
.67964 .63744 Mdot
.42367 .28565 Mdot
.37957 .70627 Mdot
.34853 .53661 Mdot
.67279 .62773 Mdot
.5133 .71057 Mdot
.68066 .41193 Mdot
.40172 .71296 Mdot
.69934 .61818 Mdot
.56262 .28722 Mdot
.34823 .50285 Mdot
.44667 .32264 Mdot
.44619 .34535 Mdot
.36582 .67647 Mdot
.34667 .34721 Mdot
.68448 .61222 Mdot
.44225 .33333 Mdot
.66886 .63035 Mdot
.6003 .3019 Mdot
.68274 .40355 Mdot
.68197 .62315 Mdot
.35363 .53091 Mdot
.5324 .28735 Mdot
.69667 .50889 Mdot
.29289 .62065 Mdot
.70442 .41811 Mdot
.58985 .68767 Mdot
.66972 .61725 Mdot
.40069 .34096 Mdot
.49964 .7263 Mdot
.71486 .52982 Mdot
.33175 .54581 Mdot
.57403 .67885 Mdot
.47158 .70739 Mdot
.34272 .34476 Mdot
.30755 .60481 Mdot
.3149 .57012 Mdot
.57519 .28919 Mdot
.3229 .6108 Mdot
.70236 .45163 Mdot
.68795 .40612 Mdot
.69476 .44562 Mdot
.70018 .63227 Mdot
.42337 .36005 Mdot
.59222 .67068 Mdot
.43175 .30882 Mdot
.6475 .31465 Mdot
.29299 .6164 Mdot
.40466 .31868 Mdot
.71173 .42794 Mdot
.31364 .36401 Mdot
.37295 .68037 Mdot
.63791 .31306 Mdot
.41295 .34337 Mdot
.71373 .5246 Mdot
.56664 .69762 Mdot
.68763 .61914 Mdot
.56354 .28093 Mdot
.29726 .63055 Mdot
.3434 .52591 Mdot
.70729 .43487 Mdot
.48219 .32966 Mdot
.31992 .34828 Mdot
.41817 .30073 Mdot
.70803 .43049 Mdot
.39855 .71468 Mdot
.58481 .69002 Mdot
.29639 .5926 Mdot
.39389 .71352 Mdot
.70623 .45253 Mdot
.55503 .68093 Mdot
.31238 .34837 Mdot
.31887 .5286 Mdot
.68273 .61165 Mdot
.70629 .51012 Mdot
.40625 .29073 Mdot
.47374 .72806 Mdot
.33231 .53812 Mdot
.27744 .6166 Mdot
.40586 .70087 Mdot
.49057 .70496 Mdot
.40719 .34769 Mdot
.28215 .60677 Mdot
.51795 .71807 Mdot
.49394 .70113 Mdot
.3115 .60878 Mdot
.31398 .60947 Mdot
.67217 .62408 Mdot
.42347 .71359 Mdot
.6121 .31741 Mdot
.49706 .72952 Mdot
.49206 .31208 Mdot
.49278 .70807 Mdot
.41474 .7144 Mdot
.5656 .6696 Mdot
.36004 .67568 Mdot
.68638 .58636 Mdot
.68615 .64057 Mdot
.69352 .48881 Mdot
.46998 .71057 Mdot
.61279 .34051 Mdot
.45128 .33233 Mdot
.53468 .26977 Mdot
.67043 .62479 Mdot
.64148 .369 Mdot
.71213 .40333 Mdot
.6308 .30715 Mdot
.61236 .30103 Mdot
.71981 .51267 Mdot
.65801 .61664 Mdot
.37388 .68616 Mdot
.72067 .51691 Mdot
.45318 .3167 Mdot
.33601 .35816 Mdot
.54904 .69212 Mdot
.42586 .2969 Mdot
.3225 .54049 Mdot
.69033 .47571 Mdot
.64225 .3125 Mdot
.2755 .62066 Mdot
.66874 .64317 Mdot
.33689 .39342 Mdot
.67999 .62082 Mdot
.40239 .34848 Mdot
.30321 .35155 Mdot
.31089 .63141 Mdot
.49108 .31362 Mdot
.7124 .46105 Mdot
.30618 .59814 Mdot
.57343 .66646 Mdot
.53549 .26942 Mdot
.70512 .54156 Mdot
.71946 .47324 Mdot
.4458 .32001 Mdot
.69701 .62129 Mdot
.58412 .67229 Mdot
.42682 .30896 Mdot
.70801 .51113 Mdot
.60872 .70594 Mdot
.32009 .57192 Mdot
.69133 .51791 Mdot
.3024 .59881 Mdot
.32116 .50357 Mdot
.31989 .39279 Mdot
.40442 .32511 Mdot
.4985 .69943 Mdot
.65085 .34305 Mdot
.51973 .71228 Mdot
.32818 .50243 Mdot
.32432 .63356 Mdot
.33769 .53872 Mdot
.27577 .62426 Mdot
.55005 .2851 Mdot
.70593 .61214 Mdot
.41585 .33025 Mdot
.43376 .32337 Mdot
.47144 .70533 Mdot
.51062 .27333 Mdot
.31879 .35696 Mdot
.56569 .27936 Mdot
.36028 .53504 Mdot
.34392 .5346 Mdot
.58079 .68509 Mdot
.32068 .50038 Mdot
.40709 .32274 Mdot
.33844 .54144 Mdot
.36342 .68011 Mdot
.70732 .50191 Mdot
.31273 .57228 Mdot
.34909 .50435 Mdot
.68172 .40758 Mdot
.70889 .50661 Mdot
.54412 .27639 Mdot
.4003 .33582 Mdot
.61718 .35639 Mdot
.32434 .34492 Mdot
.27953 .61614 Mdot
.32909 .59619 Mdot
.40654 .71758 Mdot
.32007 .3427 Mdot
.48911 .71088 Mdot
.33583 .48955 Mdot
.33702 .50283 Mdot
.32079 .35154 Mdot
.6942 .50129 Mdot
.67629 .62675 Mdot
.31896 .50831 Mdot
.43387 .32156 Mdot
.4913 .70194 Mdot
.35488 .37344 Mdot
.66796 .62938 Mdot
.60795 .65969 Mdot
.6657 .61288 Mdot
.71329 .52031 Mdot
.54645 .26811 Mdot
.30258 .35168 Mdot
.68078 .62075 Mdot
.6528 .35338 Mdot
.71284 .41988 Mdot
.41412 .70475 Mdot
.69768 .48285 Mdot
.65291 .6363 Mdot
.69675 .62966 Mdot
.67664 .64787 Mdot
.48454 .72788 Mdot
.27528 .6261 Mdot
.4348 .30908 Mdot
.70872 .4315 Mdot
.651 .33814 Mdot
.3262 .62179 Mdot
.59887 .6577 Mdot
.27349 .64544 Mdot
.31209 .63259 Mdot
.35319 .51447 Mdot
.33773 .51079 Mdot
.41343 .35076 Mdot
.32601 .54091 Mdot
.33193 .51628 Mdot
.71338 .48025 Mdot
.5412 .27408 Mdot
.35773 .54297 Mdot
.41618 .33746 Mdot
.28894 .34294 Mdot
.33567 .39415 Mdot
.31688 .52843 Mdot
.5018 .68759 Mdot
.67978 .62871 Mdot
.6055 .3248 Mdot
.63133 .36427 Mdot
.33886 .38207 Mdot
.71052 .49473 Mdot
.6706 .60099 Mdot
.56312 .29031 Mdot
.30044 .35469 Mdot
.29719 .61112 Mdot
.39927 .70811 Mdot
.35956 .67586 Mdot
.40116 .69377 Mdot
.29415 .61699 Mdot
.41814 .3053 Mdot
.60378 .32362 Mdot
.41207 .69743 Mdot
.61651 .66626 Mdot
.35365 .36486 Mdot
.34217 .36063 Mdot
.56583 .70436 Mdot
.3294 .50204 Mdot
.70276 .53163 Mdot
.38422 .71529 Mdot
.7123 .55062 Mdot
.6583 .59824 Mdot
.27376 .35648 Mdot
.31073 .6033 Mdot
.31354 .60018 Mdot
.32796 .55077 Mdot
.56658 .70668 Mdot
.56965 .67998 Mdot
.57794 .69905 Mdot
.70689 .49995 Mdot
.3131 .59337 Mdot
.69346 .43173 Mdot
.40643 .32457 Mdot
.68968 .61087 Mdot
.43108 .70971 Mdot
.63135 .34281 Mdot
.50154 .70058 Mdot
.31535 .37897 Mdot
.38739 .69587 Mdot
.42155 .33344 Mdot
.31748 .56522 Mdot
.63737 .335 Mdot
.58633 .6922 Mdot
.50907 .70265 Mdot
.6294 .29125 Mdot
.28193 .60839 Mdot
.46012 .33084 Mdot
.40839 .31027 Mdot
.30931 .34443 Mdot
.31131 .59781 Mdot
.32032 .38593 Mdot
.7146 .52881 Mdot
.35407 .54747 Mdot
.29302 .59462 Mdot
.35007 .52539 Mdot
.31412 .62327 Mdot
.70224 .50206 Mdot
.47186 .71337 Mdot
.45581 .3106 Mdot
.40084 .32981 Mdot
.49214 .70685 Mdot
.31308 .37041 Mdot
.69895 .41615 Mdot
.54163 .27635 Mdot
.43926 .30015 Mdot
.30232 .34526 Mdot
.30609 .59583 Mdot
.34914 .53981 Mdot
.40265 .33448 Mdot
.3119 .62769 Mdot
.48058 .72309 Mdot
.62065 .30742 Mdot
.47701 .70594 Mdot
.3458 .38694 Mdot
.31868 .38173 Mdot
.69873 .50238 Mdot
.68215 .6213 Mdot
.33897 .37761 Mdot
.64208 .3367 Mdot
.32099 .5675 Mdot
.30975 .60604 Mdot
.57459 .68074 Mdot
.31977 .63582 Mdot
.34682 .38612 Mdot
.30921 .63041 Mdot
.58796 .70459 Mdot
.57667 .71441 Mdot
.3321 .53702 Mdot
.48591 .72032 Mdot
.6963 .63416 Mdot
.33356 .35676 Mdot
.71293 .49334 Mdot
.30582 .67109 Mdot
.72173 .49882 Mdot
.5778 .70038 Mdot
.4442 .32811 Mdot
.65635 .62299 Mdot
.44535 .32724 Mdot
.55384 .67573 Mdot
.34613 .50216 Mdot
.57069 .6847 Mdot
.45921 .31476 Mdot
.61754 .34516 Mdot
.63306 .29967 Mdot
.41164 .32138 Mdot
.6869 .61183 Mdot
.42936 .31209 Mdot
.33331 .37387 Mdot
.71533 .44226 Mdot
.68613 .64191 Mdot
.61457 .30002 Mdot
.64177 .31274 Mdot
.70745 .43674 Mdot
.3522 .51909 Mdot
.30114 .58739 Mdot
.63009 .30898 Mdot
.71122 .55096 Mdot
.69438 .60094 Mdot
.34284 .52461 Mdot
.43419 .29834 Mdot
.61447 .31367 Mdot
.69702 .39026 Mdot
.58584 .68226 Mdot
.51121 .70197 Mdot
.32508 .63242 Mdot
.68681 .40916 Mdot
.31033 .57505 Mdot
.48623 .72302 Mdot
.33604 .35111 Mdot
.32012 .54973 Mdot
.32029 .58081 Mdot
.68893 .4129 Mdot
.44764 .31261 Mdot
.39885 .69206 Mdot
.61064 .28801 Mdot
.2948 .58979 Mdot
.27384 .40364 Mdot
.40287 .33301 Mdot
.29975 .61003 Mdot
.44999 .29629 Mdot
.6709 .60777 Mdot
.34679 .52822 Mdot
.7135 .41839 Mdot
.61299 .3373 Mdot
.29738 .6304 Mdot
.44253 .36064 Mdot
.70585 .41265 Mdot
.42276 .33401 Mdot
.31727 .34836 Mdot
.50649 .71034 Mdot
.33148 .62199 Mdot
.53752 .28239 Mdot
.32071 .36461 Mdot
.35425 .52256 Mdot
.63972 .34548 Mdot
.69388 .41377 Mdot
.41362 .32707 Mdot
.30861 .58997 Mdot
.69814 .42526 Mdot
.71341 .50178 Mdot
.31704 .38358 Mdot
.71298 .637 Mdot
.35097 .4974 Mdot
.35953 .51416 Mdot
.67925 .65655 Mdot
.58237 .67629 Mdot
.29314 .59909 Mdot
.3617 .54083 Mdot
.70612 .53075 Mdot
.27904 .65487 Mdot
.31529 .56736 Mdot
.45957 .31779 Mdot
.70448 .54242 Mdot
.6274 .36615 Mdot
.64598 .31444 Mdot
.3271 .36304 Mdot
.66545 .60782 Mdot
.31899 .39022 Mdot
.61297 .33109 Mdot
.31205 .5824 Mdot
.72378 .50978 Mdot
.5314 .71401 Mdot
.70733 .42154 Mdot
.64044 .32678 Mdot
.60547 .67342 Mdot
.3979 .72477 Mdot
.27564 .40603 Mdot
.7155 .55219 Mdot
.56125 .28046 Mdot
.35049 .36938 Mdot
.61662 .6664 Mdot
.35818 .52964 Mdot
.41884 .7085 Mdot
.29753 .62902 Mdot
.42523 .35858 Mdot
.53275 .27538 Mdot
.40059 .34066 Mdot
.44574 .3188 Mdot
.27889 .62185 Mdot
.7137 .50068 Mdot
.68759 .42125 Mdot
.4326 .33968 Mdot
.71307 .51627 Mdot
.36381 .52572 Mdot
.6333 .32129 Mdot
.59413 .6513 Mdot
.34932 .53622 Mdot
.29212 .36069 Mdot
.70805 .39989 Mdot
.61673 .67853 Mdot
.6314 .36667 Mdot
.31279 .59996 Mdot
.64555 .6199 Mdot
.71853 .52387 Mdot
.31658 .54516 Mdot
.61496 .34061 Mdot
.43816 .2999 Mdot
.6371 .34977 Mdot
.29707 .60327 Mdot
.31459 .60545 Mdot
.45038 .31027 Mdot
.34928 .53477 Mdot
.70788 .60468 Mdot
.47618 .72942 Mdot
.52404 .7049 Mdot
.33099 .51667 Mdot
.58609 .65828 Mdot
.69969 .40481 Mdot
.43447 .33929 Mdot
.40635 .70098 Mdot
.31781 .62737 Mdot
.6969 .63734 Mdot
.69865 .41378 Mdot
.73065 .47884 Mdot
.70461 .50228 Mdot
.61579 .34474 Mdot
.71182 .49604 Mdot
.32824 .55247 Mdot
.68914 .59171 Mdot
.62112 .3283 Mdot
.42896 .33107 Mdot
.65618 .35427 Mdot
.33649 .5604 Mdot
.71032 .39908 Mdot
.65435 .32766 Mdot
.49508 .72788 Mdot
.68268 .59204 Mdot
.48695 .31796 Mdot
.50217 .68676 Mdot
.31644 .579 Mdot
.29691 .62702 Mdot
.41629 .30255 Mdot
.69989 .50126 Mdot
.58402 .67937 Mdot
.56053 .27215 Mdot
.34263 .38945 Mdot
.68684 .58669 Mdot
.33039 .39259 Mdot
.39441 .70955 Mdot
.59996 .65431 Mdot
.36367 .68066 Mdot
.69697 .51982 Mdot
.68773 .61631 Mdot
.3565 .37156 Mdot
.49575 .73288 Mdot
.32145 .37444 Mdot
.64094 .36216 Mdot
.37472 .70134 Mdot
.61651 .30367 Mdot
.71193 .43939 Mdot
.55032 .27413 Mdot
.71197 .53579 Mdot
.44676 .35878 Mdot
.46247 .71915 Mdot
.69244 .40439 Mdot
.71737 .42265 Mdot
.60881 .32133 Mdot
.42482 .34097 Mdot
.47381 .71176 Mdot
.43499 .34654 Mdot
.42311 .34591 Mdot
.68621 .41532 Mdot
.68947 .62107 Mdot
.67837 .63629 Mdot
.30059 .33764 Mdot
.68757 .62256 Mdot
.62134 .31541 Mdot
.40095 .71177 Mdot
.41817 .72535 Mdot
.70066 .40398 Mdot
.50617 .7093 Mdot
.32369 .55061 Mdot
.52454 .27067 Mdot
.628 .31778 Mdot
.70939 .49961 Mdot
.65424 .64771 Mdot
.44392 .33323 Mdot
.58808 .68058 Mdot
.67778 .6017 Mdot
.67183 .61111 Mdot
.65466 .62532 Mdot
.31806 .59698 Mdot
.71505 .53633 Mdot
.6831 .61008 Mdot
.30066 .59823 Mdot
.36036 .50838 Mdot
.43622 .30144 Mdot
.42719 .35837 Mdot
.47982 .71891 Mdot
.43694 .30948 Mdot
.34419 .54534 Mdot
.62686 .34548 Mdot
.42921 .36023 Mdot
.44889 .32743 Mdot
.60784 .33339 Mdot
.60594 .33066 Mdot
.4301 .347 Mdot
.42752 .36028 Mdot
.7088 .60933 Mdot
.45886 .72673 Mdot
.57427 .66614 Mdot
.65493 .32559 Mdot
.69901 .45183 Mdot
.57272 .68265 Mdot
.29372 .62742 Mdot
.43319 .29508 Mdot
.63542 .33261 Mdot
.67958 .64486 Mdot
.33733 .51967 Mdot
.43467 .31682 Mdot
.32733 .37236 Mdot
.42853 .33323 Mdot
.41831 .30402 Mdot
.56095 .68656 Mdot
.68192 .51243 Mdot
.61039 .67684 Mdot
.62216 .29036 Mdot
.42173 .32956 Mdot
.5927 .71376 Mdot
.54593 .26288 Mdot
.71451 .4457 Mdot
.47491 .73003 Mdot
.32867 .51909 Mdot
.60526 .32334 Mdot
.6945 .61042 Mdot
.70543 .47674 Mdot
.36144 .67934 Mdot
.68163 .61996 Mdot
.40109 .34408 Mdot
.41228 .31474 Mdot
.61316 .31404 Mdot
.56391 .69638 Mdot
.48771 .72238 Mdot
.67832 .61447 Mdot
.70503 .43404 Mdot
.30614 .63553 Mdot
.64213 .63089 Mdot
.44058 .31396 Mdot
.67969 .63242 Mdot
.64952 .3361 Mdot
.33195 .38446 Mdot
.3105 .6223 Mdot
.73763 .51756 Mdot
.35383 .5252 Mdot
.70503 .43852 Mdot
.28673 .36038 Mdot
.51138 .71889 Mdot
.2969 .61809 Mdot
.41387 .70747 Mdot
.71738 .41831 Mdot
.29347 .60915 Mdot
.39999 .72327 Mdot
.61117 .6608 Mdot
.59713 .68317 Mdot
.36095 .53339 Mdot
.62683 .30982 Mdot
.60061 .28231 Mdot
.35332 .50601 Mdot
.63266 .29095 Mdot
.3816 .71512 Mdot
.44945 .33449 Mdot
.34349 .3434 Mdot
.32703 .59005 Mdot
.30465 .62047 Mdot
.32791 .53806 Mdot
.30603 .63654 Mdot
.35782 .67641 Mdot
.61332 .33507 Mdot
.62029 .35757 Mdot
.33432 .36969 Mdot
.27824 .60902 Mdot
.32174 .38255 Mdot
.69438 .41223 Mdot
.46602 .71417 Mdot
.40397 .31711 Mdot
.68368 .62546 Mdot
.3495 .52864 Mdot
.64319 .35602 Mdot
.29995 .61157 Mdot
.49813 .71641 Mdot
.61813 .31499 Mdot
.63453 .33814 Mdot
.60145 .28789 Mdot
.3508 .38015 Mdot
.66341 .62253 Mdot
.33172 .55752 Mdot
.34914 .35413 Mdot
.45201 .32124 Mdot
.3106 .6762 Mdot
.68139 .58768 Mdot
.67 .632 Mdot
.65954 .63247 Mdot
.33192 .54813 Mdot
.33223 .55023 Mdot
.70028 .43893 Mdot
.5862 .66838 Mdot
.72414 .52282 Mdot
.60461 .31642 Mdot
.61769 .28368 Mdot
.30281 .61613 Mdot
.2952 .35642 Mdot
.31406 .37237 Mdot
.65695 .3406 Mdot
.40804 .31417 Mdot
.3232 .38851 Mdot
.33535 .55343 Mdot
.61014 .31264 Mdot
.35376 .37331 Mdot
.65369 .64096 Mdot
.72833 .48364 Mdot
.32731 .38697 Mdot
.44448 .31463 Mdot
.60048 .66072 Mdot
.32543 .59973 Mdot
.32382 .39321 Mdot
.69678 .40629 Mdot
.37314 .68401 Mdot
.40594 .31953 Mdot
.29858 .36082 Mdot
.28293 .65713 Mdot
.6159 .32777 Mdot
.44576 .31498 Mdot
.35832 .36914 Mdot
.42324 .72347 Mdot
.31233 .38299 Mdot
.67352 .63312 Mdot
.52306 .69549 Mdot
.30171 .62435 Mdot
.5053 .71874 Mdot
.69419 .48979 Mdot
.64241 .36316 Mdot
.63063 .36169 Mdot
.569 .69028 Mdot
.4076 .70981 Mdot
.62637 .30479 Mdot
.41118 .70643 Mdot
.32934 .33565 Mdot
.30073 .59852 Mdot
.30003 .33693 Mdot
.50124 .73051 Mdot
.35194 .38822 Mdot
.32943 .38597 Mdot
.70745 .40407 Mdot
.7177 .51018 Mdot
.69982 .5051 Mdot
.62128 .30499 Mdot
.39312 .70365 Mdot
.624 .35872 Mdot
.70342 .64813 Mdot
.31999 .35756 Mdot
.56044 .28855 Mdot
.32455 .54255 Mdot
.34159 .54571 Mdot
.51332 .70647 Mdot
.42736 .29867 Mdot
.29842 .59692 Mdot
.69929 .43 Mdot
.65308 .35328 Mdot
.71265 .40087 Mdot
.56957 .70151 Mdot
.69707 .65223 Mdot
.63207 .33909 Mdot
.3205 .33427 Mdot
.31332 .37611 Mdot
.28079 .66075 Mdot
.44938 .34509 Mdot
.62695 .35098 Mdot
.33774 .49745 Mdot
.68518 .64334 Mdot
.56982 .29155 Mdot
.34764 .52566 Mdot
.64554 .31627 Mdot
.5479 .26094 Mdot
.50489 .72539 Mdot
.32244 .61022 Mdot
.7104 .46251 Mdot
.40625 .70434 Mdot
.34775 .38979 Mdot
.45041 .30855 Mdot
.42994 .7069 Mdot
.61151 .32929 Mdot
.65182 .3634 Mdot
.33646 .38745 Mdot
.61482 .67613 Mdot
.68052 .64028 Mdot
.70859 .61094 Mdot
.70052 .43424 Mdot
.34103 .50157 Mdot
.61063 .31482 Mdot
.59657 .67431 Mdot
.32051 .56482 Mdot
.70521 .5249 Mdot
.65872 .34562 Mdot
.34921 .53455 Mdot
.29709 .61598 Mdot
.32534 .38097 Mdot
.28837 .34379 Mdot
.45511 .30607 Mdot
.71578 .44494 Mdot
.27804 .64171 Mdot
.46697 .71155 Mdot
.33172 .53721 Mdot
.69932 .60647 Mdot
.42719 .31048 Mdot
.31687 .37301 Mdot
.28733 .60518 Mdot
.41804 .71508 Mdot
.69755 .62603 Mdot
.69784 .52352 Mdot
.42755 .32715 Mdot
.27689 .63589 Mdot
.35148 .53091 Mdot
.30341 .62917 Mdot
.4849 .72783 Mdot
.32288 .53173 Mdot
.53229 .2686 Mdot
.61221 .68678 Mdot
.33725 .34778 Mdot
.66775 .61618 Mdot
.55403 .26871 Mdot
.47102 .72744 Mdot
.3825 .70182 Mdot
.59623 .65485 Mdot
.68387 .59012 Mdot
.7064 .43459 Mdot
.71774 .53171 Mdot
.29424 .35249 Mdot
.30051 .60611 Mdot
.40444 .33141 Mdot
.67794 .60934 Mdot
.64115 .36241 Mdot
.32099 .38323 Mdot
.56254 .28221 Mdot
.33587 .53792 Mdot
.61035 .323 Mdot
.41417 .32214 Mdot
.56262 .69935 Mdot
.62404 .34411 Mdot
.43748 .29984 Mdot
.33754 .35657 Mdot
.37825 .68578 Mdot
.41079 .35897 Mdot
.44371 .32603 Mdot
.30376 .60937 Mdot
.51819 .73091 Mdot
.5068 .71327 Mdot
.45906 .32309 Mdot
.63485 .36999 Mdot
.44129 .31969 Mdot
.61849 .67669 Mdot
.50468 .72404 Mdot
.65086 .34525 Mdot
.57796 .6752 Mdot
.47764 .73064 Mdot
.44425 .3298 Mdot
.67859 .58866 Mdot
.55604 .26715 Mdot
.66787 .65079 Mdot
.32352 .58107 Mdot
.34258 .5079 Mdot
.61775 .30279 Mdot
.3234 .37419 Mdot
.6925 .43337 Mdot
.68731 .39985 Mdot
.71607 .41941 Mdot
.60775 .29756 Mdot
.34872 .53143 Mdot
.68496 .61353 Mdot
.71848 .51954 Mdot
.581 .68234 Mdot
.64343 .34055 Mdot
.63176 .31609 Mdot
.51071 .7053 Mdot
.31908 .38278 Mdot
.32514 .54303 Mdot
.64072 .36181 Mdot
.5458 .27244 Mdot
.60908 .70617 Mdot
.35145 .38596 Mdot
.47273 .72392 Mdot
.40976 .35818 Mdot
.29376 .58824 Mdot
.61624 .65606 Mdot
.40964 .32127 Mdot
.56573 .69976 Mdot
.31959 .57469 Mdot
.67488 .38492 Mdot
.54447 .26301 Mdot
.40798 .70642 Mdot
.71282 .45975 Mdot
.72148 .52038 Mdot
.62086 .34113 Mdot
.33785 .52819 Mdot
.56213 .28407 Mdot
.32819 .3631 Mdot
.51394 .72431 Mdot
.43408 .34031 Mdot
.57737 .6812 Mdot
.72069 .50193 Mdot
.43614 .36105 Mdot
.69272 .43354 Mdot
.69802 .50953 Mdot
.57151 .66601 Mdot
.30212 .62352 Mdot
.63027 .33094 Mdot
.63561 .31439 Mdot
.30166 .33661 Mdot
.52279 .2754 Mdot
.66712 .64155 Mdot
.67446 .38475 Mdot
.41856 .70149 Mdot
.35803 .53724 Mdot
.40453 .3464 Mdot
.4063 .33313 Mdot
.55055 .27033 Mdot
.29309 .60899 Mdot
.59596 .69167 Mdot
.62493 .3624 Mdot
.63824 .3065 Mdot
.50092 .72285 Mdot
.71888 .51221 Mdot
.46095 .33396 Mdot
.62422 .31678 Mdot
.30895 .6717 Mdot
.30444 .6165 Mdot
.71514 .55159 Mdot
.62247 .31781 Mdot
.51293 .27046 Mdot
.68417 .42819 Mdot
.60412 .67522 Mdot
.39121 .68461 Mdot
.58711 .68584 Mdot
.32203 .38714 Mdot
.62739 .35628 Mdot
.69007 .41985 Mdot
.42433 .33113 Mdot
.59828 .28331 Mdot
.62149 .30249 Mdot
.67187 .62542 Mdot
.30132 .62734 Mdot
.3201 .51181 Mdot
.35175 .53286 Mdot
.27598 .65443 Mdot
.347 .38814 Mdot
.68745 .39942 Mdot
.70778 .43342 Mdot
.392 .6848 Mdot
.35335 .37684 Mdot
.61378 .34568 Mdot
.61691 .31612 Mdot
.73714 .51439 Mdot
.41746 .30515 Mdot
.61604 .34951 Mdot
.3056 .61153 Mdot
.60332 .28614 Mdot
.59814 .65744 Mdot
.71879 .5086 Mdot
.31593 .62797 Mdot
.61891 .30112 Mdot
.56062 .68434 Mdot
.39821 .70365 Mdot
.35478 .50775 Mdot
.45732 .30189 Mdot
.718 .52838 Mdot
.68935 .65676 Mdot
.52507 .26981 Mdot
.34483 .50289 Mdot
.69548 .41758 Mdot
.47296 .33987 Mdot
.59328 .28713 Mdot
.66245 .61545 Mdot
.64212 .31369 Mdot
.7149 .4944 Mdot
.4175 .32325 Mdot
.33599 .34699 Mdot
.63353 .35079 Mdot
.64667 .31376 Mdot
.4909 .7116 Mdot
.31207 .33548 Mdot
.32644 .39326 Mdot
.69042 .59865 Mdot
.70467 .53106 Mdot
.50064 .71701 Mdot
.30197 .66992 Mdot
.33249 .55311 Mdot
.69809 .50369 Mdot
.62048 .6961 Mdot
.34228 .49779 Mdot
.33063 .52933 Mdot
.31725 .5441 Mdot
.61205 .67109 Mdot
.68858 .60645 Mdot
.27347 .64001 Mdot
.48488 .71889 Mdot
.38744 .70563 Mdot
.67812 .62832 Mdot
.66682 .62214 Mdot
.38616 .6979 Mdot
.49416 .7125 Mdot
.57808 .67269 Mdot
.71568 .51324 Mdot
.7213 .52116 Mdot
.67093 .61036 Mdot
.51446 .70775 Mdot
.69509 .51134 Mdot
.58011 .68941 Mdot
.63848 .3246 Mdot
.39067 .71864 Mdot
.67177 .60095 Mdot
.37606 .70494 Mdot
.71422 .52903 Mdot
.29091 .6681 Mdot
.38081 .71488 Mdot
.3247 .52406 Mdot
.29997 .62332 Mdot
.35097 .36439 Mdot
.42515 .33407 Mdot
.4297 .34722 Mdot
.70072 .50027 Mdot
.32689 .54326 Mdot
.58121 .69903 Mdot
.32979 .54757 Mdot
.32291 .63338 Mdot
.29271 .66608 Mdot
.41525 .69538 Mdot
.66391 .61442 Mdot
.57918 .69986 Mdot
.61722 .28683 Mdot
.64795 .36215 Mdot
.41196 .71822 Mdot
.71937 .52581 Mdot
.68374 .63209 Mdot
.72408 .52192 Mdot
.61257 .32941 Mdot
.63221 .33266 Mdot
.43179 .30638 Mdot
.44584 .31439 Mdot
.62203 .33623 Mdot
.63138 .29239 Mdot
.29978 .67178 Mdot
.57746 .67702 Mdot
.62149 .66693 Mdot
.33071 .61361 Mdot
.32153 .50242 Mdot
.32483 .37243 Mdot
.42547 .36188 Mdot
.69688 .42649 Mdot
.40994 .70006 Mdot
.34552 .55327 Mdot
.44076 .32782 Mdot
.69091 .499 Mdot
.30906 .36037 Mdot
.72061 .51316 Mdot
.32699 .34686 Mdot
.65054 .34306 Mdot
.34517 .53485 Mdot
.32724 .53447 Mdot
.70608 .43171 Mdot
.60607 .28824 Mdot
.61009 .30961 Mdot
.32122 .37116 Mdot
.32986 .60756 Mdot
.61232 .31825 Mdot
.67296 .59878 Mdot
.66257 .59423 Mdot
.41 .32755 Mdot
.33725 .52273 Mdot
.32776 .59736 Mdot
.50297 .72545 Mdot
.45158 .32357 Mdot
.42818 .32653 Mdot
.71421 .63389 Mdot
.30635 .58132 Mdot
.73204 .47942 Mdot
.44892 .31421 Mdot
.65737 .62549 Mdot
.62859 .3326 Mdot
.44906 .32898 Mdot
.44316 .34581 Mdot
.26607 .37794 Mdot
.42322 .35073 Mdot
.6938 .62405 Mdot
.58831 .68851 Mdot
.47541 .70942 Mdot
.62754 .68655 Mdot
.31574 .34325 Mdot
.31272 .36594 Mdot
.54213 .26266 Mdot
.71261 .41535 Mdot
.31763 .55908 Mdot
.32004 .3606 Mdot
.65705 .64678 Mdot
.50519 .70248 Mdot
.49504 .70502 Mdot
.48501 .70753 Mdot
.58194 .68443 Mdot
.31203 .60253 Mdot
.53434 .27287 Mdot
.67344 .62652 Mdot
.47824 .70544 Mdot
.33581 .49255 Mdot
.70618 .61407 Mdot
.70027 .5247 Mdot
.52242 .71354 Mdot
.68505 .61588 Mdot
.3623 .67646 Mdot
.70928 .53492 Mdot
.41653 .71095 Mdot
.66251 .38257 Mdot
.51265 .27203 Mdot
.71114 .50247 Mdot
.65846 .34329 Mdot
.6089 .31904 Mdot
.61931 .30928 Mdot
.68369 .60398 Mdot
.6396 .30297 Mdot
.58148 .70124 Mdot
.56087 .28047 Mdot
.27676 .6312 Mdot
.30308 .35112 Mdot
.54735 .27477 Mdot
.67144 .61222 Mdot
.67943 .65726 Mdot
.28744 .41878 Mdot
.35343 .50276 Mdot
.69007 .40865 Mdot
.3353 .36537 Mdot
.39984 .71116 Mdot
.3372 .35126 Mdot
.61347 .33933 Mdot
.27977 .62602 Mdot
.30432 .6171 Mdot
.72863 .48144 Mdot
.32343 .37604 Mdot
.66592 .61988 Mdot
.48919 .71 Mdot
.62211 .36511 Mdot
.32643 .3638 Mdot
.31804 .3811 Mdot
.35812 .51275 Mdot
.58633 .68992 Mdot
.60357 .31808 Mdot
.69902 .53712 Mdot
.56463 .2723 Mdot
.33841 .67605 Mdot
.29991 .587 Mdot
.34662 .50144 Mdot
.39314 .71153 Mdot
.55641 .27245 Mdot
.71247 .51062 Mdot
.32003 .6363 Mdot
.52051 .26466 Mdot
.32213 .6368 Mdot
.56392 .70535 Mdot
.5533 .27802 Mdot
.41012 .33143 Mdot
.43752 .30139 Mdot
.34325 .52065 Mdot
.27735 .40917 Mdot
.31067 .59055 Mdot
.69382 .51465 Mdot
.42173 .33905 Mdot
.65819 .33187 Mdot
.67803 .6435 Mdot
.26601 .38135 Mdot
.48147 .7208 Mdot
.69878 .53551 Mdot
.6145 .31839 Mdot
.26742 .39262 Mdot
.34915 .3674 Mdot
.38337 .71974 Mdot
.36175 .50997 Mdot
.34145 .51972 Mdot
.70176 .51596 Mdot
.6932 .50688 Mdot
.61772 .65869 Mdot
.4108 .3565 Mdot
.65287 .60551 Mdot
.70914 .42144 Mdot
.26641 .38941 Mdot
.40467 .33439 Mdot
.60469 .68626 Mdot
.4095 .34757 Mdot
.69591 .48576 Mdot
.30199 .58863 Mdot
.58719 .68884 Mdot
.41412 .31878 Mdot
.51835 .69032 Mdot
.50303 .70768 Mdot
.30843 .67251 Mdot
.35464 .51476 Mdot
.66799 .63739 Mdot
.67386 .62899 Mdot
.58305 .69683 Mdot
.41671 .31046 Mdot
.3379 .54108 Mdot
.33349 .51362 Mdot
.33902 .50359 Mdot
.61589 .70082 Mdot
.34639 .53187 Mdot
.67056 .6479 Mdot
.39948 .72071 Mdot
.67606 .38477 Mdot
.32903 .53806 Mdot
.70778 .49391 Mdot
.34675 .51455 Mdot
.33333 .3945 Mdot
.38536 .68617 Mdot
.49483 .73001 Mdot
.71056 .51574 Mdot
.32713 .50462 Mdot
.49171 .31179 Mdot
.33278 .55805 Mdot
.31897 .34566 Mdot
.6913 .43976 Mdot
.31743 .59259 Mdot
.61173 .70375 Mdot
.6754 .6145 Mdot
.64141 .35036 Mdot
.71151 .47912 Mdot
.6181 .346 Mdot
.45875 .72749 Mdot
.40341 .33956 Mdot
.56301 .28765 Mdot
.29941 .66909 Mdot
.30694 .58413 Mdot
.41388 .30533 Mdot
.57313 .69816 Mdot
.53622 .26921 Mdot
.31983 .50308 Mdot
.5124 .70566 Mdot
.33615 .3858 Mdot
.33623 .35321 Mdot
.2808 .3491 Mdot
.5907 .67737 Mdot
.67263 .65679 Mdot
.70285 .5182 Mdot
.62414 .30317 Mdot
.35226 .38629 Mdot
.73446 .54683 Mdot
.69733 .49089 Mdot
.54677 .2692 Mdot
.72123 .50438 Mdot
.33284 .5406 Mdot
.4322 .34639 Mdot
.60491 .66496 Mdot
.43516 .3361 Mdot
.31962 .56868 Mdot
.63247 .30176 Mdot
.41191 .31313 Mdot
.34961 .35609 Mdot
.71017 .49029 Mdot
.6302 .34351 Mdot
.30349 .62743 Mdot
.67485 .63064 Mdot
.46027 .73829 Mdot
.51709 .26616 Mdot
.49212 .73029 Mdot
.48878 .73119 Mdot
.61428 .66898 Mdot
.45479 .32583 Mdot
.58284 .28077 Mdot
.49465 .73208 Mdot
.71479 .42937 Mdot
.2981 .36968 Mdot
.54565 .28879 Mdot
.63053 .35986 Mdot
.61956 .32681 Mdot
.31815 .57417 Mdot
.61769 .35743 Mdot
.38703 .69186 Mdot
.62405 .36665 Mdot
.68337 .42135 Mdot
.30735 .59938 Mdot
.6186 .31742 Mdot
.44918 .31759 Mdot
.3085 .61571 Mdot
.59938 .68338 Mdot
.61042 .34747 Mdot
.32468 .52371 Mdot
.64486 .30248 Mdot
.70601 .43571 Mdot
.41962 .30814 Mdot
.37015 .68271 Mdot
.7155 .51923 Mdot
.69447 .61786 Mdot
.3794 .67757 Mdot
.32594 .35978 Mdot
.59227 .69748 Mdot
.29322 .36099 Mdot
.31538 .38101 Mdot
.38795 .71465 Mdot
.68553 .59328 Mdot
.41236 .33736 Mdot
.33567 .35488 Mdot
.33834 .34157 Mdot
.61783 .32692 Mdot
.53454 .26054 Mdot
.44295 .31814 Mdot
.30489 .62884 Mdot
.54714 .28418 Mdot
.71187 .49819 Mdot
.35867 .50804 Mdot
.61399 .3073 Mdot
.41682 .33709 Mdot
.33229 .52408 Mdot
.48337 .71911 Mdot
.61049 .66216 Mdot
.41619 .35538 Mdot
.31366 .34777 Mdot
.59366 .68648 Mdot
.34756 .5021 Mdot
.31322 .34172 Mdot
.55972 .26792 Mdot
.3124 .6129 Mdot
.66092 .61602 Mdot
.65432 .644 Mdot
.63908 .36379 Mdot
.69806 .52628 Mdot
.63902 .31678 Mdot
.32641 .34523 Mdot
.28858 .42043 Mdot
.43872 .30806 Mdot
.50723 .72818 Mdot
.38368 .68921 Mdot
.63778 .35605 Mdot
.66419 .62335 Mdot
.72348 .55123 Mdot
.38317 .68578 Mdot
.31028 .61139 Mdot
.33885 .51786 Mdot
.55475 .27463 Mdot
.68138 .64171 Mdot
.33776 .5199 Mdot
.42745 .35936 Mdot
.31111 .6057 Mdot
.33525 .3753 Mdot
.65476 .38071 Mdot
.44356 .30143 Mdot
.60787 .70841 Mdot
.41546 .31452 Mdot
.62295 .3134 Mdot
.36301 .6739 Mdot
.39122 .70648 Mdot
.27296 .35804 Mdot
.69466 .6238 Mdot
.56186 .68167 Mdot
.63108 .3286 Mdot
.5539 .26775 Mdot
.47762 .72017 Mdot
.48585 .71203 Mdot
.30751 .61637 Mdot
.61406 .33986 Mdot
.64699 .37115 Mdot
.40746 .3439 Mdot
.41068 .31164 Mdot
.41497 .7198 Mdot
.64852 .34311 Mdot
.34507 .5342 Mdot
.5113 .71067 Mdot
.70185 .48179 Mdot
.59445 .68055 Mdot
.69602 .40098 Mdot
.70312 .47848 Mdot
.31416 .52926 Mdot
.2796 .64592 Mdot
.69918 .43441 Mdot
.7142 .40979 Mdot
.54395 .26671 Mdot
.41985 .72152 Mdot
.32546 .38632 Mdot
.28165 .65454 Mdot
.61671 .3462 Mdot
.34719 .54201 Mdot
.66047 .63877 Mdot
.40593 .35073 Mdot
.73686 .53651 Mdot
.33545 .45717 Mdot
.47091 .71534 Mdot
.53804 .28011 Mdot
.44376 .3274 Mdot
.43299 .33893 Mdot
.32612 .60417 Mdot
.34433 .53278 Mdot
.63751 .36367 Mdot
.42295 .72293 Mdot
.70872 .42046 Mdot
.54665 .26585 Mdot
.59232 .67491 Mdot
.3467 .5181 Mdot
.70445 .62733 Mdot
.706 .48484 Mdot
.30371 .37097 Mdot
.351 .3753 Mdot
.33352 .55857 Mdot
.47275 .72924 Mdot
.71232 .44015 Mdot
.48027 .71538 Mdot
.49631 .71539 Mdot
.43787 .31871 Mdot
.47353 .72492 Mdot
.36263 .50965 Mdot
.35123 .49468 Mdot
.45213 .32111 Mdot
.69841 .48666 Mdot
.32158 .57763 Mdot
.4434 .33132 Mdot
.37839 .68213 Mdot
.71458 .48468 Mdot
.4792 .71708 Mdot
.70462 .50121 Mdot
.54849 .26824 Mdot
.70332 .43426 Mdot
.33838 .34821 Mdot
.54502 .27131 Mdot
.62039 .66616 Mdot
.68543 .61449 Mdot
.71785 .53398 Mdot
.33753 .3576 Mdot
.70769 .4974 Mdot
.6314 .34873 Mdot
.71174 .4352 Mdot
.57268 .71418 Mdot
.31441 .67256 Mdot
.31453 .53475 Mdot
.71232 .5483 Mdot
.65012 .35619 Mdot
.67165 .61005 Mdot
.71414 .41664 Mdot
.37514 .68855 Mdot
.34896 .37144 Mdot
.34326 .51742 Mdot
.70842 .48839 Mdot
.54562 .27805 Mdot
.60765 .65698 Mdot
.32529 .34834 Mdot
.69619 .6542 Mdot
.64484 .35211 Mdot
.3062 .60199 Mdot
.68274 .40475 Mdot
.58852 .2855 Mdot
.70691 .43022 Mdot
.32148 .51121 Mdot
.40417 .32663 Mdot
.41964 .35732 Mdot
.572 .67226 Mdot
.41479 .30261 Mdot
.46244 .35 Mdot
.717 .42624 Mdot
.61191 .68247 Mdot
.61961 .28864 Mdot
.30513 .62963 Mdot
.46871 .71112 Mdot
.43526 .31057 Mdot
.67647 .63716 Mdot
.48707 .72771 Mdot
.43265 .30461 Mdot
.39811 .72073 Mdot
.58971 .68446 Mdot
.60937 .34203 Mdot
.30445 .61095 Mdot
.68443 .40811 Mdot
.7047 .41604 Mdot
.40071 .34334 Mdot
.69051 .42843 Mdot
.37895 .68227 Mdot
.68349 .59249 Mdot
.47481 .71163 Mdot
.33568 .37336 Mdot
.70637 .60207 Mdot
.41099 .35239 Mdot
.26749 .37366 Mdot
.30427 .60807 Mdot
.63118 .33093 Mdot
.595 .28738 Mdot
.4126 .71981 Mdot
.67788 .62624 Mdot
.39024 .69016 Mdot
.48052 .72787 Mdot
.48259 .71403 Mdot
.62358 .3032 Mdot
.39692 .71063 Mdot
.34639 .5331 Mdot
.70102 .53636 Mdot
.35341 .67836 Mdot
.32945 .49693 Mdot
.41863 .36089 Mdot
.49545 .72975 Mdot
.68439 .42043 Mdot
.57948 .67562 Mdot
.62919 .32936 Mdot
.59725 .69281 Mdot
.58269 .67724 Mdot
.6889 .60974 Mdot
.73217 .54938 Mdot
.49593 .73139 Mdot
.73721 .49832 Mdot
.59883 .65686 Mdot
.32212 .50292 Mdot
.66435 .64451 Mdot
.57678 .2794 Mdot
.61204 .68377 Mdot
.69472 .61903 Mdot
.59537 .65072 Mdot
.68185 .64081 Mdot
.30639 .62279 Mdot
.31675 .62887 Mdot
.42694 .70819 Mdot
.55878 .28052 Mdot
.3511 .53441 Mdot
.42988 .34867 Mdot
.3391 .37146 Mdot
.61307 .6752 Mdot
.42726 .32961 Mdot
.38208 .71162 Mdot
.43681 .28762 Mdot
.36242 .52139 Mdot
.33419 .52553 Mdot
.48224 .70937 Mdot
.28778 .66498 Mdot
.55782 .28467 Mdot
.66053 .62961 Mdot
.33209 .49369 Mdot
.59411 .28582 Mdot
.29864 .59848 Mdot
.39225 .68951 Mdot
.34749 .49384 Mdot
.63033 .33101 Mdot
.59133 .67117 Mdot
.42397 .34623 Mdot
.70801 .62753 Mdot
.3549 .52272 Mdot
.42744 .28518 Mdot
.29928 .34793 Mdot
.33644 .5245 Mdot
.70722 .6186 Mdot
.48435 .72811 Mdot
.69732 .61415 Mdot
.69401 .59515 Mdot
.31017 .61084 Mdot
.60121 .6719 Mdot
.68833 .60502 Mdot
.48547 .71282 Mdot
.53948 .28111 Mdot
.71547 .44317 Mdot
.30882 .58563 Mdot
.32443 .34908 Mdot
.2939 .61494 Mdot
.31394 .38373 Mdot
.43923 .34244 Mdot
.44302 .32271 Mdot
.3101 .59685 Mdot
.65453 .35391 Mdot
.32129 .39182 Mdot
.55722 .28268 Mdot
.58015 .71636 Mdot
.57018 .66921 Mdot
.71039 .42219 Mdot
.5336 .26028 Mdot
.44171 .32113 Mdot
.32486 .57671 Mdot
.34054 .67534 Mdot
.69518 .43374 Mdot
.56264 .70081 Mdot
.31128 .58718 Mdot
.42031 .29913 Mdot
.60614 .33615 Mdot
.63396 .31421 Mdot
.71652 .42728 Mdot
.58589 .65417 Mdot
.33558 .54543 Mdot
.4198 .29992 Mdot
.52645 .70615 Mdot
.42376 .33464 Mdot
.41782 .34794 Mdot
.65951 .3431 Mdot
.33808 .53701 Mdot
.37821 .71067 Mdot
.60742 .32252 Mdot
.30956 .37011 Mdot
.56201 .69751 Mdot
.31803 .34321 Mdot
.72566 .47834 Mdot
.61562 .6606 Mdot
.61873 .33821 Mdot
.4395 .29856 Mdot
.35252 .53744 Mdot
.58403 .67906 Mdot
.57207 .69581 Mdot
.59954 .67968 Mdot
.33607 .36963 Mdot
.62973 .3626 Mdot
.56551 .27524 Mdot
.30343 .62468 Mdot
.6809 .59069 Mdot
.26597 .37685 Mdot
.29577 .61334 Mdot
.72021 .52246 Mdot
.49147 .72742 Mdot
.66721 .60928 Mdot
.51234 .72278 Mdot
.59413 .65625 Mdot
.62926 .31155 Mdot
.33368 .56139 Mdot
.30874 .62274 Mdot
.31794 .59412 Mdot
.30972 .35976 Mdot
.69502 .63329 Mdot
.27681 .64343 Mdot
.29369 .58834 Mdot
.32598 .59612 Mdot
.33549 .5176 Mdot
.31473 .53708 Mdot
.45337 .33774 Mdot
.43818 .30532 Mdot
.38047 .69073 Mdot
.35116 .50744 Mdot
.70592 .609 Mdot
.60307 .66184 Mdot
.46448 .69648 Mdot
.69693 .50624 Mdot
.6135 .68326 Mdot
.60653 .3246 Mdot
.60756 .34353 Mdot
.61288 .28523 Mdot
.34856 .34959 Mdot
.47658 .71654 Mdot
.34103 .55703 Mdot
.69469 .51581 Mdot
.32717 .35757 Mdot
.68427 .58836 Mdot
.31848 .38416 Mdot
.40952 .70636 Mdot
.3406 .35007 Mdot
.40099 .33818 Mdot
.68238 .42246 Mdot
.511 .71037 Mdot
.30377 .35966 Mdot
.59471 .68372 Mdot
.31304 .58702 Mdot
.32189 .61566 Mdot
.67853 .6578 Mdot
.33241 .38865 Mdot
.56574 .27329 Mdot
.29997 .6018 Mdot
.27615 .6156 Mdot
.70184 .50149 Mdot
.33554 .34711 Mdot
.72331 .51724 Mdot
.49316 .72303 Mdot
.55704 .6888 Mdot
.67454 .62218 Mdot
.70737 .41582 Mdot
.39177 .68987 Mdot
.34194 .3484 Mdot
.61942 .33485 Mdot
.4244 .7185 Mdot
.55839 .28627 Mdot
.4483 .29209 Mdot
.32272 .59177 Mdot
.53284 .27138 Mdot
.334 .49315 Mdot
.70107 .42265 Mdot
.3282 .55067 Mdot
.50881 .72404 Mdot
.28465 .61225 Mdot
.60625 .31107 Mdot
.61999 .32612 Mdot
.56454 .28498 Mdot
.30838 .57893 Mdot
.34099 .49019 Mdot
.57711 .68365 Mdot
.63274 .3629 Mdot
.68187 .60628 Mdot
.6709 .63704 Mdot
.65835 .34035 Mdot
.70066 .61718 Mdot
.31831 .38186 Mdot
.28118 .62092 Mdot
.70121 .42338 Mdot
.70839 .42819 Mdot
.62151 .33778 Mdot
.65466 .32624 Mdot
.63178 .33278 Mdot
.49006 .72593 Mdot
.68431 .59458 Mdot
.27819 .65088 Mdot
.3559 .51286 Mdot
.32633 .53939 Mdot
.59166 .67417 Mdot
.38 .68588 Mdot
.34455 .46528 Mdot
.33517 .38448 Mdot
.6244 .31534 Mdot
.72078 .49848 Mdot
.47502 .74389 Mdot
.69677 .52876 Mdot
.31372 .60887 Mdot
.71103 .44608 Mdot
.56569 .70242 Mdot
.3453 .35497 Mdot
.50632 .71757 Mdot
.35291 .36723 Mdot
.70111 .48333 Mdot
.57305 .69283 Mdot
.40345 .71045 Mdot
.30929 .60208 Mdot
.3937 .70071 Mdot
.40008 .29702 Mdot
.60266 .65385 Mdot
.70979 .53108 Mdot
.50848 .71109 Mdot
.44651 .29298 Mdot
.52171 .7013 Mdot
.31886 .57409 Mdot
.32171 .52074 Mdot
.31905 .55848 Mdot
.31431 .63213 Mdot
.60492 .6748 Mdot
.40125 .69632 Mdot
.43424 .29802 Mdot
.31095 .62659 Mdot
.73539 .50261 Mdot
.35864 .53203 Mdot
.32625 .53316 Mdot
.34693 .54722 Mdot
.3219 .51505 Mdot
.61788 .67694 Mdot
.48457 .70686 Mdot
.69659 .52602 Mdot
.28306 .60275 Mdot
.70878 .41013 Mdot
.62537 .33994 Mdot
.40636 .35364 Mdot
.60802 .66924 Mdot
.35247 .36857 Mdot
.72056 .4687 Mdot
.27607 .62066 Mdot
.61859 .28567 Mdot
.32115 .63203 Mdot
.41506 .35967 Mdot
.42936 .3462 Mdot
.34152 .34708 Mdot
.62076 .30041 Mdot
.71449 .50623 Mdot
.33845 .49764 Mdot
.67828 .60712 Mdot
.68809 .62339 Mdot
.31232 .62263 Mdot
.69189 .48925 Mdot
.70469 .41649 Mdot
.54617 .27405 Mdot
.33538 .54434 Mdot
.31528 .62939 Mdot
.69947 .60818 Mdot
.55226 .2641 Mdot
.38458 .70682 Mdot
.32194 .36745 Mdot
.36133 .5412 Mdot
.43058 .29683 Mdot
.40119 .69847 Mdot
.69615 .51897 Mdot
.41354 .3343 Mdot
.34955 .55314 Mdot
.2783 .64603 Mdot
.51848 .71807 Mdot
.29407 .34011 Mdot
.64379 .36968 Mdot
.30778 .60936 Mdot
.29993 .60818 Mdot
.58894 .68394 Mdot
.70462 .43292 Mdot
.6634 .62214 Mdot
.5876 .71325 Mdot
.44273 .32237 Mdot
.70605 .43742 Mdot
.32324 .54765 Mdot
.68784 .42968 Mdot
.49193 .72776 Mdot
.31546 .5797 Mdot
.70881 .53074 Mdot
.70085 .60338 Mdot
.64128 .63513 Mdot
.31758 .60408 Mdot
.4977 .71736 Mdot
.29408 .61414 Mdot
.54978 .26432 Mdot
.40432 .34957 Mdot
.31001 .60306 Mdot
.68586 .62999 Mdot
.29735 .61601 Mdot
.70183 .48518 Mdot
.3005 .35944 Mdot
.68094 .62423 Mdot
.53396 .27773 Mdot
.62831 .3072 Mdot
.64486 .36367 Mdot
.40175 .33846 Mdot
.47703 .72695 Mdot
.59159 .69238 Mdot
.65999 .61924 Mdot
.39117 .69622 Mdot
.62259 .31361 Mdot
.32936 .37396 Mdot
.3008 .63384 Mdot
.43234 .29551 Mdot
.68583 .40717 Mdot
.62229 .69462 Mdot
.40148 .72082 Mdot
.32638 .34174 Mdot
.34779 .67516 Mdot
.43579 .32117 Mdot
.33318 .53602 Mdot
.33839 .34763 Mdot
.65177 .32304 Mdot
.52023 .71379 Mdot
.45292 .34064 Mdot
.55265 .28406 Mdot
.6135 .29747 Mdot
.70732 .41259 Mdot
.63678 .36884 Mdot
.35453 .36675 Mdot
.44744 .31213 Mdot
.68527 .62126 Mdot
.33878 .5304 Mdot
.43473 .31418 Mdot
.63288 .32049 Mdot
.40452 .33717 Mdot
.32717 .52094 Mdot
.69882 .63895 Mdot
.62688 .34828 Mdot
.29932 .61185 Mdot
.49929 .73027 Mdot
.61591 .66553 Mdot
.5401 .27721 Mdot
.38985 .69117 Mdot
.35584 .38072 Mdot
.60814 .28966 Mdot
.60791 .30884 Mdot
.3148 .61744 Mdot
.34546 .37401 Mdot
.35134 .51742 Mdot
.7175 .51056 Mdot
.37057 .67698 Mdot
.70616 .43185 Mdot
.32476 .63094 Mdot
.31046 .63403 Mdot
.4033 .68979 Mdot
.54898 .69138 Mdot
.48526 .32384 Mdot
.32863 .62821 Mdot
.33365 .51213 Mdot
.66333 .64261 Mdot
.37354 .70124 Mdot
.32082 .6744 Mdot
.5962 .66821 Mdot
.3009 .34995 Mdot
.70163 .49827 Mdot
.29784 .6317 Mdot
.73133 .48448 Mdot
.33411 .37521 Mdot
.32698 .60997 Mdot
.40737 .72347 Mdot
.66612 .62302 Mdot
.33932 .55626 Mdot
.67789 .61813 Mdot
.30906 .58347 Mdot
.61841 .66842 Mdot
.71452 .42092 Mdot
.32031 .5547 Mdot
.44814 .31446 Mdot
.58882 .2859 Mdot
.31508 .52942 Mdot
.32485 .37985 Mdot
.51169 .72128 Mdot
.43957 .32507 Mdot
.72058 .51284 Mdot
.72056 .43246 Mdot
.63216 .3313 Mdot
.69614 .53372 Mdot
.60626 .68735 Mdot
.54593 .27722 Mdot
.40616 .32484 Mdot
.52399 .70929 Mdot
.34838 .39072 Mdot
.70548 .43873 Mdot
.33963 .51144 Mdot
.33189 .55079 Mdot
.55526 .27496 Mdot
.65675 .3813 Mdot
.68511 .64876 Mdot
.61815 .66132 Mdot
.57466 .69234 Mdot
.30998 .36452 Mdot
.5427 .27956 Mdot
.3371 .56277 Mdot
.34566 .53768 Mdot
.63551 .30102 Mdot
.59217 .6716 Mdot
.34131 .36888 Mdot
.41934 .3571 Mdot
.6943 .5144 Mdot
.56897 .28922 Mdot
.68215 .62318 Mdot
.55722 .29015 Mdot
.56288 .27247 Mdot
.61926 .64809 Mdot
.32996 .61895 Mdot
.71475 .51511 Mdot
.55066 .29002 Mdot
.66556 .60995 Mdot
.31424 .60659 Mdot
.42427 .33896 Mdot
.40195 .33687 Mdot
.58297 .66095 Mdot
.62155 .34361 Mdot
.34471 .37844 Mdot
.32029 .57221 Mdot
.33635 .34031 Mdot
.58559 .67511 Mdot
.64749 .35159 Mdot
.4173 .32955 Mdot
.71665 .48751 Mdot
.29671 .61744 Mdot
.33766 .37186 Mdot
.71331 .51574 Mdot
.43886 .30144 Mdot
.27944 .6178 Mdot
.37858 .67765 Mdot
.48667 .73211 Mdot
.70184 .50491 Mdot
.38799 .70177 Mdot
.36434 .5222 Mdot
.70092 .4222 Mdot
.2923 .35851 Mdot
.58551 .28567 Mdot
.37193 .67975 Mdot
.7171 .42589 Mdot
.63581 .30011 Mdot
.63518 .36982 Mdot
.53338 .25911 Mdot
.55731 .28468 Mdot
.70234 .41103 Mdot
.42508 .32321 Mdot
.56905 .28407 Mdot
.70487 .43244 Mdot
.40823 .69997 Mdot
.29859 .63176 Mdot
.41908 .72486 Mdot
.44166 .30102 Mdot
.42085 .30939 Mdot
.5912 .66562 Mdot
.49854 .70406 Mdot
.41938 .33084 Mdot
.34479 .50525 Mdot
.57496 .69702 Mdot
.71203 .53221 Mdot
.26533 .38255 Mdot
.69242 .50733 Mdot
.5213 .71334 Mdot
.60048 .29893 Mdot
.54355 .27521 Mdot
.33871 .52895 Mdot
.71641 .46045 Mdot
.26677 .39044 Mdot
.29704 .63098 Mdot
.50639 .71755 Mdot
.32203 .63679 Mdot
.31148 .62581 Mdot
.59898 .70058 Mdot
.42291 .30073 Mdot
.58119 .69683 Mdot
.71379 .52053 Mdot
.29945 .35894 Mdot
.455 .35467 Mdot
.70027 .50354 Mdot
.35674 .52842 Mdot
.40112 .34595 Mdot
.34036 .51984 Mdot
.33823 .50256 Mdot
.29676 .5843 Mdot
.33454 .33639 Mdot
.63042 .33988 Mdot
.35281 .37298 Mdot
.69183 .63147 Mdot
.62199 .6933 Mdot
.32735 .3798 Mdot
.42212 .71891 Mdot
.38375 .70998 Mdot
.6589 .38154 Mdot
.6876 .62418 Mdot
.31926 .38686 Mdot
.70557 .49342 Mdot
.33049 .67799 Mdot
.42211 .71055 Mdot
.70075 .53921 Mdot
.32856 .52177 Mdot
.65941 .6196 Mdot
.59069 .6679 Mdot
.70818 .44067 Mdot
.66171 .61545 Mdot
.38829 .70422 Mdot
.49176 .72231 Mdot
.69565 .51794 Mdot
.33301 .61366 Mdot
.70773 .43342 Mdot
.31395 .51761 Mdot
.50176 .7174 Mdot
.67906 .62511 Mdot
.31828 .51893 Mdot
.70414 .60179 Mdot
.42846 .30651 Mdot
.28936 .59317 Mdot
.32776 .37548 Mdot
.39248 .702 Mdot
.52771 .27414 Mdot
.56025 .70348 Mdot
.66883 .61172 Mdot
.69884 .48041 Mdot
.66672 .62951 Mdot
.56835 .67529 Mdot
.71067 .5503 Mdot
.61098 .68765 Mdot
.35515 .5239 Mdot
.62993 .67963 Mdot
.59471 .69228 Mdot
.70575 .52182 Mdot
.33085 .36406 Mdot
.59893 .67728 Mdot
.55842 .27077 Mdot
.3068 .61284 Mdot
.64412 .33634 Mdot
.33182 .39305 Mdot
.60773 .67025 Mdot
.32503 .37743 Mdot
.63501 .32711 Mdot
.41891 .36005 Mdot
.69178 .39993 Mdot
.69325 .43721 Mdot
.43524 .35113 Mdot
.71548 .43197 Mdot
.68607 .63807 Mdot
.54525 .28566 Mdot
.32369 .56724 Mdot
.33748 .5445 Mdot
.33431 .39459 Mdot
.68091 .64357 Mdot
.70712 .45669 Mdot
.42558 .33045 Mdot
.57683 .67468 Mdot
.71669 .49025 Mdot
.5424 .27149 Mdot
.37674 .7078 Mdot
.70939 .41439 Mdot
.43812 .2978 Mdot
.43834 .3213 Mdot
.33888 .51724 Mdot
.32437 .60821 Mdot
.32523 .34691 Mdot
.57898 .28532 Mdot
.48472 .70068 Mdot
.65561 .32681 Mdot
.35343 .54106 Mdot
.47904 .7044 Mdot
.35575 .50327 Mdot
.35483 .37344 Mdot
.70299 .40806 Mdot
.68829 .6181 Mdot
.30589 .37575 Mdot
.62909 .30708 Mdot
.36359 .6811 Mdot
.32105 .62125 Mdot
.38344 .69786 Mdot
.60624 .33077 Mdot
.67407 .64166 Mdot
.62467 .33144 Mdot
.70023 .4203 Mdot
.32258 .38348 Mdot
.4877 .72736 Mdot
.44258 .30083 Mdot
.63527 .3572 Mdot
.71676 .53578 Mdot
.5332 .27905 Mdot
.72055 .42946 Mdot
.44171 .32313 Mdot
.37344 .6907 Mdot
.61689 .35712 Mdot
.4263 .34121 Mdot
.58303 .66396 Mdot
.27239 .63615 Mdot
.56654 .66793 Mdot
.61469 .34114 Mdot
.27216 .3596 Mdot
.71105 .51931 Mdot
.71277 .40582 Mdot
.32047 .50336 Mdot
.27656 .40805 Mdot
.31839 .56699 Mdot
.69397 .44584 Mdot
.70196 .4253 Mdot
.70401 .50746 Mdot
.62634 .32932 Mdot
.70466 .61252 Mdot
.51643 .68925 Mdot
.61113 .3429 Mdot
.32828 .58557 Mdot
.68419 .58843 Mdot
.42517 .7065 Mdot
.62005 .35705 Mdot
.48422 .71132 Mdot
.61282 .65487 Mdot
.32311 .39 Mdot
.31979 .58785 Mdot
.70715 .41653 Mdot
.29389 .62321 Mdot
.73823 .49776 Mdot
.63021 .32525 Mdot
.41426 .34303 Mdot
.70413 .47224 Mdot
.32956 .54647 Mdot
.34877 .5423 Mdot
.36138 .52404 Mdot
.33779 .39213 Mdot
.59321 .66012 Mdot
.2945 .59656 Mdot
.27901 .62741 Mdot
.46986 .70677 Mdot
.52925 .26183 Mdot
.35353 .36459 Mdot
.28278 .65532 Mdot
.63628 .2964 Mdot
.58221 .66961 Mdot
.32288 .53749 Mdot
.70185 .40426 Mdot
.49448 .704 Mdot
.70112 .52665 Mdot
.72291 .50085 Mdot
.57143 .29125 Mdot
.68238 .63397 Mdot
.47002 .71379 Mdot
.65127 .36602 Mdot
.54637 .6953 Mdot
.4735 .70916 Mdot
.62104 .66525 Mdot
.69732 .48787 Mdot
.28711 .41969 Mdot
.70242 .40151 Mdot
.40177 .33435 Mdot
.60648 .68949 Mdot
.66744 .59153 Mdot
.39884 .69702 Mdot
.68001 .60069 Mdot
.55501 .27599 Mdot
.59007 .69398 Mdot
.50277 .28731 Mdot
.57145 .69482 Mdot
.70776 .51688 Mdot
.70847 .43608 Mdot
.47717 .71207 Mdot
.35225 .52453 Mdot
.40119 .71494 Mdot
.42524 .33112 Mdot
.37501 .69077 Mdot
.60768 .322 Mdot
.56222 .27434 Mdot
.68422 .42704 Mdot
.6006 .69839 Mdot
.70279 .54423 Mdot
.34956 .54231 Mdot
.50061 .71913 Mdot
.31659 .62947 Mdot
.71232 .42004 Mdot
.5281 .70119 Mdot
.35276 .511 Mdot
.47694 .71591 Mdot
.60373 .32919 Mdot
.65677 .32521 Mdot
.5745 .65962 Mdot
.57155 .29058 Mdot
.3336 .51565 Mdot
.31605 .3616 Mdot
.35115 .35204 Mdot
.32029 .61034 Mdot
.59705 .28882 Mdot
.38574 .70788 Mdot
.34064 .51055 Mdot
.36366 .67667 Mdot
.60543 .335 Mdot
.40684 .31189 Mdot
.6302 .31697 Mdot
.61922 .67551 Mdot
.42647 .34914 Mdot
.61103 .31202 Mdot
.3858 .71693 Mdot
.43766 .31605 Mdot
.5847 .28664 Mdot
.33627 .37637 Mdot
.35598 .50586 Mdot
.3491 .46926 Mdot
.62656 .36265 Mdot
.71037 .50894 Mdot
.6052 .67872 Mdot
.69897 .52836 Mdot
.64931 .31127 Mdot
.32797 .60662 Mdot
.43196 .30229 Mdot
.71959 .4169 Mdot
.46248 .71338 Mdot
.32101 .3582 Mdot
.7 .40012 Mdot
.47268 .72532 Mdot
.32164 .6163 Mdot
.26936 .39665 Mdot
.32822 .54061 Mdot
.56366 .27644 Mdot
.70448 .4382 Mdot
.31607 .33504 Mdot
.34115 .53235 Mdot
.64764 .33792 Mdot
.34162 .34195 Mdot
.34194 .51477 Mdot
.53337 .27501 Mdot
.29895 .60773 Mdot
.33717 .34762 Mdot
.58926 .68626 Mdot
.37043 .67573 Mdot
.33618 .40098 Mdot
.30537 .37462 Mdot
.31836 .56147 Mdot
.31429 .63394 Mdot
.57654 .2839 Mdot
.66606 .6244 Mdot
.30862 .60519 Mdot
.33756 .39473 Mdot
.57433 .70146 Mdot
.59839 .69244 Mdot
.52049 .71536 Mdot
.71294 .48072 Mdot
.62489 .34517 Mdot
.32875 .35142 Mdot
.55588 .26631 Mdot
.29783 .62889 Mdot
.51525 .71612 Mdot
.33179 .38323 Mdot
.71893 .52524 Mdot
.47869 .72528 Mdot
.69565 .47062 Mdot
.28235 .60486 Mdot
.70332 .39945 Mdot
.32239 .53905 Mdot
.31783 .52646 Mdot
.58463 .69271 Mdot
.73698 .50291 Mdot
.71788 .42115 Mdot
.63205 .31114 Mdot
.41785 .32855 Mdot
.62337 .69172 Mdot
.33659 .37092 Mdot
.50726 .68639 Mdot
.32838 .53372 Mdot
.33659 .56372 Mdot
.58715 .69296 Mdot
.32087 .6244 Mdot
.58227 .70528 Mdot
.55457 .2673 Mdot
.27756 .40978 Mdot
.68453 .61754 Mdot
.66819 .61905 Mdot
.4558 .72807 Mdot
.60461 .28477 Mdot
.56116 .69732 Mdot
.29673 .63144 Mdot
.65541 .32219 Mdot
.2955 .3395 Mdot
.33815 .36178 Mdot
.32085 .33478 Mdot
.55997 .69992 Mdot
.39971 .72553 Mdot
.49007 .72982 Mdot
.30855 .59669 Mdot
.34968 .67566 Mdot
.69947 .4214 Mdot
.28812 .60404 Mdot
.43093 .32749 Mdot
.63155 .32152 Mdot
.33511 .49476 Mdot
.34688 .50443 Mdot
.6889 .61573 Mdot
.29801 .36373 Mdot
.70891 .54708 Mdot
.42565 .34307 Mdot
.63006 .36558 Mdot
.31517 .373 Mdot
.70142 .61991 Mdot
.31633 .51916 Mdot
.45104 .32931 Mdot
.41596 .3034 Mdot
.33058 .51932 Mdot
.30784 .60844 Mdot
.45444 .30624 Mdot
.6997 .5172 Mdot
.63441 .31304 Mdot
.43223 .34318 Mdot
.3916 .70416 Mdot
.36694 .67719 Mdot
.34423 .54016 Mdot
.70035 .59682 Mdot
.7191 .53305 Mdot
.42623 .30506 Mdot
.54969 .28931 Mdot
.30147 .63433 Mdot
.4174 .70977 Mdot
.41927 .28687 Mdot
.4281 .32565 Mdot
.51662 .68897 Mdot
.35086 .36533 Mdot
.50181 .71673 Mdot
.27887 .61169 Mdot
.37785 .68373 Mdot
.32695 .54926 Mdot
.64894 .31784 Mdot
.71448 .49194 Mdot
.44401 .34693 Mdot
.62387 .31609 Mdot
.59823 .69217 Mdot
.30968 .59738 Mdot
.67051 .63876 Mdot
.66062 .62228 Mdot
.57035 .67114 Mdot
.69832 .49876 Mdot
.60929 .70749 Mdot
.45395 .30819 Mdot
.33236 .54281 Mdot
.69831 .42962 Mdot
.55909 .69577 Mdot
.38914 .68417 Mdot
.56683 .70308 Mdot
.69122 .63691 Mdot
.37888 .68034 Mdot
.48292 .71882 Mdot
.27753 .62704 Mdot
.32323 .51622 Mdot
.34929 .37459 Mdot
.67207 .59193 Mdot
.418 .7068 Mdot
.31858 .57525 Mdot
.33684 .5326 Mdot
.47816 .71008 Mdot
.33273 .33704 Mdot
.32019 .63096 Mdot
.33002 .53647 Mdot
.28239 .65626 Mdot
.38991 .68536 Mdot
.66764 .64475 Mdot
.68783 .40039 Mdot
.52106 .71568 Mdot
.61358 .2911 Mdot
.58332 .68124 Mdot
.3173 .38839 Mdot
.5736 .71009 Mdot
.4779 .7324 Mdot
.70968 .49787 Mdot
.66704 .60977 Mdot
.63207 .35066 Mdot
.71294 .50954 Mdot
.70779 .43323 Mdot
.48266 .70818 Mdot
.64004 .31376 Mdot
.29744 .35411 Mdot
.70808 .41126 Mdot
.52547 .70234 Mdot
.70778 .51544 Mdot
.61073 .64981 Mdot
.37373 .69284 Mdot
.27884 .61457 Mdot
.42373 .3185 Mdot
.45094 .34049 Mdot
.70113 .41803 Mdot
.32374 .3665 Mdot
.47641 .72409 Mdot
.60069 .67884 Mdot
.32313 .36055 Mdot
.60682 .6566 Mdot
.53995 .27099 Mdot
.58404 .67174 Mdot
.55345 .2724 Mdot
.68361 .59972 Mdot
.32087 .5888 Mdot
.30225 .37231 Mdot
.45312 .3004 Mdot
.41024 .71092 Mdot
.41521 .32806 Mdot
.32905 .50437 Mdot
.47178 .71869 Mdot
.35605 .52396 Mdot
.61761 .2838 Mdot
.33065 .39625 Mdot
.58811 .69617 Mdot
.43498 .36243 Mdot
.71098 .53617 Mdot
.38579 .69796 Mdot
.41705 .34482 Mdot
.49838 .71797 Mdot
.57747 .70415 Mdot
.69356 .61137 Mdot
.61962 .67081 Mdot
.60988 .28858 Mdot
.48208 .32834 Mdot
.35011 .53795 Mdot
.43051 .36193 Mdot
.70414 .42541 Mdot
.71357 .43928 Mdot
.64003 .34545 Mdot
.29818 .42751 Mdot
.62103 .31547 Mdot
.2894 .34303 Mdot
.68678 .60063 Mdot
.31091 .34845 Mdot
.35329 .53023 Mdot
.5989 .67147 Mdot
.51423 .68875 Mdot
.29591 .36505 Mdot
.35254 .36532 Mdot
.71313 .43684 Mdot
.69931 .43507 Mdot
.40759 .33449 Mdot
.3911 .68631 Mdot
.39618 .6868 Mdot
.33259 .55655 Mdot
.69875 .41519 Mdot
.49171 .71777 Mdot
.69163 .39837 Mdot
.50881 .71408 Mdot
.33252 .39716 Mdot
.60945 .30469 Mdot
.67518 .38462 Mdot
.58785 .67739 Mdot
.309 .59612 Mdot
.56686 .67187 Mdot
.27454 .63675 Mdot
.72102 .42459 Mdot
.2928 .36457 Mdot
.62929 .33547 Mdot
.71909 .47209 Mdot
.61255 .30363 Mdot
.37186 .36037 Mdot
.40973 .7277 Mdot
.69989 .47913 Mdot
.37903 .69589 Mdot
.6572 .34442 Mdot
.32571 .50779 Mdot
.44186 .33577 Mdot
.40126 .346 Mdot
.45903 .72303 Mdot
.61526 .66255 Mdot
.35006 .37621 Mdot
.35343 .5308 Mdot
.62063 .65234 Mdot
.35152 .53268 Mdot
.35076 .53434 Mdot
.33965 .50075 Mdot
.71028 .42151 Mdot
.37763 .69867 Mdot
.35343 .52398 Mdot
.56463 .28598 Mdot
.30474 .33526 Mdot
.61978 .36178 Mdot
.58323 .69256 Mdot
.32711 .35753 Mdot
.58077 .6804 Mdot
.39796 .71132 Mdot
.69291 .49718 Mdot
.5965 .65871 Mdot
.48998 .71261 Mdot
.56204 .70378 Mdot
.71484 .40899 Mdot
.34215 .3802 Mdot
.43492 .32514 Mdot
.72381 .55219 Mdot
.55725 .2826 Mdot
.41918 .33731 Mdot
.53683 .27424 Mdot
.3238 .5377 Mdot
.68489 .62391 Mdot
.41675 .33048 Mdot
.72236 .52828 Mdot
.65921 .34094 Mdot
.2772 .6111 Mdot
.30085 .61962 Mdot
.60665 .32886 Mdot
.42862 .31815 Mdot
.39309 .70314 Mdot
.37858 .7075 Mdot
.65712 .34645 Mdot
.71461 .55114 Mdot
.70558 .42376 Mdot
.33262 .3621 Mdot
.67904 .64308 Mdot
.69124 .61307 Mdot
.7139 .53245 Mdot
.7193 .46417 Mdot
.30517 .62075 Mdot
.29899 .61361 Mdot
.40425 .70576 Mdot
.3213 .51719 Mdot
.54474 .28779 Mdot
.4228 .33658 Mdot
.67544 .60851 Mdot
.47096 .71666 Mdot
.50391 .70202 Mdot
.35643 .53133 Mdot
.32875 .60368 Mdot
.62059 .34795 Mdot
.50308 .72022 Mdot
.33521 .34712 Mdot
.61547 .70075 Mdot
.30015 .60639 Mdot
.33244 .39784 Mdot
.68876 .60738 Mdot
.58142 .28664 Mdot
.70926 .50886 Mdot
.65384 .36008 Mdot
.6527 .36359 Mdot
.39729 .29914 Mdot
.58567 .68085 Mdot
.41938 .33703 Mdot
.52806 .27962 Mdot
.40076 .34275 Mdot
.35062 .3596 Mdot
.32045 .60304 Mdot
.5569 .27783 Mdot
.62351 .36607 Mdot
.70309 .4763 Mdot
.29234 .59249 Mdot
.36428 .53421 Mdot
.71787 .42601 Mdot
.3348 .5212 Mdot
.32908 .38153 Mdot
.69267 .42478 Mdot
.66603 .61195 Mdot
.34707 .37573 Mdot
.69704 .4055 Mdot
.69356 .61572 Mdot
.48282 .7094 Mdot
.39174 .68534 Mdot
.60283 .68378 Mdot
.70112 .61406 Mdot
.30638 .62211 Mdot
.56709 .29174 Mdot
.6822 .61248 Mdot
.60963 .68113 Mdot
.62152 .67036 Mdot
.64746 .35735 Mdot
.3447 .34559 Mdot
.70425 .48079 Mdot
.35322 .5179 Mdot
.60592 .30218 Mdot
.31537 .35348 Mdot
.67079 .60524 Mdot
.36246 .50962 Mdot
.29713 .6276 Mdot
.3198 .35926 Mdot
.35496 .36301 Mdot
.32435 .3638 Mdot
.71057 .43416 Mdot
.4867 .71151 Mdot
.5857 .70265 Mdot
.71722 .41553 Mdot
.32359 .3891 Mdot
.34556 .39639 Mdot
.49264 .30985 Mdot
.30357 .61739 Mdot
.35412 .37674 Mdot
.61909 .69807 Mdot
.37863 .71532 Mdot
.40091 .3432 Mdot
.27407 .35562 Mdot
.60494 .28174 Mdot
.28246 .34696 Mdot
.71253 .49155 Mdot
.50609 .70972 Mdot
.34011 .36351 Mdot
.44233 .31357 Mdot
.30247 .6202 Mdot
.31036 .63113 Mdot
.3164 .36427 Mdot
.32744 .62494 Mdot
.69145 .62181 Mdot
.56141 .67291 Mdot
.32451 .35715 Mdot
.65358 .33725 Mdot
.60881 .34167 Mdot
.61804 .32435 Mdot
.33756 .53827 Mdot
.42176 .70048 Mdot
.3384 .6774 Mdot
.62031 .67302 Mdot
.7026 .43391 Mdot
.68832 .60431 Mdot
.63648 .65689 Mdot
.5947 .69514 Mdot
.6594 .33618 Mdot
.32399 .36685 Mdot
.70157 .59792 Mdot
.70919 .43706 Mdot
.70222 .41686 Mdot
.62433 .36316 Mdot
.6226 .31234 Mdot
.61921 .33678 Mdot
.60543 .66916 Mdot
.66417 .65579 Mdot
.37489 .68587 Mdot
.6612 .62055 Mdot
.63806 .2961 Mdot
.55375 .26731 Mdot
.62311 .36146 Mdot
.70637 .52555 Mdot
.69513 .59579 Mdot
.30066 .60978 Mdot
.35292 .47368 Mdot
.60763 .34009 Mdot
.33162 .38882 Mdot
.62751 .68677 Mdot
.27559 .40659 Mdot
.51386 .71039 Mdot
.72201 .51515 Mdot
.43745 .30869 Mdot
.36162 .52763 Mdot
.63367 .31436 Mdot
.27618 .35435 Mdot
.41956 .30351 Mdot
.38588 .69334 Mdot
.58359 .71629 Mdot
.71566 .50314 Mdot
.3739 .70262 Mdot
.44524 .32872 Mdot
.46714 .71545 Mdot
.69317 .42308 Mdot
.63345 .35857 Mdot
.53088 .25993 Mdot
.59368 .66499 Mdot
.31329 .59539 Mdot
.43918 .30414 Mdot
.31722 .57162 Mdot
.61139 .31563 Mdot
.34685 .37373 Mdot
.61076 .3239 Mdot
.6695 .64556 Mdot
.64033 .36362 Mdot
.36358 .52133 Mdot
.57898 .70264 Mdot
.70349 .42199 Mdot
.33275 .67635 Mdot
.44395 .36017 Mdot
.64502 .3498 Mdot
.45452 .30271 Mdot
.49586 .70287 Mdot
.52496 .70992 Mdot
.44322 .34816 Mdot
.36413 .51921 Mdot
.70793 .53108 Mdot
.58781 .70376 Mdot
.71322 .53649 Mdot
.34478 .34431 Mdot
.72721 .55104 Mdot
.70904 .50749 Mdot
.43016 .7101 Mdot
.34463 .37974 Mdot
.32848 .60858 Mdot
.35067 .5068 Mdot
.7238 .51208 Mdot
.38373 .7011 Mdot
.62088 .65236 Mdot
.38574 .71632 Mdot
.28047 .61662 Mdot
.7108 .53259 Mdot
.40552 .32522 Mdot
.37679 .70416 Mdot
.34128 .34101 Mdot
.70297 .41128 Mdot
.36591 .6752 Mdot
.42444 .33792 Mdot
.31518 .37695 Mdot
.34449 .38605 Mdot
.31904 .37392 Mdot
.36081 .51909 Mdot
.31752 .54192 Mdot
.30604 .3771 Mdot
.71065 .55052 Mdot
.30913 .37815 Mdot
.2867 .36171 Mdot
.70383 .45733 Mdot
.35455 .36599 Mdot
.33909 .51079 Mdot
.50878 .71307 Mdot
.50454 .7086 Mdot
.64187 .33394 Mdot
.73711 .53489 Mdot
.56647 .2819 Mdot
.34091 .55933 Mdot
.68867 .65665 Mdot
.59123 .69166 Mdot
.45896 .31834 Mdot
.28077 .62259 Mdot
.47778 .73063 Mdot
.60306 .68916 Mdot
.40097 .70288 Mdot
.58083 .67351 Mdot
.44613 .33163 Mdot
.36318 .52757 Mdot
.58493 .68729 Mdot
.55864 .68731 Mdot
.33013 .62169 Mdot
.57715 .67487 Mdot
.68095 .59731 Mdot
.70469 .43441 Mdot
.70889 .4904 Mdot
.70879 .53181 Mdot
.62433 .30859 Mdot
.66789 .61642 Mdot
.30675 .59901 Mdot
.63065 .31128 Mdot
.32821 .52419 Mdot
.71204 .53273 Mdot
.31744 .56596 Mdot
.66763 .61907 Mdot
.34383 .50845 Mdot
.42792 .71326 Mdot
.53424 .27292 Mdot
.31915 .36027 Mdot
.61721 .66005 Mdot
.54424 .26051 Mdot
.70787 .41245 Mdot
.6543 .63339 Mdot
.29023 .36349 Mdot
.46555 .7139 Mdot
.36337 .53912 Mdot
.34291 .49707 Mdot
.466 .71371 Mdot
.40432 .72739 Mdot
.41276 .30882 Mdot
.62869 .30702 Mdot
.64908 .36294 Mdot
.30922 .61781 Mdot
.67145 .61649 Mdot
.3377 .34511 Mdot
.33414 .40013 Mdot
.45958 .33296 Mdot
.38698 .7118 Mdot
.27907 .6269 Mdot
.30533 .57773 Mdot
.30989 .5957 Mdot
.63789 .34064 Mdot
.40562 .31471 Mdot
.39758 .69742 Mdot
.32158 .38097 Mdot
.30336 .59891 Mdot
.58229 .6908 Mdot
.67266 .59969 Mdot
.61807 .34345 Mdot
.68438 .40744 Mdot
.43829 .34502 Mdot
.61616 .35596 Mdot
.30872 .61676 Mdot
.48464 .70121 Mdot
.69113 .42965 Mdot
.69595 .6362 Mdot
.31071 .37027 Mdot
.63296 .31638 Mdot
.30238 .35737 Mdot
.66574 .62828 Mdot
.67135 .60486 Mdot
.31802 .62308 Mdot
.4722 .33926 Mdot
.63735 .35935 Mdot
.34544 .53924 Mdot
.60642 .32679 Mdot
.55059 .27242 Mdot
.69338 .39935 Mdot
.30928 .60508 Mdot
.51977 .68909 Mdot
.70317 .53192 Mdot
.34928 .54743 Mdot
.49513 .7059 Mdot
.48128 .72587 Mdot
.6552 .33689 Mdot
.31105 .38583 Mdot
.31226 .37722 Mdot
.65463 .64197 Mdot
.71219 .58876 Mdot
.29307 .5894 Mdot
.64714 .35475 Mdot
.52395 .69993 Mdot
.707 .50272 Mdot
.6881 .59903 Mdot
.68135 .50218 Mdot
.7053 .51965 Mdot
.3029 .6144 Mdot
.32799 .37947 Mdot
.69915 .62007 Mdot
.40036 .34328 Mdot
.29968 .67418 Mdot
.44983 .29596 Mdot
.48151 .32958 Mdot
.42903 .34022 Mdot
.69141 .48638 Mdot
.61494 .33554 Mdot
.56766 .70215 Mdot
.72206 .52521 Mdot
.70815 .49967 Mdot
.56692 .27443 Mdot
.61561 .66682 Mdot
.59379 .65162 Mdot
.60489 .71042 Mdot
.55677 .282 Mdot
.32635 .37063 Mdot
.3931 .7199 Mdot
.61901 .32362 Mdot
.51977 .26513 Mdot
.70895 .44443 Mdot
.7141 .43802 Mdot
.69395 .64586 Mdot
.29188 .61717 Mdot
.62114 .67076 Mdot
.32626 .52148 Mdot
.31985 .60156 Mdot
.71791 .52443 Mdot
.68718 .59914 Mdot
.6951 .44459 Mdot
.3126 .61575 Mdot
.30463 .5879 Mdot
.65706 .32241 Mdot
.42815 .3316 Mdot
.66084 .38236 Mdot
.31355 .6054 Mdot
.61765 .30931 Mdot
.59305 .655 Mdot
.44607 .31327 Mdot
.41921 .71036 Mdot
.69782 .44022 Mdot
.42994 .30291 Mdot
.44802 .32092 Mdot
.37006 .50691 Mdot
.58194 .67457 Mdot
.65841 .63278 Mdot
.34818 .35005 Mdot
.68437 .42383 Mdot
.69214 .40531 Mdot
.69579 .47226 Mdot
.304 .61382 Mdot
.70189 .44616 Mdot
.40862 .35644 Mdot
.34744 .54915 Mdot
.47305 .71251 Mdot
.60074 .66017 Mdot
.31003 .57605 Mdot
.49386 .73164 Mdot
.70959 .52075 Mdot
.42324 .28513 Mdot
.29321 .58974 Mdot
.61218 .33848 Mdot
.70565 .62172 Mdot
.59521 .66765 Mdot
.34393 .36029 Mdot
.71493 .42062 Mdot
.28701 .41815 Mdot
.68899 .59876 Mdot
.29604 .6084 Mdot
.70503 .5062 Mdot
.43813 .30688 Mdot
.41984 .32061 Mdot
.45778 .3031 Mdot
.68242 .59138 Mdot
.44117 .3112 Mdot
.5653 .67524 Mdot
.4008 .70626 Mdot
.32014 .60553 Mdot
.69787 .50382 Mdot
.32714 .37246 Mdot
.42133 .36136 Mdot
.54443 .26892 Mdot
.39512 .68918 Mdot
.32333 .61209 Mdot
.73117 .54997 Mdot
.33049 .37584 Mdot
.35867 .52561 Mdot
.41308 .3076 Mdot
.42973 .70617 Mdot
.26665 .37838 Mdot
.41865 .34119 Mdot
.51063 .70273 Mdot
.69076 .63331 Mdot
.41454 .33091 Mdot
.6698 .60146 Mdot
.35838 .52864 Mdot
.38746 .69734 Mdot
.66156 .63894 Mdot
.65466 .60368 Mdot
.4492 .33362 Mdot
.69841 .4033 Mdot
.38577 .70417 Mdot
.33649 .50971 Mdot
.4236 .70367 Mdot
.42932 .30847 Mdot
.71917 .55217 Mdot
.60442 .30957 Mdot
.57409 .2894 Mdot
.52925 .28175 Mdot
.72029 .42987 Mdot
.68109 .41446 Mdot
.30878 .63673 Mdot
.47471 .692 Mdot
.42204 .7014 Mdot
.69283 .51772 Mdot
.38559 .72203 Mdot
.35233 .52438 Mdot
.33019 .52564 Mdot
.60621 .32672 Mdot
.69965 .48273 Mdot
.5208 .71494 Mdot
.39505 .698 Mdot
.32604 .39244 Mdot
.66262 .61601 Mdot
.34793 .51622 Mdot
.72837 .5524 Mdot
.65534 .34128 Mdot
.73749 .54012 Mdot
.33842 .51261 Mdot
.42878 .33138 Mdot
.68923 .43144 Mdot
.70559 .42688 Mdot
.65016 .32736 Mdot
.64996 .33031 Mdot
.33556 .51121 Mdot
.70387 .54094 Mdot
.38763 .7223 Mdot
.38109 .70822 Mdot
.43193 .31614 Mdot
.33353 .34994 Mdot
.33072 .50256 Mdot
.57725 .6582 Mdot
.462 .35009 Mdot
.34235 .54 Mdot
.6662 .63526 Mdot
.62312 .33823 Mdot
.53891 .26975 Mdot
.68527 .60876 Mdot
.54129 .27453 Mdot
.73563 .54142 Mdot
.31622 .55952 Mdot
.3451 .3522 Mdot
.45601 .73242 Mdot
.30269 .36995 Mdot
.42855 .3045 Mdot
.3021 .61532 Mdot
.58005 .29004 Mdot
.52382 .27676 Mdot
.47261 .7432 Mdot
.71654 .5122 Mdot
.40148 .33637 Mdot
.48968 .71603 Mdot
.32739 .39537 Mdot
.62977 .32207 Mdot
.41283 .35157 Mdot
.30655 .60251 Mdot
.58467 .6785 Mdot
.51604 .7191 Mdot
.41621 .34759 Mdot
.42268 .30918 Mdot
.42822 .34962 Mdot
.69734 .40532 Mdot
.61371 .68154 Mdot
.71084 .44232 Mdot
.53419 .26728 Mdot
.37398 .68731 Mdot
.30262 .59123 Mdot
.68634 .60304 Mdot
.33891 .55019 Mdot
.69944 .5322 Mdot
.63478 .66652 Mdot
.32682 .36527 Mdot
.44949 .3255 Mdot
.72553 .47771 Mdot
.39974 .34402 Mdot
.4703 .70829 Mdot
.5004 .6984 Mdot
.58207 .69375 Mdot
.70226 .47201 Mdot
.33313 .4929 Mdot
.64252 .37169 Mdot
.31026 .37184 Mdot
.70799 .43631 Mdot
.47246 .70801 Mdot
.35043 .50545 Mdot
.32847 .37433 Mdot
.71436 .43508 Mdot
.45681 .33803 Mdot
.7068 .54476 Mdot
.44867 .29425 Mdot
.49834 .74219 Mdot
.33999 .51577 Mdot
.42941 .33365 Mdot
.59851 .68857 Mdot
.70147 .43048 Mdot
.60595 .66364 Mdot
.44625 .33085 Mdot
.54834 .26943 Mdot
.7062 .43691 Mdot
.30347 .59481 Mdot
.57479 .7099 Mdot
.66686 .65636 Mdot
.61042 .6869 Mdot
.49976 .29443 Mdot
.56039 .27577 Mdot
.61847 .33934 Mdot
.70504 .52414 Mdot
.60679 .29833 Mdot
.34434 .3811 Mdot
.3964 .72038 Mdot
.64872 .33728 Mdot
.61399 .67846 Mdot
.61686 .30016 Mdot
.41358 .71975 Mdot
.70596 .40312 Mdot
.61245 .35078 Mdot
.33297 .54737 Mdot
.4914 .7075 Mdot
.41817 .313 Mdot
.32687 .33595 Mdot
.39853 .70565 Mdot
.2901 .60391 Mdot
.43772 .32725 Mdot
.3415 .51074 Mdot
.70144 .53535 Mdot
.33444 .67314 Mdot
.37906 .68225 Mdot
.54561 .27259 Mdot
.65771 .60011 Mdot
.65079 .36073 Mdot
.34945 .39451 Mdot
.34297 .54548 Mdot
.34461 .51008 Mdot
.48716 .72361 Mdot
.63143 .67769 Mdot
.70976 .42368 Mdot
.37258 .6846 Mdot
.55041 .28178 Mdot
.57658 .69992 Mdot
.57801 .69706 Mdot
.31167 .58915 Mdot
.42707 .33579 Mdot
.71727 .4913 Mdot
.36237 .52079 Mdot
.40222 .34268 Mdot
.28178 .61639 Mdot
.71846 .43825 Mdot
.56249 .27705 Mdot
.52488 .2696 Mdot
.56849 .69488 Mdot
.6073 .33602 Mdot
.48934 .72352 Mdot
.43881 .31019 Mdot
.52905 .28219 Mdot
.71073 .4207 Mdot
.30874 .3706 Mdot
.33068 .5324 Mdot
.32941 .61958 Mdot
.60646 .33502 Mdot
.637 .31207 Mdot
.39007 .72307 Mdot
.73388 .54752 Mdot
.48739 .3169 Mdot
.69632 .42292 Mdot
.58083 .69149 Mdot
.32032 .50052 Mdot
.33428 .45647 Mdot
.70384 .4964 Mdot
.47537 .70646 Mdot
.6121 .34471 Mdot
.41507 .28713 Mdot
.59944 .69267 Mdot
.30893 .36958 Mdot
.33636 .55338 Mdot
.58477 .69695 Mdot
.55001 .28695 Mdot
.59848 .70043 Mdot
.42033 .33069 Mdot
.71057 .40529 Mdot
.63438 .32888 Mdot
.70066 .48105 Mdot
.52017 .68978 Mdot
.32631 .36844 Mdot
.31625 .58622 Mdot
.50994 .71633 Mdot
.59964 .6579 Mdot
.48323 .7136 Mdot
.43422 .35122 Mdot
.48455 .70983 Mdot
.57665 .69235 Mdot
.34899 .50662 Mdot
.32613 .55405 Mdot
.5449 .26365 Mdot
.33158 .51797 Mdot
.3012 .6327 Mdot
.42829 .71325 Mdot
.33734 .54145 Mdot
.35076 .53497 Mdot
.31032 .60843 Mdot
.67657 .63914 Mdot
.28357 .60886 Mdot
.69779 .63982 Mdot
.67736 .64954 Mdot
.53391 .26876 Mdot
.32987 .39647 Mdot
.35246 .35713 Mdot
.28395 .60452 Mdot
.32947 .61284 Mdot
.61454 .66443 Mdot
.69867 .59677 Mdot
.7032 .42346 Mdot
.38102 .68551 Mdot
.48792 .31993 Mdot
.32147 .56357 Mdot
.64252 .33554 Mdot
.6537 .34153 Mdot
.32418 .52712 Mdot
.27315 .40367 Mdot
.31614 .63456 Mdot
.40826 .71556 Mdot
.35721 .51388 Mdot
.31657 .61266 Mdot
.64717 .36133 Mdot
.32154 .5908 Mdot
.48893 .73031 Mdot
.57165 .69088 Mdot
.30578 .36255 Mdot
.41792 .33418 Mdot
.38756 .69746 Mdot
.31391 .53029 Mdot
.58878 .66654 Mdot
.4843 .72411 Mdot
.63729 .32383 Mdot
.6734 .60589 Mdot
.40949 .71191 Mdot
.70616 .40838 Mdot
.29416 .67215 Mdot
.72518 .55268 Mdot
.69787 .41092 Mdot
.31407 .37584 Mdot
.63272 .3538 Mdot
.35695 .54329 Mdot
.62233 .30188 Mdot
.30998 .61234 Mdot
.37689 .70854 Mdot
.34357 .35207 Mdot
.60585 .67389 Mdot
.69742 .43902 Mdot
.68527 .63355 Mdot
.60423 .64949 Mdot
.34997 .67297 Mdot
.64731 .379 Mdot
.63767 .36302 Mdot
.43885 .35957 Mdot
.57337 .66966 Mdot
.30309 .63403 Mdot
.60167 .71098 Mdot
.68263 .62551 Mdot
.59016 .67285 Mdot
.30694 .67115 Mdot
.28086 .65883 Mdot
.30674 .60662 Mdot
.59497 .68997 Mdot
.63022 .35458 Mdot
.34808 .35408 Mdot
.3091 .62522 Mdot
.43779 .30948 Mdot
.56814 .69529 Mdot
.61379 .34341 Mdot
.31881 .58646 Mdot
.62023 .30994 Mdot
.58967 .69934 Mdot
.6546 .35194 Mdot
.69246 .39881 Mdot
.64811 .33928 Mdot
.33551 .49717 Mdot
.35389 .5094 Mdot
.57617 .6945 Mdot
.6712 .60525 Mdot
.46956 .70993 Mdot
.33435 .54424 Mdot
.56197 .69822 Mdot
.61941 .29156 Mdot
.7056 .60171 Mdot
.47615 .72442 Mdot
.30041 .6297 Mdot
.3063 .37621 Mdot
.3698 .68495 Mdot
.32391 .67364 Mdot
.37729 .68132 Mdot
.32312 .36974 Mdot
.48209 .6898 Mdot
.31966 .57691 Mdot
.32418 .63085 Mdot
.55145 .28387 Mdot
.33096 .54999 Mdot
.44627 .30996 Mdot
.47044 .7257 Mdot
.28329 .6657 Mdot
.47174 .71068 Mdot
.60727 .68568 Mdot
.58531 .70115 Mdot
.6354 .29959 Mdot
.59596 .69335 Mdot
.44156 .30816 Mdot
.7181 .49316 Mdot
.60696 .6499 Mdot
.40481 .31639 Mdot
.42619 .30145 Mdot
.454 .30834 Mdot
.42029 .34375 Mdot
.48598 .3202 Mdot
.56246 .27071 Mdot
.42162 .30561 Mdot
.56786 .67662 Mdot
.59791 .28691 Mdot
.29137 .36162 Mdot
.71771 .49167 Mdot
.44774 .31753 Mdot
.33109 .55108 Mdot
.47811 .72202 Mdot
.65422 .62778 Mdot
.72073 .42475 Mdot
.43614 .34843 Mdot
.30439 .63183 Mdot
.56588 .69143 Mdot
.34881 .51813 Mdot
.31786 .39025 Mdot
.6673 .62047 Mdot
.62941 .31393 Mdot
.34183 .35226 Mdot
.43645 .33965 Mdot
.32471 .35884 Mdot
.60844 .31989 Mdot
.70604 .548 Mdot
.33435 .5566 Mdot
.4133 .36035 Mdot
.33674 .3926 Mdot
.33262 .5539 Mdot
.56894 .67657 Mdot
.43958 .34563 Mdot
.29338 .62304 Mdot
.4892 .71913 Mdot
.69401 .61925 Mdot
.73608 .49414 Mdot
.35299 .54884 Mdot
.49778 .69866 Mdot
.56977 .6923 Mdot
.40587 .34425 Mdot
.62784 .31036 Mdot
.36049 .50703 Mdot
.71986 .51634 Mdot
.71269 .53387 Mdot
.55265 .28655 Mdot
.65864 .61719 Mdot
.60065 .29902 Mdot
.33339 .49562 Mdot
.44718 .32259 Mdot
.36026 .50861 Mdot
.64136 .29927 Mdot
.73739 .52541 Mdot
.69933 .61341 Mdot
.5305 .26845 Mdot
.27313 .63975 Mdot
.71224 .48066 Mdot
.54393 .27305 Mdot
.57252 .69186 Mdot
.6627 .62657 Mdot
.68303 .60763 Mdot
.33193 .34681 Mdot
.62275 .31413 Mdot
.66391 .64289 Mdot
.68756 .63853 Mdot
.47967 .72503 Mdot
.32416 .52892 Mdot
.5842 .68893 Mdot
.55974 .28239 Mdot
.30755 .37148 Mdot
.54491 .28108 Mdot
.45807 .35298 Mdot
.69921 .43199 Mdot
.4179 .71906 Mdot
.39642 .68909 Mdot
.29591 .42677 Mdot
.30468 .59449 Mdot
.36124 .52112 Mdot
.61392 .67024 Mdot
.32781 .33455 Mdot
.31226 .34481 Mdot
.56757 .67841 Mdot
.70037 .61853 Mdot
.33377 .35365 Mdot
.31881 .55038 Mdot
.3315 .62433 Mdot
.27302 .6415 Mdot
.61472 .68397 Mdot
.5618 .67554 Mdot
.71507 .52173 Mdot
.56914 .69628 Mdot
.5924 .28382 Mdot
.62179 .35884 Mdot
.64466 .35162 Mdot
.70502 .43113 Mdot
.35031 .55321 Mdot
.64078 .36474 Mdot
.50384 .71621 Mdot
.58689 .28325 Mdot
.49383 .70369 Mdot
.53716 .28853 Mdot
.33582 .54662 Mdot
.71703 .45953 Mdot
.69338 .4829 Mdot
.47045 .72101 Mdot
.31712 .54768 Mdot
.31331 .36777 Mdot
.61447 .66981 Mdot
.6952 .52216 Mdot
.61951 .66875 Mdot
.34148 .51318 Mdot
.59396 .68064 Mdot
.69482 .43336 Mdot
.71899 .55323 Mdot
.48151 .73094 Mdot
.49982 .7168 Mdot
.62201 .66335 Mdot
.55792 .69865 Mdot
.62606 .30938 Mdot
.58706 .67257 Mdot
.67416 .6456 Mdot
.48904 .7065 Mdot
.61126 .34582 Mdot
.36113 .67572 Mdot
.60864 .67571 Mdot
.34052 .34467 Mdot
.6662 .6255 Mdot
.33063 .35254 Mdot
.65877 .63807 Mdot
.54611 .26267 Mdot
.353 .53839 Mdot
.53456 .26998 Mdot
.33186 .38776 Mdot
.64747 .37055 Mdot
.69492 .52813 Mdot
.44274 .3227 Mdot
.70475 .5331 Mdot
.40066 .71789 Mdot
.61974 .67143 Mdot
.71247 .4907 Mdot
.35402 .67515 Mdot
.35538 .50689 Mdot
.65812 .63731 Mdot
.63474 .32192 Mdot
.53963 .28299 Mdot
.39664 .71025 Mdot
.68687 .59529 Mdot
.62854 .29747 Mdot
.52258 .70082 Mdot
.58119 .28781 Mdot
.4685 .72223 Mdot
.68376 .48793 Mdot
.59356 .70113 Mdot
.54058 .28466 Mdot
.40692 .71795 Mdot
.68799 .64264 Mdot
.62845 .36047 Mdot
.70789 .54511 Mdot
.71942 .51457 Mdot
.3487 .49821 Mdot
.70395 .47629 Mdot
.64172 .33199 Mdot
.73672 .54287 Mdot
.6657 .64267 Mdot
.73799 .52705 Mdot
.32298 .3661 Mdot
.62663 .34923 Mdot
.43219 .31463 Mdot
.51879 .69087 Mdot
.60969 .30114 Mdot
.28137 .4136 Mdot
.50903 .2756 Mdot
.61397 .2869 Mdot
.66599 .61922 Mdot
.68326 .59208 Mdot
.51609 .71147 Mdot
.39659 .70741 Mdot
.63059 .32426 Mdot
.59599 .2851 Mdot
.27811 .62835 Mdot
.44212 .32726 Mdot
.5567 .28884 Mdot
.30567 .59767 Mdot
.48566 .71566 Mdot
.69917 .42234 Mdot
.30342 .58902 Mdot
.70117 .63085 Mdot
.31945 .61234 Mdot
.69852 .52813 Mdot
.65996 .3356 Mdot
.34154 .51194 Mdot
.31203 .37356 Mdot
.71906 .53349 Mdot
.71632 .53514 Mdot
.64141 .37697 Mdot
.65874 .61644 Mdot
.60704 .65977 Mdot
.62309 .31183 Mdot
.49258 .7097 Mdot
.43706 .32331 Mdot
.30562 .6047 Mdot
.59899 .67209 Mdot
.61859 .67222 Mdot
.62702 .34985 Mdot
.31907 .56995 Mdot
.70108 .51179 Mdot
.61837 .28735 Mdot
.48415 .70273 Mdot
.6425 .35227 Mdot
.43827 .28591 Mdot
.62133 .3619 Mdot
.56245 .67929 Mdot
.45815 .32162 Mdot
.59533 .67815 Mdot
.41335 .31177 Mdot
.40072 .29525 Mdot
.3146 .37728 Mdot
.6493 .35715 Mdot
.65125 .61013 Mdot
.53061 .2715 Mdot
.34142 .54325 Mdot
.29894 .60763 Mdot
.60565 .31362 Mdot
.32883 .36972 Mdot
.28309 .34548 Mdot
.29802 .34882 Mdot
.66736 .60974 Mdot
.47504 .73026 Mdot
.51232 .27116 Mdot
.52328 .26282 Mdot
.68967 .42287 Mdot
.56987 .68239 Mdot
.4242 .30103 Mdot
.69358 .52698 Mdot
.71448 .53802 Mdot
.33488 .3656 Mdot
.5206 .26542 Mdot
.58772 .67821 Mdot
.69469 .49522 Mdot
.69011 .64198 Mdot
.32173 .63561 Mdot
.41675 .34637 Mdot
.428 .3623 Mdot
.41068 .31242 Mdot
.39993 .70139 Mdot
.70254 .48176 Mdot
.34674 .53009 Mdot
.32474 .39439 Mdot
.70316 .42885 Mdot
.30061 .36812 Mdot
.47851 .7043 Mdot
.65932 .33605 Mdot
.718 .62374 Mdot
.34593 .49665 Mdot
.3432 .5546 Mdot
.70109 .4353 Mdot
.31648 .53002 Mdot
.57512 .68706 Mdot
.6742 .64239 Mdot
.61575 .33575 Mdot
.31477 .67256 Mdot
.31758 .62889 Mdot
.30768 .62705 Mdot
.61064 .30922 Mdot
.42228 .338 Mdot
.56838 .27933 Mdot
.30472 .62671 Mdot
.71103 .52305 Mdot
.47332 .70936 Mdot
.71614 .48453 Mdot
.33024 .4992 Mdot
.34968 .54365 Mdot
.50225 .71519 Mdot
.47868 .71309 Mdot
.70505 .53284 Mdot
.4232 .34103 Mdot
.44446 .33764 Mdot
.61249 .68032 Mdot
.33194 .54469 Mdot
.2755 .63275 Mdot
.36267 .52239 Mdot
.31363 .36857 Mdot
.32402 .6784 Mdot
.41255 .72172 Mdot
.37989 .70279 Mdot
.28013 .60665 Mdot
.35637 .52605 Mdot
.6971 .43399 Mdot
.68908 .59217 Mdot
.70194 .50623 Mdot
.71977 .41373 Mdot
.63207 .30077 Mdot
.30015 .36593 Mdot
.33485 .51173 Mdot
.34388 .36973 Mdot
.28134 .65263 Mdot
.35416 .38315 Mdot
.39234 .69603 Mdot
.38771 .72082 Mdot
.33017 .34371 Mdot
.364 .52258 Mdot
.60793 .3263 Mdot
.63446 .37004 Mdot
.50584 .7094 Mdot
.33148 .4997 Mdot
.68824 .41411 Mdot
.72336 .50814 Mdot
.55965 .27238 Mdot
.57387 .2835 Mdot
.31737 .39012 Mdot
.41878 .28702 Mdot
.4836 .70921 Mdot
.34049 .50199 Mdot
.43224 .33833 Mdot
.60157 .30853 Mdot
.4165 .30821 Mdot
.55156 .26751 Mdot
.69493 .51782 Mdot
.71302 .49814 Mdot
.32664 .53415 Mdot
.26595 .38877 Mdot
.68281 .62875 Mdot
.6823 .59271 Mdot
.7245 .50925 Mdot
.65067 .36081 Mdot
.41659 .32588 Mdot
.61889 .6979 Mdot
.56947 .68704 Mdot
.33884 .38955 Mdot
.35811 .50582 Mdot
.6276 .3625 Mdot
.56563 .70249 Mdot
.32794 .39085 Mdot
.38158 .67992 Mdot
.60551 .28559 Mdot
.34313 .52402 Mdot
.50677 .69857 Mdot
.70231 .61082 Mdot
.39281 .70468 Mdot
.60835 .67474 Mdot
.71715 .52517 Mdot
.69446 .50328 Mdot
.34917 .54593 Mdot
.7131 .63586 Mdot
.59081 .65594 Mdot
.69731 .49078 Mdot
.3317 .34562 Mdot
.43697 .31646 Mdot
.30218 .37128 Mdot
.61395 .3391 Mdot
.31326 .37592 Mdot
.61365 .30035 Mdot
.54506 .27498 Mdot
.58702 .68565 Mdot
.32872 .37477 Mdot
.42457 .71468 Mdot
.43494 .31058 Mdot
.3458 .3967 Mdot
.38294 .69443 Mdot
.47837 .70154 Mdot
.6326 .33557 Mdot
.34388 .37454 Mdot
.3634 .53883 Mdot
.72816 .48493 Mdot
.70852 .40338 Mdot
.69515 .52732 Mdot
.41889 .33004 Mdot
.63257 .35062 Mdot
.59451 .67247 Mdot
.28134 .61611 Mdot
.54907 .69079 Mdot
.29371 .62639 Mdot
.33301 .53158 Mdot
.57751 .66203 Mdot
.59547 .67192 Mdot
.35149 .54546 Mdot
.30798 .59511 Mdot
.43916 .31301 Mdot
.71745 .52995 Mdot
.6673 .61547 Mdot
.67204 .61304 Mdot
.64022 .31877 Mdot
.57515 .69671 Mdot
.47725 .33283 Mdot
.69348 .5214 Mdot
.40038 .34409 Mdot
.70294 .52051 Mdot
.27531 .35574 Mdot
.61103 .28967 Mdot
.64283 .62907 Mdot
.6559 .62314 Mdot
.48811 .72579 Mdot
.58432 .68773 Mdot
.32535 .3635 Mdot
.57964 .69823 Mdot
.5925 .68841 Mdot
.33142 .54648 Mdot
.4303 .34111 Mdot
.42165 .30805 Mdot
.39901 .69895 Mdot
.68222 .62815 Mdot
.35589 .53278 Mdot
.37852 .68962 Mdot
.34027 .55156 Mdot
.39388 .70361 Mdot
.66701 .63904 Mdot
.31476 .52552 Mdot
.58327 .69283 Mdot
.68674 .65005 Mdot
.45848 .35322 Mdot
.43141 .30921 Mdot
.41906 .30293 Mdot
.69813 .39081 Mdot
.2931 .62041 Mdot
.5392 .27163 Mdot
.48956 .71083 Mdot
.44386 .32994 Mdot
.43202 .71218 Mdot
.34881 .37491 Mdot
.31066 .6139 Mdot
.43467 .33421 Mdot
.63154 .31816 Mdot
.48995 .72492 Mdot
.30188 .61545 Mdot
.41735 .33619 Mdot
.58426 .68322 Mdot
.69048 .61612 Mdot
.57385 .67689 Mdot
.33085 .35741 Mdot
.69807 .52063 Mdot
.48763 .71287 Mdot
.61299 .33462 Mdot
.53775 .26924 Mdot
.59485 .67748 Mdot
.65538 .33427 Mdot
.71767 .50275 Mdot
.30163 .61963 Mdot
.71252 .53173 Mdot
.3483 .36611 Mdot
.66839 .62106 Mdot
.49329 .71869 Mdot
.50592 .72928 Mdot
.58472 .70126 Mdot
.44374 .31411 Mdot
.29949 .35288 Mdot
.65897 .34637 Mdot
.69575 .60836 Mdot
.69646 .51859 Mdot
.64432 .32059 Mdot
.49786 .72061 Mdot
.35762 .37548 Mdot
.30866 .58394 Mdot
.32666 .5211 Mdot
.4956 .68721 Mdot
.32241 .53606 Mdot
.53444 .26659 Mdot
.61491 .67314 Mdot
.4703 .71611 Mdot
.3856 .71717 Mdot
.26614 .37393 Mdot
.29537 .36832 Mdot
.35423 .51824 Mdot
.4266 .70685 Mdot
.32218 .56394 Mdot
.65585 .60189 Mdot
.39364 .70821 Mdot
.63406 .29602 Mdot
.43001 .36202 Mdot
.7194 .41251 Mdot
.43787 .329 Mdot
.65871 .337 Mdot
.30862 .59743 Mdot
.31647 .57746 Mdot
.71002 .60678 Mdot
.47762 .70315 Mdot
.70577 .49767 Mdot
.31486 .54009 Mdot
.63717 .3226 Mdot
.52298 .27734 Mdot
.34036 .48856 Mdot
.57468 .6844 Mdot
.71742 .46966 Mdot
.4367 .33658 Mdot
.41678 .30419 Mdot
.3327 .38864 Mdot
.64719 .30906 Mdot
.45745 .30161 Mdot
.70168 .51333 Mdot
.36553 .53435 Mdot
.41351 .72141 Mdot
.73205 .48272 Mdot
.58031 .70447 Mdot
.69236 .40602 Mdot
.27386 .35798 Mdot
.34307 .53503 Mdot
.67818 .63467 Mdot
.5987 .69314 Mdot
.33504 .39323 Mdot
.54511 .26601 Mdot
.55505 .28245 Mdot
.27286 .40141 Mdot
.45263 .33116 Mdot
.60201 .30733 Mdot
.45463 .30096 Mdot
.49597 .71035 Mdot
.38755 .69636 Mdot
.7055 .40029 Mdot
.33746 .54278 Mdot
.67658 .6562 Mdot
.61018 .68257 Mdot
.35688 .51245 Mdot
.30478 .35696 Mdot
.6308 .67685 Mdot
.50428 .72481 Mdot
.36963 .5137 Mdot
.62963 .35466 Mdot
.33873 .5384 Mdot
.47882 .33315 Mdot
.40072 .34076 Mdot
.32699 .54717 Mdot
.62628 .31094 Mdot
.45813 .32032 Mdot
.30512 .35262 Mdot
.61173 .68703 Mdot
.43678 .32814 Mdot
.48318 .70245 Mdot
.30227 .60411 Mdot
.32945 .34532 Mdot
.49971 .71345 Mdot
.55845 .6773 Mdot
.4168 .30032 Mdot
.64659 .34981 Mdot
.69879 .62284 Mdot
.34638 .53947 Mdot
.43917 .31601 Mdot
.34865 .50381 Mdot
.61697 .64828 Mdot
.32868 .52004 Mdot
.71877 .55156 Mdot
.70215 .60608 Mdot
.70822 .51122 Mdot
.48665 .72331 Mdot
.34125 .52497 Mdot
.45552 .30306 Mdot
.41628 .32176 Mdot
.305 .63225 Mdot
.59686 .67713 Mdot
.59767 .68876 Mdot
.58 .67447 Mdot
.64481 .32682 Mdot
.27922 .64645 Mdot
.71267 .51262 Mdot
.42634 .3396 Mdot
.70481 .47571 Mdot
.41576 .69644 Mdot
.32741 .3566 Mdot
.73504 .50305 Mdot
.29996 .6247 Mdot
.68254 .59681 Mdot
.33251 .60801 Mdot
.67766 .58843 Mdot
.69429 .38936 Mdot
.6913 .40708 Mdot
.67914 .62288 Mdot
.35705 .51936 Mdot
.40185 .7034 Mdot
.40969 .72372 Mdot
.69998 .48721 Mdot
.43097 .34738 Mdot
.49501 .30625 Mdot
.62142 .35599 Mdot
.35664 .38007 Mdot
.70685 .43767 Mdot
.70548 .45857 Mdot
.47609 .72442 Mdot
.69533 .62142 Mdot
.6974 .50787 Mdot
.70383 .54308 Mdot
.63906 .33218 Mdot
.4827 .72559 Mdot
.34121 .51967 Mdot
.44172 .30716 Mdot
.70586 .41162 Mdot
.31177 .62898 Mdot
.47002 .70787 Mdot
.56061 .27097 Mdot
.59406 .66752 Mdot
.73704 .49311 Mdot
.40449 .68774 Mdot
.59961 .65748 Mdot
.57875 .28821 Mdot
.66463 .64267 Mdot
.35448 .53062 Mdot
.42268 .32359 Mdot
.65628 .34028 Mdot
.29529 .60823 Mdot
.5289 .26811 Mdot
.70407 .4936 Mdot
.72667 .47734 Mdot
.40655 .69268 Mdot
.58658 .28494 Mdot
.35515 .53992 Mdot
.51111 .71764 Mdot
.32045 .38289 Mdot
.69867 .49491 Mdot
.70795 .62389 Mdot
.35136 .50202 Mdot
.63374 .3099 Mdot
.61396 .35125 Mdot
.60468 .67856 Mdot
.57172 .68034 Mdot
.6479 .61654 Mdot
.43001 .31495 Mdot
.6461 .31607 Mdot
.43844 .31501 Mdot
.36998 .52044 Mdot
.69597 .4922 Mdot
.3058 .35144 Mdot
.65516 .35085 Mdot
.71078 .4319 Mdot
.479 .70136 Mdot
.6637 .61004 Mdot
.51004 .68843 Mdot
.50621 .71433 Mdot
.64842 .31228 Mdot
.31823 .35589 Mdot
.38726 .70536 Mdot
.48799 .73213 Mdot
.32892 .35002 Mdot
.64179 .32696 Mdot
.68761 .61997 Mdot
.60204 .69214 Mdot
.69399 .5944 Mdot
.4189 .71611 Mdot
.58156 .7142 Mdot
.32217 .604 Mdot
.32611 .55089 Mdot
.6533 .64022 Mdot
.28614 .60853 Mdot
.69527 .5267 Mdot
.69278 .60038 Mdot
.39332 .70405 Mdot
.4639 .71464 Mdot
.32154 .61209 Mdot
.32 .5726 Mdot
.47748 .71033 Mdot
.29302 .62044 Mdot
.56977 .66806 Mdot
.61842 .67264 Mdot
.38206 .7042 Mdot
.6922 .4952 Mdot
.31948 .36217 Mdot
.67264 .64644 Mdot
.3369 .53588 Mdot
.5702 .66651 Mdot
.38165 .69851 Mdot
.71894 .55117 Mdot
.47897 .70786 Mdot
.6595 .33364 Mdot
.30919 .58762 Mdot
.61553 .35596 Mdot
.50257 .73031 Mdot
.57085 .66511 Mdot
.70216 .40285 Mdot
.50373 .72594 Mdot
.60619 .28148 Mdot
.31446 .54063 Mdot
.42135 .32085 Mdot
.31219 .3776 Mdot
.45797 .31306 Mdot
.70376 .53423 Mdot
.29414 .61458 Mdot
.30163 .59524 Mdot
.32307 .51423 Mdot
.37004 .51968 Mdot
.433 .30947 Mdot
.34675 .34785 Mdot
.61951 .64914 Mdot
.30647 .61311 Mdot
.63968 .36646 Mdot
.68911 .63345 Mdot
.31338 .60099 Mdot
.4087 .72661 Mdot
.50932 .70127 Mdot
.68141 .62712 Mdot
.66001 .61244 Mdot
.48824 .31924 Mdot
.32219 .3752 Mdot
.34347 .54931 Mdot
.33412 .34025 Mdot
.49027 .7137 Mdot
.70453 .52688 Mdot
.32296 .51165 Mdot
.61149 .29013 Mdot
.39649 .71403 Mdot
.64316 .32837 Mdot
.33614 .5603 Mdot
.66432 .62169 Mdot
.69516 .50372 Mdot
.54862 .28576 Mdot
.55429 .2878 Mdot
.32254 .62842 Mdot
.51624 .26759 Mdot
.33618 .36055 Mdot
.33108 .36288 Mdot
.69629 .50604 Mdot
.3596 .51893 Mdot
.39182 .71132 Mdot
.45695 .73078 Mdot
.29167 .61366 Mdot
.34835 .55556 Mdot
.71253 .42698 Mdot
.70625 .43196 Mdot
.65399 .35058 Mdot
.3498 .54966 Mdot
.31418 .62369 Mdot
.67334 .6271 Mdot
.29789 .36722 Mdot
.64353 .30964 Mdot
.32536 .39119 Mdot
.61402 .31328 Mdot
.28425 .6655 Mdot
.42502 .34603 Mdot
.33054 .35977 Mdot
.70149 .44393 Mdot
.67853 .6003 Mdot
.43803 .30793 Mdot
.62724 .33613 Mdot
.65237 .32651 Mdot
.3121 .60239 Mdot
.58291 .70519 Mdot
.67159 .64256 Mdot
.33143 .35531 Mdot
.72427 .51365 Mdot
.50415 .71609 Mdot
.41144 .31079 Mdot
.27062 .36337 Mdot
.64156 .31358 Mdot
.66332 .59379 Mdot
.52265 .69314 Mdot
.33413 .52489 Mdot
.68963 .61582 Mdot
.3369 .52171 Mdot
.5866 .67326 Mdot
.68062 .64816 Mdot
.33561 .49238 Mdot
.58295 .66782 Mdot
.60331 .2983 Mdot
.52583 .28355 Mdot
.4674 .71514 Mdot
.68244 .4059 Mdot
.49132 .711 Mdot
.56918 .28235 Mdot
.33192 .60655 Mdot
.29902 .6041 Mdot
.33514 .53483 Mdot
.3693 .36712 Mdot
.28736 .59669 Mdot
.41001 .32125 Mdot
.42189 .31989 Mdot
.69002 .62205 Mdot
.45822 .30968 Mdot
.39837 .70158 Mdot
.33264 .3762 Mdot
.61671 .3369 Mdot
.3266 .62292 Mdot
.32562 .35376 Mdot
.60685 .68846 Mdot
.49111 .72945 Mdot
.65569 .64495 Mdot
.62713 .36689 Mdot
.42504 .33516 Mdot
.70409 .49542 Mdot
.36922 .6804 Mdot
.63428 .31513 Mdot
.70435 .4185 Mdot
.39632 .69162 Mdot
.66032 .33414 Mdot
.69102 .51003 Mdot
.52298 .28223 Mdot
.69775 .4172 Mdot
.72045 .49668 Mdot
.412 .71387 Mdot
.33282 .37697 Mdot
.45963 .31396 Mdot
.34081 .34143 Mdot
.69913 .40515 Mdot
.57408 .29121 Mdot
.63554 .34658 Mdot
.38323 .71371 Mdot
.58438 .7138 Mdot
.44829 .31894 Mdot
.35107 .55084 Mdot
.7005 .42773 Mdot
.2775 .65207 Mdot
.4593 .31368 Mdot
.71358 .50168 Mdot
.50398 .72955 Mdot
.32012 .67708 Mdot
.4292 .32033 Mdot
.42809 .3043 Mdot
.3414 .37654 Mdot
.55395 .27517 Mdot
.66306 .63906 Mdot
.34832 .37997 Mdot
.31927 .53202 Mdot
.33726 .54636 Mdot
.70368 .5315 Mdot
.43561 .32906 Mdot
.7161 .51119 Mdot
.30155 .36108 Mdot
.34825 .34992 Mdot
.6106 .68731 Mdot
.57717 .6783 Mdot
.44766 .29352 Mdot
.27884 .60739 Mdot
.30648 .57731 Mdot
.71046 .61423 Mdot
.66258 .63085 Mdot
.31639 .55728 Mdot
.30544 .34526 Mdot
.34136 .38042 Mdot
.50926 .72225 Mdot
.37696 .69309 Mdot
.47524 .71363 Mdot
.38955 .68332 Mdot
.66533 .3832 Mdot
.49002 .72285 Mdot
.65871 .34209 Mdot
.38762 .68224 Mdot
.69285 .4415 Mdot
.50695 .70825 Mdot
.33355 .51833 Mdot
.61743 .32018 Mdot
.33151 .55563 Mdot
.61773 .34553 Mdot
.35206 .53709 Mdot
.64321 .30078 Mdot
.6131 .3345 Mdot
.49688 .30106 Mdot
.34649 .67633 Mdot
.41128 .31883 Mdot
.3157 .34525 Mdot
.42141 .36042 Mdot
.31807 .58777 Mdot
.68453 .61825 Mdot
.58933 .71493 Mdot
.33318 .52421 Mdot
.63937 .33599 Mdot
.70727 .49121 Mdot
.51369 .7232 Mdot
.3317 .50381 Mdot
.50171 .70957 Mdot
.66346 .60994 Mdot
.62835 .35257 Mdot
.31387 .38175 Mdot
.5505 .2622 Mdot
.5658 .28232 Mdot
.60827 .28936 Mdot
.36792 .49725 Mdot
.50901 .70284 Mdot
.47915 .33268 Mdot
.60266 .66354 Mdot
.28621 .34333 Mdot
.59332 .69434 Mdot
.43951 .32594 Mdot
.33309 .38574 Mdot
.33246 .67409 Mdot
.68348 .63905 Mdot
.61044 .30993 Mdot
.34362 .52531 Mdot
.42043 .34248 Mdot
.34144 .34192 Mdot
.70009 .63121 Mdot
.3294 .34488 Mdot
.62299 .33232 Mdot
.4354 .31965 Mdot
.27764 .64741 Mdot
.31845 .50573 Mdot
.37398 .7064 Mdot
.34084 .52808 Mdot
.33246 .35354 Mdot
.58012 .70547 Mdot
.50316 .71005 Mdot
.70098 .41327 Mdot
.39715 .70669 Mdot
.34479 .55793 Mdot
.58389 .28268 Mdot
.6634 .61416 Mdot
.32335 .36786 Mdot
.69955 .42652 Mdot
.32038 .37573 Mdot
.41534 .30708 Mdot
.58275 .6774 Mdot
.41499 .30649 Mdot
.47519 .70486 Mdot
.6992 .50467 Mdot
.67414 .64215 Mdot
.56797 .27698 Mdot
.44957 .33511 Mdot
.60467 .31527 Mdot
.33187 .67711 Mdot
.60067 .67938 Mdot
.7158 .41818 Mdot
.54715 .26135 Mdot
.71361 .5499 Mdot
.3749 .70074 Mdot
.72187 .52207 Mdot
.33285 .52553 Mdot
.69768 .59628 Mdot
.71062 .47884 Mdot
.55644 .28657 Mdot
.42635 .70776 Mdot
.40567 .31945 Mdot
.36134 .51466 Mdot
.73743 .53481 Mdot
.69416 .48354 Mdot
.57901 .69215 Mdot
.70672 .43958 Mdot
.32438 .57115 Mdot
.43567 .31222 Mdot
.32863 .54084 Mdot
.69423 .40878 Mdot
.71197 .43465 Mdot
.54102 .28047 Mdot
.34689 .52759 Mdot
.31468 .37104 Mdot
.65897 .33584 Mdot
.61171 .34768 Mdot
.65325 .34403 Mdot
.59447 .6567 Mdot
.44015 .339 Mdot
.42809 .31536 Mdot
.33093 .61049 Mdot
.71845 .51379 Mdot
.41081 .32048 Mdot
.30341 .60743 Mdot
.31465 .5937 Mdot
.69619 .5971 Mdot
.6229 .32579 Mdot
.34054 .55817 Mdot
.46632 .71788 Mdot
.41566 .33222 Mdot
.62211 .31306 Mdot
.58576 .68158 Mdot
.57286 .28058 Mdot
.2983 .61692 Mdot
.47363 .71985 Mdot
.58843 .7016 Mdot
.55857 .67406 Mdot
.28513 .59879 Mdot
.33744 .5198 Mdot
.71208 .5347 Mdot
.51081 .66469 Mdot
.37422 .60235 Mdot
.44346 .49501 Mdot
.45023 .32266 Mdot
.59769 .56085 Mdot
.46792 .65022 Mdot
.46192 .7333 Mdot
.4984 .58593 Mdot
.42864 .7013 Mdot
.54355 .61612 Mdot
.6381 .42049 Mdot
.47419 .55607 Mdot
.54689 .29596 Mdot
.66633 .48821 Mdot
.52504 .71799 Mdot
.3277 .43071 Mdot
.67644 .55721 Mdot
.50908 .63054 Mdot
.66997 .49016 Mdot
.60284 .44846 Mdot
.58978 .33351 Mdot
.64468 .37911 Mdot
.60854 .40815 Mdot
.36537 .5369 Mdot
.53745 .64439 Mdot
.38668 .62267 Mdot
.64023 .59099 Mdot
.66746 .41106 Mdot
.4646 .72344 Mdot
.40488 .38849 Mdot
.61641 .56845 Mdot
.45598 .39427 Mdot
.41746 .67011 Mdot
.63053 .44464 Mdot
.38542 .6167 Mdot
.37815 .43075 Mdot
.4349 .69739 Mdot
.54937 .58596 Mdot
.5985 .58998 Mdot
.42742 .64732 Mdot
.62539 .55286 Mdot
.62678 .30132 Mdot
.57354 .70592 Mdot
.67346 .51957 Mdot
.46552 .37666 Mdot
.64452 .54437 Mdot
.49767 .58697 Mdot
.44812 .29624 Mdot
.59903 .55367 Mdot
.2885 .64856 Mdot
.67876 .58456 Mdot
.64829 .46816 Mdot
.66399 .42006 Mdot
.43804 .65638 Mdot
.67056 .44178 Mdot
.33576 .66393 Mdot
.51326 .63251 Mdot
.474 .65325 Mdot
.60563 .44423 Mdot
.55127 .34951 Mdot
.65972 .62219 Mdot
.33859 .44065 Mdot
.56034 .42951 Mdot
.40821 .48741 Mdot
.65328 .48737 Mdot
.43975 .6822 Mdot
.6289 .6553 Mdot
.70406 .59133 Mdot
.59581 .36162 Mdot
.48235 .35409 Mdot
.61779 .40546 Mdot
.56961 .43093 Mdot
.64656 .53447 Mdot
.3575 .62646 Mdot
.58233 .60743 Mdot
.58296 .37246 Mdot
.52153 .68043 Mdot
.36811 .39177 Mdot
.5511 .51512 Mdot
.43633 .36886 Mdot
.4542 .65988 Mdot
.61351 .45289 Mdot
.44832 .58766 Mdot
.61134 .52636 Mdot
.32109 .65321 Mdot
.45237 .3677 Mdot
.54 .64282 Mdot
.55828 .37719 Mdot
.67118 .56091 Mdot
.48046 .66954 Mdot
.6632 .44212 Mdot
.39579 .34074 Mdot
.44696 .43066 Mdot
.40787 .37611 Mdot
.50675 .57907 Mdot
.37842 .41495 Mdot
.63065 .44199 Mdot
.67882 .49124 Mdot
.60039 .32497 Mdot
.6231 .61458 Mdot
.47867 .37975 Mdot
.67958 .65364 Mdot
.57935 .31473 Mdot
.48829 .6128 Mdot
.61165 .62541 Mdot
.40426 .37831 Mdot
.60467 .37258 Mdot
.59973 .51626 Mdot
.59876 .4212 Mdot
.59635 .58549 Mdot
.57078 .61296 Mdot
.68136 .56229 Mdot
.42995 .28647 Mdot
.5677 .65455 Mdot
.44247 .39731 Mdot
.63084 .39178 Mdot
.34159 .41336 Mdot
.28075 .62369 Mdot
.47016 .40119 Mdot
.4673 .68884 Mdot
.50661 .48096 Mdot
.65841 .57867 Mdot
.41935 .37087 Mdot
.46149 .72197 Mdot
.52481 .67354 Mdot
.60725 .40538 Mdot
.37387 .48044 Mdot
.66765 .58328 Mdot
.67293 .48687 Mdot
.61009 .35965 Mdot
.46615 .66681 Mdot
.47793 .33921 Mdot
.35752 .57092 Mdot
.40487 .45489 Mdot
.66958 .38751 Mdot
.40045 .48024 Mdot
.43414 .45436 Mdot
.51469 .29628 Mdot
.62086 .63029 Mdot
.43282 .43757 Mdot
.4823 .68642 Mdot
.57677 .36622 Mdot
.63216 .41537 Mdot
.52681 .65825 Mdot
.2852 .38432 Mdot
.39837 .40533 Mdot
.45498 .46008 Mdot
.6013 .53824 Mdot
.46492 .73884 Mdot
.39916 .59736 Mdot
.62659 .43362 Mdot
.51491 .41069 Mdot
.53673 .35912 Mdot
.67316 .47876 Mdot
.68526 .65314 Mdot
.49847 .39077 Mdot
.42955 .5803 Mdot
.53932 .68765 Mdot
.50074 .43089 Mdot
.64866 .59827 Mdot
.48538 .42096 Mdot
.40332 .3854 Mdot
.63521 .37837 Mdot
.59298 .38055 Mdot
.65106 .53474 Mdot
.66633 .42407 Mdot
.57613 .62895 Mdot
.58341 .62838 Mdot
.50659 .36855 Mdot
.67235 .55032 Mdot
.62227 .47076 Mdot
.69819 .58614 Mdot
.51409 .61722 Mdot
.41297 .64471 Mdot
.37382 .58978 Mdot
.44578 .54244 Mdot
.30808 .34179 Mdot
.37788 .43787 Mdot
.46741 .6692 Mdot
.27687 .36775 Mdot
.39567 .52578 Mdot
.38115 .61458 Mdot
.40897 .30784 Mdot
.36187 .58439 Mdot
.3037 .66126 Mdot
.57288 .53401 Mdot
.59994 .38012 Mdot
.45684 .47891 Mdot
.36812 .57343 Mdot
.64972 .58313 Mdot
.43095 .69607 Mdot
.42071 .3717 Mdot
.50497 .32951 Mdot
.49755 .64788 Mdot
.54617 .65868 Mdot
.68021 .41812 Mdot
.70546 .46518 Mdot
.52634 .29792 Mdot
.65157 .53384 Mdot
.62891 .66423 Mdot
.53718 .26345 Mdot
.60761 .48204 Mdot
.44143 .59904 Mdot
.37646 .6459 Mdot
.44176 .37845 Mdot
.57978 .54999 Mdot
.33946 .40175 Mdot
.45851 .62458 Mdot
.43875 .47345 Mdot
.39086 .40045 Mdot
.36077 .4136 Mdot
.35341 .42628 Mdot
.67322 .52892 Mdot
.37032 .44061 Mdot
.39151 .37783 Mdot
.28502 .65487 Mdot
.56601 .46818 Mdot
.48233 .73911 Mdot
.40838 .55411 Mdot
.57286 .32088 Mdot
.56081 .41808 Mdot
.56852 .60723 Mdot
.43831 .65733 Mdot
.38342 .36504 Mdot
.30228 .65952 Mdot
.62349 .53484 Mdot
.43764 .40359 Mdot
.56798 .38895 Mdot
.46616 .39727 Mdot
.51741 .36029 Mdot
.52635 .58098 Mdot
.67235 .4893 Mdot
.26889 .38904 Mdot
.55712 .34604 Mdot
.63477 .57704 Mdot
.49917 .67937 Mdot
.57718 .32047 Mdot
.59803 .63533 Mdot
.60887 .60627 Mdot
.45231 .64628 Mdot
.41035 .59153 Mdot
.47028 .51393 Mdot
.55582 .58744 Mdot
.39165 .44086 Mdot
.54336 .39446 Mdot
.63678 .37707 Mdot
.53046 .31143 Mdot
.46675 .49906 Mdot
.56045 .46298 Mdot
.37615 .55337 Mdot
.59837 .35832 Mdot
.54581 .55483 Mdot
.37 .60697 Mdot
.45585 .47542 Mdot
.51183 .64131 Mdot
.64078 .61829 Mdot
.42116 .58548 Mdot
.28708 .62506 Mdot
.46441 .37295 Mdot
.52503 .29257 Mdot
.51277 .35554 Mdot
.5388 .65119 Mdot
.6817 .45167 Mdot
.65675 .51424 Mdot
.38721 .52598 Mdot
.36447 .64104 Mdot
.51362 .54654 Mdot
.3756 .66392 Mdot
.72811 .51903 Mdot
.63376 .65558 Mdot
.56266 .63431 Mdot
.35123 .55857 Mdot
.45183 .55757 Mdot
.54877 .63045 Mdot
.39439 .49983 Mdot
.47389 .68525 Mdot
.619 .64727 Mdot
.56562 .35238 Mdot
.64039 .37785 Mdot
.29668 .39755 Mdot
.55643 .43947 Mdot
.31994 .39354 Mdot
.5214 .32352 Mdot
.59657 .52945 Mdot
.41793 .66592 Mdot
.67743 .43055 Mdot
.52814 .37037 Mdot
.56251 .29655 Mdot
.51906 .35841 Mdot
.62826 .41051 Mdot
.65195 .49451 Mdot
.3485 .6023 Mdot
.62243 .58009 Mdot
.672 .46924 Mdot
.34001 .62148 Mdot
.6455 .40008 Mdot
.61059 .54238 Mdot
.68488 .58035 Mdot
.29077 .63875 Mdot
.33333 .61185 Mdot
.36088 .44284 Mdot
.3522 .61847 Mdot
.43361 .49846 Mdot
.60214 .70682 Mdot
.3442 .4585 Mdot
.62824 .53591 Mdot
.48885 .73686 Mdot
.54254 .6629 Mdot
.67032 .57805 Mdot
.49253 .68044 Mdot
.57815 .30065 Mdot
.68855 .45747 Mdot
.55575 .62592 Mdot
.39159 .52841 Mdot
.40599 .41075 Mdot
.3855 .50918 Mdot
.55605 .65515 Mdot
.41973 .55956 Mdot
.63934 .61628 Mdot
.44326 .65679 Mdot
.56631 .49955 Mdot
.62418 .61944 Mdot
.46736 .61642 Mdot
.47393 .68085 Mdot
.53247 .70588 Mdot
.49631 .35128 Mdot
.35451 .46065 Mdot
.5417 .59367 Mdot
.32226 .55498 Mdot
.49413 .4796 Mdot
.49564 .61366 Mdot
.37109 .54164 Mdot
.52457 .60398 Mdot
.33044 .45242 Mdot
.71298 .61376 Mdot
.57997 .58325 Mdot
.52503 .40379 Mdot
.37253 .52096 Mdot
.41581 .6682 Mdot
.48222 .66763 Mdot
.67242 .48228 Mdot
.35105 .46019 Mdot
.48509 .34934 Mdot
.54458 .49684 Mdot
.37018 .56728 Mdot
.46186 .4464 Mdot
.36148 .45187 Mdot
.41909 .29203 Mdot
.51324 .36301 Mdot
.6016 .56037 Mdot
.31874 .43728 Mdot
.65804 .39675 Mdot
.44322 .53331 Mdot
.4475 .5932 Mdot
.56493 .34779 Mdot
.46386 .5949 Mdot
.47664 .57727 Mdot
.46853 .4753 Mdot
.57571 .34108 Mdot
.57539 .56585 Mdot
.61843 .54525 Mdot
.61408 .64705 Mdot
.38618 .38944 Mdot
.55701 .61018 Mdot
.60838 .61088 Mdot
.53767 .4024 Mdot
.32965 .5114 Mdot
.43937 .54635 Mdot
.6607 .59292 Mdot
.51025 .44703 Mdot
.57107 .62067 Mdot
.53454 .29305 Mdot
.58619 .54478 Mdot
.45904 .4877 Mdot
.32137 .43247 Mdot
.31021 .43154 Mdot
.42229 .61663 Mdot
.39397 .36529 Mdot
.62884 .5333 Mdot
.5673 .64638 Mdot
.62553 .55923 Mdot
.3557 .65115 Mdot
.70626 .63597 Mdot
.49488 .3338 Mdot
.67958 .40547 Mdot
.64983 .58059 Mdot
.447 .62423 Mdot
.4678 .349 Mdot
.55732 .47249 Mdot
.61644 .48424 Mdot
.68057 .45855 Mdot
.61664 .37531 Mdot
.59628 .37177 Mdot
.42929 .54179 Mdot
.64883 .44308 Mdot
.55461 .35043 Mdot
.6038 .63107 Mdot
.5658 .301 Mdot
.55434 .36039 Mdot
.45449 .7009 Mdot
.58209 .37221 Mdot
.58001 .65275 Mdot
.66193 .43859 Mdot
.49333 .60925 Mdot
.59349 .53666 Mdot
.51287 .42826 Mdot
.57108 .64956 Mdot
.66949 .52528 Mdot
.5785 .49538 Mdot
.3269 .66837 Mdot
.48795 .67362 Mdot
.52794 .67927 Mdot
.39113 .62591 Mdot
.59438 .51243 Mdot
.32867 .44574 Mdot
.69272 .39637 Mdot
.34392 .64371 Mdot
.6818 .5824 Mdot
.28775 .65683 Mdot
.62062 .47447 Mdot
.39446 .68083 Mdot
.49571 .355 Mdot
.62358 .4742 Mdot
.34737 .42593 Mdot
.51782 .27388 Mdot
.34653 .45205 Mdot
.58177 .60036 Mdot
.52067 .32436 Mdot
.56935 .32104 Mdot
.55001 .30946 Mdot
.35065 .41566 Mdot
.54504 .33632 Mdot
.33569 .63523 Mdot
.57954 .50899 Mdot
.36026 .62918 Mdot
.3776 .49017 Mdot
.55532 .3357 Mdot
.62256 .68927 Mdot
.41461 .41489 Mdot
.47871 .63321 Mdot
.64328 .39004 Mdot
.35465 .45 Mdot
.31916 .63873 Mdot
.49543 .44961 Mdot
.60897 .43242 Mdot
.5991 .30351 Mdot
.33363 .41281 Mdot
.53171 .65911 Mdot
.50471 .38566 Mdot
.52492 .67119 Mdot
.50731 .68489 Mdot
.6427 .42391 Mdot
.47188 .6432 Mdot
.26949 .38585 Mdot
.64211 .48258 Mdot
.49455 .31524 Mdot
.61125 .53374 Mdot
.69919 .56719 Mdot
.37464 .47754 Mdot
.50404 .36572 Mdot
.50761 .38922 Mdot
.34038 .42372 Mdot
.42042 .41636 Mdot
.42066 .42327 Mdot
.3284 .45056 Mdot
.49789 .64041 Mdot
.3507 .63358 Mdot
.39102 .39718 Mdot
.42193 .64475 Mdot
.48242 .35544 Mdot
.71095 .54585 Mdot
.60272 .45422 Mdot
.63751 .64005 Mdot
.35945 .60146 Mdot
.35688 .61453 Mdot
.53443 .3702 Mdot
.669 .5639 Mdot
.45737 .51598 Mdot
.45676 .46248 Mdot
.66536 .43328 Mdot
.35462 .65866 Mdot
.52861 .59092 Mdot
.33016 .41917 Mdot
.28633 .62652 Mdot
.3892 .31238 Mdot
.59615 .38088 Mdot
.62076 .58072 Mdot
.5884 .5229 Mdot
.63438 .64263 Mdot
.42984 .50626 Mdot
.33976 .57632 Mdot
.39082 .38919 Mdot
.58769 .52146 Mdot
.37558 .62039 Mdot
.37434 .46502 Mdot
.60525 .61522 Mdot
.65659 .55357 Mdot
.50644 .58882 Mdot
.58846 .44896 Mdot
.27859 .63966 Mdot
.61352 .40408 Mdot
.53501 .29235 Mdot
.33072 .44267 Mdot
.65838 .54654 Mdot
.35701 .60406 Mdot
.4427 .44471 Mdot
.57334 .409 Mdot
.32307 .42336 Mdot
.59976 .35644 Mdot
.46741 .66995 Mdot
.64152 .40001 Mdot
.6615 .5622 Mdot
.61374 .47849 Mdot
.34844 .61882 Mdot
.33861 .4418 Mdot
.4397 .61153 Mdot
.55881 .51805 Mdot
.47675 .44067 Mdot
.37554 .67361 Mdot
.54107 .64021 Mdot
.41041 .59581 Mdot
.685 .54322 Mdot
.33742 .42756 Mdot
.61263 .41867 Mdot
.36871 .45468 Mdot
.33082 .42982 Mdot
.61844 .68781 Mdot
.56509 .63625 Mdot
.67741 .49903 Mdot
.37219 .56983 Mdot
.5977 .30024 Mdot
.30717 .63724 Mdot
.31868 .66461 Mdot
.46903 .61018 Mdot
.50208 .39907 Mdot
.27137 .38422 Mdot
.48087 .6779 Mdot
.60298 .40731 Mdot
.48405 .68289 Mdot
.55253 .30034 Mdot
.52424 .57639 Mdot
.46751 .65414 Mdot
.42432 .50598 Mdot
.64866 .49853 Mdot
.50209 .63966 Mdot
.45394 .39576 Mdot
.41144 .54447 Mdot
.45912 .6494 Mdot
.45974 .65629 Mdot
.43587 .5926 Mdot
.63086 .60136 Mdot
.43618 .39697 Mdot
.61501 .38378 Mdot
.27285 .36898 Mdot
.42034 .64696 Mdot
.36062 .61404 Mdot
.59782 .53591 Mdot
.47382 .39244 Mdot
.52361 .26889 Mdot
.28218 .40165 Mdot
.39252 .65644 Mdot
.64384 .61279 Mdot
.52188 .53873 Mdot
.36569 .63231 Mdot
.35525 .63565 Mdot
.65986 .48325 Mdot
.59698 .52039 Mdot
.4484 .4976 Mdot
.58594 .71092 Mdot
.72929 .4957 Mdot
.31936 .33883 Mdot
.27653 .37067 Mdot
.64195 .55894 Mdot
.41294 .61262 Mdot
.57992 .36269 Mdot
.68948 .57344 Mdot
.28705 .37782 Mdot
.63216 .51062 Mdot
.34497 .56275 Mdot
.39815 .57838 Mdot
.27554 .39816 Mdot
.37684 .42641 Mdot
.60916 .69663 Mdot
.5801 .63519 Mdot
.65094 .46254 Mdot
.5263 .37327 Mdot
.56316 .53892 Mdot
.55013 .33181 Mdot
.45489 .42448 Mdot
.50793 .37713 Mdot
.46329 .63971 Mdot
.49848 .57044 Mdot
.62305 .39921 Mdot
.51941 .32755 Mdot
.62921 .38869 Mdot
.4208 .47502 Mdot
.56629 .43243 Mdot
.64899 .3827 Mdot
.49997 .44203 Mdot
.63676 .52374 Mdot
.4782 .73712 Mdot
.51112 .55156 Mdot
.57309 .33671 Mdot
.57789 .70985 Mdot
.59418 .43307 Mdot
.49072 .65192 Mdot
.648 .5796 Mdot
.43792 .39953 Mdot
.56208 .64235 Mdot
.61958 .38962 Mdot
.36168 .61854 Mdot
.55913 .39175 Mdot
.41012 .66111 Mdot
.40063 .47676 Mdot
.43831 .29579 Mdot
.40095 .45139 Mdot
.39591 .32167 Mdot
.32313 .64271 Mdot
.39705 .5117 Mdot
.45135 .37221 Mdot
.32101 .64941 Mdot
.51752 .42903 Mdot
.61689 .45372 Mdot
.69588 .58299 Mdot
.41656 .37345 Mdot
.34665 .57426 Mdot
.57731 .64898 Mdot
.59464 .37187 Mdot
.39461 .31108 Mdot
.32816 .43176 Mdot
.66515 .56356 Mdot
.53393 .42786 Mdot
.5534 .29563 Mdot
.54934 .49741 Mdot
.53 .32263 Mdot
.61105 .53373 Mdot
.5316 .694 Mdot
.40193 .38246 Mdot
.62225 .46179 Mdot
.5117 .43248 Mdot
.36949 .61244 Mdot
.44425 .65484 Mdot
.33735 .59827 Mdot
.37446 .57979 Mdot
.62651 .30064 Mdot
.38129 .60412 Mdot
.63278 .43827 Mdot
.42619 .61871 Mdot
.57981 .3651 Mdot
.52266 .3098 Mdot
.56717 .41727 Mdot
.6729 .44573 Mdot
.32334 .43846 Mdot
.42199 .421 Mdot
.4966 .73833 Mdot
.47778 .68302 Mdot
.27656 .3913 Mdot
.54702 .3369 Mdot
.3524 .45861 Mdot
.39313 .59928 Mdot
.45057 .4284 Mdot
.49775 .33971 Mdot
.50556 .46795 Mdot
.69397 .39493 Mdot
.42345 .6357 Mdot
.57117 .65207 Mdot
.49885 .65907 Mdot
.68607 .54728 Mdot
.57021 .33409 Mdot
.55504 .62567 Mdot
.49747 .58148 Mdot
.50171 .42379 Mdot
.50421 .29752 Mdot
.64537 .56784 Mdot
.72267 .54161 Mdot
.42135 .67027 Mdot
.33243 .43825 Mdot
.51455 .68332 Mdot
.49679 .60611 Mdot
.5487 .57524 Mdot
.37615 .50203 Mdot
.68475 .56049 Mdot
.55411 .64127 Mdot
.45706 .67775 Mdot
.35284 .43389 Mdot
.56084 .593 Mdot
.51495 .3209 Mdot
.6508 .40985 Mdot
.53518 .57474 Mdot
.53646 .31763 Mdot
.70509 .59042 Mdot
.3548 .42705 Mdot
.375 .56025 Mdot
.40652 .29993 Mdot
.29639 .63695 Mdot
.46225 .62171 Mdot
.5139 .36106 Mdot
.56121 .53784 Mdot
.67377 .57647 Mdot
.48315 .66089 Mdot
.58624 .33892 Mdot
.29981 .3846 Mdot
.67504 .42075 Mdot
.61211 .44095 Mdot
.38242 .61601 Mdot
.37716 .62699 Mdot
.6172 .59913 Mdot
.60227 .54055 Mdot
.46564 .57884 Mdot
.58567 .4473 Mdot
.41101 .63701 Mdot
.50645 .326 Mdot
.32631 .41732 Mdot
.4526 .69013 Mdot
.56664 .29344 Mdot
.42937 .67464 Mdot
.44094 .67637 Mdot
.59905 .40747 Mdot
.57855 .59292 Mdot
.52822 .41616 Mdot
.52197 .39916 Mdot
.66831 .65203 Mdot
.29544 .4167 Mdot
.57058 .62183 Mdot
.58679 .4318 Mdot
.65766 .45934 Mdot
.50315 .61922 Mdot
.59171 .29166 Mdot
.66325 .50811 Mdot
.58212 .32582 Mdot
.58248 .3719 Mdot
.66434 .49277 Mdot
.62208 .53954 Mdot
.62054 .62186 Mdot
.38776 .40301 Mdot
.61785 .45049 Mdot
.45994 .39094 Mdot
.67974 .54146 Mdot
.42753 .57075 Mdot
.31086 .65859 Mdot
.35689 .57034 Mdot
.41422 .51582 Mdot
.41256 .44287 Mdot
.35148 .43954 Mdot
.39977 .33122 Mdot
.27607 .37231 Mdot
.65957 .44564 Mdot
.31101 .42388 Mdot
.50307 .63567 Mdot
.44396 .29421 Mdot
.5382 .39609 Mdot
.55926 .59233 Mdot
.342 .6455 Mdot
.46332 .47024 Mdot
.53716 .34267 Mdot
.61023 .6159 Mdot
.51146 .65947 Mdot
.49026 .34621 Mdot
.29651 .63514 Mdot
.41818 .69173 Mdot
.66484 .57584 Mdot
.59624 .3054 Mdot
.49289 .66213 Mdot
.33946 .40815 Mdot
.7278 .50536 Mdot
.6743 .42538 Mdot
.62018 .59398 Mdot
.51057 .38242 Mdot
.68348 .48035 Mdot
.64583 .59553 Mdot
.51829 .27933 Mdot
.7323 .51885 Mdot
.38552 .44838 Mdot
.53785 .68018 Mdot
.32265 .64384 Mdot
.41562 .45742 Mdot
.43005 .28703 Mdot
.48674 .3632 Mdot
.35327 .64366 Mdot
.60021 .44532 Mdot
.33944 .45029 Mdot
.63052 .40018 Mdot
.65352 .40231 Mdot
.67784 .56792 Mdot
.44745 .63703 Mdot
.68579 .44589 Mdot
.65643 .47109 Mdot
.40419 .66642 Mdot
.34495 .45235 Mdot
.4027 .43771 Mdot
.55998 .53205 Mdot
.45161 .45555 Mdot
.41066 .3899 Mdot
.55439 .32397 Mdot
.59561 .32138 Mdot
.61181 .35417 Mdot
.36838 .55285 Mdot
.56291 .41004 Mdot
.45996 .5297 Mdot
.36156 .43959 Mdot
.65289 .49725 Mdot
.62187 .45998 Mdot
.61363 .39261 Mdot
.46225 .62202 Mdot
.28053 .62564 Mdot
.34049 .42841 Mdot
.40865 .56224 Mdot
.58604 .32536 Mdot
.67376 .53263 Mdot
.66079 .44554 Mdot
.31992 .4232 Mdot
.45917 .57706 Mdot
.40297 .51938 Mdot
.31783 .43968 Mdot
.44413 .36587 Mdot
.61744 .6216 Mdot
.36141 .48239 Mdot
.51349 .27214 Mdot
.66752 .46978 Mdot
.53128 .38078 Mdot
.63632 .65603 Mdot
.66238 .39447 Mdot
.38329 .57847 Mdot
.34783 .46112 Mdot
.59009 .44167 Mdot
.61723 .68584 Mdot
.45124 .64438 Mdot
.62136 .43602 Mdot
.64658 .40181 Mdot
.40548 .63349 Mdot
.71293 .6126 Mdot
.42856 .48909 Mdot
.57169 .7064 Mdot
.49168 .36416 Mdot
.31576 .41526 Mdot
.43514 .68759 Mdot
.36808 .41816 Mdot
.41619 .69173 Mdot
.48206 .62103 Mdot
.42473 .67481 Mdot
.35134 .6001 Mdot
.62564 .43427 Mdot
.31516 .427 Mdot
.4158 .62226 Mdot
.31923 .41621 Mdot
.49077 .32578 Mdot
.6042 .69735 Mdot
.43184 .5902 Mdot
.36596 .59416 Mdot
.54792 .61216 Mdot
.58738 .59963 Mdot
.66626 .43429 Mdot
.52807 .32003 Mdot
.63377 .48598 Mdot
.28981 .61847 Mdot
.44304 .4581 Mdot
.4996 .37157 Mdot
.61394 .47687 Mdot
.49575 .37173 Mdot
.42391 .46839 Mdot
.29359 .64311 Mdot
.31236 .43741 Mdot
.56529 .64839 Mdot
.39147 .55252 Mdot
.28119 .36094 Mdot
.44491 .29456 Mdot
.41715 .6956 Mdot
.72764 .51722 Mdot
.36985 .53525 Mdot
.66272 .40322 Mdot
.48327 .36832 Mdot
.42824 .67151 Mdot
.36026 .60942 Mdot
.67125 .42093 Mdot
.28207 .64063 Mdot
.36813 .60936 Mdot
.71721 .54275 Mdot
.65287 .43301 Mdot
.58055 .29164 Mdot
.64632 .58451 Mdot
.52124 .63383 Mdot
.32491 .67205 Mdot
.42989 .29039 Mdot
.63521 .43051 Mdot
.61519 .59866 Mdot
.66687 .57337 Mdot
.6216 .39054 Mdot
.41949 .42556 Mdot
.66284 .55523 Mdot
.51537 .31238 Mdot
.35035 .62994 Mdot
.44295 .45028 Mdot
.57456 .61238 Mdot
.41696 .57448 Mdot
.41427 .39541 Mdot
.31039 .39755 Mdot
.40423 .31517 Mdot
.42036 .54343 Mdot
.44861 .37651 Mdot
.7231 .49569 Mdot
.51509 .28886 Mdot
.58065 .58878 Mdot
.48764 .65083 Mdot
.41968 .52421 Mdot
.58432 .52876 Mdot
.46886 .72956 Mdot
.3628 .48213 Mdot
.40045 .47353 Mdot
.67708 .44021 Mdot
.59196 .52569 Mdot
.513 .62627 Mdot
.52879 .61474 Mdot
.40115 .42334 Mdot
.47837 .73284 Mdot
.3336 .56415 Mdot
.39942 .32045 Mdot
.30933 .66487 Mdot
.42623 .28747 Mdot
.54406 .41021 Mdot
.67569 .46831 Mdot
.64028 .43223 Mdot
.65772 .39807 Mdot
.45301 .4113 Mdot
.40942 .38686 Mdot
.46895 .73587 Mdot
.37087 .43083 Mdot
.48354 .46584 Mdot
.66739 .52969 Mdot
.4037 .57551 Mdot
.3252 .42467 Mdot
.43455 .46101 Mdot
.41818 .36271 Mdot
.50109 .32582 Mdot
.47759 .38731 Mdot
.65752 .51159 Mdot
.63123 .64591 Mdot
.66081 .44074 Mdot
.38835 .52249 Mdot
.5123 .66397 Mdot
.29712 .39938 Mdot
.52931 .36436 Mdot
.59006 .46918 Mdot
.57879 .60685 Mdot
.4087 .60422 Mdot
.37083 .49285 Mdot
.61464 .29517 Mdot
.41979 .55975 Mdot
.41714 .44123 Mdot
.34888 .44255 Mdot
.50235 .7366 Mdot
.50647 .52194 Mdot
.42876 .45463 Mdot
.3426 .42263 Mdot
.61491 .29191 Mdot
.37436 .62184 Mdot
.42945 .69133 Mdot
.67831 .46895 Mdot
.40105 .30342 Mdot
.32945 .44337 Mdot
.67264 .46644 Mdot
.58518 .44625 Mdot
.73434 .5258 Mdot
.43417 .44824 Mdot
.46013 .68281 Mdot
.63506 .57351 Mdot
.38307 .34727 Mdot
.46473 .4409 Mdot
.28836 .41867 Mdot
.51483 .37097 Mdot
.52507 .4174 Mdot
.41415 .67393 Mdot
.6073 .38891 Mdot
.37627 .65367 Mdot
.66818 .55187 Mdot
.49631 .35688 Mdot
.67095 .38764 Mdot
.53384 .29019 Mdot
.53818 .58377 Mdot
.70307 .58689 Mdot
.55962 .40945 Mdot
.52229 .66526 Mdot
.58761 .50581 Mdot
.71375 .61649 Mdot
.5406 .66309 Mdot
.37821 .4307 Mdot
.56813 .56469 Mdot
.66049 .64736 Mdot
.41991 .62921 Mdot
.52609 .54763 Mdot
.58763 .58325 Mdot
.49765 .60552 Mdot
.50395 .58138 Mdot
.64242 .57519 Mdot
.51759 .52931 Mdot
.57294 .64467 Mdot
.63206 .55667 Mdot
.40659 .46046 Mdot
.61617 .42867 Mdot
.47034 .4026 Mdot
.53634 .26277 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Z?ooool8o`0009Wooooo
000Looooo`03o`000?oooooooooo0:Gooooo3Ol0002Gooooo`007?ooool00ol0003oooooooooo`2T
ooooo`oo0000U_ooool001cooooo00?o0000ooooooooool0XooooolBo`0009Cooooo000Looooo`03
o`000?oooooooooo0:;ooooo5?l0002Cooooo`007?ooool00ol0003oooooooooo`2RoooooaGo0000
T_ooool001cooooo00?o0000ooooooooool0X_ooool2o`000003ooooool0003o0000013o000000?o
ooooo`000?l00000Soooool001cooooo00?o0000ooooooooool0YOoooolGo`0000?ooooo1?l00026
ooooo`007?ooool00ol0003oooooooooo`26ooooo`?o00000_ooool2o`0001Wooooo8Ol00022oooo
o`007?ooool00ol0003oooooooooo`23ooooo`_o00004_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Oo`00087ooooo000Looooo`03o`000?oooooooooo083ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00Wo00003oooool3o`0000;ooooo0_l00003oooooaoo000000Coooooo`000?l0
003o0000OOooool001cooooo00?o0000ooooooooool0O_ooool4o`0000;ooooo0_l00002ooooo`?o
000000?oooooo`000?l000000_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o000000?o
oooo3?l000000ooooooo0000o`000004ooooo`[o0000OOooool001cooooo00?o0000ooooooooool0
O_ooool2o`0000Oooooo2Ol0000?ooooo`?o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;ooooo1?l000001?oooooo0000o`000?l0000:ooooo`Ko00000_ooool5o`0007co
oooo000Looooo`;o0000O_ooool5o`0000;ooooo3ol0000;ooooo`Co000000?oooooo`000?l00000
0_ooool2o`0000Gooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00001?oooolAo`0007[o
oooo000Looooo`03o`000?oooooooooo07gooooo1Ol000000ooooooo0000o`000009o`000003oooo
ool0003o000000;o00002oooool2o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo
4_l0001iooooo`007?ooool00ol0003oooooooooo`1moooooaKo00002_ooool2o`0001oooooo4ol0
001hooooo`007?ooool00ol0003oooooooooo`21oooooa;o00002Oooool3o`0000Oooooo0_l00007
ooooo`;o00003OoooolCo`0007Sooooo000Looooo`03o`000?oooooooooo07_ooooo0ol00002oooo
oaCo00002?ooool2o`0000Kooooo1?l000000ooooooo0000o`000004ooooo`;o00003_oooolBo`00
07Sooooo000Looooo`03o`000?oooooooooo07_ooooo0ol00002oooooaCo00001oooool4o`0000Go
oooo0_l00003ooooo`;o00003Oooool2o`0000Oooooo4?l0001hooooo`007?ooool00ol0003ooooo
ooooo`1ooooooaGo00001_ooool5o`0000Wooooo1?l0000<ooooo`;o00001_oooolAo`0007Sooooo
000Looooo`03o`000?oooooooooo07gooooo5ol00006ooooo`?o00001oooool2o`0000;ooooo1?l0
0009ooooo`Go00001?oooolFo`0007Gooooo000Looooo`03o`000?oooooooooo07gooooo5_l00007
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000Kooooo0_l00003
ooooo`So000000?oooooo`000?l000005?l0001eooooo`007?ooool00ol0003oooooooooo`1ooooo
oa?o00001oooool5o`000003ooooool0003o000000;o00000_ooool3o`0000Sooooo0_l00007oooo
o`Co00000_oooolFo`0007Cooooo000Looooo`03o`000?oooooooooo07kooooo4ol000000ooooooo
0000o`000004ooooo`?o00001Oooool2o`0000?ooooo0_l00008ooooo`;o00003ooooolEo`0007Co
oooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000001Gooooo5_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000gooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo5?l0001dooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`?o000000?oooooo`000?l000001ol0000CoooooaKo00000oooool3o`0000?ooooo0_l0
000>ooooo`?o000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l00003oooooaCo0000M?oo
ool001cooooo00?o0000ooooooooool0G?ooool5o`000003ooooool0003o000000Wo00004?oooolF
o`0000?ooooo0ol00005ooooo`;o00003Oooool3o`000003ooooool0003o000000?ooooo0ol00002
ooooo`;o00001?oooolDo`0007Cooooo000Looooo`03o`000?oooooooooo05Wooooo1Ol00002oooo
o`ko00003ooooolAo`000003ooooool0003o000000Gooooo0ol00005ooooo`;o00002oooool2o`00
00[ooooo0_l00002ooooo`;o00001OoooolBo`0007Gooooo000Looooo`03o`000?oooooooooo05So
oooo1Ol000000ooooooo0000o`00000@o`0000Wooooo0_l00003oooooa;o00002oooool2o`0000ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool<o`000003ooooool0003o000000?o
0000MOooool001cooooo0_l0001Hooooo`?o00000ooooolCo`0000Wooooo0_l00004oooooa7o0000
0_ooool4o`0000Cooooo0ol0000Booooo`Co000000?oooooo`000?l000003OoooolAo`0007Gooooo
000Looooo`03o`000?oooooooooo05Kooooo0ol00002oooooaGo00001_ooool2o`0000Oooooo3ol0
0003ooooo`Go00001?ooool2o`000003ooooool0003o0000013ooooo0ol00002ooooo`;o00003Ooo
ool@o`0007Kooooo000Looooo`03o`000?oooooooooo05Gooooo0ol00003ooooo`Oo000000?ooooo
o`000?l000003?l00005ooooo`;o00002?ooool6o`0000?ooooo0ol00002ooooo`Go00001_ooool2
o`0000;ooooo0_l00004ooooo`;o00003oooool2o`0000Wooooo0_l00002oooooa3o0000M_ooool0
01cooooo00?o0000ooooooooool0EOooool3o`0000?ooooo5ol0000?ooooo`Wo000000?oooooo`00
0?l000001Ol00007ooooo`;o00000_ooool2o`0000Cooooo1?l00004ooooo`;o00004_ooool2o`00
0003ooooool0003o000000oo0000M_ooool001cooooo00?o0000ooooooooool0EOooool2o`000003
ooooool0003o000001So00000oooool2o`0000[ooooo3_l0000;ooooo`;o00001oooool4o`0000Co
oooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool>o`00
07Kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002oooooa[o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`co00002oooool4o`0000;ooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00001_ooool2o`0000Kooooo0ol00003ooooo`;o00001_ooool<o`00
07Oooooo000Looooo`03o`000?oooooooooo05Cooooo1?l00003ooooo`Go000000?oooooo`000?l0
00004?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003?ooool2o`000003
ooooool0003o000000;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o
00003_ooool3o`0000_ooooo3?l0001gooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o0000
1?oooolGo`000003ooooool0003o000000kooooo0ol00003ooooo`;o00000oooool2o`0000Sooooo
0_l00002ooooo`So00000oooool4o`0000gooooo0ol000001?oooooo0000o`000?l00007ooooo`[o
0000N?ooool001cooooo00?o0000ooooooooool0Doooool2o`000003ooooool0003o000000Gooooo
5Ol0000Booooo`?o00002?ooool2o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0000;ooooo
1Ol0000=ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`Oo
0000N?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000Gooooo0_l00003oooooa?o0000
2Oooool2o`0000?ooooo0ol000000ooooooo0000o`000006ooooo`Co00000oooool2o`0000cooooo
0_l00004ooooo`;o00002Oooool2o`0000gooooo0_l00002ooooo`;o00001?ooool4o`0007[ooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00005ooooo`;o00001?oooolBo`0000Wooooo0_l0
0003ooooo`?o00002Oooool4o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l0
0007ooooo`;o00002Oooool4o`0000[ooooo1Ol000001?oooooo0000o`000?l0001eooooo`007?oo
ool00ol0003oooooooooo`1Booooo`Co00000oooool2o`0000?ooooo0_l00002oooooa3o00003Ooo
ool2o`0001Oooooo0_l00008ooooo`;o00001Oooool2o`0001;ooooo1?l00003ooooo`;o00002?oo
ool8o`000004ooooool0003o0000o`0006oooooo000Looooo`03o`000?oooooooooo05;ooooo1?l0
0003ooooo`;o00000oooool2o`000003ooooool0003o000000ko00003_ooool4o`0001Cooooo0_l0
0007ooooo`Co00008?ooool2o`0000Wooooo0_l00002ooooo`Oo0000Koooool001cooooo00?o0000
ooooooooool0Doooool3o`0000_ooooo4?l00009ooooo`?o00000_ooool5o`0000kooooo0_l00003
ooooo`;o00001Oooool5o`0001;ooooo0_l0000:ooooo`;o00000_ooool3o`000003ooooool0003o
000000;ooooo0_l00007ooooo`?o00001Oooool3o`0006Sooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`1Cooooo`Go00002oooool>o`0000?ooooo0_l00004ooooo`?o00000oooool4o`0000kooooo0_l0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`00
000:ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00003ooo
ool3o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Doooool5o`0000cooooo2?l000001?oooooo0000
o`000?l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Cooooo`Co00000oooool2o`00013ooooo0_l00003ooooo`;o00001oooool3o`0000So
oooo0ol0001Yooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go0000
1_ooool00ol0003oooooooooo`1Dooooo`Co00001Oooool2o`0000;ooooo0_l00003ooooo`Ko0000
00Coooooo`000?l0003o00002oooool2o`0000Kooooo0_l00005ooooo`Co00000_ooool2o`0000;o
oooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo1?l0000Hooooo`Co00000_ooool3o`0000;o
oooo0ol00006ooooo`[o0000I?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000EOooool5o`0000?ooooo0_l00002ooooo`;o
00001Oooool5o`0000gooooo0ol0000>ooooo`?o00001_ooool3o`0000Sooooo0_l00005ooooo`;o
00000oooool2o`0001[ooooo1?l00002ooooo`So00001_ooool;o`0006?ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`1Eooooo`Go00003oooool4o`0000gooooo0ol000000ooooooo0000o`00000:ooooo`;o
00002Oooool2o`00013ooooo0_l00002ooooo`;o00005?ooool2o`000004ooooool0003o0000o`00
00Oooooo1?l000000ooooooo0000o`000004ooooo`go0000Hoooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo05Go
oooo0ol0000Cooooo`;o00004Oooool2o`0000[ooooo0_l0000Kooooo`;o00002Oooool2o`0000;o
oooo0_l00007ooooo`So00004_ooool=o`0006?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Fooooo`;o00004oooool2o`00
01?ooooo0_l0000=ooooo`;o00004_ooool2o`0000Sooooo0_l00003ooooo`?o000000?oooooo`00
0?l000001oooool5o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo3ol0001Qoooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0E_ooool4o`0000Wooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l0
0004ooooo`;o00001oooool2o`000003ooooool0003o000000[ooooo0_l0000Booooo`;o00002?oo
ool2o`0000Cooooo0_l0000Cooooo`Co00001?ooool2o`0000?ooooo0_l00002ooooo`oo0000HOoo
ool001cooooo00?o0000ooooooooool0F?ooool6o`0000Gooooo1Ol000000ooooooo0000o`000002
o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Co0000
8?ooool3o`0000Sooooo1?l0000=ooooo`;o00001Oooool2o`0000gooooo3ol0001Qooooo`007?oo
ool00ol0003oooooooooo`1Jooooo`Co00001_ooool6o`0000[ooooo0_l0000?ooooo`;o00004ooo
ool2o`0000_ooooo0ol00008ooooo`Co00002Oooool2o`0000;ooooo0_l00006ooooo`;o00001ooo
oolDo`00067ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?l000001?oooooo0000o`000?l0000Aooooo`;o00001?ooool2o`0000Wooooo0_l0
0008ooooo`;o00000oooool2o`0001kooooo0_l0000:ooooo`Co00001Oooool5o`000003ooooool0
003o000000co0000HOooool001cooooo00?o0000ooooooooool0G?ooool3o`0000;ooooo1ol00002
ooooo`So00001Oooool2o`0000Kooooo0_l00004ooooo`;o00002Oooool2o`0000gooooo0_l00009
ooooo`;o00008Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000<o`00067ooooo000Loooo
o`03o`000?oooooooooo05cooooo0ol00004ooooo`;o00000_ooool;o`0000?ooooo1?l0000<oooo
o`;o00001_ooool4o`0000kooooo0_l00002ooooo`?o00001?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00001Oooool2o`0000[ooooo4Ol0001Qooooo`007?ooool00ol0003o
ooooooooo`1Qooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co
00005?ooool4o`0000kooooo0_l000000ooooooo0000o`000002o`0000cooooo1Ol00004ooooo`Co
00000oooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`00
00;ooooo4?l0001Qooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000_ooool4o`0000Ko
oooo0_l0000aooooo`;o00004?ooool2o`0000Gooooo1?l00003ooooo`;o00000_ooool4o`0000;o
oooo0_l00002ooooo`;o00000_ooool3o`0000Cooooo3Ol0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`Go000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`;o0000
1_ooool2o`0000Sooooo0_l0000Vooooo`;o00004oooool3o`000003ooooool0003o000000Oooooo
1?l000000ooooooo0000o`000003ooooo`_o0000HOooool001cooooo00?o0000ooooooooool0H_oo
ool:o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo
0_l0000@ooooo`;o00002Oooool2o`0000Gooooo0_l00004ooooo`?o00000oooool2o`0000;ooooo
1ol00003ooooo`_o0000HOooool001cooooo00?o0000ooooooooool0Ioooool5o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Gooooo1?l00006ooooo`;o00001?oo
ool3o`0000;ooooo0_l00006ooooo`;o00006Oooool4o`000003ooooool0003o000000Co00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000005o`0000;ooooo3?l0001Rooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`;o00004?ooool2o`0000kooooo0_l000000ooooooo0000o`000004
ooooo`;o00003_ooool2o`0001Kooooo0ol00002ooooo`Co00001_ooool2o`0000Oooooo0ol00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo0000H_ooool001cooooo0_l0001Xoooo
o`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2o`0001Kooooo0ol00003oooo
o`;o00000oooool2o`0001?ooooo0_l00003ooooo`Go0000IOooool001cooooo00?o0000oooooooo
ool0Ioooool3o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00009ooooo`?o
00001_ooool3o`000004ooooool0003o0000ooooo`;o00003?ooool2o`00027ooooo0_l00002oooo
o`?o00004oooool2o`0000?ooooo1Ol0001Uooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o0000
00?ooooo0ol000001?oooooo0000o`000?ooool2o`0002oooooo0_l00002ooooo`?o00004_ooool2
o`000003ooooool0003o000000?ooooo1Ol0001Sooooo`007?ooool00ol0003oooooooooo`1Yoooo
o`;o000000?oooooo`000?l000000ol0000?ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000;ooooo0_l0000dooooo`;o00002_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000003ooooo`Ko0000H_ooool001cooooo00?o0000ooooooooool0K?ooool5o`0000oo
oooo0_l00007ooooo`;o00001Oooool3o`0001oooooo0_l0000Booooo`;o00002?ooool4o`0000oo
oooo1Ol0001Qooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00002?ooool2o`0001Wooooo
0_l00006ooooo`;o00001Oooool2o`00013ooooo0_l0000Looooo`;o00001Oooool2o`0000Kooooo
2Ol0001Qooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co00001_ooool2o`0000kooooo0_l0
000;ooooo`;o00001?ooool2o`0000Gooooo0_l0000Booooo`;o00001_ooool2o`0000Sooooo0_l0
0007ooooo`Co00000_ooool6o`0000?ooooo1Ol00002ooooo`Co0000H?ooool001cooooo00?o0000
ooooooooool0K_ooool3o`0000gooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l0000L
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0ol00006ooooo`Co00000_ooool6
o`0000?ooooo1Ol00002ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0Koooool2o`00
00gooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00006oooool2o`00
017ooooo1Ol0000Cooooo`Oo00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo07Ko
oooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo0ol000000ooooooo0000o`000007ooooo`;o
00009Oooool4o`0000oooooo0_l000000ooooooo0000o`000002o`0000;ooooo1_l000000ooooooo
0000o`000003o`0005gooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00002ooooo`;o0000
1_ooool2o`00017ooooo0_l0000:ooooo`;o00000_ooool2o`0001oooooo1?l00007ooooo`;o0000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000?o0000
GOooool001cooooo00?o0000ooooooooool0L_ooool2o`0000;ooooo0_l0000Yooooo`;o00007ooo
ool4o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Cooooo2_l0
0002ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0JOooool4o`0001Cooooo0_l00004
ooooo`;o00002?ooool2o`00037ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo1?l00000
1?oooooo0000o`000?ooool:o`0000;ooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`1Y
ooooo`Co00001_ooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000Sooooo0_l0000m
ooooo`;o00000oooool7o`000003ooooool0003o000000So00001?ooool2o`0005cooooo000Loooo
o`03o`000?oooooooooo06Kooooo2_l00003ooooo`Ko00004oooool2o`0002[ooooo0_l0000Foooo
o`;o00000_ooool4o`000003ooooool0003o000000;ooooo4Ol0001Kooooo`007?ooool00ol0003o
ooooooooo`1Vooooo`[o00001?ooool3o`0001;ooooo0_l000000ooooooo0000o`000002o`0001go
oooo1?l00007ooooo`;o00005Oooool3o`0000;ooooo0_l00007oooooa7o0000Foooool001cooooo
0_l0001Uooooo`;o000000?oooooo`000?l000001ol00004ooooo`;o00001_ooool2o`0000_ooooo
0_l00003ooooo`;o00001?ooool2o`0001Oooooo1?l00003ooooo`;o00006Oooool3o`0000Kooooo
0_l00003ooooo`co00000_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo06Cooooo3_l0
0004ooooo`;o00001?ooool2o`0001Kooooo0_l0000Nooooo`;o00008_ooool4o`000003ooooool0
003o000000[o00000_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo06Cooooo3ol00000
0ooooooo0000o`000002o`0000kooooo1?l0000aooooo`;o00007Oooool2o`000003ooooool0003o
000000Wo000000?oooooo`000?l000000ol0001Kooooo`007?ooool00ol0003oooooooooo`1Soooo
o`Ko000000?oooooo`000?l000002_l00003ooooo`;o00002oooool4o`0002kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00002?ooool2o`0000Oooooo4?l0001Looooo`007?ooool00ol0003o
ooooooooo`1Soooooa?o00000oooool2o`0000;ooooo0_l0000Fooooo`;o00008Oooool2o`0000?o
oooo0_l0000;ooooo`;o00001_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000;o`000003
ooooool0003o000005cooooo000Looooo`03o`000?oooooooooo06Cooooo4_l00007ooooo`;o0000
1?ooool2o`0000cooooo0_l00002ooooo`;o00006?ooool2o`0000cooooo1?l0000Aooooo`;o0000
1_ooool2o`0000;ooooo3Ol000000ooooooo0000o`00001Kooooo`007?ooool00ol0003ooooooooo
o`1RoooooaCo00002Oooool2o`0000;ooooo0_l0000<ooooo`;o00007?ooool2o`000003ooooool0
003o000000[ooooo0ol0000Fooooo`;o00001?oooolAo`0005_ooooo000Looooo`03o`000?oooooo
oooo06;ooooo5Ol00003ooooo`;o00000oooool2o`00023ooooo0_l0000?ooooo`;o00001oooool2
o`000003ooooool0003o000001Oooooo0_l000001?oooooo0000o`000?oooolAo`0005_ooooo000L
ooooo`03o`000?oooooooooo06?ooooo5?l00003ooooo`;o000000?oooooo`000?l000001_ooool2
o`0001[ooooo0_l0000Hooooo`Co00001?ooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool2
o`000003ooooool0003o000000[o00000_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo
06;ooooo4_l00006ooooo`Go00001_ooool2o`0001gooooo0_l0000Dooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0000Kooooo0_l00009ooooo`?o00001?ooool<o`0000;ooooo0ol0001K
ooooo`007?ooool00ol0003oooooooooo`1RoooooaCo00001Oooool2o`0001Gooooo0_l0000@oooo
o`;o00003?ooool2o`0000Kooooo0_l00002ooooo`;o00005Oooool4o`0000Cooooo3?l00003oooo
o`;o0000Foooool001cooooo00?o0000ooooooooool0H_oooolDo`0001Kooooo0_l00004ooooo`;o
00007_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool3o`0000Cooooo1?l00003ooooo`Co
00001Oooool:o`0000Cooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1RoooooaCo0000
5_ooool2o`0001Sooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool5o`000003oooo
ool0003o000000;ooooo0ol00004ooooo`Co00003?ooool:o`0000Cooooo0_l0001Kooooo`007?oo
ool00ol0003oooooooooo`1RoooooaGo00004Oooool2o`0001cooooo0_l0000;ooooo`;o00002?oo
ool5o`0000Cooooo1?l0000?ooooo`;o00001?ooool7o`000003ooooool0003o000000;ooooo0ol0
001Kooooo`007?ooool00ol0003oooooooooo`1Roooooa;o000000?oooooo`000?l000002oooool2
o`000004ooooool0003o0000ooooo`;o00000oooool2o`0002Cooooo0_l00006ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Wooooo1?l00003ooooo`Co0000
00?oooooo`000?l000000_l00002ooooo`?o0000Foooool001cooooo00?o0000ooooooooool0Hooo
ool?o`00013ooooo0_l000000ooooooo0000o`000004ooooo`Co00005?ooool2o`0000;ooooo0_l0
000Booooo`;o00001_ooool4o`0000Oooooo0_l00002ooooo`;o00001oooool3o`0000;ooooo1ol0
0004ooooo`?o0000Foooool001cooooo0_l0001Tooooo`ko00006_ooool2o`0001Kooooo0_l00002
ooooo`;o00004?ooool2o`0000[ooooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0ol00004
ooooo`_o0000G?ooool001cooooo00?o0000ooooooooool0I?ooool=o`0000?ooooo1?l00003oooo
o`;o00001?ooool2o`0001oooooo0_l0000Eooooo`;o00001?ooool2o`0000Kooooo0_l00008oooo
o`;o00000_ooool4o`0000[ooooo2Ol0001Mooooo`007?ooool00ol0003oooooooooo`1Sooooo`go
00001?ooool4o`0000?ooooo0_l00004ooooo`;o00004oooool2o`0000[ooooo0_l0000:ooooo`;o
00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0000[ooooo1ol0001Nooooo`007?ooool00ol0003oooooooooo`1Sooooo`go
00001_ooool2o`0000gooooo0_l00008ooooo`;o00001Oooool2o`0001Kooooo0_l0000@ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1Sooooo`?o00000_ooool8o`0000Kooooo0_l00009ooooo`;o
00000_ooool2o`0000Sooooo0_l0000]ooooo`Co00001Oooool2o`0000Cooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_ooool3o`0006cooooo000Looooo`03o`000?oooooooooo06?ooooo
1?l00002ooooo`Go00004oooool2o`0003;ooooo1?l00005ooooo`;o00004oooool5o`0000;ooooo
0ol0001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00000_ooool3o`0000Wooooo0_l0
000nooooo`Co00002oooool2o`0000Sooooo0_l00004ooooo`Ko00001Oooool2o`0006Sooooo000L
ooooo`03o`000?oooooooooo06;ooooo1_l00008ooooo`;o00000oooool2o`00013ooooo0_l0000E
ooooo`;o00009?ooool2o`0000Sooooo0_l00008ooooo`;o00001Oooool2o`0006Sooooo000Loooo
o`03o`000?oooooooooo067ooooo1ol00005ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00Sooooo0_l00003ooooo`;o000000?oooooo`000?l000005Oooool2o`0000[ooooo0_l00002oooo
o`;o00006oooool4o`0000Gooooo0ol00005ooooo`;o0000Joooool001cooooo00?o0000oooooooo
ool0Goooool9o`0000?ooooo1?l00005ooooo`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o
00002oooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000Jooooo`Go00000oooool7o`0000?ooooo0_l0001[ooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`Wo00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo1Ol00004oooo
o`;o00007Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`000?l0
00001ol00009ooooo`;o00000_ooool2o`00013ooooo0_l0000Dooooo`Go00001?ooool2o`0000;o
oooo0_l0000<ooooo`Co00002Oooool2o`0000Kooooo0ol00004ooooo`;o00000_ooool4o`000003
ooooool0003o000006Wooooo000Looooo`03o`000?oooooooooo05gooooo2Ol000000ooooooo0000
o`000009ooooo`;o00004Oooool2o`0000Oooooo0_l0000>ooooo`;o00002oooool2o`0000;ooooo
1?l00006ooooo`Co000000?oooooo`000?l000003_ooool3o`0000Cooooo0_l000000ooooooo0000
o`000003o`000003ooooool0003o000000?o0000I_ooool001cooooo00?o0000ooooooooool0Fooo
ool>o`0000gooooo0_l0000=ooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Gooooo1?l00006ooooo`;o00000oooool3o`0000_ooooo0_l0
000:ooooo`Go00000_ooool4o`000003ooooool0003o000006?ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`1Jooooo`oo00002_ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`?o
00000_ooool2o`00017ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`?o
00001?ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool;o`0000?ooooo0_l000000ooooooo
0000o`00001Sooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0F_ooool@o`0000Wooooo0_l00009
ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0001Oooooo0_l00004
ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`;o00000_oooolAo`0006Kooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo05Wooooo4ol00002ooooo`;o00003?ooool4o`0000;ooooo0_l00008
ooooo`;o00001Oooool2o`0002Cooooo1?l00007ooooo`?o00001oooool3o`000003ooooool0003o
000000?ooooo2ol0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0005Sooooo5?l000001Ooooooo0000o`000?l0
003ooooo00;o00000oooool2o`0000Cooooo0_l0000>ooooo`;o0000:oooool4o`0000Oooooo0ol0
0002ooooo`;o00001?ooool5o`0000;ooooo3_l0001Uooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`1Goooooa?o00000oooool2o`000004ooooool0003o0000o`0000?ooooo1?l00007ooooo`;o0000
6oooool2o`0000Oooooo0_l0000Iooooo`;o00001Oooool2o`0000Gooooo0ol00002ooooo`oo0000
IOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo05Oooooo4ol00006ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Oooooo0_l0000Iooooo`Co00001oooool2o`0000cooooo0_l000001?oooooo0000o`00
0?l00007ooooo`;o00003?ooool3o`000003ooooool0003o000000oo0000I?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05Ko
oooo5Ol00006ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l00008ooooo`;o
00001?ooool3o`00013ooooo0_l000000ooooooo0000o`000002ooooo`Ko00001oooool2o`0000Wo
oooo0_l000001?oooooo0000o`000?oooolCo`0006?ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1FoooooaGo00001Ooo
ool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo0_l0
0004ooooo`Co00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`?o00002?oo
ool3o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo4ol0001Sooooo`007?oo
ool00ol0003oooooooooo`1FoooooaCo00000oooool7o`0000Cooooo0ol0000:ooooo`Co00002ooo
ool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o00002Ooo
ool3o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo5?l0001Sooooo`007?oo
ool00ol0003oooooooooo`1FoooooaCo000000?oooooo`000?l000001?l000000ooooooo0000o`00
0002ooooo`Go00002_ooool4o`0000Wooooo1?l00003ooooo`;o00001Oooool2o`000003ooooool0
003o000000Sooooo0_l00007ooooo`;o00003Oooool4o`0000?ooooo1Ol000000ooooooo0000o`00
000Bo`0006?ooooo000Looooo`03o`000?oooooooooo05Gooooo5Ol000000ooooooo0000o`000009
ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool3o`0000Gooooo0_l00005
ooooo`;o00005?ooool2o`0000gooooo1?l00005ooooo`;o000000?oooooo`000?l000004Ol00000
0ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`1EoooooaGo00001_ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0000@
ooooo`;o00003?ooool2o`00013ooooo0_l0000<oooooa?o000000?oooooo`000?l00000H_ooool0
01cooooo00?o0000ooooooooool0E_ooool5o`000003ooooool0003o000000co00001?ooool5o`00
00Cooooo0_l00002ooooo`;o00002?ooool2o`0001_ooooo0ol00009ooooo`;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l00002ooooo`go000000?oooooo`000?l000000ol0001Uooooo`007?ooool00ol0
003oooooooooo`1Fooooo`?o00000oooool<o`0000Kooooo0_l000000ooooooo0000o`000002o`00
00_ooooo0_l00003ooooo`;o00004Oooool2o`0000Sooooo0ol000000ooooooo0000o`000006oooo
o`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`00000@o`0000;ooooo0_l0001Sooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`?o00001Oooool;o`000003ooooool0003o000000?ooooo1?l000000ooooooo
0000o`00000;ooooo`Co00000_ooool2o`0000Kooooo0_l00008ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`;o00002oooool3o`0000?ooooo0_l00003ooooo`;o00003?ooool3o`00
0003ooooool0003o000000;o000000?oooooo`000?l000003ol0001Sooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`Co00000_ooool4o`000003ooooool0003o000000Go00000_ooool2o`0000Go
oooo0_l0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool4o`0000[o
oooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l0
00005?l0001Sooooo`007?ooool00ol0003oooooooooo`1Eooooo`Go000000Coooooo`000?l0003o
00001_ooool3o`0000cooooo0_l0000Nooooo`;o000000?oooooo`000?l000001_ooool3o`000003
ooooool0003o000000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000005Oooool3o`0000?o
oooo4_l0001Wooooo`007?ooool00ol0003oooooooooo`1Eooooo`Go00000_ooool2o`0000Oooooo
0_l00004ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000:ooooo`;o00001oooool3o`0000;ooooo
0_l000000ooooooo0000o`000003o`00017ooooo0ol00005ooooo`;o000000?oooooo`000?l00000
2_l00002ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0EOooool4o`000003ooooool0
003o000000Wooooo0_l00004ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo1?l0000;ooooo`;o00002oooool2o`0000Oooooo1_l0
0006ooooo`;o00000_ooool4o`000003ooooool0003o000000Kooooo3ol000001?oooooo0000o`00
0?l0001Uooooo`007?ooool2o`0005Oooooo1_l00009ooooo`;o00002Oooool2o`0001?ooooo1?l0
0008ooooo`;o000000?oooooo`000?l000001Oooool5o`0000_ooooo0_l00007ooooo`Oo00000_oo
ool;o`0000Wooooo3?l00002ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0E_ooool5
o`0000[ooooo0_l00009ooooo`;o00001?ooool2o`0001Gooooo0_l00005ooooo`Co00000oooool3
o`0000gooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000[o000000Cooooo
o`000?l0003ooooo0ol00006ooooo`Go00000_ooool4o`000004ooooool0003o0000o`0006Sooooo
000Looooo`03o`000?oooooooooo05Kooooo1_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0
0005ooooo`;o00001?ooool2o`0000gooooo1?l00003ooooo`Ko00003oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo3?l00002ooooo`Co0000
1oooool<o`0006Wooooo000Looooo`03o`000?oooooooooo05Oooooo1Ol00002ooooo`Go00003?oo
ool2o`0000_ooooo0_l00003ooooo`;o00002?ooool3o`0000;ooooo1?l00005ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`Co00000oooool2o`0000Oooooo4?l00004ooooo`;o00002?oo
ool6o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00000
0ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000000oooool2o`0000_ooooo0_l00009
ooooo`;o00003Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00004
ooooo`;o000000?oooooo`000?l000002?ooool6o`000003ooooool0003o000000Wo000000?ooooo
o`000?l00000O_ooool001cooooo00?o0000ooooooooool0F?ooool5o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000>
ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000004
ooooo`;o00001_oooolDo`000004ooooool0003o0000o`0007gooooo000Looooo`03o`000?oooooo
oooo05Sooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000000_l0000=ooooo`;o00000_ooool3o`0000_ooooo0ol0000;oooooaCo00000_ooool2
o`0007gooooo000Looooo`03o`000?oooooooooo05cooooo3ol000000ooooooo0000o`000002o`00
00;ooooo0_l00002ooooo`;o00002oooool6o`0000_ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000Wooooo5_l00021ooooo`007?ooool00ol0003oooooooooo`1Loooooaco
00002oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003_ooool2o`0000[o
oooo0_l00007oooooaSo000000?oooooo`000?l00000O_ooool001cooooo00?o0000ooooooooool0
HOooool2o`000003ooooool0003o000001Co00003?ooool4o`000003ooooool0003o000000Cooooo
0_l00005ooooo`;o00000_ooool4o`0000Kooooo1?l000000ooooooo0000o`000003oooooaOo0000
0_ooool2o`0007kooooo000Looooo`03o`000?oooooooooo06Kooooo1?l00005ooooo`;o000000?o
ooooo`000?l000002_l0000=ooooo`;o00001?ooool3o`0000;ooooo1Ol000000ooooooo0000o`00
0002o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo5_l0
0002ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0L_ooool>o`0000_ooooo0_l00005
ooooo`;o00000_ooool5o`0000Kooooo1?l0000<oooooaKo000000?oooooo`000?l00000Ooooool0
01cooooo00?o0000ooooooooool0M?ooool>o`0000Sooooo0_l00008ooooo`Co000000?oooooo`00
0?l000000_ooool;o`0000?ooooo0_l00004oooooaWo0000Ooooool001cooooo00?o0000oooooooo
ool0M_ooool<o`000004ooooool0003o0000o`0000;ooooo1?l00003ooooo`;o00000oooool4o`00
0003ooooool0003o000000;ooooo2ol00003ooooo`;o000000?oooooo`000?l000006_l0001ooooo
o`007?ooool00ol0003oooooooooo`1fooooo`co000000Coooooo`000?l0003o00000_ooool2o`00
00Gooooo0_l00005ooooo`;o00003Oooool3o`000003ooooool0003o000000?ooooo0ol000000ooo
oooo0000o`00000>o`0000Cooooo0ol00020ooooo`007?ooool00ol0003oooooooooo`1foooooa3o
00000_ooool4o`0000Kooooo0ol00009ooooo`Go00000oooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`00000Ao`000004ooooool0003o0000o`00087ooooo000Looooo`;o
0000MooooolFo`0000Cooooo1Ol00003ooooo`go000000?oooooo`000?l000000_l00007oooooaOo
0000POooool001cooooo00?o0000ooooooooool0M_oooolCo`0000Oooooo0_l00005ooooo`ko0000
00?oooooo`000?l000000_l00008ooooo`oo00000_ooool3o`0008?ooooo000Looooo`03o`000?oo
oooooooo07Kooooo5?l0000;oooooa3o000000?oooooo`000?l000000ol00007ooooo`_o00000ooo
ool5o`0008Cooooo000Looooo`03o`000?oooooooooo07Kooooo5?l0000:oooooa7o000000?ooooo
o`000?l000000ol00008ooooo`[o00000oooool4o`0008Gooooo000Looooo`03o`000?oooooooooo
07Oooooo5?l00007oooooaWo00002oooool9o`000003ooooool0003o000000;o0000QOooool001co
oooo00?o0000ooooooooool0MooooolDo`0000Oooooo5_l000000ooooooo0000o`00000;ooooo`Wo
0000R_ooool001cooooo00?o0000ooooooooool0MooooolAo`0000[ooooo5ol0000?ooooo`Oo0000
R_ooool001cooooo00?o0000ooooooooool0NOooool?o`0000Wooooo6?l0002Pooooo`007?ooool0
0ol0003oooooooooo`1iooooo`oo00002OoooolDo`000:Cooooo000Looooo`03o`000?oooooooooo
07cooooo1ol000001?oooooo0000o`000?l00009ooooo`?o00000_ooool@o`000:Cooooo000Loooo
o`03o`000?oooooooooo083ooooo0ol0000=ooooo`?o00000_ooool>o`0000;ooooo0_l0002Roooo
o`007?ooool00ol0003oooooooooo`2@ooooo`Co000000?oooooo`000?l000002_l00004ooooo`;o
0000X_ooool001cooooo00?o0000ooooooooool0T_ooool5o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003o0000Z?ooool001cooooo00?o0000ooooooooool0T_ooool3o`0000?ooooo
1Ol000001?oooooo0000o`000?l0002Xooooo`007?ooool00ol0003oooooooooo`2Fooooo`?o0000
1Oooool2o`000:Wooooo000Looooo`03o`000?oooooooooo09Kooooo0ol0002`ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood[ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom:ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000B
ooooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Wooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^09Cooooo002Zooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0U?ooool00:[ooooo00Go0000ooooooooooooooooo`00
000Hooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@09Co
oooo002Zooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool00000U?ooool00:[ooooo00Go0000ohN7
QoooooooZJVYo`00000Hooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooo
oooooooo000009Cooooo002Yooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_oo
ool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@4100U?ooool00<Oooooo00?o
gMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg09Cooooo0038ooooo`04olc<c?m4
A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Dooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(204) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45522 .36182 Mdot
.40637 .34854 Mdot
.367 .69729 Mdot
.57146 .43759 Mdot
.58529 .66296 Mdot
.35568 .67353 Mdot
.28018 .50615 Mdot
.28963 .49572 Mdot
.41466 .65133 Mdot
.61385 .3175 Mdot
.31541 .50412 Mdot
.56365 .45313 Mdot
.29199 .50892 Mdot
.59529 .43373 Mdot
.64299 .58767 Mdot
.67446 .38371 Mdot
.41938 .33062 Mdot
.59139 .72859 Mdot
.68006 .38125 Mdot
.41743 .63908 Mdot
.56156 .64153 Mdot
.60972 .42563 Mdot
.37313 .35665 Mdot
.59559 .43143 Mdot
.67227 .3755 Mdot
.3983 .35182 Mdot
.45471 .36064 Mdot
.68825 .35848 Mdot
.56553 .42367 Mdot
.28653 .47942 Mdot
.68796 .35015 Mdot
.727 .64783 Mdot
.52501 .58882 Mdot
.56012 .29023 Mdot
.26948 .48407 Mdot
.33141 .53956 Mdot
.38166 .68359 Mdot
.27297 .47912 Mdot
.317 .5347 Mdot
.30632 .49818 Mdot
.29972 .49201 Mdot
.39245 .34832 Mdot
.2605 .48612 Mdot
.18174 .56569 Mdot
.59031 .42478 Mdot
.55691 .20028 Mdot
.33862 .69876 Mdot
.5718 .4565 Mdot
.36903 .35172 Mdot
.41126 .68002 Mdot
.65893 .66379 Mdot
.30492 .50718 Mdot
.54584 .57639 Mdot
.50732 .14982 Mdot
.28829 .50077 Mdot
.67405 .37871 Mdot
.36875 .64995 Mdot
.5968 .40478 Mdot
.58731 .46934 Mdot
.55004 .25908 Mdot
.59295 .39961 Mdot
.60768 .68029 Mdot
.46828 .38317 Mdot
.38211 .70541 Mdot
.4129 .66271 Mdot
.26445 .48067 Mdot
.43529 .33278 Mdot
.26584 .51322 Mdot
.57094 .44163 Mdot
.40634 .63309 Mdot
.58353 .39002 Mdot
.31498 .50318 Mdot
.44728 .34737 Mdot
.61574 .43172 Mdot
.4671 .35195 Mdot
.32939 .50727 Mdot
.57063 .69429 Mdot
.39759 .37592 Mdot
.39874 .70158 Mdot
.63969 .54239 Mdot
.6153 .42748 Mdot
.18447 .40678 Mdot
.69858 .59625 Mdot
.43157 .36439 Mdot
.6356 .4028 Mdot
.23365 .34546 Mdot
.59816 .37814 Mdot
.66969 .36593 Mdot
.68168 .36165 Mdot
.58908 .5357 Mdot
.36751 .64711 Mdot
.37292 .34777 Mdot
.60817 .4194 Mdot
.58321 .45503 Mdot
.60949 .31212 Mdot
.58529 .39311 Mdot
.67674 .36764 Mdot
.55448 .60974 Mdot
.3118 .51722 Mdot
.54644 .59787 Mdot
.3399 .57184 Mdot
.5339 .58365 Mdot
.59155 .38329 Mdot
.36831 .67263 Mdot
.45544 .3441 Mdot
.53043 .5922 Mdot
.2636 .5021 Mdot
.60475 .42225 Mdot
.33578 .47398 Mdot
.37449 .35644 Mdot
.69648 .35974 Mdot
.59267 .68565 Mdot
.47422 .60629 Mdot
.44369 .34821 Mdot
.65092 .24879 Mdot
.58111 .44394 Mdot
.61966 .40839 Mdot
.40162 .34684 Mdot
.41869 .6298 Mdot
.22409 .54861 Mdot
.41207 .33514 Mdot
.31426 .51463 Mdot
.41489 .32896 Mdot
.5339 .60338 Mdot
.41981 .6356 Mdot
.54892 .55311 Mdot
.56666 .60416 Mdot
.70258 .66231 Mdot
.57053 .42039 Mdot
.57795 .59598 Mdot
.37265 .67652 Mdot
.41278 .33696 Mdot
.29709 .51763 Mdot
.6299 .4383 Mdot
.4143 .36331 Mdot
.28018 .50023 Mdot
.59418 .71952 Mdot
.60637 .72716 Mdot
.43984 .35726 Mdot
.64067 .24586 Mdot
.25135 .49342 Mdot
.27722 .53171 Mdot
.65777 .66117 Mdot
.43418 .3622 Mdot
.60796 .70475 Mdot
.26874 .51164 Mdot
.39298 .7823 Mdot
.69015 .3691 Mdot
.68166 .68383 Mdot
.18737 .41016 Mdot
.65756 .66226 Mdot
.55584 .63656 Mdot
.60213 .69443 Mdot
.28024 .49962 Mdot
.60795 .45282 Mdot
.42912 .3534 Mdot
.41238 .36144 Mdot
.56709 .40675 Mdot
.52676 .58365 Mdot
.58118 .43266 Mdot
.5497 .6013 Mdot
.56994 .60049 Mdot
.60141 .42202 Mdot
.54483 .19759 Mdot
.41043 .36677 Mdot
.6376 .40953 Mdot
.39095 .67676 Mdot
.56404 .5425 Mdot
.25736 .49317 Mdot
.63361 .41487 Mdot
.64077 .40134 Mdot
.56198 .4516 Mdot
.27989 .53411 Mdot
.31846 .39552 Mdot
.38126 .71278 Mdot
.31995 .51712 Mdot
.33827 .57265 Mdot
.38717 .66385 Mdot
.58743 .46771 Mdot
.59008 .69192 Mdot
.55574 .57977 Mdot
.60689 .45038 Mdot
.65824 .66542 Mdot
.59698 .46532 Mdot
.48775 .59792 Mdot
.49467 .59727 Mdot
.20985 .38335 Mdot
.32432 .39118 Mdot
.58201 .44965 Mdot
.65972 .39538 Mdot
.6733 .67177 Mdot
.21668 .50392 Mdot
.29567 .52134 Mdot
.38038 .62867 Mdot
.4149 .62625 Mdot
.32199 .59596 Mdot
.63448 .26867 Mdot
.69285 .31466 Mdot
.61808 .39842 Mdot
.54088 .58509 Mdot
.44322 .39274 Mdot
.60353 .69347 Mdot
.43604 .34466 Mdot
.18263 .40973 Mdot
.69115 .51703 Mdot
.70446 .34226 Mdot
.33237 .73973 Mdot
.39968 .69034 Mdot
.53101 .57757 Mdot
.59849 .71054 Mdot
.58687 .41347 Mdot
.39929 .3668 Mdot
.66758 .66701 Mdot
.52482 .56867 Mdot
.83329 .60515 Mdot
.41727 .33366 Mdot
.70656 .54223 Mdot
.28735 .50332 Mdot
.39152 .64511 Mdot
.59894 .37807 Mdot
.60078 .44088 Mdot
.36166 .33694 Mdot
.60594 .4565 Mdot
.69109 .3444 Mdot
.68707 .36821 Mdot
.41772 .67036 Mdot
.34383 .56742 Mdot
.31621 .52989 Mdot
.36473 .73367 Mdot
.44495 .34978 Mdot
.54395 .18076 Mdot
.37451 .66048 Mdot
.51142 .61709 Mdot
.30913 .49588 Mdot
.59925 .72171 Mdot
.3683 .66432 Mdot
.58855 .66188 Mdot
.59102 .46955 Mdot
.39831 .66176 Mdot
.5978 .67857 Mdot
.55235 .39402 Mdot
.5317 .59273 Mdot
.6605 .75141 Mdot
.27587 .50986 Mdot
.37154 .33109 Mdot
.60861 .45001 Mdot
.54967 .58142 Mdot
.52659 .5617 Mdot
.65568 .56432 Mdot
.5673 .57782 Mdot
.52701 .56897 Mdot
.62082 .56273 Mdot
.58829 .72331 Mdot
.2956 .32864 Mdot
.69188 .34906 Mdot
.42359 .33175 Mdot
.58967 .45661 Mdot
.33998 .55585 Mdot
.27761 .50107 Mdot
.58693 .40942 Mdot
.19908 .38973 Mdot
.27459 .51625 Mdot
.60904 .4065 Mdot
.32377 .52335 Mdot
.42183 .36519 Mdot
.70213 .51489 Mdot
.44905 .34647 Mdot
.60228 .41892 Mdot
.32355 .51876 Mdot
.37343 .63194 Mdot
.40063 .35349 Mdot
.60761 .42295 Mdot
.59005 .39655 Mdot
.54222 .58227 Mdot
.68735 .36928 Mdot
.24864 .54901 Mdot
.56108 .43868 Mdot
.35013 .689 Mdot
.57293 .40526 Mdot
.61566 .72456 Mdot
.47826 .80415 Mdot
.43794 .36086 Mdot
.56607 .57304 Mdot
.36653 .65797 Mdot
.61389 .36203 Mdot
.71333 .52875 Mdot
.59114 .42735 Mdot
.54318 .55816 Mdot
.71437 .56987 Mdot
.2905 .53092 Mdot
.69909 .34996 Mdot
.53591 .53111 Mdot
.36361 .65274 Mdot
.5355 .58299 Mdot
.62251 .39213 Mdot
.38584 .36602 Mdot
.67346 .38156 Mdot
.39311 .65662 Mdot
.40656 .33017 Mdot
.60542 .38062 Mdot
.31456 .56943 Mdot
.55948 .54663 Mdot
.29717 .53205 Mdot
.68823 .35374 Mdot
.58674 .4671 Mdot
.40817 .63569 Mdot
.39013 .34858 Mdot
.28914 .49822 Mdot
.4475 .35029 Mdot
.61701 .61449 Mdot
.70651 .55291 Mdot
.44155 .3305 Mdot
.58232 .70944 Mdot
.42224 .8204 Mdot
.31683 .51528 Mdot
.5604 .589 Mdot
.33873 .67803 Mdot
.39263 .37039 Mdot
.36411 .67026 Mdot
.62822 .24518 Mdot
.36887 .64704 Mdot
.69059 .37691 Mdot
.37743 .63231 Mdot
.68964 .30445 Mdot
.63019 .42617 Mdot
.40963 .67266 Mdot
.55457 .61056 Mdot
.62953 .40982 Mdot
.41133 .36275 Mdot
.73768 .63564 Mdot
.60019 .28568 Mdot
.6395 .26963 Mdot
.37189 .64969 Mdot
.62264 .24064 Mdot
.6926 .36195 Mdot
.68732 .35556 Mdot
.4243 .35202 Mdot
.55939 .58803 Mdot
.62023 .68508 Mdot
.61804 .67532 Mdot
.55484 .79752 Mdot
.74206 .51372 Mdot
.6589 .25297 Mdot
.41465 .36031 Mdot
.31971 .65358 Mdot
.46313 .34645 Mdot
.52524 .5687 Mdot
.2897 .49556 Mdot
.31528 .40126 Mdot
.58689 .38116 Mdot
.51451 .61187 Mdot
.68361 .34829 Mdot
.37395 .33164 Mdot
.42204 .32393 Mdot
.28884 .49727 Mdot
.64322 .26862 Mdot
.61771 .31821 Mdot
.57892 .42875 Mdot
.28251 .49285 Mdot
.52546 .56448 Mdot
.63113 .36923 Mdot
.70641 .66985 Mdot
.20104 .65452 Mdot
.59511 .42142 Mdot
.37649 .41974 Mdot
.61003 .44784 Mdot
.69611 .66483 Mdot
.59059 .41204 Mdot
.39178 .35227 Mdot
.71648 .35408 Mdot
.61286 .36905 Mdot
.34479 .7601 Mdot
.68443 .51985 Mdot
.58365 .67048 Mdot
.59939 .43285 Mdot
.58279 .43794 Mdot
.61144 .70672 Mdot
.37893 .3477 Mdot
.57094 .44953 Mdot
.30192 .32564 Mdot
.61096 .41991 Mdot
.25653 .49889 Mdot
.67093 .59089 Mdot
.72466 .64765 Mdot
.68818 .36493 Mdot
.38378 .36517 Mdot
.28233 .53307 Mdot
.28563 .48332 Mdot
.56308 .57191 Mdot
.27669 .50155 Mdot
.61847 .44129 Mdot
.67045 .58976 Mdot
.43755 .33318 Mdot
.52963 .58528 Mdot
.37582 .33866 Mdot
.37885 .6149 Mdot
.27819 .5105 Mdot
.53988 .57017 Mdot
.61661 .27145 Mdot
.28414 .52152 Mdot
.3703 .57899 Mdot
.69822 .35572 Mdot
.52641 .5629 Mdot
.44902 .36602 Mdot
.4027 .63173 Mdot
.53373 .56049 Mdot
.28789 .50006 Mdot
.58986 .42612 Mdot
.67693 .37675 Mdot
.27653 .50048 Mdot
.34395 .33013 Mdot
.69359 .34699 Mdot
.61251 .41691 Mdot
.40121 .36211 Mdot
.39976 .33662 Mdot
.63695 .41353 Mdot
.59862 .45668 Mdot
.35318 .67036 Mdot
.54552 .55713 Mdot
.54615 .55615 Mdot
.56912 .59694 Mdot
.38065 .64508 Mdot
.39235 .80331 Mdot
.26904 .5251 Mdot
.72592 .64567 Mdot
.33273 .42766 Mdot
.54926 .5757 Mdot
.35267 .6755 Mdot
.59076 .4451 Mdot
.56433 .40552 Mdot
.32292 .51411 Mdot
.52875 .84664 Mdot
.56814 .39463 Mdot
.43552 .33699 Mdot
.29285 .49372 Mdot
.6388 .43627 Mdot
.32768 .59208 Mdot
.59982 .66873 Mdot
.65669 .25045 Mdot
.29708 .49684 Mdot
.3808 .30034 Mdot
.29837 .49796 Mdot
.58356 .43754 Mdot
.62076 .39275 Mdot
.37676 .32763 Mdot
.58134 .67148 Mdot
.5625 .42259 Mdot
.60445 .40859 Mdot
.31716 .6937 Mdot
.45971 .34 Mdot
.61672 .66978 Mdot
.56432 .44323 Mdot
.55042 .60738 Mdot
.57919 .6692 Mdot
.62187 .41877 Mdot
.57217 .40383 Mdot
.57526 .60999 Mdot
.31268 .49325 Mdot
.57588 .69074 Mdot
.34918 .76598 Mdot
.42281 .33457 Mdot
.2261 .52743 Mdot
.54538 .54885 Mdot
.31651 .5134 Mdot
.66528 .35792 Mdot
.53442 .57329 Mdot
.27933 .43583 Mdot
.84996 .3753 Mdot
.53178 .56509 Mdot
.34977 .67771 Mdot
.60779 .30926 Mdot
.56797 .4097 Mdot
.61253 .41594 Mdot
.62077 .68988 Mdot
.40613 .34174 Mdot
.32441 .39224 Mdot
.3212 .52031 Mdot
.60422 .44413 Mdot
.4459 .356 Mdot
.21611 .37095 Mdot
.53792 .57958 Mdot
.58685 .67838 Mdot
.58235 .70359 Mdot
.62081 .42846 Mdot
.72657 .54944 Mdot
.40191 .35518 Mdot
.6073 .42297 Mdot
.62551 .41571 Mdot
.35852 .64388 Mdot
.43043 .36669 Mdot
.39651 .66308 Mdot
.70535 .3471 Mdot
.70088 .29254 Mdot
.34181 .55193 Mdot
.27259 .51313 Mdot
.55493 .56035 Mdot
.31486 .53076 Mdot
.34783 .70176 Mdot
.54689 .55657 Mdot
.60689 .42396 Mdot
.43695 .33255 Mdot
.60727 .42219 Mdot
.61038 .41955 Mdot
.5873 .42293 Mdot
.66061 .25213 Mdot
.38937 .70869 Mdot
.58595 .68579 Mdot
.57437 .46268 Mdot
.3894 .651 Mdot
.31841 .61365 Mdot
.61084 .31683 Mdot
.60347 .43424 Mdot
.61754 .40764 Mdot
.42993 .37597 Mdot
.6912 .36946 Mdot
.2847 .51943 Mdot
.37441 .32861 Mdot
.60512 .37746 Mdot
.35066 .72268 Mdot
.57333 .45321 Mdot
.44313 .33198 Mdot
.26477 .51801 Mdot
.50587 .3561 Mdot
.53046 .55221 Mdot
.55399 .55667 Mdot
.53195 .56278 Mdot
.56987 .59072 Mdot
.25828 .49273 Mdot
.35348 .68144 Mdot
.36468 .73597 Mdot
.5531 .44676 Mdot
.60449 .45604 Mdot
.62288 .39384 Mdot
.34626 .65619 Mdot
.54991 .61223 Mdot
.62053 .25541 Mdot
.63021 .45039 Mdot
.39633 .64166 Mdot
.56107 .60877 Mdot
.39599 .26692 Mdot
.37316 .33661 Mdot
.37102 .7117 Mdot
.28556 .48151 Mdot
.59783 .67551 Mdot
.61147 .77761 Mdot
.38837 .33354 Mdot
.42816 .39519 Mdot
.38354 .6771 Mdot
.66781 .5743 Mdot
.50439 .14564 Mdot
.36093 .67346 Mdot
.68558 .3486 Mdot
.42467 .35705 Mdot
.54123 .60368 Mdot
.71164 .57409 Mdot
.67427 .58333 Mdot
.41048 .65067 Mdot
.5865 .39922 Mdot
.42001 .61712 Mdot
.35363 .66284 Mdot
.55895 .57168 Mdot
.37329 .64955 Mdot
.29041 .53215 Mdot
.37561 .67268 Mdot
.35345 .3174 Mdot
.56968 .4293 Mdot
.50582 .14889 Mdot
.66476 .61641 Mdot
.58329 .44833 Mdot
.2998 .52633 Mdot
.27755 .56191 Mdot
.57918 .4183 Mdot
.60709 .66701 Mdot
.35048 .67917 Mdot
.35517 .5891 Mdot
.68323 .3784 Mdot
.38051 .63185 Mdot
.38866 .36764 Mdot
.34597 .57223 Mdot
.33961 .57244 Mdot
.53559 .55985 Mdot
.42584 .36428 Mdot
.32923 .50495 Mdot
.31388 .51537 Mdot
.56364 .54976 Mdot
.62277 .43962 Mdot
.3937 .3629 Mdot
.57939 .37264 Mdot
.51762 .53474 Mdot
.61131 .42114 Mdot
.3939 .66506 Mdot
.40883 .6845 Mdot
.64968 .59674 Mdot
.37583 .65818 Mdot
.55998 .57196 Mdot
.40452 .36463 Mdot
.68201 .38009 Mdot
.40702 .33583 Mdot
.58799 .45714 Mdot
.33738 .56307 Mdot
.37109 .34299 Mdot
.51086 .61661 Mdot
.59955 .39736 Mdot
.54759 .19878 Mdot
.56938 .45818 Mdot
.61299 .41777 Mdot
.41955 .64868 Mdot
.61006 .7077 Mdot
.49776 .57807 Mdot
.3233 .59816 Mdot
.6093 .67724 Mdot
.34792 .33481 Mdot
.41987 .63122 Mdot
.60216 .71984 Mdot
.5592 .79893 Mdot
.56511 .56954 Mdot
.58432 .69957 Mdot
.6358 .40401 Mdot
.27121 .50974 Mdot
.40741 .32395 Mdot
.63039 .41035 Mdot
.69085 .2946 Mdot
.70934 .3437 Mdot
.54137 .57895 Mdot
.61486 .41412 Mdot
.58283 .44156 Mdot
.44629 .35514 Mdot
.18408 .41313 Mdot
.36002 .70068 Mdot
.55252 .59679 Mdot
.39832 .33322 Mdot
.18512 .40565 Mdot
.41053 .66698 Mdot
.61011 .72063 Mdot
.31251 .53571 Mdot
.39571 .29938 Mdot
.54526 .57924 Mdot
.2778 .50768 Mdot
.42726 .6218 Mdot
.64992 .65613 Mdot
.66566 .38228 Mdot
.36943 .68594 Mdot
.65747 .66263 Mdot
.70357 .35391 Mdot
.3187 .60133 Mdot
.21835 .50186 Mdot
.37378 .35453 Mdot
.27799 .49808 Mdot
.58492 .67587 Mdot
.44613 .34179 Mdot
.37547 .33897 Mdot
.27282 .51685 Mdot
.61886 .20275 Mdot
.71359 .56823 Mdot
.31527 .53939 Mdot
.65024 .56512 Mdot
.653 .65771 Mdot
.5457 .58266 Mdot
.58857 .68857 Mdot
.34369 .56739 Mdot
.39305 .34848 Mdot
.32174 .40754 Mdot
.66061 .66635 Mdot
.70002 .35324 Mdot
.60013 .67718 Mdot
.21925 .37087 Mdot
.28293 .457 Mdot
.28189 .51598 Mdot
.31675 .68969 Mdot
.61244 .68429 Mdot
.63461 .41524 Mdot
.55101 .84836 Mdot
.62966 .42456 Mdot
.26764 .50924 Mdot
.68569 .34708 Mdot
.42926 .34293 Mdot
.26979 .52407 Mdot
.70238 .34114 Mdot
.56138 .43704 Mdot
.57585 .43775 Mdot
.39934 .70153 Mdot
.36341 .33612 Mdot
.54591 .54557 Mdot
.58524 .44987 Mdot
.60379 .40586 Mdot
.52221 .56891 Mdot
.72113 .65002 Mdot
.45048 .57743 Mdot
.52748 .5914 Mdot
.40227 .65221 Mdot
.52965 .58662 Mdot
.55432 .59444 Mdot
.43959 .37077 Mdot
.32187 .63211 Mdot
.53281 .55507 Mdot
.60002 .4183 Mdot
.60628 .41744 Mdot
.31419 .53643 Mdot
.71383 .57038 Mdot
.67148 .57635 Mdot
.35271 .69332 Mdot
.54035 .53339 Mdot
.59718 .38942 Mdot
.42799 .36484 Mdot
.5992 .64881 Mdot
.56352 .57627 Mdot
.42351 .3335 Mdot
.56775 .42607 Mdot
.35757 .64438 Mdot
.5333 .56549 Mdot
.51946 .57521 Mdot
.59918 .6821 Mdot
.29572 .53958 Mdot
.37941 .37007 Mdot
.35113 .66879 Mdot
.66443 .37774 Mdot
.53009 .53819 Mdot
.36991 .64004 Mdot
.54518 .58447 Mdot
.53413 .59235 Mdot
.42109 .36403 Mdot
.37426 .30165 Mdot
.53609 .60964 Mdot
.38297 .64689 Mdot
.1805 .60841 Mdot
.30721 .50533 Mdot
.58306 .46676 Mdot
.30241 .53585 Mdot
.37543 .3575 Mdot
.70232 .66403 Mdot
.59245 .71594 Mdot
.2805 .51852 Mdot
.52496 .57269 Mdot
.37328 .34044 Mdot
.36074 .34343 Mdot
.5997 .42229 Mdot
.60749 .42831 Mdot
.34043 .70492 Mdot
.67882 .67709 Mdot
.32546 .52146 Mdot
.61958 .6931 Mdot
.36206 .69753 Mdot
.67763 .37857 Mdot
.43318 .35157 Mdot
.68738 .74376 Mdot
.57882 .46717 Mdot
.38644 .65026 Mdot
.40881 .3507 Mdot
.6187 .68216 Mdot
.58492 .68697 Mdot
.59694 .45257 Mdot
.55503 .63617 Mdot
.27895 .52139 Mdot
.40547 .36021 Mdot
.37835 .40196 Mdot
.56958 .4558 Mdot
.60341 .43134 Mdot
.70097 .35507 Mdot
.31124 .5405 Mdot
.63559 .40781 Mdot
.58129 .67363 Mdot
.44054 .35035 Mdot
.59972 .44928 Mdot
.61296 .68787 Mdot
.5576 .55198 Mdot
.53399 .57028 Mdot
.41519 .66436 Mdot
.61198 .66963 Mdot
.61184 .69568 Mdot
.61303 .67989 Mdot
.31494 .40148 Mdot
.58695 .47688 Mdot
.52209 .60836 Mdot
.59235 .39459 Mdot
.65078 .65537 Mdot
.66174 .38477 Mdot
.30893 .51981 Mdot
.40902 .63749 Mdot
.58294 .42594 Mdot
.59661 .3929 Mdot
.37587 .3656 Mdot
.67978 .38365 Mdot
.63645 .41344 Mdot
.43295 .34509 Mdot
.38432 .4 Mdot
.40524 .62501 Mdot
.18827 .40879 Mdot
.60061 .83723 Mdot
.61773 .4524 Mdot
.66726 .57897 Mdot
.37676 .34715 Mdot
.31316 .53614 Mdot
.65648 .56684 Mdot
.28586 .53746 Mdot
.39774 .33914 Mdot
.68803 .38103 Mdot
.34166 .33548 Mdot
.60719 .67707 Mdot
.58398 .43615 Mdot
.27504 .52163 Mdot
.58242 .43449 Mdot
.28003 .52885 Mdot
.6092 .23807 Mdot
.70502 .58926 Mdot
.61836 .44891 Mdot
.58335 .39459 Mdot
.56412 .6448 Mdot
.60533 .43162 Mdot
.33311 .74338 Mdot
.41555 .3514 Mdot
.5634 .54589 Mdot
.68618 .38363 Mdot
.60042 .28744 Mdot
.61781 .41146 Mdot
.70926 .33733 Mdot
.61847 .40328 Mdot
.51242 .84282 Mdot
.59374 .46813 Mdot
.6248 .43651 Mdot
.30032 .51916 Mdot
.3136 .50382 Mdot
.36577 .35523 Mdot
.53294 .58661 Mdot
.21411 .37742 Mdot
.60893 .40786 Mdot
.38602 .69688 Mdot
.5092 .53799 Mdot
.61259 .69852 Mdot
.44135 .34507 Mdot
.84971 .35547 Mdot
.25898 .48708 Mdot
.40031 .66714 Mdot
.68491 .35109 Mdot
.40074 .65638 Mdot
.37426 .70755 Mdot
.35113 .38902 Mdot
.5883 .68728 Mdot
.57776 .45634 Mdot
.56021 .28547 Mdot
.47765 .37964 Mdot
.56945 .45533 Mdot
.41628 .62072 Mdot
.5744 .61121 Mdot
.69271 .46965 Mdot
.58567 .72293 Mdot
.60476 .70033 Mdot
.28384 .50195 Mdot
.38923 .69399 Mdot
.55087 .59654 Mdot
.60006 .72036 Mdot
.39741 .62617 Mdot
.56472 .57107 Mdot
.31709 .66555 Mdot
.40153 .35557 Mdot
.62429 .24186 Mdot
.55685 .196 Mdot
.30216 .53148 Mdot
.31701 .61089 Mdot
.43886 .33325 Mdot
.45069 .34766 Mdot
.54265 .59054 Mdot
.39864 .64057 Mdot
.39028 .31659 Mdot
.59502 .45126 Mdot
.53061 .58741 Mdot
.61831 .43606 Mdot
.59376 .72764 Mdot
.60947 .41237 Mdot
.38842 .6285 Mdot
.29808 .52372 Mdot
.36409 .65422 Mdot
.28066 .50314 Mdot
.73054 .64221 Mdot
.60309 .39964 Mdot
.60142 .43051 Mdot
.67092 .58914 Mdot
.42108 .3712 Mdot
.56064 .29477 Mdot
.38171 .64892 Mdot
.36747 .65193 Mdot
.68382 .38465 Mdot
.4163 .32835 Mdot
.52238 .59853 Mdot
.64594 .56457 Mdot
.62018 .40485 Mdot
.41477 .34999 Mdot
.66059 .38818 Mdot
.20302 .49644 Mdot
.69441 .59879 Mdot
.42181 .37237 Mdot
.34219 .75963 Mdot
.62425 .40201 Mdot
.55843 .59562 Mdot
.57667 .59292 Mdot
.73448 .53855 Mdot
.4976 .57416 Mdot
.41792 .33337 Mdot
.54634 .59951 Mdot
.43218 .35329 Mdot
.36101 .6513 Mdot
.26332 .51848 Mdot
.42548 .34922 Mdot
.61486 .40058 Mdot
.60155 .83605 Mdot
.27398 .52358 Mdot
.58698 .4355 Mdot
.26535 .51393 Mdot
.40763 .32177 Mdot
.41637 .34036 Mdot
.56465 .57109 Mdot
.69092 .34574 Mdot
.27952 .52024 Mdot
.60855 .45337 Mdot
.36059 .4163 Mdot
.67349 .38173 Mdot
.54973 .53205 Mdot
.59237 .39065 Mdot
.56794 .42128 Mdot
.36997 .78791 Mdot
.59639 .36386 Mdot
.34075 .55707 Mdot
.29339 .54567 Mdot
.31757 .3925 Mdot
.44407 .36694 Mdot
.60028 .72845 Mdot
.36577 .35697 Mdot
.5502 .55482 Mdot
.4046 .65332 Mdot
.58667 .42618 Mdot
.56866 .57626 Mdot
.32552 .53294 Mdot
.58841 .7045 Mdot
.59698 .4653 Mdot
.37143 .69075 Mdot
.5611 .60138 Mdot
.27955 .51175 Mdot
.39023 .34595 Mdot
.4301 .33948 Mdot
.32145 .63743 Mdot
.59786 .4494 Mdot
.60746 .42625 Mdot
.26189 .49471 Mdot
.52144 .62179 Mdot
.6088 .67408 Mdot
.55449 .61064 Mdot
.26236 .50306 Mdot
.69569 .59814 Mdot
.36287 .33445 Mdot
.58635 .44384 Mdot
.67096 .59431 Mdot
.32073 .38992 Mdot
.48057 .31528 Mdot
.60627 .69322 Mdot
.71756 .53373 Mdot
.41694 .33333 Mdot
.2979 .51529 Mdot
.55383 .79937 Mdot
.70062 .35824 Mdot
.57545 .42179 Mdot
.71832 .52313 Mdot
.64687 .56264 Mdot
.67343 .36055 Mdot
.53792 .54947 Mdot
.70289 .56793 Mdot
.67891 .38672 Mdot
.66726 .37851 Mdot
.60219 .38736 Mdot
.59314 .38973 Mdot
.41566 .34581 Mdot
.64422 .27124 Mdot
.38439 .67298 Mdot
.65149 .40782 Mdot
.56705 .67768 Mdot
.69643 .35402 Mdot
.56888 .40168 Mdot
.43326 .27645 Mdot
.74083 .48274 Mdot
.41766 .35705 Mdot
.39977 .37048 Mdot
.30489 .53189 Mdot
.67693 .38224 Mdot
.38446 .64887 Mdot
.56881 .61589 Mdot
.40316 .63503 Mdot
.41332 .34615 Mdot
.40899 .62349 Mdot
.26019 .4814 Mdot
.36964 .68611 Mdot
.39863 .64481 Mdot
.30185 .52221 Mdot
.36617 .33335 Mdot
.56824 .45723 Mdot
.30178 .52285 Mdot
.51993 .584 Mdot
.6079 .7236 Mdot
.40906 .39847 Mdot
.53415 .59902 Mdot
.56362 .40083 Mdot
.17997 .58962 Mdot
.38006 .68457 Mdot
.70637 .51554 Mdot
.36793 .34119 Mdot
.57773 .65565 Mdot
.42493 .34681 Mdot
.53459 .60936 Mdot
.60546 .68787 Mdot
.63471 .40191 Mdot
.64771 .75426 Mdot
.22048 .50183 Mdot
.62826 .37241 Mdot
.38369 .40021 Mdot
.39982 .63403 Mdot
.29243 .52979 Mdot
.23822 .54918 Mdot
.55213 .59772 Mdot
.38392 .36587 Mdot
.37648 .29673 Mdot
.54812 .55549 Mdot
.29657 .51836 Mdot
.5444 .2151 Mdot
.58858 .4494 Mdot
.30377 .53438 Mdot
.58989 .39241 Mdot
.64621 .24801 Mdot
.58088 .64131 Mdot
.56998 .59685 Mdot
.69048 .37858 Mdot
.41043 .66613 Mdot
.68572 .38337 Mdot
.67703 .28394 Mdot
.69124 .67542 Mdot
.60404 .39265 Mdot
.71117 .51708 Mdot
.34563 .69708 Mdot
.43542 .35582 Mdot
.54934 .56745 Mdot
.5438 .58205 Mdot
.69694 .37113 Mdot
.68701 .78936 Mdot
.5977 .71502 Mdot
.32929 .73621 Mdot
.60601 .40075 Mdot
.6148 .42722 Mdot
.36748 .36092 Mdot
.60774 .23996 Mdot
.55234 .6089 Mdot
.58217 .40836 Mdot
.74309 .4918 Mdot
.2997 .5069 Mdot
.60216 .38222 Mdot
.61865 .43203 Mdot
.34963 .56985 Mdot
.29979 .51769 Mdot
.35569 .65077 Mdot
.56265 .56375 Mdot
.41809 .65946 Mdot
.5844 .66434 Mdot
.70833 .53963 Mdot
.71332 .65709 Mdot
.69022 .59882 Mdot
.6002 .66444 Mdot
.69063 .3646 Mdot
.55248 .42424 Mdot
.57182 .42504 Mdot
.60273 .70435 Mdot
.28965 .47985 Mdot
.41741 .34975 Mdot
.63651 .24448 Mdot
.54304 .58427 Mdot
.66705 .37456 Mdot
.57173 .67938 Mdot
.4287 .35452 Mdot
.54345 .19809 Mdot
.40763 .34261 Mdot
.28367 .51258 Mdot
.31807 .60379 Mdot
.60625 .68392 Mdot
.4257 .34688 Mdot
.41838 .6471 Mdot
.33479 .56179 Mdot
.599 .47747 Mdot
.26122 .48052 Mdot
.35899 .32228 Mdot
.4077 .371 Mdot
.46068 .35754 Mdot
.69093 .37429 Mdot
.70921 .51672 Mdot
.55656 .56222 Mdot
.26312 .51308 Mdot
.39888 .67849 Mdot
.68128 .67614 Mdot
.54473 .23329 Mdot
.69374 .57965 Mdot
.62654 .39537 Mdot
.60848 .41302 Mdot
.6213 .42409 Mdot
.52543 .55648 Mdot
.55177 .42185 Mdot
.6024 .3913 Mdot
.32334 .51494 Mdot
.36178 .64557 Mdot
.60352 .40272 Mdot
.53665 .56692 Mdot
.50871 .60456 Mdot
.57768 .65685 Mdot
.6627 .24872 Mdot
.40681 .39645 Mdot
.42668 .35235 Mdot
.39187 .65645 Mdot
.42151 .6328 Mdot
.5954 .72087 Mdot
.28692 .49462 Mdot
.40488 .34114 Mdot
.50757 .84054 Mdot
.60356 .67362 Mdot
.59666 .41901 Mdot
.67126 .59032 Mdot
.74069 .50274 Mdot
.56565 .41107 Mdot
.58712 .42171 Mdot
.52621 .57526 Mdot
.38813 .64834 Mdot
.69172 .3098 Mdot
.54504 .19929 Mdot
.61203 .68818 Mdot
.61368 .71261 Mdot
.45658 .35141 Mdot
.61431 .4499 Mdot
.27472 .52008 Mdot
.71593 .56738 Mdot
.26365 .55631 Mdot
.23768 .34352 Mdot
.3877 .61896 Mdot
.5755 .45536 Mdot
.60329 .30193 Mdot
.58512 .38189 Mdot
.45555 .34443 Mdot
.37699 .30357 Mdot
.41631 .35942 Mdot
.29666 .50217 Mdot
.6362 .64215 Mdot
.29558 .48869 Mdot
.56055 .60836 Mdot
.38222 .33148 Mdot
.60006 .36701 Mdot
.36884 .65161 Mdot
.67123 .38432 Mdot
.59362 .69367 Mdot
.58154 .5258 Mdot
.54991 .57194 Mdot
.71455 .5358 Mdot
.35295 .67593 Mdot
.37124 .32523 Mdot
.67104 .38494 Mdot
.32747 .59438 Mdot
.70052 .57505 Mdot
.33625 .66958 Mdot
.56818 .57355 Mdot
.60759 .67987 Mdot
.61159 .31892 Mdot
.59751 .67159 Mdot
.27812 .51815 Mdot
.59986 .39884 Mdot
.62114 .44089 Mdot
.61542 .41796 Mdot
.63243 .40685 Mdot
.29112 .50049 Mdot
.67215 .37019 Mdot
.52926 .6008 Mdot
.56934 .58677 Mdot
.69217 .34968 Mdot
.58668 .69403 Mdot
.30863 .50993 Mdot
.36844 .63998 Mdot
.52837 .56405 Mdot
.57364 .68261 Mdot
.64542 .38552 Mdot
.59491 .39621 Mdot
.56425 .6019 Mdot
.63534 .40393 Mdot
.67578 .36656 Mdot
.37049 .68091 Mdot
.67277 .36396 Mdot
.5768 .65922 Mdot
.59681 .69071 Mdot
.27397 .50368 Mdot
.42673 .34752 Mdot
.58124 .70444 Mdot
.35962 .69347 Mdot
.6142 .37915 Mdot
.59516 .38945 Mdot
.35625 .31488 Mdot
.65941 .66622 Mdot
.5795 .65415 Mdot
.63597 .40919 Mdot
.4375 .365 Mdot
.38358 .29268 Mdot
.57745 .41695 Mdot
.68392 .36119 Mdot
.44497 .36939 Mdot
.60415 .72292 Mdot
.2802 .49385 Mdot
.6698 .62355 Mdot
.27463 .5294 Mdot
.38901 .34653 Mdot
.54333 .59708 Mdot
.36835 .33248 Mdot
.55079 .59877 Mdot
.29456 .28719 Mdot
.60229 .38988 Mdot
.33708 .36075 Mdot
.54817 .61265 Mdot
.3726 .64832 Mdot
.38658 .63897 Mdot
.53598 .56325 Mdot
.41009 .33124 Mdot
.55918 .57018 Mdot
.5901 .6735 Mdot
.31997 .39651 Mdot
.43639 .37215 Mdot
.39835 .64367 Mdot
.37884 .68623 Mdot
.26215 .5043 Mdot
.61328 .41174 Mdot
.58598 .44427 Mdot
.36601 .68604 Mdot
.25678 .55314 Mdot
.37622 .35409 Mdot
.60682 .42622 Mdot
.52456 .58624 Mdot
.37791 .67708 Mdot
.23779 .4759 Mdot
.39342 .3203 Mdot
.69303 .37724 Mdot
.6945 .67385 Mdot
.25963 .51211 Mdot
.59563 .37973 Mdot
.6773 .36625 Mdot
.60469 .71137 Mdot
.71959 .53033 Mdot
.65659 .65997 Mdot
.26014 .48445 Mdot
.55465 .55778 Mdot
.56537 .41031 Mdot
.37565 .64321 Mdot
.62815 .38378 Mdot
.84382 .4257 Mdot
.5668 .60186 Mdot
.60065 .44708 Mdot
.57409 .60046 Mdot
.4081 .33577 Mdot
.61175 .42445 Mdot
.33896 .55441 Mdot
.38829 .65885 Mdot
.59568 .44863 Mdot
.56023 .63966 Mdot
.2662 .51473 Mdot
.5492 .57153 Mdot
.60979 .68017 Mdot
.67183 .36052 Mdot
.7369 .63622 Mdot
.34499 .65836 Mdot
.583 .68969 Mdot
.6147 .40989 Mdot
.36325 .69941 Mdot
.31516 .50695 Mdot
.54733 .56401 Mdot
.63681 .37597 Mdot
.31231 .51952 Mdot
.30309 .51144 Mdot
.60276 .68091 Mdot
.53675 .17429 Mdot
.62249 .4464 Mdot
.59485 .43892 Mdot
.53751 .19342 Mdot
.39881 .28375 Mdot
.58402 .43412 Mdot
.62696 .42136 Mdot
.27579 .5095 Mdot
.63302 .64129 Mdot
.71579 .5342 Mdot
.56453 .61489 Mdot
.29625 .52914 Mdot
.41067 .61854 Mdot
.39348 .67286 Mdot
.58069 .68838 Mdot
.40726 .35031 Mdot
.58914 .7171 Mdot
.37999 .66964 Mdot
.59776 .42121 Mdot
.27307 .49562 Mdot
.71515 .32043 Mdot
.26782 .52118 Mdot
.36078 .69193 Mdot
.44671 .3363 Mdot
.69043 .30276 Mdot
.84451 .41724 Mdot
.44481 .57461 Mdot
.31706 .60297 Mdot
.61226 .70024 Mdot
.54463 .19956 Mdot
.61216 .40249 Mdot
.6677 .2827 Mdot
.58791 .43832 Mdot
.61721 .72734 Mdot
.39635 .631 Mdot
.56463 .57087 Mdot
.55318 .5974 Mdot
.71218 .5334 Mdot
.30237 .50685 Mdot
.27829 .48213 Mdot
.53814 .59692 Mdot
.28609 .51605 Mdot
.59927 .44496 Mdot
.35654 .67248 Mdot
.31674 .27491 Mdot
.61868 .40262 Mdot
.5538 .54063 Mdot
.25261 .49325 Mdot
.42435 .32225 Mdot
.41119 .61883 Mdot
.60212 .29593 Mdot
.20398 .39028 Mdot
.28408 .52259 Mdot
.66442 .25064 Mdot
.38788 .65368 Mdot
.52796 .5649 Mdot
.36478 .70151 Mdot
.59278 .44183 Mdot
.5755 .45559 Mdot
.52364 .56533 Mdot
.62065 .41019 Mdot
.55443 .32024 Mdot
.70066 .34971 Mdot
.60269 .48328 Mdot
.58854 .39726 Mdot
.34255 .3508 Mdot
.31801 .50914 Mdot
.53845 .59618 Mdot
.61753 .56196 Mdot
.56868 .42356 Mdot
.44814 .36531 Mdot
.30978 .52289 Mdot
.19571 .40982 Mdot
.2961 .5033 Mdot
.36557 .65053 Mdot
.29188 .49598 Mdot
.59 .38007 Mdot
.3926 .33765 Mdot
.37256 .66539 Mdot
.54792 .57602 Mdot
.40476 .66744 Mdot
.58387 .4486 Mdot
.2504 .46688 Mdot
.39965 .66728 Mdot
.70081 .3545 Mdot
.3967 .33727 Mdot
.66875 .75219 Mdot
.46281 .38605 Mdot
.59518 .42757 Mdot
.58859 .43133 Mdot
.55058 .60978 Mdot
.28053 .4993 Mdot
.36699 .32681 Mdot
.31777 .69895 Mdot
.57871 .65413 Mdot
.41134 .35509 Mdot
.55107 .63275 Mdot
.66719 .57323 Mdot
.44395 .34821 Mdot
.74305 .49612 Mdot
.27225 .51465 Mdot
.42541 .33595 Mdot
.52267 .52799 Mdot
.65857 .39716 Mdot
.59115 .68389 Mdot
.41947 .65176 Mdot
.6613 .56933 Mdot
.39544 .66754 Mdot
.33768 .56301 Mdot
.41749 .67081 Mdot
.28378 .52578 Mdot
.5472 .63409 Mdot
.68221 .34932 Mdot
.27605 .47957 Mdot
.34034 .44838 Mdot
.38937 .66747 Mdot
.54329 .60282 Mdot
.67752 .36047 Mdot
.51943 .57116 Mdot
.55648 .60083 Mdot
.26045 .48508 Mdot
.42747 .33599 Mdot
.42758 .33171 Mdot
.57152 .56159 Mdot
.43259 .3421 Mdot
.36375 .67293 Mdot
.68164 .60268 Mdot
.616 .27175 Mdot
.31726 .50467 Mdot
.66708 .36737 Mdot
.58271 .3893 Mdot
.3846 .63035 Mdot
.35981 .6689 Mdot
.30001 .50485 Mdot
.49081 .36033 Mdot
.56152 .59403 Mdot
.41033 .32112 Mdot
.38845 .33294 Mdot
.41248 .33569 Mdot
.36738 .35086 Mdot
.64541 .65166 Mdot
.30046 .52617 Mdot
.40745 .33142 Mdot
.62669 .40164 Mdot
.62516 .42084 Mdot
.53194 .56046 Mdot
.59873 .72759 Mdot
.68606 .35804 Mdot
.56004 .57116 Mdot
.57548 .42562 Mdot
.37412 .64955 Mdot
.5006 .54743 Mdot
.55188 .55371 Mdot
.38512 .64799 Mdot
.38021 .64626 Mdot
.55601 .55746 Mdot
.49746 .55304 Mdot
.54805 .33224 Mdot
.69821 .37837 Mdot
.36196 .4003 Mdot
.39573 .63785 Mdot
.35026 .47607 Mdot
.33714 .35748 Mdot
.61794 .44305 Mdot
.55594 .61177 Mdot
.35577 .66591 Mdot
.43023 .3732 Mdot
.60305 .43644 Mdot
.54421 .59202 Mdot
.59351 .67784 Mdot
.54578 .5718 Mdot
.52693 .57799 Mdot
.41767 .36889 Mdot
.18208 .60208 Mdot
.44538 .35629 Mdot
.39869 .70002 Mdot
.55243 .58037 Mdot
.50428 .14763 Mdot
.39423 .63367 Mdot
.31947 .39879 Mdot
.68767 .34626 Mdot
.57397 .42247 Mdot
.39207 .65792 Mdot
.38928 .36773 Mdot
.26873 .47654 Mdot
.74206 .47777 Mdot
.42698 .34615 Mdot
.54456 .54868 Mdot
.52945 .57006 Mdot
.38269 .67467 Mdot
.38445 .34658 Mdot
.67821 .36559 Mdot
.42318 .33821 Mdot
.28129 .48529 Mdot
.63498 .39507 Mdot
.21301 .37908 Mdot
.54996 .59622 Mdot
.43754 .34543 Mdot
.38845 .68764 Mdot
.58067 .67373 Mdot
.63025 .42459 Mdot
.19655 .39319 Mdot
.61664 .4104 Mdot
.26849 .48607 Mdot
.50841 .54851 Mdot
.65902 .39351 Mdot
.59161 .41319 Mdot
.56265 .41024 Mdot
.3125 .48889 Mdot
.58938 .41249 Mdot
.5656 .42819 Mdot
.55214 .1996 Mdot
.44239 .35539 Mdot
.60584 .40278 Mdot
.36341 .68261 Mdot
.47406 .55901 Mdot
.61272 .43959 Mdot
.31968 .60719 Mdot
.7321 .54062 Mdot
.54803 .61459 Mdot
.56709 .5452 Mdot
.70097 .66492 Mdot
.59085 .43442 Mdot
.60753 .45532 Mdot
.63413 .39507 Mdot
.62026 .29491 Mdot
.38396 .66531 Mdot
.40725 .67527 Mdot
.58087 .67731 Mdot
.71836 .51973 Mdot
.59899 .68752 Mdot
.31571 .50805 Mdot
.70266 .34295 Mdot
.56587 .56869 Mdot
.42934 .34949 Mdot
.61599 .41976 Mdot
.39696 .68287 Mdot
.59384 .44429 Mdot
.67925 .37505 Mdot
.3676 .67555 Mdot
.35803 .6602 Mdot
.42311 .65516 Mdot
.61428 .68673 Mdot
.42269 .35563 Mdot
.63071 .42977 Mdot
.61175 .68024 Mdot
.5227 .56529 Mdot
.68142 .62542 Mdot
.42109 .35728 Mdot
.43809 .34858 Mdot
.38761 .32581 Mdot
.62273 .44101 Mdot
.63953 .40044 Mdot
.30011 .49279 Mdot
.35634 .31458 Mdot
.26739 .51232 Mdot
.39409 .65949 Mdot
.35623 .65449 Mdot
.59138 .44164 Mdot
.54118 .62996 Mdot
.58735 .69173 Mdot
.39563 .67628 Mdot
.57309 .59011 Mdot
.57616 .68332 Mdot
.60238 .45483 Mdot
.39619 .6643 Mdot
.6096 .6691 Mdot
.49122 .35956 Mdot
.2408 .37603 Mdot
.5788 .67472 Mdot
.55645 .59558 Mdot
.54597 .24093 Mdot
.68698 .67258 Mdot
.59626 .64717 Mdot
.31696 .5067 Mdot
.58039 .46808 Mdot
.57149 .59378 Mdot
.57462 .68106 Mdot
.67385 .6819 Mdot
.37388 .67196 Mdot
.55975 .59312 Mdot
.47602 .60666 Mdot
.61682 .27279 Mdot
.58005 .67188 Mdot
.43871 .34631 Mdot
.36035 .32533 Mdot
.59261 .41822 Mdot
.69091 .34641 Mdot
.31997 .50684 Mdot
.42121 .63768 Mdot
.40477 .67667 Mdot
.38409 .29915 Mdot
.69198 .59902 Mdot
.37284 .68328 Mdot
.5892 .46587 Mdot
.57284 .6974 Mdot
.62593 .4005 Mdot
.51917 .53636 Mdot
.66234 .39274 Mdot
.57494 .56054 Mdot
.57979 .67398 Mdot
.31577 .49953 Mdot
.2973 .5236 Mdot
.28396 .49923 Mdot
.37565 .68087 Mdot
.65873 .56592 Mdot
.39434 .68881 Mdot
.54536 .18033 Mdot
.59592 .71488 Mdot
.4058 .81115 Mdot
.55985 .40498 Mdot
.5737 .43117 Mdot
.66389 .3828 Mdot
.52651 .58749 Mdot
.59287 .43426 Mdot
.31273 .51618 Mdot
.41777 .64846 Mdot
.22582 .48682 Mdot
.39949 .36213 Mdot
.54773 .1851 Mdot
.36929 .65249 Mdot
.56122 .54862 Mdot
.59089 .69459 Mdot
.71556 .66256 Mdot
.61854 .71545 Mdot
.34979 .67476 Mdot
.58003 .452 Mdot
.46083 .36066 Mdot
.52013 .8443 Mdot
.61245 .4218 Mdot
.38178 .68408 Mdot
.33889 .6676 Mdot
.65152 .41207 Mdot
.64648 .33875 Mdot
.2157 .50299 Mdot
.67571 .59366 Mdot
.6099 .66657 Mdot
.52047 .57505 Mdot
.7206 .56302 Mdot
.3816 .66967 Mdot
.41364 .65295 Mdot
.61938 .67197 Mdot
.42988 .32394 Mdot
.38667 .32865 Mdot
.41567 .40836 Mdot
.3103 .50658 Mdot
.57569 .41516 Mdot
.39249 .66765 Mdot
.44538 .3364 Mdot
.61032 .55755 Mdot
.28586 .50551 Mdot
.3998 .6694 Mdot
.62057 .41153 Mdot
.59438 .41261 Mdot
.59844 .68539 Mdot
.50666 .60117 Mdot
.52337 .58841 Mdot
.32118 .39852 Mdot
.67777 .57382 Mdot
.70344 .3412 Mdot
.57547 .42156 Mdot
.38331 .36101 Mdot
.55072 .55619 Mdot
.58776 .68739 Mdot
.62604 .3838 Mdot
.68276 .29441 Mdot
.39808 .36964 Mdot
.273 .51778 Mdot
.54821 .58344 Mdot
.70617 .53779 Mdot
.61939 .41042 Mdot
.58879 .43876 Mdot
.69067 .37447 Mdot
.69566 .30508 Mdot
.40786 .63636 Mdot
.43574 .36337 Mdot
.61102 .68245 Mdot
.4133 .34052 Mdot
.32098 .64646 Mdot
.69775 .34571 Mdot
.59031 .4691 Mdot
.44176 .36664 Mdot
.39979 .34099 Mdot
.26958 .4858 Mdot
.29464 .52691 Mdot
.35414 .63989 Mdot
.62754 .42383 Mdot
.56747 .60259 Mdot
.40608 .33216 Mdot
.42075 .64707 Mdot
.60028 .68637 Mdot
.31588 .61642 Mdot
.59821 .3933 Mdot
.38589 .66997 Mdot
.55161 .56763 Mdot
.4094 .36609 Mdot
.3822 .65142 Mdot
.52758 .56553 Mdot
.60971 .72011 Mdot
.56186 .43257 Mdot
.33557 .68513 Mdot
.53967 .5918 Mdot
.63002 .41646 Mdot
.61467 .48105 Mdot
.68675 .34886 Mdot
.56784 .61424 Mdot
.38015 .62856 Mdot
.54008 .58755 Mdot
.36148 .32641 Mdot
.64823 .41913 Mdot
.41458 .65914 Mdot
.3414 .33611 Mdot
.69121 .34401 Mdot
.54824 .5992 Mdot
.43478 .35467 Mdot
.31725 .66765 Mdot
.44988 .32866 Mdot
.68259 .66718 Mdot
.60966 .43869 Mdot
.39523 .66792 Mdot
.59259 .68238 Mdot
.27645 .48322 Mdot
.31454 .44971 Mdot
.35627 .52054 Mdot
.39113 .64218 Mdot
.61686 .42067 Mdot
.42216 .33509 Mdot
.28347 .52074 Mdot
.36933 .36349 Mdot
.36776 .69909 Mdot
.3589 .68066 Mdot
.6638 .38132 Mdot
.59931 .68869 Mdot
.55275 .41968 Mdot
.41619 .65944 Mdot
.41078 .68109 Mdot
.55213 .20206 Mdot
.60795 .66575 Mdot
.6928 .37369 Mdot
.57204 .56121 Mdot
.60399 .38261 Mdot
.54152 .19788 Mdot
.52904 .57693 Mdot
.39659 .36123 Mdot
.58162 .42768 Mdot
.23455 .68789 Mdot
.38749 .63327 Mdot
.67608 .59356 Mdot
.22117 .50049 Mdot
.30493 .51653 Mdot
.38426 .65902 Mdot
.60827 .43387 Mdot
.3154 .61338 Mdot
.58023 .68946 Mdot
.68625 .38432 Mdot
.54304 .59998 Mdot
.38771 .29505 Mdot
.27529 .49313 Mdot
.48289 .59574 Mdot
.27907 .48349 Mdot
.27582 .50235 Mdot
.48512 .36591 Mdot
.5935 .41848 Mdot
.37115 .65517 Mdot
.36518 .69001 Mdot
.55236 .53643 Mdot
.39751 .7058 Mdot
.37457 .33111 Mdot
.22878 .67882 Mdot
.68439 .29853 Mdot
.60308 .39707 Mdot
.53887 .54913 Mdot
.55657 .60853 Mdot
.31772 .60372 Mdot
.58738 .41654 Mdot
.43398 .35827 Mdot
.41672 .66079 Mdot
.39005 .67468 Mdot
.70039 .35455 Mdot
.2973 .52402 Mdot
.61959 .70365 Mdot
.36203 .66962 Mdot
.66763 .62128 Mdot
.60052 .44764 Mdot
.25254 .48199 Mdot
.36367 .66893 Mdot
.63329 .80773 Mdot
.18204 .61781 Mdot
.4492 .35037 Mdot
.56024 .43124 Mdot
.39242 .32053 Mdot
.58377 .67106 Mdot
.38194 .70277 Mdot
.27834 .48059 Mdot
.55083 .57823 Mdot
.21309 .53019 Mdot
.38558 .67575 Mdot
.41421 .34687 Mdot
.59147 .42327 Mdot
.6696 .25382 Mdot
.61787 .40317 Mdot
.63043 .63911 Mdot
.58158 .65215 Mdot
.31177 .44884 Mdot
.26118 .49785 Mdot
.56012 .43236 Mdot
.61247 .67821 Mdot
.34901 .68105 Mdot
.36953 .67578 Mdot
.19051 .40104 Mdot
.52695 .57636 Mdot
.37022 .70678 Mdot
.6297 .41851 Mdot
.42122 .65977 Mdot
.54448 .23306 Mdot
.30372 .51705 Mdot
.59007 .38966 Mdot
.4011 .65923 Mdot
.435 .32063 Mdot
.6721 .58683 Mdot
.60638 .44376 Mdot
.57558 .59764 Mdot
.28782 .52549 Mdot
.54948 .18428 Mdot
.39487 .62982 Mdot
.61389 .39217 Mdot
.31434 .5211 Mdot
.54844 .63411 Mdot
.22828 .48005 Mdot
.42277 .35609 Mdot
.37859 .6872 Mdot
.28033 .49318 Mdot
.5567 .57957 Mdot
.60691 .66825 Mdot
.35468 .69183 Mdot
.40368 .65711 Mdot
.68728 .36752 Mdot
.5684 .55909 Mdot
.54817 .63163 Mdot
.37419 .34906 Mdot
.27421 .51216 Mdot
.68321 .37428 Mdot
.67853 .62898 Mdot
.63613 .38734 Mdot
.27169 .50809 Mdot
.51652 .15483 Mdot
.57638 .45102 Mdot
.59263 .39512 Mdot
.6772 .26171 Mdot
.37121 .32151 Mdot
.3744 .35731 Mdot
.69688 .57805 Mdot
.68633 .36093 Mdot
.59459 .36786 Mdot
.4221 .35247 Mdot
.41015 .34538 Mdot
.59613 .36765 Mdot
.6836 .37018 Mdot
.43255 .40569 Mdot
.28635 .51976 Mdot
.30453 .51903 Mdot
.41107 .33593 Mdot
.66346 .38385 Mdot
.31439 .53548 Mdot
.46028 .30377 Mdot
.3581 .68655 Mdot
.72542 .55043 Mdot
.4051 .33833 Mdot
.66831 .58926 Mdot
.27765 .51763 Mdot
.72546 .62247 Mdot
.73454 .5359 Mdot
.62825 .43925 Mdot
.59154 .41623 Mdot
.61004 .70371 Mdot
.54786 .57179 Mdot
.55539 .55656 Mdot
.28391 .49875 Mdot
.55155 .42287 Mdot
.41418 .35911 Mdot
.59451 .37829 Mdot
.68041 .67749 Mdot
.73898 .6176 Mdot
.69418 .32206 Mdot
.40708 .34902 Mdot
.39574 .35025 Mdot
.35404 .65599 Mdot
.41607 .62388 Mdot
.61327 .45531 Mdot
.29123 .52577 Mdot
.43398 .33857 Mdot
.26886 .50339 Mdot
.37996 .6706 Mdot
.3671 .65513 Mdot
.54343 .55435 Mdot
.56064 .59162 Mdot
.37883 .66325 Mdot
.3195 .60697 Mdot
.67929 .62831 Mdot
.36743 .30715 Mdot
.54662 .17554 Mdot
.7261 .64776 Mdot
.64353 .24692 Mdot
.59264 .67967 Mdot
.50309 .54462 Mdot
.31417 .51797 Mdot
.55931 .42517 Mdot
.57831 .43073 Mdot
.53766 .57907 Mdot
.30698 .53161 Mdot
.59418 .70674 Mdot
.30438 .51633 Mdot
.60713 .66954 Mdot
.40948 .6675 Mdot
.61637 .42475 Mdot
.58127 .4494 Mdot
.27187 .48566 Mdot
.35088 .6622 Mdot
.39914 .66001 Mdot
.58909 .68116 Mdot
.71728 .65518 Mdot
.3828 .67367 Mdot
.40416 .33884 Mdot
.358 .26523 Mdot
.5302 .57323 Mdot
.60376 .4354 Mdot
.70264 .66543 Mdot
.64786 .41958 Mdot
.52375 .56317 Mdot
.54755 .58381 Mdot
.53546 .17427 Mdot
.59687 .45177 Mdot
.18678 .41364 Mdot
.55018 .55308 Mdot
.36852 .33203 Mdot
.37543 .65585 Mdot
.53532 .55224 Mdot
.57846 .58545 Mdot
.57645 .63965 Mdot
.53215 .55228 Mdot
.38976 .32948 Mdot
.37982 .32143 Mdot
.67916 .35801 Mdot
.5558 .17002 Mdot
.60861 .6796 Mdot
.58703 .70116 Mdot
.4073 .6387 Mdot
.3377 .56376 Mdot
.54599 .45379 Mdot
.5867 .70452 Mdot
.41683 .39928 Mdot
.66605 .3803 Mdot
.67366 .35989 Mdot
.68984 .35084 Mdot
.36065 .33858 Mdot
.64547 .4086 Mdot
.40183 .63329 Mdot
.41487 .34833 Mdot
.67164 .3653 Mdot
.61782 .37827 Mdot
.41947 .3586 Mdot
.27667 .5055 Mdot
.69853 .33679 Mdot
.42831 .33923 Mdot
.74281 .47573 Mdot
.27762 .52186 Mdot
.66525 .36694 Mdot
.46389 .81975 Mdot
.65647 .80118 Mdot
.30238 .51405 Mdot
.39769 .67192 Mdot
.39181 .66641 Mdot
.36989 .67963 Mdot
.37195 .3521 Mdot
.36515 .64528 Mdot
.38501 .35061 Mdot
.31923 .59841 Mdot
.71507 .5263 Mdot
.60607 .68585 Mdot
.38642 .71175 Mdot
.41392 .33648 Mdot
.54261 .18929 Mdot
.85035 .37208 Mdot
.61763 .39391 Mdot
.27354 .48001 Mdot
.58393 .70631 Mdot
.67474 .59893 Mdot
.60497 .71091 Mdot
.38858 .65404 Mdot
.70922 .53622 Mdot
.59528 .44606 Mdot
.22495 .38969 Mdot
.59308 .68454 Mdot
.40944 .3443 Mdot
.6933 .3621 Mdot
.37058 .63222 Mdot
.5815 .68485 Mdot
.5957 .69164 Mdot
.59531 .43471 Mdot
.3709 .32559 Mdot
.39323 .65469 Mdot
.29889 .53284 Mdot
.37769 .59073 Mdot
.56656 .50694 Mdot
.60146 .45159 Mdot
.58706 .39648 Mdot
.66907 .57807 Mdot
.31646 .6164 Mdot
.29182 .52101 Mdot
.66758 .67091 Mdot
.38346 .62988 Mdot
.68566 .67748 Mdot
.45036 .33304 Mdot
.38431 .71231 Mdot
.52981 .57813 Mdot
.52983 .56179 Mdot
.60657 .42452 Mdot
.84759 .39786 Mdot
.64681 .34462 Mdot
.31716 .53291 Mdot
.53388 .57436 Mdot
.35064 .65913 Mdot
.37041 .35592 Mdot
.47287 .61027 Mdot
.6829 .35977 Mdot
.29725 .5333 Mdot
.37486 .67617 Mdot
.86165 .45053 Mdot
.61335 .70087 Mdot
.6809 .59601 Mdot
.62639 .41633 Mdot
.60365 .42793 Mdot
.29058 .50435 Mdot
.30112 .48527 Mdot
.55596 .19316 Mdot
.62152 .71627 Mdot
.21574 .37229 Mdot
.33018 .52583 Mdot
.86958 .46442 Mdot
.56165 .60675 Mdot
.3963 .35424 Mdot
.55898 .56041 Mdot
.30751 .48986 Mdot
.58228 .43157 Mdot
.37051 .32398 Mdot
.54828 .56287 Mdot
.43669 .39434 Mdot
.67446 .35813 Mdot
.67105 .62333 Mdot
.60759 .41287 Mdot
.40487 .32501 Mdot
.41801 .35222 Mdot
.4282 .32681 Mdot
.53388 .56286 Mdot
.58263 .40738 Mdot
.61347 .39347 Mdot
.58541 .39906 Mdot
.55889 .19861 Mdot
.61333 .42594 Mdot
.46657 .3521 Mdot
.70091 .59014 Mdot
.24564 .70283 Mdot
.57997 .44755 Mdot
.28355 .49489 Mdot
.60761 .41931 Mdot
.61587 .68306 Mdot
.5624 .42434 Mdot
.67313 .35824 Mdot
.29 .51721 Mdot
.67938 .28576 Mdot
.56736 .67424 Mdot
.59883 .45379 Mdot
.60193 .66487 Mdot
.30875 .40588 Mdot
.66506 .66597 Mdot
.54449 .21623 Mdot
.42088 .338 Mdot
.37415 .70104 Mdot
.32203 .51031 Mdot
.36618 .65045 Mdot
.71401 .35251 Mdot
.5675 .57667 Mdot
.39204 .80316 Mdot
.69205 .63047 Mdot
.582 .4297 Mdot
.54674 .60804 Mdot
.439 .35481 Mdot
.39249 .63305 Mdot
.61016 .23958 Mdot
.66456 .38226 Mdot
.59967 .72384 Mdot
.60662 .71647 Mdot
.52535 .5386 Mdot
.42765 .32494 Mdot
.5427 .2286 Mdot
.29106 .50606 Mdot
.37914 .6802 Mdot
.57541 .66821 Mdot
.39556 .4014 Mdot
.2841 .47787 Mdot
.32091 .59809 Mdot
.27744 .49214 Mdot
.57229 .43462 Mdot
.54656 .55034 Mdot
.35048 .40559 Mdot
.53446 .58652 Mdot
.61941 .38025 Mdot
.40296 .65608 Mdot
.52821 .57678 Mdot
.60953 .69582 Mdot
.27809 .49641 Mdot
.37171 .65063 Mdot
.59061 .42932 Mdot
.42641 .3538 Mdot
.69312 .46364 Mdot
.34007 .69794 Mdot
.6951 .34464 Mdot
.69531 .34457 Mdot
.36818 .30074 Mdot
.56551 .61635 Mdot
.28856 .44721 Mdot
.64892 .4196 Mdot
.34936 .54384 Mdot
.50836 .60855 Mdot
.32731 .73194 Mdot
.39071 .69186 Mdot
.37131 .66753 Mdot
.58488 .44603 Mdot
.42172 .64868 Mdot
.58872 .46734 Mdot
.38884 .62671 Mdot
.31883 .38744 Mdot
.62739 .37217 Mdot
.36669 .67319 Mdot
.55876 .56441 Mdot
.6306 .4217 Mdot
.43779 .35853 Mdot
.39476 .6915 Mdot
.62873 .43864 Mdot
.33771 .74922 Mdot
.27046 .48549 Mdot
.53328 .56251 Mdot
.6317 .56502 Mdot
.28153 .51454 Mdot
.37816 .3321 Mdot
.57397 .46435 Mdot
.58329 .70127 Mdot
.39065 .34843 Mdot
.51763 .55744 Mdot
.59906 .69076 Mdot
.68272 .60399 Mdot
.38686 .33605 Mdot
.53093 .57715 Mdot
.60804 .71998 Mdot
.55772 .53644 Mdot
.37164 .67005 Mdot
.33737 .67502 Mdot
.54246 .59373 Mdot
.59217 .44548 Mdot
.35438 .6499 Mdot
.29934 .5021 Mdot
.61852 .43387 Mdot
.39284 .66932 Mdot
.53847 .56554 Mdot
.62171 .40168 Mdot
.68694 .35984 Mdot
.54649 .19819 Mdot
.55092 .61605 Mdot
.60813 .68908 Mdot
.43648 .33048 Mdot
.60803 .3901 Mdot
.60556 .67253 Mdot
.34555 .6952 Mdot
.61963 .3915 Mdot
.44006 .3401 Mdot
.49349 .36969 Mdot
.42111 .63275 Mdot
.27684 .52502 Mdot
.36803 .69234 Mdot
.58855 .66275 Mdot
.85099 .36123 Mdot
.5517 .55533 Mdot
.67588 .38926 Mdot
.56922 .41286 Mdot
.37901 .70092 Mdot
.41767 .35455 Mdot
.22599 .3557 Mdot
.56143 .43051 Mdot
.62341 .39452 Mdot
.60065 .43488 Mdot
.35393 .58909 Mdot
.3686 .34436 Mdot
.60203 .43564 Mdot
.49795 .57909 Mdot
.58462 .39635 Mdot
.58567 .67333 Mdot
.42449 .81772 Mdot
.52412 .56927 Mdot
.49897 .1445 Mdot
.54622 .56077 Mdot
.36259 .67542 Mdot
.74315 .4749 Mdot
.6295 .56383 Mdot
.37957 .61483 Mdot
.37638 .33236 Mdot
.36034 .39884 Mdot
.36649 .65687 Mdot
.31787 .66228 Mdot
.67848 .36214 Mdot
.69089 .36321 Mdot
.62581 .43135 Mdot
.38834 .65396 Mdot
.41723 .64045 Mdot
.56791 .58359 Mdot
.54178 .60488 Mdot
.62816 .45211 Mdot
.39584 .68216 Mdot
.61476 .42656 Mdot
.65691 .39523 Mdot
.28254 .47726 Mdot
.44754 .34978 Mdot
.28381 .48093 Mdot
.27338 .47711 Mdot
.63529 .24491 Mdot
.67684 .5724 Mdot
.31106 .50773 Mdot
.31966 .52002 Mdot
.33552 .58982 Mdot
.63036 .26652 Mdot
.58817 .67039 Mdot
.64374 .345 Mdot
.35574 .65783 Mdot
.58521 .40496 Mdot
.36725 .3431 Mdot
.53084 .60637 Mdot
.24914 .32752 Mdot
.81343 .55965 Mdot
.67188 .37872 Mdot
.37412 .63469 Mdot
.54017 .59328 Mdot
.53702 .5952 Mdot
.68635 .67348 Mdot
.61186 .42857 Mdot
.42143 .63631 Mdot
.61732 .27157 Mdot
.33164 .52193 Mdot
.31694 .60975 Mdot
.41097 .3209 Mdot
.60996 .41873 Mdot
.37949 .35563 Mdot
.27872 .53028 Mdot
.60168 .67298 Mdot
.61297 .69484 Mdot
.59739 .4546 Mdot
.68255 .34935 Mdot
.35148 .54056 Mdot
.69123 .35807 Mdot
.67898 .37286 Mdot
.54137 .58716 Mdot
.69636 .36973 Mdot
.6135 .39125 Mdot
.64341 .37806 Mdot
.52193 .56692 Mdot
.28113 .47877 Mdot
.61516 .25574 Mdot
.54648 .59917 Mdot
.56504 .45587 Mdot
.2761 .52831 Mdot
.68875 .35712 Mdot
.295 .50181 Mdot
.31739 .61751 Mdot
.30387 .49709 Mdot
.61075 .6867 Mdot
.42796 .63237 Mdot
.55272 .18381 Mdot
.42461 .33634 Mdot
.30066 .52535 Mdot
.60989 .72098 Mdot
.2932 .49818 Mdot
.35239 .66647 Mdot
.3269 .50201 Mdot
.41294 .28453 Mdot
.66626 .61912 Mdot
.65102 .25195 Mdot
.33075 .52127 Mdot
.41942 .63088 Mdot
.41074 .33542 Mdot
.3385 .55745 Mdot
.56381 .44289 Mdot
.61439 .6969 Mdot
.60496 .425 Mdot
.27672 .49893 Mdot
.36145 .64539 Mdot
.54249 .21412 Mdot
.60912 .69036 Mdot
.54362 .17646 Mdot
.39275 .68635 Mdot
.56797 .43851 Mdot
.26336 .51859 Mdot
.32519 .45488 Mdot
.26311 .49306 Mdot
.7214 .52795 Mdot
.56995 .59731 Mdot
.62394 .72981 Mdot
.38909 .34369 Mdot
.56316 .60834 Mdot
.74488 .70974 Mdot
.33183 .42462 Mdot
.42513 .36453 Mdot
.36382 .70813 Mdot
.5997 .44901 Mdot
.69491 .37309 Mdot
.56147 .57978 Mdot
.4231 .3295 Mdot
.6903 .37451 Mdot
.53759 .5565 Mdot
.70458 .58524 Mdot
.41909 .32312 Mdot
.35181 .69129 Mdot
.62851 .42259 Mdot
.25913 .48719 Mdot
.26886 .52232 Mdot
.55106 .5507 Mdot
.2838 .48349 Mdot
.56758 .46036 Mdot
.39375 .33641 Mdot
.68059 .35762 Mdot
.5821 .67503 Mdot
.37898 .41828 Mdot
.51911 .5879 Mdot
.5871 .72681 Mdot
.62936 .40391 Mdot
.36878 .65531 Mdot
.21156 .53002 Mdot
.57025 .39949 Mdot
.41941 .35018 Mdot
.56579 .42435 Mdot
.6939 .37182 Mdot
.69134 .36071 Mdot
.37937 .67996 Mdot
.67036 .58675 Mdot
.61473 .42543 Mdot
.29062 .53282 Mdot
.60624 .36474 Mdot
.55844 .40938 Mdot
.61974 .7237 Mdot
.6719 .35965 Mdot
.27643 .53535 Mdot
.37292 .3013 Mdot
.37157 .65613 Mdot
.40764 .35747 Mdot
.44374 .37393 Mdot
.37805 .33289 Mdot
.40637 .31398 Mdot
.64787 .42208 Mdot
.18441 .40737 Mdot
.54418 .23166 Mdot
.65516 .24939 Mdot
.4364 .373 Mdot
.19483 .54292 Mdot
.42726 .3645 Mdot
.37761 .33222 Mdot
.30763 .27871 Mdot
.37238 .33331 Mdot
.59039 .44187 Mdot
.5684 .42388 Mdot
.68651 .30368 Mdot
.38091 .5908 Mdot
.617 .40128 Mdot
.52383 .56002 Mdot
.58692 .71142 Mdot
.43743 .3274 Mdot
.54924 .58 Mdot
.67421 .60065 Mdot
.54873 .54637 Mdot
.59478 .43432 Mdot
.62145 .42088 Mdot
.69316 .35264 Mdot
.74947 .61389 Mdot
.40125 .59439 Mdot
.387 .32439 Mdot
.55579 .41349 Mdot
.23446 .47456 Mdot
.6238 .43061 Mdot
.56706 .41166 Mdot
.64588 .40592 Mdot
.3711 .65513 Mdot
.36357 .35048 Mdot
.56096 .5973 Mdot
.37209 .41925 Mdot
.61428 .40904 Mdot
.52117 .60144 Mdot
.57869 .70473 Mdot
.60755 .43512 Mdot
.37449 .32657 Mdot
.69246 .37286 Mdot
.39981 .36873 Mdot
.38485 .33843 Mdot
.62098 .39275 Mdot
.43714 .32813 Mdot
.38086 .36236 Mdot
.68994 .36367 Mdot
.36417 .63931 Mdot
.31991 .39786 Mdot
.59638 .44474 Mdot
.6072 .6957 Mdot
.5875 .41888 Mdot
.58739 .66912 Mdot
.53342 .55231 Mdot
.53927 .58874 Mdot
.61324 .32073 Mdot
.41325 .65605 Mdot
.60881 .72819 Mdot
.41953 .66765 Mdot
.55233 .45332 Mdot
.42326 .39661 Mdot
.32094 .4954 Mdot
.34695 .71807 Mdot
.53945 .58633 Mdot
.63777 .64286 Mdot
.55985 .38548 Mdot
.29935 .49148 Mdot
.42927 .36784 Mdot
.60257 .26302 Mdot
.5565 .61078 Mdot
.35079 .68996 Mdot
.36313 .68824 Mdot
.33389 .43063 Mdot
.31657 .27507 Mdot
.58116 .44809 Mdot
.55261 .6106 Mdot
.61182 .4792 Mdot
.54769 .5705 Mdot
.56691 .58616 Mdot
.40421 .65972 Mdot
.62096 .40269 Mdot
.70838 .58369 Mdot
.38899 .6661 Mdot
.58929 .69802 Mdot
.3942 .36049 Mdot
.60611 .67061 Mdot
.25731 .36138 Mdot
.55553 .19115 Mdot
.38198 .66377 Mdot
.52314 .57811 Mdot
.59328 .39791 Mdot
.36843 .327 Mdot
.37118 .3645 Mdot
.44202 .35715 Mdot
.57813 .68859 Mdot
.4134 .66573 Mdot
.34138 .75786 Mdot
.59318 .42224 Mdot
.40073 .34233 Mdot
.56996 .68874 Mdot
.59447 .41149 Mdot
.29505 .52561 Mdot
.68765 .3749 Mdot
.40802 .34085 Mdot
.67046 .38954 Mdot
.38819 .34308 Mdot
.36214 .68375 Mdot
.59208 .45452 Mdot
.61241 .44554 Mdot
.66191 .66492 Mdot
.59489 .70764 Mdot
.41204 .37197 Mdot
.66773 .5667 Mdot
.60421 .38255 Mdot
.69246 .67029 Mdot
.61599 .43069 Mdot
.65412 .25313 Mdot
.57445 .57561 Mdot
.53842 .55465 Mdot
.56677 .41891 Mdot
.60011 .44369 Mdot
.36849 .36176 Mdot
.54582 .23415 Mdot
.55909 .19714 Mdot
.27457 .52476 Mdot
.43372 .36314 Mdot
.39018 .66236 Mdot
.39534 .69251 Mdot
.36421 .64853 Mdot
.58182 .66472 Mdot
.68466 .35703 Mdot
.57881 .43845 Mdot
.30673 .5369 Mdot
.59081 .71217 Mdot
.40094 .34784 Mdot
.60253 .68135 Mdot
.67524 .57908 Mdot
.60667 .70089 Mdot
.56266 .56433 Mdot
.17938 .58997 Mdot
.6566 .3957 Mdot
.59736 .69824 Mdot
.44672 .34756 Mdot
.61597 .36183 Mdot
.63979 .41678 Mdot
.54532 .18991 Mdot
.59719 .72251 Mdot
.35675 .7071 Mdot
.63009 .40848 Mdot
.70869 .51551 Mdot
.28972 .49985 Mdot
.60903 .67221 Mdot
.27777 .49108 Mdot
.67697 .37728 Mdot
.3474 .37929 Mdot
.41975 .34548 Mdot
.28677 .47648 Mdot
.57164 .40577 Mdot
.60942 .6727 Mdot
.37773 .6661 Mdot
.62917 .26751 Mdot
.32469 .59202 Mdot
.53416 .616 Mdot
.68348 .67083 Mdot
.40444 .63423 Mdot
.64808 .267 Mdot
.2877 .48773 Mdot
.5818 .38354 Mdot
.66212 .39164 Mdot
.6168 .38522 Mdot
.39736 .65741 Mdot
.37087 .66698 Mdot
.32238 .7184 Mdot
.60844 .45027 Mdot
.64479 .40857 Mdot
.39197 .29249 Mdot
.41561 .66162 Mdot
.37849 .33355 Mdot
.41468 .32628 Mdot
.3978 .67094 Mdot
.42665 .37152 Mdot
.59733 .69063 Mdot
.70376 .56053 Mdot
.29002 .48869 Mdot
.26335 .51311 Mdot
.38042 .66274 Mdot
.40332 .64357 Mdot
.36864 .65464 Mdot
.68133 .379 Mdot
.38304 .33615 Mdot
.58783 .46217 Mdot
.60309 .42027 Mdot
.63882 .40942 Mdot
.39308 .31967 Mdot
.56141 .43504 Mdot
.60649 .37044 Mdot
.5769 .69599 Mdot
.36153 .67222 Mdot
.26845 .50736 Mdot
.6921 .46847 Mdot
.2895 .53367 Mdot
.59238 .39017 Mdot
.32181 .39087 Mdot
.42394 .36829 Mdot
.60718 .70865 Mdot
.68165 .35144 Mdot
.61099 .69449 Mdot
.28238 .47715 Mdot
.39661 .2932 Mdot
.68806 .60173 Mdot
.58809 .45956 Mdot
.66971 .57398 Mdot
.55453 .79854 Mdot
.47178 .35295 Mdot
.27582 .51203 Mdot
.65737 .3894 Mdot
.55335 .54815 Mdot
.62551 .46038 Mdot
.58287 .44337 Mdot
.5615 .40298 Mdot
.70081 .51347 Mdot
.57749 .403 Mdot
.44991 .34697 Mdot
.61098 .36719 Mdot
.52579 .58959 Mdot
.63544 .41029 Mdot
.19289 .40868 Mdot
.61015 .40058 Mdot
.59573 .45755 Mdot
.57629 .42598 Mdot
.59265 .38312 Mdot
.38969 .31833 Mdot
.68472 .35261 Mdot
.28396 .53161 Mdot
.70435 .56088 Mdot
.29306 .49075 Mdot
.38185 .65737 Mdot
.54048 .61227 Mdot
.35845 .33027 Mdot
.61098 .69571 Mdot
.39381 .57266 Mdot
.71256 .51704 Mdot
.35373 .65657 Mdot
.65141 .65909 Mdot
.6207 .69734 Mdot
.56495 .57905 Mdot
.59157 .66102 Mdot
.40157 .65826 Mdot
.30013 .52142 Mdot
.57911 .45157 Mdot
.39446 .3315 Mdot
.43211 .34022 Mdot
.63456 .40971 Mdot
.31753 .40522 Mdot
.26747 .51944 Mdot
.39093 .71017 Mdot
.57689 .4415 Mdot
.59046 .38939 Mdot
.39121 .36528 Mdot
.37844 .63538 Mdot
.56186 .38487 Mdot
.58554 .6812 Mdot
.6248 .42681 Mdot
.53013 .59427 Mdot
.67412 .57824 Mdot
.27686 .52632 Mdot
.53408 .56793 Mdot
.59497 .40071 Mdot
.68316 .57938 Mdot
.68429 .38458 Mdot
.49912 .57041 Mdot
.41074 .62372 Mdot
.6232 .39476 Mdot
.61661 .44114 Mdot
.41607 .32238 Mdot
.28638 .48662 Mdot
.42086 .35544 Mdot
.38639 .28656 Mdot
.53922 .58799 Mdot
.26559 .48889 Mdot
.59515 .38272 Mdot
.31546 .53969 Mdot
.68883 .37293 Mdot
.59583 .42583 Mdot
.27643 .51011 Mdot
.38073 .34283 Mdot
.21905 .37086 Mdot
.61372 .2559 Mdot
.67858 .37533 Mdot
.58844 .41599 Mdot
.3816 .59117 Mdot
.53005 .60577 Mdot
.57466 .45467 Mdot
.43304 .33858 Mdot
.59476 .41293 Mdot
.32328 .52699 Mdot
.60473 .67717 Mdot
.42369 .34995 Mdot
.38698 .63139 Mdot
.36775 .68483 Mdot
.41688 .62262 Mdot
.56473 .56892 Mdot
.69644 .36936 Mdot
.43393 .32938 Mdot
.42422 .3276 Mdot
.65261 .56398 Mdot
.36281 .67509 Mdot
.59529 .6777 Mdot
.62785 .43066 Mdot
.54714 .60929 Mdot
.25681 .50421 Mdot
.49572 .14302 Mdot
.6903 .59833 Mdot
.57357 .67424 Mdot
.56702 .50801 Mdot
.54217 .58338 Mdot
.58995 .39737 Mdot
.6099 .6746 Mdot
.39691 .67021 Mdot
.69523 .37671 Mdot
.50141 .59919 Mdot
.35558 .70802 Mdot
.38535 .64002 Mdot
.31103 .54008 Mdot
.39945 .62583 Mdot
.60899 .66889 Mdot
.55295 .55576 Mdot
.43055 .34569 Mdot
.61033 .43254 Mdot
.5517 .59475 Mdot
.35676 .67306 Mdot
.56302 .60312 Mdot
.57134 .43786 Mdot
.39393 .36479 Mdot
.3591 .65545 Mdot
.5915 .43666 Mdot
.65235 .41063 Mdot
.54747 .199 Mdot
.36796 .63816 Mdot
.58148 .46667 Mdot
.47722 .60697 Mdot
.38026 .64291 Mdot
.39937 .6554 Mdot
.61859 .3904 Mdot
.61906 .69023 Mdot
.61229 .41251 Mdot
.29553 .52369 Mdot
.66609 .58045 Mdot
.27129 .48575 Mdot
.68763 .67633 Mdot
.63268 .4031 Mdot
.60107 .4766 Mdot
.43217 .39556 Mdot
.57694 .72013 Mdot
.72475 .65026 Mdot
.60636 .39117 Mdot
.37619 .36263 Mdot
.66785 .58788 Mdot
.66093 .61285 Mdot
.43554 .29014 Mdot
.59582 .66781 Mdot
.28486 .49854 Mdot
.60734 .4487 Mdot
.20121 .4066 Mdot
.58984 .67303 Mdot
.6876 .67396 Mdot
.55842 .43035 Mdot
.40942 .34774 Mdot
.58226 .44721 Mdot
.42507 .34317 Mdot
.58935 .40849 Mdot
.543 .20673 Mdot
.35128 .54045 Mdot
.72088 .52752 Mdot
.55979 .56745 Mdot
.32506 .45478 Mdot
.65148 .25157 Mdot
.59666 .68642 Mdot
.66344 .39008 Mdot
.54013 .57733 Mdot
.30443 .51584 Mdot
.22605 .52615 Mdot
.36615 .65595 Mdot
.29827 .53129 Mdot
.39884 .35717 Mdot
.34909 .65998 Mdot
.56406 .60665 Mdot
.5902 .4817 Mdot
.61272 .67624 Mdot
.26502 .48937 Mdot
.60654 .43891 Mdot
.62788 .38193 Mdot
.35156 .58898 Mdot
.43697 .82176 Mdot
.45864 .35262 Mdot
.54315 .17256 Mdot
.39592 .29302 Mdot
.59006 .70401 Mdot
.36056 .64247 Mdot
.58011 .42934 Mdot
.62184 .40834 Mdot
.38775 .63891 Mdot
.36715 .32755 Mdot
.61328 .72173 Mdot
.62337 .73151 Mdot
.31655 .53374 Mdot
.48864 .83394 Mdot
.42575 .34922 Mdot
.48609 .83381 Mdot
.3301 .73738 Mdot
.33817 .26864 Mdot
.72026 .6536 Mdot
.28486 .51723 Mdot
.48765 .83426 Mdot
.40536 .34544 Mdot
.57268 .41661 Mdot
.53322 .57924 Mdot
.56821 .57877 Mdot
.38646 .36013 Mdot
.38445 .65278 Mdot
.61957 .68446 Mdot
.587 .44844 Mdot
.49731 .55535 Mdot
.36928 .36353 Mdot
.41007 .66776 Mdot
.55239 .5734 Mdot
.2691 .51291 Mdot
.592 .41276 Mdot
.57783 .69383 Mdot
.28606 .51652 Mdot
.52815 .56324 Mdot
.7085 .53895 Mdot
.57444 .46471 Mdot
.68852 .34639 Mdot
.29182 .50185 Mdot
.56849 .50854 Mdot
.61808 .43665 Mdot
.28748 .48768 Mdot
.55812 .54509 Mdot
.30366 .44242 Mdot
.54187 .41536 Mdot
.33183 .4247 Mdot
.34441 .67817 Mdot
.38241 .62806 Mdot
.40238 .72836 Mdot
.424 .61148 Mdot
.30677 .5047 Mdot
.54948 .58949 Mdot
.41535 .81649 Mdot
.28228 .48558 Mdot
.56657 .40682 Mdot
.60374 .44926 Mdot
.61614 .27186 Mdot
.52537 .56706 Mdot
.54767 .55944 Mdot
.3372 .35255 Mdot
.66446 .37404 Mdot
.55233 .57545 Mdot
.61884 .4308 Mdot
.38268 .32175 Mdot
.27708 .51895 Mdot
.83626 .60141 Mdot
.31891 .50216 Mdot
.70504 .36196 Mdot
.35662 .65495 Mdot
.34406 .67487 Mdot
.60773 .4335 Mdot
.44945 .58444 Mdot
.86784 .45887 Mdot
.6045 .44929 Mdot
.68035 .35237 Mdot
.68494 .67766 Mdot
.63571 .40788 Mdot
.44881 .35892 Mdot
.52597 .58065 Mdot
.4004 .32157 Mdot
.28275 .51258 Mdot
.59526 .66814 Mdot
.56668 .66858 Mdot
.28522 .4992 Mdot
.6149 .40462 Mdot
.51754 .57342 Mdot
.60238 .42995 Mdot
.5738 .41988 Mdot
.68181 .5831 Mdot
.57535 .67263 Mdot
.37521 .65185 Mdot
.61209 .69131 Mdot
.37526 .33233 Mdot
.52473 .15925 Mdot
.59837 .68337 Mdot
.62949 .26692 Mdot
.66423 .57134 Mdot
.42264 .81614 Mdot
.43313 .34177 Mdot
.58349 .6708 Mdot
.28492 .49675 Mdot
.64074 .58436 Mdot
.65372 .27534 Mdot
.29632 .53282 Mdot
.57556 .4191 Mdot
.40125 .32334 Mdot
.37288 .29887 Mdot
.27004 .52715 Mdot
.43652 .35249 Mdot
.53844 .4426 Mdot
.67574 .37242 Mdot
.28274 .53172 Mdot
.73714 .63181 Mdot
.26113 .49744 Mdot
.62542 .24388 Mdot
.68881 .37071 Mdot
.4211 .34995 Mdot
.66541 .25039 Mdot
.40267 .29268 Mdot
.5434 .55538 Mdot
.56608 .43992 Mdot
.59603 .68081 Mdot
.65891 .56584 Mdot
.37895 .632 Mdot
.43453 .32075 Mdot
.41155 .33791 Mdot
.25582 .50552 Mdot
.43574 .35159 Mdot
.42736 .36927 Mdot
.28488 .47611 Mdot
.43073 .3645 Mdot
.61484 .40864 Mdot
.55847 .17193 Mdot
.44018 .35497 Mdot
.28983 .50833 Mdot
.57938 .69133 Mdot
.44884 .34982 Mdot
.31626 .67675 Mdot
.62943 .42056 Mdot
.36876 .69853 Mdot
.60516 .65328 Mdot
.38749 .31897 Mdot
.59493 .68482 Mdot
.35573 .66922 Mdot
.59788 .7262 Mdot
.29391 .54586 Mdot
.28812 .54284 Mdot
.57876 .58892 Mdot
.33756 .44045 Mdot
.37281 .33329 Mdot
.3504 .65593 Mdot
.61986 .44322 Mdot
.57328 .43459 Mdot
.58552 .64962 Mdot
.40223 .37092 Mdot
.31301 .40384 Mdot
.55025 .57927 Mdot
.38202 .41848 Mdot
.27089 .5228 Mdot
.38846 .71109 Mdot
.68847 .60337 Mdot
.33009 .5715 Mdot
.52505 .58861 Mdot
.54096 .58222 Mdot
.60057 .4355 Mdot
.66745 .66891 Mdot
.60533 .66719 Mdot
.19514 .55364 Mdot
.67213 .38317 Mdot
.39404 .63751 Mdot
.58489 .40936 Mdot
.66992 .36862 Mdot
.61042 .39041 Mdot
.57405 .66976 Mdot
.31161 .52686 Mdot
.42725 .33678 Mdot
.58553 .66885 Mdot
.36843 .68527 Mdot
.74303 .49521 Mdot
.57634 .45679 Mdot
.58975 .46809 Mdot
.38267 .64678 Mdot
.38186 .32908 Mdot
.37581 .66086 Mdot
.28992 .4888 Mdot
.60097 .68403 Mdot
.6884 .37592 Mdot
.525 .56811 Mdot
.38049 .70065 Mdot
.30271 .52456 Mdot
.36175 .64035 Mdot
.32625 .5316 Mdot
.53882 .58395 Mdot
.59034 .47102 Mdot
.42269 .63973 Mdot
.54574 .60404 Mdot
.55962 .28604 Mdot
.70577 .53719 Mdot
.39554 .26729 Mdot
.3868 .6515 Mdot
.36786 .61933 Mdot
.28764 .51364 Mdot
.3051 .4898 Mdot
.62465 .24085 Mdot
.84686 .40288 Mdot
.59404 .36813 Mdot
.30084 .41738 Mdot
.29137 .48916 Mdot
.2972 .50826 Mdot
.37422 .65866 Mdot
.3799 .34472 Mdot
.45166 .39074 Mdot
.34869 .67644 Mdot
.70576 .66076 Mdot
.40083 .34759 Mdot
.68481 .30085 Mdot
.40057 .68229 Mdot
.6936 .35968 Mdot
.54165 .21375 Mdot
.58003 .7047 Mdot
.67895 .66878 Mdot
.32492 .49989 Mdot
.58707 .43848 Mdot
.18517 .40479 Mdot
.36465 .65925 Mdot
.55817 .60465 Mdot
.24164 .47141 Mdot
.61856 .37875 Mdot
.58401 .40785 Mdot
.60412 .41087 Mdot
.60527 .65963 Mdot
.54626 .24839 Mdot
.58363 .43521 Mdot
.71243 .53197 Mdot
.706 .3499 Mdot
.33701 .68836 Mdot
.61169 .68981 Mdot
.64451 .65307 Mdot
.3244 .63228 Mdot
.36798 .41981 Mdot
.56056 .40401 Mdot
.31834 .50894 Mdot
.66704 .36966 Mdot
.27512 .50814 Mdot
.28527 .53722 Mdot
.51057 .84114 Mdot
.43062 .33466 Mdot
.67469 .38166 Mdot
.40912 .6594 Mdot
.45055 .39181 Mdot
.67346 .36527 Mdot
.53181 .16374 Mdot
.25694 .48277 Mdot
.85093 .3568 Mdot
.30184 .48843 Mdot
.56742 .59507 Mdot
.40688 .36139 Mdot
.37656 .36469 Mdot
.67109 .57355 Mdot
.3783 .33525 Mdot
.42083 .6074 Mdot
.43748 .33192 Mdot
.6346 .78171 Mdot
.42214 .28699 Mdot
.29262 .51524 Mdot
.26543 .52247 Mdot
.68874 .35391 Mdot
.61666 .41331 Mdot
.70635 .58515 Mdot
.55037 .57815 Mdot
.5671 .45427 Mdot
.38925 .66642 Mdot
.31793 .70021 Mdot
.19941 .50246 Mdot
.42762 .36587 Mdot
.30714 .51954 Mdot
.58351 .40937 Mdot
.68625 .37292 Mdot
.56745 .4272 Mdot
.34294 .56535 Mdot
.70568 .3017 Mdot
.60237 .42232 Mdot
.6865 .35615 Mdot
.34975 .66721 Mdot
.35328 .58963 Mdot
.32301 .27292 Mdot
.50053 .83747 Mdot
.62152 .40036 Mdot
.59035 .70828 Mdot
.57729 .6672 Mdot
.64835 .37416 Mdot
.52807 .48433 Mdot
.58545 .53083 Mdot
.60568 .43969 Mdot
.7433 .48885 Mdot
.35375 .69495 Mdot
.55384 .54965 Mdot
.3582 .67463 Mdot
.43375 .37579 Mdot
.54342 .54971 Mdot
.39475 .66632 Mdot
.72759 .5477 Mdot
.54357 .5927 Mdot
.29285 .44512 Mdot
.58188 .67452 Mdot
.61906 .43263 Mdot
.59397 .24346 Mdot
.41554 .66265 Mdot
.29664 .52065 Mdot
.41941 .36296 Mdot
.27795 .52607 Mdot
.42726 .62094 Mdot
.69739 .66991 Mdot
.53838 .55788 Mdot
.31995 .51181 Mdot
.67453 .35581 Mdot
.59232 .71204 Mdot
.29283 .48434 Mdot
.70375 .3566 Mdot
.64311 .37433 Mdot
.85135 .44297 Mdot
.61842 .44798 Mdot
.31938 .70739 Mdot
.27227 .48422 Mdot
.55188 .54682 Mdot
.61095 .43112 Mdot
.38627 .69093 Mdot
.56439 .54185 Mdot
.60048 .4303 Mdot
.39882 .6314 Mdot
.6063 .44647 Mdot
.61083 .67908 Mdot
.40921 .32167 Mdot
.66723 .59209 Mdot
.61004 .74627 Mdot
.59236 .66805 Mdot
.71222 .51378 Mdot
.56874 .44795 Mdot
.43642 .61369 Mdot
.41114 .35028 Mdot
.59118 .39121 Mdot
.64588 .75268 Mdot
.38756 .35563 Mdot
.40251 .35518 Mdot
.70154 .36987 Mdot
.32581 .52199 Mdot
.37848 .64957 Mdot
.60311 .71305 Mdot
.31768 .60631 Mdot
.58816 .43601 Mdot
.66675 .38851 Mdot
.58784 .67137 Mdot
.28702 .52452 Mdot
.6748 .37929 Mdot
.26954 .44238 Mdot
.70491 .55665 Mdot
.27487 .47897 Mdot
.56547 .39822 Mdot
.70368 .29269 Mdot
.36231 .33563 Mdot
.18557 .4074 Mdot
.35151 .5397 Mdot
.36487 .68742 Mdot
.55376 .57678 Mdot
.50138 .14662 Mdot
.57805 .68728 Mdot
.47701 .37804 Mdot
.57206 .43679 Mdot
.58152 .42263 Mdot
.37487 .32283 Mdot
.59501 .46053 Mdot
.42763 .36702 Mdot
.31671 .672 Mdot
.84834 .39255 Mdot
.42962 .34192 Mdot
.41406 .34208 Mdot
.69796 .33517 Mdot
.42402 .65286 Mdot
.39706 .36207 Mdot
.61363 .44602 Mdot
.42708 .61991 Mdot
.50234 .55336 Mdot
.61033 .72339 Mdot
.6136 .6661 Mdot
.45096 .35991 Mdot
.65788 .27552 Mdot
.70089 .35534 Mdot
.60731 .30927 Mdot
.58969 .53958 Mdot
.30674 .50318 Mdot
.6355 .38979 Mdot
.54679 .58001 Mdot
.35853 .66693 Mdot
.63943 .42118 Mdot
.62068 .42849 Mdot
.42092 .33349 Mdot
.5906 .72037 Mdot
.27744 .48839 Mdot
.5481 .60416 Mdot
.41579 .61905 Mdot
.58754 .68999 Mdot
.42583 .37107 Mdot
.64455 .24815 Mdot
.52086 .58976 Mdot
.5464 .60814 Mdot
.59266 .39446 Mdot
.61891 .39181 Mdot
.52275 .58751 Mdot
.28417 .50104 Mdot
.36523 .68913 Mdot
.56036 .59678 Mdot
.64002 .56286 Mdot
.71396 .57446 Mdot
.60339 .39326 Mdot
.4437 .34442 Mdot
.30559 .51753 Mdot
.54448 .55738 Mdot
.40835 .81271 Mdot
.6322 .42237 Mdot
.68787 .30057 Mdot
.62553 .70668 Mdot
.54704 .58499 Mdot
.45244 .39056 Mdot
.61048 .70324 Mdot
.68824 .37102 Mdot
.71561 .53093 Mdot
.56264 .44529 Mdot
.58088 .38416 Mdot
.39908 .66698 Mdot
.27427 .49767 Mdot
.578 .59549 Mdot
.36203 .67091 Mdot
.40584 .35673 Mdot
.61026 .31263 Mdot
.40856 .32598 Mdot
.4288 .32955 Mdot
.41102 .3155 Mdot
.27289 .52225 Mdot
.50083 .14573 Mdot
.52431 .59395 Mdot
.58392 .45158 Mdot
.31357 .51647 Mdot
.40466 .3652 Mdot
.56064 .42916 Mdot
.42444 .36817 Mdot
.4137 .37271 Mdot
.56347 .44894 Mdot
.68747 .35966 Mdot
.71653 .525 Mdot
.68529 .29156 Mdot
.61431 .69237 Mdot
.36807 .33114 Mdot
.67204 .28575 Mdot
.58138 .43001 Mdot
.62135 .41939 Mdot
.68814 .35283 Mdot
.59 .66488 Mdot
.61135 .32004 Mdot
.57181 .43249 Mdot
.6667 .67346 Mdot
.56171 .4214 Mdot
.40087 .37105 Mdot
.31349 .44929 Mdot
.70553 .36036 Mdot
.34883 .66354 Mdot
.36768 .32663 Mdot
.58014 .70543 Mdot
.35177 .33027 Mdot
.64876 .41596 Mdot
.29648 .50026 Mdot
.40815 .34093 Mdot
.35063 .6822 Mdot
.29302 .52169 Mdot
.2612 .49787 Mdot
.68969 .35136 Mdot
.37493 .69013 Mdot
.58948 .71958 Mdot
.26595 .49748 Mdot
.63073 .45556 Mdot
.29351 .51649 Mdot
.48579 .33349 Mdot
.59358 .46829 Mdot
.7134 .5332 Mdot
.56007 .58376 Mdot
.57563 .57866 Mdot
.26859 .489 Mdot
.58496 .67989 Mdot
.67438 .37964 Mdot
.43901 .35888 Mdot
.58254 .69805 Mdot
.54282 .2178 Mdot
.34448 .67262 Mdot
.37433 .29876 Mdot
.32269 .59511 Mdot
.37325 .34474 Mdot
.68161 .66957 Mdot
.57415 .69121 Mdot
.54957 .61181 Mdot
.67693 .59391 Mdot
.55069 .56876 Mdot
.63539 .42957 Mdot
.67349 .3802 Mdot
.61381 .40742 Mdot
.35684 .65383 Mdot
.60766 .66191 Mdot
.44328 .35165 Mdot
.49062 .60183 Mdot
.28226 .525 Mdot
.63894 .36858 Mdot
.56001 .60113 Mdot
.67951 .37625 Mdot
.41471 .36659 Mdot
.3773 .36069 Mdot
.54646 .23686 Mdot
.37753 .64284 Mdot
.52327 .62277 Mdot
.60377 .39415 Mdot
.48239 .58064 Mdot
.26831 .48837 Mdot
.33256 .42603 Mdot
.36364 .6995 Mdot
.84942 .35438 Mdot
.36403 .67302 Mdot
.50098 .58658 Mdot
.37481 .35507 Mdot
.60481 .69518 Mdot
.61716 .40343 Mdot
.4151 .32138 Mdot
.45767 .38878 Mdot
.57884 .64145 Mdot
.61011 .69781 Mdot
.33995 .55515 Mdot
.31029 .50528 Mdot
.54323 .60459 Mdot
.56224 .41817 Mdot
.55979 .43366 Mdot
.61538 .44741 Mdot
.30998 .51728 Mdot
.68033 .36661 Mdot
.32376 .45618 Mdot
.65509 .39654 Mdot
.64698 .7526 Mdot
.40002 .65037 Mdot
.23761 .69253 Mdot
.39013 .31993 Mdot
.61144 .31753 Mdot
.49555 .36206 Mdot
.70469 .54101 Mdot
.31274 .52875 Mdot
.55622 .54323 Mdot
.37648 .65454 Mdot
.22639 .5382 Mdot
.40167 .65074 Mdot
.86174 .53818 Mdot
.6148 .27148 Mdot
.3084 .44687 Mdot
.56577 .44836 Mdot
.39835 .67422 Mdot
.66391 .27549 Mdot
.55937 .59642 Mdot
.51768 .5722 Mdot
.66292 .39578 Mdot
.55726 .19722 Mdot
.61432 .68965 Mdot
.6157 .40141 Mdot
.39744 .32169 Mdot
.61886 .4051 Mdot
.6184 .40324 Mdot
.56961 .43231 Mdot
.27606 .47472 Mdot
.58846 .47051 Mdot
.61606 .41118 Mdot
.34801 .76734 Mdot
.53731 .53194 Mdot
.40127 .62482 Mdot
.36661 .35832 Mdot
.59091 .71226 Mdot
.43203 .37591 Mdot
.67125 .5933 Mdot
.30274 .48687 Mdot
.54517 .23954 Mdot
.68571 .36771 Mdot
.45181 .33492 Mdot
.31786 .50221 Mdot
.61922 .6991 Mdot
.54394 .57878 Mdot
.25507 .32059 Mdot
.42001 .66675 Mdot
.54151 .56533 Mdot
.38888 .63254 Mdot
.6116 .47034 Mdot
.43054 .34765 Mdot
.55049 .56967 Mdot
.27292 .49249 Mdot
.40458 .65787 Mdot
.71389 .5165 Mdot
.59496 .41665 Mdot
.39052 .65265 Mdot
.55161 .59235 Mdot
.65994 .5664 Mdot
.66815 .58653 Mdot
.40046 .67241 Mdot
.30385 .5387 Mdot
.26313 .50546 Mdot
.58495 .7066 Mdot
.36922 .35267 Mdot
.38879 .33018 Mdot
.28105 .52258 Mdot
.23299 .54716 Mdot
.59037 .4373 Mdot
.59484 .42416 Mdot
.68114 .60106 Mdot
.57988 .39509 Mdot
.41241 .60033 Mdot
.54351 .56695 Mdot
.40466 .33271 Mdot
.673 .38012 Mdot
.66646 .38058 Mdot
.61239 .40009 Mdot
.70819 .66235 Mdot
.35659 .65717 Mdot
.69993 .35293 Mdot
.60952 .67366 Mdot
.55266 .20215 Mdot
.62581 .42821 Mdot
.5962 .73759 Mdot
.37157 .3529 Mdot
.22384 .48398 Mdot
.29771 .51963 Mdot
.41149 .65761 Mdot
.41004 .65903 Mdot
.55816 .79846 Mdot
.38577 .32027 Mdot
.54262 .56524 Mdot
.35307 .70742 Mdot
.55876 .55935 Mdot
.60845 .70183 Mdot
.54243 .40655 Mdot
.41506 .60243 Mdot
.40095 .62505 Mdot
.32889 .54135 Mdot
.61651 .38046 Mdot
.62557 .4248 Mdot
.3292 .41644 Mdot
.61698 .42891 Mdot
.59932 .67754 Mdot
.3034 .49343 Mdot
.40775 .34212 Mdot
.61627 .69446 Mdot
.31628 .50354 Mdot
.37925 .33188 Mdot
.69387 .35307 Mdot
.56075 .42556 Mdot
.41145 .36011 Mdot
.41639 .37099 Mdot
.59111 .44296 Mdot
.52832 .84635 Mdot
.42027 .33488 Mdot
.41462 .36284 Mdot
.55363 .20157 Mdot
.42046 .63547 Mdot
.56185 .54026 Mdot
.32426 .52253 Mdot
.61177 .41078 Mdot
.39639 .64706 Mdot
.60128 .70437 Mdot
.40669 .33662 Mdot
.61833 .39396 Mdot
.58841 .43273 Mdot
.59083 .71012 Mdot
.60293 .66236 Mdot
.5821 .68624 Mdot
.27076 .52771 Mdot
.69111 .36338 Mdot
.40421 .36285 Mdot
.30378 .53044 Mdot
.57594 .68948 Mdot
.60881 .66644 Mdot
.67422 .74928 Mdot
.59079 .44006 Mdot
.59929 .65966 Mdot
.5177 .15542 Mdot
.73249 .53816 Mdot
.5547 .55359 Mdot
.37688 .62604 Mdot
.41964 .61628 Mdot
.51013 .55027 Mdot
.27668 .49628 Mdot
.6709 .36176 Mdot
.61314 .71865 Mdot
.55448 .59591 Mdot
.59494 .42074 Mdot
.63541 .40038 Mdot
.58494 .69967 Mdot
.69701 .67194 Mdot
.41803 .33121 Mdot
.36952 .26585 Mdot
.59257 .71321 Mdot
.40003 .67584 Mdot
.3582 .69964 Mdot
.36991 .6701 Mdot
.6084 .39317 Mdot
.69329 .31908 Mdot
.55578 .4914 Mdot
.54303 .33987 Mdot
.3073 .50106 Mdot
.38259 .36335 Mdot
.55124 .19612 Mdot
.39975 .35354 Mdot
.37038 .64209 Mdot
.58545 .67923 Mdot
.37821 .32344 Mdot
.26466 .51596 Mdot
.26323 .498 Mdot
.4223 .64027 Mdot
.36329 .6768 Mdot
.37999 .6649 Mdot
.36463 .32471 Mdot
.38902 .36259 Mdot
.56356 .44188 Mdot
.44118 .34491 Mdot
.31806 .66997 Mdot
.31725 .66656 Mdot
.42009 .65325 Mdot
.28526 .50609 Mdot
.38546 .33866 Mdot
.61321 .44365 Mdot
.69839 .51345 Mdot
.36662 .70566 Mdot
.59067 .7172 Mdot
.55784 .17161 Mdot
.84573 .40992 Mdot
.66147 .38722 Mdot
.30168 .50096 Mdot
.55611 .56119 Mdot
.60454 .40775 Mdot
.36256 .68772 Mdot
.52639 .61236 Mdot
.52611 .57695 Mdot
.60067 .46204 Mdot
.56487 .4626 Mdot
.30358 .51153 Mdot
.66989 .59599 Mdot
.55439 .59831 Mdot
.70541 .34446 Mdot
.31204 .5031 Mdot
.38532 .697 Mdot
.37882 .73692 Mdot
.33886 .37952 Mdot
.61672 .61241 Mdot
.53219 .55825 Mdot
.63126 .4279 Mdot
.38893 .67041 Mdot
.61751 .69342 Mdot
.38447 .67063 Mdot
.43831 .37264 Mdot
.42109 .63309 Mdot
.61147 .44264 Mdot
.39878 .36113 Mdot
.26246 .49776 Mdot
.63408 .58199 Mdot
.5609 .64078 Mdot
.38908 .69 Mdot
.54427 .61024 Mdot
.66568 .37401 Mdot
.59645 .48179 Mdot
.57532 .5768 Mdot
.6215 .43125 Mdot
.27589 .51024 Mdot
.42325 .36703 Mdot
.29224 .52781 Mdot
.56793 .54629 Mdot
.48477 .3569 Mdot
.29911 .51875 Mdot
.69255 .32454 Mdot
.61947 .68321 Mdot
.70089 .66808 Mdot
.60418 .44378 Mdot
.27242 .49506 Mdot
.59129 .4671 Mdot
.36946 .32904 Mdot
.7204 .55899 Mdot
.70504 .55242 Mdot
.27598 .51761 Mdot
.56941 .60096 Mdot
.66284 .5705 Mdot
.56173 .53955 Mdot
.29171 .48994 Mdot
.73816 .53028 Mdot
.53621 .57065 Mdot
.59047 .69321 Mdot
.61092 .66687 Mdot
.58929 .68522 Mdot
.6012 .42074 Mdot
.69231 .27683 Mdot
.57574 .67869 Mdot
.22626 .51829 Mdot
.60108 .67302 Mdot
.51082 .54607 Mdot
.31403 .40104 Mdot
.60932 .66958 Mdot
.61176 .43605 Mdot
.65626 .39262 Mdot
.67448 .35796 Mdot
.35917 .69214 Mdot
.2381 .34072 Mdot
.34592 .76461 Mdot
.57973 .4292 Mdot
.54987 .18646 Mdot
.42362 .32497 Mdot
.54875 .61296 Mdot
.70514 .54898 Mdot
.69191 .34359 Mdot
.39388 .35232 Mdot
.6742 .59475 Mdot
.37004 .30521 Mdot
.56367 .57892 Mdot
.59812 .42477 Mdot
.36822 .32569 Mdot
.43299 .31994 Mdot
.72568 .6489 Mdot
.3609 .41659 Mdot
.38317 .3348 Mdot
.28637 .48651 Mdot
.28002 .49612 Mdot
.27521 .5125 Mdot
.36531 .68157 Mdot
.41357 .34056 Mdot
.63258 .37317 Mdot
.36335 .68587 Mdot
.57405 .42296 Mdot
.27777 .52017 Mdot
.70821 .54566 Mdot
.41305 .34231 Mdot
.60334 .44196 Mdot
.66372 .2818 Mdot
.40186 .6332 Mdot
.58895 .70757 Mdot
.5509 .18116 Mdot
.36436 .63622 Mdot
.31613 .53908 Mdot
.44626 .37071 Mdot
.53674 .53366 Mdot
.70255 .34396 Mdot
.60428 .38884 Mdot
.57922 .45272 Mdot
.70242 .34281 Mdot
.61706 .26754 Mdot
.53099 .59269 Mdot
.36829 .68503 Mdot
.41873 .63203 Mdot
.62997 .42411 Mdot
.41831 .33954 Mdot
.57092 .68777 Mdot
.60325 .73351 Mdot
.50349 .60386 Mdot
.66823 .57785 Mdot
.71225 .53233 Mdot
.58899 .38587 Mdot
.62951 .32974 Mdot
.35387 .68579 Mdot
.56143 .55944 Mdot
.67402 .57995 Mdot
.59566 .68929 Mdot
.57235 .41847 Mdot
.39195 .37629 Mdot
.40432 .33804 Mdot
.38475 .65092 Mdot
.25939 .48717 Mdot
.51949 .58594 Mdot
.4207 .65272 Mdot
.63005 .42359 Mdot
.66897 .38032 Mdot
.28429 .48369 Mdot
.44501 .3687 Mdot
.58818 .69723 Mdot
.3594 .6832 Mdot
.60243 .69254 Mdot
.43377 .35304 Mdot
.40589 .336 Mdot
.5756 .40695 Mdot
.5132 .6173 Mdot
.39156 .68966 Mdot
.61298 .39608 Mdot
.39135 .65735 Mdot
.35071 .58905 Mdot
.25767 .50758 Mdot
.58667 .39432 Mdot
.43977 .3942 Mdot
.27446 .51927 Mdot
.57793 .42476 Mdot
.68283 .35249 Mdot
.67481 .3787 Mdot
.39755 .67615 Mdot
.61153 .72877 Mdot
.59493 .69464 Mdot
.50159 .3623 Mdot
.53957 .22892 Mdot
.59975 .38166 Mdot
.41691 .65591 Mdot
.65977 .40175 Mdot
.29981 .50784 Mdot
.37352 .35005 Mdot
.18941 .62948 Mdot
.29164 .50957 Mdot
.60246 .44742 Mdot
.59845 .68244 Mdot
.41722 .37214 Mdot
.54734 .54913 Mdot
.68614 .62758 Mdot
.57395 .59851 Mdot
.50715 .61159 Mdot
.54076 .60047 Mdot
.30553 .4154 Mdot
.38203 .66616 Mdot
.41005 .36593 Mdot
.2989 .4971 Mdot
.29831 .50345 Mdot
.38147 .63442 Mdot
.54456 .22049 Mdot
.33412 .26975 Mdot
.51535 .1488 Mdot
.40811 .68641 Mdot
.59124 .67716 Mdot
.7212 .55567 Mdot
.36911 .66882 Mdot
.38183 .63032 Mdot
.34545 .56588 Mdot
.3301 .41802 Mdot
.38286 .34376 Mdot
.587 .43193 Mdot
.54672 .19943 Mdot
.57556 .44383 Mdot
.61635 .60708 Mdot
.28241 .52135 Mdot
.37323 .3496 Mdot
.35313 .48804 Mdot
.63028 .4032 Mdot
.59377 .405 Mdot
.31744 .68647 Mdot
.54828 .57567 Mdot
.44465 .82122 Mdot
.56761 .43615 Mdot
.37347 .67938 Mdot
.38915 .39968 Mdot
.56295 .58459 Mdot
.66575 .28132 Mdot
.27498 .48352 Mdot
.54037 .55764 Mdot
.56344 .58721 Mdot
.63605 .3317 Mdot
.38299 .29561 Mdot
.38708 .32671 Mdot
.59329 .66048 Mdot
.32404 .39034 Mdot
.28083 .48046 Mdot
.28422 .43265 Mdot
.61609 .44206 Mdot
.2775 .53666 Mdot
.62345 .73057 Mdot
.57704 .42844 Mdot
.67597 .36272 Mdot
.5457 .23715 Mdot
.63458 .38728 Mdot
.64363 .43085 Mdot
.28872 .51213 Mdot
.65403 .7396 Mdot
.58594 .3835 Mdot
.38835 .65228 Mdot
.37961 .34591 Mdot
.38742 .29172 Mdot
.61343 .70964 Mdot
.3553 .52765 Mdot
.84985 .37627 Mdot
.37373 .34939 Mdot
.59722 .41677 Mdot
.29856 .5092 Mdot
.54394 .55254 Mdot
.55908 .58104 Mdot
.56479 .61179 Mdot
.39908 .3386 Mdot
.56189 .58689 Mdot
.4753 .38136 Mdot
.67298 .59469 Mdot
.6107 .31639 Mdot
.27078 .51215 Mdot
.59359 .67809 Mdot
.49662 .57357 Mdot
.343 .58912 Mdot
.56404 .41143 Mdot
.61638 .60869 Mdot
.3963 .31337 Mdot
.59663 .67753 Mdot
.61053 .40457 Mdot
.53514 .59933 Mdot
.74481 .47739 Mdot
.58193 .71957 Mdot
.53708 .59776 Mdot
.6787 .38508 Mdot
.37374 .33296 Mdot
.54465 .56326 Mdot
.40416 .34308 Mdot
.61178 .40297 Mdot
.59622 .5449 Mdot
.36846 .33562 Mdot
.22806 .35552 Mdot
.52498 .59816 Mdot
.31126 .49585 Mdot
.6427 .4178 Mdot
.62213 .40043 Mdot
.69001 .3098 Mdot
.54741 .55443 Mdot
.19366 .40549 Mdot
.39623 .65463 Mdot
.42623 .82227 Mdot
.42811 .62577 Mdot
.34043 .565 Mdot
.24634 .45546 Mdot
.62547 .39387 Mdot
.54542 .2205 Mdot
.69278 .3159 Mdot
.30839 .53611 Mdot
.69448 .31248 Mdot
.61656 .41321 Mdot
.59222 .39515 Mdot
.39148 .65624 Mdot
.24972 .49408 Mdot
.70355 .36637 Mdot
.67313 .57927 Mdot
.61903 .70239 Mdot
.41805 .35535 Mdot
.61015 .4167 Mdot
.45359 .32889 Mdot
.40319 .67153 Mdot
.39303 .26568 Mdot
.60878 .43746 Mdot
.54789 .57557 Mdot
.27387 .53321 Mdot
.26349 .49305 Mdot
.38775 .685 Mdot
.38662 .68739 Mdot
.62229 .40097 Mdot
.29263 .53135 Mdot
.56212 .4096 Mdot
.66206 .56952 Mdot
.55002 .59385 Mdot
.60404 .70813 Mdot
.5966 .45808 Mdot
.34691 .26748 Mdot
.73714 .71543 Mdot
.60743 .39332 Mdot
.40133 .32409 Mdot
.38055 .66107 Mdot
.3639 .64436 Mdot
.3889 .33081 Mdot
.36529 .64319 Mdot
.37018 .26444 Mdot
.69382 .27904 Mdot
.6083 .69788 Mdot
.64928 .43255 Mdot
.59507 .66852 Mdot
.54333 .55659 Mdot
.59129 .44109 Mdot
.20394 .54175 Mdot
.41023 .68342 Mdot
.69225 .46813 Mdot
.28896 .52196 Mdot
.56742 .57545 Mdot
.6832 .36593 Mdot
.60071 .65028 Mdot
.36182 .66259 Mdot
.51985 .56562 Mdot
.5694 .42539 Mdot
.36551 .3269 Mdot
.67492 .38808 Mdot
.56679 .58855 Mdot
.54973 .55894 Mdot
.52235 .56232 Mdot
.31639 .5037 Mdot
.43497 .36239 Mdot
.3401 .55529 Mdot
.40709 .63689 Mdot
.56801 .45666 Mdot
.59876 .41422 Mdot
.37918 .36079 Mdot
.58778 .45377 Mdot
.28709 .53242 Mdot
.47911 .13696 Mdot
.58284 .67971 Mdot
.54889 .55184 Mdot
.25721 .3615 Mdot
.52551 .55522 Mdot
.68597 .37999 Mdot
.68949 .34165 Mdot
.37041 .36408 Mdot
.32016 .50864 Mdot
.5539 .43127 Mdot
.41113 .62475 Mdot
.58973 .69685 Mdot
.26329 .51474 Mdot
.67044 .37442 Mdot
.61216 .43931 Mdot
.59553 .67897 Mdot
.35083 .47872 Mdot
.61958 .71245 Mdot
.29996 .49609 Mdot
.56977 .57143 Mdot
.70242 .50714 Mdot
.59958 .43466 Mdot
.54398 .57044 Mdot
.43056 .35991 Mdot
.30959 .50731 Mdot
.54767 .25079 Mdot
.56433 .5831 Mdot
.31773 .60424 Mdot
.26611 .4884 Mdot
.60153 .38858 Mdot
.37596 .31684 Mdot
.40218 .28534 Mdot
.42451 .36515 Mdot
.59281 .79262 Mdot
.31836 .62354 Mdot
.3836 .66236 Mdot
.28683 .50585 Mdot
.39333 .64374 Mdot
.61932 .68159 Mdot
.71138 .57271 Mdot
.38816 .68849 Mdot
.45054 .34617 Mdot
.40136 .6472 Mdot
.56051 .41451 Mdot
.31132 .49481 Mdot
.39858 .68506 Mdot
.6063 .45372 Mdot
.69501 .35157 Mdot
.5522 .56375 Mdot
.57219 .69114 Mdot
.6716 .58688 Mdot
.59284 .449 Mdot
.54135 .57473 Mdot
.60201 .44047 Mdot
.28742 .53219 Mdot
.62847 .58031 Mdot
.56837 .46142 Mdot
.40706 .68734 Mdot
.27095 .30244 Mdot
.41872 .63886 Mdot
.4789 .60692 Mdot
.57445 .42823 Mdot
.59719 .43706 Mdot
.67569 .36912 Mdot
.56977 .18049 Mdot
.30036 .54098 Mdot
.59151 .47118 Mdot
.35289 .6532 Mdot
.39247 .34798 Mdot
.38478 .32145 Mdot
.59959 .36338 Mdot
.5418 .56839 Mdot
.27449 .52894 Mdot
.59428 .43743 Mdot
.56483 .57221 Mdot
.69478 .58404 Mdot
.32337 .39905 Mdot
.32056 .64675 Mdot
.39491 .62979 Mdot
.36104 .34078 Mdot
.35383 .65944 Mdot
.6752 .37179 Mdot
.56187 .58052 Mdot
.31695 .62204 Mdot
.3036 .56796 Mdot
.591 .69771 Mdot
.58264 .40577 Mdot
.71354 .65946 Mdot
.34977 .66792 Mdot
.37113 .69019 Mdot
.56081 .41256 Mdot
.36936 .40453 Mdot
.71516 .7289 Mdot
.31336 .521 Mdot
.46942 .31498 Mdot
.60874 .24044 Mdot
.81927 .53786 Mdot
.28766 .49779 Mdot
.67273 .3652 Mdot
.35014 .68765 Mdot
.50156 .80747 Mdot
.39516 .35157 Mdot
.5898 .69844 Mdot
.60358 .45535 Mdot
.44315 .33978 Mdot
.40777 .68768 Mdot
.44089 .36341 Mdot
.55249 .57719 Mdot
.31529 .49861 Mdot
.35736 .6647 Mdot
.26112 .48231 Mdot
.43186 .39484 Mdot
.58774 .6766 Mdot
.66022 .66272 Mdot
.65241 .40783 Mdot
.54504 .23507 Mdot
.69122 .36143 Mdot
.53681 .53122 Mdot
.69506 .35588 Mdot
.39391 .28983 Mdot
.60544 .44309 Mdot
.56861 .39521 Mdot
.34405 .67642 Mdot
.60444 .39136 Mdot
.61256 .44638 Mdot
.6663 .28352 Mdot
.57965 .41337 Mdot
.61679 .40083 Mdot
.60626 .3874 Mdot
.41021 .32737 Mdot
.5701 .4157 Mdot
.40888 .36875 Mdot
.45819 .33948 Mdot
.40586 .63585 Mdot
.61347 .67227 Mdot
.60791 .66821 Mdot
.60389 .55311 Mdot
.71213 .66005 Mdot
.54824 .199 Mdot
.39687 .3466 Mdot
.26685 .48992 Mdot
.5613 .43696 Mdot
.68348 .74768 Mdot
.59723 .54597 Mdot
.36116 .69496 Mdot
.40614 .67006 Mdot
.61326 .45087 Mdot
.84462 .41791 Mdot
.56747 .43847 Mdot
.68941 .59936 Mdot
.60261 .42036 Mdot
.58638 .39351 Mdot
.41659 .62333 Mdot
.68132 .67032 Mdot
.70118 .35224 Mdot
.38507 .29857 Mdot
.59336 .70148 Mdot
.54634 .56542 Mdot
.60006 .55045 Mdot
.63402 .2445 Mdot
.33856 .34518 Mdot
.67493 .36938 Mdot
.35695 .68279 Mdot
.40327 .33391 Mdot
.68138 .59918 Mdot
.30594 .52914 Mdot
.68838 .62911 Mdot
.48677 .33058 Mdot
.31433 .52285 Mdot
.58984 .69375 Mdot
.37065 .70424 Mdot
.60264 .39971 Mdot
.38864 .6738 Mdot
.62875 .40109 Mdot
.69866 .59685 Mdot
.60642 .70348 Mdot
.44821 .33882 Mdot
.28801 .48574 Mdot
.42178 .33064 Mdot
.39993 .26765 Mdot
.60042 .55732 Mdot
.38422 .79691 Mdot
.4207 .64801 Mdot
.48138 .5936 Mdot
.38604 .35927 Mdot
.63272 .42099 Mdot
.51095 .15171 Mdot
.42711 .3504 Mdot
.36666 .32728 Mdot
.66842 .62242 Mdot
.68826 .68161 Mdot
.61363 .38939 Mdot
.44542 .34492 Mdot
.37334 .70483 Mdot
.61062 .69153 Mdot
.61907 .44075 Mdot
.56031 .57208 Mdot
.37676 .32293 Mdot
.3637 .65131 Mdot
.67505 .66766 Mdot
.36775 .67921 Mdot
.38627 .34898 Mdot
.41334 .65651 Mdot
.34102 .52545 Mdot
.38879 .68846 Mdot
.5917 .45774 Mdot
.59545 .43688 Mdot
.41566 .2857 Mdot
.4062 .33602 Mdot
.68629 .37972 Mdot
.58074 .44777 Mdot
.40028 .36345 Mdot
.36689 .70949 Mdot
.34251 .33504 Mdot
.67628 .38056 Mdot
.58872 .43522 Mdot
.58638 .66869 Mdot
.64509 .56509 Mdot
.65314 .60253 Mdot
.56218 .43714 Mdot
.58894 .67909 Mdot
.36336 .32957 Mdot
.5949 .44335 Mdot
.683 .67713 Mdot
.34329 .68548 Mdot
.59913 .37761 Mdot
.54188 .55167 Mdot
.6981 .36401 Mdot
.7481 .61256 Mdot
.67126 .37183 Mdot
.40167 .35836 Mdot
.38676 .354 Mdot
.34654 .69426 Mdot
.41387 .35958 Mdot
.54803 .55266 Mdot
.26819 .51563 Mdot
.47813 .30998 Mdot
.56489 .56612 Mdot
.52414 .5805 Mdot
.52448 .59433 Mdot
.55448 .60517 Mdot
.60054 .74269 Mdot
.32275 .63504 Mdot
.52761 .56803 Mdot
.41148 .36787 Mdot
.51695 .48481 Mdot
.56108 .54551 Mdot
.27623 .53089 Mdot
.56282 .58807 Mdot
.59971 .37762 Mdot
.67509 .36695 Mdot
.39125 .37128 Mdot
.30405 .53128 Mdot
.57725 .57633 Mdot
.61824 .44207 Mdot
.37917 .36937 Mdot
.61214 .41581 Mdot
.59904 .72432 Mdot
.41183 .34344 Mdot
.35992 .6802 Mdot
.60601 .70785 Mdot
.54914 .60116 Mdot
.58639 .70565 Mdot
.39121 .66631 Mdot
.26831 .49648 Mdot
.59906 .45481 Mdot
.60082 .72894 Mdot
.61416 .67466 Mdot
.63936 .39738 Mdot
.38172 .35149 Mdot
.56865 .6163 Mdot
.58811 .44268 Mdot
.68228 .36377 Mdot
.38889 .32977 Mdot
.18338 .41073 Mdot
.59839 .39895 Mdot
.70622 .34496 Mdot
.39538 .29508 Mdot
.56727 .58051 Mdot
.36298 .68321 Mdot
.61956 .3951 Mdot
.29533 .52477 Mdot
.28065 .52287 Mdot
.412 .68021 Mdot
.3831 .32527 Mdot
.36034 .65169 Mdot
.63694 .41707 Mdot
.56176 .59229 Mdot
.62377 .42488 Mdot
.32281 .7148 Mdot
.20691 .37822 Mdot
.42314 .37198 Mdot
.40819 .63528 Mdot
.69869 .57433 Mdot
.32554 .5231 Mdot
.38031 .71249 Mdot
.38805 .29645 Mdot
.43898 .33909 Mdot
.3861 .33135 Mdot
.6085 .67143 Mdot
.36262 .6743 Mdot
.37254 .35947 Mdot
.37803 .36291 Mdot
.67317 .37666 Mdot
.61107 .45105 Mdot
.36238 .33513 Mdot
.34089 .58865 Mdot
.59492 .69643 Mdot
.35875 .64435 Mdot
.72069 .72702 Mdot
.3127 .51419 Mdot
.66739 .28181 Mdot
.56227 .41466 Mdot
.84863 .34959 Mdot
.56834 .4395 Mdot
.60287 .41646 Mdot
.43373 .37579 Mdot
.62093 .67754 Mdot
.6081 .68569 Mdot
.38584 .35848 Mdot
.43184 .3713 Mdot
.60636 .7193 Mdot
.65389 .54053 Mdot
.73911 .63232 Mdot
.68704 .58367 Mdot
.44124 .36034 Mdot
.48514 .33976 Mdot
.28022 .51327 Mdot
.41855 .32402 Mdot
.33711 .47313 Mdot
.41204 .66917 Mdot
.39104 .68816 Mdot
.27785 .48498 Mdot
.60119 .40105 Mdot
.41894 .62417 Mdot
.69862 .358 Mdot
.31648 .4458 Mdot
.66684 .37043 Mdot
.5432 .84842 Mdot
.59075 .4557 Mdot
.45056 .57963 Mdot
.31125 .40854 Mdot
.69258 .37449 Mdot
.67455 .25931 Mdot
.58593 .69702 Mdot
.38586 .29105 Mdot
.29137 .53505 Mdot
.54571 .19936 Mdot
.59858 .43578 Mdot
.44774 .34847 Mdot
.2985 .49082 Mdot
.19716 .39571 Mdot
.69771 .34623 Mdot
.68145 .37521 Mdot
.50429 .14947 Mdot
.45724 .35023 Mdot
.36393 .6823 Mdot
.45718 .30087 Mdot
.41409 .37318 Mdot
.6878 .35076 Mdot
.37959 .70676 Mdot
.74185 .47484 Mdot
.44822 .35313 Mdot
.62055 .71082 Mdot
.41366 .35209 Mdot
.6041 .71737 Mdot
.37022 .35774 Mdot
.40375 .63709 Mdot
.58905 .40194 Mdot
.40337 .63499 Mdot
.58209 .70738 Mdot
.41714 .64234 Mdot
.29732 .53488 Mdot
.53909 .58774 Mdot
.27446 .51854 Mdot
.71491 .56671 Mdot
.55212 .26229 Mdot
.27289 .49944 Mdot
.64181 .35687 Mdot
.61322 .43957 Mdot
.36942 .35654 Mdot
.35626 .67632 Mdot
.34628 .65642 Mdot
.67025 .58445 Mdot
.37856 .33895 Mdot
.37252 .64183 Mdot
.62928 .45612 Mdot
.20319 .51548 Mdot
.70531 .34915 Mdot
.20045 .65093 Mdot
.40745 .36341 Mdot
.34649 .65791 Mdot
.68562 .59962 Mdot
.45672 .36278 Mdot
.39403 .68827 Mdot
.28421 .48866 Mdot
.29532 .52449 Mdot
.58281 .45584 Mdot
.2565 .4828 Mdot
.36013 .69286 Mdot
.48627 .35857 Mdot
.36771 .34351 Mdot
.21285 .36927 Mdot
.58432 .68172 Mdot
.35422 .66146 Mdot
.55428 .5931 Mdot
.43928 .39398 Mdot
.39705 .64406 Mdot
.84942 .38248 Mdot
.69037 .78316 Mdot
.36877 .64538 Mdot
.4097 .34375 Mdot
.39568 .337 Mdot
.66416 .38598 Mdot
.6705 .57953 Mdot
.36271 .66077 Mdot
.20117 .54092 Mdot
.71512 .52798 Mdot
.53744 .58392 Mdot
.34699 .76615 Mdot
.6435 .37491 Mdot
.68738 .36371 Mdot
.30886 .50894 Mdot
.5922 .40584 Mdot
.4359 .36892 Mdot
.56765 .438 Mdot
.27913 .5274 Mdot
.41439 .67497 Mdot
.59927 .43865 Mdot
.58921 .69525 Mdot
.3059 .51502 Mdot
.30081 .52582 Mdot
.41176 .65213 Mdot
.38146 .3257 Mdot
.54227 .20001 Mdot
.3632 .67757 Mdot
.69343 .36279 Mdot
.54213 .57942 Mdot
.60551 .38802 Mdot
.43525 .32758 Mdot
.36871 .30336 Mdot
.35186 .66629 Mdot
.63871 .40615 Mdot
.29063 .50283 Mdot
.34474 .67981 Mdot
.66821 .37247 Mdot
.38192 .69718 Mdot
.54246 .62001 Mdot
.41414 .61664 Mdot
.4229 .39656 Mdot
.54624 .6122 Mdot
.44883 .34651 Mdot
.5282 .57288 Mdot
.56043 .79938 Mdot
.59137 .69392 Mdot
.41939 .62931 Mdot
.22317 .3621 Mdot
.40385 .63298 Mdot
.57889 .41623 Mdot
.60677 .44632 Mdot
.39572 .65951 Mdot
.58904 .67541 Mdot
.50597 .55609 Mdot
.60685 .72904 Mdot
.40876 .34023 Mdot
.68238 .34954 Mdot
.65205 .80203 Mdot
.33946 .66642 Mdot
.28097 .48165 Mdot
.33798 .37328 Mdot
.52522 .58387 Mdot
.30095 .53394 Mdot
.30496 .52275 Mdot
.58179 .70299 Mdot
.38566 .62973 Mdot
.39709 .32007 Mdot
.28191 .47886 Mdot
.44988 .3662 Mdot
.67897 .67762 Mdot
.56132 .59866 Mdot
.48726 .56587 Mdot
.53637 .60044 Mdot
.67358 .59177 Mdot
.3048 .48727 Mdot
.61254 .42522 Mdot
.52654 .6223 Mdot
.29527 .49077 Mdot
.57478 .68145 Mdot
.66994 .369 Mdot
.37608 .63979 Mdot
.52423 .16823 Mdot
.58972 .45845 Mdot
.57812 .43575 Mdot
.30885 .50274 Mdot
.65895 .24752 Mdot
.38152 .29694 Mdot
.37268 .33253 Mdot
.38135 .66622 Mdot
.6659 .61877 Mdot
.56822 .42527 Mdot
.60823 .44769 Mdot
.39896 .6609 Mdot
.53801 .56819 Mdot
.36439 .78357 Mdot
.5901 .43249 Mdot
.28514 .51029 Mdot
.67332 .36563 Mdot
.30628 .53788 Mdot
.55519 .4358 Mdot
.5811 .41512 Mdot
.69042 .36884 Mdot
.692 .35522 Mdot
.2742 .51719 Mdot
.54102 .60124 Mdot
.52929 .55521 Mdot
.42939 .36358 Mdot
.61709 .44952 Mdot
.71435 .52638 Mdot
.59498 .43325 Mdot
.5858 .69525 Mdot
.65617 .60539 Mdot
.5589 .43674 Mdot
.60251 .46178 Mdot
.71719 .52941 Mdot
.6146 .40644 Mdot
.31008 .50331 Mdot
.39038 .33721 Mdot
.2927 .50293 Mdot
.29164 .48247 Mdot
.40232 .64581 Mdot
.57664 .67325 Mdot
.61874 .3969 Mdot
.61733 .70192 Mdot
.65111 .38405 Mdot
.573 .55452 Mdot
.66081 .56611 Mdot
.69013 .59785 Mdot
.57712 .71011 Mdot
.6134 .44131 Mdot
.38759 .66527 Mdot
.37745 .6296 Mdot
.67062 .36218 Mdot
.63954 .42169 Mdot
.25381 .49102 Mdot
.27291 .49481 Mdot
.31725 .66482 Mdot
.42468 .70792 Mdot
.60291 .72632 Mdot
.50642 .59669 Mdot
.69422 .35316 Mdot
.57735 .4118 Mdot
.53593 .59355 Mdot
.38786 .64655 Mdot
.52717 .57141 Mdot
.32191 .64118 Mdot
.3 .53674 Mdot
.29831 .50044 Mdot
.59186 .45668 Mdot
.8697 .46479 Mdot
.43307 .34878 Mdot
.3948 .33639 Mdot
.27036 .52282 Mdot
.41875 .63815 Mdot
.55491 .57659 Mdot
.54325 .17173 Mdot
.36354 .31015 Mdot
.61849 .67736 Mdot
.62631 .41457 Mdot
.41387 .66534 Mdot
.42543 .36814 Mdot
.60559 .72698 Mdot
.57966 .47236 Mdot
.37888 .70847 Mdot
.60714 .42553 Mdot
.60305 .48249 Mdot
.38153 .35904 Mdot
.65274 .56467 Mdot
.45009 .34415 Mdot
.28074 .51983 Mdot
.29581 .48208 Mdot
.57816 .4225 Mdot
.53757 .17568 Mdot
.37784 .40053 Mdot
.28109 .47735 Mdot
.59444 .66142 Mdot
.54325 .59191 Mdot
.57592 .67686 Mdot
.38854 .65611 Mdot
.59069 .6946 Mdot
.39838 .64399 Mdot
.3536 .70558 Mdot
.39346 .32055 Mdot
.59591 .6791 Mdot
.64156 .27048 Mdot
.56133 .57896 Mdot
.6016 .65987 Mdot
.57848 .46507 Mdot
.67401 .38315 Mdot
.36717 .65415 Mdot
.61899 .69677 Mdot
.61755 .39276 Mdot
.25249 .36561 Mdot
.30515 .49007 Mdot
.2956 .53517 Mdot
.55293 .57635 Mdot
.35147 .68455 Mdot
.39131 .31949 Mdot
.70101 .57315 Mdot
.46196 .38832 Mdot
.60767 .449 Mdot
.61653 .3968 Mdot
.45036 .39231 Mdot
.3895 .31948 Mdot
.58132 .41766 Mdot
.60894 .31093 Mdot
.55355 .5955 Mdot
.28901 .52613 Mdot
.41237 .34049 Mdot
.41555 .33683 Mdot
.36848 .69335 Mdot
.37342 .3247 Mdot
.49679 .60143 Mdot
.3004 .53613 Mdot
.53361 .55038 Mdot
.2894 .5054 Mdot
.57322 .5331 Mdot
.37838 .642 Mdot
.21119 .38143 Mdot
.37166 .33071 Mdot
.67764 .37909 Mdot
.37012 .32729 Mdot
.58164 .68638 Mdot
.44474 .34756 Mdot
.42511 .32521 Mdot
.60673 .45265 Mdot
.54135 .60031 Mdot
.54427 .55824 Mdot
.6741 .58591 Mdot
.43068 .35034 Mdot
.60796 .39687 Mdot
.56682 .41663 Mdot
.58346 .44966 Mdot
.66452 .56928 Mdot
.40114 .32599 Mdot
.63593 .24496 Mdot
.36521 .35456 Mdot
.38755 .36198 Mdot
.75166 .70406 Mdot
.55129 .55569 Mdot
.52723 .58087 Mdot
.23681 .47659 Mdot
.58728 .4329 Mdot
.36903 .64096 Mdot
.69047 .36486 Mdot
.54531 .5985 Mdot
.57433 .46722 Mdot
.61459 .69182 Mdot
.63129 .40674 Mdot
.5354 .57677 Mdot
.35759 .6748 Mdot
.67654 .37808 Mdot
.59094 .43885 Mdot
.54113 .5642 Mdot
.36882 .32391 Mdot
.41635 .33168 Mdot
.42883 .40626 Mdot
.59695 .7187 Mdot
.27579 .50499 Mdot
.68753 .36598 Mdot
.38394 .66553 Mdot
.374 .63679 Mdot
.44877 .34389 Mdot
.39141 .67951 Mdot
.30057 .50119 Mdot
.59527 .41845 Mdot
.27734 .51897 Mdot
.61371 .70171 Mdot
.41344 .34343 Mdot
.67815 .36907 Mdot
.67922 .38852 Mdot
.38677 .35409 Mdot
.55596 .59567 Mdot
.58428 .66842 Mdot
.40138 .66707 Mdot
.40698 .36954 Mdot
.27326 .52018 Mdot
.37703 .69245 Mdot
.68116 .37724 Mdot
.81496 .63069 Mdot
.59128 .40617 Mdot
.5735 .44172 Mdot
.39328 .39663 Mdot
.56364 .39982 Mdot
.40769 .63745 Mdot
.37985 .3195 Mdot
.6759 .38173 Mdot
.73022 .54341 Mdot
.57025 .67356 Mdot
.36187 .63305 Mdot
.61124 .40988 Mdot
.69004 .31045 Mdot
.59862 .3825 Mdot
.23328 .34904 Mdot
.65988 .56691 Mdot
.31927 .60676 Mdot
.48296 .57843 Mdot
.27362 .4787 Mdot
.53989 .5738 Mdot
.40414 .64426 Mdot
.60348 .30187 Mdot
.58661 .41302 Mdot
.54324 .24388 Mdot
.66923 .37445 Mdot
.29134 .49781 Mdot
.65632 .25392 Mdot
.35791 .68471 Mdot
.41704 .81796 Mdot
.62711 .43637 Mdot
.3745 .30049 Mdot
.36237 .58033 Mdot
.53597 .59077 Mdot
.52947 .58959 Mdot
.60157 .72504 Mdot
.39111 .70836 Mdot
.57563 .59317 Mdot
.29169 .50442 Mdot
.57554 .41237 Mdot
.64205 .42981 Mdot
.19009 .41168 Mdot
.41682 .36687 Mdot
.29319 .48541 Mdot
.38705 .61672 Mdot
.61584 .42659 Mdot
.43476 .33687 Mdot
.39573 .35175 Mdot
.61655 .68799 Mdot
.32304 .59583 Mdot
.38645 .71205 Mdot
.8458 .43682 Mdot
.57665 .6093 Mdot
.39054 .64764 Mdot
.54803 .6107 Mdot
.69182 .36528 Mdot
.59691 .54596 Mdot
.28378 .48049 Mdot
.57512 .424 Mdot
.54312 .23261 Mdot
.41644 .36359 Mdot
.59825 .42742 Mdot
.59764 .69961 Mdot
.55523 .16932 Mdot
.64824 .41945 Mdot
.61351 .31408 Mdot
.37365 .70497 Mdot
.61441 .39621 Mdot
.50099 .60607 Mdot
.56476 .57117 Mdot
.56283 .40051 Mdot
.36232 .68086 Mdot
.5441 .61124 Mdot
.60158 .69638 Mdot
.43366 .36387 Mdot
.54185 .57396 Mdot
.6681 .37472 Mdot
.62581 .39898 Mdot
.59153 .66183 Mdot
.68597 .37126 Mdot
.46104 .29108 Mdot
.56337 .60839 Mdot
.39671 .68204 Mdot
.41017 .37105 Mdot
.60839 .39408 Mdot
.5434 .59312 Mdot
.62302 .42388 Mdot
.34799 .26702 Mdot
.57498 .42023 Mdot
.22442 .38827 Mdot
.37914 .34493 Mdot
.29633 .51859 Mdot
.67646 .36757 Mdot
.60513 .42884 Mdot
.55081 .61284 Mdot
.55596 .57453 Mdot
.62763 .43069 Mdot
.44918 .34577 Mdot
.43743 .35718 Mdot
.3707 .30464 Mdot
.37371 .69586 Mdot
.68313 .57923 Mdot
.28928 .51947 Mdot
.53488 .5926 Mdot
.28133 .47901 Mdot
.69471 .32006 Mdot
.59418 .71537 Mdot
.1991 .40633 Mdot
.59078 .41824 Mdot
.38025 .33586 Mdot
.73507 .63597 Mdot
.43838 .3359 Mdot
.24639 .46998 Mdot
.28087 .48055 Mdot
.42253 .34826 Mdot
.60891 .40837 Mdot
.67532 .59655 Mdot
.69267 .30767 Mdot
.32184 .51141 Mdot
.53532 .55125 Mdot
.59137 .59115 Mdot
.38973 .69562 Mdot
.74413 .71151 Mdot
.26107 .49868 Mdot
.31069 .40652 Mdot
.67648 .38061 Mdot
.37086 .3383 Mdot
.27108 .51107 Mdot
.30018 .52784 Mdot
.3549 .6836 Mdot
.67388 .37696 Mdot
.60331 .42839 Mdot
.54066 .55274 Mdot
.26535 .49675 Mdot
.63507 .40325 Mdot
.69554 .37266 Mdot
.32358 .72111 Mdot
.37981 .29564 Mdot
.18223 .40928 Mdot
.68924 .33861 Mdot
.54464 .23186 Mdot
.22571 .54992 Mdot
.36844 .3527 Mdot
.61406 .4003 Mdot
.55314 .58836 Mdot
.39876 .67454 Mdot
.59693 .4125 Mdot
.40698 .63353 Mdot
.28341 .49774 Mdot
.23864 .3782 Mdot
.68807 .34067 Mdot
.3132 .44441 Mdot
.58872 .40387 Mdot
.65686 .39724 Mdot
.59943 .68782 Mdot
.28854 .53552 Mdot
.37924 .30437 Mdot
.60757 .38989 Mdot
.36892 .68844 Mdot
.3944 .6907 Mdot
.42082 .36311 Mdot
.3697 .41964 Mdot
.2158 .37296 Mdot
.55772 .59009 Mdot
.38444 .68089 Mdot
.54566 .59454 Mdot
.61352 .3167 Mdot
.28034 .47849 Mdot
.60247 .69569 Mdot
.41111 .66041 Mdot
.27016 .52683 Mdot
.6748 .38329 Mdot
.42441 .35634 Mdot
.45788 .38835 Mdot
.69238 .34644 Mdot
.37216 .64159 Mdot
.5993 .7133 Mdot
.61516 .36743 Mdot
.6842 .34899 Mdot
.60315 .70767 Mdot
.36503 .69507 Mdot
.43111 .34058 Mdot
.39034 .35172 Mdot
.38876 .3384 Mdot
.66593 .28107 Mdot
.3668 .30493 Mdot
.64543 .65214 Mdot
.57324 .3902 Mdot
.49214 .3591 Mdot
.61235 .38063 Mdot
.29344 .53491 Mdot
.37574 .35382 Mdot
.6593 .56619 Mdot
.70308 .35092 Mdot
.69777 .3068 Mdot
.58632 .44783 Mdot
.68691 .35336 Mdot
.58718 .43366 Mdot
.48944 .36441 Mdot
.37409 .2963 Mdot
.61179 .45661 Mdot
.31683 .52938 Mdot
.58388 .69916 Mdot
.43677 .37259 Mdot
.62164 .4036 Mdot
.47828 .36245 Mdot
.57628 .46376 Mdot
.23542 .3791 Mdot
.68076 .3556 Mdot
.40778 .59809 Mdot
.58173 .40074 Mdot
.42277 .64074 Mdot
.66798 .39106 Mdot
.48178 .31716 Mdot
.31191 .4957 Mdot
.64891 .4186 Mdot
.4242 .6281 Mdot
.6542 .25363 Mdot
.55895 .58489 Mdot
.59629 .69398 Mdot
.53212 .60253 Mdot
.27724 .52388 Mdot
.58834 .41644 Mdot
.62955 .40772 Mdot
.55203 .42467 Mdot
.61353 .31759 Mdot
.55603 .56159 Mdot
.57916 .71437 Mdot
.48581 .33545 Mdot
.62912 .42253 Mdot
.41201 .61942 Mdot
.39588 .32868 Mdot
.64421 .26324 Mdot
.62694 .2653 Mdot
.69445 .37596 Mdot
.42666 .35143 Mdot
.38269 .32522 Mdot
.69816 .74045 Mdot
.59193 .68431 Mdot
.57594 .43512 Mdot
.61852 .73148 Mdot
.68386 .36785 Mdot
.28133 .50464 Mdot
.5608 .4059 Mdot
.37735 .64191 Mdot
.67942 .60256 Mdot
.3686 .69657 Mdot
.58568 .45067 Mdot
.41117 .35118 Mdot
.32256 .51674 Mdot
.34947 .70396 Mdot
.32501 .59168 Mdot
.65168 .65925 Mdot
.38252 .71313 Mdot
.60611 .72456 Mdot
.58002 .69792 Mdot
.28921 .53546 Mdot
.6045 .41334 Mdot
.66615 .57257 Mdot
.71964 .33118 Mdot
.58628 .42856 Mdot
.60125 .40264 Mdot
.22679 .51207 Mdot
.27078 .48585 Mdot
.41465 .65521 Mdot
.58244 .41702 Mdot
.63227 .40607 Mdot
.41471 .34901 Mdot
.61891 .70453 Mdot
.40406 .65479 Mdot
.59597 .72203 Mdot
.38004 .67625 Mdot
.74871 .61277 Mdot
.56168 .59646 Mdot
.58846 .71064 Mdot
.26076 .4958 Mdot
.38638 .33334 Mdot
.55086 .55456 Mdot
.37891 .65691 Mdot
.38606 .68171 Mdot
.65071 .38522 Mdot
.42739 .36701 Mdot
.37236 .33256 Mdot
.60232 .72149 Mdot
.27209 .49729 Mdot
.69956 .35561 Mdot
.53468 .59865 Mdot
.33731 .65254 Mdot
.37789 .68792 Mdot
.48648 .34055 Mdot
.40957 .39661 Mdot
.62135 .42124 Mdot
.41888 .33259 Mdot
.60444 .43601 Mdot
.46743 .36011 Mdot
.45951 .35412 Mdot
.55711 .44006 Mdot
.52964 .35306 Mdot
.3894 .64522 Mdot
.61451 .82043 Mdot
.70593 .34849 Mdot
.30488 .54507 Mdot
.68889 .36659 Mdot
.38324 .79762 Mdot
.73272 .63951 Mdot
.62456 .4307 Mdot
.61879 .39924 Mdot
.86452 .49086 Mdot
.58182 .39327 Mdot
.52958 .57311 Mdot
.55963 .5836 Mdot
.42548 .33439 Mdot
.52746 .59711 Mdot
.67279 .58851 Mdot
.59486 .67447 Mdot
.38182 .66522 Mdot
.6856 .67606 Mdot
.60169 .71776 Mdot
.4057 .36078 Mdot
.70046 .35656 Mdot
.40032 .40094 Mdot
.40813 .62234 Mdot
.54567 .56943 Mdot
.28663 .49756 Mdot
.66626 .58002 Mdot
.36233 .68803 Mdot
.26501 .51145 Mdot
.57026 .40632 Mdot
.32137 .65041 Mdot
.31229 .53373 Mdot
.62912 .80948 Mdot
.31057 .52168 Mdot
.26845 .51724 Mdot
.67496 .57763 Mdot
.59507 .6742 Mdot
.55716 .61481 Mdot
.56381 .54142 Mdot
.31797 .50958 Mdot
.46541 .83105 Mdot
.35198 .68315 Mdot
.70106 .59401 Mdot
.38408 .2912 Mdot
.56352 .58393 Mdot
.59399 .40098 Mdot
.31003 .51013 Mdot
.64095 .42076 Mdot
.54856 .61277 Mdot
.30309 .51082 Mdot
.6691 .39075 Mdot
.66588 .61675 Mdot
.54647 .59107 Mdot
.54352 .55697 Mdot
.61641 .71502 Mdot
.42123 .6078 Mdot
.37744 .32976 Mdot
.61209 .66975 Mdot
.70683 .55432 Mdot
.57901 .44463 Mdot
.27389 .51638 Mdot
.54244 .57336 Mdot
.29042 .52236 Mdot
.60465 .68642 Mdot
.59092 .66077 Mdot
.42716 .36496 Mdot
.37329 .30244 Mdot
.56145 .55674 Mdot
.71812 .51893 Mdot
.58778 .38318 Mdot
.54565 .2534 Mdot
.4001 .32363 Mdot
.6818 .2664 Mdot
.60191 .66996 Mdot
.62004 .6966 Mdot
.65944 .39372 Mdot
.56415 .44311 Mdot
.68328 .35652 Mdot
.5612 .44336 Mdot
.4484 .81476 Mdot
.67577 .3705 Mdot
.39894 .66974 Mdot
.56784 .46156 Mdot
.321 .38628 Mdot
.65814 .38769 Mdot
.62441 .40907 Mdot
.36856 .67256 Mdot
.63113 .38351 Mdot
.36961 .64905 Mdot
.59718 .39585 Mdot
.33155 .73744 Mdot
.38349 .66591 Mdot
.50992 .55997 Mdot
.54066 .41529 Mdot
.53156 .56743 Mdot
.60882 .67771 Mdot
.5976 .72739 Mdot
.67286 .6674 Mdot
.4298 .34284 Mdot
.57607 .18492 Mdot
.62401 .41101 Mdot
.35513 .6867 Mdot
.28216 .49637 Mdot
.6814 .38684 Mdot
.57642 .44755 Mdot
.69653 .35067 Mdot
.43156 .35512 Mdot
.35183 .68795 Mdot
.60313 .67938 Mdot
.39624 .62805 Mdot
.33035 .73862 Mdot
.3797 .643 Mdot
.63394 .33021 Mdot
.66916 .38416 Mdot
.49939 .60414 Mdot
.56029 .2842 Mdot
.61181 .65761 Mdot
.42436 .36031 Mdot
.53994 .57654 Mdot
.57667 .68922 Mdot
.63462 .58293 Mdot
.38557 .32903 Mdot
.39848 .66162 Mdot
.60775 .42555 Mdot
.55364 .60666 Mdot
.56469 .54221 Mdot
.44191 .36803 Mdot
.58259 .66494 Mdot
.37586 .66312 Mdot
.54222 .58614 Mdot
.68753 .58138 Mdot
.61009 .23997 Mdot
.71351 .57351 Mdot
.60596 .43123 Mdot
.60549 .71958 Mdot
.42776 .36715 Mdot
.69548 .34883 Mdot
.2977 .4931 Mdot
.67096 .5817 Mdot
.59148 .40368 Mdot
.2943 .44395 Mdot
.41103 .3523 Mdot
.58673 .67911 Mdot
.31117 .51506 Mdot
.59074 .68616 Mdot
.52775 .58028 Mdot
.41396 .37626 Mdot
.52958 .58952 Mdot
.67006 .37236 Mdot
.27967 .49989 Mdot
.37568 .33118 Mdot
.32971 .73625 Mdot
.56496 .61668 Mdot
.39461 .65898 Mdot
.6368 .58276 Mdot
.43665 .35976 Mdot
.34279 .55126 Mdot
.39785 .62806 Mdot
.28654 .56404 Mdot
.64231 .56431 Mdot
.30455 .50731 Mdot
.62373 .40694 Mdot
.39461 .34242 Mdot
.32278 .51323 Mdot
.34851 .5886 Mdot
.68512 .30152 Mdot
.57034 .59495 Mdot
.61107 .44242 Mdot
.24058 .33785 Mdot
.31873 .4042 Mdot
.40377 .28435 Mdot
.26298 .51374 Mdot
.5806 .43612 Mdot
.55807 .59145 Mdot
.6204 .44659 Mdot
.3155 .50356 Mdot
.31764 .49237 Mdot
.36384 .63974 Mdot
.61168 .42401 Mdot
.58649 .69129 Mdot
.39138 .63704 Mdot
.39077 .69841 Mdot
.41036 .66491 Mdot
.3786 .30344 Mdot
.5654 .5861 Mdot
.56017 .58607 Mdot
.72714 .64644 Mdot
.29115 .52374 Mdot
.53147 .56807 Mdot
.63008 .406 Mdot
.64631 .65217 Mdot
.38306 .33983 Mdot
.37126 .66313 Mdot
.57891 .43723 Mdot
.70421 .34326 Mdot
.54558 .56414 Mdot
.36337 .67584 Mdot
.391 .32021 Mdot
.53038 .49534 Mdot
.59519 .41401 Mdot
.67188 .37537 Mdot
.3968 .35964 Mdot
.33003 .27127 Mdot
.69282 .58661 Mdot
.60272 .43622 Mdot
.28101 .52352 Mdot
.309 .28657 Mdot
.57497 .40117 Mdot
.44017 .40543 Mdot
.54015 .55112 Mdot
.50899 .46541 Mdot
.46582 .30309 Mdot
.57865 .48186 Mdot
.43275 .52329 Mdot
.69516 .46818 Mdot
.45175 .54293 Mdot
.48788 .81599 Mdot
.39476 .52875 Mdot
.64811 .79999 Mdot
.24984 .50054 Mdot
.59456 .4858 Mdot
.84111 .38148 Mdot
.31704 .41904 Mdot
.37795 .55234 Mdot
.33272 .54303 Mdot
.61062 .64644 Mdot
.35675 .77604 Mdot
.32035 .65291 Mdot
.49102 .81305 Mdot
.64608 .3757 Mdot
.31995 .32736 Mdot
.63373 .4551 Mdot
.3507 .53166 Mdot
.32309 .60438 Mdot
.6662 .36716 Mdot
.84747 .51059 Mdot
.25856 .46257 Mdot
.7885 .63313 Mdot
.55948 .20842 Mdot
.33021 .65009 Mdot
.70671 .50733 Mdot
.67834 .7086 Mdot
.67191 .3991 Mdot
.48249 .50143 Mdot
.24892 .49207 Mdot
.35121 .34813 Mdot
.20271 .52552 Mdot
.39386 .67014 Mdot
.44541 .36297 Mdot
.23417 .46709 Mdot
.83356 .5743 Mdot
.26428 .54026 Mdot
.43159 .52477 Mdot
.5695 .6081 Mdot
.51365 .45458 Mdot
.65846 .56248 Mdot
.47499 .33693 Mdot
.32437 .70495 Mdot
.36136 .7753 Mdot
.38882 .39185 Mdot
.36142 .59322 Mdot
.62614 .58134 Mdot
.37317 .55211 Mdot
.44262 .28661 Mdot
.59592 .64441 Mdot
.50975 .56455 Mdot
.40058 .32336 Mdot
.82563 .47112 Mdot
.61382 .35005 Mdot
.71158 .54965 Mdot
.33099 .60856 Mdot
.34688 .35975 Mdot
.5418 .19494 Mdot
.36537 .41783 Mdot
.56712 .84114 Mdot
.81389 .62454 Mdot
.53379 .8207 Mdot
.53526 .42538 Mdot
.2456 .52395 Mdot
.60589 .56577 Mdot
.45424 .58746 Mdot
.55791 .8205 Mdot
.34603 .26942 Mdot
.83971 .45746 Mdot
.48414 .42241 Mdot
.8411 .58697 Mdot
.41478 .38539 Mdot
.5493 .62968 Mdot
.4226 .28486 Mdot
.55117 .49859 Mdot
.71427 .62859 Mdot
.8479 .55448 Mdot
.35993 .53827 Mdot
.5634 .6212 Mdot
.31955 .42279 Mdot
.45975 .29311 Mdot
.32167 .70363 Mdot
.51887 .58909 Mdot
.58546 .27706 Mdot
.85683 .52865 Mdot
.44229 .51268 Mdot
.8261 .53367 Mdot
.33279 .7252 Mdot
.18488 .60721 Mdot
.39256 .69913 Mdot
.27065 .47545 Mdot
.80103 .62619 Mdot
.39391 .34576 Mdot
.59346 .8382 Mdot
.39992 .54908 Mdot
.42428 .58942 Mdot
.85536 .52041 Mdot
.54253 .84318 Mdot
.54453 .485 Mdot
.50563 .58978 Mdot
.20647 .51906 Mdot
.47096 .53887 Mdot
.34544 .46408 Mdot
.56499 .52577 Mdot
.23595 .36335 Mdot
.80989 .60884 Mdot
.52404 .83769 Mdot
.83798 .42306 Mdot
.70536 .54722 Mdot
.64305 .69329 Mdot
.38301 .39396 Mdot
.40515 .46604 Mdot
.34963 .4803 Mdot
.83442 .60061 Mdot
.63754 .44413 Mdot
.29175 .29404 Mdot
.5054 .81591 Mdot
.63388 .25937 Mdot
.27233 .34423 Mdot
.30449 .43559 Mdot
.54293 .50589 Mdot
.47509 .35782 Mdot
.57035 .70689 Mdot
.7071 .64165 Mdot
.57365 .26228 Mdot
.38746 .59323 Mdot
.68559 .59107 Mdot
.3844 .42526 Mdot
.6171 .78067 Mdot
.29863 .32477 Mdot
.58376 .27118 Mdot
.45313 .38938 Mdot
.55934 .81874 Mdot
.5098 .82072 Mdot
.28159 .31584 Mdot
.3678 .62194 Mdot
.82579 .54412 Mdot
.35736 .4429 Mdot
.52343 .45118 Mdot
.6255 .46483 Mdot
.66196 .40109 Mdot
.38669 .78293 Mdot
.59483 .33566 Mdot
.69822 .73211 Mdot
.33027 .45619 Mdot
.55986 .29584 Mdot
.69459 .71189 Mdot
.56532 .29 Mdot
.47679 .30924 Mdot
.42992 .41423 Mdot
.26408 .46171 Mdot
.5264 .3621 Mdot
.85045 .51099 Mdot
.40958 .64525 Mdot
.5551 .82388 Mdot
.25984 .53421 Mdot
.32543 .64269 Mdot
.4046 .58322 Mdot
.39343 .58178 Mdot
.77057 .66203 Mdot
.30479 .42751 Mdot
.59157 .63661 Mdot
.43524 .29077 Mdot
.42142 .5626 Mdot
.55194 .25432 Mdot
.66922 .34284 Mdot
.33564 .33101 Mdot
.58465 .66765 Mdot
.58866 .30154 Mdot
.47749 .3544 Mdot
.38403 .61607 Mdot
.64929 .33133 Mdot
.72738 .48491 Mdot
.55228 .54854 Mdot
.65561 .63819 Mdot
.74636 .6182 Mdot
.51214 .41631 Mdot
.55675 .83383 Mdot
.34388 .42006 Mdot
.66032 .64307 Mdot
.34998 .48471 Mdot
.58236 .18867 Mdot
.8433 .58409 Mdot
.73859 .71008 Mdot
.32819 .28241 Mdot
.26319 .3383 Mdot
.22213 .68916 Mdot
.33799 .55794 Mdot
.64436 .78689 Mdot
.25948 .53398 Mdot
.47768 .13863 Mdot
.4112 .64046 Mdot
.60239 .57561 Mdot
.39979 .37756 Mdot
.72153 .48555 Mdot
.84292 .53974 Mdot
.50889 .4345 Mdot
.60458 .6612 Mdot
.40945 .28041 Mdot
.53084 .354 Mdot
.84149 .50524 Mdot
.83462 .47091 Mdot
.83188 .48079 Mdot
.24523 .45948 Mdot
.58979 .32248 Mdot
.85782 .49883 Mdot
.61831 .62391 Mdot
.53593 .37179 Mdot
.63393 .44478 Mdot
.73047 .53002 Mdot
.624 .7995 Mdot
.63339 .67948 Mdot
.47534 .53567 Mdot
.39072 .39234 Mdot
.86234 .52221 Mdot
.74361 .63314 Mdot
.52146 .47099 Mdot
.77151 .64808 Mdot
.62255 .74467 Mdot
.70522 .7036 Mdot
.75842 .67565 Mdot
.46082 .50614 Mdot
.311 .43662 Mdot
.8687 .52148 Mdot
.5452 .80763 Mdot
.33062 .55164 Mdot
.47751 .3589 Mdot
.61645 .81046 Mdot
.26499 .34784 Mdot
.2351 .53598 Mdot
.4067 .38337 Mdot
.6017 .20426 Mdot
.37236 .50835 Mdot
.48714 .50237 Mdot
.54743 .43323 Mdot
.68767 .72534 Mdot
.41603 .64299 Mdot
.59163 .80361 Mdot
.36231 .48123 Mdot
.52447 .37686 Mdot
.67772 .65181 Mdot
.50024 .83564 Mdot
.48195 .46169 Mdot
.63436 .30861 Mdot
.3449 .42119 Mdot
.30462 .30937 Mdot
.2811 .33555 Mdot
.5788 .22447 Mdot
.61976 .3854 Mdot
.83784 .56821 Mdot
.67243 .78813 Mdot
.76203 .67685 Mdot
.28963 .31599 Mdot
.20587 .64993 Mdot
.25642 .51124 Mdot
.62747 .62977 Mdot
.73289 .46556 Mdot
.44876 .48087 Mdot
.70861 .45671 Mdot
.32881 .52338 Mdot
.54124 .1944 Mdot
.40358 .57913 Mdot
.61888 .62317 Mdot
.34519 .29676 Mdot
.42766 .57959 Mdot
.62524 .31276 Mdot
.45719 .38434 Mdot
.26788 .30888 Mdot
.56283 .81739 Mdot
.41035 .64848 Mdot
.35583 .63267 Mdot
.57501 .34683 Mdot
.51943 .61798 Mdot
.58889 .61639 Mdot
.52619 .44987 Mdot
.5488 .22909 Mdot
.21976 .66916 Mdot
.72841 .70229 Mdot
.61268 .8201 Mdot
.75655 .67889 Mdot
.52467 .82348 Mdot
.3433 .59856 Mdot
.66683 .63519 Mdot
.2751 .5538 Mdot
.24701 .51582 Mdot
.65811 .62178 Mdot
.50439 .82952 Mdot
.52357 .46461 Mdot
.42373 .28827 Mdot
.62523 .39165 Mdot
.73652 .63131 Mdot
.67029 .70745 Mdot
.64404 .62371 Mdot
.59313 .2322 Mdot
.39735 .31798 Mdot
.63566 .65624 Mdot
.50743 .49551 Mdot
.70659 .36806 Mdot
.26523 .33309 Mdot
.32364 .51323 Mdot
.46379 .37647 Mdot
.49966 .8367 Mdot
.22334 .68333 Mdot
.4416 .56184 Mdot
.63726 .35417 Mdot
.81253 .59856 Mdot
.54873 .39636 Mdot
.25238 .35153 Mdot
.61725 .21106 Mdot
.33675 .57567 Mdot
.39481 .38976 Mdot
.52085 .39248 Mdot
.418 .59268 Mdot
.32662 .30267 Mdot
.45103 .3823 Mdot
.67091 .39463 Mdot
.80165 .63545 Mdot
.58574 .37718 Mdot
.47131 .51223 Mdot
.70169 .57494 Mdot
.3902 .47649 Mdot
.40826 .55308 Mdot
.68046 .65999 Mdot
.44376 .53793 Mdot
.82462 .48525 Mdot
.53428 .19678 Mdot
.48603 .53024 Mdot
.61541 .63227 Mdot
.61801 .61891 Mdot
.55889 .20857 Mdot
.438 .28136 Mdot
.33522 .46383 Mdot
.61749 .3722 Mdot
.79495 .65069 Mdot
.47028 .42272 Mdot
.67038 .64777 Mdot
.37244 .43568 Mdot
.62342 .3768 Mdot
.56435 .6254 Mdot
.76253 .67026 Mdot
.50886 .47038 Mdot
.84273 .36632 Mdot
.47676 .82081 Mdot
.33511 .35914 Mdot
.46893 .31224 Mdot
.57174 .82332 Mdot
.32912 .38255 Mdot
.4038 .53225 Mdot
.36334 .46997 Mdot
.60436 .81207 Mdot
.50184 .46055 Mdot
.51086 .48058 Mdot
.25685 .32393 Mdot
.85294 .48702 Mdot
.47035 .53002 Mdot
.23149 .52854 Mdot
.63969 .7 Mdot
.57044 .43611 Mdot
.35931 .41902 Mdot
.20166 .39173 Mdot
.40251 .43979 Mdot
.45587 .54985 Mdot
.66548 .79654 Mdot
.51433 .43235 Mdot
.34292 .42284 Mdot
.84439 .36996 Mdot
.84758 .35877 Mdot
.35327 .41145 Mdot
.8282 .61146 Mdot
.51439 .4776 Mdot
.25332 .35443 Mdot
.24642 .49327 Mdot
.66012 .36475 Mdot
.54455 .24737 Mdot
.77432 .67518 Mdot
.19874 .65574 Mdot
.34523 .46867 Mdot
.37822 .37414 Mdot
.77217 .682 Mdot
.50588 .39179 Mdot
.60193 .61987 Mdot
.18632 .60757 Mdot
.42617 .82059 Mdot
.56855 .83745 Mdot
.5975 .22458 Mdot
.38528 .78709 Mdot
.44877 .80067 Mdot
.36081 .52427 Mdot
.62161 .81098 Mdot
.58114 .59758 Mdot
.59254 .19171 Mdot
.55716 .81919 Mdot
.24751 .34143 Mdot
.34237 .7529 Mdot
.41147 .55045 Mdot
.52195 .43683 Mdot
.44646 .41125 Mdot
.23429 .36827 Mdot
.28868 .43755 Mdot
.54448 .37977 Mdot
.6439 .59154 Mdot
.47786 .31363 Mdot
.30866 .28113 Mdot
.63437 .21444 Mdot
.53173 .45547 Mdot
.82401 .4412 Mdot
.29966 .44788 Mdot
.6301 .60149 Mdot
.45472 .30009 Mdot
.67312 .68041 Mdot
.59676 .63492 Mdot
.57072 .46221 Mdot
.80526 .62947 Mdot
.59279 .63434 Mdot
.82701 .4549 Mdot
.59032 .8425 Mdot
.77779 .63651 Mdot
.44745 .60176 Mdot
.59145 .57322 Mdot
.62334 .79604 Mdot
.63169 .78895 Mdot
.83011 .43478 Mdot
.49609 .80963 Mdot
.6559 .61779 Mdot
.53151 .39778 Mdot
.66783 .35126 Mdot
.62266 .32079 Mdot
.57634 .82148 Mdot
.55519 .20276 Mdot
.6962 .70526 Mdot
.32714 .2886 Mdot
.50373 .83239 Mdot
.55168 .48792 Mdot
.67181 .67388 Mdot
.38711 .44622 Mdot
.5085 .58858 Mdot
.34748 .67743 Mdot
.86398 .4625 Mdot
.27647 .32169 Mdot
.71763 .70068 Mdot
.28748 .29945 Mdot
.48202 .37391 Mdot
.46387 .81188 Mdot
.41424 .27928 Mdot
.47491 .58991 Mdot
.33979 .6189 Mdot
.64722 .75416 Mdot
.53399 .475 Mdot
.23333 .34791 Mdot
.61472 .2583 Mdot
.77536 .66059 Mdot
.6958 .71286 Mdot
.83549 .40836 Mdot
.63709 .66428 Mdot
.58712 .3007 Mdot
.82269 .46601 Mdot
.31666 .29386 Mdot
.63521 .61665 Mdot
.84534 .49967 Mdot
.37743 .29021 Mdot
.81691 .61994 Mdot
.29125 .49148 Mdot
.60708 .63175 Mdot
.21897 .37283 Mdot
.63054 .62242 Mdot
.62765 .61801 Mdot
.71918 .71172 Mdot
.32222 .42372 Mdot
.33779 .41501 Mdot
.356 .44326 Mdot
.32 .66521 Mdot
.65925 .35973 Mdot
.45859 .51748 Mdot
.8389 .42681 Mdot
.61665 .3864 Mdot
.53608 .79578 Mdot
.55538 .8283 Mdot
.27016 .55224 Mdot
.52631 .42704 Mdot
.22966 .35911 Mdot
.61598 .22436 Mdot
.71855 .64709 Mdot
.85244 .49364 Mdot
.52681 .42483 Mdot
.72397 .4721 Mdot
.66687 .2495 Mdot
.21472 .50878 Mdot
.3401 .46752 Mdot
.43757 .52512 Mdot
.5594 .37942 Mdot
.69289 .58356 Mdot
.53145 .81884 Mdot
.65658 .79931 Mdot
.82523 .43656 Mdot
.34251 .47542 Mdot
.63864 .62561 Mdot
.42842 .40928 Mdot
.66369 .73264 Mdot
.84072 .41665 Mdot
.36862 .78649 Mdot
.47621 .35692 Mdot
.51395 .83192 Mdot
.32336 .43237 Mdot
.60351 .62048 Mdot
.64986 .62305 Mdot
.82605 .47605 Mdot
.35955 .35231 Mdot
.49873 .41448 Mdot
.39202 .42932 Mdot
.66618 .58869 Mdot
.39027 .55995 Mdot
.59319 .20461 Mdot
.29583 .4275 Mdot
.835 .40708 Mdot
.4303 .79915 Mdot
.64666 .25743 Mdot
.8392 .38885 Mdot
.38982 .31776 Mdot
.3863 .56039 Mdot
.18294 .58396 Mdot
.65411 .64081 Mdot
.40397 .68389 Mdot
.63341 .40114 Mdot
.65151 .60679 Mdot
.32627 .34778 Mdot
.63639 .67333 Mdot
.57975 .66291 Mdot
.46245 .37394 Mdot
.46358 .80693 Mdot
.46182 .38075 Mdot
.65752 .79592 Mdot
.46015 .50175 Mdot
.4789 .32299 Mdot
.64506 .22641 Mdot
.3481 .59784 Mdot
.30879 .30331 Mdot
.78495 .63618 Mdot
.72707 .53428 Mdot
.45075 .3744 Mdot
.44129 .37901 Mdot
.35523 .29625 Mdot
.31168 .5638 Mdot
.82256 .58387 Mdot
.54456 .84019 Mdot
.34002 .64827 Mdot
.36278 .29678 Mdot
.53822 .42155 Mdot
.52338 .44583 Mdot
.73734 .68144 Mdot
.39141 .62974 Mdot
.8532 .56889 Mdot
.56656 .18515 Mdot
.31633 .32795 Mdot
.45666 .47016 Mdot
.73833 .47727 Mdot
.61807 .58606 Mdot
.36875 .59424 Mdot
.53535 .46896 Mdot
.33852 .39108 Mdot
.36271 .32133 Mdot
.39356 .57137 Mdot
.59941 .66664 Mdot
.36976 .61929 Mdot
.30885 .55291 Mdot
.57307 .22122 Mdot
.56912 .82912 Mdot
.4385 .39638 Mdot
.59113 .61914 Mdot
.39192 .60147 Mdot
.62528 .32744 Mdot
.73495 .50494 Mdot
.86974 .48644 Mdot
.79793 .61476 Mdot
.45277 .34885 Mdot
.30334 .32144 Mdot
.33445 .73428 Mdot
.72779 .70131 Mdot
.49639 .42812 Mdot
.57293 .81861 Mdot
.58738 .28413 Mdot
.75177 .67422 Mdot
.46575 .3046 Mdot
.43687 .5065 Mdot
.53708 .83052 Mdot
.60927 .74434 Mdot
.51091 .83641 Mdot
.62233 .23246 Mdot
.60579 .35801 Mdot
.44386 .82473 Mdot
.39693 .43561 Mdot
.52942 .48027 Mdot
.71212 .35686 Mdot
.44715 .48566 Mdot
.60717 .80724 Mdot
.37751 .31667 Mdot
.61863 .6536 Mdot
.35194 .27465 Mdot
.34424 .46694 Mdot
.80718 .61139 Mdot
.28932 .32322 Mdot
.5383 .83921 Mdot
.65816 .35477 Mdot
.63619 .74901 Mdot
.55307 .2092 Mdot
.71514 .54124 Mdot
.53629 .60216 Mdot
.57529 .27266 Mdot
.547 .61596 Mdot
.73107 .64534 Mdot
.63332 .32109 Mdot
.84521 .54828 Mdot
.7424 .62288 Mdot
.44749 .41159 Mdot
.52674 .61844 Mdot
.36502 .35245 Mdot
.85467 .55124 Mdot
.72089 .64108 Mdot
.22994 .36871 Mdot
.56873 .83625 Mdot
.49834 .80618 Mdot
.83991 .38407 Mdot
.32187 .42692 Mdot
.51954 .37299 Mdot
.62651 .8089 Mdot
.48055 .41676 Mdot
.45304 .80103 Mdot
.53378 .47461 Mdot
.38874 .39783 Mdot
.85278 .51223 Mdot
.56882 .63353 Mdot
.42648 .41849 Mdot
.69509 .31308 Mdot
.39048 .38843 Mdot
.72089 .6316 Mdot
.53895 .4577 Mdot
.40011 .66259 Mdot
.7303 .47752 Mdot
.37949 .77951 Mdot
.35192 .30143 Mdot
.56514 .82642 Mdot
.58059 .81332 Mdot
.64253 .71063 Mdot
.44537 .61308 Mdot
.83833 .38232 Mdot
.57605 .32307 Mdot
.57301 .47618 Mdot
.45579 .38255 Mdot
.57657 .66557 Mdot
.52062 .81076 Mdot
.6303 .37684 Mdot
.71882 .50313 Mdot
.58612 .27949 Mdot
.78423 .66126 Mdot
.39855 .45963 Mdot
.28936 .45454 Mdot
.37123 .29169 Mdot
.23334 .3662 Mdot
.33627 .27609 Mdot
.31335 .41282 Mdot
.60705 .80522 Mdot
.44198 .56097 Mdot
.4336 .51837 Mdot
.47256 .39861 Mdot
.58998 .79804 Mdot
.35067 .50681 Mdot
.31693 .53577 Mdot
.54857 .23388 Mdot
.82878 .4233 Mdot
.4749 .36308 Mdot
.41794 .54996 Mdot
.48578 .48625 Mdot
.57906 .3696 Mdot
.34691 .4682 Mdot
.33542 .42162 Mdot
.43311 .38814 Mdot
.83077 .50777 Mdot
.48638 .51427 Mdot
.59196 .58432 Mdot
.49564 .82313 Mdot
.47354 .49244 Mdot
.58224 .8158 Mdot
.52917 .35299 Mdot
.83293 .48802 Mdot
.66863 .64904 Mdot
.62083 .74269 Mdot
.6315 .3897 Mdot
.34271 .28291 Mdot
.76206 .67182 Mdot
.49421 .42864 Mdot
.45463 .57113 Mdot
.40861 .27426 Mdot
.58622 .83956 Mdot
.52147 .55211 Mdot
.21763 .66532 Mdot
.5084 .59543 Mdot
.72635 .49103 Mdot
.72372 .47956 Mdot
.2983 .56387 Mdot
.52276 .45177 Mdot
.36709 .52868 Mdot
.57432 .36796 Mdot
.55429 .22813 Mdot
.68461 .74595 Mdot
.85964 .4567 Mdot
.34633 .36099 Mdot
.55658 .84691 Mdot
.34091 .33612 Mdot
.36326 .38799 Mdot
.43367 .79868 Mdot
.4597 .5794 Mdot
.58424 .33907 Mdot
.63781 .69005 Mdot
.38855 .31447 Mdot
.85313 .44834 Mdot
.45285 .55263 Mdot
.62435 .65958 Mdot
.32631 .71714 Mdot
.409 .55846 Mdot
.19954 .52704 Mdot
.25326 .52379 Mdot
.59827 .83389 Mdot
.55822 .82056 Mdot
.27067 .45854 Mdot
.51341 .47656 Mdot
.45691 .56285 Mdot
.84024 .50546 Mdot
.51913 .61114 Mdot
.79562 .62697 Mdot
.25059 .45532 Mdot
.56953 .23313 Mdot
.74053 .62033 Mdot
.70951 .64149 Mdot
.71878 .54343 Mdot
.58802 .25625 Mdot
.81969 .5419 Mdot
.56209 .56222 Mdot
.35779 .6275 Mdot
.34509 .75596 Mdot
.84083 .42383 Mdot
.31721 .31319 Mdot
.57465 .59123 Mdot
.67257 .72367 Mdot
.48641 .5116 Mdot
.62949 .59737 Mdot
.35761 .45373 Mdot
.58967 .61253 Mdot
.22422 .4872 Mdot
.30127 .2943 Mdot
.79435 .64994 Mdot
.63654 .39585 Mdot
.69926 .45771 Mdot
.35293 .5319 Mdot
.41576 .66623 Mdot
.36711 .27069 Mdot
.86743 .48288 Mdot
.32186 .53075 Mdot
.18448 .57669 Mdot
.29294 .56056 Mdot
.72401 .69785 Mdot
.20637 .65831 Mdot
.31628 .56546 Mdot
.65286 .80144 Mdot
.32305 .34466 Mdot
.61928 .24498 Mdot
.29115 .2911 Mdot
.73422 .64217 Mdot
.57204 .27048 Mdot
.56314 .52378 Mdot
.82316 .60411 Mdot
.62156 .59633 Mdot
.61234 .64564 Mdot
.82343 .52683 Mdot
.52987 .83213 Mdot
.48363 .82248 Mdot
.33382 .55869 Mdot
.38251 .37816 Mdot
.23037 .69229 Mdot
.32744 .64521 Mdot
.54532 .17005 Mdot
.79777 .6121 Mdot
.69403 .29688 Mdot
.49463 .42447 Mdot
.35948 .43977 Mdot
.84309 .5165 Mdot
.59897 .80394 Mdot
.53059 .48689 Mdot
.41 .61642 Mdot
.69945 .65092 Mdot
.66169 .72823 Mdot
.34186 .43307 Mdot
.76023 .65553 Mdot
.36595 .595 Mdot
.56227 .63201 Mdot
.54422 .83221 Mdot
.34436 .28227 Mdot
.70638 .54211 Mdot
.82964 .42614 Mdot
.7307 .51552 Mdot
.48531 .83191 Mdot
.24504 .45935 Mdot
.33489 .73951 Mdot
.83986 .43227 Mdot
.32888 .31352 Mdot
.6089 .28115 Mdot
.84147 .36748 Mdot
.84044 .58752 Mdot
.45837 .56261 Mdot
.59431 .37766 Mdot
.64273 .80391 Mdot
.40545 .62126 Mdot
.7091 .71362 Mdot
.54285 .19359 Mdot
.46277 .8166 Mdot
.65254 .32427 Mdot
.60506 .37466 Mdot
.60991 .61255 Mdot
.44146 .32964 Mdot
.40028 .38294 Mdot
.32416 .6723 Mdot
.50447 .82869 Mdot
.57389 .2159 Mdot
.53424 .19707 Mdot
.61713 .22986 Mdot
.45408 .35611 Mdot
.81158 .61886 Mdot
.49536 .60844 Mdot
.56078 .20111 Mdot
.83604 .50138 Mdot
.72476 .44972 Mdot
.36201 .51109 Mdot
.54662 .21952 Mdot
.66238 .63555 Mdot
.37591 .77642 Mdot
.84478 .3946 Mdot
.55494 .24177 Mdot
.85627 .56078 Mdot
.73922 .71205 Mdot
.44899 .35828 Mdot
.34782 .31573 Mdot
.61347 .57844 Mdot
.46108 .53347 Mdot
.21407 .50136 Mdot
.32612 .6413 Mdot
.48169 .8063 Mdot
.39879 .61039 Mdot
.62157 .43978 Mdot
.35991 .43076 Mdot
.77783 .65451 Mdot
.60262 .62433 Mdot
.7853 .64713 Mdot
.57832 .24362 Mdot
.6178 .38797 Mdot
.843 .3548 Mdot
.25112 .35554 Mdot
.66486 .33962 Mdot
.54701 .53971 Mdot
.57408 .59675 Mdot
.57515 .46816 Mdot
.32337 .50029 Mdot
.64729 .65027 Mdot
.43697 .81145 Mdot
.82399 .59966 Mdot
.36268 .29894 Mdot
.61855 .59035 Mdot
.27197 .53575 Mdot
.64522 .56103 Mdot
.65233 .32096 Mdot
.323 .53396 Mdot
.40837 .79916 Mdot
.20708 .53552 Mdot
.35119 .4914 Mdot
.39125 .55752 Mdot
.64967 .59732 Mdot
.57166 .58131 Mdot
.42193 .7999 Mdot
.28381 .56079 Mdot
.35505 .52063 Mdot
.53475 .83949 Mdot
.59561 .26307 Mdot
.32225 .43572 Mdot
.34609 .74633 Mdot
.63876 .61813 Mdot
.37268 .43115 Mdot
.47075 .54355 Mdot
.60703 .20791 Mdot
.83264 .53451 Mdot
.34639 .72092 Mdot
.56237 .56156 Mdot
.67358 .25232 Mdot
.8422 .54572 Mdot
.27225 .52422 Mdot
.67056 .78548 Mdot
.46352 .5719 Mdot
.36278 .27375 Mdot
.70817 .30391 Mdot
.5229 .41914 Mdot
.64353 .43347 Mdot
.56388 .3984 Mdot
.69039 .51511 Mdot
.19276 .52636 Mdot
.52577 .43907 Mdot
.40475 .56215 Mdot
.43797 .55202 Mdot
.62553 .64209 Mdot
.64424 .42821 Mdot
.58148 .4434 Mdot
.52291 .55378 Mdot
.68572 .63118 Mdot
.59496 .60295 Mdot
.62475 .64808 Mdot
.30998 .43712 Mdot
.42191 .80113 Mdot
.4792 .82096 Mdot
.58705 .32856 Mdot
.84707 .51464 Mdot
.70919 .35921 Mdot
.7944 .61846 Mdot
.37755 .47005 Mdot
.30816 .43302 Mdot
.7309 .50934 Mdot
.84333 .39592 Mdot
.40732 .41391 Mdot
.50813 .54042 Mdot
.73252 .71517 Mdot
.77093 .65223 Mdot
.30759 .4448 Mdot
.24666 .33688 Mdot
.34811 .76036 Mdot
.61777 .60356 Mdot
.30438 .2899 Mdot
.34332 .64812 Mdot
.73322 .70055 Mdot
.58103 .36023 Mdot
.46036 .57337 Mdot
.58713 .20586 Mdot
.63309 .32929 Mdot
.36082 .64883 Mdot
.61597 .21072 Mdot
.58943 .25572 Mdot
.8184 .54491 Mdot
.5739 .4752 Mdot
.42787 .47634 Mdot
.43071 .40807 Mdot
.83365 .41559 Mdot
.34481 .6867 Mdot
.72385 .47052 Mdot
.5526 .16905 Mdot
.19318 .52434 Mdot
.45352 .79981 Mdot
.82599 .4322 Mdot
.24772 .51624 Mdot
.56731 .37267 Mdot
.18949 .40526 Mdot
.41817 .41144 Mdot
.44925 .38829 Mdot
.30975 .55373 Mdot
.64436 .73869 Mdot
.39758 .422 Mdot
.84904 .38162 Mdot
.74977 .67883 Mdot
.56486 .34431 Mdot
.53612 .16415 Mdot
.5488 .83072 Mdot
.71144 .47418 Mdot
.31238 .42697 Mdot
.80343 .63077 Mdot
.21736 .49336 Mdot
.63105 .80744 Mdot
.47289 .50174 Mdot
.34912 .32359 Mdot
.65952 .72317 Mdot
.28848 .30247 Mdot
.53228 .41225 Mdot
.53295 .18812 Mdot
.26721 .33032 Mdot
.67873 .70854 Mdot
.49773 .45988 Mdot
.34899 .38485 Mdot
.33738 .37539 Mdot
.46362 .47343 Mdot
.4569 .58819 Mdot
.41907 .54953 Mdot
.43913 .51621 Mdot
.35123 .50307 Mdot
.44883 .46796 Mdot
.24542 .36174 Mdot
.24854 .53381 Mdot
.59758 .23609 Mdot
.36053 .7639 Mdot
.63381 .6584 Mdot
.41209 .63682 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool0
0ol0003oooooooooo`2Gooooo`?o0000[oooool001cooooo00?o0000ooooooooool0Uoooool2o`00
00Cooooo0ol0002Yooooo`007?ooool00ol0003oooooooooo`2Mooooo`Go0000Yoooool001cooooo
00?o0000ooooooooool0Woooool4o`000003ooooool0003o00000:?ooooo000Looooo`;o0000XOoo
ool6o`000:?ooooo000Looooo`03o`000?oooooooooo0:;ooooo1?l0002Sooooo`007?ooool00ol0
003oooooooooo`2Tooooo`;o000000?oooooo`000?l00000X?ooool001cooooo00?o0000oooooooo
ool0Yoooool2o`000:3ooooo000Looooo`03o`000?oooooooooo0:Wooooo0ol0002Mooooo`007?oo
ool00ol0003oooooooooo`2Wooooo`Go00001?ooool2o`0009Oooooo000Looooo`03o`000?oooooo
oooo0:Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0002Eooooo`007?ooool00ol0
003oooooooooo`2Zooooo`Go00000_ooool3o`0009Gooooo000Looooo`03o`000?oooooooooo0:[o
oooo1_l0002Iooooo`007?ooool00ol0003oooooooooo`2[ooooo`Ko00001?ooool2o`0009;ooooo
000Looooo`03o`000?oooooooooo0:gooooo1Ol00003ooooo`;o0000T_ooool001cooooo00?o0000
ooooooooool0[_ooool4o`0000;ooooo0_l000000ooooooo0000o`00002@ooooo`007?ooool00ol0
003oooooooooo`2Yooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`00
0?l000000_l0002>ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0ZOooool6o`0000;ooooo0_l00006ooooo`;o00000_ooool2
o`0008[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Zooooo`Wo00002_ooool2o`0008[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`2Zooooo`[o0000UOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Z_ooool:o`00017ooooo0_l00022
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0/?ooool4o`0000Oooooo1?l000000ooooooo0000o`000003oooo
o`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:gooooo0_l000000ooooooo0000o`000002o`0000Oo
oooo1?l000001?oooooo0000o`000?l00026ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2]ooooo`;o000000?o
ooooo`000?l000000_l0000=ooooo`;o000000Coooooo`000?l0003o0000P_ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0[?ooool3o`0001Gooooo0ol00003ooooo`;o0000OOooool001cooooo00?o0000oooooooo
ool0[?ooool3o`0000Sooooo0_l0000Aooooo`;o0000OOooool001cooooo00?o0000ooooooooool0
[Oooool3o`0000Kooooo0ol0002@ooooo`007?ooool00ol0003oooooooooo`2]ooooo`?o00001_oo
ool4o`0000Cooooo0_l00004ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0^?ooool2
o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo
0:cooooo1_l0000Cooooo`;o00001oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo0:co
oooo1_l00003ooooo`;o00001_ooool2o`0000Kooooo0ol00021ooooo`007?ooool00ol0003ooooo
ooooo`2]ooooo`?o00001Oooool2o`0000Kooooo0ol00006ooooo`;o0000POooool001cooooo00?o
0000ooooooooool0[Oooool3o`0000kooooo0_l00002ooooo`;o0000QOooool001cooooo00?o0000
ooooooooool0[Oooool5o`00013ooooo0_l00002ooooo`?o0000P?ooool001cooooo00?o0000oooo
ooooool0[Oooool5o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o0000
00Oo0000Noooool001cooooo00?o0000ooooooooool0[Oooool3o`0000Sooooo0_l00003ooooo`;o
00001_ooool@o`0007Cooooo000Looooo`;o0000[_ooool3o`0001gooooo3?l0001`ooooo`007?oo
ool00ol0003oooooooooo`2]ooooo`Go00005?ooool2o`0000Sooooo2Ol0001`ooooo`007?ooool0
0ol0003oooooooooo`2]ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Kooooo1?l00006
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00077ooooo000Looooo`03o`000?oooooo
oooo0:oooooo0_l0000:ooooo`?o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2
o`00073ooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000hooooo`?o00001Oooool2o`00
00Gooooo1?l00008ooooo`;o000000?oooooo`000?l000002?ooool3o`0006oooooo000Looooo`03
o`000?oooooooooo06gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool4o`00
033ooooo0_l00005ooooo`;o00001Oooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00002
ooooo`Co00001oooool4o`0006gooooo000Looooo`03o`000?oooooooooo06Wooooo0ol000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000001_ooool4o`0003Kooooo0_l0000=oooo
o`;o000000?oooooo`000?l000001ol00009ooooo`;o0000KOooool001cooooo00?o0000oooooooo
ool0IOooool7o`000003ooooool0003o000000?ooooo1?l00010ooooo`?o000000?oooooo`000?l0
00002?ooool3o`0000?ooooo1Ol0001jooooo`007?ooool00ol0003oooooooooo`1Sooooo`Ko0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000gooooo0_l00006ooooo`;o0000
;?ooool2o`000003ooooool0003o000000Sooooo0ol00006ooooo`;o00000_ooool5o`0000Oooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo0_l0000@ooooo`Co00001?ooool2o`0002oooooo0ol0000Dooooo`Go00001ooo
ool3o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo0ol00004ooooo`;o00000oooool2
o`0001?ooooo1?l00006ooooo`;o0000;_ooool2o`0000Gooooo0_l0000@ooooo`?o00001oooool2
o`0006Wooooo000Looooo`03o`000?oooooooooo067ooooo0_l00004ooooo`;o00000oooool2o`00
013ooooo1ol000000ooooooo0000o`000003ooooo`;o00009Oooool2o`0000Oooooo0_l00002oooo
o`;o000000?oooooo`000?l000004?ooool7o`0006kooooo000Looooo`03o`000?oooooooooo05co
oooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l00002ooooo`?o000000?oooooo`000?l0
00001?l00004ooooo`;o00009?ooool2o`0000Oooooo0_l00002ooooo`;o00005?ooool6o`0006ko
oooo000Looooo`03o`000?oooooooooo05_ooooo0ol000000ooooooo0000o`000002o`0000Cooooo
0_l0000<ooooo`Wo00001oooool3o`0000;ooooo1?l00004ooooo`;o00007_ooool4o`0000Wooooo
0_l0000Jooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Foooool2o`000004ooooool0
003o0000o`0000;ooooo0_l0000@ooooo`co00002Oooool2o`0000Kooooo0_l0000Nooooo`Co0000
4?ooool2o`0001;ooooo1Ol000001?oooooo0000o`000?l0001Vooooo`007?ooool00ol0003ooooo
ooooo`1Kooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00002ooooo`Co0000
0_ooool;o`00017ooooo0_l0000Nooooo`;o00003?ooool2o`0000Cooooo0_l0000Booooo`Wo0000
I_ooool001cooooo0_l0001Kooooo`;o00004?ooool2o`000003ooooool0003o000000_o000000?o
ooooo`000?l000004Oooool3o`0001oooooo0_l00007ooooo`;o00000oooool2o`0001Wooooo1Ol0
00000ooooooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2
o`0000Gooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000Oo00000_ooool2
o`00017ooooo1_l0000Uooooo`;o00000oooool2o`0001Wooooo0ol00003ooooo`?o0000IOooool0
01cooooo00?o0000ooooooooool0E?ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`00
00_ooooo1_l0000Iooooo`Co0000:_ooool2o`0001Wooooo1_l000000ooooooo0000o`00001Uoooo
o`007?ooool00ol0003oooooooooo`1Cooooo`;o00002_ooool2o`00017ooooo1?l0000Qooooo`?o
00009oooool3o`0000Kooooo0_l0000@ooooo`Go0000J?ooool001cooooo00?o0000ooooooooool0
Doooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00009ooooo`;o0000
00?oooooo`000?l000004oooool5o`0002Oooooo0ol00003ooooo`;o000000?oooooo`000?l00000
4?ooool4o`0006Wooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00007ooooo`;o00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000000ol0
00000ooooooo0000o`000002o`00017ooooo1Ol0000Xooooo`Co000000?oooooo`000?l000005?oo
ool3o`0006Wooooo000Looooo`03o`000?oooooooooo05Sooooo1?l0000Aooooo`Go00001?ooool9
o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0002Sooooo1?l0
000Fooooo`?o0000JOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Gooooo0_l00002
ooooo`;o00000oooool2o`0000kooooo1Ol000000ooooooo0000o`000009o`000003ooooool0003o
000000Go000000Coooooo`000?l0003o00003?ooool3o`0001Gooooo0_l00005ooooo`;o00000ooo
ool2o`0000Gooooo1Ol00002ooooo`;o00001?ooool2o`0000_ooooo0ol00005ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0Coooool3o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l0000=ooooo`;o000000?oooooo`000?l000006Ol0000<ooooo`;o00005_ooool2
o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00002oooool3o`0000Gooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1=oooo
o`;o000000?oooooo`000?l000002_ooool4o`0000?ooooo0ol00008ooooo`;o000000?oooooo`00
0?l000002Ol000000ooooooo0000o`00000=o`0000;ooooo1?l0000Yooooo`;o00002_ooool2o`00
0003ooooool0003o000000Cooooo0_l0000;ooooo`;o0000J_ooool001cooooo00?o0000oooooooo
ool0COooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool3o`0000?ooooo0_l000001?oooooo
0000o`000?ooool@o`000003ooooool0003o0000013o00002?ooool2o`0001;ooooo0_l0000;oooo
o`;o00002_ooool6o`0000;ooooo0_l0000Eooooo`;o0000HOooool001cooooo00?o0000oooooooo
ool0D_ooool3o`0000?ooooo0_l0000?ooooobGo000000?oooooo`000?l000002Oooool2o`0001;o
oooo0_l0000Iooooo`Co00000_ooool2o`0000kooooo0_l00005ooooo`;o0000HOooool001cooooo
00?o0000ooooooooool0B_ooool4o`0000Cooooo0_l00004ooooo`;o00004Oooool4o`0000;ooooo
8?l00006ooooo`;o000000?oooooo`000?l000008Oooool2o`0001gooooo0_l000000ooooooo0000
o`000002ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0B_ooool5o`0000?ooooo0_l0
000Gooooo`;o00001?oooolOo`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000
o`00000Aooooo`;o00002oooool2o`000003ooooool0003o000000oooooo0_l00004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Co0000I?ooool001cooooo00?o0000ooooooooool0BOoo
ool3o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00002_oooolSo`0000Kooooo0_l0
000Aooooo`;o00001Oooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool4o`0000Cooooo2Ol0
001Tooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00001oooool2o`000003ooooool0003o
000000kooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000001co000000?ooooo
o`000?l000007oooool2o`000003ooooool0003o000001Cooooo0ol00006ooooo`;o00000oooool:
o`0006Cooooo000Looooo`;o0000BOooool2o`0000Sooooo0_l0000Booooo`;o00000_ooool6o`00
00;ooooo8ol0000Rooooo`;o00002oooool2o`0000Oooooo0_l0000;ooooo`[o0000;?ooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00004ooooo`;o00006_ooool6o`000003
ooooool0003o0000023o000000Coooooo`000?l0003o00004Oooool3o`0001Wooooo0_l0000?oooo
o`;o00000_ooool=o`0002[ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`16ooooo`;o
00001_ooool3o`0001Wooooo0_l00005ooooobSo000000?oooooo`000?l000001Oooool2o`0000Go
oooo0ol0000Pooooo`Co00000oooool2o`000003ooooool0003o000000co000000Coooooo`000?l0
003o00009oooool5o`0003Kooooo000Looooo`03o`000?oooooooooo04Kooooo0ol00005ooooo`?o
00006?ooool3o`000003ooooool0003o000000Cooooo2Ol000000ooooooo0000o`00000Go`000004
ooooool0003o0000ooooo`Co00000oooool2o`0001Kooooo0_l00006ooooo`;o00002?ooool4o`00
00?ooooo5Ol0000Wooooo`Go0000=_ooool001cooooo00?o0000ooooooooool0AOooool4o`0000?o
oooo0_l00002ooooo`;o00005oooool3o`000003ooooool0003o000000Cooooo8ol000000ooooooo
0000o`000008o`0000Kooooo0_l0000@ooooo`;o00001_ooool2o`000003ooooool0003o000000co
oooo4ol0000Zooooo`Co0000=_ooool001cooooo00?o0000ooooooooool0AOooool2o`000005oooo
ool0003o0000o`000?ooool01_l0000Hooooo`;o000000?oooooo`000?l000001OoooolPo`0000?o
oooo2_l00006ooooo`;o00005Oooool5o`000003ooooool0003o000000gooooo0_l000000ooooooo
0000o`00000;o`0002_ooooo0_l000000ooooooo0000o`00000fooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00001?ooool4o`0000?ooooo0_l0000Toooooaco00002_ooool3o`0001[ooooo
0_l00004ooooo`Wo00000oooool2o`000003ooooool0003o000000Gooooo4Ol0000Zooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0@Oooool5o`000004ooooool0003o0000o`0002gooooo
0ol000000ooooooo0000o`00000Bo`0000kooooo0_l0000;ooooo`;o00002oooool3o`0000?ooooo
2_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool@o`0002[ooooo1?l0000gooooo`00
7?ooool00ol0003oooooooooo`12ooooo`Co00009?ooool2o`0000_ooooo0ol000000ooooooo0000
o`00000Do`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo
0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000;o00000oooool>o`0002cooooo1?l0000gooooo`007?oo
ool00ol0003oooooooooo`10ooooo`Go00001Oooool3o`0001gooooo0_l0000;ooooo`Co000000?o
ooooo`000?l000000_l00003ooooo`;o00000oooool6o`000004ooooool0003o0000ooooo`?o0000
0_ooool4o`0000[ooooo1?l0000<ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000004o`0000;ooooo3?l00003ooooo`go0000;oooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo043ooooo1?l00005ooooo`Co00007Oooool2o`000003ooooool0003o000000[ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000001?oo
ool3o`0000;ooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l00006oooooaKo00001?oo
ool=o`0002cooooo0_l000000ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`10
ooooo`?o00001_ooool2o`0001cooooo0_l000001?oooooo0000o`000?ooool3o`0000kooooo1?l0
000:ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000Dooooo`;o00000ooo
ool3o`0000Cooooo3_l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l00000
2Ol0000^ooooo`?o000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0@?oo
ool2o`0002;ooooo1Ol00005ooooo`;o00003_ooool4o`000003ooooool0003o000000[ooooo1ol0
000Looooo`?o00001?ooool:o`0000;ooooo2?l000000ooooooo0000o`00000=o`0002oooooo0ol0
00000ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00001?ooool2
o`0001gooooo1?l00006ooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`;o00001?ooool2
o`0000?ooooo1ol0000Mooooo`;o00000_ooool2o`0000;ooooo3_l000000ooooooo0000o`000002
o`000003ooooool0003o000000co0000<Oooool2o`0003[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0looooo`Go00001?ooool2o`0001cooooo1Ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
0005ooooo`Ko00002_ooool;o`0000gooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Bo`0000Cooooo2_l0000booooo`;o000000?oooooo`000?l00000=ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0looooo`Co00008oooool5o`0000;ooooo0_l0000=ooooo`Go0000
0_ooool3o`0000?ooooo2?l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000Oooooo
1?l00003ooooo`;o00000_oooolDo`0000Cooooo1ol0000fooooo`Co0000=oooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0??oo
ool2o`0002Kooooo0ol0000:ooooo`;o00001_ooool5o`0000;ooooo0ol000000ooooooo0000o`00
0007o`0000Wooooo0_l0000Aooooo`;o00000oooool2o`0000?ooooo1?l00002oooooaGo00000ooo
ool7o`0003Kooooo0ol0000hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000jooooo`;o00009_ooool5o`0000[ooooo0ol0
0003ooooo`Wo000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00004Oooool2o`0000Sooooo
6ol00004ooooo`?o000000?oooooo`000?l00000=oooool2o`0003Sooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`0hooooo`Oo00008_ooool5o`0000Sooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1?ooool3o`0000Sooooo1Ol0000Uoooooako00000oooool2o`0003[ooooo0_l0000hooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0=oooool9o`00027ooooo1_l00007ooooo`;o00001?ooool2o`0000gooooo0_l0
0002ooooo`Ko00007oooool2o`0000Cooooo8?l0000iooooo`?o0000>oooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Oooooo
2Ol0000Qooooo`;o00000_ooool2o`0000Sooooo0_l0000Booooo`?o000000Coooooo`000?l0003o
00000oooool3o`0001Wooooo0_l000000ooooooo0000o`000004ooooob3o0000>Oooool3o`000003
ooooool0003o000003Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`0hooooo`Ko00008_ooool4o`0000Kooooo0_l00003oooo
o`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00003_ooool2o`00
00Wooooo0_l000000ooooooo0000o`000003oooooaco00000oooool2o`0003Wooooo0_l00002oooo
o`;o0000>?ooool001cooooo00?o0000ooooooooool0>?ooool3o`0002?ooooo1_l00003ooooo`Go
00001Oooool4o`0000;ooooo0ol00007ooooo`;o00001?ooool3o`0000kooooo0_l00004ooooo`;o
00000oooool2o`0000Oooooo0_l00003ooooob3o0000>_ooool6o`0003Sooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo
2Ol0000=ooooo`;o00003oooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool2o`000003ooooool0003o000001co0000??ooool4o`0003Sooooo000Looooo`03o`000?oo
oooooooo06?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`000003oooo
ool0003o000000?o00001?ooool2o`0001Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1oooool3o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000006Ol000000ooooooo0000
o`00000hooooo`;o000000Coooooo`000?l0003o0000>_ooool001cooooo00?o0000ooooooooool0
G?ooool2o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000000_ooool2o`0000_o
oooo0_l00002ooooo`;o00005_ooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l000000ooooolMo`0000?ooooo0_l0000hooooo`Oo0000>Oooool001cooooo
00?o0000ooooooooool0G?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0
003ooooo0ol00006ooooo`;o00001_ooool2o`000003ooooool0003o000001oooooo0_l00008oooo
o`;o000000?oooooo`000?l000001_oooolMo`0003_ooooo0_l000001?oooooo0000o`000?l0000i
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Oooool2o`0000?ooooo0_l00002oooo
o`Co00001?ooool2o`0000;ooooo0_l00005ooooo`;o00007oooool2o`0000Cooooo0_l00009oooo
ob?o0000=oooool2o`0000?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co
00001?ooool4o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0000Sooooo`?o
000000?oooooo`000?l000001_oooolLo`0000;ooooo1Ol0000gooooo`Co000000?oooooo`000?l0
00000_l0000hooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`000?l00000
0oooool4o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo1?l0000Qooooo`;o0000
0_ooool3o`0000Sooooo6_l000000ooooooo0000o`00000jooooo`Co00000oooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo05Cooooo0_l00004ooooo`;o00000oooool2o`0000Wooooo0_l0
0004ooooo`?o00003?ooool2o`0002Kooooo0_l00002ooooo`;o00001?oooolJo`0003gooooo0_l0
0007ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo0ol00000
0ooooooo0000o`000004o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0002[ooooo0_l00003
ooooo`;o00001_oooolEo`0000;ooooo0ol0000kooooo`;o00001oooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo05[ooooo2ol00006ooooo`;o00003Oooool2o`0002[ooooo0_l00008oooo
o`;o000000?oooooo`000?l000004ol00002ooooo`?o0000A?ooool2o`0003Kooooo000Looooo`;o
0000Foooool2o`0000;ooooo1_l00007ooooo`;o0000>Oooool3o`0000Oooooo0_l000000ooooooo
0000o`00000Fo`0001gooooo0_l0000Wooooo`;o000000?oooooo`000?l00000<oooool001cooooo
00?o0000ooooooooool0C?ooool4o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo
0_l0000aooooo`;o000000?oooooo`000?l000000ol00003ooooo`Co000000?oooooo`000?l00000
4_l000000ooooooo0000o`000002o`0001cooooo0_l0000Oooooo`;o00002Oooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo04cooooo1?l00004ooooo`;o00000_ooool4o`0000Wooooo1Ol0
0006ooooo`;o0000<Oooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`000003ooooool0
003o0000013o00001?ooool3o`0001?ooooo0_l000000ooooooo0000o`00000Uooooo`;o00000_oo
ool2o`0000Cooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001?ooool4
o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000005?ooool2o`0001Wooooo0_l00003
ooooo`?o00002_ooool2o`0000Oooooo4Ol00002ooooo`Co00005?ooool2o`000003ooooool0003o
000002Wooooo0_l00004ooooo`;o000000?oooooo`000?l00000<Oooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000;ooooo1?l0000Eooooo`;o000000?oooooo`000?l000004?ooool2o`00
01Wooooo0_l00003ooooo`?o00001Oooool2o`0000cooooo1Ol00002ooooo`Oo00001Oooool2o`00
01Cooooo0_l0000fooooo`Co0000<?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Co
oooo1?l0000Gooooo`Go00004_ooool2o`0000cooooo0_l0000Booooo`;o00000_ooool2o`0000co
oooo3Ol00006ooooo`;o00005?ooool2o`0000_ooooo0_l0000Kooooo`;o00003?ooool4o`00033o
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`Co00006oooool4o`0000?ooooo
0_l00003ooooo`;o00001oooool2o`0000cooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000;ooooo`Wo00000oooool2o`0001Sooooo0ol00007ooooo`;o0000
00?oooooo`000?l000006oooool3o`000003ooooool0003o000003cooooo000Looooo`03o`000?oo
oooooooo04_ooooo0ol0000Kooooo`Ko00000oooool2o`0000?ooooo0_l0000Hooooo`Co00003Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00002oooool8o`0000Cooooo0_l0000Hooooo`?o00000ooo
ool2o`0000;ooooo0_l0000Oooooo`;o000000?oooooo`000?l00000??ooool001cooooo00?o0000
ooooooooool0B?ooool5o`0000Oooooo1ol0000>ooooo`Oo00002oooool2o`0000[ooooo0_l0000:
ooooo`;o00003_ooool2o`0000Gooooo0_l0000:ooooo`So000000?oooooo`000?l000008_ooool2
o`0000;ooooo0_l00003ooooo`Co00006Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo
04Kooooo1_l00008ooooo`So00004?ooool4o`0000_ooooo0_l0000:ooooo`;o00006_ooool2o`00
00?ooooo1?l0000:ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00008_ooool4o`00
0003ooooool0003o000000;o00006Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Ko
oooo0_l00006ooooo`Ko000000?oooooo`000?l000001ol0000@ooooo`;o00000_ooool2o`0001[o
oooo0_l0000Booooo`?o00000oooool2o`0000kooooo0_l00002ooooo`Ko000000Coooooo`000?l0
003o00008Oooool4o`0000;ooooo0ol0000Jooooo`;o00002_ooool2o`00037ooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l00007oooooa;o00003_ooool2o`0000;ooooo0_l0000Iooooo`?o
00002_ooool2o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`Ko
00000_ooool2o`00027ooooo0ol00003ooooo`;o00006Oooool4o`0000[ooooo0ol0000`ooooo`00
7?ooool00ol0003oooooooooo`15ooooo`?o00002?oooolAo`000003ooooool0003o000000[ooooo
0ol0000Looooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`?o00000_ooool4o`0000cooooo
0_l0000Xooooo`?o00001?ooool2o`0001Sooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00005oooooaSo00002Ooo
ool3o`0002Gooooo0_l0000Aooooo`;o00001?ooool4o`0003Gooooo0_l00004ooooo`;o00006ooo
ool2o`0000Cooooo0_l00002ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000Oooooo6ol00007ooooo`;o00009_ooool2o`0000Wooooo0_l00006ooooo`;o00001_ooool2
o`0003Gooooo0_l00004ooooo`;o00008Oooool2o`0000;ooooo0_l0000booooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00000oooool2o`0000Oooooo6ol0000jooooo`;o00001_ooool2o`00
00Cooooo0_l0000mooooo`;o00008Oooool4o`0003Cooooo000Looooo`;o0000?oooool2o`0000;o
oooo1?l00007ooooo`;o000000?oooooo`000?l000005_l0000Zooooo`;o00000_ooool2o`000003
ooooool0003o000001Cooooo0_l0000mooooo`;o00007?ooool2o`000003ooooool0003o000000;o
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool4o`0000Oooooo
0_l000000ooooooo0000o`00000Go`0000Gooooo0_l0000Rooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0004[ooooo0_l00003ooooo`Co00007Oooool2o`000003ooooool0003o000003So
oooo000Looooo`03o`000?oooooooooo03gooooo0_l00003ooooo`?o00002_oooolJo`0000Gooooo
0_l0000Jooooo`;o00001_ooool2o`0000Kooooo0_l0000Aooooo`;o00001Oooool2o`0002[ooooo
1?l00002ooooo`;o00000oooool4o`0001_ooooo0_l000001?oooooo0000o`000?l0000iooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00002ooooolJo`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000004oooool2o`0000Kooooo0_l0000Iooooo`;o00001Oooool3o`0002Wooooo
1?l00006ooooo`;o00007_ooool2o`000003ooooool0003o000000?o0000=oooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000;ooooo0_l00008oooooaOo00002oooool2o`000003ooooool0
003o000001Gooooo0_l00007ooooo`;o00000oooool2o`0001Wooooo0_l0000Xooooo`?o00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000Pooooo`Co0000=_ooool001cooooo00?o0000
ooooooooool0?_ooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol0000T
ooooo`?o00001oooool2o`0000?ooooo0_l00010ooooo`[o00001?ooool2o`000003ooooool0003o
000001oooooo1Ol0000fooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00001Oooool2o`00
00Gooooo0_l00003oooooaGo00008_ooool4o`0000Cooooo0_l00007ooooo`;o0000?oooool4o`00
0003ooooool0003o000000Ko00000_ooool2o`0002;ooooo0ol000000ooooooo0000o`00000eoooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`0000[ooooo6?l00006ooooo`;o
00005oooool2o`0000Kooooo0_l00018ooooo`;o00002?ooool3o`0002[ooooo1_l0000aooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002oooooa7o000000?oooooo`000?l000000ol000000ooooooo0000
o`000003ooooo`?o00005Oooool4o`0002Oooooo0ol00003ooooo`;o0000:Oooool4o`0002cooooo
1?l0000aooooo`007?ooool00ol0003oooooooooo`0kooooo`Go00001_ooool3o`0000?ooooo0_l0
00000ooooooo0000o`000003oooooa?o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000001_ooool2o`0000[ooooo1?l0000Jooooo`;o00002oooool3o`0000?ooooo
0_l0000Yooooo`Go00007oooool2o`0000Sooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00000_ooool3o`0000;ooooo0ol0000;oooooaCo00001_ooool4o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l0000:ooooo`;o00000_oo
ool3o`0000;ooooo0_l00009ooooo`;o0000:?ooool7o`000003ooooool0003o000001[ooooo0_l0
0008ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0@?ooool4o`0000Wooooo0_l00002
ooooo`;o00000_oooolCo`0000Kooooo0ol0000>ooooo`;o00004Oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000002?ooool2o`0000Cooooo1?l000000ooooooo0000o`000005
ooooo`;o00000_ooool4o`0002Kooooo1ol000000ooooooo0000o`00000Kooooo`Co0000??ooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0000;ooooo4ol00009ooooo`;o00006Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000Wooooo2?l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2
o`0000Cooooo0_l0000Sooooo`Ko000000?oooooo`000?l000000ol0000Iooooo`;o000000?ooooo
o`000?l000000_l00007ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0?_ooool3o`00
00Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`Wo00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000Iooooo`;o00001oooool2
o`0000[ooooo0ol000000ooooooo0000o`000003o`0000Cooooo2?l00006ooooo`;o00004oooool2
o`0000kooooo1Ol00004ooooo`?o00006Oooool2o`0000Kooooo0_l00004ooooo`;o0000<oooool0
01cooooo00?o0000ooooooooool0??ooool5o`00017ooooo0_l00006ooooo`Ko000000?oooooo`00
0?l000000_l00002ooooo`?o00001?ooool2o`0001oooooo0_l00004ooooo`;o00002Oooool3o`00
00_ooooo2?l00006ooooo`Co00003?ooool2o`0000?ooooo0_l0000>ooooo`Oo000000Coooooo`00
0?l0003o00006_ooool4o`0000Cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00002_ooool2o`00013ooooo1?l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`00
01oooooo0_l00004ooooo`;o00002?ooool5o`0000[ooooo2Ol00007ooooo`;o00003?ooool2o`00
01?ooooo0ol00002ooooo`;o000000?oooooo`000?l000006oooool4o`0000Cooooo0_l0000ioooo
o`007?ooool2o`0004Kooooo1ol000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l0
00007Oooool2o`0000;ooooo1?l0000:ooooo`;o00003Oooool5o`0000Kooooo3Ol00007ooooo`?o
00008?ooool4o`0000?ooooo0ol0000Sooooo`?o0000>?ooool001cooooo00?o0000ooooooooool0
??ooool2o`0000Oooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co
00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00007ooooo`Co00001Oooool2o`00
0003ooooool0003o000000?o00001Oooool2o`0000;ooooo0ol0000<ooooo`Ko00000_ooool2o`00
0003ooooool0003o000000[o00002_ooool3o`0001oooooo1?l00003ooooo`;o00009Oooool2o`00
0003ooooool0003o000003Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Booooo`So
00002Oooool2o`0000Gooooo1_l00007ooooo`Co00002?ooool2o`0000Sooooo0_l00002ooooo`;o
00003Oooool5o`0000?ooooo3ol000000ooooooo0000o`000007ooooo`?o00007oooool3o`0000;o
oooo0_l0000Xooooo`Co0000=Oooool001cooooo00?o0000ooooooooool0D_ooool2o`0001Gooooo
1?l0000=ooooo`?o00001?ooool2o`0001?ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
5Ol00007ooooo`;o000000?oooooo`000?l000007Oooool3o`0000;ooooo0_l0000Looooo`;o0000
2_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo05Kooooo1?l000000ooooooo0000o`00
000<ooooo`?o00003_ooool3o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l0
0003ooooo`;o00002_oooolGo`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`Co0000
0_ooool2o`0000gooooo0_l00003ooooo`;o00007?ooool2o`0000cooooo0_l0000eooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00007Oooool9o`0000?ooooo0ol00004ooooo`Go00004_oo
ool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o000000?o
ooooo`000?l000004_l00008ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`Wo0000
3?ooool2o`0000?ooooo0_l0000Zooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0=ooo
ool2o`00023ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00001Oooool4o`0002gooooo
0_l00005ooooo`;o000000?oooooo`000?l000003ol0000;ooooo`;o00001_ooool2o`0000;ooooo
2_l0000:ooooo`;o000000Coooooo`000?l0003o00009Oooool2o`0000?ooooo0_l0000fooooo`00
7?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000Co00003?ooool2o`0001;ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool=o`000003ooooool0003o000000?o00006_ooool6o`000003ooooool0003o000000Oooooo
1_l0000Uooooo`;o00000oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0
00000ooooooo0000o`000004o`0000cooooo0_l0000?ooooo`;o000000?oooooo`000?l000000ol0
0009ooooo`;o00001?oooolEo`0000?ooooo0_l00002ooooo`;o00004_ooool6o`0000Gooooo0ol0
00001?oooooo0000o`000?l0000Uooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`00033ooooo0_l0000Qooooo`Co000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0
0004oooooaKo00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`Go00001Ooo
ool3o`000004ooooool0003o0000o`0002Gooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o0000>?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00001_oo
oolDo`0000Wooooo0_l00003ooooo`Co00002Oooool<o`0006Sooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000hooooo`;o000000?oooooo`000?l000001Oooool2o`000004ooooool0003o
0000o`0000Gooooo0_l00005ooooo`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0
0005oooooa?o00001Oooool2o`0000Wooooo1_l00007ooooo`_o00000_ooool2o`0002?ooooo0_l0
0005ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0004Kooooo0_l0000<
ooooo`Co00003Oooool2o`0000Cooooo2ol00002ooooo`Go000000?oooooo`000?l000000oooool2
o`0000Kooooo0_l00003ooooo`Go00001_ooool4o`000003ooooool0003o000000Co000000Cooooo
o`000?l0003o00008oooool2o`0000Cooooo0ol0000iooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o0000<?ooool9o`0000Gooooo0ol0000<ooooo`;o00002?ooool3o`0000Cooooo0_l00006
ooooo`Co00000_oooolEo`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo1?l00002
ooooo`Co000000?oooooo`000?l000000_l0000Yooooo`;o0000>_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo03Oooooo0_l0000]oooooa3o000000?oooooo`000?l000000ol00008ooooo`Co0000
2Oooool2o`0000Cooooo1?l00005ooooo`?o00000_oooolEo`0000;ooooo0_l00007ooooo`;o0000
1_ooool2o`0000Kooooo1Ol000000ooooooo0000o`000003ooooo`?o0000I_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo06Gooooo1?l00009ooooo`Co00001?ooool2o`0000?ooooo0_l00003oooo
o`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o00001?oooolCo`0000cooooo0_l000000ooo
oooo0000o`000002ooooo`Co00001?ooool6o`0000Cooooo0ol0001Wooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1Tooooo`Go00000oooool3o`0000Cooooo0_l0000:ooooo`Go00005Oooool:o`00
00?ooooo5Ol0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo2ol0000Soooo
o`;o00000_ooool2o`0003oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=oooool2o`0002[ooooo1?l00005oooo
o`?o00003Oooool2o`0000?ooooo1?l00009ooooo`;o00002oooool8o`0000?ooooo5Ol00002oooo
o`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool9o`0002Cooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o0000>oooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=oooool2
o`0002[ooooo1?l0000Eooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`?o00000oooool7
o`0000?ooooo4Ol00006ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool7
o`0002[ooooo0_l000001?oooooo0000o`000?l0000kooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0=oooool4
o`0002Sooooo1?l000000ooooooo0000o`00000Kooooo`;o00003oooool4o`0000?ooooo1_l00003
oooooa7o000000?oooooo`000?l000002_ooool2o`0000[ooooo0ol00007ooooo`;o00009oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000looooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0=oooool4o`0002Sooooo0ol0
0002ooooo`;o00005?ooool2o`0000Gooooo0ol0000>ooooo`Co00000oooool2o`0000;ooooo2?l0
00000ooooooo0000o`00000>o`0000;ooooo0_l00004ooooo`Go00002Oooool2o`0001gooooo0_l0
000>ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0003kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Soooo
o`?o00004Oooool3o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Oooooo0_l00009ooooo`So00000oooool7o`000003ooooool0003o000000?o00000oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00006_ooool3o`0000gooooo0_l000000ooo
oooo0000o`000005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=oooool2o`0002[o
oooo0ol00005ooooo`;o00002_ooool5o`0000Gooooo1_l00003ooooo`;o000000?oooooo`000?l0
00004oooool7o`000003ooooool0003o000000;ooooo1Ol000001?oooooo0000o`000?l00005oooo
o`;o00001oooool2o`000004ooooool0003o0000ooooo`?o00000oooool6o`0001Gooooo0_l00000
1?oooooo0000o`000?l0000<ooooo`?o00000oooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l0000Zooooo`;o00001_ooool2o`0000Oooooo0_l00003ooooo`?o00001?ooool9
o`0001Wooooo1ol000000ooooooo0000o`000005o`0000;ooooo1?l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo1_l0000Eooooo`Go00003Ooo
ool2o`0000Cooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`1Sooooo`?o00003_ooool2
o`0000Wooooo1ol000000ooooooo0000o`00000Mooooo`?o00000oooool2o`0000Gooooo0_l00007
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`000004ooooool0003o
0000ooooo`?o00004?ooool2o`0000?ooooo0_l0000Fooooo`?o0000@Oooool001cooooo00?o0000
ooooooooool0I?ooool2o`0000[ooooo0_l00005ooooo`?o000000?oooooo`000?l000003?l0000M
ooooo`?o00002oooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o
000000?o00001?ooool3o`0000;ooooo0ol0000;ooooo`;o00000oooool2o`00013ooooo0ol00003
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0003Cooooo0_l00005oooo
o`Wo00000oooool6o`0002?ooooo0_l000000ooooooo0000o`000003ooooo`;o00004_ooool2o`00
00;ooooo0_l0000;ooooo`Ko00001Oooool2o`0001Wooooo1Ol000000ooooooo0000o`000012oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o0000:Oooool3o`0000Sooooo1?l000000ooooooo
0000o`00000;o`0000;ooooo1Ol0000Sooooo`Go00000_ooool4o`0000Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000oooooo1_l00005ooooo`Co00000oooool5o`0000co
oooo0_l00003ooooo`?o000000?oooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0
IOooool3o`0000Sooooo6Ol0000Uooooo`Wo00001Oooool4o`000004ooooool0003o0000ooooo`;o
00003Oooool4o`0000oooooo0_l00003ooooo`Go00002Oooool5o`0000?ooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`1Uooooo`;o00002?ooool2o`000003ooooool0003o000001Co0000
:Oooool3o`0000?ooooo0_l00003ooooo`Co00002Oooool2o`0000Kooooo1_l0000Cooooo`Co0000
2oooool4o`0000Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00001ooo
oolIo`0002[ooooo0ol00002ooooo`Co00003?ooool6o`0000Cooooo1?l0000=ooooo`?o000000Co
ooooo`000?l0003ooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`1Uooooo`Co00001ooo
oolHo`0002[ooooo0ol00003ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00001?ooool4o`0000gooooo0ol000000ooooooo0000o`000005o`0005cooooo
000Looooo`03o`000?oooooooooo06Cooooo1Ol00002ooooo`?o00000_oooolGo`0002cooooo0_l0
0005ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00003?ooool3o`0000kooooo1_l0
000;ooooo`;o00000_ooool2o`0004cooooo000Looooo`;o0000?_ooool4o`0002?ooooo0ol00000
0ooooooo0000o`000004o`000003ooooool0003o0000013o000000?oooooo`000?l000001?l0000a
ooooo`?o00000_ooool3o`0000Kooooo0_l00005ooooo`;o00001Oooool5o`0000Gooooo0_l00005
ooooo`Co00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0
003oooooooooo`0mooooo`Co00008oooool3o`000003ooooool0003o000000;o00000_oooolJo`00
033ooooo0ol00004ooooo`Co00000_ooool2o`0000Oooooo1?l00006ooooo`;o00001Oooool2o`00
00Cooooo1Ol00009ooooo`;o00000_ooool4o`0000?ooooo0_l00019ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`Co00008oooool2o`0000Kooooo7?l0000`ooooo`;o00001oooool6o`0000?o
oooo0ol000000ooooooo0000o`000002o`0001;ooooo1?l0000;ooooo`;o00001?ooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000[oooooa_o0000<Oooool2o`000003oooo
ool0003o000000So00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1Ol00005ooooo`;o
00001_ooool2o`000003ooooool0003o0000013ooooo1?l000000ooooooo0000o`00001<ooooo`00
7?ooool00ol0003oooooooooo`1Sooooo`?o00002?oooolIo`00037ooooo3?l00003ooooo`;o0000
0_ooool2o`0000?ooooo1Ol00004ooooo`;o00000oooool9o`0000oooooo1?l000000ooooooo0000
o`00001<ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00007_ooool3o`0000Cooooo0ol0
00000ooooooo0000o`00000Go`00033ooooo3ol00005ooooo`;o00001Oooool7o`000003ooooool0
003o000000;ooooo1_l000000ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`13
ooooo`?o00007Oooool3o`0000?ooooo1?l000000ooooooo0000o`00000Go`0002gooooo0_l00000
0ooooooo0000o`00000>o`0000_ooooo2_l000000ooooooo0000o`000005o`00013ooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00007Oooool5o`000004ooooool0003o0000
oooooa[o0000;_oooolCo`0000Cooooo0_l00008ooooo`co000000?oooooo`000?l000003?ooool2
o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o000000?oooooo`00
0?l000000_oooolKo`00033ooooo4_l00004ooooo`;o00002?ooool<o`0000oooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0Aoooool2o`00
01[ooooo0_l00005oooooa_o0000;ooooolDo`0000;ooooo0_l0000;ooooo`So00004Oooool6o`00
00;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00008OoooolFo`0000;o
oooo0_l0000`ooooo`Go000000?oooooo`000?l000003?l00002ooooo`;o00002oooool7o`0000ko
oooo0_l00002ooooo`Co00000oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l0000Looooo`;o00001?ooool2o`000003ooooool0003o000001Ko0000<ooooolAo`0000oooooo
0_l000000ooooooo0000o`000002o`0000kooooo0_l00009ooooo`;o0000D?ooool001cooooo00?o
0000ooooooooool0A?ooool2o`0000;ooooo0_l0000Iooooo`;o00001?ooool=o`000003ooooool0
003o000000[o0000<_oooolCo`0001;ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o000000?oooooo`000?l000000_l0000Hooooo`;o00001Oooool2o`0000;ooooo2ol00000
0ooooooo0000o`000007o`0003;ooooo4ol00003ooooo`;o0000O?ooool001cooooo00?o0000oooo
ooooool0Aoooool4o`0001Sooooo0_l00008ooooo`co000000?oooooo`000?l000001?l0000foooo
o`Co000000?oooooo`000?l000002ol00003ooooo`Co0000N_ooool001cooooo00?o0000oooooooo
ool0Hoooool2o`0000Gooooo4ol0000ioooooa;o00001Oooool2o`0001Sooooo0_l0001Pooooo`00
7?ooool2o`0006Cooooo0ol00004ooooo`Go00000_ooool?o`0003Kooooo0_l000000ooooooo0000
o`00000=o`0000Cooooo0_l0000Gooooo`Oo0000GOooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0001Kooooo1?l00003ooooo`Go000000?oooooo`000?l000001ol00002ooooo`Co0000>?oo
ool?o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o0000Eooo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0001Kooooo1?l00003ooooo`;o000000?ooooo
o`000?l000002_l00003ooooo`;o00001oooool2o`0002gooooo0_l000000ooooooo0000o`000005
o`000003ooooool0003o000000Oo00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006
ooooo`;o00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00009oooo
oa3o00001oooool2o`0002gooooo0_l000000ooooooo0000o`00000;o`000004ooooool0003o0000
o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo1?l0001I
ooooo`007?ooool00ol0003oooooooooo`1cooooo`[o0000>oooool@o`0000Gooooo0_l0000:oooo
o`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co0000FOooool001co
oooo00?o0000ooooooooool0IOooool3o`0000gooooo0_l000000ooooooo0000o`000002o`0003co
oooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000;o00005_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`Ko0000FOooool001cooooo00?o0000ooooooooool0
IOooool3o`0000Gooooo0_l00019ooooo`?o000000?oooooo`000?l000002_l0000Rooooo`Co0000
Foooool001cooooo00?o0000ooooooooool0IOooool2o`0000Kooooo0ol00018ooooo`go000000?o
ooooo`000?l000002_ooool2o`0000?ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o000000?oooooo`000?l000000oooool3o`0004[ooooo0ol000000ooooooo0000o`000008
o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo
06Sooooo0_l0000Eooooo`;o0000>_ooool>o`0000[ooooo0_l00007ooooo`;o00001oooool3o`00
067ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000Fooooo`;o0000>_ooool>o`0000[o
oooo0ol00009ooooo`;o00001?ooool3o`00067ooooo000Looooo`03o`000?oooooooooo06Oooooo
1?l00008ooooo`;o0000Boooool2o`0000?ooooo1?l0000;ooooo`;o00002Oooool2o`0006Sooooo
000Looooo`03o`000?oooooooooo06Oooooo1?l00008ooooo`;o00000_ooool2o`0004Gooooo1?l0
000<ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Ioooool4o`0000cooooo0_l00015
ooooo`;o00003_ooool2o`000003ooooool0003o000000cooooo0_l0001Xooooo`007?ooool00ol0
003oooooooooo`1Xooooo`?o0000E?ooool2o`000003ooooool0003o000000;ooooo0_l00009oooo
o`;o00002?ooool2o`0000;ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o
00000oooool2o`00053ooooo0_l000000ooooooo0000o`000002ooooo`;o00004_ooool3o`0006co
oooo000Looooo`;o0000Joooool2o`000003ooooool0003o000005?ooooo0_l00007ooooo`;o0000
1_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0001/ooooo`007?ooool00ol0003ooooo
ooooo`1Zooooo`?o0000G_ooool2o`000004ooooool0003o0000o`0000;ooooo1_l0001`ooooo`00
7?ooool00ol0003oooooooooo`1[ooooo`?o0000H?ooool3o`0000Cooooo0_l0001booooo`007?oo
ool00ol0003oooooooooo`1[ooooo`Co0000f_ooool001cooooo00?o0000ooooooooool0Joooool4
o`000=[ooooo000Looooo`03o`000?oooooooooo06gooooo0ol000000ooooooo0000o`00003Foooo
o`007?ooool00ol0003oooooooooo`1]ooooo`?o000000?oooooo`000?l00000e_ooool001cooooo
00?o0000ooooooooool0KOooool2o`000=[ooooo000Looooo`03o`000?oooooooooo073ooooo1?l0
003Eooooo`007?ooool00ol0003oooooooooo`1`ooooo`Co00000_ooool2o`0004_ooooo0_l00024
ooooo`007?ooool00ol0003oooooooooo`1fooooo`Co0000BOooool4o`0000?ooooo0_l0001moooo
o`007?ooool00ol0003oooooooooo`1cooooo`;o00000oooool6o`0004Oooooo0_l00003ooooo`;o
00004?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo07?ooooo0ol00003ooooo`Go0000
D?ooool2o`0000Kooooo0ol00003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0M?oo
ool2o`0000?ooooo0_l0001>ooooo`;o00000oooool2o`0000Kooooo0ol00002ooooo`;o0000K?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo0;gooooo0_l0000:ooooo`;o00004?ooool2o`0006co
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`1iooooo`;o0000;oooool2o`0000Cooooo0_l0000;
ooooo`;o00002?ooool2o`0000Wooooo1?l0001cooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1i
ooooo`;o00001_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00006?oo
ool2o`0000Cooooo1?l00008ooooo`;o00002Oooool2o`0000Kooooo1ol0001cooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`0007cooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo
1?l0000Nooooo`Co00002?ooool2o`0000Wooooo0_l00006ooooo`Co0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0O?ooool2o`0000Oooooo0_l00008ooooo`;o00001oooool3o`0000?ooooo
0_l0000Looooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o000000Coooooo`000?l0003o
0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool0Toooool2o`0000?ooooo0ol00002ooooo`Co
00003?ooool2o`00013ooooo1?l00005ooooo`Co000000?oooooo`000?l00000N_ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0P?ooool3o`0000Oooooo0_l00007ooooo`;o00001oooool5o`0000Cooooo0_l00006
ooooo`;o00004_ooool2o`000003ooooool0003o000000Ko0000OOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
P?ooool3o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0ol00002ooooo`;o0000
0oooool2o`0001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00021ooooo`007?oo
ool00ol0003oooooooooo`23ooooo`Go00001_ooool2o`0000?ooooo0_l00006ooooo`;o00000ooo
ool2o`0000Oooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l0002>ooooo`007?oo
ool00ol0003oooooooooo`23ooooo`Ko000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000
0_ooool3o`0000Sooooo0_l00005ooooo`?o00001Oooool4o`000004ooooool0003o0000o`0000[o
oooo0ol00023ooooo`007?ooool00ol0003oooooooooo`25ooooo`Co000000?oooooo`000?l00000
0ol00004ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`000003oooo
ool0003o000000Gooooo0ol00002ooooo`?o00002_ooool3o`0008?ooooo000Looooo`03o`000?oo
oooooooo08cooooo0_l0000;ooooo`;o00000_ooool2o`0000Sooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000_l0002Aooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00002oooool2
o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0009;ooooo
000Looooo`03o`000?oooooooooo09?ooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l0
0008ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0V_ooool3o`0000;ooooo1_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0ol00027
ooooo`007?ooool00ol0003oooooooooo`2Oooooo`Go00000_ooool2o`0000;ooooo1Ol00006oooo
o`;o00001?ooool7o`0008Oooooo000Looooo`03o`000?oooooooooo0:7ooooo1?l00005ooooo`Go
00001Oooool2o`0000Gooooo1?l0002:ooooo`007?ooool00ol0003oooooooooo`2Rooooo`Go0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
Roooool001cooooo00?o0000ooooooooool0YOooool2o`000003ooooool0003o000000?ooooo1_l0
002Fooooo`007?ooool2o`000:kooooo1?l0002Hooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo
00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo08kooooo002Voooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2?ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04odA4A?oMgMgoooooo`00097ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?oMgMgoEEEEoooo
ool0002Aooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01[ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;ooooo00?oMgMgolc<c?l00000
TOooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01?ooool00oo^k^koA4A4o`00002Aooooo`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(540) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64419 .53401 Mdot
.68699 .54086 Mdot
.38647 .34544 Mdot
.49913 .62149 Mdot
.32432 .51903 Mdot
.36456 .37109 Mdot
.53461 .29896 Mdot
.53385 .33476 Mdot
.37591 .36802 Mdot
.55783 .73986 Mdot
.55819 .31344 Mdot
.46818 .69929 Mdot
.54276 .31042 Mdot
.46194 .64027 Mdot
.59337 .44401 Mdot
.39533 .60116 Mdot
.68983 .58567 Mdot
.27711 .54231 Mdot
.39483 .59996 Mdot
.37693 .34508 Mdot
.37053 .59819 Mdot
.46285 .62744 Mdot
.70186 .57622 Mdot
.46127 .63643 Mdot
.50547 .65422 Mdot
.67995 .54693 Mdot
.65033 .52999 Mdot
.52186 .63365 Mdot
.51548 .60274 Mdot
.5491 .32302 Mdot
.25323 .34542 Mdot
.82459 .60517 Mdot
.5254 .66187 Mdot
.72316 .66665 Mdot
.53446 .33702 Mdot
.52846 .21072 Mdot
.38788 .38722 Mdot
.52265 .32532 Mdot
.55136 .33815 Mdot
.54697 .34216 Mdot
.5286 .29827 Mdot
.66987 .54432 Mdot
.57243 .32117 Mdot
.41976 .33991 Mdot
.46617 .66547 Mdot
.77576 .52857 Mdot
.27465 .28687 Mdot
.52112 .62015 Mdot
.63801 .56001 Mdot
.35804 .34685 Mdot
.27521 .69019 Mdot
.52085 .29026 Mdot
.6634 .45409 Mdot
.3236 .84098 Mdot
.55242 .3131 Mdot
.50591 .61308 Mdot
.35959 .35624 Mdot
.4845 .62403 Mdot
.48216 .6018 Mdot
.71955 .64732 Mdot
.45503 .61371 Mdot
.29405 .50616 Mdot
.6841 .52197 Mdot
.39119 .41134 Mdot
.37086 .36517 Mdot
.5216 .30569 Mdot
.70559 .54498 Mdot
.53297 .31577 Mdot
.51132 .58506 Mdot
.36537 .34095 Mdot
.51631 .61329 Mdot
.55441 .32082 Mdot
.70263 .5482 Mdot
.47137 .67046 Mdot
.74288 .46406 Mdot
.53707 .37146 Mdot
.34161 .44822 Mdot
.67403 .75165 Mdot
.31659 .76417 Mdot
.30761 .35084 Mdot
.45224 .65019 Mdot
.23426 .71063 Mdot
.58493 .41174 Mdot
.68243 .53454 Mdot
.73234 .53831 Mdot
.75644 .33312 Mdot
.52453 .61564 Mdot
.3786 .49095 Mdot
.48639 .68696 Mdot
.50538 .50028 Mdot
.38137 .36707 Mdot
.69489 .55591 Mdot
.46387 .66634 Mdot
.48042 .6828 Mdot
.5808 .65653 Mdot
.49629 .5874 Mdot
.48714 .6459 Mdot
.69732 .51377 Mdot
.56049 .29433 Mdot
.53203 .6907 Mdot
.23486 .48866 Mdot
.65475 .44697 Mdot
.50132 .63403 Mdot
.36349 .39677 Mdot
.66487 .51678 Mdot
.48296 .65596 Mdot
.5298 .32222 Mdot
.45256 .63641 Mdot
.5407 .26061 Mdot
.68012 .58423 Mdot
.48226 .6846 Mdot
.31202 .47471 Mdot
.56555 .51201 Mdot
.65675 .57215 Mdot
.55971 .799 Mdot
.45495 .61637 Mdot
.46787 .61282 Mdot
.67684 .53515 Mdot
.39264 .36122 Mdot
.41841 .45473 Mdot
.70484 .56909 Mdot
.5526 .33949 Mdot
.64963 .57903 Mdot
.44775 .68286 Mdot
.39108 .35844 Mdot
.64916 .45429 Mdot
.65821 .44918 Mdot
.25351 .55407 Mdot
.47023 .67265 Mdot
.59316 .52971 Mdot
.35888 .38567 Mdot
.67225 .53988 Mdot
.53781 .31949 Mdot
.46979 .59663 Mdot
.65466 .55914 Mdot
.56057 .3307 Mdot
.28386 .52019 Mdot
.32417 .522 Mdot
.64565 .55032 Mdot
.44267 .75253 Mdot
.52492 .27856 Mdot
.54958 .34394 Mdot
.27582 .68423 Mdot
.67583 .5319 Mdot
.30843 .51661 Mdot
.57067 .31132 Mdot
.32462 .62897 Mdot
.44639 .60746 Mdot
.25005 .59913 Mdot
.17733 .62863 Mdot
.27519 .68754 Mdot
.77954 .64018 Mdot
.32009 .48134 Mdot
.5715 .31192 Mdot
.51416 .62631 Mdot
.66438 .55824 Mdot
.65851 .5507 Mdot
.47459 .68026 Mdot
.49614 .66863 Mdot
.46673 .65546 Mdot
.46343 .60023 Mdot
.45984 .18648 Mdot
.45662 .65794 Mdot
.61989 .32155 Mdot
.65883 .5653 Mdot
.49217 .66509 Mdot
.36356 .40539 Mdot
.41569 .62693 Mdot
.52474 .32699 Mdot
.48794 .60371 Mdot
.50287 .66272 Mdot
.42704 .61307 Mdot
.57134 .31948 Mdot
.74656 .42769 Mdot
.39001 .8074 Mdot
.54991 .2206 Mdot
.67899 .43548 Mdot
.35107 .37667 Mdot
.43858 .63549 Mdot
.31642 .49223 Mdot
.48136 .70674 Mdot
.47121 .60508 Mdot
.2745 .6967 Mdot
.50559 .66766 Mdot
.74157 .68968 Mdot
.54764 .66968 Mdot
.74373 .30856 Mdot
.63419 .29659 Mdot
.46418 .60389 Mdot
.52115 .75584 Mdot
.24716 .57864 Mdot
.21908 .37305 Mdot
.54339 .32268 Mdot
.36156 .41048 Mdot
.3946 .3707 Mdot
.53997 .3471 Mdot
.54696 .6017 Mdot
.56263 .74674 Mdot
.49382 .58242 Mdot
.64814 .4526 Mdot
.7132 .59527 Mdot
.32273 .49201 Mdot
.64489 .54985 Mdot
.25628 .73887 Mdot
.38304 .51706 Mdot
.3229 .34749 Mdot
.28299 .54287 Mdot
.34012 .36068 Mdot
.63065 .44364 Mdot
.31497 .50769 Mdot
.49104 .63318 Mdot
.6585 .57996 Mdot
.24367 .57944 Mdot
.40542 .60088 Mdot
.5872 .144 Mdot
.68879 .53302 Mdot
.53338 .46933 Mdot
.54726 .31644 Mdot
.39162 .40682 Mdot
.52445 .61659 Mdot
.476 .63762 Mdot
.67266 .52039 Mdot
.51938 .61268 Mdot
.42331 .48379 Mdot
.50639 .66208 Mdot
.36776 .42334 Mdot
.27314 .49404 Mdot
.54004 .25645 Mdot
.2959 .55328 Mdot
.70505 .55689 Mdot
.5759 .37207 Mdot
.36365 .40084 Mdot
.54944 .55473 Mdot
.54165 .32972 Mdot
.28273 .51178 Mdot
.38044 .39414 Mdot
.30334 .47393 Mdot
.44576 .66583 Mdot
.38886 .37855 Mdot
.29468 .51767 Mdot
.48168 .37098 Mdot
.48798 .64638 Mdot
.27851 .61597 Mdot
.56395 .28482 Mdot
.64647 .53554 Mdot
.46014 .60814 Mdot
.64736 .45868 Mdot
.42225 .65364 Mdot
.58533 .50766 Mdot
.62443 .44213 Mdot
.6364 .4243 Mdot
.31553 .37043 Mdot
.30271 .52892 Mdot
.72468 .48024 Mdot
.45409 .43291 Mdot
.69227 .58523 Mdot
.4383 .65642 Mdot
.78765 .42594 Mdot
.56468 .28443 Mdot
.49103 .62936 Mdot
.73761 .31875 Mdot
.57124 .30962 Mdot
.48113 .61786 Mdot
.53232 .29189 Mdot
.6592 .55488 Mdot
.52596 .39559 Mdot
.63693 .57163 Mdot
.49724 .61865 Mdot
.54947 .28721 Mdot
.36776 .40881 Mdot
.67957 .54757 Mdot
.45468 .62964 Mdot
.45017 .65234 Mdot
.64345 .45003 Mdot
.48312 .67144 Mdot
.79906 .41091 Mdot
.52109 .62281 Mdot
.34274 .35402 Mdot
.5063 .58863 Mdot
.22875 .58332 Mdot
.32202 .52789 Mdot
.71596 .5603 Mdot
.62318 .43779 Mdot
.3823 .36279 Mdot
.50401 .38132 Mdot
.26308 .55306 Mdot
.45404 .64487 Mdot
.644 .43503 Mdot
.53343 .46358 Mdot
.52227 .31552 Mdot
.53181 .61787 Mdot
.4204 .46851 Mdot
.38162 .37794 Mdot
.63945 .45052 Mdot
.46956 .56481 Mdot
.63666 .53885 Mdot
.5086 .61559 Mdot
.38383 .39379 Mdot
.63538 .55019 Mdot
.48632 .5935 Mdot
.35879 .23516 Mdot
.65281 .45914 Mdot
.54951 .28132 Mdot
.59139 .59527 Mdot
.44592 .65573 Mdot
.39555 .37854 Mdot
.65322 .55417 Mdot
.55389 .29939 Mdot
.67942 .58047 Mdot
.23656 .56096 Mdot
.60513 .53205 Mdot
.45979 .2159 Mdot
.27278 .53787 Mdot
.73041 .74789 Mdot
.54391 .21879 Mdot
.58829 .556 Mdot
.36648 .44473 Mdot
.66965 .22595 Mdot
.37403 .39664 Mdot
.47387 .76189 Mdot
.37483 .35658 Mdot
.50735 .62814 Mdot
.36718 .36939 Mdot
.80747 .39466 Mdot
.51622 .65248 Mdot
.34946 .36791 Mdot
.43608 .2143 Mdot
.50502 .67014 Mdot
.6552 .56495 Mdot
.81095 .55165 Mdot
.5853 .80146 Mdot
.40483 .7289 Mdot
.34963 .36212 Mdot
.46781 .77063 Mdot
.52405 .62724 Mdot
.40337 .59125 Mdot
.67033 .55676 Mdot
.44153 .68346 Mdot
.32639 .48163 Mdot
.31344 .47094 Mdot
.30604 .69428 Mdot
.61544 .80493 Mdot
.50247 .55009 Mdot
.6719 .54786 Mdot
.29997 .75185 Mdot
.74793 .46615 Mdot
.65793 .45841 Mdot
.54534 .33818 Mdot
.73811 .42515 Mdot
.46702 .56227 Mdot
.54559 .69198 Mdot
.45817 .46588 Mdot
.69674 .55607 Mdot
.47617 .26322 Mdot
.54975 .29577 Mdot
.47351 .7876 Mdot
.59895 .7172 Mdot
.46947 .65598 Mdot
.54188 .27463 Mdot
.53132 .68187 Mdot
.44448 .47108 Mdot
.26745 .61087 Mdot
.34821 .2793 Mdot
.49458 .63071 Mdot
.73519 .48255 Mdot
.47349 .60631 Mdot
.25553 .5832 Mdot
.49381 .62212 Mdot
.67517 .57904 Mdot
.51563 .56364 Mdot
.46019 .41109 Mdot
.47729 .80766 Mdot
.38611 .51267 Mdot
.31194 .52094 Mdot
.46485 .64003 Mdot
.4765 .64631 Mdot
.29127 .51058 Mdot
.69278 .56147 Mdot
.4327 .64365 Mdot
.28264 .27585 Mdot
.45724 .65993 Mdot
.51887 .29701 Mdot
.50826 .40713 Mdot
.73629 .70724 Mdot
.51264 .66416 Mdot
.64094 .53275 Mdot
.52419 .31293 Mdot
.554 .33027 Mdot
.50147 .55291 Mdot
.55844 .28006 Mdot
.51598 .62177 Mdot
.51069 .40782 Mdot
.69818 .57933 Mdot
.50302 .7014 Mdot
.69142 .56567 Mdot
.26701 .70939 Mdot
.57257 .29843 Mdot
.64036 .42985 Mdot
.45063 .76767 Mdot
.53919 .2991 Mdot
.41505 .53459 Mdot
.52825 .57782 Mdot
.43298 .58321 Mdot
.59908 .5676 Mdot
.3752 .4081 Mdot
.63255 .43107 Mdot
.55442 .30888 Mdot
.45845 .65904 Mdot
.49013 .65091 Mdot
.53418 .27595 Mdot
.67136 .64 Mdot
.25653 .34216 Mdot
.49644 .61464 Mdot
.68421 .57777 Mdot
.67192 .54109 Mdot
.43992 .60715 Mdot
.46684 .60716 Mdot
.34028 .38751 Mdot
.6434 .43388 Mdot
.62663 .43136 Mdot
.65457 .43756 Mdot
.35062 .42015 Mdot
.69477 .77749 Mdot
.54994 .34393 Mdot
.79139 .64204 Mdot
.74464 .3682 Mdot
.46582 .55027 Mdot
.39007 .38995 Mdot
.47574 .62732 Mdot
.49937 .64193 Mdot
.55364 .28798 Mdot
.5873 .8242 Mdot
.53012 .6603 Mdot
.65455 .52987 Mdot
.5234 .2874 Mdot
.48064 .70075 Mdot
.56214 .35684 Mdot
.29561 .48589 Mdot
.37099 .62323 Mdot
.54519 .27217 Mdot
.67596 .58262 Mdot
.54246 .2723 Mdot
.47355 .6499 Mdot
.45386 .57051 Mdot
.69757 .55405 Mdot
.28452 .53258 Mdot
.45222 .66694 Mdot
.48109 .61587 Mdot
.17587 .46693 Mdot
.74243 .46687 Mdot
.30283 .43526 Mdot
.50725 .64279 Mdot
.43859 .58555 Mdot
.27745 .52578 Mdot
.4397 .65158 Mdot
.5119 .59939 Mdot
.56335 .50757 Mdot
.53023 .26306 Mdot
.31948 .52036 Mdot
.46318 .79756 Mdot
.68322 .52975 Mdot
.79063 .39267 Mdot
.65483 .45145 Mdot
.55722 .25282 Mdot
.53156 .39434 Mdot
.63299 .43787 Mdot
.72692 .32158 Mdot
.55911 .2208 Mdot
.63801 .43268 Mdot
.39991 .39807 Mdot
.45865 .71953 Mdot
.51233 .59664 Mdot
.48624 .60696 Mdot
.30082 .52865 Mdot
.66075 .53364 Mdot
.62454 .32085 Mdot
.51472 .27824 Mdot
.46419 .62111 Mdot
.63073 .57212 Mdot
.74998 .32028 Mdot
.63502 .44633 Mdot
.31533 .48367 Mdot
.29394 .5361 Mdot
.47253 .60822 Mdot
.50373 .52242 Mdot
.67427 .54632 Mdot
.45479 .62961 Mdot
.44392 .61606 Mdot
.37422 .35179 Mdot
.65222 .57694 Mdot
.35858 .40284 Mdot
.62053 .43597 Mdot
.62561 .18758 Mdot
.17564 .42041 Mdot
.56771 .29594 Mdot
.50108 .24965 Mdot
.57205 .27581 Mdot
.36899 .26497 Mdot
.64201 .43246 Mdot
.45834 .62788 Mdot
.70886 .56179 Mdot
.45272 .63374 Mdot
.45972 .6629 Mdot
.47476 .65827 Mdot
.49992 .54906 Mdot
.26538 .69219 Mdot
.30553 .48969 Mdot
.52282 .59028 Mdot
.3366 .38156 Mdot
.74065 .31 Mdot
.80713 .50543 Mdot
.46949 .64247 Mdot
.46982 .61331 Mdot
.69602 .534 Mdot
.44527 .66668 Mdot
.52932 .32456 Mdot
.68303 .53226 Mdot
.49755 .63782 Mdot
.22549 .50966 Mdot
.43196 .63392 Mdot
.51066 .23636 Mdot
.54513 .27102 Mdot
.38866 .65987 Mdot
.45985 .57399 Mdot
.64053 .43114 Mdot
.63295 .43152 Mdot
.64104 .45819 Mdot
.52681 .28656 Mdot
.37698 .35309 Mdot
.39656 .33924 Mdot
.48475 .56664 Mdot
.51582 .62822 Mdot
.4474 .57472 Mdot
.3316 .40094 Mdot
.45055 .42747 Mdot
.74525 .5196 Mdot
.55029 .66393 Mdot
.34443 .41123 Mdot
.65042 .50717 Mdot
.50719 .8095 Mdot
.66995 .52874 Mdot
.3563 .44402 Mdot
.53797 .33253 Mdot
.31907 .47672 Mdot
.31343 .73358 Mdot
.70113 .57418 Mdot
.66818 .52131 Mdot
.34931 .37328 Mdot
.55401 .43863 Mdot
.41837 .90088 Mdot
.36338 .39204 Mdot
.33706 .45241 Mdot
.6723 .55375 Mdot
.52372 .66809 Mdot
.5351 .45979 Mdot
.55759 .46292 Mdot
.35653 .36347 Mdot
.4497 .65039 Mdot
.42483 .52494 Mdot
.34028 .3866 Mdot
.53382 .61753 Mdot
.34762 .36389 Mdot
.55004 .27814 Mdot
.35532 .38704 Mdot
.66351 .59354 Mdot
.46342 .6688 Mdot
.35179 .86119 Mdot
.58223 .40644 Mdot
.45065 .62478 Mdot
.52676 .2813 Mdot
.41143 .20774 Mdot
.47968 .64766 Mdot
.32547 .49277 Mdot
.33914 .40681 Mdot
.34185 .27071 Mdot
.5104 .60104 Mdot
.361 .36662 Mdot
.69431 .59254 Mdot
.36126 .4415 Mdot
.28608 .43805 Mdot
.62905 .431 Mdot
.65941 .55781 Mdot
.64289 .41901 Mdot
.53214 .33709 Mdot
.42457 .63621 Mdot
.43722 .62478 Mdot
.66578 .57241 Mdot
.49144 .36943 Mdot
.54139 .61763 Mdot
.45266 .65026 Mdot
.34293 .3909 Mdot
.33284 .38098 Mdot
.61176 .45822 Mdot
.36989 .40159 Mdot
.43951 .58572 Mdot
.66553 .57406 Mdot
.50602 .62217 Mdot
.65016 .55806 Mdot
.44098 .6595 Mdot
.67767 .47315 Mdot
.6652 .5299 Mdot
.55892 .5502 Mdot
.4775 .67569 Mdot
.65291 .61288 Mdot
.45028 .66115 Mdot
.49021 .63941 Mdot
.33588 .40491 Mdot
.30681 .5015 Mdot
.5258 .65251 Mdot
.57256 .3692 Mdot
.27687 .51048 Mdot
.75947 .62487 Mdot
.3916 .36061 Mdot
.28484 .52778 Mdot
.30497 .654 Mdot
.62334 .43793 Mdot
.29595 .49965 Mdot
.61959 .45048 Mdot
.56531 .29074 Mdot
.66792 .58729 Mdot
.49659 .67541 Mdot
.67081 .2202 Mdot
.25329 .3462 Mdot
.64361 .4473 Mdot
.46031 .60928 Mdot
.47897 .62913 Mdot
.6338 .54732 Mdot
.24839 .72689 Mdot
.3754 .42374 Mdot
.49638 .63229 Mdot
.70394 .56546 Mdot
.2095 .6763 Mdot
.3451 .3711 Mdot
.29991 .48984 Mdot
.56217 .27203 Mdot
.67057 .60448 Mdot
.63283 .42824 Mdot
.57281 .29895 Mdot
.33564 .43492 Mdot
.27536 .70455 Mdot
.5089 .60089 Mdot
.37917 .40308 Mdot
.27498 .68815 Mdot
.54431 .67399 Mdot
.56975 .33531 Mdot
.67049 .47634 Mdot
.69464 .55341 Mdot
.53091 .27837 Mdot
.31012 .52471 Mdot
.68571 .58553 Mdot
.69383 .56264 Mdot
.53743 .33551 Mdot
.63092 .26133 Mdot
.53709 .46687 Mdot
.51903 .31805 Mdot
.56063 .48822 Mdot
.27508 .6808 Mdot
.64744 .43407 Mdot
.31635 .48365 Mdot
.21571 .53875 Mdot
.67338 .54454 Mdot
.73941 .42534 Mdot
.27515 .69446 Mdot
.48753 .64533 Mdot
.29957 .52144 Mdot
.7534 .34038 Mdot
.54621 .25086 Mdot
.56277 .32732 Mdot
.3942 .4676 Mdot
.32112 .50445 Mdot
.43867 .61515 Mdot
.72159 .72562 Mdot
.48916 .67948 Mdot
.57172 .30326 Mdot
.44727 .47586 Mdot
.65229 .57612 Mdot
.52961 .33677 Mdot
.41692 .48533 Mdot
.50099 .6412 Mdot
.44814 .6198 Mdot
.29752 .56364 Mdot
.64746 .57506 Mdot
.63523 .42644 Mdot
.44954 .64221 Mdot
.48536 .62134 Mdot
.42573 .6269 Mdot
.43098 .76664 Mdot
.55002 .53165 Mdot
.49522 .63751 Mdot
.38496 .41057 Mdot
.4229 .59417 Mdot
.46894 .60029 Mdot
.63051 .55272 Mdot
.2263 .59563 Mdot
.62023 .43613 Mdot
.48781 .60882 Mdot
.4959 .61411 Mdot
.54547 .34039 Mdot
.53553 .46495 Mdot
.55934 .46535 Mdot
.34449 .35519 Mdot
.36678 .47159 Mdot
.48418 .58005 Mdot
.66229 .5639 Mdot
.32669 .47877 Mdot
.42741 .60443 Mdot
.66916 .52714 Mdot
.51365 .57858 Mdot
.33764 .37541 Mdot
.64196 .43597 Mdot
.56623 .62015 Mdot
.29719 .50519 Mdot
.52796 .27185 Mdot
.80199 .61906 Mdot
.35786 .40808 Mdot
.51401 .64275 Mdot
.3826 .32656 Mdot
.37266 .3853 Mdot
.64649 .44945 Mdot
.4118 .59177 Mdot
.66161 .55136 Mdot
.66138 .57903 Mdot
.25977 .65422 Mdot
.35835 .42261 Mdot
.16305 .53504 Mdot
.5522 .27817 Mdot
.5298 .61573 Mdot
.78826 .48551 Mdot
.65374 .5754 Mdot
.25429 .56567 Mdot
.28399 .52812 Mdot
.56299 .32663 Mdot
.62291 .42216 Mdot
.66037 .53001 Mdot
.64698 .56672 Mdot
.46362 .6656 Mdot
.46828 .63387 Mdot
.36083 .45182 Mdot
.24935 .58873 Mdot
.53239 .29235 Mdot
.30257 .48524 Mdot
.35154 .34788 Mdot
.50583 .63752 Mdot
.69118 .54235 Mdot
.7228 .71824 Mdot
.44459 .65339 Mdot
.33838 .37609 Mdot
.69018 .54691 Mdot
.29105 .49821 Mdot
.28825 .52218 Mdot
.48795 .64364 Mdot
.71688 .705 Mdot
.5367 .30137 Mdot
.65838 .57025 Mdot
.72306 .53269 Mdot
.51911 .59049 Mdot
.46772 .63942 Mdot
.50547 .69068 Mdot
.55806 .34407 Mdot
.56626 .63095 Mdot
.2743 .52767 Mdot
.65788 .54171 Mdot
.44998 .63158 Mdot
.29393 .50566 Mdot
.55151 .68515 Mdot
.63685 .43872 Mdot
.34623 .37122 Mdot
.32531 .48857 Mdot
.30371 .51291 Mdot
.27874 .50837 Mdot
.73763 .42781 Mdot
.6639 .51612 Mdot
.43658 .80792 Mdot
.45863 .66509 Mdot
.27511 .67797 Mdot
.44598 .6708 Mdot
.53665 .28372 Mdot
.36114 .41256 Mdot
.46341 .66126 Mdot
.45946 .66615 Mdot
.75711 .67159 Mdot
.38588 .61417 Mdot
.3785 .63112 Mdot
.67062 .58328 Mdot
.60183 .60402 Mdot
.3942 .38487 Mdot
.15874 .60507 Mdot
.83477 .51655 Mdot
.4898 .5829 Mdot
.55075 .43445 Mdot
.68298 .53293 Mdot
.56426 .32858 Mdot
.55091 .47719 Mdot
.57683 .25591 Mdot
.66354 .5366 Mdot
.50604 .63217 Mdot
.79271 .62632 Mdot
.28935 .48561 Mdot
.46783 .65361 Mdot
.53628 .32138 Mdot
.46731 .65452 Mdot
.52869 .28737 Mdot
.69799 .60636 Mdot
.56669 .4486 Mdot
.50836 .66494 Mdot
.50003 .58665 Mdot
.54947 .6771 Mdot
.46953 .63965 Mdot
.39624 .2914 Mdot
.68505 .55822 Mdot
.55067 .5503 Mdot
.4392 .60461 Mdot
.67383 .73291 Mdot
.43408 .62975 Mdot
.50799 .37085 Mdot
.43988 .62521 Mdot
.38419 .72003 Mdot
.44179 .61151 Mdot
.43864 .63349 Mdot
.55061 .29263 Mdot
.55462 .33787 Mdot
.7022 .59181 Mdot
.64065 .42643 Mdot
.74276 .30854 Mdot
.47584 .61443 Mdot
.33186 .39365 Mdot
.63788 .47869 Mdot
.30671 .50776 Mdot
.66247 .53978 Mdot
.12358 .48523 Mdot
.5247 .30517 Mdot
.39306 .40841 Mdot
.32128 .33151 Mdot
.39963 .38561 Mdot
.32942 .40665 Mdot
.63228 .60595 Mdot
.31314 .48056 Mdot
.43599 .62137 Mdot
.72637 .67338 Mdot
.7426 .47929 Mdot
.52075 .59617 Mdot
.39881 .33507 Mdot
.42568 .68692 Mdot
.26746 .67905 Mdot
.30426 .47153 Mdot
.32144 .48742 Mdot
.55361 .30313 Mdot
.38925 .34973 Mdot
.54382 .66949 Mdot
.28444 .5269 Mdot
.35816 .41145 Mdot
.66083 .44865 Mdot
.34208 .52697 Mdot
.66918 .54573 Mdot
.42506 .73935 Mdot
.78255 .51005 Mdot
.52665 .30086 Mdot
.56453 .37507 Mdot
.65867 .51054 Mdot
.7236 .56026 Mdot
.64675 .42883 Mdot
.33683 .38798 Mdot
.68601 .58746 Mdot
.46288 .66779 Mdot
.40563 .60059 Mdot
.47068 .60798 Mdot
.29411 .52893 Mdot
.44904 .61234 Mdot
.34093 .39717 Mdot
.53108 .30135 Mdot
.38242 .36967 Mdot
.53715 .29626 Mdot
.78677 .59942 Mdot
.47511 .60165 Mdot
.46582 .63727 Mdot
.52042 .41234 Mdot
.64462 .55793 Mdot
.71341 .66635 Mdot
.33586 .38532 Mdot
.36569 .35448 Mdot
.5049 .62426 Mdot
.7148 .5533 Mdot
.26855 .54423 Mdot
.53863 .44563 Mdot
.44071 .62192 Mdot
.6848 .55908 Mdot
.50623 .61762 Mdot
.37594 .24768 Mdot
.57881 .43947 Mdot
.67366 .58027 Mdot
.48039 .80965 Mdot
.47869 .67242 Mdot
.38686 .63225 Mdot
.39901 .6409 Mdot
.35962 .62545 Mdot
.53411 .63312 Mdot
.6904 .53477 Mdot
.48702 .60238 Mdot
.66722 .5636 Mdot
.37297 .39099 Mdot
.55481 .34285 Mdot
.66774 .56057 Mdot
.4842 .67906 Mdot
.82835 .53552 Mdot
.52692 .31115 Mdot
.46129 .65057 Mdot
.55767 .30928 Mdot
.65352 .58443 Mdot
.6402 .55557 Mdot
.61192 .44598 Mdot
.31705 .37623 Mdot
.52819 .31666 Mdot
.51676 .62599 Mdot
.74432 .44549 Mdot
.50648 .62175 Mdot
.36156 .47213 Mdot
.45262 .59748 Mdot
.51211 .59018 Mdot
.74458 .73648 Mdot
.50214 .37647 Mdot
.14511 .51944 Mdot
.50173 .31506 Mdot
.74786 .43444 Mdot
.73201 .57298 Mdot
.30523 .47111 Mdot
.48926 .26821 Mdot
.63101 .44951 Mdot
.38901 .40467 Mdot
.46148 .66157 Mdot
.77006 .57078 Mdot
.51809 .30544 Mdot
.3096 .49722 Mdot
.50651 .66667 Mdot
.38569 .34064 Mdot
.62148 .40116 Mdot
.57023 .31481 Mdot
.66785 .54415 Mdot
.64405 .54974 Mdot
.33698 .78065 Mdot
.45137 .62679 Mdot
.46503 .62987 Mdot
.52939 .3297 Mdot
.55111 .64978 Mdot
.28291 .49919 Mdot
.43813 .22285 Mdot
.53901 .32395 Mdot
.58289 .42924 Mdot
.67461 .58458 Mdot
.47761 .62864 Mdot
.5063 .40707 Mdot
.70513 .38264 Mdot
.56677 .69965 Mdot
.31067 .51786 Mdot
.33926 .56582 Mdot
.69034 .53458 Mdot
.53972 .32071 Mdot
.30276 .67959 Mdot
.46849 .68448 Mdot
.48094 .62773 Mdot
.32611 .57229 Mdot
.54128 .45103 Mdot
.35487 .48982 Mdot
.48305 .69313 Mdot
.51808 .46148 Mdot
.50443 .62609 Mdot
.49048 .65072 Mdot
.50985 .58452 Mdot
.48395 .59602 Mdot
.6812 .56219 Mdot
.60385 .79356 Mdot
.36094 .37582 Mdot
.52323 .74057 Mdot
.39195 .46082 Mdot
.52501 .6275 Mdot
.50374 .63591 Mdot
.5735 .77563 Mdot
.61155 .50741 Mdot
.68158 .55433 Mdot
.72059 .53172 Mdot
.54644 .34414 Mdot
.38605 .61261 Mdot
.35145 .42208 Mdot
.39843 .66564 Mdot
.37505 .37409 Mdot
.68533 .56042 Mdot
.3848 .35732 Mdot
.51047 .32086 Mdot
.37919 .40288 Mdot
.3588 .42055 Mdot
.5723 .28931 Mdot
.63876 .56553 Mdot
.43831 .6393 Mdot
.56941 .28624 Mdot
.2824 .56184 Mdot
.29361 .52867 Mdot
.61641 .45298 Mdot
.52428 .66791 Mdot
.38324 .62398 Mdot
.35572 .23767 Mdot
.38955 .37065 Mdot
.57955 .49276 Mdot
.66411 .53027 Mdot
.32519 .50219 Mdot
.677 .56377 Mdot
.37039 .76955 Mdot
.29699 .51289 Mdot
.61789 .45381 Mdot
.2961 .66923 Mdot
.58563 .3403 Mdot
.4189 .64703 Mdot
.59611 .5766 Mdot
.3769 .37551 Mdot
.51939 .29511 Mdot
.74752 .32902 Mdot
.47945 .66832 Mdot
.66582 .43994 Mdot
.72277 .54805 Mdot
.62382 .43636 Mdot
.53673 .3183 Mdot
.49734 .29642 Mdot
.45364 .62159 Mdot
.57004 .36026 Mdot
.49368 .58971 Mdot
.45474 .76787 Mdot
.36462 .46511 Mdot
.62026 .52283 Mdot
.51004 .61559 Mdot
.34022 .37853 Mdot
.50881 .61775 Mdot
.4561 .73742 Mdot
.2852 .68639 Mdot
.48068 .58586 Mdot
.59634 .5582 Mdot
.34581 .26017 Mdot
.69394 .54759 Mdot
.44674 .58306 Mdot
.64809 .44111 Mdot
.50097 .65324 Mdot
.7208 .22704 Mdot
.2981 .49981 Mdot
.31434 .44121 Mdot
.4797 .67841 Mdot
.45104 .63911 Mdot
.73265 .69111 Mdot
.60454 .58874 Mdot
.62082 .4231 Mdot
.48429 .63098 Mdot
.34498 .57275 Mdot
.55418 .29666 Mdot
.48097 .59404 Mdot
.4838 .60443 Mdot
.18735 .43846 Mdot
.55639 .2974 Mdot
.39176 .37707 Mdot
.62378 .43998 Mdot
.34425 .35818 Mdot
.32811 .4673 Mdot
.53123 .49214 Mdot
.25839 .57237 Mdot
.58106 .44168 Mdot
.32083 .50938 Mdot
.52666 .62263 Mdot
.71572 .5191 Mdot
.44505 .6329 Mdot
.32077 .49306 Mdot
.5495 .32279 Mdot
.67878 .56016 Mdot
.43741 .74869 Mdot
.64898 .45185 Mdot
.52743 .60115 Mdot
.29828 .47362 Mdot
.66482 .55656 Mdot
.64226 .36168 Mdot
.66733 .53233 Mdot
.54226 .29547 Mdot
.53504 .34413 Mdot
.30181 .50841 Mdot
.67968 .56371 Mdot
.35298 .35316 Mdot
.50084 .31764 Mdot
.46042 .59443 Mdot
.51334 .33353 Mdot
.70867 .58237 Mdot
.65289 .52782 Mdot
.71231 .56345 Mdot
.4866 .5984 Mdot
.5457 .44691 Mdot
.45121 .67756 Mdot
.52657 .3185 Mdot
.39843 .37362 Mdot
.25386 .60696 Mdot
.71859 .68754 Mdot
.58123 .4258 Mdot
.52805 .64842 Mdot
.45357 .61079 Mdot
.47209 .60854 Mdot
.5021 .61051 Mdot
.44206 .22342 Mdot
.47587 .60171 Mdot
.54608 .28698 Mdot
.36931 .38063 Mdot
.45601 .61317 Mdot
.64648 .43806 Mdot
.44978 .43331 Mdot
.32715 .47963 Mdot
.38036 .6958 Mdot
.80538 .47793 Mdot
.66694 .55683 Mdot
.37688 .40083 Mdot
.38046 .35224 Mdot
.28383 .51997 Mdot
.57099 .29363 Mdot
.65996 .5349 Mdot
.36104 .68208 Mdot
.27714 .50436 Mdot
.48827 .60951 Mdot
.51403 .40927 Mdot
.4932 .80884 Mdot
.52124 .65055 Mdot
.48143 .65026 Mdot
.63007 .42619 Mdot
.39142 .4093 Mdot
.74581 .2724 Mdot
.6318 .27911 Mdot
.30543 .50313 Mdot
.29271 .4919 Mdot
.70797 .55178 Mdot
.53007 .61117 Mdot
.53447 .30435 Mdot
.52636 .46351 Mdot
.36681 .22315 Mdot
.77906 .36469 Mdot
.36853 .26741 Mdot
.43211 .63634 Mdot
.62232 .77285 Mdot
.43222 .607 Mdot
.66446 .51671 Mdot
.71341 .55677 Mdot
.67662 .55054 Mdot
.54988 .2942 Mdot
.27795 .71293 Mdot
.546 .28587 Mdot
.80824 .48016 Mdot
.70112 .55694 Mdot
.479 .38419 Mdot
.35755 .35674 Mdot
.4281 .5755 Mdot
.31486 .48097 Mdot
.25842 .49646 Mdot
.44646 .58104 Mdot
.49927 .52473 Mdot
.39013 .38967 Mdot
.6384 .54972 Mdot
.5292 .57984 Mdot
.73287 .29527 Mdot
.55619 .43765 Mdot
.2885 .28039 Mdot
.59592 .61664 Mdot
.29202 .5111 Mdot
.54066 .74969 Mdot
.2835 .49523 Mdot
.56594 .32231 Mdot
.47632 .67014 Mdot
.46911 .67775 Mdot
.49626 .62846 Mdot
.4923 .59871 Mdot
.55466 .31007 Mdot
.43946 .59982 Mdot
.22923 .58512 Mdot
.65631 .45398 Mdot
.4661 .37714 Mdot
.28697 .51494 Mdot
.54314 .2772 Mdot
.37103 .38414 Mdot
.64565 .4271 Mdot
.28652 .55602 Mdot
.4311 .61595 Mdot
.45407 .66185 Mdot
.65886 .4504 Mdot
.55395 .62054 Mdot
.46331 .56279 Mdot
.36187 .37086 Mdot
.45199 .45695 Mdot
.30494 .53113 Mdot
.31571 .47644 Mdot
.53977 .27422 Mdot
.67721 .56397 Mdot
.2914 .53202 Mdot
.38846 .34758 Mdot
.49432 .59281 Mdot
.50205 .58656 Mdot
.70825 .58286 Mdot
.27462 .6943 Mdot
.32496 .47071 Mdot
.55229 .66402 Mdot
.65086 .54886 Mdot
.719 .54013 Mdot
.48365 .63315 Mdot
.44611 .68941 Mdot
.66007 .52022 Mdot
.2853 .50428 Mdot
.54785 .27458 Mdot
.49826 .38797 Mdot
.54253 .28378 Mdot
.65456 .55103 Mdot
.41606 .5961 Mdot
.65062 .57833 Mdot
.48361 .67012 Mdot
.14708 .63966 Mdot
.4602 .60415 Mdot
.48107 .53917 Mdot
.36775 .52741 Mdot
.34633 .3656 Mdot
.3439 .36964 Mdot
.64346 .43648 Mdot
.67359 .52799 Mdot
.4247 .60672 Mdot
.30712 .48044 Mdot
.7477 .43626 Mdot
.61915 .53514 Mdot
.35127 .41821 Mdot
.37847 .41925 Mdot
.55034 .32104 Mdot
.43627 .62341 Mdot
.47523 .62482 Mdot
.38296 .39954 Mdot
.42064 .20954 Mdot
.67222 .56802 Mdot
.46478 .63004 Mdot
.47576 .598 Mdot
.36299 .37783 Mdot
.50081 .2917 Mdot
.71216 .52947 Mdot
.477 .59736 Mdot
.28479 .65643 Mdot
.5264 .29236 Mdot
.52055 .62855 Mdot
.43432 .60557 Mdot
.30843 .51065 Mdot
.26229 .54931 Mdot
.27584 .68252 Mdot
.5728 .31805 Mdot
.62983 .42926 Mdot
.46117 .67392 Mdot
.35271 .36134 Mdot
.5307 .65623 Mdot
.55289 .20654 Mdot
.65167 .45616 Mdot
.45835 .62074 Mdot
.48421 .57854 Mdot
.65068 .56193 Mdot
.45607 .62729 Mdot
.67339 .47345 Mdot
.34625 .39101 Mdot
.45798 .62002 Mdot
.71289 .70727 Mdot
.5479 .32265 Mdot
.44522 .5807 Mdot
.32326 .47995 Mdot
.37167 .49332 Mdot
.80129 .56686 Mdot
.32939 .38813 Mdot
.28994 .52179 Mdot
.44754 .61339 Mdot
.34073 .35958 Mdot
.56308 .27242 Mdot
.53944 .5377 Mdot
.52677 .61556 Mdot
.53925 .28555 Mdot
.52941 .30575 Mdot
.30202 .50402 Mdot
.13369 .53258 Mdot
.48635 .57915 Mdot
.46712 .64844 Mdot
.33617 .23085 Mdot
.63231 .53493 Mdot
.46244 .65355 Mdot
.43618 .62574 Mdot
.56362 .28484 Mdot
.35051 .73648 Mdot
.38373 .54947 Mdot
.43672 .21379 Mdot
.52934 .28788 Mdot
.39775 .406 Mdot
.35166 .40124 Mdot
.28982 .51968 Mdot
.689 .54412 Mdot
.31166 .52595 Mdot
.35416 .38211 Mdot
.49109 .6375 Mdot
.56294 .31913 Mdot
.62295 .64553 Mdot
.52652 .28051 Mdot
.37573 .33722 Mdot
.69068 .5213 Mdot
.79998 .51885 Mdot
.4489 .15893 Mdot
.77906 .51936 Mdot
.56823 .33068 Mdot
.3069 .50782 Mdot
.62705 .29873 Mdot
.4503 .61459 Mdot
.49176 .78601 Mdot
.46719 .65192 Mdot
.56459 .67182 Mdot
.35974 .41248 Mdot
.65401 .43371 Mdot
.47925 .66798 Mdot
.34275 .5649 Mdot
.57346 .30052 Mdot
.53237 .32609 Mdot
.49544 .60751 Mdot
.54045 .2965 Mdot
.4708 .62394 Mdot
.36583 .38283 Mdot
.13801 .53523 Mdot
.44064 .62925 Mdot
.42905 .59378 Mdot
.53966 .25746 Mdot
.61805 .45486 Mdot
.40476 .35317 Mdot
.63376 .77222 Mdot
.73266 .28907 Mdot
.53879 .30189 Mdot
.44695 .54834 Mdot
.38786 .3829 Mdot
.63618 .42422 Mdot
.35329 .4304 Mdot
.47476 .644 Mdot
.43364 .64399 Mdot
.5011 .62585 Mdot
.45354 .61175 Mdot
.51382 .77635 Mdot
.4505 .56661 Mdot
.618 .71628 Mdot
.45689 .66294 Mdot
.48439 .54037 Mdot
.5519 .2863 Mdot
.38833 .6391 Mdot
.35297 .49457 Mdot
.43067 .63644 Mdot
.59718 .58456 Mdot
.54625 .27697 Mdot
.78319 .44765 Mdot
.55619 .30433 Mdot
.38128 .36403 Mdot
.55276 .33574 Mdot
.48204 .6724 Mdot
.674 .54188 Mdot
.35998 .39782 Mdot
.74555 .51872 Mdot
.39037 .39923 Mdot
.45082 .62464 Mdot
.57502 .24701 Mdot
.34963 .35847 Mdot
.38005 .65793 Mdot
.67539 .54057 Mdot
.33246 .59124 Mdot
.63891 .52588 Mdot
.45641 .63362 Mdot
.45678 .64174 Mdot
.65024 .4281 Mdot
.57082 .31385 Mdot
.69947 .58032 Mdot
.1785 .47734 Mdot
.30359 .46854 Mdot
.68691 .55176 Mdot
.39949 .63308 Mdot
.5486 .4311 Mdot
.65875 .57375 Mdot
.35284 .59113 Mdot
.57191 .30374 Mdot
.70257 .54972 Mdot
.42825 .66649 Mdot
.50266 .73911 Mdot
.30019 .47835 Mdot
.33757 .3667 Mdot
.51824 .44386 Mdot
.3497 .39863 Mdot
.51628 .29143 Mdot
.35893 .42415 Mdot
.55409 .29131 Mdot
.65093 .48668 Mdot
.43656 .4803 Mdot
.51275 .30832 Mdot
.51467 .28193 Mdot
.35405 .37352 Mdot
.49964 .61111 Mdot
.45843 .41529 Mdot
.42608 .67472 Mdot
.42842 .58395 Mdot
.52978 .29146 Mdot
.69469 .53793 Mdot
.66993 .58523 Mdot
.556 .55733 Mdot
.64327 .56111 Mdot
.36574 .3959 Mdot
.5834 .45343 Mdot
.45872 .77376 Mdot
.5491 .32516 Mdot
.32708 .34 Mdot
.50797 .62393 Mdot
.35045 .36948 Mdot
.37137 .3955 Mdot
.53471 .29688 Mdot
.5369 .73445 Mdot
.44371 .57785 Mdot
.63114 .5475 Mdot
.70318 .56434 Mdot
.66311 .57609 Mdot
.71312 .55231 Mdot
.29282 .73275 Mdot
.51955 .29468 Mdot
.68594 .53265 Mdot
.50163 .60214 Mdot
.44502 .65612 Mdot
.6274 .43969 Mdot
.28674 .50338 Mdot
.43615 .66281 Mdot
.41676 .62425 Mdot
.48271 .63298 Mdot
.3472 .36416 Mdot
.49835 .71255 Mdot
.64969 .45539 Mdot
.36756 .42245 Mdot
.35115 .42126 Mdot
.63866 .43025 Mdot
.65998 .49219 Mdot
.77644 .32367 Mdot
.49681 .63096 Mdot
.7399 .59525 Mdot
.35394 .36277 Mdot
.5084 .50845 Mdot
.54398 .5791 Mdot
.51655 .6221 Mdot
.45745 .38594 Mdot
.36559 .38863 Mdot
.71978 .58673 Mdot
.47157 .6427 Mdot
.64923 .43278 Mdot
.31448 .47466 Mdot
.41641 .66135 Mdot
.63067 .42566 Mdot
.68642 .56289 Mdot
.30533 .30713 Mdot
.62956 .5643 Mdot
.34963 .35707 Mdot
.44589 .58262 Mdot
.39314 .88799 Mdot
.37788 .37637 Mdot
.74233 .41526 Mdot
.4277 .48262 Mdot
.44353 .62485 Mdot
.36041 .40255 Mdot
.72353 .57174 Mdot
.52635 .29293 Mdot
.52216 .41996 Mdot
.69091 .54235 Mdot
.64676 .42784 Mdot
.62953 .4339 Mdot
.36185 .37573 Mdot
.6981 .5742 Mdot
.44769 .59769 Mdot
.64883 .54371 Mdot
.55145 .32989 Mdot
.502 .66288 Mdot
.74263 .30786 Mdot
.40624 .59656 Mdot
.65153 .54299 Mdot
.39263 .34999 Mdot
.28119 .53061 Mdot
.51384 .65846 Mdot
.78517 .40712 Mdot
.43808 .62097 Mdot
.55612 .31404 Mdot
.46528 .50064 Mdot
.61957 .65259 Mdot
.49439 .6199 Mdot
.50564 .6301 Mdot
.55055 .27053 Mdot
.49383 .62439 Mdot
.5164 .59928 Mdot
.5071 .35523 Mdot
.65392 .56942 Mdot
.46477 .61417 Mdot
.35179 .40563 Mdot
.7066 .63006 Mdot
.47322 .6685 Mdot
.68118 .4647 Mdot
.33435 .57911 Mdot
.44944 .49086 Mdot
.42738 .60267 Mdot
.25373 .56056 Mdot
.45966 .64329 Mdot
.51941 .61197 Mdot
.50032 .62029 Mdot
.61262 .77735 Mdot
.35284 .37799 Mdot
.34555 .40972 Mdot
.31699 .47333 Mdot
.34296 .57055 Mdot
.30238 .52077 Mdot
.5542 .27287 Mdot
.32539 .33615 Mdot
.65642 .45171 Mdot
.67411 .56417 Mdot
.47162 .66625 Mdot
.38504 .40632 Mdot
.47739 .63212 Mdot
.50333 .65122 Mdot
.36005 .39121 Mdot
.37033 .39282 Mdot
.33144 .40288 Mdot
.2829 .49281 Mdot
.67569 .55566 Mdot
.48189 .6536 Mdot
.27659 .51103 Mdot
.44376 .60358 Mdot
.55498 .41148 Mdot
.67771 .55452 Mdot
.64816 .54566 Mdot
.65147 .5815 Mdot
.45458 .66436 Mdot
.48988 .67182 Mdot
.54547 .28571 Mdot
.70535 .58403 Mdot
.5316 .3291 Mdot
.35873 .40223 Mdot
.34441 .37594 Mdot
.47469 .64467 Mdot
.55488 .65521 Mdot
.288 .50629 Mdot
.38543 .36519 Mdot
.63634 .45487 Mdot
.32057 .47402 Mdot
.46223 .60772 Mdot
.35369 .40067 Mdot
.32622 .48037 Mdot
.58288 .65722 Mdot
.70371 .25916 Mdot
.27649 .50251 Mdot
.49513 .60694 Mdot
.73326 .68406 Mdot
.2834 .6673 Mdot
.29254 .47613 Mdot
.55996 .30233 Mdot
.43662 .63954 Mdot
.44984 .18499 Mdot
.29935 .53489 Mdot
.2767 .69366 Mdot
.35578 .39025 Mdot
.57643 .61525 Mdot
.41298 .65596 Mdot
.4739 .78408 Mdot
.29597 .53704 Mdot
.65611 .5412 Mdot
.70796 .56516 Mdot
.4909 .6114 Mdot
.34007 .46125 Mdot
.51731 .29281 Mdot
.38066 .35219 Mdot
.36197 .41862 Mdot
.68901 .58045 Mdot
.58259 .43662 Mdot
.35224 .40466 Mdot
.5234 .59041 Mdot
.31206 .45049 Mdot
.38716 .61036 Mdot
.33464 .77504 Mdot
.78065 .58159 Mdot
.4365 .5953 Mdot
.27818 .52752 Mdot
.57248 .2876 Mdot
.54126 .29118 Mdot
.54766 .29526 Mdot
.34331 .3795 Mdot
.54463 .46708 Mdot
.36181 .4157 Mdot
.68022 .41763 Mdot
.2935 .50437 Mdot
.33226 .62308 Mdot
.42109 .63672 Mdot
.4441 .62507 Mdot
.50626 .59402 Mdot
.50077 .62791 Mdot
.46056 .64167 Mdot
.52752 .29938 Mdot
.36197 .34862 Mdot
.36679 .24163 Mdot
.68235 .57743 Mdot
.63617 .35778 Mdot
.35905 .35583 Mdot
.62241 .43055 Mdot
.30993 .49017 Mdot
.26836 .57412 Mdot
.29347 .45087 Mdot
.38118 .35554 Mdot
.52741 .63372 Mdot
.70006 .53968 Mdot
.42531 .76514 Mdot
.45259 .65039 Mdot
.38724 .36668 Mdot
.38884 .41637 Mdot
.54962 .73392 Mdot
.52086 .677 Mdot
.33638 .44978 Mdot
.54876 .43503 Mdot
.27362 .53286 Mdot
.52363 .66018 Mdot
.52072 .50862 Mdot
.35554 .38043 Mdot
.37389 .3632 Mdot
.28399 .48629 Mdot
.44318 .70508 Mdot
.6983 .55737 Mdot
.65666 .4378 Mdot
.56073 .29583 Mdot
.44507 .6424 Mdot
.34354 .38299 Mdot
.7396 .57232 Mdot
.51814 .40291 Mdot
.54966 .31365 Mdot
.37232 .42182 Mdot
.43388 .63265 Mdot
.49208 .61576 Mdot
.29443 .51361 Mdot
.21934 .39545 Mdot
.42456 .67249 Mdot
.74719 .43406 Mdot
.56577 .47174 Mdot
.39848 .48919 Mdot
.48068 .62731 Mdot
.65465 .57828 Mdot
.64189 .43212 Mdot
.317 .4855 Mdot
.43968 .60904 Mdot
.75629 .29848 Mdot
.63382 .57925 Mdot
.52869 .31378 Mdot
.64421 .43111 Mdot
.53586 .47161 Mdot
.43959 .61938 Mdot
.46753 .65148 Mdot
.48781 .59861 Mdot
.75681 .29493 Mdot
.3529 .41202 Mdot
.71372 .57168 Mdot
.30797 .52139 Mdot
.64655 .54391 Mdot
.33964 .40908 Mdot
.39325 .48745 Mdot
.47132 .60106 Mdot
.63189 .55807 Mdot
.66065 .53634 Mdot
.54746 .32369 Mdot
.56863 .28453 Mdot
.33414 .36418 Mdot
.44886 .61381 Mdot
.65725 .4462 Mdot
.69676 .54289 Mdot
.37912 .34836 Mdot
.2949 .5127 Mdot
.53764 .35215 Mdot
.45694 .66341 Mdot
.35894 .37604 Mdot
.45191 .5894 Mdot
.6579 .56578 Mdot
.37513 .35369 Mdot
.62374 .42572 Mdot
.28823 .49995 Mdot
.44047 .65473 Mdot
.33717 .26505 Mdot
.64677 .43022 Mdot
.48767 .67949 Mdot
.76489 .59206 Mdot
.34881 .4816 Mdot
.75803 .5358 Mdot
.36789 .40914 Mdot
.65393 .44622 Mdot
.7152 .5635 Mdot
.49785 .74402 Mdot
.37269 .36683 Mdot
.764 .64768 Mdot
.47651 .3932 Mdot
.49174 .6399 Mdot
.69323 .55551 Mdot
.26895 .51199 Mdot
.75412 .43035 Mdot
.27222 .63735 Mdot
.46525 .62329 Mdot
.34896 .39814 Mdot
.3169 .47626 Mdot
.53389 .32916 Mdot
.67852 .45731 Mdot
.37188 .79145 Mdot
.36937 .42103 Mdot
.47303 .66306 Mdot
.69803 .54225 Mdot
.53237 .30411 Mdot
.79015 .6306 Mdot
.38566 .34466 Mdot
.36259 .40803 Mdot
.51114 .60182 Mdot
.31052 .51899 Mdot
.45672 .18744 Mdot
.347 .40913 Mdot
.34588 .3559 Mdot
.60392 .39569 Mdot
.30762 .47175 Mdot
.49685 .60219 Mdot
.55535 .55687 Mdot
.4779 .595 Mdot
.69172 .39812 Mdot
.65489 .44591 Mdot
.68111 .57659 Mdot
.46208 .65872 Mdot
.34764 .25851 Mdot
.37348 .37524 Mdot
.55093 .43838 Mdot
.52507 .24842 Mdot
.56967 .28737 Mdot
.34641 .38902 Mdot
.47285 .63564 Mdot
.52993 .34202 Mdot
.28864 .51103 Mdot
.47649 .59745 Mdot
.48653 .67092 Mdot
.72547 .56653 Mdot
.56003 .32253 Mdot
.71689 .62577 Mdot
.54621 .3348 Mdot
.53929 .27359 Mdot
.71914 .53987 Mdot
.48978 .61072 Mdot
.38175 .36003 Mdot
.37574 .33529 Mdot
.44712 .59464 Mdot
.50783 .50757 Mdot
.69697 .55639 Mdot
.32729 .40991 Mdot
.73182 .26403 Mdot
.49268 .58214 Mdot
.6252 .44475 Mdot
.58376 .6145 Mdot
.52068 .30441 Mdot
.48988 .63716 Mdot
.66593 .56444 Mdot
.35897 .34595 Mdot
.34459 .39669 Mdot
.48229 .68737 Mdot
.53407 .2963 Mdot
.32592 .49591 Mdot
.37437 .39567 Mdot
.52319 .39834 Mdot
.45597 .62214 Mdot
.66329 .42964 Mdot
.37773 .39435 Mdot
.81802 .55997 Mdot
.354 .2519 Mdot
.68093 .58039 Mdot
.50958 .63971 Mdot
.68078 .52487 Mdot
.30498 .52396 Mdot
.35693 .42823 Mdot
.53811 .28898 Mdot
.42546 .73707 Mdot
.18379 .42492 Mdot
.34923 .37357 Mdot
.68221 .56135 Mdot
.47384 .65997 Mdot
.54049 .58443 Mdot
.43997 .62434 Mdot
.35113 .73093 Mdot
.31577 .45847 Mdot
.50842 .308 Mdot
.52764 .32442 Mdot
.50144 .6404 Mdot
.28078 .50209 Mdot
.34831 .34364 Mdot
.35895 .38982 Mdot
.14411 .58532 Mdot
.62966 .42522 Mdot
.35731 .44498 Mdot
.45442 .66386 Mdot
.38601 .35241 Mdot
.71558 .6886 Mdot
.53036 .33019 Mdot
.47579 .59362 Mdot
.39618 .39727 Mdot
.68929 .37422 Mdot
.54619 .43066 Mdot
.46006 .62163 Mdot
.54938 .65609 Mdot
.55803 .30332 Mdot
.6275 .29783 Mdot
.37305 .40868 Mdot
.45307 .60077 Mdot
.58249 .3022 Mdot
.62124 .47046 Mdot
.18351 .47212 Mdot
.67557 .55527 Mdot
.4019 .36443 Mdot
.55393 .27792 Mdot
.51786 .70052 Mdot
.28564 .5104 Mdot
.35787 .34251 Mdot
.39582 .39366 Mdot
.5068 .65505 Mdot
.43801 .66352 Mdot
.53747 .67015 Mdot
.69198 .56087 Mdot
.56486 .2878 Mdot
.49335 .65391 Mdot
.57076 .41762 Mdot
.49635 .6366 Mdot
.55985 .28313 Mdot
.26601 .79879 Mdot
.49353 .68152 Mdot
.45072 .65396 Mdot
.36646 .63847 Mdot
.68993 .58322 Mdot
.64837 .56247 Mdot
.57151 .44176 Mdot
.45253 .66325 Mdot
.48729 .37504 Mdot
.67441 .55758 Mdot
.69245 .55043 Mdot
.4851 .37656 Mdot
.50705 .66012 Mdot
.5767 .26477 Mdot
.53414 .30123 Mdot
.56899 .28589 Mdot
.65028 .56044 Mdot
.42502 .57581 Mdot
.56617 .27594 Mdot
.52457 .77481 Mdot
.37347 .35238 Mdot
.5213 .50876 Mdot
.65005 .54229 Mdot
.49811 .40706 Mdot
.57051 .31282 Mdot
.83353 .59039 Mdot
.41554 .75234 Mdot
.47876 .5898 Mdot
.49391 .61524 Mdot
.30526 .51387 Mdot
.50756 .55585 Mdot
.62811 .43035 Mdot
.54234 .29389 Mdot
.44483 .22845 Mdot
.67676 .54999 Mdot
.44159 .64502 Mdot
.25104 .5976 Mdot
.78819 .58106 Mdot
.54891 .54578 Mdot
.68857 .54269 Mdot
.67797 .54592 Mdot
.39029 .39114 Mdot
.37523 .35157 Mdot
.48132 .60185 Mdot
.54924 .29087 Mdot
.70494 .55918 Mdot
.56693 .30406 Mdot
.35511 .38214 Mdot
.37269 .35419 Mdot
.64159 .45515 Mdot
.47065 .56611 Mdot
.34874 .38614 Mdot
.60924 .39342 Mdot
.56933 .4163 Mdot
.722 .57077 Mdot
.43057 .17005 Mdot
.78811 .64582 Mdot
.37001 .64911 Mdot
.31354 .47449 Mdot
.64192 .48282 Mdot
.56293 .33184 Mdot
.50201 .63796 Mdot
.47577 .64993 Mdot
.6343 .4455 Mdot
.56987 .3222 Mdot
.31264 .49813 Mdot
.56885 .31897 Mdot
.3113 .48302 Mdot
.34001 .40093 Mdot
.47082 .66999 Mdot
.45071 .60856 Mdot
.53078 .32049 Mdot
.39125 .38136 Mdot
.34838 .35932 Mdot
.29495 .48393 Mdot
.28202 .5745 Mdot
.36122 .37738 Mdot
.64997 .54212 Mdot
.69421 .64314 Mdot
.62929 .43564 Mdot
.47103 .6424 Mdot
.25597 .57965 Mdot
.52806 .75741 Mdot
.48983 .64472 Mdot
.6452 .43086 Mdot
.12911 .55526 Mdot
.47403 .67047 Mdot
.21567 .68682 Mdot
.65005 .45421 Mdot
.65264 .57944 Mdot
.38525 .38823 Mdot
.63638 .42568 Mdot
.50237 .71142 Mdot
.35464 .46021 Mdot
.45723 .58451 Mdot
.69855 .5525 Mdot
.63488 .56094 Mdot
.44289 .47188 Mdot
.68955 .39586 Mdot
.31202 .51937 Mdot
.30588 .49523 Mdot
.37051 .36838 Mdot
.52954 .37075 Mdot
.53764 .61136 Mdot
.30748 .49759 Mdot
.4831 .20869 Mdot
.50887 .62235 Mdot
.36392 .49306 Mdot
.46319 .39556 Mdot
.66527 .58108 Mdot
.38902 .64348 Mdot
.37287 .37118 Mdot
.682 .56077 Mdot
.45374 .43742 Mdot
.49189 .5928 Mdot
.67779 .55281 Mdot
.56763 .29117 Mdot
.4835 .32866 Mdot
.64188 .55481 Mdot
.52163 .41653 Mdot
.53484 .30634 Mdot
.35045 .48373 Mdot
.31683 .65434 Mdot
.79139 .28758 Mdot
.54455 .29154 Mdot
.38928 .37626 Mdot
.3457 .37913 Mdot
.36446 .37938 Mdot
.69346 .54472 Mdot
.37377 .38871 Mdot
.68843 .5719 Mdot
.52577 .26408 Mdot
.26682 .56457 Mdot
.29931 .50979 Mdot
.32046 .42431 Mdot
.66043 .54353 Mdot
.68829 .41954 Mdot
.35608 .20329 Mdot
.49959 .6051 Mdot
.51389 .30367 Mdot
.27489 .52023 Mdot
.58799 .48952 Mdot
.30815 .51183 Mdot
.38738 .3851 Mdot
.52344 .50913 Mdot
.47063 .62271 Mdot
.76887 .57062 Mdot
.32008 .47925 Mdot
.68981 .54253 Mdot
.52565 .62519 Mdot
.35929 .33359 Mdot
.29332 .52353 Mdot
.30852 .47582 Mdot
.4623 .6422 Mdot
.63722 .55534 Mdot
.38124 .35758 Mdot
.55625 .33825 Mdot
.28436 .48164 Mdot
.55549 .63903 Mdot
.49807 .61452 Mdot
.51772 .66104 Mdot
.55667 .44989 Mdot
.46046 .18068 Mdot
.53872 .30448 Mdot
.27721 .66712 Mdot
.34685 .37217 Mdot
.27539 .64408 Mdot
.75028 .4659 Mdot
.29207 .44644 Mdot
.65515 .44861 Mdot
.6551 .44487 Mdot
.46019 .62792 Mdot
.49573 .1763 Mdot
.49509 .53758 Mdot
.57259 .26832 Mdot
.63222 .43664 Mdot
.34932 .35802 Mdot
.67712 .59362 Mdot
.40301 .67375 Mdot
.4237 .65158 Mdot
.57249 .31778 Mdot
.35922 .38386 Mdot
.5531 .206 Mdot
.29464 .50405 Mdot
.57934 .48429 Mdot
.45704 .61145 Mdot
.46556 .63344 Mdot
.5416 .31565 Mdot
.54369 .2873 Mdot
.66185 .41672 Mdot
.47378 .47439 Mdot
.75213 .32617 Mdot
.53858 .26433 Mdot
.54988 .20267 Mdot
.69431 .61309 Mdot
.65337 .55668 Mdot
.62346 .44093 Mdot
.5577 .2713 Mdot
.4617 .65524 Mdot
.65768 .58127 Mdot
.52662 .5404 Mdot
.72503 .58433 Mdot
.36515 .49363 Mdot
.50175 .3889 Mdot
.45671 .61015 Mdot
.70421 .54246 Mdot
.68162 .55868 Mdot
.69622 .53201 Mdot
.63771 .43133 Mdot
.48302 .62827 Mdot
.50085 .61005 Mdot
.47602 .67063 Mdot
.53786 .58321 Mdot
.45563 .62702 Mdot
.75173 .4615 Mdot
.58111 .41332 Mdot
.23258 .43293 Mdot
.46098 .66646 Mdot
.55871 .27965 Mdot
.46706 .66779 Mdot
.28081 .50629 Mdot
.45073 .66568 Mdot
.36193 .49403 Mdot
.54695 .3014 Mdot
.46098 .71887 Mdot
.32744 .3516 Mdot
.4645 .6048 Mdot
.32226 .50607 Mdot
.46619 .17798 Mdot
.25427 .61623 Mdot
.60473 .39556 Mdot
.64955 .54315 Mdot
.33246 .37549 Mdot
.51546 .31314 Mdot
.37907 .35922 Mdot
.46894 .59313 Mdot
.64244 .45677 Mdot
.70931 .76674 Mdot
.48763 .41744 Mdot
.46103 .65662 Mdot
.47965 .5649 Mdot
.65505 .57679 Mdot
.37462 .37767 Mdot
.71725 .60076 Mdot
.50947 .60194 Mdot
.29374 .53094 Mdot
.28116 .52596 Mdot
.41486 .4725 Mdot
.49015 .25318 Mdot
.437 .76217 Mdot
.54162 .31315 Mdot
.34092 .38954 Mdot
.29821 .53641 Mdot
.59667 .57324 Mdot
.51889 .29043 Mdot
.52059 .30574 Mdot
.56094 .32081 Mdot
.44763 .62582 Mdot
.63315 .44955 Mdot
.48333 .23382 Mdot
.64281 .42678 Mdot
.50079 .59683 Mdot
.39395 .39738 Mdot
.63917 .42483 Mdot
.30337 .51802 Mdot
.53664 .2758 Mdot
.35006 .36088 Mdot
.45559 .639 Mdot
.66826 .55545 Mdot
.26105 .65165 Mdot
.26728 .29255 Mdot
.32736 .42732 Mdot
.32612 .42355 Mdot
.64266 .57837 Mdot
.79743 .42061 Mdot
.51497 .33929 Mdot
.5337 .73958 Mdot
.26427 .51805 Mdot
.44938 .59368 Mdot
.16346 .56061 Mdot
.3633 .41462 Mdot
.36172 .3982 Mdot
.46048 .6164 Mdot
.38345 .34672 Mdot
.43782 .63454 Mdot
.3786 .40597 Mdot
.73287 .39323 Mdot
.42311 .65336 Mdot
.36442 .3965 Mdot
.53821 .62461 Mdot
.5116 .66256 Mdot
.64917 .5746 Mdot
.36009 .34251 Mdot
.48053 .58924 Mdot
.65104 .81728 Mdot
.54249 .32539 Mdot
.63637 .43121 Mdot
.31711 .39292 Mdot
.55764 .33255 Mdot
.69612 .56711 Mdot
.46139 .67265 Mdot
.29014 .51105 Mdot
.65588 .5498 Mdot
.34622 .33903 Mdot
.3228 .48463 Mdot
.58294 .4508 Mdot
.65118 .55779 Mdot
.63003 .44254 Mdot
.29004 .4968 Mdot
.45785 .58422 Mdot
.35931 .39561 Mdot
.3281 .25914 Mdot
.6401 .42721 Mdot
.47443 .6257 Mdot
.40121 .35803 Mdot
.5683 .31982 Mdot
.47928 .60496 Mdot
.34219 .38765 Mdot
.64097 .4304 Mdot
.48994 .67806 Mdot
.48868 .68024 Mdot
.42551 .70179 Mdot
.45937 .50994 Mdot
.29872 .51361 Mdot
.71054 .53138 Mdot
.50102 .60107 Mdot
.28197 .49859 Mdot
.36809 .27628 Mdot
.42279 .62266 Mdot
.65565 .52853 Mdot
.46905 .74152 Mdot
.386 .35563 Mdot
.52888 .32731 Mdot
.37842 .33791 Mdot
.32322 .47615 Mdot
.1875 .34717 Mdot
.62366 .43717 Mdot
.49642 .56899 Mdot
.51307 .59565 Mdot
.3671 .42698 Mdot
.68358 .55652 Mdot
.76366 .34576 Mdot
.44575 .65947 Mdot
.41061 .59453 Mdot
.46675 .64346 Mdot
.3414 .27039 Mdot
.69519 .55285 Mdot
.46911 .64383 Mdot
.5593 .62546 Mdot
.50266 .58614 Mdot
.31747 .51877 Mdot
.33588 .63762 Mdot
.48067 .66007 Mdot
.46474 .91821 Mdot
.65855 .45422 Mdot
.36197 .38956 Mdot
.53512 .42512 Mdot
.30422 .34122 Mdot
.30333 .75628 Mdot
.69216 .56681 Mdot
.61395 .6014 Mdot
.37965 .35791 Mdot
.24447 .63757 Mdot
.79728 .43933 Mdot
.51753 .65383 Mdot
.43546 .63967 Mdot
.3874 .385 Mdot
.37622 .34806 Mdot
.65446 .45796 Mdot
.42832 .63378 Mdot
.41216 .59077 Mdot
.39744 .36017 Mdot
.45105 .63987 Mdot
.57738 .75077 Mdot
.52829 .33738 Mdot
.65011 .5624 Mdot
.53481 .32946 Mdot
.52139 .3091 Mdot
.47263 .77137 Mdot
.56534 .47359 Mdot
.55322 .2822 Mdot
.57326 .3265 Mdot
.34379 .53474 Mdot
.4055 .72711 Mdot
.31428 .52228 Mdot
.50097 .25829 Mdot
.36658 .3718 Mdot
.48418 .62949 Mdot
.68916 .5384 Mdot
.41937 .79429 Mdot
.67392 .26025 Mdot
.54202 .51248 Mdot
.5038 .60751 Mdot
.37111 .37617 Mdot
.64213 .42889 Mdot
.42095 .64927 Mdot
.28205 .65954 Mdot
.46557 .62717 Mdot
.37276 .35008 Mdot
.46091 .77535 Mdot
.6673 .47525 Mdot
.53722 .26584 Mdot
.68558 .59552 Mdot
.46975 .66807 Mdot
.66925 .57023 Mdot
.54517 .28055 Mdot
.28223 .4947 Mdot
.30644 .50661 Mdot
.45915 .60625 Mdot
.43788 .47972 Mdot
.27803 .55402 Mdot
.51737 .65346 Mdot
.50557 .65784 Mdot
.65387 .45013 Mdot
.5045 .65927 Mdot
.45457 .60186 Mdot
.49315 .65098 Mdot
.4266 .62292 Mdot
.54636 .27063 Mdot
.75889 .55851 Mdot
.43885 .66037 Mdot
.50527 .58307 Mdot
.54492 .34539 Mdot
.47109 .69993 Mdot
.55571 .30147 Mdot
.70189 .27091 Mdot
.55891 .29168 Mdot
.30508 .50711 Mdot
.3942 .34312 Mdot
.65194 .61268 Mdot
.70499 .56076 Mdot
.5573 .2773 Mdot
.30269 .48852 Mdot
.54561 .29309 Mdot
.34473 .40192 Mdot
.38416 .19821 Mdot
.66197 .51545 Mdot
.55916 .40482 Mdot
.37633 .68895 Mdot
.66167 .42628 Mdot
.39221 .36171 Mdot
.69054 .57935 Mdot
.67121 .47293 Mdot
.49993 .64425 Mdot
.29213 .51577 Mdot
.46085 .62867 Mdot
.5306 .27924 Mdot
.3691 .37507 Mdot
.55804 .24648 Mdot
.29953 .51408 Mdot
.22292 .3167 Mdot
.38579 .40454 Mdot
.5024 .57562 Mdot
.5406 .34466 Mdot
.40429 .18262 Mdot
.55748 .29537 Mdot
.26663 .56579 Mdot
.66796 .50219 Mdot
.39047 .77704 Mdot
.67044 .54373 Mdot
.66841 .43696 Mdot
.82984 .41433 Mdot
.77511 .42491 Mdot
.65936 .5572 Mdot
.32655 .35246 Mdot
.45107 .62788 Mdot
.49916 .63294 Mdot
.53033 .59435 Mdot
.70738 .59704 Mdot
.49006 .59912 Mdot
.62691 .43277 Mdot
.56383 .4559 Mdot
.46009 .19902 Mdot
.33447 .3677 Mdot
.43744 .63003 Mdot
.52883 .2929 Mdot
.53227 .27582 Mdot
.64314 .42528 Mdot
.55545 .32941 Mdot
.50643 .66617 Mdot
.66276 .54325 Mdot
.45729 .41929 Mdot
.30292 .52402 Mdot
.7405 .43905 Mdot
.26595 .53233 Mdot
.29561 .46093 Mdot
.49655 .58337 Mdot
.37367 .35412 Mdot
.1651 .48489 Mdot
.50295 .63252 Mdot
.67574 .55947 Mdot
.51558 .60247 Mdot
.4891 .65544 Mdot
.4777 .66061 Mdot
.3412 .38669 Mdot
.53753 .42307 Mdot
.45121 .64285 Mdot
.5512 .28031 Mdot
.48323 .37937 Mdot
.42543 .65128 Mdot
.45235 .23665 Mdot
.36684 .49394 Mdot
.66313 .43018 Mdot
.72113 .57255 Mdot
.38475 .37202 Mdot
.67594 .54801 Mdot
.6299 .58559 Mdot
.69609 .56748 Mdot
.46264 .22493 Mdot
.50835 .74059 Mdot
.23698 .71377 Mdot
.69539 .70255 Mdot
.46777 .78155 Mdot
.63062 .55247 Mdot
.41207 .27273 Mdot
.66012 .56162 Mdot
.69427 .56757 Mdot
.18294 .69554 Mdot
.66654 .52873 Mdot
.47579 .6435 Mdot
.46897 .68038 Mdot
.78976 .54225 Mdot
.34423 .53733 Mdot
.45751 .66686 Mdot
.48753 .59992 Mdot
.28826 .53374 Mdot
.5221 .71098 Mdot
.66245 .45575 Mdot
.57448 .47691 Mdot
.62368 .44619 Mdot
.4618 .64144 Mdot
.46546 .60896 Mdot
.48691 .68686 Mdot
.83915 .42386 Mdot
.39323 .7921 Mdot
.64225 .57478 Mdot
.49384 .70325 Mdot
.61043 .42785 Mdot
.51914 .60047 Mdot
.51305 .59812 Mdot
.4814 .67157 Mdot
.3814 .35938 Mdot
.67474 .59307 Mdot
.41597 .65189 Mdot
.73682 .48273 Mdot
.45883 .61046 Mdot
.2788 .47526 Mdot
.27925 .54693 Mdot
.47361 .63625 Mdot
.65478 .53085 Mdot
.50455 .61865 Mdot
.68915 .53025 Mdot
.65258 .56408 Mdot
.46452 .56619 Mdot
.48649 .2383 Mdot
.67124 .59503 Mdot
.51569 .65817 Mdot
.3919 .3748 Mdot
.74622 .42677 Mdot
.4748 .62799 Mdot
.31395 .51413 Mdot
.49055 .6369 Mdot
.324 .50272 Mdot
.49447 .66703 Mdot
.64517 .42745 Mdot
.61123 .66188 Mdot
.37221 .36367 Mdot
.27882 .48927 Mdot
.38736 .3519 Mdot
.37863 .64258 Mdot
.64481 .53137 Mdot
.65931 .46738 Mdot
.38489 .79997 Mdot
.65305 .45138 Mdot
.27433 .67508 Mdot
.48494 .36605 Mdot
.52464 .316 Mdot
.71464 .55552 Mdot
.45533 .76902 Mdot
.4653 .26538 Mdot
.34023 .41832 Mdot
.3495 .42129 Mdot
.17706 .49217 Mdot
.13753 .53716 Mdot
.45026 .64704 Mdot
.44288 .1839 Mdot
.62263 .70175 Mdot
.54158 .61248 Mdot
.48013 .6928 Mdot
.39797 .38784 Mdot
.46064 .66996 Mdot
.51568 .43401 Mdot
.35352 .37426 Mdot
.29958 .49422 Mdot
.67932 .57594 Mdot
.29188 .48954 Mdot
.6452 .23714 Mdot
.58406 .39383 Mdot
.3496 .38101 Mdot
.4245 .63039 Mdot
.44209 .63538 Mdot
.71712 .567 Mdot
.77024 .64479 Mdot
.6527 .56808 Mdot
.31402 .51853 Mdot
.36031 .36443 Mdot
.45559 .7931 Mdot
.48442 .64679 Mdot
.66447 .53446 Mdot
.33096 .34729 Mdot
.49196 .61709 Mdot
.52679 .31405 Mdot
.50494 .60835 Mdot
.65708 .53617 Mdot
.5036 .65998 Mdot
.66431 .5444 Mdot
.3848 .39855 Mdot
.44221 .61312 Mdot
.46795 .60772 Mdot
.27637 .68292 Mdot
.31322 .49966 Mdot
.64106 .53524 Mdot
.51839 .43596 Mdot
.47865 .59502 Mdot
.28489 .66023 Mdot
.47178 .67022 Mdot
.41614 .5599 Mdot
.45754 .69289 Mdot
.62594 .43611 Mdot
.51179 .59369 Mdot
.47378 .62768 Mdot
.73839 .68867 Mdot
.72541 .68554 Mdot
.3759 .61744 Mdot
.56762 .28264 Mdot
.64983 .53623 Mdot
.3453 .38169 Mdot
.35574 .34848 Mdot
.37809 .38652 Mdot
.33485 .55269 Mdot
.54541 .67261 Mdot
.47225 .62034 Mdot
.51024 .29108 Mdot
.30391 .49771 Mdot
.67959 .53667 Mdot
.3018 .50452 Mdot
.57044 .48289 Mdot
.321 .49858 Mdot
.62556 .43173 Mdot
.35604 .24948 Mdot
.55037 .75947 Mdot
.31909 .49226 Mdot
.6525 .56694 Mdot
.50416 .38163 Mdot
.45292 .59217 Mdot
.66161 .3725 Mdot
.2935 .53119 Mdot
.17688 .47523 Mdot
.48343 .67783 Mdot
.52422 .42395 Mdot
.55493 .30837 Mdot
.29276 .48908 Mdot
.55773 .32383 Mdot
.50399 .62244 Mdot
.76267 .54311 Mdot
.67936 .56308 Mdot
.52668 .33414 Mdot
.50724 .59148 Mdot
.29163 .4901 Mdot
.35056 .38573 Mdot
.42866 .75008 Mdot
.56181 .33955 Mdot
.25473 .64217 Mdot
.27219 .63795 Mdot
.35797 .36578 Mdot
.5034 .80248 Mdot
.56007 .31397 Mdot
.43274 .60129 Mdot
.57324 .62708 Mdot
.50819 .61474 Mdot
.34554 .36185 Mdot
.36401 .39934 Mdot
.78143 .4851 Mdot
.45683 .60883 Mdot
.45986 .67756 Mdot
.66689 .59047 Mdot
.34962 .3687 Mdot
.69791 .56623 Mdot
.71197 .57184 Mdot
.38864 .3833 Mdot
.68163 .58065 Mdot
.31898 .4787 Mdot
.55472 .48674 Mdot
.56088 .31045 Mdot
.52855 .30544 Mdot
.3481 .38436 Mdot
.3374 .38531 Mdot
.36907 .35346 Mdot
.5116 .61078 Mdot
.7009 .57348 Mdot
.51317 .63653 Mdot
.47038 .66635 Mdot
.71033 .5223 Mdot
.67821 .58781 Mdot
.51208 .6277 Mdot
.46652 .38241 Mdot
.32137 .51475 Mdot
.36588 .39503 Mdot
.56781 .30121 Mdot
.26778 .68431 Mdot
.53227 .33797 Mdot
.48315 .59571 Mdot
.68928 .37696 Mdot
.69328 .54526 Mdot
.30705 .51295 Mdot
.3431 .47097 Mdot
.30197 .51471 Mdot
.52605 .33377 Mdot
.71251 .57783 Mdot
.58058 .44599 Mdot
.45207 .60975 Mdot
.55771 .45286 Mdot
.30311 .68679 Mdot
.75 .47281 Mdot
.56526 .28737 Mdot
.49874 .60403 Mdot
.65076 .45339 Mdot
.55161 .73439 Mdot
.46846 .61852 Mdot
.4767 .59313 Mdot
.26689 .35354 Mdot
.50132 .58273 Mdot
.72342 .56187 Mdot
.41747 .48326 Mdot
.43806 .61172 Mdot
.37953 .63259 Mdot
.14091 .606 Mdot
.48486 .67888 Mdot
.46575 .60661 Mdot
.48195 .64081 Mdot
.50428 .63498 Mdot
.67107 .52235 Mdot
.25158 .3487 Mdot
.53484 .28626 Mdot
.5538 .48587 Mdot
.56197 .31584 Mdot
.3545 .39789 Mdot
.49377 .43527 Mdot
.68471 .52715 Mdot
.30218 .51529 Mdot
.43144 .18256 Mdot
.53038 .50359 Mdot
.39188 .38736 Mdot
.32615 .76164 Mdot
.29614 .52879 Mdot
.44775 .59363 Mdot
.31766 .47304 Mdot
.39989 .38401 Mdot
.53541 .29467 Mdot
.52601 .63847 Mdot
.69983 .55135 Mdot
.64244 .55369 Mdot
.50387 .60418 Mdot
.73735 .43217 Mdot
.56034 .33163 Mdot
.24639 .47701 Mdot
.4494 .62103 Mdot
.4725 .59377 Mdot
.65881 .57449 Mdot
.37335 .37862 Mdot
.48499 .36873 Mdot
.31185 .48987 Mdot
.52893 .60144 Mdot
.50283 .62168 Mdot
.56761 .48016 Mdot
.55056 .27213 Mdot
.63975 .4403 Mdot
.45234 .61427 Mdot
.56724 .46519 Mdot
.48059 .5974 Mdot
.45745 .55669 Mdot
.39049 .36398 Mdot
.42681 .58391 Mdot
.43277 .63702 Mdot
.74749 .57522 Mdot
.55744 .31936 Mdot
.67881 .55631 Mdot
.65101 .50755 Mdot
.65035 .43343 Mdot
.53822 .32412 Mdot
.51223 .62374 Mdot
.51916 .31155 Mdot
.49088 .64796 Mdot
.45352 .63984 Mdot
.56567 .28766 Mdot
.69775 .57008 Mdot
.75041 .334 Mdot
.75961 .55695 Mdot
.49981 .65309 Mdot
.49325 .63054 Mdot
.34728 .53905 Mdot
.44283 .81737 Mdot
.43219 .63815 Mdot
.70127 .57543 Mdot
.49145 .6149 Mdot
.52881 .29946 Mdot
.31568 .51505 Mdot
.6692 .55862 Mdot
.33942 .39463 Mdot
.37681 .40483 Mdot
.3712 .31694 Mdot
.62378 .43477 Mdot
.42909 .63126 Mdot
.71073 .53101 Mdot
.66238 .58713 Mdot
.58482 .50687 Mdot
.36204 .39067 Mdot
.32234 .49949 Mdot
.46821 .67568 Mdot
.44572 .7528 Mdot
.52436 .29592 Mdot
.4745 .91609 Mdot
.58086 .44186 Mdot
.27476 .54308 Mdot
.44502 .49035 Mdot
.64779 .45197 Mdot
.45103 .6563 Mdot
.2823 .5017 Mdot
.37234 .40353 Mdot
.50103 .62927 Mdot
.54385 .66599 Mdot
.46436 .27816 Mdot
.33686 .39696 Mdot
.52091 .3192 Mdot
.36098 .41112 Mdot
.32321 .50694 Mdot
.62674 .43111 Mdot
.63901 .56036 Mdot
.47064 .63069 Mdot
.38749 .62474 Mdot
.36602 .382 Mdot
.65226 .43116 Mdot
.46512 .60342 Mdot
.64612 .54124 Mdot
.37084 .39194 Mdot
.46201 .64732 Mdot
.53893 .73671 Mdot
.63009 .60394 Mdot
.36328 .36854 Mdot
.52945 .61972 Mdot
.40469 .69591 Mdot
.34023 .40721 Mdot
.39228 .40284 Mdot
.4877 .59937 Mdot
.2951 .48894 Mdot
.43684 .62219 Mdot
.55419 .29285 Mdot
.53765 .42249 Mdot
.53167 .31912 Mdot
.2833 .6697 Mdot
.46378 .68176 Mdot
.53782 .54073 Mdot
.70546 .54614 Mdot
.32535 .46554 Mdot
.71545 .72244 Mdot
.45637 .59677 Mdot
.76629 .32355 Mdot
.50137 .40595 Mdot
.5875 .4066 Mdot
.70563 .24985 Mdot
.31503 .48703 Mdot
.54803 .29538 Mdot
.4691 .60417 Mdot
.51438 .35057 Mdot
.3121 .48131 Mdot
.28366 .67224 Mdot
.52214 .60067 Mdot
.69171 .549 Mdot
.45198 .6211 Mdot
.65151 .53851 Mdot
.49125 .62435 Mdot
.49324 .72099 Mdot
.28057 .47826 Mdot
.26791 .56681 Mdot
.44372 .59424 Mdot
.43857 .17454 Mdot
.38898 .70781 Mdot
.30873 .52008 Mdot
.50023 .65654 Mdot
.64229 .4471 Mdot
.57138 .31299 Mdot
.39124 .21621 Mdot
.37695 .35598 Mdot
.55619 .28398 Mdot
.66987 .57755 Mdot
.39392 .34714 Mdot
.65435 .43651 Mdot
.57545 .61596 Mdot
.28922 .49288 Mdot
.54165 .32507 Mdot
.47354 .63101 Mdot
.50465 .59583 Mdot
.34023 .2698 Mdot
.52076 .82394 Mdot
.70574 .57469 Mdot
.19032 .37802 Mdot
.71333 .53491 Mdot
.30977 .49575 Mdot
.38882 .36148 Mdot
.465 .65721 Mdot
.46744 .61363 Mdot
.34198 .37228 Mdot
.68607 .58437 Mdot
.31535 .45073 Mdot
.39813 .78308 Mdot
.51114 .26219 Mdot
.31927 .59714 Mdot
.66768 .56083 Mdot
.31586 .59514 Mdot
.29447 .54032 Mdot
.53433 .21869 Mdot
.36105 .67398 Mdot
.52882 .32304 Mdot
.3228 .59979 Mdot
.67817 .5346 Mdot
.44996 .64902 Mdot
.63066 .44253 Mdot
.65173 .45582 Mdot
.66824 .5727 Mdot
.38768 .38014 Mdot
.28562 .50865 Mdot
.45574 .61918 Mdot
.58077 .54404 Mdot
.79563 .62609 Mdot
.33903 .382 Mdot
.4939 .56575 Mdot
.5596 .32991 Mdot
.49408 .61951 Mdot
.28206 .52926 Mdot
.53855 .2971 Mdot
.62699 .42513 Mdot
.53151 .49707 Mdot
.46583 .67564 Mdot
.40147 .48825 Mdot
.54901 .31713 Mdot
.44861 .82 Mdot
.46887 .60808 Mdot
.5599 .31452 Mdot
.38975 .61766 Mdot
.70943 .48337 Mdot
.46557 .40445 Mdot
.77478 .41698 Mdot
.32938 .37305 Mdot
.37224 .4081 Mdot
.61493 .82818 Mdot
.2641 .51685 Mdot
.55038 .27711 Mdot
.63082 .42826 Mdot
.34604 .65077 Mdot
.55021 .32864 Mdot
.5218 .64882 Mdot
.47059 .67128 Mdot
.46335 .77717 Mdot
.37229 .6411 Mdot
.65974 .45635 Mdot
.57563 .58498 Mdot
.51456 .65183 Mdot
.4405 .58642 Mdot
.48606 .60488 Mdot
.63537 .5627 Mdot
.53445 .3332 Mdot
.56625 .13309 Mdot
.51691 .30604 Mdot
.56311 .52797 Mdot
.36689 .37198 Mdot
.34788 .34717 Mdot
.47265 .63705 Mdot
.46807 .53345 Mdot
.48719 .16885 Mdot
.48202 .65225 Mdot
.34636 .47787 Mdot
.27059 .63655 Mdot
.41718 .6306 Mdot
.63185 .5755 Mdot
.41099 .59208 Mdot
.68771 .52169 Mdot
.53701 .29735 Mdot
.31499 .48534 Mdot
.3168 .52497 Mdot
.55237 .2993 Mdot
.47468 .617 Mdot
.31948 .52409 Mdot
.46631 .63674 Mdot
.44429 .63939 Mdot
.57547 .48312 Mdot
.27351 .51932 Mdot
.36879 .35293 Mdot
.30511 .50909 Mdot
.6938 .56362 Mdot
.19759 .72383 Mdot
.29493 .50811 Mdot
.40883 .73078 Mdot
.51063 .42268 Mdot
.32128 .60231 Mdot
.64286 .5573 Mdot
.31127 .52135 Mdot
.53032 .32921 Mdot
.5898 .4333 Mdot
.49873 .7997 Mdot
.52957 .33449 Mdot
.464 .61521 Mdot
.68752 .5285 Mdot
.64681 .58058 Mdot
.54314 .26536 Mdot
.6593 .58 Mdot
.47239 .57348 Mdot
.51688 .65679 Mdot
.54502 .27898 Mdot
.80046 .56762 Mdot
.53038 .33142 Mdot
.43837 .74953 Mdot
.48697 .67222 Mdot
.67259 .55891 Mdot
.43109 .55279 Mdot
.73228 .56275 Mdot
.64196 .45566 Mdot
.45038 .66625 Mdot
.29588 .51861 Mdot
.54423 .46642 Mdot
.36486 .3679 Mdot
.69342 .37609 Mdot
.64898 .54335 Mdot
.51237 .30239 Mdot
.64736 .57266 Mdot
.70234 .57854 Mdot
.52597 .33104 Mdot
.68802 .56176 Mdot
.46108 .6106 Mdot
.633 .26926 Mdot
.65001 .54505 Mdot
.54474 .31265 Mdot
.2921 .52012 Mdot
.68584 .58012 Mdot
.32376 .44668 Mdot
.44235 .64188 Mdot
.39574 .36506 Mdot
.28299 .48506 Mdot
.69473 .53169 Mdot
.31498 .51496 Mdot
.3651 .38652 Mdot
.28425 .50934 Mdot
.50182 .31382 Mdot
.50944 .32235 Mdot
.54232 .51658 Mdot
.68638 .48197 Mdot
.69218 .54009 Mdot
.3273 .37854 Mdot
.44603 .65647 Mdot
.4453 .62603 Mdot
.327 .47713 Mdot
.63787 .57386 Mdot
.73224 .42236 Mdot
.51229 .54756 Mdot
.73968 .44064 Mdot
.5616 .27583 Mdot
.21909 .55407 Mdot
.58323 .43816 Mdot
.59621 .39339 Mdot
.52313 .66386 Mdot
.64582 .45189 Mdot
.46715 .6441 Mdot
.2535 .6145 Mdot
.31096 .52488 Mdot
.38492 .29771 Mdot
.53761 .61011 Mdot
.35603 .36144 Mdot
.48876 .6342 Mdot
.43194 .19369 Mdot
.40796 .58978 Mdot
.29937 .53111 Mdot
.53811 .34736 Mdot
.70502 .56068 Mdot
.30132 .52574 Mdot
.38112 .40231 Mdot
.34702 .58834 Mdot
.51342 .66624 Mdot
.51203 .65848 Mdot
.35678 .42246 Mdot
.69875 .56245 Mdot
.35687 .3975 Mdot
.56089 .31104 Mdot
.29778 .50656 Mdot
.50401 .63889 Mdot
.43264 .58341 Mdot
.37061 .42607 Mdot
.52047 .29324 Mdot
.33739 .37677 Mdot
.51953 .30647 Mdot
.64191 .4514 Mdot
.42872 .62334 Mdot
.3751 .42054 Mdot
.52564 .66537 Mdot
.7266 .67133 Mdot
.562 .49797 Mdot
.67519 .75164 Mdot
.36901 .35258 Mdot
.3462 .56067 Mdot
.54951 .30305 Mdot
.54702 .3254 Mdot
.4671 .77027 Mdot
.48832 .17298 Mdot
.48699 .37509 Mdot
.36101 .21506 Mdot
.56112 .30953 Mdot
.54299 .32036 Mdot
.37542 .39983 Mdot
.6883 .56975 Mdot
.62344 .57171 Mdot
.40218 .37601 Mdot
.25643 .58003 Mdot
.67881 .53627 Mdot
.79378 .36562 Mdot
.36176 .41759 Mdot
.50599 .67822 Mdot
.65292 .46533 Mdot
.29639 .53148 Mdot
.25467 .6065 Mdot
.37685 .20746 Mdot
.46887 .65189 Mdot
.20089 .65992 Mdot
.38303 .36793 Mdot
.49659 .28644 Mdot
.549 .21969 Mdot
.4962 .59217 Mdot
.48676 .63411 Mdot
.47932 .61345 Mdot
.29177 .47726 Mdot
.76112 .6423 Mdot
.46585 .65413 Mdot
.2787 .56387 Mdot
.42329 .65441 Mdot
.32891 .26318 Mdot
.30493 .50886 Mdot
.3501 .73501 Mdot
.33358 .35315 Mdot
.73126 .47129 Mdot
.49507 .58445 Mdot
.55995 .30532 Mdot
.46596 .32776 Mdot
.55963 .28192 Mdot
.51476 .2066 Mdot
.35876 .67538 Mdot
.63425 .56102 Mdot
.50532 .60782 Mdot
.36823 .41814 Mdot
.6912 .53043 Mdot
.46619 .35784 Mdot
.17041 .68384 Mdot
.55192 .2686 Mdot
.13242 .46283 Mdot
.53781 .32914 Mdot
.65411 .4561 Mdot
.663 .57386 Mdot
.38301 .55899 Mdot
.55873 .45978 Mdot
.69755 .5672 Mdot
.22985 .46099 Mdot
.62587 .53702 Mdot
.32475 .58047 Mdot
.64321 .51965 Mdot
.54505 .30549 Mdot
.51022 .32279 Mdot
.51967 .68768 Mdot
.43653 .64745 Mdot
.55902 .44245 Mdot
.49378 .69105 Mdot
.45189 .66317 Mdot
.35345 .37405 Mdot
.68912 .47765 Mdot
.52785 .36422 Mdot
.66748 .56546 Mdot
.5304 .28533 Mdot
.48722 .63558 Mdot
.50023 .65319 Mdot
.51203 .58752 Mdot
.25117 .64683 Mdot
.79019 .35829 Mdot
.4525 .64373 Mdot
.41735 .58369 Mdot
.39158 .385 Mdot
.33603 .2693 Mdot
.21571 .3553 Mdot
.35163 .65288 Mdot
.46401 .60257 Mdot
.31164 .50249 Mdot
.29018 .5352 Mdot
.49028 .57409 Mdot
.53347 .53444 Mdot
.32208 .44066 Mdot
.47377 .63085 Mdot
.36134 .56255 Mdot
.35608 .43247 Mdot
.64889 .42809 Mdot
.36559 .38238 Mdot
.68972 .52846 Mdot
.65417 .45201 Mdot
.34545 .39477 Mdot
.41671 .53622 Mdot
.64883 .43296 Mdot
.71372 .48165 Mdot
.31357 .51949 Mdot
.47925 .6052 Mdot
.68475 .60955 Mdot
.34262 .3757 Mdot
.54731 .32125 Mdot
.66246 .54972 Mdot
.57343 .29464 Mdot
.34323 .25823 Mdot
.25915 .59856 Mdot
.62427 .43847 Mdot
.55954 .29976 Mdot
.45857 .46367 Mdot
.31016 .50354 Mdot
.5466 .33325 Mdot
.52639 .54119 Mdot
.43361 .66012 Mdot
.54949 .18392 Mdot
.52076 .64077 Mdot
.78671 .47152 Mdot
.55326 .3185 Mdot
.61899 .42909 Mdot
.46928 .6297 Mdot
.38541 .40403 Mdot
.46291 .69984 Mdot
.46493 .63636 Mdot
.35214 .41146 Mdot
.4512 .64783 Mdot
.27639 .51119 Mdot
.69633 .52704 Mdot
.49594 .41214 Mdot
.23526 .60654 Mdot
.28636 .51926 Mdot
.61763 .50751 Mdot
.43355 .64479 Mdot
.21222 .45277 Mdot
.69076 .55168 Mdot
.46939 .59499 Mdot
.28883 .71477 Mdot
.67807 .57237 Mdot
.67625 .54704 Mdot
.50928 .65206 Mdot
.53307 .33631 Mdot
.34771 .36144 Mdot
.30893 .50605 Mdot
.52724 .37013 Mdot
.46141 .64969 Mdot
.49666 .60271 Mdot
.29713 .52813 Mdot
.5385 .32219 Mdot
.50615 .63697 Mdot
.7238 .34893 Mdot
.58154 .50808 Mdot
.5215 .30467 Mdot
.42571 .65099 Mdot
.60999 .17866 Mdot
.62263 .57394 Mdot
.20884 .67498 Mdot
.26569 .51934 Mdot
.38994 .37467 Mdot
.51931 .57668 Mdot
.43547 .90954 Mdot
.30811 .5222 Mdot
.73806 .46672 Mdot
.44872 .63962 Mdot
.4683 .66052 Mdot
.63794 .54635 Mdot
.51496 .63041 Mdot
.66151 .53149 Mdot
.22476 .59224 Mdot
.4356 .15901 Mdot
.65457 .57706 Mdot
.65697 .53399 Mdot
.38054 .61971 Mdot
.25784 .66357 Mdot
.67829 .577 Mdot
.51222 .66793 Mdot
.23275 .44182 Mdot
.55309 .64647 Mdot
.27574 .53967 Mdot
.33532 .47011 Mdot
.6299 .56698 Mdot
.56292 .80234 Mdot
.38744 .60773 Mdot
.4496 .71615 Mdot
.32067 .53743 Mdot
.56181 .2917 Mdot
.48523 .66424 Mdot
.6244 .43146 Mdot
.37156 .39477 Mdot
.40762 .60334 Mdot
.47529 .60803 Mdot
.66964 .52659 Mdot
.30677 .46712 Mdot
.55376 .32824 Mdot
.48204 .60072 Mdot
.39512 .41017 Mdot
.30378 .49034 Mdot
.6498 .54884 Mdot
.41675 .73533 Mdot
.30741 .53181 Mdot
.44755 .57604 Mdot
.45789 .66425 Mdot
.47051 .60041 Mdot
.5474 .62439 Mdot
.55364 .30223 Mdot
.40145 .36256 Mdot
.52263 .58136 Mdot
.57649 .46468 Mdot
.5349 .46341 Mdot
.51152 .57696 Mdot
.69912 .57699 Mdot
.56477 .28088 Mdot
.64303 .4336 Mdot
.33245 .62358 Mdot
.48568 .67617 Mdot
.7795 .339 Mdot
.361 .78098 Mdot
.64877 .4377 Mdot
.64378 .5269 Mdot
.30555 .51288 Mdot
.50413 .66437 Mdot
.26416 .54924 Mdot
.52187 .64716 Mdot
.5625 .61829 Mdot
.38749 .37038 Mdot
.56555 .299 Mdot
.59443 .53297 Mdot
.37048 .39644 Mdot
.67608 .54769 Mdot
.81288 .48567 Mdot
.62217 .55512 Mdot
.70781 .57498 Mdot
.49205 .23211 Mdot
.54037 .28987 Mdot
.45198 .91721 Mdot
.43871 .81909 Mdot
.48575 .68342 Mdot
.53851 .28664 Mdot
.6612 .5704 Mdot
.5167 .61426 Mdot
.68788 .53814 Mdot
.6657 .59416 Mdot
.45856 .669 Mdot
.45141 .66129 Mdot
.27582 .5705 Mdot
.8043 .38907 Mdot
.29186 .51481 Mdot
.65534 .58035 Mdot
.49191 .76515 Mdot
.46218 .65667 Mdot
.45013 .61151 Mdot
.46654 .29936 Mdot
.30819 .52392 Mdot
.57798 .7413 Mdot
.44689 .62693 Mdot
.2782 .70815 Mdot
.44929 .66317 Mdot
.63716 .59246 Mdot
.55371 .26092 Mdot
.5555 .53719 Mdot
.34687 .35968 Mdot
.71568 .5556 Mdot
.32688 .48574 Mdot
.71928 .5767 Mdot
.50592 .74935 Mdot
.53657 .29518 Mdot
.65735 .53588 Mdot
.38091 .33567 Mdot
.53475 .3131 Mdot
.52715 .32213 Mdot
.46624 .36596 Mdot
.38751 .34176 Mdot
.28274 .48881 Mdot
.57061 .30856 Mdot
.53515 .73661 Mdot
.54241 .30496 Mdot
.51341 .74905 Mdot
.43569 .61804 Mdot
.29849 .56996 Mdot
.58281 .53388 Mdot
.53191 .67722 Mdot
.53854 .33461 Mdot
.2906 .49974 Mdot
.51159 .61838 Mdot
.66491 .58145 Mdot
.29287 .50336 Mdot
.50618 .35374 Mdot
.34469 .34692 Mdot
.64456 .58121 Mdot
.53059 .34137 Mdot
.67365 .52983 Mdot
.26437 .62601 Mdot
.29218 .45049 Mdot
.45683 .38819 Mdot
.55486 .45268 Mdot
.44961 .58705 Mdot
.37874 .62992 Mdot
.50833 .59487 Mdot
.47092 .61315 Mdot
.36341 .36927 Mdot
.33462 .55389 Mdot
.68677 .58011 Mdot
.81276 .60595 Mdot
.55811 .30485 Mdot
.42051 .48322 Mdot
.56533 .62043 Mdot
.49421 .64181 Mdot
.65698 .56173 Mdot
.68448 .5927 Mdot
.7252 .68639 Mdot
.34164 .37178 Mdot
.55079 .64907 Mdot
.48722 .58239 Mdot
.53451 .693 Mdot
.53218 .32712 Mdot
.73616 .34153 Mdot
.34195 .35831 Mdot
.11514 .5176 Mdot
.36559 .39595 Mdot
.24163 .38053 Mdot
.68779 .56269 Mdot
.32258 .49165 Mdot
.44482 .61751 Mdot
.71875 .51166 Mdot
.66195 .5225 Mdot
.33469 .42469 Mdot
.30329 .51736 Mdot
.74631 .33769 Mdot
.54904 .28353 Mdot
.44579 .6063 Mdot
.45526 .66897 Mdot
.51053 .64305 Mdot
.51945 .60994 Mdot
.53971 .2801 Mdot
.52586 .63583 Mdot
.56466 .3378 Mdot
.52664 .75735 Mdot
.29399 .71602 Mdot
.38452 .41243 Mdot
.32437 .27423 Mdot
.70173 .57815 Mdot
.58806 .65102 Mdot
.57117 .7509 Mdot
.56308 .49878 Mdot
.5073 .28994 Mdot
.43202 .61977 Mdot
.38653 .38292 Mdot
.44977 .1778 Mdot
.38114 .41403 Mdot
.50433 .12631 Mdot
.45165 .76852 Mdot
.78827 .43018 Mdot
.52122 .62142 Mdot
.39439 .40651 Mdot
.58929 .78875 Mdot
.43182 .58301 Mdot
.32881 .50384 Mdot
.49523 .73919 Mdot
.77895 .52938 Mdot
.3211 .50458 Mdot
.44508 .64697 Mdot
.6895 .58705 Mdot
.459 .61246 Mdot
.4399 .62523 Mdot
.48463 .64875 Mdot
.56327 .2659 Mdot
.44938 .66891 Mdot
.43718 .62203 Mdot
.50416 .81998 Mdot
.36436 .4893 Mdot
.39088 .39202 Mdot
.69187 .73222 Mdot
.30349 .4977 Mdot
.6954 .53321 Mdot
.50637 .40696 Mdot
.55396 .28863 Mdot
.72122 .68823 Mdot
.52221 .62869 Mdot
.75359 .45438 Mdot
.51069 .31863 Mdot
.3036 .48563 Mdot
.6438 .43135 Mdot
.71357 .29025 Mdot
.37811 .35043 Mdot
.65505 .45875 Mdot
.36594 .36715 Mdot
.64434 .78081 Mdot
.65554 .53383 Mdot
.4481 .58662 Mdot
.56126 .32315 Mdot
.39733 .38923 Mdot
.26955 .55639 Mdot
.48618 .61119 Mdot
.36626 .3526 Mdot
.4395 .59224 Mdot
.53711 .45454 Mdot
.51649 .4101 Mdot
.40004 .36844 Mdot
.51499 .33144 Mdot
.5317 .31279 Mdot
.32406 .48172 Mdot
.70858 .54641 Mdot
.69942 .55552 Mdot
.53699 .30334 Mdot
.14389 .56308 Mdot
.46298 .64939 Mdot
.46295 .66458 Mdot
.57832 .45625 Mdot
.51574 .60833 Mdot
.35633 .55286 Mdot
.66271 .44712 Mdot
.69679 .54141 Mdot
.51114 .6023 Mdot
.50581 .63835 Mdot
.46973 .67461 Mdot
.26204 .59882 Mdot
.36787 .38216 Mdot
.51292 .65457 Mdot
.28523 .49736 Mdot
.66302 .41811 Mdot
.44375 .65369 Mdot
.43096 .58635 Mdot
.66648 .53067 Mdot
.18272 .47228 Mdot
.55213 .31738 Mdot
.34864 .36792 Mdot
.35558 .41876 Mdot
.3037 .66505 Mdot
.71132 .59337 Mdot
.66213 .45494 Mdot
.36928 .26187 Mdot
.63437 .42924 Mdot
.31055 .51625 Mdot
.47434 .38526 Mdot
.36841 .43592 Mdot
.37682 .4068 Mdot
.52407 .34147 Mdot
.50062 .59766 Mdot
.4516 .66386 Mdot
.73146 .46289 Mdot
.47483 .66131 Mdot
.29733 .52041 Mdot
.54339 .34334 Mdot
.66268 .53275 Mdot
.2807 .52624 Mdot
.54586 .32726 Mdot
.69929 .56378 Mdot
.41855 .6398 Mdot
.52572 .59247 Mdot
.6661 .54719 Mdot
.64679 .55228 Mdot
.47771 .63884 Mdot
.57263 .82678 Mdot
.70045 .54616 Mdot
.65579 .55497 Mdot
.62019 .41264 Mdot
.38842 .35529 Mdot
.44417 .55188 Mdot
.53792 .28816 Mdot
.45622 .6105 Mdot
.38423 .41356 Mdot
.31942 .4978 Mdot
.66992 .54092 Mdot
.48614 .66702 Mdot
.45775 .64342 Mdot
.3114 .50462 Mdot
.27611 .53318 Mdot
.29179 .5235 Mdot
.56622 .27194 Mdot
.51665 .65612 Mdot
.68021 .57819 Mdot
.5482 .28288 Mdot
.29482 .53443 Mdot
.31311 .47128 Mdot
.50187 .81458 Mdot
.4703 .64928 Mdot
.32123 .52388 Mdot
.25427 .78649 Mdot
.34805 .59789 Mdot
.65726 .44947 Mdot
.38135 .42293 Mdot
.30381 .56575 Mdot
.29171 .47414 Mdot
.55525 .27877 Mdot
.37292 .49297 Mdot
.31852 .46427 Mdot
.47892 .66139 Mdot
.49664 .61779 Mdot
.52903 .64725 Mdot
.29748 .49827 Mdot
.26509 .61419 Mdot
.65779 .5843 Mdot
.63307 .67505 Mdot
.30331 .49782 Mdot
.39886 .36455 Mdot
.37718 .4229 Mdot
.36368 .39826 Mdot
.43498 .61174 Mdot
.72209 .70391 Mdot
.5052 .76107 Mdot
.5909 .73027 Mdot
.55398 .2837 Mdot
.67974 .59301 Mdot
.55978 .24615 Mdot
.67656 .5465 Mdot
.3782 .38331 Mdot
.2995 .49186 Mdot
.63593 .55087 Mdot
.52644 .31654 Mdot
.52982 .31584 Mdot
.33578 .37753 Mdot
.36246 .3863 Mdot
.34982 .38297 Mdot
.71419 .55311 Mdot
.68814 .56211 Mdot
.50214 .64565 Mdot
.66232 .53964 Mdot
.37128 .79261 Mdot
.27044 .53799 Mdot
.3463 .4212 Mdot
.55088 .31167 Mdot
.65156 .55817 Mdot
.47587 .60529 Mdot
.27545 .35673 Mdot
.33498 .42258 Mdot
.28379 .52047 Mdot
.62079 .3121 Mdot
.38554 .16242 Mdot
.42261 .64066 Mdot
.52505 .28661 Mdot
.53471 .53749 Mdot
.48282 .61731 Mdot
.38487 .36115 Mdot
.37299 .76429 Mdot
.64316 .42788 Mdot
.4352 .6346 Mdot
.4783 .59162 Mdot
.53314 .33458 Mdot
.5102 .4083 Mdot
.48192 .65642 Mdot
.45298 .43899 Mdot
.54036 .27065 Mdot
.34134 .35925 Mdot
.63662 .82824 Mdot
.49538 .2978 Mdot
.23774 .5569 Mdot
.6544 .44089 Mdot
.47495 .66516 Mdot
.35553 .37234 Mdot
.28076 .51146 Mdot
.35897 .37753 Mdot
.63629 .53199 Mdot
.38571 .35548 Mdot
.49272 .60796 Mdot
.68487 .57702 Mdot
.53991 .3244 Mdot
.40794 .48818 Mdot
.5355 .81605 Mdot
.38578 .403 Mdot
.64354 .42288 Mdot
.44659 .65409 Mdot
.56136 .71837 Mdot
.51677 .69022 Mdot
.43308 .63896 Mdot
.56416 .285 Mdot
.66111 .56408 Mdot
.56205 .27677 Mdot
.41994 .6135 Mdot
.59288 .61917 Mdot
.5573 .30158 Mdot
.76679 .53329 Mdot
.29746 .52872 Mdot
.25603 .58153 Mdot
.46556 .62162 Mdot
.56192 .32145 Mdot
.51217 .66293 Mdot
.65401 .58025 Mdot
.52756 .48287 Mdot
.59775 .54985 Mdot
.56018 .32977 Mdot
.79788 .47839 Mdot
.51868 .43733 Mdot
.43054 .55991 Mdot
.56058 .31621 Mdot
.71533 .721 Mdot
.6421 .4447 Mdot
.31377 .49208 Mdot
.28071 .53451 Mdot
.30295 .47892 Mdot
.4717 .66321 Mdot
.49599 .72684 Mdot
.30066 .47565 Mdot
.56436 .27268 Mdot
.28394 .49239 Mdot
.26064 .65429 Mdot
.73686 .4296 Mdot
.289 .52497 Mdot
.4621 .62352 Mdot
.42292 .59693 Mdot
.36413 .4937 Mdot
.36693 .33774 Mdot
.74763 .31233 Mdot
.47166 .80359 Mdot
.46631 .65708 Mdot
.52503 .72404 Mdot
.62908 .54837 Mdot
.45383 .51288 Mdot
.58704 .58609 Mdot
.50574 .38552 Mdot
.65338 .55543 Mdot
.54238 .42828 Mdot
.701 .54286 Mdot
.42877 .60337 Mdot
.45328 .63863 Mdot
.67679 .52097 Mdot
.67658 .36849 Mdot
.77555 .66758 Mdot
.74372 .44005 Mdot
.70253 .57001 Mdot
.55721 .31978 Mdot
.53427 .27576 Mdot
.56522 .28785 Mdot
.34425 .37716 Mdot
.64658 .54384 Mdot
.49661 .67288 Mdot
.38447 .39725 Mdot
.44558 .62072 Mdot
.53209 .30542 Mdot
.58155 .51047 Mdot
.66243 .53235 Mdot
.47335 .62847 Mdot
.50921 .79424 Mdot
.37219 .37036 Mdot
.3105 .50061 Mdot
.62805 .29724 Mdot
.36986 .43069 Mdot
.5166 .31195 Mdot
.66336 .59678 Mdot
.37575 .3226 Mdot
.25262 .34367 Mdot
.49636 .6819 Mdot
.49746 .68022 Mdot
.31789 .35996 Mdot
.53159 .80346 Mdot
.49059 .64255 Mdot
.37928 .40364 Mdot
.39132 .35653 Mdot
.5049 .67149 Mdot
.6411 .56144 Mdot
.30585 .46992 Mdot
.32716 .47794 Mdot
.45792 .58932 Mdot
.55545 .44338 Mdot
.28935 .56836 Mdot
.51072 .6286 Mdot
.51446 .56574 Mdot
.37429 .33446 Mdot
.65433 .43702 Mdot
.56421 .47636 Mdot
.31694 .47697 Mdot
.44732 .63847 Mdot
.7856 .63351 Mdot
.65348 .5405 Mdot
.35263 .3571 Mdot
.52616 .29805 Mdot
.31751 .52605 Mdot
.33511 .40164 Mdot
.50443 .6719 Mdot
.50613 .63742 Mdot
.55468 .32958 Mdot
.64084 .59426 Mdot
.29677 .49615 Mdot
.38687 .39387 Mdot
.32285 .49158 Mdot
.69072 .55899 Mdot
.65387 .5485 Mdot
.4827 .58156 Mdot
.5262 .68122 Mdot
.36935 .41365 Mdot
.53191 .60815 Mdot
.36205 .40291 Mdot
.33959 .26954 Mdot
.52515 .29412 Mdot
.48681 .59251 Mdot
.72358 .58554 Mdot
.53295 .305 Mdot
.47493 .65231 Mdot
.31882 .35663 Mdot
.5028 .63015 Mdot
.40106 .38843 Mdot
.39682 .7758 Mdot
.31497 .4808 Mdot
.39582 .6618 Mdot
.38892 .57798 Mdot
.51462 .6076 Mdot
.38587 .34518 Mdot
.47491 .73053 Mdot
.55539 .29789 Mdot
.68069 .56684 Mdot
.16734 .48994 Mdot
.54372 .3104 Mdot
.45411 .62413 Mdot
.29554 .50684 Mdot
.70634 .56196 Mdot
.634 .44944 Mdot
.57042 .43533 Mdot
.40644 .60588 Mdot
.44801 .69102 Mdot
.47601 .59993 Mdot
.36298 .21288 Mdot
.3524 .37985 Mdot
.65733 .56539 Mdot
.5314 .27997 Mdot
.54283 .2922 Mdot
.37363 .37826 Mdot
.78189 .51014 Mdot
.71604 .38656 Mdot
.30394 .82863 Mdot
.33979 .41273 Mdot
.28941 .4876 Mdot
.52615 .4719 Mdot
.36833 .39949 Mdot
.35214 .3689 Mdot
.34781 .34266 Mdot
.73114 .45 Mdot
.70007 .5726 Mdot
.45706 .64544 Mdot
.72088 .57652 Mdot
.47356 .66538 Mdot
.24049 .5496 Mdot
.53662 .30004 Mdot
.68261 .56627 Mdot
.29508 .43465 Mdot
.38952 .6096 Mdot
.48599 .62526 Mdot
.23581 .52654 Mdot
.41263 .64629 Mdot
.32808 .60796 Mdot
.51278 .58685 Mdot
.36436 .37663 Mdot
.59944 .6042 Mdot
.4771 .56517 Mdot
.50112 .79163 Mdot
.53181 .32036 Mdot
.62679 .44438 Mdot
.41542 .63237 Mdot
.47275 .55464 Mdot
.70777 .56199 Mdot
.63622 .54851 Mdot
.30132 .47486 Mdot
.63512 .28057 Mdot
.53404 .32246 Mdot
.76591 .387 Mdot
.4351 .64598 Mdot
.53573 .36536 Mdot
.38751 .77525 Mdot
.47935 .64546 Mdot
.46643 .37556 Mdot
.72241 .68736 Mdot
.4961 .637 Mdot
.60347 .72011 Mdot
.54922 .3085 Mdot
.28287 .71043 Mdot
.52182 .59352 Mdot
.38258 .35991 Mdot
.6874 .56874 Mdot
.64538 .58143 Mdot
.2816 .52071 Mdot
.4009 .80747 Mdot
.59382 .27751 Mdot
.68686 .56464 Mdot
.48128 .61131 Mdot
.55101 .31708 Mdot
.63468 .45148 Mdot
.39667 .61302 Mdot
.49975 .19285 Mdot
.66158 .53724 Mdot
.52044 .57879 Mdot
.75361 .44599 Mdot
.52851 .41767 Mdot
.80514 .37991 Mdot
.56886 .3002 Mdot
.31833 .47666 Mdot
.54285 .64585 Mdot
.36552 .26521 Mdot
.52762 .59657 Mdot
.23945 .55223 Mdot
.73164 .58524 Mdot
.31607 .51416 Mdot
.4794 .61955 Mdot
.48402 .6543 Mdot
.55057 .46445 Mdot
.28411 .53749 Mdot
.48213 .65666 Mdot
.53522 .59297 Mdot
.69666 .55609 Mdot
.66277 .44592 Mdot
.66617 .53281 Mdot
.46455 .61387 Mdot
.39339 .76245 Mdot
.63742 .5594 Mdot
.74899 .32218 Mdot
.26809 .50052 Mdot
.55494 .28901 Mdot
.48522 .56283 Mdot
.43259 .62504 Mdot
.71994 .24482 Mdot
.64409 .45616 Mdot
.19271 .38942 Mdot
.39392 .40638 Mdot
.78598 .6931 Mdot
.3644 .43336 Mdot
.79455 .44642 Mdot
.42793 .47366 Mdot
.53229 .62778 Mdot
.37297 .66381 Mdot
.59439 .72115 Mdot
.51866 .35159 Mdot
.57713 .68026 Mdot
.43665 .64757 Mdot
.45069 .65351 Mdot
.37695 .40076 Mdot
.78169 .49284 Mdot
.55319 .5395 Mdot
.56192 .47255 Mdot
.30573 .48594 Mdot
.68292 .55602 Mdot
.49383 .61126 Mdot
.64388 .35085 Mdot
.39402 .39227 Mdot
.40308 .73453 Mdot
.47116 .62801 Mdot
.55713 .53006 Mdot
.76066 .50281 Mdot
.54318 .32496 Mdot
.39984 .36414 Mdot
.39514 .35288 Mdot
.4756 .66876 Mdot
.5412 .28203 Mdot
.49927 .64263 Mdot
.51698 .44293 Mdot
.41085 .59841 Mdot
.31583 .50919 Mdot
.4489 .61121 Mdot
.36411 .62746 Mdot
.82349 .48146 Mdot
.43507 .56895 Mdot
.71324 .56199 Mdot
.34748 .38715 Mdot
.36964 .3866 Mdot
.69993 .55631 Mdot
.37039 .38655 Mdot
.63255 .6829 Mdot
.55676 .69215 Mdot
.31183 .51596 Mdot
.56491 .76228 Mdot
.31306 .48269 Mdot
.62523 .44223 Mdot
.47321 .64644 Mdot
.42709 .24575 Mdot
.33859 .41161 Mdot
.26756 .68176 Mdot
.54081 .30209 Mdot
.6484 .45656 Mdot
.47443 .67883 Mdot
.33094 .51309 Mdot
.38211 .38383 Mdot
.48425 .30345 Mdot
.47423 .67288 Mdot
.67728 .58479 Mdot
.49347 .64212 Mdot
.4431 .67902 Mdot
.65714 .45513 Mdot
.48094 .59857 Mdot
.54607 .32716 Mdot
.64753 .5401 Mdot
.78595 .43788 Mdot
.34301 .3755 Mdot
.4384 .63988 Mdot
.48138 .61247 Mdot
.63748 .53977 Mdot
.4684 .67982 Mdot
.55142 .27903 Mdot
.505 .9175 Mdot
.30135 .52668 Mdot
.65333 .43478 Mdot
.64516 .23714 Mdot
.50203 .61004 Mdot
.51026 .62181 Mdot
.51229 .37594 Mdot
.77729 .63959 Mdot
.55833 .31031 Mdot
.41681 .64392 Mdot
.39436 .37998 Mdot
.29392 .49785 Mdot
.5712 .3141 Mdot
.51955 .65104 Mdot
.45353 .65476 Mdot
.31026 .51998 Mdot
.23968 .53299 Mdot
.31504 .44833 Mdot
.55789 .28363 Mdot
.54465 .69944 Mdot
.27968 .35564 Mdot
.46554 .6429 Mdot
.61273 .432 Mdot
.66101 .55849 Mdot
.56242 .30952 Mdot
.76419 .63518 Mdot
.43244 .60047 Mdot
.52215 .32487 Mdot
.53809 .32412 Mdot
.46362 .678 Mdot
.70495 .59626 Mdot
.70594 .58843 Mdot
.65895 .55843 Mdot
.2981 .7131 Mdot
.2456 .3202 Mdot
.34839 .38085 Mdot
.54745 .31507 Mdot
.37971 .41721 Mdot
.32136 .46722 Mdot
.53657 .46187 Mdot
.39747 .36282 Mdot
.69924 .58093 Mdot
.37035 .41874 Mdot
.50206 .63705 Mdot
.52595 .31159 Mdot
.35924 .41714 Mdot
.51642 .61768 Mdot
.52273 .57156 Mdot
.37187 .64901 Mdot
.30457 .4694 Mdot
.54368 .42823 Mdot
.45767 .61961 Mdot
.64515 .43273 Mdot
.47599 .63639 Mdot
.54668 .27817 Mdot
.37482 .49639 Mdot
.51926 .64106 Mdot
.33969 .41361 Mdot
.26377 .31819 Mdot
.37829 .3433 Mdot
.45666 .68207 Mdot
.46324 .61518 Mdot
.46538 .64614 Mdot
.45666 .66726 Mdot
.77677 .5381 Mdot
.55375 .34855 Mdot
.56105 .62333 Mdot
.33595 .39749 Mdot
.67241 .54435 Mdot
.63949 .56956 Mdot
.50466 .37901 Mdot
.64656 .45842 Mdot
.53857 .28524 Mdot
.46398 .6473 Mdot
.48322 .30806 Mdot
.58375 .42335 Mdot
.74908 .44125 Mdot
.36552 .31702 Mdot
.37393 .40841 Mdot
.71506 .56795 Mdot
.35385 .4091 Mdot
.51733 .6567 Mdot
.53066 .59568 Mdot
.78668 .4315 Mdot
.5736 .27699 Mdot
.29809 .4943 Mdot
.44686 .6178 Mdot
.25922 .57218 Mdot
.39152 .38513 Mdot
.37988 .33629 Mdot
.49863 .6461 Mdot
.63152 .58221 Mdot
.84059 .44593 Mdot
.53178 .29132 Mdot
.55682 .72147 Mdot
.60766 .58845 Mdot
.55118 .67806 Mdot
.55121 .29725 Mdot
.46347 .39549 Mdot
.3567 .34257 Mdot
.45009 .80911 Mdot
.66521 .54526 Mdot
.30058 .49352 Mdot
.50947 .57966 Mdot
.69988 .58059 Mdot
.37037 .42304 Mdot
.69343 .53414 Mdot
.446 .58674 Mdot
.55874 .27105 Mdot
.36868 .39329 Mdot
.53276 .35415 Mdot
.67149 .5214 Mdot
.31351 .48181 Mdot
.27662 .67838 Mdot
.54636 .73545 Mdot
.72278 .68661 Mdot
.51195 .65606 Mdot
.4598 .25097 Mdot
.4942 .67357 Mdot
.70536 .58233 Mdot
.465 .62169 Mdot
.38013 .6361 Mdot
.34656 .34847 Mdot
.4954 .56995 Mdot
.44348 .61442 Mdot
.49313 .78691 Mdot
.4848 .63592 Mdot
.48137 .67901 Mdot
.47341 .59001 Mdot
.63999 .597 Mdot
.49224 .57036 Mdot
.67774 .58434 Mdot
.74361 .46595 Mdot
.3537 .3671 Mdot
.3242 .47304 Mdot
.32445 .50252 Mdot
.23371 .54893 Mdot
.25896 .5785 Mdot
.77884 .50073 Mdot
.68009 .53819 Mdot
.53467 .33118 Mdot
.50065 .64164 Mdot
.69792 .74176 Mdot
.36712 .73101 Mdot
.34723 .35037 Mdot
.36915 .41617 Mdot
.5199 .58623 Mdot
.45744 .16119 Mdot
.50124 .5728 Mdot
.58043 .44415 Mdot
.47066 .66549 Mdot
.47684 .59343 Mdot
.38896 .34032 Mdot
.2618 .62206 Mdot
.51296 .65463 Mdot
.70753 .56106 Mdot
.30798 .49125 Mdot
.57469 .62266 Mdot
.35516 .72989 Mdot
.44506 .75435 Mdot
.49787 .54121 Mdot
.52443 .62887 Mdot
.38976 .38305 Mdot
.70463 .56848 Mdot
.57316 .4644 Mdot
.55348 .2816 Mdot
.56181 .43805 Mdot
.52504 .75384 Mdot
.56135 .23135 Mdot
.30309 .49073 Mdot
.32377 .40067 Mdot
.49308 .60726 Mdot
.34489 .37839 Mdot
.42254 .61386 Mdot
.584 .41125 Mdot
.31879 .50454 Mdot
.70866 .54224 Mdot
.55651 .32033 Mdot
.68056 .58624 Mdot
.67858 .74848 Mdot
.37479 .73971 Mdot
.78546 .69474 Mdot
.36977 .34872 Mdot
.71907 .6245 Mdot
.6704 .57355 Mdot
.48132 .67414 Mdot
.29707 .82239 Mdot
.66639 .55991 Mdot
.6853 .58447 Mdot
.50438 .38955 Mdot
.28294 .66963 Mdot
.50857 .57227 Mdot
.69521 .53818 Mdot
.33533 .34739 Mdot
.30142 .51348 Mdot
.51603 .623 Mdot
.44361 .59272 Mdot
.63689 .54818 Mdot
.38078 .38111 Mdot
.24802 .56884 Mdot
.36396 .38171 Mdot
.69644 .57473 Mdot
.37258 .36389 Mdot
.7459 .32586 Mdot
.3973 .37893 Mdot
.44386 .61262 Mdot
.46391 .64615 Mdot
.45603 .20807 Mdot
.6539 .54846 Mdot
.51084 .61949 Mdot
.44976 .64472 Mdot
.67438 .57702 Mdot
.37018 .43521 Mdot
.75498 .62884 Mdot
.51096 .60962 Mdot
.46003 .64742 Mdot
.31297 .52221 Mdot
.53311 .43765 Mdot
.59844 .41741 Mdot
.51422 .62118 Mdot
.29693 .48282 Mdot
.71633 .55835 Mdot
.47749 .63613 Mdot
.26 .62018 Mdot
.35906 .43159 Mdot
.52476 .6143 Mdot
.62799 .44279 Mdot
.48658 .6469 Mdot
.837 .44691 Mdot
.44458 .65072 Mdot
.66062 .57251 Mdot
.6811 .57211 Mdot
.33468 .44073 Mdot
.67479 .5488 Mdot
.6561 .45158 Mdot
.53255 .31031 Mdot
.80866 .49973 Mdot
.65442 .45327 Mdot
.4576 .59908 Mdot
.43684 .81949 Mdot
.44954 .58948 Mdot
.42537 .58891 Mdot
.26034 .67162 Mdot
.65477 .44416 Mdot
.66456 .56658 Mdot
.67542 .36433 Mdot
.53095 .62022 Mdot
.535 .28753 Mdot
.43146 .58379 Mdot
.52499 .61438 Mdot
.37604 .64621 Mdot
.55876 .68354 Mdot
.54499 .34456 Mdot
.43621 .55489 Mdot
.51577 .62386 Mdot
.77448 .64143 Mdot
.48553 .60708 Mdot
.28673 .52533 Mdot
.68846 .54047 Mdot
.3476 .40425 Mdot
.30888 .51564 Mdot
.49766 .60865 Mdot
.2996 .49818 Mdot
.34765 .37689 Mdot
.5678 .31409 Mdot
.45311 .60834 Mdot
.27629 .54087 Mdot
.29843 .49185 Mdot
.49758 .66059 Mdot
.68569 .56675 Mdot
.50954 .69472 Mdot
.4788 .63733 Mdot
.49308 .67917 Mdot
.69906 .55477 Mdot
.25095 .73107 Mdot
.46244 .66981 Mdot
.46404 .39062 Mdot
.69457 .52231 Mdot
.66115 .44922 Mdot
.36519 .40771 Mdot
.53287 .65177 Mdot
.54135 .29103 Mdot
.53509 .30659 Mdot
.33412 .37446 Mdot
.64431 .53611 Mdot
.37132 .39111 Mdot
.40615 .58911 Mdot
.52909 .59176 Mdot
.51083 .5806 Mdot
.1674 .48844 Mdot
.70523 .28014 Mdot
.64928 .56325 Mdot
.36957 .33958 Mdot
.55964 .44815 Mdot
.53016 .29781 Mdot
.36543 .33325 Mdot
.72669 .56243 Mdot
.6615 .52761 Mdot
.70108 .55436 Mdot
.29507 .48749 Mdot
.36264 .39224 Mdot
.72397 .54316 Mdot
.69742 .59177 Mdot
.49867 .65328 Mdot
.51637 .62584 Mdot
.62728 .53827 Mdot
.36528 .45309 Mdot
.31848 .49217 Mdot
.39086 .37082 Mdot
.8124 .32672 Mdot
.53163 .2911 Mdot
.49302 .7876 Mdot
.51569 .61609 Mdot
.11583 .6085 Mdot
.49884 .57286 Mdot
.48247 .60987 Mdot
.68953 .52832 Mdot
.30264 .53734 Mdot
.3017 .50995 Mdot
.67202 .57384 Mdot
.64853 .59163 Mdot
.28606 .50156 Mdot
.48735 .38284 Mdot
.82329 .52316 Mdot
.56938 .45749 Mdot
.66084 .57532 Mdot
.55221 .73611 Mdot
.5698 .31574 Mdot
.70841 .53401 Mdot
.5383 .35108 Mdot
.35237 .36683 Mdot
.38369 .40696 Mdot
.55353 .33161 Mdot
.47349 .67657 Mdot
.37366 .3514 Mdot
.41471 .58181 Mdot
.78709 .40235 Mdot
.53478 .20625 Mdot
.71008 .74959 Mdot
.43178 .6429 Mdot
.54145 .53528 Mdot
.70617 .45725 Mdot
.48832 .59885 Mdot
.4273 .55366 Mdot
.29802 .49609 Mdot
.69978 .52647 Mdot
.57038 .32195 Mdot
.76329 .31764 Mdot
.46521 .64425 Mdot
.68754 .57988 Mdot
.52619 .3058 Mdot
.74036 .32573 Mdot
.45324 .43762 Mdot
.48975 .65465 Mdot
.36107 .86787 Mdot
.67061 .52217 Mdot
.34758 .4039 Mdot
.53975 .78306 Mdot
.7212 .5653 Mdot
.27701 .33903 Mdot
.40357 .36745 Mdot
.59852 .49398 Mdot
.67937 .52669 Mdot
.31737 .452 Mdot
.68829 .55514 Mdot
.27679 .51554 Mdot
.66063 .59674 Mdot
.37751 .37257 Mdot
.48134 .62519 Mdot
.37459 .3734 Mdot
.29615 .53215 Mdot
.35445 .35287 Mdot
.57002 .32257 Mdot
.65179 .43677 Mdot
.5291 .31233 Mdot
.53272 .46377 Mdot
.71642 .64996 Mdot
.56566 .29864 Mdot
.47656 .31535 Mdot
.49323 .63554 Mdot
.63643 .59187 Mdot
.34259 .39781 Mdot
.33074 .39792 Mdot
.54933 .4337 Mdot
.69715 .56875 Mdot
.38103 .36974 Mdot
.53774 .73907 Mdot
.14141 .57559 Mdot
.46312 .56353 Mdot
.25746 .3052 Mdot
.67138 .57725 Mdot
.3511 .34366 Mdot
.57868 .45353 Mdot
.63709 .57209 Mdot
.36436 .41566 Mdot
.55927 .31993 Mdot
.54618 .29044 Mdot
.46009 .67511 Mdot
.54436 .2642 Mdot
.38679 .3449 Mdot
.78344 .63596 Mdot
.69368 .5445 Mdot
.68519 .26549 Mdot
.28713 .5205 Mdot
.34975 .37107 Mdot
.5015 .57053 Mdot
.73613 .57214 Mdot
.35482 .41999 Mdot
.49537 .17955 Mdot
.77134 .28263 Mdot
.38136 .36905 Mdot
.68723 .53958 Mdot
.67353 .54141 Mdot
.43538 .57032 Mdot
.55734 .45625 Mdot
.38285 .37852 Mdot
.42577 .24481 Mdot
.26375 .5593 Mdot
.64198 .45155 Mdot
.4875 .81267 Mdot
.51322 .6549 Mdot
.52486 .62616 Mdot
.55428 .27997 Mdot
.48823 .62559 Mdot
.6667 .59463 Mdot
.50242 .5756 Mdot
.54268 .27118 Mdot
.34137 .36037 Mdot
.4704 .64544 Mdot
.2897 .50296 Mdot
.56507 .28343 Mdot
.51847 .29397 Mdot
.36456 .36227 Mdot
.69332 .54059 Mdot
.66059 .37174 Mdot
.3639 .38373 Mdot
.51946 .64943 Mdot
.64782 .44106 Mdot
.51127 .58745 Mdot
.458 .21434 Mdot
.66085 .58564 Mdot
.35323 .40847 Mdot
.65069 .5203 Mdot
.54324 .31799 Mdot
.33116 .36719 Mdot
.48799 .60328 Mdot
.37721 .40892 Mdot
.45551 .39774 Mdot
.22753 .42289 Mdot
.67874 .59518 Mdot
.35113 .48424 Mdot
.63629 .54589 Mdot
.64101 .45158 Mdot
.3054 .64637 Mdot
.31545 .49273 Mdot
.39244 .36296 Mdot
.74614 .31584 Mdot
.33951 .39594 Mdot
.48403 .63976 Mdot
.45854 .66311 Mdot
.37529 .40192 Mdot
.30721 .48022 Mdot
.22839 .57992 Mdot
.27995 .55425 Mdot
.65128 .54029 Mdot
.44342 .47752 Mdot
.83602 .36987 Mdot
.39588 .33216 Mdot
.53775 .33304 Mdot
.52163 .55626 Mdot
.5014 .62649 Mdot
.52855 .33227 Mdot
.52944 .28675 Mdot
.29301 .53468 Mdot
.34504 .37384 Mdot
.70735 .52784 Mdot
.56189 .33059 Mdot
.73774 .55527 Mdot
.24933 .58936 Mdot
.41961 .65956 Mdot
.51256 .71265 Mdot
.43813 .61167 Mdot
.52932 .41793 Mdot
.55172 .27208 Mdot
.45678 .6267 Mdot
.53971 .60208 Mdot
.56159 .30456 Mdot
.28678 .53252 Mdot
.69419 .50794 Mdot
.37911 .36176 Mdot
.12769 .58706 Mdot
.45181 .60913 Mdot
.4807 .62993 Mdot
.55369 .28379 Mdot
.54694 .80347 Mdot
.65102 .56971 Mdot
.69041 .53797 Mdot
.35192 .38063 Mdot
.56206 .40462 Mdot
.47599 .68231 Mdot
.47105 .60379 Mdot
.37787 .35445 Mdot
.64517 .43349 Mdot
.63622 .81396 Mdot
.45814 .64065 Mdot
.55107 .30457 Mdot
.4659 .33025 Mdot
.55619 .27307 Mdot
.42115 .63564 Mdot
.48169 .64558 Mdot
.45855 .60243 Mdot
.43771 .65808 Mdot
.55142 .33554 Mdot
.48157 .60046 Mdot
.46428 .69937 Mdot
.6618 .56314 Mdot
.52148 .63928 Mdot
.26556 .56268 Mdot
.46156 .63938 Mdot
.29012 .50359 Mdot
.6015 .40678 Mdot
.44001 .64056 Mdot
.52225 .63799 Mdot
.26224 .55369 Mdot
.47734 .61657 Mdot
.52466 .31693 Mdot
.6666 .54275 Mdot
.54478 .31895 Mdot
.53599 .32856 Mdot
.36372 .42029 Mdot
.27599 .5245 Mdot
.53695 .61184 Mdot
.28609 .49886 Mdot
.41695 .58309 Mdot
.43411 .59708 Mdot
.53392 .45079 Mdot
.58038 .44283 Mdot
.31507 .46099 Mdot
.47979 .60325 Mdot
.35353 .37526 Mdot
.3571 .41079 Mdot
.37252 .49289 Mdot
.41002 .59509 Mdot
.56921 .32075 Mdot
.5619 .32119 Mdot
.35724 .55362 Mdot
.37728 .52885 Mdot
.29421 .49445 Mdot
.5172 .49657 Mdot
.4365 .60246 Mdot
.44605 .64542 Mdot
.42406 .59423 Mdot
.39372 .40438 Mdot
.65181 .43507 Mdot
.34066 .36495 Mdot
.62454 .4128 Mdot
.57335 .29673 Mdot
.43173 .64223 Mdot
.55345 .20603 Mdot
.64046 .55266 Mdot
.6653 .54257 Mdot
.53921 .27182 Mdot
.37989 .34343 Mdot
.4099 .5984 Mdot
.15921 .42576 Mdot
.64621 .58548 Mdot
.32353 .47464 Mdot
.46077 .61175 Mdot
.35946 .36467 Mdot
.64733 .53816 Mdot
.27312 .51065 Mdot
.42988 .63257 Mdot
.39139 .33725 Mdot
.46327 .62881 Mdot
.60329 .73633 Mdot
.67139 .56695 Mdot
.5828 .50596 Mdot
.62172 .56443 Mdot
.53535 .33416 Mdot
.55513 .31652 Mdot
.47624 .65129 Mdot
.13826 .49862 Mdot
.64793 .50817 Mdot
.52595 .33367 Mdot
.27914 .49705 Mdot
.64828 .43109 Mdot
.2755 .50516 Mdot
.36362 .40289 Mdot
.30753 .48993 Mdot
.3525 .41877 Mdot
.37403 .45036 Mdot
.65556 .51096 Mdot
.30615 .52146 Mdot
.54856 .80821 Mdot
.53107 .59658 Mdot
.29838 .53388 Mdot
.51663 .58481 Mdot
.38198 .62139 Mdot
.36972 .3539 Mdot
.29585 .48871 Mdot
.48691 .66694 Mdot
.64391 .23 Mdot
.54583 .32622 Mdot
.56859 .32389 Mdot
.53181 .6012 Mdot
.35135 .34175 Mdot
.66666 .59635 Mdot
.49969 .41669 Mdot
.66018 .44295 Mdot
.47062 .60432 Mdot
.42947 .62087 Mdot
.65646 .5214 Mdot
.70675 .57573 Mdot
.47764 .65159 Mdot
.5462 .72442 Mdot
.49427 .60654 Mdot
.5492 .29067 Mdot
.64786 .54267 Mdot
.66864 .54074 Mdot
.39346 .35458 Mdot
.64338 .53759 Mdot
.54848 .66256 Mdot
.51545 .27801 Mdot
.47208 .57671 Mdot
.54296 .31486 Mdot
.38052 .46607 Mdot
.34404 .36874 Mdot
.74393 .30912 Mdot
.64773 .53469 Mdot
.5109 .60169 Mdot
.63972 .5684 Mdot
.29261 .52324 Mdot
.65442 .54638 Mdot
.62864 .54371 Mdot
.44198 .65483 Mdot
.47929 .66248 Mdot
.64485 .43594 Mdot
.55479 .44665 Mdot
.67697 .56438 Mdot
.50323 .60422 Mdot
.50879 .58986 Mdot
.46697 .67056 Mdot
.51946 .43456 Mdot
.69915 .53499 Mdot
.47301 .77153 Mdot
.49068 .20986 Mdot
.68377 .56437 Mdot
.80794 .35657 Mdot
.63053 .42971 Mdot
.64431 .45808 Mdot
.51597 .32665 Mdot
.4578 .64596 Mdot
.37284 .38627 Mdot
.5257 .62153 Mdot
.40965 .59315 Mdot
.43797 .63574 Mdot
.31184 .51962 Mdot
.50061 .6802 Mdot
.63147 .43996 Mdot
.36676 .37853 Mdot
.50464 .60793 Mdot
.46639 .65052 Mdot
.63272 .45189 Mdot
.62206 .55197 Mdot
.66096 .52827 Mdot
.62856 .4645 Mdot
.2881 .53101 Mdot
.56076 .28267 Mdot
.52516 .63408 Mdot
.35311 .37795 Mdot
.3726 .37905 Mdot
.68186 .58569 Mdot
.38463 .36267 Mdot
.55711 .27768 Mdot
.48761 .60997 Mdot
.53708 .33542 Mdot
.31152 .51989 Mdot
.68908 .54096 Mdot
.52111 .64825 Mdot
.49622 .65662 Mdot
.68075 .57209 Mdot
.49165 .6402 Mdot
.31507 .51788 Mdot
.39479 .39801 Mdot
.64823 .55175 Mdot
.53336 .30998 Mdot
.39625 .35905 Mdot
.50406 .63684 Mdot
.656 .1875 Mdot
.48905 .62539 Mdot
.46307 .60399 Mdot
.80358 .47962 Mdot
.49214 .58505 Mdot
.33954 .38384 Mdot
.63665 .56398 Mdot
.42332 .64415 Mdot
.26124 .55685 Mdot
.26762 .45736 Mdot
.40207 .3465 Mdot
.46089 .61026 Mdot
.794 .35605 Mdot
.51359 .6043 Mdot
.76292 .34582 Mdot
.53478 .45154 Mdot
.37768 .20971 Mdot
.50841 .71369 Mdot
.52499 .33233 Mdot
.6469 .43493 Mdot
.33752 .38486 Mdot
.62223 .77283 Mdot
.49105 .63276 Mdot
.73738 .68244 Mdot
.5263 .63359 Mdot
.55023 .29538 Mdot
.47854 .54543 Mdot
.38985 .36857 Mdot
.4751 .80454 Mdot
.49776 .67411 Mdot
.68586 .52759 Mdot
.3279 .37079 Mdot
.6419 .42901 Mdot
.48323 .66914 Mdot
.28345 .51243 Mdot
.28332 .45591 Mdot
.54539 .66563 Mdot
.54076 .31573 Mdot
.44753 .64202 Mdot
.4732 .55119 Mdot
.14907 .56607 Mdot
.65741 .56115 Mdot
.54587 .33041 Mdot
.44567 .52418 Mdot
.46179 .66582 Mdot
.66395 .52729 Mdot
.66769 .54493 Mdot
.2796 .51259 Mdot
.58652 .39165 Mdot
.25019 .46514 Mdot
.55633 .18646 Mdot
.71234 .71009 Mdot
.39792 .397 Mdot
.75238 .52889 Mdot
.51737 .63926 Mdot
.37865 .74449 Mdot
.53261 .32527 Mdot
.48017 .6269 Mdot
.69612 .7018 Mdot
.65583 .55559 Mdot
.45929 .6315 Mdot
.31841 .49538 Mdot
.69004 .4135 Mdot
.49762 .74209 Mdot
.69188 .22476 Mdot
.34237 .34188 Mdot
.46297 .57038 Mdot
.53635 .68055 Mdot
.66083 .44866 Mdot
.42192 .63535 Mdot
.34037 .3923 Mdot
.46478 .25622 Mdot
.31687 .47927 Mdot
.64148 .5494 Mdot
.63327 .42835 Mdot
.52825 .62465 Mdot
.46928 .58749 Mdot
.32089 .47178 Mdot
.48884 .67242 Mdot
.52816 .77895 Mdot
.6287 .45144 Mdot
.3973 .38149 Mdot
.69605 .5366 Mdot
.43736 .61137 Mdot
.64826 .43273 Mdot
.44622 .65859 Mdot
.37792 .58887 Mdot
.45439 .6146 Mdot
.79692 .51924 Mdot
.68837 .56805 Mdot
.53622 .31752 Mdot
.50794 .6767 Mdot
.46757 .63548 Mdot
.28054 .35907 Mdot
.40822 .59824 Mdot
.44677 .65257 Mdot
.69919 .5831 Mdot
.6387 .55823 Mdot
.69402 .57937 Mdot
.39636 .36598 Mdot
.56722 .46493 Mdot
.54423 .29909 Mdot
.41771 .5964 Mdot
.56645 .32394 Mdot
.4678 .71139 Mdot
.31052 .47283 Mdot
.72417 .28002 Mdot
.49518 .61644 Mdot
.70096 .56297 Mdot
.78451 .58691 Mdot
.71707 .56049 Mdot
.5849 .27433 Mdot
.53284 .3217 Mdot
.66996 .56062 Mdot
.4744 .61354 Mdot
.56081 .47321 Mdot
.64643 .19318 Mdot
.52966 .30011 Mdot
.43644 .58437 Mdot
.34081 .34207 Mdot
.33299 .39946 Mdot
.82946 .40979 Mdot
.52792 .32557 Mdot
.70375 .4565 Mdot
.51045 .6059 Mdot
.63928 .54928 Mdot
.56697 .29542 Mdot
.52235 .31437 Mdot
.38235 .35731 Mdot
.49288 .65294 Mdot
.46581 .63421 Mdot
.62642 .43999 Mdot
.56561 .32125 Mdot
.40416 .6499 Mdot
.48942 .65159 Mdot
.79147 .44238 Mdot
.72682 .55848 Mdot
.25857 .74164 Mdot
.41086 .57719 Mdot
.70363 .69498 Mdot
.41647 .4575 Mdot
.64604 .55722 Mdot
.48606 .67864 Mdot
.41664 .59561 Mdot
.401 .38425 Mdot
.48895 .61403 Mdot
.36133 .34368 Mdot
.53088 .3304 Mdot
.73291 .28332 Mdot
.48118 .33298 Mdot
.50911 .28531 Mdot
.48669 .63018 Mdot
.49718 .73935 Mdot
.30274 .52074 Mdot
.57817 .2902 Mdot
.66863 .58122 Mdot
.44034 .60286 Mdot
.39877 .39882 Mdot
.39586 .36972 Mdot
.66384 .54984 Mdot
.73278 .47787 Mdot
.75048 .32326 Mdot
.43329 .65285 Mdot
.36396 .40604 Mdot
.49862 .27429 Mdot
.58402 .6612 Mdot
.51399 .31315 Mdot
.31916 .48063 Mdot
.34008 .37853 Mdot
.55755 .265 Mdot
.38073 .6261 Mdot
.67282 .55438 Mdot
.65983 .52211 Mdot
.30201 .33434 Mdot
.38047 .37605 Mdot
.30972 .50819 Mdot
.3984 .4867 Mdot
.40404 .48773 Mdot
.3192 .50199 Mdot
.34711 .35017 Mdot
.64258 .55803 Mdot
.69107 .57835 Mdot
.66865 .54292 Mdot
.50145 .7918 Mdot
.65039 .58268 Mdot
.32302 .75912 Mdot
.42852 .61447 Mdot
.56434 .71542 Mdot
.49652 .59751 Mdot
.55505 .33825 Mdot
.67327 .5677 Mdot
.54071 .46043 Mdot
.4609 .59416 Mdot
.67201 .21354 Mdot
.45759 .61818 Mdot
.46613 .36153 Mdot
.45853 .64735 Mdot
.55578 .76937 Mdot
.69766 .524 Mdot
.48342 .60216 Mdot
.50855 .29903 Mdot
.29486 .50075 Mdot
.63443 .51975 Mdot
.44618 .64995 Mdot
.75606 .45154 Mdot
.517 .58568 Mdot
.78795 .37179 Mdot
.25091 .34995 Mdot
.32706 .49926 Mdot
.49693 .57995 Mdot
.35223 .42365 Mdot
.51636 .54513 Mdot
.56548 .72674 Mdot
.5294 .30126 Mdot
.51263 .74072 Mdot
.38559 .35689 Mdot
.42522 .55508 Mdot
.43682 .67945 Mdot
.31149 .47781 Mdot
.66464 .50187 Mdot
.55179 .29044 Mdot
.49301 .63135 Mdot
.48248 .67789 Mdot
.45969 .18791 Mdot
.56075 .73801 Mdot
.42799 .6797 Mdot
.31274 .46857 Mdot
.51183 .74716 Mdot
.4403 .63571 Mdot
.40182 .34675 Mdot
.63494 .5647 Mdot
.54944 .60259 Mdot
.46314 .77768 Mdot
.50096 .60504 Mdot
.66661 .55787 Mdot
.64771 .53382 Mdot
.80137 .58697 Mdot
.3074 .47485 Mdot
.45387 .61528 Mdot
.29199 .33477 Mdot
.5197 .64961 Mdot
.546 .29502 Mdot
.41986 .62842 Mdot
.35313 .3613 Mdot
.58254 .4559 Mdot
.39587 .36394 Mdot
.4745 .67034 Mdot
.69042 .55128 Mdot
.55464 .28754 Mdot
.36053 .25561 Mdot
.53875 .3823 Mdot
.31878 .75515 Mdot
.28026 .45946 Mdot
.28772 .50188 Mdot
.27369 .51654 Mdot
.55846 .25044 Mdot
.46701 .61054 Mdot
.52024 .41148 Mdot
.4366 .57553 Mdot
.45604 .65141 Mdot
.44457 .61844 Mdot
.50205 .34352 Mdot
.53309 .32039 Mdot
.37501 .36687 Mdot
.47897 .65063 Mdot
.50272 .60357 Mdot
.68343 .56007 Mdot
.29838 .49151 Mdot
.39391 .39687 Mdot
.29076 .52983 Mdot
.36268 .3764 Mdot
.83812 .43687 Mdot
.41963 .61718 Mdot
.29465 .5025 Mdot
.55911 .27324 Mdot
.70204 .57223 Mdot
.63729 .45411 Mdot
.36414 .40189 Mdot
.38926 .37035 Mdot
.48314 .59982 Mdot
.67897 .53286 Mdot
.67006 .52863 Mdot
.2867 .50086 Mdot
.56447 .31578 Mdot
.45006 .67346 Mdot
.48339 .65828 Mdot
.33146 .2638 Mdot
.40076 .37915 Mdot
.5256 .74482 Mdot
.78632 .54015 Mdot
.46891 .60907 Mdot
.6721 .52741 Mdot
.47258 .64114 Mdot
.51255 .23916 Mdot
.70294 .57647 Mdot
.49167 .58956 Mdot
.38625 .66241 Mdot
.39274 .40532 Mdot
.80478 .63358 Mdot
.53467 .62945 Mdot
.54854 .36636 Mdot
.50707 .65411 Mdot
.8241 .65092 Mdot
.77866 .59685 Mdot
.52671 .63459 Mdot
.43891 .6582 Mdot
.55617 .17638 Mdot
.51637 .60973 Mdot
.62851 .43783 Mdot
.40591 .59658 Mdot
.66471 .52664 Mdot
.44978 .43088 Mdot
.54015 .42547 Mdot
.28999 .48629 Mdot
.3512 .38034 Mdot
.27683 .64639 Mdot
.27977 .52595 Mdot
.66369 .57436 Mdot
.4608 .58985 Mdot
.75244 .5865 Mdot
.34925 .43343 Mdot
.43872 .67361 Mdot
.54744 .2947 Mdot
.5413 .42528 Mdot
.34132 .36674 Mdot
.5321 .31159 Mdot
.51167 .59715 Mdot
.19006 .41852 Mdot
.58112 .34966 Mdot
.81597 .57829 Mdot
.5571 .28347 Mdot
.54291 .32439 Mdot
.56974 .48156 Mdot
.28945 .48693 Mdot
.43025 .20587 Mdot
.56996 .61538 Mdot
.53117 .29308 Mdot
.33392 .62331 Mdot
.39632 .34871 Mdot
.57838 .4112 Mdot
.70567 .53038 Mdot
.4186 .61831 Mdot
.47199 .61774 Mdot
.56366 .30814 Mdot
.75795 .55341 Mdot
.41146 .52025 Mdot
.52823 .30894 Mdot
.53107 .68366 Mdot
.58279 .40673 Mdot
.65047 .44034 Mdot
.62588 .43207 Mdot
.28443 .489 Mdot
.22293 .46323 Mdot
.6938 .56536 Mdot
.32532 .48862 Mdot
.60503 .51797 Mdot
.45061 .62165 Mdot
.565 .32354 Mdot
.6225 .43884 Mdot
.53677 .30592 Mdot
.29751 .51029 Mdot
.31707 .47301 Mdot
.66087 .56282 Mdot
.65034 .57034 Mdot
.5988 .61562 Mdot
.34342 .57034 Mdot
.52241 .62203 Mdot
.75354 .63649 Mdot
.69995 .5788 Mdot
.58708 .79233 Mdot
.28818 .49252 Mdot
.30745 .48465 Mdot
.60773 .68947 Mdot
.5015 .64516 Mdot
.46574 .34053 Mdot
.44121 .64243 Mdot
.31945 .6535 Mdot
.52942 .61279 Mdot
.38213 .35838 Mdot
.50752 .66486 Mdot
.65121 .35808 Mdot
.50645 .61412 Mdot
.43913 .6241 Mdot
.36325 .39673 Mdot
.4928 .68638 Mdot
.35644 .35764 Mdot
.4613 .66951 Mdot
.29893 .54032 Mdot
.35327 .37831 Mdot
.29605 .5516 Mdot
.46745 .39771 Mdot
.63917 .43447 Mdot
.27742 .50283 Mdot
.28456 .51215 Mdot
.24707 .56067 Mdot
.65577 .57791 Mdot
.37583 .61476 Mdot
.46502 .61259 Mdot
.37487 .33455 Mdot
.5684 .2896 Mdot
.49945 .60423 Mdot
.49757 .5732 Mdot
.53574 .62882 Mdot
.66345 .56099 Mdot
.35017 .34622 Mdot
.29976 .50234 Mdot
.3606 .41185 Mdot
.2902 .54588 Mdot
.33935 .40549 Mdot
.5094 .56203 Mdot
.40323 .59331 Mdot
.47417 .70171 Mdot
.72593 .67552 Mdot
.43607 .8123 Mdot
.66983 .55116 Mdot
.64478 .44566 Mdot
.30932 .47262 Mdot
.43813 .48067 Mdot
.69883 .55972 Mdot
.38843 .37389 Mdot
.46338 .62858 Mdot
.52474 .69001 Mdot
.5608 .65624 Mdot
.73278 .56145 Mdot
.3344 .55533 Mdot
.35264 .39301 Mdot
.65113 .45206 Mdot
.57106 .44999 Mdot
.63176 .59803 Mdot
.5362 .46443 Mdot
.4698 .639 Mdot
.28378 .50623 Mdot
.64724 .53829 Mdot
.43995 .21853 Mdot
.56131 .31521 Mdot
.55636 .45164 Mdot
.4869 .6276 Mdot
.71528 .487 Mdot
.68985 .55087 Mdot
.31497 .48305 Mdot
.56347 .30723 Mdot
.29764 .48109 Mdot
.63774 .42579 Mdot
.6088 .44069 Mdot
.48808 .6698 Mdot
.44539 .65201 Mdot
.57305 .29751 Mdot
.69418 .56328 Mdot
.31741 .44371 Mdot
.47604 .18935 Mdot
.36829 .40349 Mdot
.53498 .39907 Mdot
.64696 .54131 Mdot
.68872 .47792 Mdot
.3772 .40703 Mdot
.56258 .2704 Mdot
.52283 .41512 Mdot
.53676 .274 Mdot
.43979 .62843 Mdot
.67404 .53654 Mdot
.52726 .32525 Mdot
.34291 .26961 Mdot
.81489 .425 Mdot
.70248 .51496 Mdot
.4819 .65233 Mdot
.72427 .27813 Mdot
.73873 .42086 Mdot
.72448 .51685 Mdot
.55756 .33371 Mdot
.47781 .64531 Mdot
.43153 .6494 Mdot
.49977 .67278 Mdot
.55072 .32503 Mdot
.54251 .37393 Mdot
.39242 .37788 Mdot
.45459 .62848 Mdot
.28789 .52094 Mdot
.35917 .35955 Mdot
.34369 .42107 Mdot
.33774 .38724 Mdot
.70264 .57798 Mdot
.43743 .59785 Mdot
.58179 .53296 Mdot
.83417 .59056 Mdot
.53898 .3221 Mdot
.63886 .4346 Mdot
.45471 .60586 Mdot
.27527 .70447 Mdot
.69781 .5765 Mdot
.372 .40026 Mdot
.47986 .62883 Mdot
.2623 .34745 Mdot
.62297 .44798 Mdot
.36168 .38914 Mdot
.67063 .58112 Mdot
.72204 .51527 Mdot
.48949 .61316 Mdot
.50835 .65069 Mdot
.68598 .57601 Mdot
.71636 .42422 Mdot
.57618 .44072 Mdot
.4708 .64325 Mdot
.53389 .31605 Mdot
.13418 .5535 Mdot
.49978 .58701 Mdot
.73355 .58174 Mdot
.65181 .4333 Mdot
.78885 .5087 Mdot
.53339 .73411 Mdot
.4797 .56245 Mdot
.66338 .22836 Mdot
.26132 .65142 Mdot
.75148 .29815 Mdot
.31699 .67914 Mdot
.55947 .22532 Mdot
.83991 .49156 Mdot
.50952 .299 Mdot
.56491 .76386 Mdot
.46367 .16706 Mdot
.71407 .45349 Mdot
.21838 .3999 Mdot
.38597 .25878 Mdot
.26587 .32889 Mdot
.55136 .82969 Mdot
.33979 .40931 Mdot
.34065 .68915 Mdot
.47034 .67778 Mdot
.7193 .4111 Mdot
.52499 .76241 Mdot
.39922 .80908 Mdot
.72506 .2846 Mdot
.28351 .3383 Mdot
.62159 .17022 Mdot
.7339 .30505 Mdot
.64749 .61928 Mdot
.41191 .73906 Mdot
.229 .47562 Mdot
.39906 .48961 Mdot
.27748 .65625 Mdot
.47902 .73207 Mdot
.6511 .34349 Mdot
.50659 .32087 Mdot
.68346 .64035 Mdot
.1592 .5966 Mdot
.34567 .3963 Mdot
.63444 .56476 Mdot
.41851 .20704 Mdot
.70947 .61182 Mdot
.58334 .2631 Mdot
.66341 .22816 Mdot
.79777 .44814 Mdot
.55418 .76786 Mdot
.59058 .50991 Mdot
.61442 .72488 Mdot
.22035 .57486 Mdot
.3976 .73899 Mdot
.7126 .58987 Mdot
.38932 .28751 Mdot
.40246 .48982 Mdot
.23365 .50438 Mdot
.56217 .77908 Mdot
.27217 .51293 Mdot
.28874 .55406 Mdot
.67996 .58173 Mdot
.5913 .64775 Mdot
.64769 .46012 Mdot
.6069 .52245 Mdot
.40033 .39808 Mdot
.5 .24742 Mdot
.69238 .40811 Mdot
.73705 .44534 Mdot
.76132 .69543 Mdot
.69633 .2161 Mdot
.28624 .59645 Mdot
.46202 .23863 Mdot
.58834 .31873 Mdot
.26128 .63289 Mdot
.56682 .51675 Mdot
.31955 .58937 Mdot
.37037 .609 Mdot
.54474 .13622 Mdot
.76529 .44688 Mdot
.60368 .15496 Mdot
.64999 .59562 Mdot
.54318 .63406 Mdot
.47877 .23898 Mdot
.69535 .73038 Mdot
.25569 .53596 Mdot
.69817 .22188 Mdot
.3287 .48274 Mdot
.68777 .51762 Mdot
.71349 .45644 Mdot
.52406 .77562 Mdot
.31904 .4392 Mdot
.27815 .48575 Mdot
.5491 .60463 Mdot
.52856 .11916 Mdot
.65118 .21945 Mdot
.7995 .56217 Mdot
.78907 .44482 Mdot
.40363 .33688 Mdot
.34915 .4265 Mdot
.52442 .32595 Mdot
.82363 .45365 Mdot
.68341 .54336 Mdot
.83677 .59291 Mdot
.81479 .44659 Mdot
.49345 .53784 Mdot
.51458 .11886 Mdot
.6321 .81151 Mdot
.55994 .71677 Mdot
.37295 .76296 Mdot
.22699 .34891 Mdot
.55849 .50562 Mdot
.67937 .47053 Mdot
.37135 .32568 Mdot
.8051 .49769 Mdot
.82348 .41669 Mdot
.3406 .62863 Mdot
.5798 .23008 Mdot
.60518 .52956 Mdot
.37613 .47352 Mdot
.67927 .50882 Mdot
.20576 .42856 Mdot
.36343 .55696 Mdot
.6162 .16295 Mdot
.50555 .74895 Mdot
.15124 .48724 Mdot
.30789 .66562 Mdot
.54188 .8034 Mdot
.65824 .24197 Mdot
.41411 .39024 Mdot
.38529 .5553 Mdot
.75393 .46868 Mdot
.45466 .57776 Mdot
.52492 .49891 Mdot
.39809 .57118 Mdot
.33909 .49197 Mdot
.57013 .4706 Mdot
.75202 .37709 Mdot
.29744 .64785 Mdot
.53087 .19991 Mdot
.41517 .73644 Mdot
.70715 .54835 Mdot
.30714 .58322 Mdot
.30924 .62173 Mdot
.78166 .428 Mdot
.44809 .52428 Mdot
.80989 .54321 Mdot
.4367 .52085 Mdot
.45327 .56899 Mdot
.57263 .76048 Mdot
.46941 .72964 Mdot
.32493 .61269 Mdot
.5331 .62831 Mdot
.77386 .67564 Mdot
.7955 .46892 Mdot
.71026 .66711 Mdot
.2809 .62975 Mdot
.72335 .6718 Mdot
.80896 .49868 Mdot
.4848 .23286 Mdot
.68144 .46279 Mdot
.75117 .53607 Mdot
.53475 .12292 Mdot
.37023 .35999 Mdot
.33704 .60954 Mdot
.52711 .35942 Mdot
.34876 .26729 Mdot
.4383 .18194 Mdot
.42253 .51915 Mdot
.81668 .49199 Mdot
.72848 .45306 Mdot
.33825 .43132 Mdot
.63625 .3173 Mdot
.49346 .31852 Mdot
.73678 .64239 Mdot
.53894 .61725 Mdot
.39874 .56023 Mdot
.31653 .5157 Mdot
.65201 .75469 Mdot
.48044 .21554 Mdot
.30736 .38813 Mdot
.5057 .56568 Mdot
.31948 .33664 Mdot
.64419 .45324 Mdot
.55536 .42614 Mdot
.8396 .4253 Mdot
.43652 .56021 Mdot
.60644 .81868 Mdot
.73174 .43185 Mdot
.53081 .41524 Mdot
.23832 .53185 Mdot
.77269 .53849 Mdot
.58328 .14267 Mdot
.82307 .48359 Mdot
.73295 .39741 Mdot
.71608 .26976 Mdot
.68037 .80736 Mdot
.39339 .19259 Mdot
.68714 .75269 Mdot
.52599 .3587 Mdot
.48989 .91203 Mdot
.36879 .41067 Mdot
.40265 .77301 Mdot
.69206 .73143 Mdot
.26206 .36117 Mdot
.71626 .6097 Mdot
.46886 .74095 Mdot
.25843 .49032 Mdot
.62487 .5481 Mdot
.52784 .58336 Mdot
.74476 .26658 Mdot
.55252 .1338 Mdot
.73146 .25209 Mdot
.60607 .4292 Mdot
.75955 .29806 Mdot
.54236 .15785 Mdot
.3283 .7638 Mdot
.44885 .19085 Mdot
.42009 .63062 Mdot
.35082 .59891 Mdot
.65479 .79553 Mdot
.30134 .45574 Mdot
.59152 .53049 Mdot
.72315 .58303 Mdot
.52752 .14374 Mdot
.84048 .42217 Mdot
.62885 .68478 Mdot
.6164 .62716 Mdot
.44506 .41642 Mdot
.33255 .58935 Mdot
.73752 .60271 Mdot
.65718 .32895 Mdot
.79042 .40803 Mdot
.53072 .15675 Mdot
.30694 .63106 Mdot
.38533 .2653 Mdot
.72406 .38392 Mdot
.67086 .77723 Mdot
.65695 .23682 Mdot
.41158 .20697 Mdot
.45168 .53449 Mdot
.60752 .55175 Mdot
.41266 .52101 Mdot
.64578 .33478 Mdot
.46728 .29318 Mdot
.27 .60242 Mdot
.35583 .35168 Mdot
.3428 .61815 Mdot
.49151 .45831 Mdot
.44629 .19076 Mdot
.25664 .60595 Mdot
.34231 .6398 Mdot
.7473 .39107 Mdot
.74702 .27447 Mdot
.73079 .43487 Mdot
.20357 .3727 Mdot
.68515 .27727 Mdot
.41493 .5581 Mdot
.51599 .67638 Mdot
.81318 .49372 Mdot
.79938 .32081 Mdot
.81794 .4902 Mdot
.72394 .49486 Mdot
.30541 .32153 Mdot
.54447 .26461 Mdot
.24995 .60933 Mdot
.31438 .39265 Mdot
.79675 .40682 Mdot
.46591 .47424 Mdot
.55627 .26047 Mdot
.69022 .41738 Mdot
.60251 .61273 Mdot
.27338 .67935 Mdot
.65868 .64279 Mdot
.41051 .63117 Mdot
.57625 .68157 Mdot
.64873 .52405 Mdot
.71777 .49153 Mdot
.32452 .59357 Mdot
.36469 .36161 Mdot
.31686 .26797 Mdot
.73995 .58139 Mdot
.54057 .6064 Mdot
.46353 .26603 Mdot
.67821 .50776 Mdot
.7188 .68702 Mdot
.32855 .40397 Mdot
.83794 .47023 Mdot
.74991 .70099 Mdot
.7435 .5994 Mdot
.29433 .58755 Mdot
.32869 .27182 Mdot
.56965 .42841 Mdot
.53237 .3569 Mdot
.72471 .28806 Mdot
.4771 .40038 Mdot
.30612 .58959 Mdot
.56649 .69398 Mdot
.47607 .19736 Mdot
.42791 .5831 Mdot
.79293 .57697 Mdot
.31314 .74529 Mdot
.55689 .41706 Mdot
.71732 .60336 Mdot
.64903 .58513 Mdot
.47845 .83831 Mdot
.66385 .35723 Mdot
.5516 .54746 Mdot
.68693 .25378 Mdot
.51792 .30907 Mdot
.7095 .56468 Mdot
.34753 .6447 Mdot
.2326 .41882 Mdot
.57379 .66049 Mdot
.47391 .28738 Mdot
.66381 .61931 Mdot
.48111 .36799 Mdot
.70413 .26077 Mdot
.62827 .19436 Mdot
.13945 .54509 Mdot
.63063 .57765 Mdot
.44573 .22505 Mdot
.43876 .22712 Mdot
.71637 .5849 Mdot
.73452 .57047 Mdot
.49387 .74236 Mdot
.7888 .32911 Mdot
.45026 .46547 Mdot
.6484 .31613 Mdot
.52384 .41289 Mdot
.21782 .40974 Mdot
.45517 .20143 Mdot
.26805 .6295 Mdot
.62478 .22202 Mdot
.63042 .63754 Mdot
.26742 .28008 Mdot
.45042 .69977 Mdot
.40769 .7759 Mdot
.24966 .60919 Mdot
.38311 .70468 Mdot
.56837 .77731 Mdot
.76616 .36741 Mdot
.52257 .64014 Mdot
.71789 .23184 Mdot
.76785 .42063 Mdot
.51691 .50229 Mdot
.41498 .3562 Mdot
.51067 .62593 Mdot
.43466 .60094 Mdot
.76947 .57863 Mdot
.78724 .52506 Mdot
.33923 .21565 Mdot
.31319 .6626 Mdot
.44104 .54507 Mdot
.55752 .70987 Mdot
.6074 .8181 Mdot
.48405 .24716 Mdot
.77458 .34248 Mdot
.48967 .46904 Mdot
.67305 .78223 Mdot
.63659 .2745 Mdot
.63472 .33806 Mdot
.67819 .26618 Mdot
.54906 .15968 Mdot
.53877 .57101 Mdot
.77265 .50163 Mdot
.41998 .2135 Mdot
.45362 .6072 Mdot
.73362 .47848 Mdot
.68885 .26075 Mdot
.17463 .51677 Mdot
.55848 .52293 Mdot
.79264 .30524 Mdot
.395 .64758 Mdot
.76961 .48608 Mdot
.44975 .16895 Mdot
.18072 .35496 Mdot
.64183 .35107 Mdot
.62544 .16916 Mdot
.62979 .32381 Mdot
.67368 .24314 Mdot
.5223 .33003 Mdot
.46332 .43676 Mdot
.75059 .65435 Mdot
.79373 .33596 Mdot
.24965 .43197 Mdot
.54935 .21434 Mdot
.77065 .62289 Mdot
.78615 .31808 Mdot
.38674 .65066 Mdot
.47896 .83372 Mdot
.39116 .41831 Mdot
.68153 .7864 Mdot
.71934 .72641 Mdot
.64574 .60925 Mdot
.33256 .63291 Mdot
.47315 .82485 Mdot
.37576 .7924 Mdot
.71284 .72768 Mdot
.36122 .66618 Mdot
.77863 .53956 Mdot
.28545 .5853 Mdot
.80277 .41258 Mdot
.53517 .83081 Mdot
.45262 .21087 Mdot
.65873 .41578 Mdot
.61185 .42822 Mdot
.79181 .53287 Mdot
.72642 .35109 Mdot
.47077 .25492 Mdot
.59404 .42343 Mdot
.63948 .61435 Mdot
.15584 .6556 Mdot
.61934 .29494 Mdot
.54148 .69793 Mdot
.57434 .14599 Mdot
.78813 .41087 Mdot
.45279 .47545 Mdot
.55346 .78404 Mdot
.27663 .6927 Mdot
.38163 .44153 Mdot
.43834 .63732 Mdot
.78035 .31171 Mdot
.35362 .44583 Mdot
.65025 .19199 Mdot
.82128 .57694 Mdot
.60061 .65485 Mdot
.50451 .55559 Mdot
.35804 .32823 Mdot
.4132 .75185 Mdot
.36211 .67912 Mdot
.5759 .15535 Mdot
.41069 .77493 Mdot
.51654 .3947 Mdot
.47296 .35891 Mdot
.47913 .31863 Mdot
.54131 .55498 Mdot
.65847 .79569 Mdot
.77942 .5275 Mdot
.28841 .65215 Mdot
.71615 .38619 Mdot
.33174 .60896 Mdot
.5327 .73621 Mdot
.24738 .5981 Mdot
.48321 .50819 Mdot
.24919 .49814 Mdot
.40058 .36336 Mdot
.5439 .18206 Mdot
.72902 .3089 Mdot
.78069 .65967 Mdot
.20839 .36812 Mdot
.75367 .47226 Mdot
.35194 .70039 Mdot
.50451 .20482 Mdot
.5486 .51369 Mdot
.24579 .45098 Mdot
.29455 .68721 Mdot
.51152 .7431 Mdot
.77211 .35642 Mdot
.41957 .73307 Mdot
.8268 .41842 Mdot
.2701 .60665 Mdot
.50428 .17851 Mdot
.44076 .42381 Mdot
.66902 .73395 Mdot
.58013 .72088 Mdot
.24027 .331 Mdot
.55394 .41763 Mdot
.52957 .12046 Mdot
.71624 .554 Mdot
.69149 .21295 Mdot
.55636 .28112 Mdot
.16304 .56577 Mdot
.78175 .38258 Mdot
.51767 .47968 Mdot
.50844 .43455 Mdot
.79538 .58431 Mdot
.72473 .43468 Mdot
.7391 .43626 Mdot
.41547 .52269 Mdot
.33523 .37719 Mdot
.52264 .38588 Mdot
.65285 .31508 Mdot
.55365 .19325 Mdot
.44038 .6653 Mdot
.33061 .43368 Mdot
.38409 .71888 Mdot
.54893 .35943 Mdot
.79841 .47862 Mdot
.75452 .33986 Mdot
.49678 .7231 Mdot
.33244 .58606 Mdot
.54234 .15197 Mdot
.80064 .43334 Mdot
.41308 .51292 Mdot
.39173 .58571 Mdot
.59271 .31473 Mdot
.35474 .22597 Mdot
.62792 .20901 Mdot
.47692 .33982 Mdot
.58035 .43082 Mdot
.28813 .59901 Mdot
.79809 .29506 Mdot
.54837 .13487 Mdot
.2337 .32004 Mdot
.52289 .41014 Mdot
.62838 .58695 Mdot
.28559 .70784 Mdot
.50763 .17937 Mdot
.69517 .77758 Mdot
.74887 .40934 Mdot
.33465 .61359 Mdot
.17607 .49293 Mdot
.44026 .80525 Mdot
.49939 .39054 Mdot
.58113 .72131 Mdot
.72021 .6957 Mdot
.58532 .28111 Mdot
.38189 .44551 Mdot
.49426 .41213 Mdot
.58766 .26651 Mdot
.77901 .53764 Mdot
.72371 .43805 Mdot
.50176 .1775 Mdot
.42326 .78253 Mdot
.39037 .58904 Mdot
.54573 .20477 Mdot
.68119 .51233 Mdot
.43618 .22308 Mdot
.34031 .25525 Mdot
.50126 .4026 Mdot
.35539 .41478 Mdot
.5423 .68263 Mdot
.57004 .40229 Mdot
.63118 .3052 Mdot
.18211 .45303 Mdot
.30636 .534 Mdot
.69314 .59872 Mdot
.45399 .8107 Mdot
.63622 .58511 Mdot
.83369 .36304 Mdot
.6593 .32789 Mdot
.56732 .69749 Mdot
.62529 .25843 Mdot
.40093 .27147 Mdot
.17941 .4049 Mdot
.63507 .61772 Mdot
.2612 .55392 Mdot
.66096 .60004 Mdot
.64502 .52875 Mdot
.63265 .25124 Mdot
.65133 .46826 Mdot
.60357 .63276 Mdot
.5767 .8257 Mdot
.32608 .27352 Mdot
.65457 .5926 Mdot
.47032 .36706 Mdot
.71187 .51536 Mdot
.84102 .43172 Mdot
.35388 .41127 Mdot
.54211 .1247 Mdot
.40732 .58078 Mdot
.34542 .2283 Mdot
.80759 .48654 Mdot
.58366 .46287 Mdot
.52366 .40454 Mdot
.35413 .27545 Mdot
.44799 .57279 Mdot
.44993 .54277 Mdot
.65674 .57667 Mdot
.45998 .18468 Mdot
.30534 .48886 Mdot
.33228 .56414 Mdot
.51921 .3495 Mdot
.57855 .80517 Mdot
.69714 .76372 Mdot
.64511 .52666 Mdot
.45635 .37903 Mdot
.42994 .2368 Mdot
.3854 .66381 Mdot
.3825 .71307 Mdot
.5499 .17715 Mdot
.61846 .62191 Mdot
.71463 .55219 Mdot
.23112 .32753 Mdot
.36486 .54828 Mdot
.83492 .49317 Mdot
.44884 .70878 Mdot
.4057 .74454 Mdot
.394 .71653 Mdot
.7857 .56331 Mdot
.53213 .73434 Mdot
.7888 .36955 Mdot
.31114 .58523 Mdot
.3803 .52539 Mdot
.34365 .6375 Mdot
.49825 .72365 Mdot
.48767 .35621 Mdot
.65575 .80342 Mdot
.17554 .4862 Mdot
.60704 .73364 Mdot
.57254 .52387 Mdot
.71485 .60726 Mdot
.61583 .81513 Mdot
.70761 .59517 Mdot
.32684 .51823 Mdot
.69296 .64304 Mdot
.78154 .38473 Mdot
.82364 .44661 Mdot
.78096 .428 Mdot
.41384 .75436 Mdot
.48067 .32021 Mdot
.32925 .7303 Mdot
.38134 .61352 Mdot
.52756 .4733 Mdot
.48177 .56965 Mdot
.46747 .54456 Mdot
.45843 .48594 Mdot
.78629 .5985 Mdot
.52837 .55683 Mdot
.78664 .33204 Mdot
.83106 .48888 Mdot
.73665 .27492 Mdot
.46566 .29123 Mdot
.63125 .56738 Mdot
.57185 .13983 Mdot
.45832 .78794 Mdot
.8032 .41948 Mdot
.70817 .73762 Mdot
.49401 .84411 Mdot
.45979 .16476 Mdot
.75921 .3771 Mdot
.59812 .56687 Mdot
.80698 .63088 Mdot
.76669 .4455 Mdot
.48352 .83267 Mdot
.50616 .74332 Mdot
.80358 .48565 Mdot
.51593 .1246 Mdot
.64147 .78156 Mdot
.74014 .44414 Mdot
.57376 .72595 Mdot
.53092 .72019 Mdot
.5483 .82309 Mdot
.43712 .59236 Mdot
.34734 .41909 Mdot
.24517 .36433 Mdot
.32988 .62529 Mdot
.51364 .71644 Mdot
.53347 .82439 Mdot
.36328 .68395 Mdot
.34442 .69623 Mdot
.3457 .27468 Mdot
.46357 .16602 Mdot
.55662 .70045 Mdot
.53507 .68204 Mdot
.72403 .5869 Mdot
.2761 .52195 Mdot
.30546 .67918 Mdot
.50262 .62884 Mdot
.54043 .43721 Mdot
.55641 .59394 Mdot
.75828 .27592 Mdot
.22983 .40199 Mdot
.53791 .25401 Mdot
.63462 .57695 Mdot
.78893 .53862 Mdot
.50786 .23067 Mdot
.71322 .45374 Mdot
.51825 .82037 Mdot
.59013 .62283 Mdot
.69139 .24811 Mdot
.74081 .45587 Mdot
.28855 .62074 Mdot
.21676 .5507 Mdot
.54332 .34188 Mdot
.73324 .68274 Mdot
.57001 .15816 Mdot
.74716 .48162 Mdot
.69074 .51759 Mdot
.72003 .3716 Mdot
.48765 .36021 Mdot
.7574 .50046 Mdot
.72793 .42999 Mdot
.47078 .20947 Mdot
.60066 .67555 Mdot
.62378 .19567 Mdot
.33658 .34521 Mdot
.31406 .63612 Mdot
.68219 .3603 Mdot
.54721 .82587 Mdot
.38824 .66835 Mdot
.8127 .38961 Mdot
.51652 .47246 Mdot
.34111 .53523 Mdot
.4952 .66331 Mdot
.45654 .78007 Mdot
.78067 .56656 Mdot
.70806 .37849 Mdot
.4792 .53271 Mdot
.64444 .52066 Mdot
.75919 .69505 Mdot
.41447 .36469 Mdot
.39076 .42613 Mdot
.38445 .76306 Mdot
.71781 .49898 Mdot
.34484 .50079 Mdot
.64253 .39923 Mdot
.39901 .60113 Mdot
.21982 .5228 Mdot
.47398 .31095 Mdot
.74177 .67346 Mdot
.677 .76077 Mdot
.54877 .18157 Mdot
.476 .27479 Mdot
.76708 .6914 Mdot
.74472 .68333 Mdot
.79671 .51121 Mdot
.44393 .79958 Mdot
.59128 .55298 Mdot
.53514 .61281 Mdot
.32718 .51759 Mdot
.71819 .57429 Mdot
.56348 .1896 Mdot
.40694 .54908 Mdot
.33312 .53643 Mdot
.51077 .49105 Mdot
.47579 .24125 Mdot
.41653 .44242 Mdot
.79457 .47334 Mdot
.80697 .63153 Mdot
.32347 .59287 Mdot
.5294 .34478 Mdot
.6343 .31298 Mdot
.54997 .52393 Mdot
.79862 .35884 Mdot
.44702 .49547 Mdot
.75288 .59193 Mdot
.64871 .41801 Mdot
.70227 .69368 Mdot
.81872 .53418 Mdot
.34611 .56344 Mdot
.53611 .47031 Mdot
.74416 .58664 Mdot
.59391 .52584 Mdot
.63919 .45529 Mdot
.25748 .37525 Mdot
.44868 .78795 Mdot
.57909 .23453 Mdot
.55411 .3774 Mdot
.39565 .6291 Mdot
.28929 .71126 Mdot
.60964 .19529 Mdot
.43906 .48136 Mdot
.50842 .47417 Mdot
.41573 .21663 Mdot
.35577 .44773 Mdot
.13217 .57305 Mdot
.73619 .24915 Mdot
.49646 .66168 Mdot
.49498 .43252 Mdot
.33963 .5609 Mdot
.35926 .34366 Mdot
.65615 .63919 Mdot
.55797 .18176 Mdot
.52509 .31601 Mdot
.32802 .29131 Mdot
.6356 .3973 Mdot
.79301 .58918 Mdot
.26519 .2929 Mdot
.56354 .26187 Mdot
.8316 .35689 Mdot
.74419 .40968 Mdot
.76421 .53757 Mdot
.13301 .59962 Mdot
.78232 .59047 Mdot
.37312 .61383 Mdot
.31769 .30984 Mdot
.75999 .28323 Mdot
.52789 .4063 Mdot
.30458 .32804 Mdot
.6569 .77165 Mdot
.31864 .59102 Mdot
.31334 .65359 Mdot
.6651 .41557 Mdot
.78029 .63656 Mdot
.45301 .83838 Mdot
.40252 .27008 Mdot
.18942 .37914 Mdot
.6029 .64144 Mdot
.64866 .20217 Mdot
.64264 .34906 Mdot
.18061 .5079 Mdot
.82198 .45064 Mdot
.35231 .62241 Mdot
.54691 .81516 Mdot
.23009 .44209 Mdot
.27587 .55925 Mdot
.2827 .71184 Mdot
.60155 .43173 Mdot
.62877 .62221 Mdot
.36818 .28317 Mdot
.50314 .53308 Mdot
.34281 .6276 Mdot
.70342 .7065 Mdot
.53393 .46972 Mdot
.5977 .16912 Mdot
.49764 .81104 Mdot
.29848 .59401 Mdot
.38782 .23146 Mdot
.29228 .55553 Mdot
.57823 .19712 Mdot
.51603 .2423 Mdot
.3675 .63027 Mdot
.41528 .16709 Mdot
.61596 .16321 Mdot
.59196 .54995 Mdot
.43114 .6069 Mdot
.8396 .49538 Mdot
.38127 .48434 Mdot
.68745 .75108 Mdot
.6915 .39811 Mdot
.31673 .66827 Mdot
.54938 .57545 Mdot
.52326 .59283 Mdot
.35044 .75017 Mdot
.60069 .57586 Mdot
.7088 .70314 Mdot
.29575 .2743 Mdot
.299 .58981 Mdot
.50768 .80546 Mdot
.27477 .27522 Mdot
.44946 .71032 Mdot
.66406 .52568 Mdot
.75892 .2799 Mdot
.72081 .62438 Mdot
.39242 .57438 Mdot
.57424 .70275 Mdot
.4321 .50177 Mdot
.26585 .44972 Mdot
.39066 .59074 Mdot
.56811 .42757 Mdot
.33082 .63375 Mdot
.51504 .18483 Mdot
.75709 .64387 Mdot
.52164 .1147 Mdot
.81776 .4961 Mdot
.64192 .5891 Mdot
.66491 .76135 Mdot
.49583 .40087 Mdot
.72424 .26448 Mdot
.37115 .27315 Mdot
.33242 .26663 Mdot
.42358 .82043 Mdot
.29052 .56323 Mdot
.50802 .67212 Mdot
.60643 .42796 Mdot
.82637 .43539 Mdot
.43913 .82398 Mdot
.82545 .4169 Mdot
.51751 .55683 Mdot
.52642 .6653 Mdot
.15599 .38748 Mdot
.68689 .25034 Mdot
.4565 .56092 Mdot
.56789 .55787 Mdot
.54825 .55179 Mdot
.46506 .67399 Mdot
.64656 .47077 Mdot
.27574 .66436 Mdot
.32163 .66156 Mdot
.78625 .32758 Mdot
.66536 .5911 Mdot
.53391 .41055 Mdot
.57727 .30357 Mdot
.52535 .4298 Mdot
.50119 .71544 Mdot
.51945 .30807 Mdot
.33191 .67175 Mdot
.39633 .47228 Mdot
.29752 .4333 Mdot
.59728 .60655 Mdot
.59407 .44516 Mdot
.61724 .60698 Mdot
.3789 .73421 Mdot
.67573 .47633 Mdot
.3722 .79165 Mdot
.36214 .68329 Mdot
.36888 .64808 Mdot
.7881 .46998 Mdot
.64951 .823 Mdot
.545 .41257 Mdot
.68349 .48628 Mdot
.40404 .67414 Mdot
.48486 .77181 Mdot
.58759 .68599 Mdot
.28632 .45805 Mdot
.65407 .45402 Mdot
.50654 .55183 Mdot
.74408 .5969 Mdot
.52797 .27893 Mdot
.79631 .29944 Mdot
.53781 .60457 Mdot
.63946 .65051 Mdot
.79926 .37534 Mdot
.44241 .21619 Mdot
.50577 .74093 Mdot
.48704 .57143 Mdot
.39056 .513 Mdot
.39201 .47442 Mdot
.74309 .54577 Mdot
.45503 .19791 Mdot
.66062 .22123 Mdot
.3933 .75873 Mdot
.62131 .65015 Mdot
.45908 .61553 Mdot
.33013 .49391 Mdot
.55984 .43526 Mdot
.19198 .48466 Mdot
.35515 .47259 Mdot
.79276 .42866 Mdot
.36682 .71846 Mdot
.31269 .66256 Mdot
.55604 .74056 Mdot
.66934 .20272 Mdot
.56281 .52927 Mdot
.59561 .66044 Mdot
.48539 .50018 Mdot
.73192 .35592 Mdot
.36017 .66755 Mdot
.56963 .22903 Mdot
.50994 .54926 Mdot
.58635 .56917 Mdot
.83 .38 Mdot
.64716 .61975 Mdot
.50293 .33013 Mdot
.77342 .35619 Mdot
.45815 .79431 Mdot
.50761 .43568 Mdot
.13783 .62232 Mdot
.36708 .27068 Mdot
.82228 .34439 Mdot
.49279 .19393 Mdot
.40131 .70539 Mdot
.7745 .53539 Mdot
.52385 .57807 Mdot
.36917 .3887 Mdot
.70198 .24615 Mdot
.73406 .59427 Mdot
.59835 .54175 Mdot
.42171 .61626 Mdot
.41947 .47852 Mdot
.7437 .55551 Mdot
.56692 .22116 Mdot
.33267 .3998 Mdot
.4172 .51067 Mdot
.55597 .21907 Mdot
.39092 .47441 Mdot
.5174 .84867 Mdot
.57832 .15513 Mdot
.72903 .29247 Mdot
.4743 .32235 Mdot
.14958 .54431 Mdot
.66757 .60446 Mdot
.73416 .55534 Mdot
.5086 .31537 Mdot
.3355 .73786 Mdot
.75236 .49172 Mdot
.50434 .18318 Mdot
.80164 .53801 Mdot
.38733 .66814 Mdot
.17359 .6897 Mdot
.35075 .63522 Mdot
.41924 .49235 Mdot
.73713 .48864 Mdot
.7953 .34409 Mdot
.30636 .30751 Mdot
.81596 .57931 Mdot
.65497 .3449 Mdot
.50757 .71721 Mdot
.3279 .7541 Mdot
.23562 .32516 Mdot
.46956 .35069 Mdot
.18635 .38346 Mdot
.66705 .24807 Mdot
.27732 .65522 Mdot
.70081 .37615 Mdot
.62967 .57782 Mdot
.46861 .53983 Mdot
.66159 .32148 Mdot
.59051 .53207 Mdot
.75877 .55354 Mdot
.65698 .22375 Mdot
.23083 .60443 Mdot
.38243 .22192 Mdot
.72543 .2759 Mdot
.55022 .36054 Mdot
.64678 .60765 Mdot
.3626 .6918 Mdot
.33987 .45675 Mdot
.37022 .34722 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o
0000XOooool001cooooo00?o0000ooooooooool0Xoooool2o`000003ooooool0003o000000;o0000
Woooool001cooooo00?o0000ooooooooool0Xoooool2o`0000?ooooo1?l0002Mooooo`007?ooool0
0ol0003oooooooooo`2Tooooo`;o00000_ooool6o`0009_ooooo000Looooo`03o`000?oooooooooo
0:3ooooo0_l00002ooooo`;o00001_ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo0:3o
oooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`2^ooooo`Co00000_ooool2o`0009?ooooo
000Looooo`03o`000?oooooooooo0:gooooo1Ol00002ooooo`;o0000Toooool001cooooo00?o0000
ooooooooool0[Oooool2o`0000Oooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2Xoooo
o`;o00003?ooool2o`0000;ooooo0ol0002<ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o
00003Oooool2o`000004ooooool0003o0000o`0008cooooo000Looooo`03o`000?oooooooooo0;Oo
oooo0_l0002@ooooo`007?ooool2o`000:gooooo0_l0002Kooooo`007?ooool00ol0003ooooooooo
o`2Yooooo`;o000000?oooooo`000?l000002Oooool3o`0000Kooooo0_l00027ooooo`007?ooool0
0ol0003oooooooooo`2:ooooo`;o00000_ooool2o`0001Wooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo1Ol00006ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0NOooool2
o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2o`000003ooooool0003o
000000Cooooo0_l0000=ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0NOooool2o`00
01Kooooo1?l0000_ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0Poooool2o`0000Wo
oooo0_l00002ooooo`?o00001Oooool2o`0002;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
0000P?ooool001cooooo00?o0000ooooooooool0Poooool2o`0000?ooooo0_l00004ooooo`;o0000
0oooool2o`0000Gooooo0_l0000Rooooo`;o00001_ooool3o`00083ooooo000Looooo`03o`000?oo
oooooooo08Sooooo0_l000000ooooooo0000o`00000>ooooo`;o0000:Oooool2o`00087ooooo000L
ooooo`03o`000?oooooooooo08_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool6
o`0000kooooo1?l0002Fooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00000_ooool4o`00
00Oooooo1_l0000<ooooo`Co00003oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo083o
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?l0000:ooooo`Ko00003oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo
083ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l0000<
ooooo`;o00000_ooool2o`0000Oooooo1_l0000Dooooo`;o00002?ooool2o`0007Kooooo000Loooo
o`03o`000?oooooooooo08gooooo0ol000001?oooooo0000o`000?l00003ooooo`;o00002oooool2
o`0000_ooooo1?l0000Booooo`;o00002?ooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1looooo`;o00002ooo
ool2o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0000Kooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000006Oooool3o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1looooo`;o
00002oooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000003oooool2o`00013o
oooo0_l00003ooooo`?o00001?ooool3o`0007Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1iooooo`;o0000
5Oooool4o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000gooooo0_l00008ooooo`;o0000
0oooool3o`0007oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`0007Wooooo0_l0000Eooooo`Co00000oooool2o`00013ooooo0_l0
0004ooooo`;o00001oooool2o`0001Gooooo0_l00005ooooo`;o0000LOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo073ooooo0_l0000Fooooo`;o00001_ooool2o`0000kooooo0_l0000<ooooo`Co00007Oooool2
o`0000Gooooo0_l0001aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool2o`0000Gooooo0_l00009oooo
o`Co00000_ooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Gooooo0_l00002ooooo`Co00005_ooool2o`0007oooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l0
0009ooooo`Go00002?ooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo1?l00004ooooo`;o00005_ooool2o`0007oooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07;o
oooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000Go
oooo0_l0000:ooooo`;o00001Oooool2o`0002Gooooo0_l00005ooooo`;o0000J_ooool001cooooo
00?o0000ooooooooool0J_ooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool4o`0000?ooooo
1?l00003ooooo`?o00001?ooool2o`0001Gooooo0_l0000Uooooo`;o00001Oooool3o`0006Wooooo
000Looooo`03o`000?oooooooooo06[ooooo0_l0000?ooooo`;o00001_ooool2o`0000Kooooo0ol0
0004ooooo`;o00001?ooool2o`00013ooooo0_l000000ooooooo0000o`000007o`0001[ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0_l0001Yooooo`007?ooool00ol0003ooooooooo
o`1cooooo`;o00000oooool2o`00013ooooo1?l0000Looooo`;o000000?oooooo`000?l000001ol0
000Aooooo`;o00001oooool5o`000003ooooool0003o000000Oooooo0_l0001Xooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo1Ol00004
ooooo`;o00007Oooool2o`0001?ooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo1?l00005
ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o0000
00;ooooo0_l0000Iooooo`Co00001?ooool2o`0000cooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0001;ooooo0_l00005ooooo`Co00001Oooool2o`0000Oooooo0_l0001Qoooo
o`007?ooool00ol0003oooooooooo`1Yooooo`;o000000?oooooo`000?l000003?ooool2o`00017o
oooo0_l0000:ooooo`Go00000oooool2o`00013ooooo1?l00002ooooo`;o00004_ooool2o`0000Go
oooo0_l0000?ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000Oooooo
0_l0000<ooooo`;o00001Oooool2o`0000Sooooo1Ol00004ooooo`;o00003oooool2o`0000?ooooo
0_l0000Hooooo`;o00004Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo073ooooo0ol0
000Eooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo1?l00006ooooo`?o00004ooo
ool2o`0001Cooooo0_l00002ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0L?ooool2
o`000003ooooool0003o000001gooooo0_l00003ooooo`Go00001oooool3o`0002Sooooo0_l00002
ooooo`;o00000oooool2o`00073ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000Boooo
o`;o00003_ooool2o`0000_ooooo0_l0000<ooooo`;o00007_ooool2o`0000?ooooo0_l00007oooo
o`;o00001?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000?ooooo`;o
00004?ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool3o`0000?ooooo0_l0000Looooo`;o
00001_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o0000G?ooool001cooooo
0_l0001`ooooo`?o00001?ooool2o`0001[ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00017ooooo0_l00009ooooo`;o
00001?ooool4o`0000;ooooo0_l00007ooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0
Joooool2o`0000;ooooo0ol0000Pooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Fooooo`;o00003oooool2o`0000Co
oooo0_l00007ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0Joooool4o`0000;ooooo
0_l0000Pooooo`Co00001?ooool2o`0000;ooooo0_l0000:ooooo`?o00000oooool2o`0000Gooooo
0_l0000=ooooo`;o00004_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0
0003ooooo`?o00000_ooool2o`0000Oooooo0_l0000Gooooo`;o00002_ooool2o`0000_ooooo0_l0
0002ooooo`?o00001Oooool2o`0000gooooo1?l0000<ooooo`;o00000oooool2o`0000?ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Wooooo`?o00000oooool2o`0000Gooooo0_l00004
ooooo`;o00006oooool2o`0000Wooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000003o`0000Gooooo0_l0000=ooooo`;o00003?ooool2o`0000?ooooo0_l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooooooo
06Oooooo1Ol00002ooooo`;o00000oooool3o`0000?ooooo0_l0000Hooooo`;o00000_ooool2o`00
00Wooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00002ooooo`Co00000oooool5o`00
01cooooo1?l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo06?ooooo0_l00003ooooo`So00000oooool3o`0000?ooooo0_l00004ooooo`;o
00004_ooool2o`0000Kooooo0_l0000>ooooo`[o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000=ooooo`;o00003Oooool4o`0000Sooooo0_l00007ooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0Hoooool2o`000003ooooool0003o000000Ko00001_ooool3o`0000Oooooo
0ol000000ooooooo0000o`00000Gooooo`;o00002oooool2o`000003ooooool0003o000000_o0000
4_ooool2o`0001Cooooo0_l00003ooooo`;o00001oooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo05Kooooo1?l00002ooooo`;o00002?ooool3o`0000Cooooo1?l00003ooooo`?o00001ooo
ool2o`0000;ooooo0_l0000Cooooo`;o00001Oooool2o`0000Sooooo4Ol000000ooooooo0000o`00
000?ooooo`;o00004oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o00002?ooool2o`0000Gooooo1?l00003ooooo`;o00007Oooool2o`0000;ooooo0_l0
0005ooooo`;o00000oooool3o`000003ooooool0003o0000013o000000Coooooo`000?l0003ooooo
0_l0000:ooooo`Co00003_ooool2o`0000Cooooo0_l00004ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001Ooo
ool2o`00017ooooo0_l00005ooooo`;o00007Oooool2o`0000kooooo0ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000Wo00000oooool2o`000003ooooool0003o000000[ooooo1?l0
000>ooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`00053ooooo000L
ooooo`03o`000?oooooooooo05[ooooo0_l0000Hooooo`;o0000;?ooool3o`0000;ooooo4?l00003
ooooo`;o00003oooool2o`0001_ooooo1?l00007ooooo`;o00000_ooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo05Kooooo0_l0000Sooooo`;o00006Oooool2o`0000Kooooo0_l00002oooo
o`;o00000_oooolBo`00033ooooo1?l00007ooooo`;o00002?ooool2o`0004[ooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l0000?ooooo`;o00004_ooool4o`0001Gooooo1?l00006oooooaco
0000:_ooool2o`0000;ooooo1?l0000Aooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
D_ooool3o`0001;ooooo0_l0000Dooooo`;o00005Oooool2o`0000Wooooo6ol0000;ooooo`;o0000
7Oooool2o`0000?ooooo0ol00006ooooo`;o00002oooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo05;ooooo0ol0000Tooooo`;o00006Oooool2o`0000Oooooo0ol00004oooooaCo00003Ooo
ool2o`000003ooooool0003o000000;o00007Oooool3o`0000Cooooo1Ol0000:ooooo`;o0000B?oo
ool001cooooo0_l0001jooooo`;o00006Oooool2o`0000Oooooo0ol000001Ooooooo0000o`000?l0
003ooooo01Co00003oooool4o`0002Cooooo1Ol0000:ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0U?ooool2o`0000Cooooo0_l00005oooooa[o00003Oooool2o`0003Gooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00003Oooool3o`0003Sooooo0_l00007oooo
oaSo00003_ooool2o`00023ooooo1?l0000?ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0D?ooool2o`0000gooooo0ol000000ooooooo0000o`00000dooooo`;o00001_oooolDo`000003
ooooool0003o0000017ooooo0_l0000Nooooo`Oo00003_ooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l0000aooooo`;o000000?oooooo`000?l000001?oooolFo`000003oooo
ool0003o000000kooooo0_l00002ooooo`;o00007Oooool2o`0000;ooooo1?l00009ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0AOooool2o`0002cooooo1?l0000Oooooo`?o00001_oo
oolIo`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0ol0000Mooooo`;o00002Ooo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l000000ooooooo0000o`000008
ooooo`;o00007oooool4o`00023ooooo0ol00003ooooo`Oo000000?oooooo`000?l000004Ol00003
ooooo`Co00003?ooool2o`0000;ooooo0ol0000Jooooo`;o000000?oooooo`000?l000000oooool2
o`0000Kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_ooool2o`00
00Cooooo0_l0000;ooooo`;o00005Oooool2o`0001kooooo1?l00003ooooo`Oo000000?oooooo`00
0?l000004Ol00003ooooo`;o00002Oooool3o`0000;ooooo0_l00006ooooo`;o00004oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00017
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`000?l000004Oooool2o`00
01Cooooo0ol0000Nooooo`Co00001oooool3o`0000;ooooo4_l0000>ooooo`Go00002?ooool2o`00
01?ooooo0_l00003ooooo`Ko00000_ooool2o`000003ooooool0003o000000Kooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`17ooooo`Co00002?ooool2o`0000[ooooo0_l0000@ooooo`;o
00000_ooool2o`0000;ooooo0_l0000Iooooo`;o00000oooool2o`0000Wooooo5?l0000Aooooo`;o
00001oooool2o`0001Wooooo1_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Ko
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`0000Kooooo0_l00002ooooo`;o0000
5Oooool2o`0000?ooooo0_l00005ooooo`;o00000_oooolDo`0001[ooooo0_l0000Kooooo`;o0000
2oooool2o`0000Kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003ooo
ool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000001Ooo
ool3o`0001Cooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000001;o00005ooo
ool2o`00023ooooo1?l00008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0F?ooool2
o`000004ooooool0003o0000ooooo`;o00001?ooool4o`0000Wooooo1?l000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`?o00006?ooool2o`0000Sooooo0_l00002ooooo`co0000
00Coooooo`000?l0003o00004oooool2o`0000;ooooo0_l0000Oooooo`Go00002_ooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo05Kooooo1?l00005ooooo`;o00000oooool5o`0000Cooooo
0_l00004ooooo`ko00001?ooool2o`0000gooooo0_l000000ooooooo0000o`00000;ooooo`So0000
00?oooooo`000?l000001ol00004ooooo`;o00003_ooool2o`0001oooooo0_l00002ooooo`Co0000
1_ooool2o`0000?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00001?oo
ool2o`0000Oooooo0_l00006ooooo`;o00000_ooool;o`000003ooooool0003o000000Ko00001_oo
ool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o00000ooooolAo`0000Gooooo0_l0
000Dooooo`;o00006Oooool2o`0000Cooooo0_l00005ooooo`?o00001?ooool2o`0000Kooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00004oooool5o`0001;ooooo0_l00000
0ooooooo0000o`00000:o`000003ooooool0003o000000Oo000000?oooooo`000?l000007_ooool2
o`0000Oooooo3?l0000Looooo`?o00008Oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2
o`00043ooooo000Looooo`;o0000>_ooool2o`0000_ooooo0_l00006ooooo`Go00003Oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000Go`0001Cooooo0_l0000<ooooo`Co00001?ooool4o`00
0003ooooool0003o000000Oooooo0_l0000Booooo`;o00000_ooool2o`0001Cooooo0_l0000;oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Kooooo0_l00003ooooo`;o
00002oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Ao`000003ooooool0003o000001?o
oooo0_l0000:ooooo`Ko00001?ooool2o`0000?ooooo0_l00007ooooo`;o00004_ooool2o`0001So
oooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002Oooool2o`0000oooooo
0_l000001?oooooo0000o`000?l0000;ooooo`Oo000000?oooooo`000?l000004Ol000001?oooooo
0000o`000?ooool2o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo1?l00006oooo
o`;o00006?ooool2o`0001Wooooo1?l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l00005oooo
o`;o0000?Oooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l0000Booooo`?o
00002oooool2o`0000Gooooo5_l00002ooooo`;o00003oooool4o`0000?ooooo0_l00004ooooo`;o
00001?ooool4o`0000Cooooo0_l00002ooooo`;o00005_ooool2o`0000?ooooo0_l00002ooooo`;o
00005?ooool2o`0000_ooooo0_l00004ooooo`Go000000?oooooo`000?l000001Oooool2o`0003go
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo
5_l0000Cooooo`Co00000oooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2o`0001Cooooo
1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`00027ooooo0_l000000ooooooo0000
o`000009ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l0
000FoooooaSo00000_ooool2o`0000oooooo0_l00004ooooo`;o00003?ooool4o`0000;ooooo0ol0
0004ooooo`;o00005_ooool2o`0000Wooooo1?l0000Mooooo`;o00000oooool2o`0000_ooooo0_l0
000looooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002_ooool2o`0001[ooooo6Ol00002
ooooo`;o00003oooool3o`0000;ooooo1Ol0000:ooooo`Co00000_ooool2o`0000Kooooo0_l0000P
ooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo043ooooo0_l0000Qooooo`;o00000_oooolJo`0001Cooooo0_l00002oooo
o`Go00000oooool2o`0000Cooooo0ol000000ooooooo0000o`000009ooooo`?o00006_ooool2o`00
00?ooooo0_l0000<ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003_ooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`;o00002oooool2o`00017o
oooo0_l00002oooooaWo00005?ooool2o`0000?ooooo1?l00004ooooo`;o00001?ooool3o`000004
ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`00000Jooooo`;o00001oooool2o`00
00Sooooo0_l0000Dooooo`;o00000_ooool2o`0000[ooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o00004Oooool2o`0000;o
oooo6_l0000Cooooo`;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000;o
oooo0_l00002ooooo`;o00009_ooool3o`000003ooooool0003o000000;o00003?ooool2o`000003
ooooool0003o000000_ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
3oooool2o`0001Kooooo0_l00002oooooa[o00003oooool2o`0000;ooooo0_l00003ooooo`?o0000
0oooool3o`000003ooooool0003o000000_ooooo0_l0000Zooooo`?o000000?oooooo`000?l00000
0_l0000<ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`0iooooo`?o00003oooool2o`0001_ooooo6Ol0000?ooooo`;o00000_oo
ool2o`0000;ooooo1Ol00003ooooo`;o00002Oooool2o`0003Cooooo0_l00004ooooo`;o00004Ooo
ool2o`0000Kooooo0_l00006ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0;oooool2
o`0000Sooooo0_l0000^oooooaSo00004?ooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000001?ooool2o`0000?ooooo0_l00003ooooo`;o0000=?ooool2o`0000;ooooo1?l0000<
ooooo`;o00000oooool2o`0004gooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000:oooo
o`;o00008oooool2o`0000Gooooo6_l00002ooooo`;o00003?ooool4o`000003ooooool0003o0000
00Kooooo1Ol00003ooooo`;o0000?Oooool2o`0000kooooo0_l0000:ooooo`;o000000?oooooo`00
0?l00000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo0_l0000Sooooo`Go00000_oooolA
o`000003ooooool0003o000000Ko00000_ooool2o`0000cooooo1?l00002ooooo`;o00001Oooool4
o`0001Sooooo0ol000000ooooooo0000o`000002ooooo`;o00009_ooool2o`0000?ooooo0_l0000<
ooooo`;o00000_ooool2o`000003ooooool0003o000004?ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?oo
ool2o`0001cooooo0ol00003oooooaSo00004oooool2o`0000;ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000000_l0000?ooooo`?o000000?oooooo`000?l000001?l0000Hooooo`;o00003?oo
ool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0004Gooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo04?ooooo0ol0000R
oooooaSo00004?ooool2o`000004ooooool0003o0000o`0000kooooo2?l0000Dooooo`?o00002?oo
ool4o`0000gooooo0ol0000;ooooo`;o00005_ooool2o`0004Gooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004?ooooo0_l0
0002ooooo`;o00007?ooool2o`000003ooooool0003o000001Ko00004?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`Co00001?ooool3o`0000;ooooo0_l00009ooooo`;o00003ooo
ool2o`0000?ooooo1?l0000>ooooo`;o00002oooool2o`00013ooooo0_l0001;ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0=oooool2o`0000kooooo0_l0000Loooooa[o00005?ooool2o`0000;ooooo0_l0
0004ooooo`Co00001?ooool5o`0000Sooooo1Ol0000?ooooo`;o0000=?ooool2o`0004_ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`0gooooo`;o0000;_oooolHo`0001Cooooo0_l00009ooooo`Oo000000?ooooo
o`000?l000000_l00008ooooo`?o00001?ooool4o`0000?ooooo0_l0000Kooooo`;o00004?ooool2
o`0000[ooooo1_l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0@oooool2o`0002;ooooo0_l000000ooooooo0000o`00
000Co`0001?ooooo0_l00009ooooo`?o000000?oooooo`000?l000001Ol00002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Gooooo1Ol00003ooooo`;o00006oooool2o`0000Oooooo0_l0
0006ooooo`?o00002_ooool8o`0000Oooooo0_l0000mooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0@oooool2o`0002;ooooo
0_l000000ooooooo0000o`00000:o`0000;ooooo1ol0000Booooo`?o00002Oooool2o`0000Gooooo
1?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Gooooo1?l0000:ooooo`?o
00002oooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool3o`0000cooooo0_l00002ooooo`?o
00001oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000_ooooo`;o0000
00?oooooo`000?l000001ol000000ooooooo0000o`000003o`00013ooooo0_l00002ooooo`;o0000
2?ooool2o`0000;ooooo0_l00005ooooo`Go00001Oooool3o`0000;ooooo0ol000000ooooooo0000
o`000004ooooo`;o00001Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo
0_l000000ooooooo0000o`00000?ooooo`;o00002Oooool2o`0000kooooo1?l0000mooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000cooooo0_l0000Qooooo`oo000000?o
ooooo`000?l000004?ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo1?l0
0006ooooo`?o00000_ooool3o`0000Oooooo0_l0000<ooooo`Co000000?oooooo`000?l000000_l0
0003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo1?l00005ooooo`Co00001Ooo
ool3o`0003kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`00000<
ooooo`Co00006_ooool4o`000004ooooool0003o0000ooooo`ko00004Oooool2o`0000Cooooo0_l0
000?ooooo`;o00000_ooool3o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001ooo
ool3o`0000;ooooo1?l0000=ooooo`;o00001oooool2o`0000?ooooo1?l00008ooooo`Co00001Ooo
ool4o`0000[ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001_ooool2
o`0000cooooo0_l0000Looooo`Oo00000oooool5o`000003ooooool0003o000000Co000000?ooooo
o`000?l000003_ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o
000000;o00000oooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool4
o`000003ooooool0003o000000So00000oooool2o`00013ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000001oooool6o`0000Oooooo0_l00006ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000gooooo0_l0000Vooooo`;o00001Oooool4o`0000;ooooo0ol00004oooo
o`;o00004Oooool3o`0001Kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`?o00001Oooool@o`0000;ooooo0ol0000Cooooo`;o000000Coooooo`00
0?l0003ooooo1?l00007ooooo`Ko00001Oooool2o`0000Kooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0oooooo`;o00001oooool2o`0000?ooooo0_l0000>ooooo`;o00002Oooool4o`00
00;ooooo2?l0000Hooooo`Co00002oooool2o`0000Gooooo0_l000000ooooooo0000o`000003oooo
o`Go00001?ooool2o`0000;ooooo1Ol00002oooooa?o000000?oooooo`000?l000004oooool5o`00
0003ooooool0003o000000;o00002Oooool6o`0000_ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00000oooool2o`0000gooooo1Ol00007ooooo`Co00000_ooool9o`0001Oo
oooo1?l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00Gooooo1Ol000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003ooooo3Ol00002ooooo`;o00000_ooool2o`0000gooooo1_l0
00000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l0000jooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00007_ooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`?o00006?ooool3o`000003oooo
ool0003o000000Sooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000007o`000003ooooool0003o000000Co00002_oooolAo`0000;ooooo0_l0000<ooooo`[o0000
2_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000>oooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000cooooo0ol0000?ooooo`;o00001oooool5o`0000;ooooo0_l0
0007ooooo`;o00001?ooool2o`0000[ooooo0_l00009ooooo`?o00004_ooool3o`0000;ooooo0_l0
0004ooooo`Ko000000?oooooo`000?l000001?l00006ooooo`;o00000_ooool@o`00017ooooo0_l0
0003ooooo`Ko00002Oooool6o`0004Sooooo000Looooo`03o`000?oooooooooo04Oooooo0ol0000A
ooooo`;o00001Oooool5o`0000;ooooo0_l00004ooooo`Ko00000oooool2o`0000[ooooo0_l0000N
ooooo`?o00001?ooool2o`0000Cooooo0ol00002ooooo`Go00000_ooool2o`0000?ooooo0ol00002
ooooo`Go000000?oooooo`000?l000001_l0000Gooooo`Oo00000_ooool2o`0000Gooooo1?l0000=
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Kooooo1?l00004oooo
o`;o00000_ooool3o`000003ooooool0003o000000?ooooo0_l0000[ooooo`;o00001?ooool4o`00
0003ooooool0003o000000Co00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool5o`00
0005ooooool0003o0000o`000?ooool01?l0000Gooooo`Co000000?oooooo`000?l000000_ooool2
o`0000Cooooo1_l00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0003[ooooo000Loooo
o`;o0000COooool2o`0000Gooooo0_l00006ooooo`?o00001?ooool5o`0000?ooooo0ol00003oooo
o`?o00000oooool2o`0003;ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo0_l00009oooo
oa3o00005Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00
00Cooooo1Ol00002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=oooool2o`0000So
oooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0ol00004ooooo`?o00001Oooool2o`0000Go
oooo1?l000000ooooooo0000o`00000<ooooo`;o00009?ooool4o`0000;ooooo0ol00003ooooo`Ko
00002?ooool3o`000003ooooool0003o000000co00003_ooool2o`0000?ooooo0ol00005ooooo`?o
00004oooool3o`0003oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00008ooooo`;o0000
4?ooool2o`0000?ooooo0ol00003ooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`;o0000
3oooool2o`0000Wooooo0_l0000;ooooo`;o00003Oooool2o`0000?ooooo1ol000000ooooooo0000
o`000002o`0000Oooooo1?l00004ooooo`_o00000oooool2o`0000Kooooo1Ol00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Eooooo`;o0000?oooool001cooooo00?o0000ooooooooool0Aooo
ool2o`0000[ooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00001_oo
ool2o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`0000Wooooo0_l0000;ooooo`;o00001ooo
ool2o`0000?ooooo1?l00003ooooo`Ko000000Coooooo`000?l0003o00002?ooool2o`0000Oooooo
2Ol00004ooooo`;o00001_ooool5o`0000Oooooo0_l000000ooooooo0000o`00001Gooooo`007?oo
ool00ol0003oooooooooo`0Wooooo`;o00007?ooool4o`0000kooooo0_l00003ooooo`;o00001Ooo
ool3o`0000Gooooo0_l00002ooooo`;o00002oooool2o`0001?ooooo0_l0000Booooo`Wo000000?o
ooooo`000?l000002?l000000ooooooo0000o`00000<ooooo`;o00001Oooool3o`0000Oooooo0ol0
000>ooooo`;o00000_ooool4o`0005Oooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000<
ooooo`;o00003_ooool2o`0000Oooooo0_l0000@ooooo`;o00000_ooool5o`0000[ooooo0_l00003
ooooo`;o00000_ooool2o`00017ooooo1?l0000Doooooa;o000000?oooooo`000?l000003?ooool2
o`0000Kooooo1?l00005ooooo`?o00003_ooool8o`0005Oooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000Gooooo`;o00003oooool5o`000003ooooool0003o000000Co000000?oooooo`00
0?l000001Oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo1_l00008oooo
o`;o00003?ooool6o`0000?ooooo1Ol0000?ooooo`;o00001_ooool6o`0000Gooooo0_l0000Aoooo
o`Oo00002Oooool2o`000003ooooool0003o000000_ooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00008Oooool=o`000004ooooool0003o0000ooooo`;o00000_ooool5o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`Ko00000oooool3o`0000cooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo1Ol00006ooooo`Go00003oooool2o`0000Kooooo1?l00004
ooooo`Go00003oooool2o`0000Cooooo0ol00009ooooo`Go00002oooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo03Kooooo1?l0000=ooooo`;o00000oooool2o`0000Wooooo0_l00002oooo
o`go00002?ooool5o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o00000_ooool2o`00
00?ooooo1Ol00003ooooo`Co00002Oooool2o`000004ooooool0003o0000ooooo`Go00000oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000007?ooool5o`00013ooooo0_l00004
ooooo`?o00002Oooool4o`0004Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000?oooo
o`;o00000oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000002Ol00004oooo
o`;o00003?ooool3o`0000Oooooo0_l00003ooooo`Oo00000oooool4o`0000cooooo0_l00009oooo
o`;o00000oooool5o`0001;ooooo0_l00008ooooo`Go00000_ooool2o`0000[ooooo1?l000000ooo
oooo0000o`00000@ooooo`Ko0000A?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001oo
oooo1?l00002ooooo`co00001?ooool3o`0001Cooooo1Ol000000ooooooo0000o`000002o`0001Ko
oooo0_l00002ooooo`;o00002oooool4o`0001;ooooo1?l0000<ooooo`?o00001Oooool3o`0000;o
oooo2Ol0000>ooooo`Ko00000oooool2o`0003oooooo000Looooo`03o`000?oooooooooo02Cooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0001[ooooo4_l00005ooooo`;o0000
2?ooool2o`0000[ooooo1Ol00002ooooo`;o00001?ooool2o`0001Gooooo0_l00006ooooo`;o0000
0oooool5o`0001?ooooo0_l0000;ooooo`?o00001_ooool3o`0000Gooooo0ol000000ooooooo0000
o`000005ooooo`;o00000_ooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
?oooool001cooooo00?o0000ooooooooool09?ooool2o`0000Oooooo0_l00003ooooo`Go00001?oo
ool2o`0000cooooo0_l0000<ooooo`Oo000000Goooooo`000?l0003o0000ooooo`05o`0000Kooooo
0_l00003ooooo`;o00000oooool2o`0000;ooooo1ol000000ooooooo0000o`000002o`0000Wooooo
0_l0000Mooooo`Co00001?ooool2o`000003ooooool0003o000001?ooooo0_l00008ooooo`;o0000
2Oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool4o`0000?ooooo1Ol00002ooooo`Co0000
?Oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000Aooooo`;o00001Oooool2o`0000Gooooo4Ol00002ooooo`;o00001?ooool2o`000003ooooool0
003o000000;ooooo0_l00003ooooo`Oo000000?oooooo`000?l000001oooool3o`0001;ooooo0_l0
0005ooooo`;o00001Oooool4o`0000Oooooo0_l0000Cooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000Gooooo0_l00003ooooo`;o00004?ooool5o`0000;ooooo0_l000000ooooooo0000o`00
000jooooo`007?ooool00ol0003oooooooooo`0cooooo`Go00006?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Bo`0000?ooooo2_l00005ooooo`?o00000oooool2o`0000Oooooo0ol0000B
ooooo`;o00001Oooool2o`0000gooooo0_l00005ooooo`;o00004_ooool2o`00013ooooo1?l00008
ooooo`;o00001oooool2o`0000Sooooo1?l00003ooooo`Co0000>_ooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0000[ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000ooooolEo`00
00Gooooo0_l000000ooooooo0000o`000004o`0001Gooooo0_l0000Eooooo`;o00000oooool2o`00
00Sooooo0_l00003ooooo`;o00001Oooool2o`0002Kooooo0_l0000Aooooo`;o00001_ooool6o`00
00?ooooo1?l0000jooooo`007?ooool2o`0002[ooooo0_l0000Rooooo`;o000000Coooooo`000?l0
003ooooo0_l00002oooooa;o00000oooool2o`0000Sooooo0_l0000Aooooo`;o00002?ooool2o`00
00Gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002?ooool2o`00
01oooooo0_l0000?ooooo`;o00002oooool2o`0000?ooooo1?l00007ooooo`?o000000?oooooo`00
0?l00000@Oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Wooooo0_l000000ooooooo
0000o`00000Ao`0000?ooooo0_l0000Kooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o0000:Oooool3o`0000kooooo0_l0000;ooooo`?o
00000_ooool4o`0000Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o0000
3oooool2o`0000cooooo4ol0000hooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo
0ol00004ooooo`?o00001oooool4o`0000Sooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo
0_l0000Cooooo`;o00003Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000=ooooo`;o00003OoooolBo`0001gooooo0_l0000;ooooo`;o00001_ooool2o`0000Kooooo0_l0
0002ooooo`?o00002_ooool3o`0000Cooooo1Ol00005ooooo`Co00002?ooool5o`0000Gooooo0_l0
0003ooooo`;o00006_ooool4o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o00003?oooolBo`0000;ooooo0_l0000@ooooo`?o00001Oooool4o`0000[ooooo0ol00006
ooooo`;o00001_ooool2o`0000;ooooo0ol00004ooooo`Co00001?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Aooooo`Go00001Oooool2o`0000Cooooo0_l00005ooooo`;o00004_ooool4
o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Koooo
oaGo000000?oooooo`000?l000003oooool4o`0000Gooooo0_l0000<ooooo`;o00006_ooool4o`00
00Cooooo0_l0000Mooooo`?o00000oooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool4
o`0001Gooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o0000ooooooooool08_ooool2o`00
00Oooooo0_l00008ooooo`;o00006ooooolGo`00013ooooo0_l00007ooooo`;o00000_ooool2o`00
02Cooooo0_l00006ooooo`;o00002oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2
o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`?o000000Coooooo`000?l0003ooooo
1ol00004ooooo`;o00002Oooool2o`0000Cooooo0ol00009ooooo`;o0000??ooool001cooooo00?o
0000ooooooooool08_ooool2o`0000Oooooo0_l0000Gooooo`;o00003?oooolGo`0001Wooooo0ol0
00000ooooooo0000o`000002ooooo`;o00005?ooool2o`00013ooooo0_l0000=ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Ao`0000?ooooo1?l00007ooooo`;o00002Ooo
ool2o`0000Cooooo0ol00006ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000?ooooo0_l0000;oooooa;o00004?ooool2o`0000Sooooo0ol000000ooooooo0000o`000002
ooooo`;o000000Coooooo`000?l0003o00003_ooool4o`0000gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001?oooolFo`000003ooooool0
003o000001Oooooo0_l0000:ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0BOooool2
o`0000[ooooo4_l00004ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000cooooo0_l0
0005ooooo`?o00003_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l00009oooooa[o00002oooool2o`0000Gooooo0ol000000ooooooo0000o`00
001;ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00008?ooool2o`0000Oooooo3ol00003
ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Oooooo`;o00005Oooool6
o`0000Oooooo0ol00002ooooo`;o00002?oooolEo`000003ooooool0003o000000Ko00002?ooool2
o`0000Gooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`0Xooooo`?o00001_ooool2o`00
01Oooooo0_l00007ooooo`oo00002Oooool3o`0001Gooooo0_l0000:ooooo`;o00000oooool2o`00
00;ooooo0_l00006ooooo`;o00002?ooool4o`000003ooooool0003o000000;o00001_ooool6o`00
00;ooooo0_l00002ooooo`;o00000ooooolOo`0000Wooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0000Kooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l00003oooo
o`ko00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Eooooo`?o00002Oooool2
o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000002?ooool4o`0000?ooooo0_l00006
ooooo`?o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000001Oo000000?ooooo
o`000?l000000_l00004ooooo`;o00001?ooool;o`000004ooooool0003o0000o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo00?o0000ooooooooool0:Oooool2
o`0001Oooooo0_l0000;ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`Go00000ooo
ool2o`0000;ooooo0_l00002ooooo`?o00005Oooool2o`0000kooooo0_l00003ooooo`?o000000Co
ooooo`000?l0003o00001oooool2o`000004ooooool0003o0000o`0000?ooooo0ol0000<ooooo`;o
00001oooool2o`000003ooooool0003o000001Go00001?ooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Uooooo`Ko00000_ooool3o`0000kooooo
0_l0000Oooooo`;o00001?ooool2o`0000?ooooo0ol00002ooooo`;o00001oooool2o`0000;ooooo
0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
oooo5_l00002ooooo`?o00002oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0:_ooool2o`000003ooooool0003o000002Go
oooo1_l000000ooooooo0000o`00000_ooooo`Co00001?ooool2o`0000;ooooo0_l00009ooooo`?o
00002Oooool2o`0000Sooooo0_l0000<ooooo`Ko000000?oooooo`000?l000005?l00003ooooo`;o
00001Oooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0004Cooooo000Looooo`;o0000
:oooool2o`0001Oooooo0_l00003ooooo`Co00001Oooool3o`0000?ooooo0_l00002ooooo`;o0000
5_ooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool3o`0000Gooooo1_l00005ooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Oooooo
5?l000000ooooooo0000o`000006o`0000?ooooo0_l00005ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0:?ooool2o`0001Wooooo0_l00003ooooo`Co00000oooool5o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0_l00005ooooo`?o00000oooool2o`0000Gooooo1?l00007ooooo`Go00002_oo
ool3o`000003ooooool0003o000000Sooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000oo000000?oooooo`000?l000002_l0000;ooooo`?o00003oooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo02Kooooo1?l0000Iooooo`;o00001Oooool2o`0000?ooooo1ol00000
0ooooooo0000o`000005o`0000_ooooo0_l00005ooooo`Co00001Oooool2o`0000_ooooo1_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000Oooooo1?l000000ooooooo0000o`000004
o`0000;ooooo1ol00008ooooo`?o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000L
o`0000Cooooo1Ol00002ooooo`?o00003oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
02Kooooo0_l0000Rooooo`;o00001Oooool7o`000003ooooool0003o000000;o00003?ooool2o`00
00Oooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`00
00Gooooo0_l00003ooooo`;o00002?ooool3o`000003ooooool0003o000000Co00000_ooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006oooo
o`;o000000?oooooo`000?l000006?l000000ooooooo0000o`000004o`000003ooooool0003o0000
00?o00000oooool2o`00017ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00001?ooool2o`0001Kooooo0_l00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`04o`00
0003ooooool0003o000000kooooo1?l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00003oooo
o`;o00000oooool4o`0000Gooooo1Ol00002ooooo`Co00001_ooool2o`00017ooooo0_l00007oooo
o`;o00002OoooolSo`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`0[ooooo`Co00000_ooool2o`0001Kooooo0_l00002ooooo`Co
00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000004o`0000Oooooo1ol00003ooooo`;o
00006oooool=o`000003ooooool0003o000000;ooooo1Ol0000Pooooo`;o000000?oooooo`000?l0
00008Ol0000>ooooo`?o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02gooooo
0_l00002ooooo`;o00006_ooool4o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo1?l00007ooooo`Ko00007?ooool2o`0000?ooooo0_l00002ooooo`Wo000000?oooooo`000?l0
00000_ooool5o`0001Gooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000001oo
00004?ooool2o`0000Cooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Cooooo0_l0000@ooooo`;o00002_ooool2o`0000?ooooo0ol000000ooooooo
0000o`000004ooooo`[o00000oooool2o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`0000Ko
oooo8_l00002ooooo`?o00002?ooool2o`0000Sooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`0Wooooo`;o000000?oooooo`000?l000006?ooool2o`0000[ooooo0_l000001?oooooo0000
o`000?ooool4o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000kooooo1?l00006ooooo`?o
000000?oooooo`000?l000000_ooool7o`000003ooooool0003o000000;ooooo2Ol00003ooooo`;o
00000oooool2o`0000;ooooo0_l0000=ooooo`?o00001OoooolEo`000003ooooool0003o000000_o
000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool09oooool2o`000003ooooool0003o000001Sooooo0_l00007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00008Oooool3o`0000Cooooo0_l00002ooooo`?o
000000?oooooo`000?l000002?l00002ooooo`;o00000_ooool7o`000003ooooool0003o000000Ko
00001Oooool2o`0000gooooo0ol00005ooooo`;o000000?oooooo`000?l000007Ol00002ooooo`;o
00000oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool4o`00043ooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00003ooooo`Oo00005?ooool2o`000003ooooool0003o0000013ooooo
0_l00004ooooo`Co00001oooool6o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00000_ooool8o`0000?ooooo0_l0000?ooooo`;o00002Oooool3o`000003ooooool0003o000001Co
000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000;o
oooo1_l00005ooooo`Co0000@?ooool001cooooo00?o0000ooooooooool0A_ooool3o`0000;ooooo
0_l00002ooooo`?o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fooooo`Go0000
00?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`;o00001_oooolAo`000003oooo
ool0003o000000;o00002?ooool2o`0000Gooooo0_l00009ooooo`?o00000_oooolFo`000003oooo
ool0003o000000Go000000?oooooo`000?l000002oooool4o`000003ooooool0003o000000Cooooo
0_l00012ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00000oooool2o`0001[ooooo0_l0
0006ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o00004_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?ooool<o`000004ooooool0003o0000ooooo`?o00002Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000008ooooo`Go000000?oooooo`000?l000005?l000000ooooooo
0000o`000005o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool3o`0004Oo
oooo000Looooo`03o`000?oooooooooo02Kooooo0_l00003ooooo`;o00006_ooool2o`0000Cooooo
0_l0000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;o
oooo0_l00003ooooo`Co00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000;o
oooo1?l000000ooooooo0000o`000007o`000003ooooool0003o000000?o00000_ooool<o`0001?o
oooo0_l00004ooooo`?o00001?ooool9o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000?o
oooo1ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001oooool3o`000003
ooooool0003o000000;o00002Oooool2o`0003cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`15
ooooo`;o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`Ko00000oooool4
o`0000Kooooo0_l00002ooooo`;o00000_ooool5o`0000;ooooo3_l000000ooooooo0000o`000008
o`0000;ooooo2ol00005ooooo`;o00003_ooool3o`0000Oooooo2?l000000ooooooo0000o`000007
o`000003ooooool0003o000000Ko00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l0000;ooooo`?o0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo033ooooo
0_l0000Cooooo`?o00004Oooool2o`0000;ooooo0_l00004ooooo`Go00005ooooolEo`000003oooo
ool0003o000001Go00001Oooool2o`0000Wooooo0_l0000=ooooo`?o000000?oooooo`000?l00000
3?l000000ooooooo0000o`000006o`0000Gooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`00017ooooo0_l0000kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Xooooo`;o0000
1_ooool2o`0001Cooooo0_l00005ooooo`Ko00001_ooool3o`0000Oooooo1?l00006ooooo`?o0000
1Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000001co0000
00Coooooo`000?l0003o00004Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00007ooooo`?o00002Oooool2o`00
0003ooooool0003o000004_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000:?ooool2o`0002?ooooo1_l000000ooo
oooo0000o`000004ooooo`;o00002Oooool2o`0000Kooooo0ol00005ooooo`;o00001_ooool7o`00
00?ooooo9?l000000ooooooo0000o`000003o`0001?ooooo0_l00003ooooo`;o00002?ooool2o`00
00Sooooo0_l00006ooooo`;o00001Oooool4o`0000cooooo0_l0001;ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0Zooooo`;o00001?ooool2o`0001Gooooo1?l00004ooooo`?o00000_ooool2o`00
00oooooo0_l0000Fooooo`Ko00001?oooolZo`0000gooooo1?l00002ooooo`;o00000oooool3o`00
00Wooooo0ol00007ooooo`;o00001?ooool2o`0000Gooooo0_l0000Fooooo`;o00000_ooool2o`00
03oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0Rooooo`;o00001_ooool2o`0000Cooooo0_l0000Eooooo`Co
00000_ooool5o`0000;ooooo0_l0000Aooooo`Go00002Oooool2o`0000?ooooo0ol00003ooooo`;o
00001?oooolPo`0000?ooooo1Ol000000ooooooo0000o`00000=ooooo`Co00000oooool2o`0000;o
oooo0ol00002ooooo`;o00001Oooool3o`0000?ooooo0_l00002ooooo`;o00000oooool3o`0001go
oooo0_l00002ooooo`;o0000?oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo02;ooooo0_l0000Yooooo`Co00000_ooool2o`00
017ooooo1_l00009ooooo`;o00000oooool3o`0000Wooooo8Ol000000ooooooo0000o`000004o`00
01;ooooo0_l00003ooooo`;o00001oooool4o`0000Wooooo0_l00006ooooo`Co0000H_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo04oooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o000000?oooooo`000?l00000
2_ooool7o`000003ooooool0003o000000Kooooo1?l000000ooooooo0000o`00000Ro`0000Oooooo
1?l000000ooooooo0000o`000003ooooo`?o00002_ooool2o`0000;ooooo0_l0000<ooooo`;o0000
0oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004?ooool2o`000003ooooool0003o000000Oooooo2_l00005ooooob;o000000?o
ooooo`000?l000001Ol00005ooooo`Ko000000?oooooo`000?l000000_ooool3o`0000[ooooo0ol0
0002ooooo`;o00003?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04oooooo1?l00004
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l00008ooooo`Co000000?ooooo
o`000?l000001oooool3o`000003ooooool0003o000002Co00000_ooool2o`000005ooooool0003o
0000o`000?ooool00_l00004ooooo`?o00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o0000:oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0
000Vooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0000Sooooo:Ol000000ooooooo0000o`000006o`000003ooooool0
003o000000?ooooo0ol00006ooooo`;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l0
000@ooooo`;o00002oooool2o`0000;ooooo0_l00008ooooo`;o0000A_ooool001cooooo00?o0000
ooooooooool0:Oooool2o`0002Oooooo0_l0000Cooooo`Co000000Coooooo`000?l0003ooooo2?l0
00000ooooooo0000o`000002o`0000Oooooo:_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool3o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0001_ooooo0ol0000;ooooo`;o00000_oo
ool2o`0000Gooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00006_ooool3
o`0000?ooooo0_l00006ooooo`;o00001?ooool3o`0000;ooooo0ol00003ooooo`Go000000Cooooo
o`000?l0003o00000oooool2o`0000?ooooo:_l00006ooooo`Ko00003?ooool2o`0001cooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00002_ooool4o`000003ooooool0003o000004Gooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000Iooooo`Co00000oooool2o`0000Kooooo0_l00004
ooooo`Co000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000?o000000Cooooo
o`000?l0003o00000_oooolZo`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00008?oo
ool2o`0000gooooo0_l00008ooooo`Co00000oooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00001?ooool2o`0000Cooooo0_l0
0008ooooo`Co00000_ooool2o`0000?ooooo8_l000000ooooooo0000o`000004o`000003ooooool0
003o0000017ooooo0_l0000_ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Gooooo0_l0
0015ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00007_ooool2o`0000Kooooo0ol0000;
ooooo`;o00001Oooool7o`0000?ooooo0_l00003ooooo`Co00002?oooolUo`0000Sooooo0_l0000F
ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o
000000?ooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00007_ooool2o`00
0003ooooool0003o000000Cooooo0_l0000Booooo`Go00001Oooool6o`000005ooooool0003o0000
o`000?ooool00_l00004ooooobGo00002?ooool2o`0000gooooo0_l00007ooooo`;o00001_ooool3
o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000Gooooo0_l0
0003ooooo`?o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00005
ooooo`;o00001oooool2o`0000cooooo0_l00006ooooo`Co00000_ooool2o`000003ooooool0003o
000000;ooooo9Ol00006ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo0_l00009
ooooo`;o00002Oooool3o`0000cooooo0_l00004ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo0_l00005oooo
o`Co00003?ooool2o`0000Gooooo1?l00005ooooo`;o00000ooooolOo`0000Cooooo1Ol00003oooo
o`Go00002_ooool2o`0000Wooooo0_l0000Mooooo`;o00002_ooool6o`0000Cooooo0_l0001;oooo
o`007?ooool2o`0004oooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000Gooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`00000Io`0000;ooooo2ol00004ooooo`;o00002_ooool3o`0000Oooooo0ol00004oooo
o`;o00005oooool3o`0000cooooo0_l0000Booooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0;oooool2o`00023ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Oooooo0ol0000:ooooo`;o00001?ooool2o`000003ooooool0003o000002Ko
00001Oooool2o`0000Wooooo0_l00002ooooo`;o00001?ooool3o`0000Cooooo0_l0000Gooooo`;o
00002Oooool2o`0001Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
8?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0_l00008ooooo`;o00002?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`ko
000000?oooooo`000?l000002ol00003ooooo`;o00001?ooool5o`0000Gooooo0ol00003ooooo`;o
0000;oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Fooooo`Go0000
2_ooool2o`00017ooooo0_l000000ooooooo0000o`000002o`0000?ooooo1Ol00002oooooa;o0000
0_ooool>o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Go00000_ooool2o`0000?ooooo
0_l0000eooooo`;o0000COooool001cooooo00?o0000ooooooooool0?_ooool2o`00013ooooo0_l0
0004ooooo`Go00001?ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000;ooooo
1_l00005ooooo`?o00000_oooolQo`0000Cooooo1?l00005ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo0_l0000eooooo`;o0000COooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0000Cooooo1?l00005ooooo`Ko00003?ooool3o`000003ooooool0003o000000;ooooo0ol0
0002ooooo`;o00001oooool2o`000003ooooool0003o000001Wo000000Coooooo`000?l0003o0000
1?ooool5o`00037ooooo0ol000000ooooooo0000o`00000?ooooo`;o0000Coooool001cooooo00?o
0000ooooooooool0E_ooool4o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?oo
ool3o`0000Kooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo5?l000000ooooooo0000o`00
0003o`000004ooooool0003o0000o`0000;ooooo1Ol0000cooooo`?o000000Coooooo`000?l0003o
00003_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o0000
0_ooool2o`0000[ooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0ol00004ooooo`;o0000
0ooooolHo`0000Sooooo1Ol00004ooooo`;o0000<Oooool3o`0000?ooooo0_l00003ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000Oooooo0ol0000;ooooo`?o00001?ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000002oooooa7o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo
1?l00003ooooo`;o00002Oooool2o`0000Wooooo0_l0000Kooooo`?o00000oooool2o`0000?ooooo
0_l00004ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0@?ooool2o`00017ooooo1Ol0
0007ooooo`?o000000?oooooo`000?l000003?ooool3o`0001?ooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000oooooa7o000000Coooooo`000?l0003o00000_ooool3o`0000?o
oooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo0_l0000Looooo`;o00003_ooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo05?ooooo1Ol00007ooooo`?o000000?oooooo`000?l00000
3Oooool2o`0001?ooooo0_l000000ooooooo0000o`00000Go`0000Cooooo1ol000001?oooooo0000
o`000?ooool2o`0000?ooooo0ol0000@ooooo`;o00007_ooool6o`0005Wooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l0000Mooooo`;o000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o
00006?ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000001_l00008ooooo`Oo
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo1?l0000Koooo
o`Wo0000FOooool001cooooo00?o0000ooooooooool0=?ooool3o`0000_ooooo0_l0000?ooooo`;o
000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00005
ooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo1Ol00007
ooooo`;o00002?ooool2o`0000[ooooo0_l00005ooooo`;o00001?ooool2o`0001_ooooo2_l0001J
ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002oooool2o`0000kooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o00000oooool2o`00
00kooooo0_l00004ooooo`?o000000?oooooo`000?l000001Oooool4o`000004ooooool0003o0000
ooooo`;o00000_ooool7o`0000;ooooo0_l00002ooooo`;o00003oooool2o`00027ooooo1?l00000
0ooooooo0000o`000003o`0000Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00006?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000@ooooo`;o00001?ooool2
o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0_l00000
0ooooooo0000o`000004o`000003ooooool0003o000000?o000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000002[ooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo1?l00004
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001_ooooo0ol00008oooo
o`;o00002_ooool2o`0000[ooooo0_l00006ooooo`;o00005oooool2o`0000Oooooo0_l00006oooo
o`Co00001_ooool3o`0002Wooooo0ol00003ooooo`;o00002oooool2o`0000Kooooo0_l0001<oooo
o`007?ooool2o`0005Kooooo0_l0000Eooooo`;o000000?oooooo`000?l000005Oooool2o`0000Oo
oooo0_l00002ooooo`Oo00001_ooool2o`0000;ooooo0_l00006ooooo`?o00000_ooool2o`000004
ooooool0003o0000o`0000oooooo0_l0000Fooooo`;o00004?ooool2o`0005Oooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l0000Gooooo`;o00002?ooool2o`0000_ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_ooool7o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l0000Foooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00001oooool2o`0005Oooooo000Looooo`03
o`000?oooooooooo05Kooooo1Ol0000Nooooo`Co00000_ooool2o`0000_ooooo0_l0000;ooooo`;o
00000_ooool2o`0001Sooooo0_l0000Uooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o
0000G?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Wooooo0_l00002ooooo`Go0000
7oooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
2Oooool2o`0002kooooo0_l000000ooooooo0000o`000005ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0B?ooool3o`0000Sooooo0_l00002ooooo`Go000000?oooooo`000?l000006_oo
ool2o`0001?ooooo0_l00004ooooo`;o00002?ooool7o`000003ooooool0003o000000Wooooo0_l0
000aooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0BOooool2o`0000cooooo2?l0000J
ooooo`;o000000?oooooo`000?l000004?ooool2o`0000kooooo1ol0000=ooooo`Co00002Oooool2
o`0000Cooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co00005Oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000@ooooo`;o000000Coooooo`000?l0003o00002oooool6
o`0000Cooooo0_l00007ooooo`Co00002Oooool3o`0000?ooooo0_l0000Pooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0Loooool2o`0000Cooooo0_l0000Fooooo`?o00002?ooool4o`00
00Wooooo0_l00006ooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Soooo
o`Co0000H?ooool001cooooo00?o0000ooooooooool0??ooool2o`0005kooooo1?l00007ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00001Oooool2o`0001oooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`0looooo`;o
00003oooool2o`00037ooooo0_l0000Cooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o
00001?ooool2o`000003ooooool0003o000000_ooooo0_l0000Nooooo`Go0000H?ooool001cooooo
00?o0000ooooooooool0COooool3o`0000_ooooo0_l0000:ooooo`;o00001Oooool4o`0000;ooooo
0_l0000:ooooo`?o00004_ooool5o`0000?ooooo0_l0000Mooooo`;o00006Oooool2o`0000Cooooo
0ol00004ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0C_ooool2o`0000_ooooo0_l0
0005ooooo`;o00000oooool2o`0000Gooooo1?l00002ooooo`;o000000?oooooo`000?l000001_oo
ool4o`000004ooooool0003o0000o`00013ooooo0ol0000?ooooo`Co000000Coooooo`000?l0003o
00002oooool2o`0000?ooooo0_l0000Cooooo`?o00001?ooool3o`0006Wooooo000Looooo`03o`00
0?oooooooooo053ooooo0_l0000@ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o0000
1?ooool4o`000003ooooool0003o000000Co00002?ooool2o`0000kooooo0_l00007ooooo`Co0000
00?oooooo`000?l000001?l0000<ooooo`?o00004oooool2o`0000[ooooo0_l0000:ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0D?ooool2o`0001Oooooo0_l00003ooooo`;o00001_oo
ool2o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l0
0006ooooo`So000000Coooooo`000?l0003ooooo1?l00003ooooo`Co00001?ooool2o`0000Kooooo
0_l0000Mooooo`;o000000?oooooo`000?l000002_ooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo053ooooo0_l0000Tooooo`?o00001oooool2o`0000Cooooo0_l0000=ooooo`;o00001_oo
ool3o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo
0_l00005ooooo`;o00009Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0
000Cooooo`;o00001oooool2o`0001_ooooo0ol000001?oooooo0000o`000?l00003ooooo`;o0000
2_ooool2o`0003Cooooo0_l0001Nooooo`007?ooool2o`0006?ooooo0_l0000:ooooo`;o00005ooo
ool2o`000004ooooool0003o0000o`0001?ooooo1Ol00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;o00007oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Oooooo0_l00005ooooo`;o00004_oo
ool3o`0000;ooooo0_l000000ooooooo0000o`000003o`00017ooooo1Ol00002ooooo`;o00000ooo
ool2o`0000Sooooo1?l0000Mooooo`Oo00001Oooool2o`0006Cooooo000Looooo`03o`000?oooooo
oooo05kooooo0ol00003ooooo`;o000000?oooooo`000?l000006Oooool3o`0000Oooooo0ol0000G
ooooo`Co00009_ooool2o`0000Gooooo0ol000000ooooooo0000o`00001/ooooo`007?ooool00ol0
003oooooooooo`1Oooooo`;o00000oooool3o`0001Gooooo0_l0000Xooooo`Co00001Oooool2o`00
00Gooooo0_l0000Hooooo`;o0000Moooool001cooooo00?o0000ooooooooool0IOooool3o`0000go
oooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000[ooooo0_l00008ooooo`;o
00001Oooool2o`0000Kooooo0_l00003ooooo`Co00007?ooool2o`0000;ooooo0_l00005ooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0Hoooool2o`000004ooooool0003o0000o`0000co
oooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool6o`0000[ooooo0_l00004ooooo`;o
00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00007_ooool2o`0000;ooooo0_l00005ooooo`;o
00000_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00002ooooo`;o0000
3?ooool2o`0000oooooo1?l00005ooooo`?o00002_ooool2o`0001;ooooo0ol000000ooooooo0000
o`00000]ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0MOooool2o`0001Sooooo0ol0
0002ooooo`Co00000_ooool2o`0001Cooooo0ol0000Cooooo`;o00000_ooool2o`0000Kooooo0_l0
001eooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00003oooool2o`000003ooooool0003o
000000Go00003Oooool7o`0000;ooooo0_l0000:ooooo`?o00003_ooool2o`0000gooooo0_l00002
ooooo`;o00001_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000?oooo
o`[o00003Oooool4o`0000kooooo0_l000000ooooooo0000o`000002o`0000Wooooo1_l0000:oooo
o`;o00004Oooool2o`0000Kooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o
00001_ooool2o`0000Oooooo0_l0000Dooooo`Go00003Oooool2o`0000?ooooo0_l00009ooooo`Co
00003?ooool2o`0000Sooooo0ol00006ooooo`?o00001Oooool2o`0006Wooooo000Looooo`03o`00
0?oooooooooo06[ooooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0_l00009ooooo`;o0000
00?oooooo`000?l000000_l0000Dooooo`;o00000_ooool2o`0001_ooooo0ol00007ooooo`;o0000
L?ooool001cooooo00?o0000ooooooooool0Coooool2o`0002gooooo0_l00006ooooo`;o00001_oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l0
000Xooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Coooool2o`0002Cooooo0_l0000G
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Nooooo`;o00007?ooool2
o`0006gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1eooooo`?o00001?ooool2o`0000Kooooo
0_l0000:ooooo`?o00003?ooool2o`000003ooooool0003o000001Oooooo0ol00002ooooo`;o0000
Qoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07Gooooo0ol00004ooooo`;o00001_ooool2o`00
00[ooooo1Ol0000:ooooo`;o000000?oooooo`000?l000005oooool2o`0000?ooooo0_l0000?oooo
o`?o0000MOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0Doooool2o`0002Cooooo0_l0000Aoooo
o`;o00001Oooool2o`0000Wooooo0_l0000Booooo`;o00007Oooool3o`0007Gooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000Doooool2o`0002Cooooo0_l0000Aooooo`;o00001oooool2o`0000Oooooo1?l00007oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`?o00001Oooool2o`0001Gooooo0_l0001foooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`2;ooooo`;o00002?ooool4o`0000Oooooo0ol00006oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000Sooooo0_l0000;oooo
o`;o0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Noooool2o`000003ooooool0003o0000
00[ooooo0ol000000ooooooo0000o`000007ooooo`?o00000_ooool2o`0000?ooooo0_l0000;oooo
o`;o00002?ooool2o`0000[ooooo0_l0000Cooooo`;o0000K_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Nooo
ool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`Co00001Oooool3o`000003ooooool0
003o000000?o000000?oooooo`000?l000002oooool2o`0001[ooooo0_l0000=ooooo`;o0000K_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0R_ooool2o`0000Cooooo0_l00009ooooo`;o000000Coooooo`000?l0
003o00002Oooool2o`0000;ooooo0_l0000Dooooo`;o00001?ooool3o`0007cooooo000Looooo`03
o`000?oooooooooo08_ooooo0ol0000Aooooo`;o00002Oooool2o`0000;ooooo0_l0000Aooooo`Go
00001Oooool2o`0000?ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`26ooooo`;o0000
0_ooool6o`00013ooooo0_l00003ooooo`;o00006_ooool3o`0000cooooo0_l0001gooooo`007?oo
ool00ol0003oooooooooo`1Mooooo`;o00009oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0006ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0
000Booooo`;o0000N?ooool001cooooo00?o0000ooooooooool0GOooool2o`0002cooooo0_l00009
ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool4o`000003ooooool0003o
000000Oooooo0_l00005ooooo`;o00000_ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo
05oooooo0_l00019ooooo`;o00000_ooool3o`0000Gooooo1?l0000:ooooo`;o00001Oooool2o`00
07cooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000gooooo`?o00003oooool2o`0000?o
oooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`2Hooooo`?o0000[_ooool001cooooo00?o
0000ooooooooool0Soooool2o`0000Oooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o0000:?ooool2o`0000Oooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`;o0000=_ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo09gooooo0_l00005ooooo`;o
0000Xoooool001cooooo0_l0002Uooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
06oooooo0_l0003Hooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o0000f?ooool001cooooo
00?o0000ooooooooool0L_ooool2o`000=Gooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0
003Eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0O?ooool2o`000<_ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0003;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l00025ooooo`;o0000`oooool001cooooo00?o0000ooooooooool0Q?ooool2
o`000<?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000?ooooo`;o0000
[?ooool001cooooo00?o0000ooooooooool0Soooool2o`0000Gooooo0_l00003ooooo`;o00000ooo
ool2o`000:Oooooo000Looooo`03o`000?oooooooooo08oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002?ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0002doooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo01Kooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001gooooo00?o
0000ooooooooool01Ol00003ooooo`05oa0@4?ooooooooooooooool@4100T?ooool00:Kooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00003Oooool02?mgMgOo<S8booooooooooooA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?n7QhOo
ooooojVYZOl000006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool05oooool00ol0003oooooooooo`05ooooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@402@ooooo`00a?ooool00ol0003oooooooooo`05ooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00a?ooool4o`0000Go
oooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1098) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33335 .63149 Mdot
.34747 .60312 Mdot
.64912 .50619 Mdot
.42362 .37309 Mdot
.3592 .75827 Mdot
.66629 .53118 Mdot
.56585 .65721 Mdot
.51089 .64364 Mdot
.64924 .5178 Mdot
.39594 .66189 Mdot
.56163 .65193 Mdot
.4998 .44324 Mdot
.54924 .64648 Mdot
.44372 .37537 Mdot
.20056 .66445 Mdot
.47722 .34923 Mdot
.37736 .56623 Mdot
.6046 .40246 Mdot
.39893 .33751 Mdot
.69 .54104 Mdot
.38529 .62077 Mdot
.43247 .37814 Mdot
.31657 .60451 Mdot
.44421 .37585 Mdot
.41368 .36433 Mdot
.37407 .58943 Mdot
.38979 .56317 Mdot
.39853 .40846 Mdot
.42331 .34931 Mdot
.51322 .65259 Mdot
.50647 .26401 Mdot
.24834 .71729 Mdot
.37157 .37153 Mdot
.65964 .75184 Mdot
.51529 .63553 Mdot
.26878 .55767 Mdot
.64622 .54308 Mdot
.5227 .64281 Mdot
.52205 .63188 Mdot
.5658 .67126 Mdot
.5345 .63426 Mdot
.36801 .59747 Mdot
.48844 .65518 Mdot
.48669 .59878 Mdot
.44398 .33579 Mdot
.41432 .74832 Mdot
.35743 .26686 Mdot
.44139 .42808 Mdot
.38032 .5737 Mdot
.68162 .46214 Mdot
.59179 .75298 Mdot
.57052 .65187 Mdot
.61005 .54048 Mdot
.71975 .80468 Mdot
.52193 .65155 Mdot
.42879 .33348 Mdot
.63461 .53157 Mdot
.43405 .38768 Mdot
.44581 .38041 Mdot
.21098 .4586 Mdot
.39927 .42214 Mdot
.62843 .38412 Mdot
.30792 .61225 Mdot
.5631 .42982 Mdot
.64542 .52909 Mdot
.53422 .62806 Mdot
.34781 .61467 Mdot
.54369 .6511 Mdot
.43536 .46557 Mdot
.64873 .56244 Mdot
.43899 .42756 Mdot
.54724 .63153 Mdot
.3849 .6072 Mdot
.42611 .41579 Mdot
.78004 .51856 Mdot
.15148 .45451 Mdot
.65473 .37043 Mdot
.2399 .5092 Mdot
.20828 .50258 Mdot
.71571 .41748 Mdot
.45675 .35904 Mdot
.55313 .21201 Mdot
.17133 .56439 Mdot
.31872 .58655 Mdot
.36748 .35599 Mdot
.58448 .50851 Mdot
.42615 .41075 Mdot
.34537 .70428 Mdot
.44455 .34088 Mdot
.80698 .55466 Mdot
.65796 .51515 Mdot
.3454 .58159 Mdot
.42567 .37087 Mdot
.39125 .4015 Mdot
.35416 .2891 Mdot
.45136 .44421 Mdot
.40284 .39827 Mdot
.37244 .62229 Mdot
.56496 .63531 Mdot
.51146 .38853 Mdot
.49424 .67154 Mdot
.62543 .51504 Mdot
.46683 .42429 Mdot
.65343 .55563 Mdot
.38711 .60941 Mdot
.42126 .42122 Mdot
.5317 .62189 Mdot
.46875 .41065 Mdot
.53608 .72811 Mdot
.34479 .60548 Mdot
.39075 .39478 Mdot
.63522 .38937 Mdot
.75159 .32222 Mdot
.33904 .58047 Mdot
.73166 .39841 Mdot
.46011 .3558 Mdot
.41208 .39593 Mdot
.34944 .60104 Mdot
.63704 .5075 Mdot
.32312 .69063 Mdot
.31341 .58332 Mdot
.5701 .66938 Mdot
.30794 .60038 Mdot
.36347 .39107 Mdot
.65853 .52207 Mdot
.6349 .70607 Mdot
.6018 .63964 Mdot
.50228 .24522 Mdot
.42763 .40613 Mdot
.4398 .68992 Mdot
.68994 .51956 Mdot
.35441 .58692 Mdot
.5446 .65474 Mdot
.45182 .32039 Mdot
.32785 .6035 Mdot
.54336 .66682 Mdot
.6222 .39853 Mdot
.67307 .65197 Mdot
.35511 .55788 Mdot
.47281 .6207 Mdot
.52449 .61392 Mdot
.56828 .66401 Mdot
.70729 .72994 Mdot
.35424 .61019 Mdot
.60611 .36892 Mdot
.53146 .6602 Mdot
.47399 .2702 Mdot
.39878 .35239 Mdot
.58058 .25019 Mdot
.48546 .16949 Mdot
.67209 .74517 Mdot
.72184 .62107 Mdot
.59483 .35618 Mdot
.57446 .63896 Mdot
.39885 .37219 Mdot
.37951 .59296 Mdot
.36978 .604 Mdot
.41668 .43166 Mdot
.41805 .36994 Mdot
.4327 .42614 Mdot
.38807 .38794 Mdot
.19046 .45952 Mdot
.47704 .4023 Mdot
.42151 .2046 Mdot
.34437 .57646 Mdot
.40548 .37945 Mdot
.62447 .5361 Mdot
.38957 .43454 Mdot
.5374 .63158 Mdot
.42681 .38447 Mdot
.41989 .37501 Mdot
.39537 .41993 Mdot
.57057 .64929 Mdot
.23818 .68363 Mdot
.5565 .18354 Mdot
.29363 .73307 Mdot
.7757 .48368 Mdot
.68119 .53475 Mdot
.41981 .40642 Mdot
.6289 .37282 Mdot
.2938 .52326 Mdot
.46041 .36775 Mdot
.80106 .31073 Mdot
.40863 .38936 Mdot
.31677 .73385 Mdot
.36209 .43443 Mdot
.31593 .76545 Mdot
.55952 .22821 Mdot
.39536 .37113 Mdot
.41551 .29152 Mdot
.3722 .51695 Mdot
.49442 .6011 Mdot
.53624 .63587 Mdot
.62638 .52896 Mdot
.63935 .51832 Mdot
.57951 .67457 Mdot
.36664 .65256 Mdot
.38897 .31521 Mdot
.45308 .45293 Mdot
.61572 .55597 Mdot
.31574 .62902 Mdot
.59065 .37482 Mdot
.35805 .62728 Mdot
.17375 .34554 Mdot
.58208 .74154 Mdot
.5672 .68899 Mdot
.64895 .38538 Mdot
.66751 .50159 Mdot
.61743 .52765 Mdot
.62679 .36438 Mdot
.45784 .41204 Mdot
.35352 .61415 Mdot
.62478 .79201 Mdot
.39757 .63431 Mdot
.67705 .76964 Mdot
.38121 .60707 Mdot
.43419 .63642 Mdot
.5495 .6626 Mdot
.65739 .54669 Mdot
.40898 .39763 Mdot
.45067 .40721 Mdot
.39559 .61144 Mdot
.43616 .42493 Mdot
.33813 .3602 Mdot
.4051 .40772 Mdot
.61905 .72764 Mdot
.65452 .36734 Mdot
.57912 .67485 Mdot
.49097 .23695 Mdot
.32786 .61973 Mdot
.6679 .30775 Mdot
.63227 .55513 Mdot
.27517 .5288 Mdot
.55235 .63246 Mdot
.62625 .39388 Mdot
.63148 .55698 Mdot
.58922 .37345 Mdot
.37635 .40125 Mdot
.6806 .49055 Mdot
.63984 .38006 Mdot
.21902 .57789 Mdot
.39559 .35941 Mdot
.18686 .45519 Mdot
.56841 .63152 Mdot
.31632 .57711 Mdot
.39904 .421 Mdot
.6727 .54652 Mdot
.37054 .36832 Mdot
.72304 .59522 Mdot
.63365 .70787 Mdot
.66081 .48561 Mdot
.72763 .4879 Mdot
.61787 .39197 Mdot
.67198 .6085 Mdot
.45065 .67381 Mdot
.38512 .58097 Mdot
.47594 .41611 Mdot
.29756 .7677 Mdot
.53188 .66002 Mdot
.46573 .4055 Mdot
.65334 .72081 Mdot
.53063 .65635 Mdot
.43443 .38976 Mdot
.54637 .61323 Mdot
.36845 .60652 Mdot
.67985 .27478 Mdot
.37897 .56832 Mdot
.44839 .34379 Mdot
.54001 .61846 Mdot
.65608 .49179 Mdot
.3746 .58243 Mdot
.46038 .41846 Mdot
.41091 .41491 Mdot
.5482 .50082 Mdot
.39951 .38429 Mdot
.26459 .70228 Mdot
.39461 .39719 Mdot
.63031 .52782 Mdot
.43834 .44515 Mdot
.84507 .47793 Mdot
.6072 .63559 Mdot
.34898 .6148 Mdot
.67706 .48474 Mdot
.64549 .51811 Mdot
.70532 .35302 Mdot
.62855 .5921 Mdot
.4678 .36521 Mdot
.6788 .54056 Mdot
.64252 .28446 Mdot
.52613 .66819 Mdot
.47185 .42745 Mdot
.47509 .60131 Mdot
.67704 .45889 Mdot
.61327 .55047 Mdot
.44263 .32319 Mdot
.39305 .58185 Mdot
.42472 .37046 Mdot
.61951 .52877 Mdot
.34332 .64511 Mdot
.46631 .35564 Mdot
.41677 .54065 Mdot
.54724 .50121 Mdot
.55063 .66961 Mdot
.35153 .39882 Mdot
.46374 .42188 Mdot
.64939 .55094 Mdot
.3441 .62356 Mdot
.50859 .65456 Mdot
.3686 .58719 Mdot
.46587 .8141 Mdot
.53914 .72438 Mdot
.19855 .52909 Mdot
.57523 .38061 Mdot
.7598 .59628 Mdot
.35489 .79264 Mdot
.80017 .44616 Mdot
.592 .30267 Mdot
.52926 .82906 Mdot
.62146 .53253 Mdot
.67093 .71524 Mdot
.64159 .52004 Mdot
.43188 .35504 Mdot
.65524 .52646 Mdot
.34653 .79099 Mdot
.40383 .4061 Mdot
.65431 .53299 Mdot
.6899 .30963 Mdot
.41249 .37617 Mdot
.33509 .58221 Mdot
.19603 .63306 Mdot
.81388 .44742 Mdot
.63171 .74347 Mdot
.68915 .50123 Mdot
.55138 .32536 Mdot
.4002 .39802 Mdot
.42176 .44609 Mdot
.37175 .5692 Mdot
.46497 .43832 Mdot
.59106 .36998 Mdot
.6485 .38861 Mdot
.48059 .49645 Mdot
.58382 .20604 Mdot
.48944 .43841 Mdot
.37487 .57913 Mdot
.22554 .38781 Mdot
.77887 .52842 Mdot
.75617 .52357 Mdot
.57237 .62236 Mdot
.22667 .65553 Mdot
.35578 .45247 Mdot
.51852 .70439 Mdot
.50516 .5872 Mdot
.341 .59105 Mdot
.24918 .69938 Mdot
.5331 .63873 Mdot
.30383 .35024 Mdot
.48273 .30043 Mdot
.45662 .40749 Mdot
.56014 .63822 Mdot
.48352 .45182 Mdot
.82932 .48635 Mdot
.32632 .26753 Mdot
.46698 .20291 Mdot
.46127 .3476 Mdot
.77981 .50877 Mdot
.41907 .38843 Mdot
.30431 .68308 Mdot
.39484 .39968 Mdot
.36632 .57995 Mdot
.34876 .67806 Mdot
.52236 .49019 Mdot
.51487 .18054 Mdot
.57138 .74097 Mdot
.59436 .35665 Mdot
.40925 .40452 Mdot
.4571 .40616 Mdot
.59854 .3824 Mdot
.32775 .57788 Mdot
.38778 .38605 Mdot
.65163 .30559 Mdot
.43442 .41577 Mdot
.52736 .63613 Mdot
.43846 .21916 Mdot
.38593 .55081 Mdot
.47667 .43553 Mdot
.33135 .63785 Mdot
.54771 .6714 Mdot
.51837 .63515 Mdot
.48796 .35706 Mdot
.54659 .68285 Mdot
.41544 .38335 Mdot
.33639 .2428 Mdot
.33972 .56602 Mdot
.34514 .39497 Mdot
.31878 .60312 Mdot
.23653 .51797 Mdot
.52298 .62446 Mdot
.61145 .7195 Mdot
.51327 .37677 Mdot
.53784 .63906 Mdot
.51678 .72075 Mdot
.49258 .43112 Mdot
.48303 .36394 Mdot
.79522 .59013 Mdot
.67956 .49496 Mdot
.54009 .49093 Mdot
.51238 .6334 Mdot
.45775 .42616 Mdot
.48024 .42281 Mdot
.55262 .67119 Mdot
.2846 .34518 Mdot
.74938 .3641 Mdot
.39969 .40489 Mdot
.35862 .57307 Mdot
.35673 .58733 Mdot
.47318 .3556 Mdot
.47161 .40226 Mdot
.67797 .51252 Mdot
.6848 .48863 Mdot
.70202 .51522 Mdot
.54587 .50054 Mdot
.61437 .72296 Mdot
.45633 .77473 Mdot
.56569 .67111 Mdot
.46383 .7193 Mdot
.80711 .53527 Mdot
.37432 .41948 Mdot
.69483 .52217 Mdot
.45919 .39556 Mdot
.42604 .37472 Mdot
.50905 .65753 Mdot
.64147 .73552 Mdot
.44199 .4756 Mdot
.33957 .56329 Mdot
.50771 .63974 Mdot
.47371 .31996 Mdot
.50423 .75681 Mdot
.63508 .38314 Mdot
.73372 .69399 Mdot
.54522 .62945 Mdot
.33682 .58981 Mdot
.53338 .61744 Mdot
.44815 .41034 Mdot
.41421 .3324 Mdot
.34789 .59427 Mdot
.64308 .37126 Mdot
.3956 .43305 Mdot
.43101 .39065 Mdot
.62635 .1802 Mdot
.79154 .50063 Mdot
.61713 .70377 Mdot
.39313 .37783 Mdot
.48785 .41253 Mdot
.59071 .38802 Mdot
.43947 .41459 Mdot
.41625 .42612 Mdot
.70547 .27338 Mdot
.59092 .69428 Mdot
.62979 .40578 Mdot
.29698 .36198 Mdot
.38369 .60089 Mdot
.27827 .74927 Mdot
.66239 .54647 Mdot
.54959 .68685 Mdot
.75563 .35726 Mdot
.62292 .51551 Mdot
.74163 .58761 Mdot
.26899 .73844 Mdot
.53853 .49467 Mdot
.66753 .3603 Mdot
.47576 .46693 Mdot
.40291 .41757 Mdot
.41787 .39224 Mdot
.62358 .37127 Mdot
.35918 .61065 Mdot
.54875 .47042 Mdot
.20601 .37923 Mdot
.42563 .38167 Mdot
.34179 .3502 Mdot
.21638 .59767 Mdot
.66821 .45268 Mdot
.59605 .36184 Mdot
.64568 .37437 Mdot
.41129 .40119 Mdot
.7208 .29763 Mdot
.375 .58891 Mdot
.4613 .41747 Mdot
.47759 .37827 Mdot
.68633 .49713 Mdot
.33917 .60549 Mdot
.61982 .53567 Mdot
.60501 .71875 Mdot
.31004 .73522 Mdot
.63588 .17897 Mdot
.519 .63056 Mdot
.25364 .64544 Mdot
.51904 .66123 Mdot
.53912 .21059 Mdot
.61553 .52767 Mdot
.4616 .36433 Mdot
.33787 .62294 Mdot
.46505 .4155 Mdot
.46998 .39103 Mdot
.45872 .41065 Mdot
.42828 .45713 Mdot
.82339 .35852 Mdot
.63249 .36399 Mdot
.48983 .42138 Mdot
.6381 .51623 Mdot
.25342 .66271 Mdot
.15595 .4879 Mdot
.45291 .40009 Mdot
.41256 .4121 Mdot
.3288 .58802 Mdot
.42669 .43849 Mdot
.52505 .66616 Mdot
.34821 .62435 Mdot
.39027 .39751 Mdot
.23878 .65962 Mdot
.41116 .35256 Mdot
.30822 .75178 Mdot
.52769 .61925 Mdot
.48784 .69811 Mdot
.48706 .43098 Mdot
.63235 .70317 Mdot
.54016 .49081 Mdot
.68422 .54012 Mdot
.50764 .67377 Mdot
.64544 .54124 Mdot
.26788 .29578 Mdot
.38643 .35257 Mdot
.40251 .36934 Mdot
.47862 .42288 Mdot
.67941 .5377 Mdot
.34444 .71686 Mdot
.63846 .61942 Mdot
.44949 .31213 Mdot
.6807 .52239 Mdot
.31514 .62525 Mdot
.59471 .43025 Mdot
.32806 .61683 Mdot
.64796 .3955 Mdot
.56044 .6514 Mdot
.62607 .3537 Mdot
.64511 .74685 Mdot
.34544 .60329 Mdot
.40205 .59435 Mdot
.67205 .53743 Mdot
.57627 .55791 Mdot
.64462 .83667 Mdot
.58819 .45234 Mdot
.54826 .24913 Mdot
.36732 .56755 Mdot
.4435 .34591 Mdot
.50063 .20989 Mdot
.56315 .55462 Mdot
.64381 .53912 Mdot
.45106 .36426 Mdot
.7 .29051 Mdot
.6789 .51281 Mdot
.47281 .42494 Mdot
.65763 .49655 Mdot
.54797 .63515 Mdot
.68809 .50859 Mdot
.3679 .55461 Mdot
.41984 .41779 Mdot
.61915 .84461 Mdot
.64184 .41891 Mdot
.39544 .39237 Mdot
.50932 .63598 Mdot
.43032 .52944 Mdot
.46359 .38468 Mdot
.60777 .39708 Mdot
.66404 .52414 Mdot
.58269 .47053 Mdot
.39813 .40415 Mdot
.68054 .53326 Mdot
.32698 .62587 Mdot
.50882 .67569 Mdot
.52354 .45609 Mdot
.63285 .71459 Mdot
.37484 .57183 Mdot
.48182 .66218 Mdot
.50972 .66919 Mdot
.48497 .42087 Mdot
.47857 .40066 Mdot
.35739 .5771 Mdot
.64961 .25429 Mdot
.42712 .4433 Mdot
.45677 .35921 Mdot
.63566 .51751 Mdot
.65209 .53956 Mdot
.65968 .2658 Mdot
.64212 .5025 Mdot
.40725 .33588 Mdot
.35921 .57821 Mdot
.43249 .36632 Mdot
.33085 .59071 Mdot
.43741 .44025 Mdot
.34104 .64862 Mdot
.32801 .57387 Mdot
.63713 .60803 Mdot
.44143 .36469 Mdot
.35525 .42041 Mdot
.46598 .40199 Mdot
.4324 .42178 Mdot
.67341 .51104 Mdot
.60801 .35876 Mdot
.47329 .33352 Mdot
.6534 .39576 Mdot
.59359 .38153 Mdot
.36967 .52015 Mdot
.68521 .49735 Mdot
.61243 .3752 Mdot
.18004 .50967 Mdot
.69851 .50674 Mdot
.62684 .37948 Mdot
.16298 .51321 Mdot
.5164 .63306 Mdot
.37766 .56333 Mdot
.41308 .37506 Mdot
.53037 .82351 Mdot
.37314 .24183 Mdot
.63371 .50191 Mdot
.39433 .39479 Mdot
.4604 .3918 Mdot
.31407 .58701 Mdot
.32831 .21185 Mdot
.67346 .55643 Mdot
.42242 .35476 Mdot
.34336 .61391 Mdot
.36892 .18732 Mdot
.62924 .53381 Mdot
.62634 .37658 Mdot
.57132 .64748 Mdot
.30939 .57094 Mdot
.60147 .63097 Mdot
.56239 .66478 Mdot
.60416 .52848 Mdot
.60046 .74666 Mdot
.46097 .35636 Mdot
.69412 .52377 Mdot
.75018 .68642 Mdot
.41227 .60346 Mdot
.51595 .60205 Mdot
.54645 .33371 Mdot
.34067 .58845 Mdot
.52571 .66549 Mdot
.61294 .35172 Mdot
.379 .61101 Mdot
.33941 .57036 Mdot
.51354 .66465 Mdot
.47898 .4877 Mdot
.47995 .59396 Mdot
.52264 .63586 Mdot
.79635 .56933 Mdot
.51482 .80064 Mdot
.69538 .52595 Mdot
.59423 .37794 Mdot
.60708 .78323 Mdot
.36854 .59648 Mdot
.22807 .65775 Mdot
.75862 .66886 Mdot
.40282 .39803 Mdot
.60737 .37626 Mdot
.38861 .74928 Mdot
.22868 .34263 Mdot
.5289 .65534 Mdot
.51969 .50125 Mdot
.60874 .34452 Mdot
.40399 .42446 Mdot
.4835 .29186 Mdot
.4431 .3579 Mdot
.55629 .65983 Mdot
.20388 .47721 Mdot
.33588 .59003 Mdot
.50515 .65261 Mdot
.73085 .69706 Mdot
.41941 .38192 Mdot
.44634 .3631 Mdot
.47413 .24201 Mdot
.37366 .60742 Mdot
.68207 .5431 Mdot
.46331 .3594 Mdot
.42902 .3878 Mdot
.44586 .32909 Mdot
.34928 .37659 Mdot
.74481 .31775 Mdot
.42709 .35496 Mdot
.58765 .72858 Mdot
.47931 .43365 Mdot
.44328 .36766 Mdot
.33012 .63778 Mdot
.69312 .21623 Mdot
.60197 .72063 Mdot
.42658 .38577 Mdot
.43988 .34688 Mdot
.51455 .66721 Mdot
.4923 .57438 Mdot
.57711 .56402 Mdot
.5751 .50489 Mdot
.57258 .30993 Mdot
.42896 .45838 Mdot
.33554 .6169 Mdot
.63912 .38718 Mdot
.4826 .37504 Mdot
.33497 .61558 Mdot
.38052 .39313 Mdot
.6815 .51496 Mdot
.69718 .50296 Mdot
.46101 .64519 Mdot
.61863 .37877 Mdot
.4273 .24196 Mdot
.45903 .72648 Mdot
.63256 .51867 Mdot
.40661 .36775 Mdot
.54099 .68969 Mdot
.61851 .52968 Mdot
.58804 .52372 Mdot
.38287 .32489 Mdot
.37619 .59599 Mdot
.34339 .58014 Mdot
.58357 .25102 Mdot
.69407 .63956 Mdot
.63857 .20058 Mdot
.55161 .6368 Mdot
.39728 .42732 Mdot
.44272 .6753 Mdot
.34111 .58031 Mdot
.51676 .21285 Mdot
.61218 .37717 Mdot
.52786 .65681 Mdot
.75017 .53327 Mdot
.32805 .5987 Mdot
.36938 .56149 Mdot
.43199 .34167 Mdot
.44067 .39653 Mdot
.60013 .29929 Mdot
.61317 .33535 Mdot
.54252 .67211 Mdot
.59693 .3817 Mdot
.62852 .55694 Mdot
.43003 .3526 Mdot
.31604 .59719 Mdot
.57634 .78838 Mdot
.44583 .34775 Mdot
.67556 .50953 Mdot
.34407 .58778 Mdot
.60368 .38761 Mdot
.59704 .38844 Mdot
.43259 .42041 Mdot
.23001 .38894 Mdot
.52748 .646 Mdot
.336 .58257 Mdot
.53659 .75355 Mdot
.43829 .44592 Mdot
.43457 .39813 Mdot
.37011 .43373 Mdot
.51746 .66491 Mdot
.46212 .66796 Mdot
.63437 .35487 Mdot
.36018 .60444 Mdot
.40164 .36254 Mdot
.62459 .38453 Mdot
.45585 .66794 Mdot
.65534 .48801 Mdot
.68298 .50416 Mdot
.60459 .39515 Mdot
.60043 .37621 Mdot
.61042 .39663 Mdot
.22256 .65432 Mdot
.35401 .55018 Mdot
.36853 .47032 Mdot
.42149 .4429 Mdot
.56484 .24046 Mdot
.46859 .32414 Mdot
.50947 .62881 Mdot
.67531 .49467 Mdot
.46758 .39526 Mdot
.45176 .34548 Mdot
.35847 .41828 Mdot
.35749 .43983 Mdot
.39192 .55911 Mdot
.34275 .60549 Mdot
.37653 .37474 Mdot
.67791 .49167 Mdot
.19644 .31236 Mdot
.46389 .84891 Mdot
.49502 .41882 Mdot
.53689 .56734 Mdot
.31692 .59489 Mdot
.53598 .67944 Mdot
.58212 .54113 Mdot
.54383 .61591 Mdot
.3588 .59915 Mdot
.42966 .35334 Mdot
.46998 .72897 Mdot
.59981 .39419 Mdot
.44528 .43017 Mdot
.54126 .66394 Mdot
.43896 .42936 Mdot
.56353 .66293 Mdot
.42966 .80129 Mdot
.81114 .52069 Mdot
.40775 .39054 Mdot
.4924 .40948 Mdot
.55931 .33123 Mdot
.45329 .39792 Mdot
.59382 .41971 Mdot
.31871 .59105 Mdot
.59895 .19543 Mdot
.41311 .34503 Mdot
.28528 .46818 Mdot
.4369 .44681 Mdot
.70428 .30191 Mdot
.43885 .40092 Mdot
.68774 .45959 Mdot
.40039 .41227 Mdot
.41888 .42517 Mdot
.54214 .61743 Mdot
.51332 .66544 Mdot
.36976 .62785 Mdot
.67539 .54567 Mdot
.29386 .74038 Mdot
.43159 .39332 Mdot
.63516 .7144 Mdot
.56139 .72017 Mdot
.59848 .37471 Mdot
.36114 .59868 Mdot
.33845 .19573 Mdot
.56254 .61707 Mdot
.77426 .43309 Mdot
.66119 .28017 Mdot
.602 .66186 Mdot
.5827 .5144 Mdot
.32019 .68044 Mdot
.62192 .39148 Mdot
.40479 .42689 Mdot
.62467 .7597 Mdot
.76773 .53336 Mdot
.39328 .31551 Mdot
.50402 .65789 Mdot
.287 .51586 Mdot
.59453 .78441 Mdot
.62746 .34743 Mdot
.62791 .35355 Mdot
.569 .65224 Mdot
.69704 .47289 Mdot
.46062 .46724 Mdot
.61236 .3799 Mdot
.64061 .50663 Mdot
.69851 .52085 Mdot
.71491 .56834 Mdot
.37292 .59536 Mdot
.70209 .71904 Mdot
.42596 .73931 Mdot
.56062 .66561 Mdot
.67368 .37859 Mdot
.33135 .55195 Mdot
.3821 .55866 Mdot
.66173 .54269 Mdot
.67052 .50788 Mdot
.38414 .56746 Mdot
.40777 .34218 Mdot
.376 .45203 Mdot
.42437 .38392 Mdot
.62083 .36625 Mdot
.4453 .40272 Mdot
.67662 .51746 Mdot
.53423 .65348 Mdot
.66298 .50748 Mdot
.55143 .61283 Mdot
.46908 .77164 Mdot
.45282 .42123 Mdot
.41578 .41776 Mdot
.37109 .24031 Mdot
.34052 .63552 Mdot
.56386 .74968 Mdot
.63144 .72901 Mdot
.64088 .51881 Mdot
.41573 .42663 Mdot
.32503 .61987 Mdot
.64956 .36898 Mdot
.36974 .2392 Mdot
.47122 .41662 Mdot
.31759 .59697 Mdot
.41069 .35913 Mdot
.19527 .54484 Mdot
.81338 .40106 Mdot
.36529 .58664 Mdot
.47622 .17262 Mdot
.42552 .34988 Mdot
.31947 .66856 Mdot
.4817 .41072 Mdot
.616 .27604 Mdot
.42916 .44364 Mdot
.38166 .60672 Mdot
.43098 .38242 Mdot
.36558 .61906 Mdot
.62607 .53899 Mdot
.55803 .67566 Mdot
.36003 .56383 Mdot
.48079 .38972 Mdot
.33811 .83458 Mdot
.5574 .65426 Mdot
.40905 .40069 Mdot
.56441 .62844 Mdot
.3507 .61778 Mdot
.37413 .56652 Mdot
.19529 .3849 Mdot
.60594 .69725 Mdot
.54674 .63516 Mdot
.42179 .35698 Mdot
.38913 .71094 Mdot
.43462 .36232 Mdot
.5804 .28531 Mdot
.44011 .33223 Mdot
.4358 .44513 Mdot
.15346 .44865 Mdot
.52861 .67095 Mdot
.66448 .22305 Mdot
.18863 .40437 Mdot
.21972 .6399 Mdot
.30165 .59331 Mdot
.63572 .35315 Mdot
.24582 .69329 Mdot
.61257 .71731 Mdot
.68218 .52769 Mdot
.46649 .39808 Mdot
.35519 .53982 Mdot
.52086 .64503 Mdot
.61259 .35857 Mdot
.40751 .39143 Mdot
.67023 .50619 Mdot
.75579 .38536 Mdot
.5754 .63803 Mdot
.36715 .59812 Mdot
.33245 .56709 Mdot
.42723 .17004 Mdot
.39513 .37066 Mdot
.41297 .41888 Mdot
.55916 .65652 Mdot
.41859 .58637 Mdot
.61856 .39373 Mdot
.71227 .32676 Mdot
.54856 .63634 Mdot
.54739 .53256 Mdot
.34987 .61056 Mdot
.46033 .39372 Mdot
.33683 .72231 Mdot
.76781 .49999 Mdot
.31334 .38873 Mdot
.6269 .37125 Mdot
.57027 .28501 Mdot
.38235 .60572 Mdot
.54111 .65778 Mdot
.68542 .65641 Mdot
.36623 .36906 Mdot
.45628 .38926 Mdot
.56335 .28182 Mdot
.51358 .48166 Mdot
.46107 .20571 Mdot
.46738 .42686 Mdot
.5339 .47513 Mdot
.45279 .43635 Mdot
.37434 .34744 Mdot
.41419 .33475 Mdot
.42899 .40206 Mdot
.31738 .59591 Mdot
.39605 .31702 Mdot
.68746 .52661 Mdot
.36104 .28852 Mdot
.55778 .51203 Mdot
.3971 .39889 Mdot
.43571 .35708 Mdot
.3302 .45724 Mdot
.50627 .69564 Mdot
.34878 .56736 Mdot
.39231 .62322 Mdot
.55374 .68134 Mdot
.36295 .43227 Mdot
.67217 .55008 Mdot
.42522 .31869 Mdot
.66939 .51112 Mdot
.31927 .61003 Mdot
.63636 .52375 Mdot
.57047 .66343 Mdot
.69627 .51693 Mdot
.6146 .72473 Mdot
.5208 .65837 Mdot
.38019 .59615 Mdot
.42755 .41555 Mdot
.50884 .63827 Mdot
.48673 .24819 Mdot
.62131 .36698 Mdot
.1873 .39534 Mdot
.38984 .37436 Mdot
.59796 .66506 Mdot
.41624 .53807 Mdot
.66405 .50876 Mdot
.77771 .34171 Mdot
.33002 .57202 Mdot
.63759 .40033 Mdot
.32015 .61355 Mdot
.81229 .57631 Mdot
.60151 .36331 Mdot
.16373 .52492 Mdot
.72288 .64315 Mdot
.61357 .45149 Mdot
.40664 .344 Mdot
.4928 .30377 Mdot
.62803 .55922 Mdot
.52082 .6461 Mdot
.71542 .63434 Mdot
.42203 .42738 Mdot
.79727 .46136 Mdot
.37985 .62203 Mdot
.67886 .54208 Mdot
.54563 .6516 Mdot
.50663 .64715 Mdot
.47472 .40229 Mdot
.68817 .36752 Mdot
.45172 .43293 Mdot
.67245 .63782 Mdot
.57034 .30394 Mdot
.42921 .47559 Mdot
.40569 .40753 Mdot
.64206 .55098 Mdot
.41115 .35916 Mdot
.56931 .3508 Mdot
.68807 .74221 Mdot
.42151 .45363 Mdot
.62734 .73393 Mdot
.62926 .41937 Mdot
.34742 .59816 Mdot
.50627 .39531 Mdot
.61319 .68798 Mdot
.40189 .36391 Mdot
.87602 .52012 Mdot
.62627 .3812 Mdot
.63848 .69633 Mdot
.46768 .44037 Mdot
.47665 .38419 Mdot
.52944 .35394 Mdot
.29003 .58774 Mdot
.77016 .499 Mdot
.44986 .3878 Mdot
.51961 .29062 Mdot
.56145 .63603 Mdot
.45969 .42823 Mdot
.41504 .39431 Mdot
.31816 .53907 Mdot
.51062 .6543 Mdot
.6501 .50919 Mdot
.61124 .53751 Mdot
.69502 .54995 Mdot
.59405 .39768 Mdot
.52449 .51471 Mdot
.53941 .22435 Mdot
.81091 .45027 Mdot
.63944 .39209 Mdot
.4113 .34986 Mdot
.56088 .35629 Mdot
.44451 .35044 Mdot
.60616 .35269 Mdot
.51276 .65609 Mdot
.34834 .56626 Mdot
.43522 .65402 Mdot
.64534 .56268 Mdot
.47286 .42664 Mdot
.58956 .36646 Mdot
.37877 .59354 Mdot
.59264 .34209 Mdot
.35279 .60259 Mdot
.54603 .63878 Mdot
.56128 .68097 Mdot
.61243 .35571 Mdot
.32406 .61268 Mdot
.52248 .71303 Mdot
.23269 .34282 Mdot
.42687 .3291 Mdot
.54621 .58799 Mdot
.3384 .63262 Mdot
.39678 .58627 Mdot
.36448 .62659 Mdot
.43962 .42484 Mdot
.5317 .56704 Mdot
.46933 .34265 Mdot
.54505 .67132 Mdot
.65865 .49687 Mdot
.66287 .3167 Mdot
.51357 .78771 Mdot
.67113 .33191 Mdot
.38947 .41976 Mdot
.42432 .37946 Mdot
.41126 .40084 Mdot
.44601 .33862 Mdot
.65802 .64818 Mdot
.46527 .41094 Mdot
.54764 .61816 Mdot
.66662 .51966 Mdot
.39999 .42394 Mdot
.64775 .49106 Mdot
.35088 .69322 Mdot
.64186 .38433 Mdot
.51277 .50946 Mdot
.29826 .78648 Mdot
.37983 .58585 Mdot
.6387 .50489 Mdot
.68067 .52951 Mdot
.62216 .39835 Mdot
.52402 .64218 Mdot
.35345 .60789 Mdot
.62699 .28741 Mdot
.60285 .39102 Mdot
.43003 .38451 Mdot
.60973 .57968 Mdot
.79106 .46657 Mdot
.41414 .4327 Mdot
.46637 .37677 Mdot
.65818 .48617 Mdot
.69074 .46712 Mdot
.68771 .77475 Mdot
.48611 .21817 Mdot
.60902 .35706 Mdot
.64252 .37399 Mdot
.39216 .57811 Mdot
.49938 .39219 Mdot
.54885 .67035 Mdot
.42517 .22136 Mdot
.43571 .51339 Mdot
.42985 .23686 Mdot
.52936 .45242 Mdot
.4706 .41393 Mdot
.27919 .32827 Mdot
.41807 .38154 Mdot
.3208 .57862 Mdot
.36094 .61549 Mdot
.36645 .57144 Mdot
.52357 .64806 Mdot
.25084 .52161 Mdot
.54315 .6192 Mdot
.32928 .80278 Mdot
.38559 .59725 Mdot
.65183 .67194 Mdot
.64394 .54991 Mdot
.48297 .43686 Mdot
.60883 .3896 Mdot
.5118 .61791 Mdot
.43261 .46584 Mdot
.72853 .30136 Mdot
.6838 .53415 Mdot
.38121 .59493 Mdot
.31592 .67764 Mdot
.3946 .80955 Mdot
.58017 .55295 Mdot
.48472 .32802 Mdot
.52161 .33553 Mdot
.59699 .37445 Mdot
.31259 .3787 Mdot
.59141 .35765 Mdot
.5341 .66364 Mdot
.41851 .41497 Mdot
.42614 .40962 Mdot
.44413 .44042 Mdot
.4607 .41506 Mdot
.53291 .68006 Mdot
.42098 .44822 Mdot
.84506 .47796 Mdot
.69561 .49912 Mdot
.21161 .5638 Mdot
.62483 .38752 Mdot
.50364 .66454 Mdot
.66834 .5184 Mdot
.67343 .4786 Mdot
.49918 .23305 Mdot
.40025 .40592 Mdot
.46768 .3979 Mdot
.77988 .45093 Mdot
.46531 .43001 Mdot
.49272 .33846 Mdot
.68125 .53174 Mdot
.66991 .33004 Mdot
.64602 .38734 Mdot
.63361 .35979 Mdot
.51264 .64531 Mdot
.32234 .61345 Mdot
.61722 .37214 Mdot
.62678 .53569 Mdot
.3825 .41081 Mdot
.47561 .37082 Mdot
.34215 .63355 Mdot
.76598 .66019 Mdot
.62061 .34475 Mdot
.33143 .6835 Mdot
.35399 .62182 Mdot
.34109 .55085 Mdot
.45604 .38743 Mdot
.37103 .32468 Mdot
.3257 .54743 Mdot
.63232 .3991 Mdot
.50572 .6677 Mdot
.57858 .49701 Mdot
.54717 .66602 Mdot
.36429 .60897 Mdot
.47486 .36392 Mdot
.36763 .60974 Mdot
.39232 .38108 Mdot
.21438 .72113 Mdot
.43105 .40569 Mdot
.8192 .46305 Mdot
.58167 .26344 Mdot
.66893 .52999 Mdot
.53665 .72034 Mdot
.66767 .54348 Mdot
.35859 .62043 Mdot
.48093 .37502 Mdot
.63636 .35809 Mdot
.20132 .60696 Mdot
.34061 .54803 Mdot
.68411 .51392 Mdot
.69484 .54244 Mdot
.52025 .66118 Mdot
.40199 .42813 Mdot
.45752 .39413 Mdot
.65392 .5347 Mdot
.41094 .47773 Mdot
.32481 .59829 Mdot
.41127 .41366 Mdot
.43533 .37254 Mdot
.66963 .53175 Mdot
.2491 .32423 Mdot
.28925 .62911 Mdot
.42023 .40759 Mdot
.68539 .68668 Mdot
.50829 .63069 Mdot
.42355 .33679 Mdot
.46744 .44796 Mdot
.60445 .37905 Mdot
.23853 .58557 Mdot
.6728 .75087 Mdot
.51553 .62411 Mdot
.66647 .54722 Mdot
.39661 .36734 Mdot
.64683 .55116 Mdot
.47898 .37996 Mdot
.26161 .61324 Mdot
.68906 .53454 Mdot
.47074 .37197 Mdot
.50135 .40238 Mdot
.37234 .60955 Mdot
.4702 .40592 Mdot
.35221 .48358 Mdot
.61729 .54252 Mdot
.47524 .3864 Mdot
.2285 .39377 Mdot
.52774 .63062 Mdot
.50042 .40891 Mdot
.63841 .3804 Mdot
.63298 .28813 Mdot
.45939 .73937 Mdot
.64257 .72023 Mdot
.63853 .37299 Mdot
.43911 .43106 Mdot
.6999 .53679 Mdot
.56678 .65764 Mdot
.80096 .42686 Mdot
.41935 .43191 Mdot
.55592 .65943 Mdot
.53645 .65327 Mdot
.63451 .37934 Mdot
.56958 .1605 Mdot
.45058 .4522 Mdot
.45187 .40029 Mdot
.36131 .51173 Mdot
.3098 .60865 Mdot
.4414 .406 Mdot
.43193 .34512 Mdot
.55294 .61975 Mdot
.5055 .35136 Mdot
.31335 .49324 Mdot
.69 .30685 Mdot
.53464 .60953 Mdot
.578 .46329 Mdot
.68547 .54466 Mdot
.62032 .38706 Mdot
.34998 .59201 Mdot
.59779 .34819 Mdot
.69231 .50862 Mdot
.41808 .34812 Mdot
.56592 .6244 Mdot
.33081 .40927 Mdot
.5688 .65576 Mdot
.64422 .71214 Mdot
.32057 .62146 Mdot
.42889 .6817 Mdot
.86573 .45349 Mdot
.42933 .74543 Mdot
.5128 .69958 Mdot
.59862 .37463 Mdot
.61276 .5084 Mdot
.43192 .37434 Mdot
.3155 .34689 Mdot
.42819 .4203 Mdot
.23213 .39449 Mdot
.6492 .4986 Mdot
.70219 .51568 Mdot
.41948 .41172 Mdot
.57428 .2987 Mdot
.56324 .66661 Mdot
.52699 .66884 Mdot
.47349 .39008 Mdot
.53783 .63874 Mdot
.44265 .39439 Mdot
.67363 .51344 Mdot
.70195 .24929 Mdot
.41623 .38752 Mdot
.48781 .37543 Mdot
.58871 .60063 Mdot
.16017 .44963 Mdot
.70858 .68386 Mdot
.30044 .31069 Mdot
.42935 .82195 Mdot
.53855 .63942 Mdot
.48079 .35013 Mdot
.58058 .45753 Mdot
.65391 .4871 Mdot
.51602 .70883 Mdot
.43774 .41237 Mdot
.43946 .41551 Mdot
.41309 .42326 Mdot
.44603 .36219 Mdot
.30964 .35749 Mdot
.36704 .47328 Mdot
.22617 .44953 Mdot
.46977 .39404 Mdot
.45386 .27683 Mdot
.51393 .63224 Mdot
.37895 .62568 Mdot
.58899 .35106 Mdot
.47055 .41335 Mdot
.3619 .46595 Mdot
.50382 .63804 Mdot
.33167 .80398 Mdot
.51485 .65441 Mdot
.64507 .51921 Mdot
.54237 .67925 Mdot
.39812 .38426 Mdot
.35647 .58649 Mdot
.56526 .50288 Mdot
.67651 .60886 Mdot
.68247 .52682 Mdot
.39538 .39262 Mdot
.62895 .68835 Mdot
.68624 .52523 Mdot
.35315 .69561 Mdot
.35154 .58524 Mdot
.50856 .28279 Mdot
.36227 .61517 Mdot
.47107 .37127 Mdot
.46226 .3614 Mdot
.50428 .605 Mdot
.56519 .66805 Mdot
.35869 .61768 Mdot
.60604 .1658 Mdot
.58871 .35928 Mdot
.36936 .57579 Mdot
.36965 .3783 Mdot
.46632 .55901 Mdot
.35446 .57932 Mdot
.64473 .32488 Mdot
.52069 .65162 Mdot
.38957 .58709 Mdot
.36766 .38352 Mdot
.77403 .62367 Mdot
.62138 .40246 Mdot
.70994 .52917 Mdot
.65138 .57917 Mdot
.61733 .53468 Mdot
.51395 .67677 Mdot
.67213 .53919 Mdot
.55872 .63183 Mdot
.53731 .73843 Mdot
.37868 .26737 Mdot
.55057 .68877 Mdot
.52463 .6802 Mdot
.67193 .53694 Mdot
.40645 .41437 Mdot
.62472 .57354 Mdot
.45698 .33685 Mdot
.39076 .44349 Mdot
.55182 .62904 Mdot
.381 .60617 Mdot
.36949 .55686 Mdot
.47299 .28676 Mdot
.32965 .5685 Mdot
.67004 .50991 Mdot
.81453 .41632 Mdot
.63098 .74819 Mdot
.5611 .64337 Mdot
.52115 .6759 Mdot
.43507 .36068 Mdot
.6447 .54067 Mdot
.63135 .54778 Mdot
.52968 .665 Mdot
.36173 .30456 Mdot
.49368 .3809 Mdot
.39966 .59247 Mdot
.38719 .59131 Mdot
.36269 .58162 Mdot
.36642 .62403 Mdot
.30613 .46176 Mdot
.52049 .65408 Mdot
.37833 .61019 Mdot
.47255 .37892 Mdot
.43988 .41416 Mdot
.57218 .50533 Mdot
.63753 .36563 Mdot
.3814 .39496 Mdot
.40574 .33971 Mdot
.45875 .38778 Mdot
.6852 .50668 Mdot
.37888 .43813 Mdot
.68487 .54145 Mdot
.70409 .53842 Mdot
.68298 .4897 Mdot
.6134 .71864 Mdot
.52901 .33782 Mdot
.47495 .83698 Mdot
.42189 .3547 Mdot
.40329 .62867 Mdot
.63925 .54462 Mdot
.75814 .32378 Mdot
.45678 .65832 Mdot
.41713 .42892 Mdot
.76439 .50474 Mdot
.65602 .53578 Mdot
.33339 .56452 Mdot
.4359 .41026 Mdot
.70293 .5443 Mdot
.63658 .38999 Mdot
.38135 .35318 Mdot
.61349 .53642 Mdot
.32881 .61581 Mdot
.57816 .37363 Mdot
.38739 .59993 Mdot
.67371 .48868 Mdot
.50105 .40457 Mdot
.66965 .8279 Mdot
.65897 .56153 Mdot
.17463 .50012 Mdot
.29599 .61416 Mdot
.41052 .4145 Mdot
.6288 .51583 Mdot
.30953 .60313 Mdot
.51311 .6776 Mdot
.46225 .5135 Mdot
.34183 .56539 Mdot
.702 .51645 Mdot
.61485 .53486 Mdot
.68185 .53083 Mdot
.34047 .60113 Mdot
.47753 .36034 Mdot
.33364 .59753 Mdot
.53905 .67905 Mdot
.42103 .37195 Mdot
.34499 .78902 Mdot
.41147 .61236 Mdot
.356 .62025 Mdot
.6561 .50407 Mdot
.59405 .39158 Mdot
.40795 .38715 Mdot
.18067 .46229 Mdot
.39127 .39306 Mdot
.56455 .64517 Mdot
.67639 .25482 Mdot
.32871 .40633 Mdot
.42571 .44414 Mdot
.43603 .36051 Mdot
.53522 .67206 Mdot
.40155 .39961 Mdot
.42232 .44162 Mdot
.61004 .71072 Mdot
.33928 .60805 Mdot
.43168 .37998 Mdot
.64806 .5036 Mdot
.59126 .75933 Mdot
.48471 .36145 Mdot
.73628 .40066 Mdot
.53318 .29123 Mdot
.63721 .2155 Mdot
.42524 .42136 Mdot
.46029 .22243 Mdot
.45367 .36569 Mdot
.44845 .42799 Mdot
.42739 .35857 Mdot
.32551 .29451 Mdot
.69173 .52588 Mdot
.67692 .52253 Mdot
.62483 .40203 Mdot
.53038 .29161 Mdot
.60691 .37777 Mdot
.51695 .64648 Mdot
.71771 .40234 Mdot
.68911 .53403 Mdot
.32979 .61752 Mdot
.44341 .43335 Mdot
.65362 .56259 Mdot
.46103 .3972 Mdot
.39723 .38201 Mdot
.65275 .55575 Mdot
.66235 .55851 Mdot
.63924 .7071 Mdot
.64046 .38228 Mdot
.36179 .56681 Mdot
.38211 .37866 Mdot
.59314 .37899 Mdot
.482 .37007 Mdot
.5637 .2364 Mdot
.36014 .5681 Mdot
.33736 .60592 Mdot
.35343 .55553 Mdot
.41728 .34856 Mdot
.39971 .38912 Mdot
.54493 .62005 Mdot
.32674 .61817 Mdot
.52805 .63224 Mdot
.55083 .50033 Mdot
.72859 .38169 Mdot
.43782 .4125 Mdot
.3442 .68009 Mdot
.61053 .38673 Mdot
.6552 .51428 Mdot
.76231 .40895 Mdot
.62004 .40352 Mdot
.39218 .3894 Mdot
.64553 .55269 Mdot
.61451 .35296 Mdot
.48259 .31734 Mdot
.54381 .83564 Mdot
.58639 .38141 Mdot
.47266 .38164 Mdot
.5224 .38329 Mdot
.32033 .2656 Mdot
.58991 .39182 Mdot
.56751 .63521 Mdot
.41384 .34967 Mdot
.41056 .5373 Mdot
.61886 .34478 Mdot
.55525 .75293 Mdot
.66257 .52708 Mdot
.72764 .68507 Mdot
.41326 .46309 Mdot
.33321 .31512 Mdot
.59879 .3507 Mdot
.35643 .60635 Mdot
.34862 .64434 Mdot
.45478 .37875 Mdot
.58774 .38987 Mdot
.54347 .60724 Mdot
.65879 .52318 Mdot
.60203 .72468 Mdot
.33906 .59897 Mdot
.39642 .67907 Mdot
.66465 .49895 Mdot
.35428 .68465 Mdot
.69037 .28819 Mdot
.41244 .47313 Mdot
.3094 .29587 Mdot
.75072 .56384 Mdot
.41119 .34814 Mdot
.58693 .3646 Mdot
.51347 .6272 Mdot
.57042 .64038 Mdot
.55076 .63945 Mdot
.55425 .72638 Mdot
.57534 .52313 Mdot
.65277 .49153 Mdot
.71657 .58129 Mdot
.62237 .38429 Mdot
.44914 .26364 Mdot
.48401 .39108 Mdot
.42288 .38103 Mdot
.39496 .42299 Mdot
.46445 .42588 Mdot
.45102 .36995 Mdot
.52845 .6389 Mdot
.56276 .72789 Mdot
.58022 .47493 Mdot
.35543 .57233 Mdot
.67402 .35361 Mdot
.6433 .54951 Mdot
.67463 .48433 Mdot
.6266 .35916 Mdot
.31246 .68429 Mdot
.63658 .502 Mdot
.63889 .51997 Mdot
.38818 .39972 Mdot
.32897 .60056 Mdot
.41717 .31592 Mdot
.45649 .35961 Mdot
.66226 .51423 Mdot
.56789 .42841 Mdot
.33056 .48316 Mdot
.35963 .37189 Mdot
.57235 .37991 Mdot
.52385 .56466 Mdot
.58764 .38776 Mdot
.48703 .3911 Mdot
.74353 .30972 Mdot
.69289 .51084 Mdot
.64162 .53087 Mdot
.59273 .35937 Mdot
.3039 .65631 Mdot
.34344 .59084 Mdot
.6729 .47823 Mdot
.56284 .62958 Mdot
.45208 .35307 Mdot
.74342 .37574 Mdot
.3166 .66189 Mdot
.69444 .37755 Mdot
.5559 .64236 Mdot
.63025 .54453 Mdot
.40653 .43323 Mdot
.47174 .38052 Mdot
.59755 .37929 Mdot
.39283 .77935 Mdot
.38387 .35497 Mdot
.2199 .64445 Mdot
.81452 .52728 Mdot
.77313 .64 Mdot
.45618 .38942 Mdot
.34063 .60696 Mdot
.61635 .5261 Mdot
.59479 .37859 Mdot
.39045 .43183 Mdot
.52308 .83793 Mdot
.35513 .63568 Mdot
.53659 .66135 Mdot
.56671 .46932 Mdot
.58267 .544 Mdot
.38817 .37986 Mdot
.42838 .41895 Mdot
.44614 .42332 Mdot
.61996 .80658 Mdot
.67988 .50594 Mdot
.31492 .5988 Mdot
.62802 .36908 Mdot
.32699 .57079 Mdot
.67464 .52689 Mdot
.40956 .68215 Mdot
.39714 .40803 Mdot
.35224 .63612 Mdot
.35619 .6036 Mdot
.5192 .65951 Mdot
.52355 .68196 Mdot
.5572 .48837 Mdot
.43176 .40441 Mdot
.61671 .55777 Mdot
.37702 .60613 Mdot
.6108 .57828 Mdot
.6003 .36483 Mdot
.52253 .6254 Mdot
.46923 .39679 Mdot
.69175 .51751 Mdot
.41983 .44824 Mdot
.34296 .57723 Mdot
.63795 .52159 Mdot
.63636 .70556 Mdot
.64189 .37529 Mdot
.45246 .41279 Mdot
.57215 .3674 Mdot
.66546 .54785 Mdot
.43364 .37219 Mdot
.29189 .66653 Mdot
.59584 .40467 Mdot
.6487 .61874 Mdot
.65722 .49178 Mdot
.63403 .71249 Mdot
.36295 .5579 Mdot
.51698 .73514 Mdot
.64364 .52615 Mdot
.29596 .67588 Mdot
.45171 .78767 Mdot
.37666 .39219 Mdot
.36861 .59251 Mdot
.63213 .48674 Mdot
.26746 .74795 Mdot
.24697 .33465 Mdot
.41012 .39908 Mdot
.64466 .49968 Mdot
.59313 .36192 Mdot
.56087 .6419 Mdot
.73691 .39885 Mdot
.56363 .35683 Mdot
.68175 .55112 Mdot
.42898 .35702 Mdot
.35175 .61571 Mdot
.5268 .65179 Mdot
.47826 .74374 Mdot
.63318 .52175 Mdot
.66378 .49578 Mdot
.41041 .43593 Mdot
.61346 .37729 Mdot
.20867 .40181 Mdot
.67675 .51466 Mdot
.78196 .46444 Mdot
.60203 .53617 Mdot
.58875 .36819 Mdot
.46137 .36982 Mdot
.49623 .30293 Mdot
.43863 .33672 Mdot
.17541 .53222 Mdot
.66204 .5453 Mdot
.34873 .57098 Mdot
.43218 .42538 Mdot
.68244 .29552 Mdot
.65884 .51662 Mdot
.54078 .56689 Mdot
.71442 .47148 Mdot
.5209 .65331 Mdot
.76615 .41319 Mdot
.44858 .40552 Mdot
.56518 .66288 Mdot
.60995 .38607 Mdot
.42321 .40363 Mdot
.40135 .38604 Mdot
.31265 .58687 Mdot
.53523 .66517 Mdot
.48263 .80436 Mdot
.5055 .65434 Mdot
.53042 .61845 Mdot
.33417 .55812 Mdot
.4432 .38292 Mdot
.64598 .51654 Mdot
.65378 .5368 Mdot
.38736 .43503 Mdot
.76492 .31651 Mdot
.34103 .59132 Mdot
.67134 .3857 Mdot
.63964 .79864 Mdot
.42403 .47339 Mdot
.76014 .40309 Mdot
.38833 .77528 Mdot
.54797 .60863 Mdot
.47217 .39219 Mdot
.33896 .61948 Mdot
.6773 .47831 Mdot
.65995 .49843 Mdot
.47417 .35874 Mdot
.53375 .64984 Mdot
.63354 .39395 Mdot
.6315 .55634 Mdot
.68892 .3659 Mdot
.45489 .42207 Mdot
.77146 .51393 Mdot
.62322 .52695 Mdot
.20689 .65542 Mdot
.63097 .49558 Mdot
.36897 .58745 Mdot
.39937 .3801 Mdot
.3382 .56443 Mdot
.62287 .36438 Mdot
.56423 .47676 Mdot
.53377 .65195 Mdot
.49147 .46229 Mdot
.85273 .55581 Mdot
.67996 .53544 Mdot
.31838 .5912 Mdot
.42685 .44477 Mdot
.54492 .38171 Mdot
.4476 .40063 Mdot
.51764 .40418 Mdot
.61585 .41807 Mdot
.5446 .62678 Mdot
.56622 .64314 Mdot
.42834 .37267 Mdot
.61266 .39479 Mdot
.62996 .54208 Mdot
.65602 .52269 Mdot
.13267 .44933 Mdot
.64058 .60191 Mdot
.60393 .29691 Mdot
.44343 .4154 Mdot
.70049 .52501 Mdot
.53802 .77945 Mdot
.5597 .65496 Mdot
.48226 .40233 Mdot
.67406 .54876 Mdot
.78443 .57818 Mdot
.63265 .27504 Mdot
.45465 .37094 Mdot
.44682 .4576 Mdot
.564 .63006 Mdot
.45624 .24929 Mdot
.67791 .49004 Mdot
.44254 .33167 Mdot
.57383 .6671 Mdot
.65663 .25346 Mdot
.72272 .71499 Mdot
.36251 .56706 Mdot
.69742 .46737 Mdot
.52757 .63926 Mdot
.3812 .43521 Mdot
.62935 .38638 Mdot
.62042 .55364 Mdot
.68604 .51107 Mdot
.41753 .36071 Mdot
.42217 .4479 Mdot
.56058 .33502 Mdot
.32205 .58523 Mdot
.51342 .63471 Mdot
.41888 .4195 Mdot
.42357 .65023 Mdot
.44755 .4392 Mdot
.53886 .62115 Mdot
.63318 .86168 Mdot
.38011 .37884 Mdot
.44915 .39892 Mdot
.20888 .39772 Mdot
.34358 .56449 Mdot
.32597 .56993 Mdot
.81438 .49395 Mdot
.44427 .41526 Mdot
.77871 .43642 Mdot
.36113 .5652 Mdot
.34106 .58751 Mdot
.61427 .66161 Mdot
.41247 .38602 Mdot
.39022 .23872 Mdot
.56471 .65899 Mdot
.54726 .61549 Mdot
.33499 .59675 Mdot
.37912 .37191 Mdot
.56141 .61496 Mdot
.30103 .39654 Mdot
.64513 .5419 Mdot
.73108 .29429 Mdot
.33695 .57741 Mdot
.52649 .49195 Mdot
.55934 .64682 Mdot
.32517 .80067 Mdot
.73331 .55396 Mdot
.4092 .41584 Mdot
.4517 .41591 Mdot
.61464 .38799 Mdot
.37953 .38338 Mdot
.70223 .51341 Mdot
.53763 .63842 Mdot
.19414 .47327 Mdot
.3675 .57225 Mdot
.43651 .40057 Mdot
.34143 .68901 Mdot
.47244 .76323 Mdot
.72974 .64827 Mdot
.34827 .59814 Mdot
.37216 .59378 Mdot
.6747 .49051 Mdot
.64028 .50444 Mdot
.44885 .37938 Mdot
.53817 .67061 Mdot
.3327 .621 Mdot
.54557 .62319 Mdot
.69209 .50975 Mdot
.64541 .51439 Mdot
.69173 .53204 Mdot
.42338 .32527 Mdot
.63987 .51508 Mdot
.68632 .34816 Mdot
.39585 .68585 Mdot
.38226 .55844 Mdot
.79343 .6493 Mdot
.47857 .74189 Mdot
.4168 .51905 Mdot
.63068 .35252 Mdot
.66512 .54826 Mdot
.52692 .67631 Mdot
.43669 .36334 Mdot
.4647 .39764 Mdot
.71686 .52169 Mdot
.54466 .67647 Mdot
.61528 .35971 Mdot
.55849 .67321 Mdot
.63485 .38051 Mdot
.76074 .51611 Mdot
.39956 .42547 Mdot
.4727 .36809 Mdot
.53376 .6363 Mdot
.63744 .52001 Mdot
.66981 .5213 Mdot
.5837 .38031 Mdot
.47218 .4951 Mdot
.68651 .52734 Mdot
.33847 .5772 Mdot
.29668 .45092 Mdot
.61533 .53097 Mdot
.43816 .40866 Mdot
.53551 .22003 Mdot
.32165 .34632 Mdot
.45014 .33891 Mdot
.60944 .68562 Mdot
.43381 .1947 Mdot
.43208 .43044 Mdot
.44473 .18359 Mdot
.63242 .71366 Mdot
.33751 .56682 Mdot
.65372 .49553 Mdot
.68273 .48094 Mdot
.51179 .37962 Mdot
.61319 .33754 Mdot
.38613 .42913 Mdot
.3492 .56261 Mdot
.33121 .63948 Mdot
.79311 .58591 Mdot
.17389 .50405 Mdot
.59812 .35402 Mdot
.6275 .35732 Mdot
.64547 .52658 Mdot
.23177 .32237 Mdot
.36361 .36755 Mdot
.61147 .3574 Mdot
.38607 .2634 Mdot
.43051 .35498 Mdot
.56307 .27417 Mdot
.77311 .47926 Mdot
.33907 .60294 Mdot
.49222 .30234 Mdot
.64915 .51928 Mdot
.32588 .57795 Mdot
.43557 .64562 Mdot
.38347 .3863 Mdot
.3618 .56924 Mdot
.54841 .62265 Mdot
.73789 .5923 Mdot
.37356 .56658 Mdot
.54791 .22496 Mdot
.53045 .66638 Mdot
.59928 .57725 Mdot
.48146 .27961 Mdot
.8302 .32503 Mdot
.53075 .64039 Mdot
.66511 .55555 Mdot
.65411 .5359 Mdot
.65459 .52353 Mdot
.3253 .57596 Mdot
.63546 .55011 Mdot
.32046 .59051 Mdot
.29149 .28008 Mdot
.46816 .49596 Mdot
.60929 .35598 Mdot
.60468 .69959 Mdot
.36407 .60226 Mdot
.80317 .3864 Mdot
.86211 .4874 Mdot
.47268 .39609 Mdot
.51106 .66623 Mdot
.60492 .35381 Mdot
.18927 .60453 Mdot
.60683 .38177 Mdot
.6269 .44511 Mdot
.69814 .26294 Mdot
.43737 .39499 Mdot
.28301 .53207 Mdot
.63788 .36085 Mdot
.35017 .60879 Mdot
.42995 .37469 Mdot
.49048 .68361 Mdot
.61299 .38226 Mdot
.63126 .39386 Mdot
.44352 .37507 Mdot
.38114 .59562 Mdot
.65121 .51217 Mdot
.55883 .67678 Mdot
.62946 .40651 Mdot
.34006 .6518 Mdot
.39997 .3543 Mdot
.39953 .36171 Mdot
.57446 .55837 Mdot
.61153 .32946 Mdot
.53818 .63993 Mdot
.35448 .25835 Mdot
.64372 .50198 Mdot
.63213 .47069 Mdot
.8033 .51192 Mdot
.61208 .69475 Mdot
.66438 .54321 Mdot
.66774 .54562 Mdot
.45171 .37291 Mdot
.61191 .32556 Mdot
.65774 .2373 Mdot
.54971 .71087 Mdot
.6186 .52321 Mdot
.65867 .52143 Mdot
.34413 .64186 Mdot
.79833 .58235 Mdot
.39204 .43236 Mdot
.52037 .62041 Mdot
.69046 .51692 Mdot
.26105 .61901 Mdot
.61787 .37727 Mdot
.77906 .35396 Mdot
.4019 .42648 Mdot
.41549 .4174 Mdot
.54691 .64739 Mdot
.54286 .61869 Mdot
.48508 .61993 Mdot
.81506 .54414 Mdot
.39367 .2211 Mdot
.51802 .74998 Mdot
.2687 .59195 Mdot
.36659 .63279 Mdot
.35712 .61985 Mdot
.59039 .7213 Mdot
.50362 .64696 Mdot
.43333 .42825 Mdot
.33263 .6199 Mdot
.72632 .63246 Mdot
.4138 .59105 Mdot
.57899 .28744 Mdot
.71437 .35073 Mdot
.39255 .38471 Mdot
.33164 .60869 Mdot
.34041 .56782 Mdot
.34699 .62596 Mdot
.63084 .71368 Mdot
.44995 .38843 Mdot
.40322 .40632 Mdot
.43514 .43622 Mdot
.34487 .36565 Mdot
.46394 .41431 Mdot
.57192 .70947 Mdot
.54824 .53648 Mdot
.21277 .54386 Mdot
.43039 .33188 Mdot
.54849 .61093 Mdot
.3906 .37056 Mdot
.61561 .39598 Mdot
.43025 .35907 Mdot
.58625 .2878 Mdot
.54987 .66016 Mdot
.29357 .62653 Mdot
.51423 .74448 Mdot
.39734 .41495 Mdot
.64217 .39023 Mdot
.401 .51335 Mdot
.42415 .80182 Mdot
.62528 .33712 Mdot
.33787 .57796 Mdot
.65037 .54503 Mdot
.53113 .67649 Mdot
.64133 .52164 Mdot
.41477 .32814 Mdot
.60187 .67684 Mdot
.38798 .74399 Mdot
.54691 .48084 Mdot
.46887 .41798 Mdot
.38441 .45195 Mdot
.33966 .58164 Mdot
.6461 .55285 Mdot
.39784 .56037 Mdot
.43694 .42391 Mdot
.62514 .36909 Mdot
.61686 .38433 Mdot
.46535 .64827 Mdot
.2856 .7187 Mdot
.50823 .72477 Mdot
.54604 .64476 Mdot
.67864 .5133 Mdot
.59389 .35319 Mdot
.37732 .65393 Mdot
.50148 .67005 Mdot
.53404 .67229 Mdot
.52998 .66205 Mdot
.43143 .34782 Mdot
.68507 .54144 Mdot
.20974 .52947 Mdot
.70085 .52076 Mdot
.39849 .39698 Mdot
.67826 .50338 Mdot
.67983 .54189 Mdot
.62136 .38929 Mdot
.51217 .64707 Mdot
.6868 .50041 Mdot
.47189 .3721 Mdot
.37605 .57578 Mdot
.50809 .487 Mdot
.59797 .26316 Mdot
.19171 .56271 Mdot
.20739 .5736 Mdot
.38514 .57807 Mdot
.29096 .75361 Mdot
.51191 .62341 Mdot
.36365 .30306 Mdot
.66921 .69253 Mdot
.46876 .35713 Mdot
.81535 .38962 Mdot
.65267 .49125 Mdot
.65601 .55601 Mdot
.4592 .36702 Mdot
.70053 .47378 Mdot
.44043 .40006 Mdot
.67764 .49874 Mdot
.67316 .35908 Mdot
.50221 .41114 Mdot
.62997 .53183 Mdot
.44843 .33123 Mdot
.41144 .3826 Mdot
.33798 .60407 Mdot
.62558 .52002 Mdot
.48127 .40673 Mdot
.14603 .53695 Mdot
.53321 .62101 Mdot
.62486 .69652 Mdot
.53117 .20873 Mdot
.52642 .63889 Mdot
.36766 .57636 Mdot
.39002 .44188 Mdot
.60293 .38348 Mdot
.3626 .60756 Mdot
.64449 .2763 Mdot
.63806 .36295 Mdot
.81293 .39632 Mdot
.33364 .58248 Mdot
.61742 .52748 Mdot
.62791 .39021 Mdot
.47481 .34565 Mdot
.62607 .5564 Mdot
.43893 .51885 Mdot
.65952 .54566 Mdot
.45768 .39528 Mdot
.59693 .72765 Mdot
.51655 .62824 Mdot
.41259 .39845 Mdot
.63429 .55607 Mdot
.60966 .71966 Mdot
.42894 .34924 Mdot
.44236 .36488 Mdot
.77197 .65117 Mdot
.78328 .38927 Mdot
.59793 .37091 Mdot
.31243 .60814 Mdot
.47253 .37841 Mdot
.63736 .38635 Mdot
.71228 .44994 Mdot
.40283 .35541 Mdot
.35297 .63403 Mdot
.35569 .36739 Mdot
.62031 .5408 Mdot
.52313 .63432 Mdot
.54473 .49468 Mdot
.63735 .38904 Mdot
.51999 .13484 Mdot
.69747 .52316 Mdot
.48655 .39645 Mdot
.4694 .42039 Mdot
.71708 .67532 Mdot
.33278 .57262 Mdot
.40175 .22216 Mdot
.45249 .41304 Mdot
.34579 .38839 Mdot
.42317 .4007 Mdot
.62349 .45485 Mdot
.34231 .59013 Mdot
.45286 .39941 Mdot
.37137 .67729 Mdot
.49031 .37689 Mdot
.6393 .3902 Mdot
.22865 .36077 Mdot
.41251 .34651 Mdot
.78494 .73141 Mdot
.77324 .43473 Mdot
.63097 .5286 Mdot
.58746 .72985 Mdot
.2342 .28016 Mdot
.53218 .73714 Mdot
.31904 .59428 Mdot
.38137 .76498 Mdot
.64616 .51565 Mdot
.55613 .75912 Mdot
.28541 .75493 Mdot
.41215 .38033 Mdot
.3881 .3803 Mdot
.62596 .44501 Mdot
.7029 .50819 Mdot
.613 .55453 Mdot
.41684 .33079 Mdot
.37215 .34649 Mdot
.6495 .50629 Mdot
.47655 .38369 Mdot
.44933 .32512 Mdot
.54915 .68077 Mdot
.38407 .57993 Mdot
.55715 .63553 Mdot
.51526 .65799 Mdot
.28366 .35425 Mdot
.80743 .55215 Mdot
.533 .62263 Mdot
.51551 .62119 Mdot
.57006 .27457 Mdot
.54573 .3326 Mdot
.62113 .34598 Mdot
.24638 .67968 Mdot
.6556 .52582 Mdot
.44696 .38791 Mdot
.38339 .57082 Mdot
.33904 .30598 Mdot
.75455 .43746 Mdot
.66993 .24192 Mdot
.43608 .4263 Mdot
.65416 .5185 Mdot
.63107 .7158 Mdot
.42792 .31647 Mdot
.61038 .49238 Mdot
.4138 .41975 Mdot
.64919 .5623 Mdot
.28745 .48692 Mdot
.31769 .6814 Mdot
.60477 .54766 Mdot
.39886 .60865 Mdot
.42255 .41529 Mdot
.33716 .5753 Mdot
.55501 .6385 Mdot
.61468 .39293 Mdot
.59929 .36965 Mdot
.43784 .37182 Mdot
.37524 .45281 Mdot
.76019 .51023 Mdot
.4074 .38666 Mdot
.42226 .36262 Mdot
.63251 .71382 Mdot
.42259 .36467 Mdot
.46314 .42571 Mdot
.45046 .43425 Mdot
.48813 .41636 Mdot
.5362 .61645 Mdot
.34229 .68799 Mdot
.39941 .33088 Mdot
.4386 .31964 Mdot
.57315 .6581 Mdot
.41932 .78885 Mdot
.5123 .65798 Mdot
.34966 .79211 Mdot
.56365 .64184 Mdot
.60467 .36156 Mdot
.64853 .72864 Mdot
.38273 .45611 Mdot
.37461 .6152 Mdot
.50287 .66697 Mdot
.63258 .37309 Mdot
.54472 .63764 Mdot
.66852 .49923 Mdot
.67119 .76819 Mdot
.37244 .64434 Mdot
.4383 .2169 Mdot
.4672 .65702 Mdot
.65991 .6079 Mdot
.69425 .50595 Mdot
.33846 .59284 Mdot
.33121 .49187 Mdot
.45569 .43378 Mdot
.63668 .38545 Mdot
.44783 .37569 Mdot
.52224 .62134 Mdot
.6499 .52166 Mdot
.22946 .35428 Mdot
.5989 .38072 Mdot
.79599 .63234 Mdot
.66516 .52673 Mdot
.4343 .44021 Mdot
.52303 .61928 Mdot
.82107 .61498 Mdot
.55143 .63012 Mdot
.43273 .49173 Mdot
.39197 .60939 Mdot
.30103 .30422 Mdot
.36619 .59648 Mdot
.63873 .49451 Mdot
.6774 .79232 Mdot
.22803 .63983 Mdot
.38064 .58955 Mdot
.69242 .5895 Mdot
.39457 .37143 Mdot
.39713 .36388 Mdot
.3012 .66394 Mdot
.31866 .61722 Mdot
.47208 .40061 Mdot
.6342 .70285 Mdot
.40102 .70391 Mdot
.77537 .41272 Mdot
.6538 .54957 Mdot
.44416 .40417 Mdot
.57438 .66079 Mdot
.557 .67344 Mdot
.69848 .52665 Mdot
.5121 .66039 Mdot
.40409 .40525 Mdot
.36451 .6003 Mdot
.63126 .56437 Mdot
.6088 .36795 Mdot
.15445 .49415 Mdot
.59171 .35234 Mdot
.66545 .54237 Mdot
.50041 .40567 Mdot
.64492 .51454 Mdot
.29034 .20444 Mdot
.4078 .40999 Mdot
.35582 .5653 Mdot
.44524 .35832 Mdot
.42152 .41147 Mdot
.38841 .37742 Mdot
.65862 .50181 Mdot
.43551 .20446 Mdot
.47518 .3783 Mdot
.53248 .65278 Mdot
.22844 .57343 Mdot
.38788 .37492 Mdot
.66891 .36993 Mdot
.55272 .30658 Mdot
.72301 .5771 Mdot
.39084 .57986 Mdot
.63531 .54477 Mdot
.37293 .57651 Mdot
.40792 .60464 Mdot
.36725 .57603 Mdot
.24161 .55567 Mdot
.32068 .49169 Mdot
.47757 .18954 Mdot
.22386 .40413 Mdot
.42183 .2889 Mdot
.31464 .61219 Mdot
.59946 .42506 Mdot
.35175 .62263 Mdot
.33626 .57229 Mdot
.42969 .91073 Mdot
.37128 .61515 Mdot
.44347 .41059 Mdot
.38621 .40444 Mdot
.44648 .74948 Mdot
.53817 .25844 Mdot
.42742 .36786 Mdot
.46618 .3689 Mdot
.61587 .39172 Mdot
.37106 .45754 Mdot
.60225 .67796 Mdot
.81444 .42792 Mdot
.49448 .76916 Mdot
.44565 .37441 Mdot
.47138 .37394 Mdot
.3951 .32439 Mdot
.81483 .66174 Mdot
.29862 .35038 Mdot
.32029 .62423 Mdot
.37492 .42586 Mdot
.18165 .56612 Mdot
.4031 .418 Mdot
.43101 .34484 Mdot
.39233 .38126 Mdot
.64638 .51596 Mdot
.36249 .63287 Mdot
.37052 .40958 Mdot
.78814 .49844 Mdot
.39526 .40931 Mdot
.61098 .69762 Mdot
.3081 .23362 Mdot
.44946 .40582 Mdot
.38156 .61365 Mdot
.4106 .35874 Mdot
.32981 .58565 Mdot
.3437 .61207 Mdot
.49753 .40012 Mdot
.25824 .58842 Mdot
.37665 .62318 Mdot
.39797 .39585 Mdot
.65713 .50775 Mdot
.23751 .68158 Mdot
.45872 .39752 Mdot
.59385 .37938 Mdot
.4506 .41526 Mdot
.64084 .39407 Mdot
.41634 .36838 Mdot
.69703 .53014 Mdot
.32462 .39238 Mdot
.64338 .53067 Mdot
.33767 .23555 Mdot
.68465 .54434 Mdot
.77778 .64493 Mdot
.33352 .63205 Mdot
.60099 .72136 Mdot
.60168 .18103 Mdot
.61888 .69168 Mdot
.50715 .57463 Mdot
.49813 .56025 Mdot
.53715 .6707 Mdot
.3433 .56119 Mdot
.42286 .2521 Mdot
.72676 .64493 Mdot
.70178 .68178 Mdot
.6856 .53497 Mdot
.60008 .16631 Mdot
.70038 .25369 Mdot
.4585 .35637 Mdot
.26709 .54247 Mdot
.23071 .46127 Mdot
.40855 .3502 Mdot
.38969 .44311 Mdot
.71122 .53274 Mdot
.47418 .41478 Mdot
.41636 .65335 Mdot
.67011 .53698 Mdot
.63409 .3752 Mdot
.34403 .57131 Mdot
.62451 .40088 Mdot
.7186 .65715 Mdot
.49348 .56428 Mdot
.6847 .50265 Mdot
.49189 .3931 Mdot
.45238 .36017 Mdot
.33277 .60011 Mdot
.35429 .53731 Mdot
.37154 .6099 Mdot
.59679 .35645 Mdot
.66759 .535 Mdot
.31699 .33389 Mdot
.46843 .3779 Mdot
.35648 .60102 Mdot
.47696 .60884 Mdot
.47237 .38281 Mdot
.53792 .63321 Mdot
.39231 .39316 Mdot
.38033 .58131 Mdot
.42234 .36496 Mdot
.36667 .59989 Mdot
.64575 .54417 Mdot
.40542 .42426 Mdot
.45828 .36926 Mdot
.80822 .63 Mdot
.61398 .36052 Mdot
.32307 .623 Mdot
.70711 .47438 Mdot
.45474 .43767 Mdot
.65085 .63303 Mdot
.42541 .41826 Mdot
.4068 .55734 Mdot
.48795 .3863 Mdot
.62317 .71719 Mdot
.3957 .43297 Mdot
.45788 .39764 Mdot
.45645 .60123 Mdot
.23105 .49484 Mdot
.34743 .53633 Mdot
.53451 .61409 Mdot
.36263 .62573 Mdot
.73665 .37345 Mdot
.62889 .50897 Mdot
.63602 .5517 Mdot
.48141 .23995 Mdot
.4774 .43613 Mdot
.43897 .39409 Mdot
.56233 .68057 Mdot
.63514 .36504 Mdot
.34945 .59988 Mdot
.63454 .37937 Mdot
.80048 .50168 Mdot
.61445 .3509 Mdot
.69107 .48622 Mdot
.76638 .50876 Mdot
.30928 .37318 Mdot
.61631 .39149 Mdot
.38138 .59736 Mdot
.70678 .35126 Mdot
.46842 .35261 Mdot
.56296 .36752 Mdot
.62408 .36993 Mdot
.58691 .15363 Mdot
.46545 .42224 Mdot
.5182 .57206 Mdot
.53054 .62633 Mdot
.62766 .38764 Mdot
.54388 .66716 Mdot
.43124 .36762 Mdot
.64192 .61998 Mdot
.31734 .605 Mdot
.5702 .62375 Mdot
.40072 .34828 Mdot
.60933 .3538 Mdot
.68923 .51744 Mdot
.49203 .62834 Mdot
.55579 .61344 Mdot
.38258 .77871 Mdot
.26329 .31931 Mdot
.66584 .53475 Mdot
.71632 .31037 Mdot
.56622 .65419 Mdot
.42213 .3446 Mdot
.35129 .42748 Mdot
.40859 .41589 Mdot
.54601 .72476 Mdot
.63767 .54761 Mdot
.39836 .72287 Mdot
.44895 .35773 Mdot
.44113 .43161 Mdot
.32992 .54654 Mdot
.64966 .53432 Mdot
.35663 .58395 Mdot
.36193 .62425 Mdot
.64625 .54331 Mdot
.36763 .58847 Mdot
.64111 .36615 Mdot
.4137 .7017 Mdot
.56906 .64429 Mdot
.53569 .65524 Mdot
.65731 .52161 Mdot
.63478 .52062 Mdot
.6396 .51968 Mdot
.39241 .39383 Mdot
.34547 .59518 Mdot
.40213 .37583 Mdot
.38882 .37758 Mdot
.29209 .57332 Mdot
.38849 .58328 Mdot
.39899 .36966 Mdot
.62743 .4902 Mdot
.56692 .36316 Mdot
.66063 .50576 Mdot
.52938 .6249 Mdot
.55743 .77587 Mdot
.54992 .60403 Mdot
.44107 .4047 Mdot
.78276 .57678 Mdot
.37849 .59904 Mdot
.6105 .38545 Mdot
.64403 .36035 Mdot
.60239 .37884 Mdot
.58169 .66463 Mdot
.33164 .62484 Mdot
.81429 .42503 Mdot
.44338 .40126 Mdot
.57546 .56036 Mdot
.39597 .25258 Mdot
.77281 .53352 Mdot
.52808 .62444 Mdot
.47136 .377 Mdot
.53983 .49177 Mdot
.33486 .47339 Mdot
.41407 .41585 Mdot
.46832 .34667 Mdot
.64546 .68413 Mdot
.36813 .33723 Mdot
.38664 .61577 Mdot
.82281 .53275 Mdot
.38272 .40819 Mdot
.28458 .64574 Mdot
.1583 .41321 Mdot
.43303 .40689 Mdot
.44439 .42567 Mdot
.46346 .38744 Mdot
.43422 .35579 Mdot
.38477 .61185 Mdot
.4881 .25879 Mdot
.50888 .62847 Mdot
.573 .53355 Mdot
.56909 .63736 Mdot
.64084 .56108 Mdot
.36636 .68882 Mdot
.35077 .55777 Mdot
.61381 .38794 Mdot
.28016 .67795 Mdot
.82482 .48537 Mdot
.67202 .4899 Mdot
.29561 .4117 Mdot
.61765 .36521 Mdot
.42944 .34189 Mdot
.64625 .39272 Mdot
.68291 .54393 Mdot
.52614 .65516 Mdot
.46439 .44894 Mdot
.36381 .61624 Mdot
.37058 .56438 Mdot
.4723 .39819 Mdot
.19978 .5984 Mdot
.53334 .6326 Mdot
.49211 .65632 Mdot
.41968 .34975 Mdot
.45628 .33707 Mdot
.35747 .58055 Mdot
.67038 .51506 Mdot
.675 .3061 Mdot
.62621 .3602 Mdot
.46053 .43917 Mdot
.43084 .35592 Mdot
.81595 .53912 Mdot
.51665 .64483 Mdot
.68267 .48751 Mdot
.43618 .34874 Mdot
.55834 .73789 Mdot
.43556 .34909 Mdot
.40644 .31425 Mdot
.65699 .50959 Mdot
.37748 .3508 Mdot
.47351 .37078 Mdot
.49235 .45499 Mdot
.55726 .6645 Mdot
.35625 .56725 Mdot
.38406 .55747 Mdot
.58582 .45281 Mdot
.54058 .63367 Mdot
.40358 .36451 Mdot
.51915 .64109 Mdot
.39425 .36478 Mdot
.47391 .40062 Mdot
.53828 .62136 Mdot
.35731 .58421 Mdot
.40291 .76703 Mdot
.35149 .68926 Mdot
.43705 .35539 Mdot
.38839 .41875 Mdot
.509 .25385 Mdot
.52815 .18406 Mdot
.43181 .42337 Mdot
.37693 .57344 Mdot
.46539 .37231 Mdot
.55008 .66401 Mdot
.62475 .35233 Mdot
.37769 .57777 Mdot
.67474 .52108 Mdot
.68552 .49354 Mdot
.51479 .74326 Mdot
.67401 .54499 Mdot
.4574 .34672 Mdot
.40525 .61433 Mdot
.3405 .55188 Mdot
.15168 .44945 Mdot
.64781 .54124 Mdot
.64369 .36468 Mdot
.43999 .3664 Mdot
.77229 .62814 Mdot
.55636 .68326 Mdot
.81913 .69893 Mdot
.81383 .40585 Mdot
.58774 .3557 Mdot
.64523 .21723 Mdot
.63057 .5613 Mdot
.47807 .39884 Mdot
.61416 .39336 Mdot
.6652 .49158 Mdot
.46084 .35217 Mdot
.46017 .45425 Mdot
.41087 .21568 Mdot
.5737 .46544 Mdot
.51847 .63904 Mdot
.62449 .53233 Mdot
.65658 .37756 Mdot
.6958 .49217 Mdot
.36923 .56203 Mdot
.45478 .39609 Mdot
.42461 .47205 Mdot
.67384 .51723 Mdot
.70176 .50469 Mdot
.39394 .38619 Mdot
.34005 .56303 Mdot
.71538 .51198 Mdot
.43891 .37537 Mdot
.40008 .29337 Mdot
.39603 .61331 Mdot
.67461 .53416 Mdot
.44583 .43356 Mdot
.57728 .33012 Mdot
.66593 .52298 Mdot
.66267 .50498 Mdot
.47308 .39822 Mdot
.64234 .36942 Mdot
.40747 .43422 Mdot
.56197 .636 Mdot
.39432 .20612 Mdot
.54479 .66463 Mdot
.72526 .38253 Mdot
.49836 .37962 Mdot
.61174 .60259 Mdot
.37057 .56012 Mdot
.65626 .36488 Mdot
.58127 .78205 Mdot
.42598 .3283 Mdot
.28217 .72901 Mdot
.5244 .50124 Mdot
.17315 .56775 Mdot
.55914 .81463 Mdot
.62328 .37358 Mdot
.54919 .63839 Mdot
.44422 .42517 Mdot
.51906 .67488 Mdot
.60279 .38847 Mdot
.32113 .26831 Mdot
.45139 .43241 Mdot
.34203 .58805 Mdot
.3957 .3972 Mdot
.33699 .5782 Mdot
.47277 .38953 Mdot
.42184 .31856 Mdot
.63586 .72334 Mdot
.62978 .27432 Mdot
.46994 .35726 Mdot
.68509 .76387 Mdot
.76323 .46377 Mdot
.62761 .36681 Mdot
.40286 .38149 Mdot
.6413 .49488 Mdot
.55144 .67452 Mdot
.42426 .60352 Mdot
.64752 .51381 Mdot
.50824 .64574 Mdot
.36334 .57934 Mdot
.64967 .54793 Mdot
.69547 .5009 Mdot
.37266 .39226 Mdot
.63493 .39608 Mdot
.52363 .65893 Mdot
.45576 .40181 Mdot
.4582 .42719 Mdot
.72029 .3247 Mdot
.74325 .42961 Mdot
.36007 .54335 Mdot
.84571 .56186 Mdot
.36657 .54925 Mdot
.61533 .35768 Mdot
.65192 .51011 Mdot
.43008 .42019 Mdot
.41183 .39626 Mdot
.60414 .72289 Mdot
.31573 .60565 Mdot
.56262 .47522 Mdot
.2764 .38179 Mdot
.71333 .51426 Mdot
.54376 .28854 Mdot
.3554 .56367 Mdot
.54343 .28665 Mdot
.6557 .37994 Mdot
.26834 .68157 Mdot
.6179 .28019 Mdot
.52674 .62807 Mdot
.53854 .28757 Mdot
.35321 .6101 Mdot
.45623 .35704 Mdot
.6216 .52077 Mdot
.6799 .54112 Mdot
.35239 .57384 Mdot
.69006 .5534 Mdot
.62269 .3877 Mdot
.4506 .42537 Mdot
.80231 .41589 Mdot
.46262 .7222 Mdot
.67624 .51051 Mdot
.44393 .31744 Mdot
.53255 .66266 Mdot
.47359 .40692 Mdot
.59306 .37661 Mdot
.52844 .64416 Mdot
.76408 .41674 Mdot
.39996 .71281 Mdot
.43439 .37058 Mdot
.7889 .61537 Mdot
.53595 .63629 Mdot
.61157 .20628 Mdot
.44388 .37989 Mdot
.56561 .65518 Mdot
.36254 .3604 Mdot
.7465 .56526 Mdot
.54248 .47994 Mdot
.28219 .75374 Mdot
.55304 .48523 Mdot
.61492 .54458 Mdot
.72472 .60384 Mdot
.69666 .66013 Mdot
.52419 .67667 Mdot
.70027 .50131 Mdot
.62937 .32826 Mdot
.54349 .66768 Mdot
.38689 .38198 Mdot
.42776 .4133 Mdot
.29846 .3391 Mdot
.51894 .5115 Mdot
.66911 .47787 Mdot
.47686 .69484 Mdot
.45192 .43857 Mdot
.37656 .38408 Mdot
.41809 .3912 Mdot
.33342 .64009 Mdot
.5207 .64909 Mdot
.75404 .69813 Mdot
.5433 .63238 Mdot
.77267 .35155 Mdot
.65415 .52528 Mdot
.62962 .54317 Mdot
.44606 .40625 Mdot
.60864 .58233 Mdot
.50937 .29901 Mdot
.40279 .40294 Mdot
.59765 .5595 Mdot
.21482 .37808 Mdot
.3912 .35947 Mdot
.39524 .60252 Mdot
.50646 .36621 Mdot
.34455 .64614 Mdot
.56999 .64725 Mdot
.61568 .37497 Mdot
.64964 .35305 Mdot
.5233 .65569 Mdot
.43741 .393 Mdot
.60839 .61542 Mdot
.41835 .40722 Mdot
.44951 .35186 Mdot
.76965 .33634 Mdot
.58921 .35585 Mdot
.63414 .53323 Mdot
.59801 .37442 Mdot
.33367 .57347 Mdot
.62217 .8793 Mdot
.63694 .36836 Mdot
.50529 .30106 Mdot
.34439 .24216 Mdot
.5354 .28471 Mdot
.36432 .56137 Mdot
.60389 .40071 Mdot
.52682 .63297 Mdot
.19722 .64669 Mdot
.49953 .17637 Mdot
.50094 .62202 Mdot
.43439 .37942 Mdot
.33938 .56079 Mdot
.3844 .59064 Mdot
.56979 .62488 Mdot
.34599 .61133 Mdot
.36412 .40466 Mdot
.44544 .35448 Mdot
.5167 .67163 Mdot
.46049 .74368 Mdot
.55567 .61319 Mdot
.41256 .68064 Mdot
.39963 .38563 Mdot
.36412 .56493 Mdot
.50682 .37103 Mdot
.30724 .62657 Mdot
.68037 .48596 Mdot
.41678 .34407 Mdot
.6208 .38853 Mdot
.5939 .60028 Mdot
.66673 .53228 Mdot
.77947 .57987 Mdot
.33245 .59669 Mdot
.5209 .58876 Mdot
.33888 .60629 Mdot
.30958 .59482 Mdot
.51648 .66042 Mdot
.32241 .61003 Mdot
.44581 .42611 Mdot
.62285 .50347 Mdot
.32616 .59281 Mdot
.54911 .65383 Mdot
.60939 .37436 Mdot
.36462 .5882 Mdot
.70553 .476 Mdot
.44868 .36647 Mdot
.66346 .49628 Mdot
.65673 .72096 Mdot
.32366 .57153 Mdot
.59287 .39201 Mdot
.64492 .55321 Mdot
.62691 .39752 Mdot
.19097 .40117 Mdot
.50296 .64877 Mdot
.68015 .25467 Mdot
.57883 .33233 Mdot
.375 .61096 Mdot
.6485 .72278 Mdot
.43213 .41786 Mdot
.4463 .36535 Mdot
.63045 .40291 Mdot
.38436 .59122 Mdot
.22387 .64765 Mdot
.34012 .53256 Mdot
.41225 .71361 Mdot
.50152 .65681 Mdot
.7522 .68496 Mdot
.40228 .67061 Mdot
.25688 .29117 Mdot
.38791 .35174 Mdot
.62455 .56034 Mdot
.43256 .39872 Mdot
.56632 .78274 Mdot
.60383 .35436 Mdot
.65855 .41566 Mdot
.49444 .38222 Mdot
.63859 .54326 Mdot
.45724 .37978 Mdot
.44738 .56594 Mdot
.4808 .33571 Mdot
.63581 .35706 Mdot
.59917 .69725 Mdot
.3706 .61794 Mdot
.61127 .36653 Mdot
.69578 .51929 Mdot
.52375 .29896 Mdot
.47333 .36384 Mdot
.40861 .32994 Mdot
.71323 .50738 Mdot
.33998 .59202 Mdot
.61791 .53716 Mdot
.56878 .64579 Mdot
.62007 .38243 Mdot
.43769 .36227 Mdot
.48948 .38806 Mdot
.65225 .63423 Mdot
.52271 .66046 Mdot
.70252 .53962 Mdot
.55165 .63154 Mdot
.61405 .55333 Mdot
.39508 .42748 Mdot
.63033 .54469 Mdot
.48163 .392 Mdot
.60943 .76349 Mdot
.76455 .33234 Mdot
.24139 .50853 Mdot
.64322 .54961 Mdot
.57266 .29952 Mdot
.55266 .65942 Mdot
.56207 .64106 Mdot
.32877 .28725 Mdot
.38554 .48391 Mdot
.75302 .37324 Mdot
.40047 .79391 Mdot
.56877 .63804 Mdot
.53953 .66224 Mdot
.66524 .49453 Mdot
.32081 .60484 Mdot
.31605 .57696 Mdot
.64479 .56224 Mdot
.52872 .2157 Mdot
.3496 .59989 Mdot
.26661 .70113 Mdot
.75247 .38611 Mdot
.37369 .41416 Mdot
.48234 .62646 Mdot
.61465 .38165 Mdot
.54664 .22729 Mdot
.44898 .57798 Mdot
.4398 .42982 Mdot
.81408 .54935 Mdot
.66486 .51544 Mdot
.46189 .24254 Mdot
.35263 .79274 Mdot
.45551 .4311 Mdot
.44671 .38589 Mdot
.4289 .39223 Mdot
.5845 .36421 Mdot
.33423 .41288 Mdot
.45334 .42859 Mdot
.5274 .21328 Mdot
.457 .43775 Mdot
.54019 .40268 Mdot
.59857 .3709 Mdot
.52681 .36175 Mdot
.63841 .69884 Mdot
.79998 .48184 Mdot
.50315 .42622 Mdot
.56768 .64491 Mdot
.58054 .50881 Mdot
.55816 .66595 Mdot
.23936 .54646 Mdot
.61111 .27769 Mdot
.39691 .57726 Mdot
.44058 .42821 Mdot
.66668 .5417 Mdot
.38434 .5881 Mdot
.69845 .63022 Mdot
.49541 .93178 Mdot
.56848 .6551 Mdot
.32089 .19544 Mdot
.55882 .63521 Mdot
.69836 .50642 Mdot
.35751 .57906 Mdot
.31453 .49067 Mdot
.5722 .55761 Mdot
.36619 .59046 Mdot
.39264 .75145 Mdot
.31275 .56719 Mdot
.55531 .29847 Mdot
.3551 .5505 Mdot
.55101 .65552 Mdot
.58113 .63479 Mdot
.41856 .46509 Mdot
.44141 .41437 Mdot
.48902 .56405 Mdot
.53555 .31978 Mdot
.43662 .41675 Mdot
.66855 .5367 Mdot
.59578 .1925 Mdot
.59965 .44601 Mdot
.33785 .61853 Mdot
.53587 .60886 Mdot
.44949 .38497 Mdot
.43268 .35173 Mdot
.46697 .35894 Mdot
.85219 .56115 Mdot
.25496 .67262 Mdot
.47491 .37816 Mdot
.44273 .44391 Mdot
.64658 .54737 Mdot
.64192 .40987 Mdot
.54563 .79247 Mdot
.51658 .44369 Mdot
.4178 .42778 Mdot
.60631 .3642 Mdot
.59514 .34753 Mdot
.46062 .35154 Mdot
.78467 .49693 Mdot
.63618 .60487 Mdot
.4562 .40155 Mdot
.41911 .48788 Mdot
.71553 .65145 Mdot
.70158 .50576 Mdot
.67217 .51942 Mdot
.37945 .61495 Mdot
.67521 .5414 Mdot
.68659 .54328 Mdot
.31753 .46924 Mdot
.55654 .50364 Mdot
.56734 .69013 Mdot
.59625 .35675 Mdot
.41236 .39992 Mdot
.34798 .54609 Mdot
.57684 .72728 Mdot
.53165 .66835 Mdot
.37596 .59463 Mdot
.55626 .67261 Mdot
.57841 .3689 Mdot
.43273 .22299 Mdot
.68498 .53851 Mdot
.5646 .62509 Mdot
.40002 .71162 Mdot
.6037 .36558 Mdot
.51071 .64607 Mdot
.61672 .61544 Mdot
.38612 .37927 Mdot
.29396 .54651 Mdot
.40109 .39768 Mdot
.1972 .61173 Mdot
.51187 .64361 Mdot
.61988 .71673 Mdot
.44512 .39519 Mdot
.66406 .52589 Mdot
.3891 .32228 Mdot
.41358 .42065 Mdot
.67956 .5212 Mdot
.45851 .35671 Mdot
.6015 .39125 Mdot
.38841 .62739 Mdot
.5722 .50984 Mdot
.76139 .27283 Mdot
.63272 .39791 Mdot
.68796 .63039 Mdot
.43318 .42468 Mdot
.23565 .34651 Mdot
.36396 .58993 Mdot
.48492 .39122 Mdot
.46793 .2885 Mdot
.32266 .58934 Mdot
.37513 .58335 Mdot
.41505 .36108 Mdot
.53224 .6271 Mdot
.67017 .53047 Mdot
.60051 .36991 Mdot
.18982 .38591 Mdot
.42429 .3809 Mdot
.46137 .37009 Mdot
.61547 .36554 Mdot
.54163 .66389 Mdot
.42679 .35179 Mdot
.66599 .73159 Mdot
.15141 .54225 Mdot
.52951 .67089 Mdot
.39036 .40605 Mdot
.31199 .5406 Mdot
.34125 .64874 Mdot
.40878 .17118 Mdot
.67237 .32356 Mdot
.63113 .53705 Mdot
.36209 .35033 Mdot
.70405 .80891 Mdot
.61378 .37563 Mdot
.80974 .45092 Mdot
.44734 .34967 Mdot
.46807 .38341 Mdot
.37348 .60665 Mdot
.39938 .37408 Mdot
.32018 .58449 Mdot
.72388 .24433 Mdot
.8203 .55798 Mdot
.33563 .58762 Mdot
.36601 .61664 Mdot
.49423 .30045 Mdot
.54951 .79043 Mdot
.35481 .57268 Mdot
.42271 .44723 Mdot
.23699 .61551 Mdot
.50975 .43706 Mdot
.63424 .40201 Mdot
.68109 .69783 Mdot
.29841 .63054 Mdot
.61905 .43673 Mdot
.39149 .77546 Mdot
.29572 .63215 Mdot
.65874 .59733 Mdot
.56088 .63144 Mdot
.44417 .43749 Mdot
.67718 .54341 Mdot
.63508 .55061 Mdot
.48295 .34118 Mdot
.41344 .40685 Mdot
.3307 .5831 Mdot
.59878 .35212 Mdot
.53681 .67818 Mdot
.46528 .36821 Mdot
.60291 .44723 Mdot
.63357 .36585 Mdot
.33127 .61198 Mdot
.36185 .27506 Mdot
.64027 .36019 Mdot
.48616 .3344 Mdot
.45721 .41104 Mdot
.39255 .38434 Mdot
.48325 .467 Mdot
.5368 .61876 Mdot
.64437 .73197 Mdot
.39598 .42083 Mdot
.80158 .50264 Mdot
.48829 .49014 Mdot
.37565 .34885 Mdot
.34537 .60403 Mdot
.55697 .68365 Mdot
.65795 .48667 Mdot
.43777 .26094 Mdot
.42956 .37444 Mdot
.2518 .65948 Mdot
.28936 .35887 Mdot
.66301 .48721 Mdot
.31511 .61205 Mdot
.60811 .38373 Mdot
.40466 .40402 Mdot
.23965 .57842 Mdot
.43167 .41023 Mdot
.57398 .3444 Mdot
.66346 .50811 Mdot
.55901 .62943 Mdot
.16767 .56163 Mdot
.63423 .54999 Mdot
.3738 .57818 Mdot
.29896 .78627 Mdot
.34701 .55419 Mdot
.34928 .62487 Mdot
.25284 .59146 Mdot
.5461 .61892 Mdot
.72797 .79296 Mdot
.47516 .1696 Mdot
.47018 .34369 Mdot
.55685 .65795 Mdot
.34706 .57747 Mdot
.47242 .40879 Mdot
.37736 .56166 Mdot
.32672 .62344 Mdot
.37631 .39981 Mdot
.46677 .40024 Mdot
.3693 .68501 Mdot
.3042 .76061 Mdot
.6041 .38243 Mdot
.34264 .5646 Mdot
.39636 .28478 Mdot
.47123 .41519 Mdot
.44416 .40118 Mdot
.71939 .63559 Mdot
.64233 .36717 Mdot
.42779 .63301 Mdot
.44107 .34955 Mdot
.81104 .58373 Mdot
.50764 .36878 Mdot
.38544 .61234 Mdot
.5266 .66867 Mdot
.79751 .47414 Mdot
.53179 .7184 Mdot
.31516 .60066 Mdot
.59188 .3673 Mdot
.38303 .55546 Mdot
.50906 .3043 Mdot
.55112 .6151 Mdot
.38036 .58138 Mdot
.54392 .49413 Mdot
.53627 .64578 Mdot
.51393 .63955 Mdot
.22921 .57616 Mdot
.69026 .54842 Mdot
.58619 .37632 Mdot
.52741 .66035 Mdot
.36567 .30263 Mdot
.55252 .64707 Mdot
.33262 .30171 Mdot
.40275 .42285 Mdot
.48469 .22376 Mdot
.51521 .57975 Mdot
.3831 .45407 Mdot
.51814 .62585 Mdot
.60117 .38605 Mdot
.4207 .35622 Mdot
.3496 .61289 Mdot
.63689 .37592 Mdot
.4984 .61341 Mdot
.65011 .50678 Mdot
.33678 .60745 Mdot
.50057 .64004 Mdot
.34809 .56428 Mdot
.42939 .25037 Mdot
.37774 .21147 Mdot
.70608 .70457 Mdot
.56789 .5508 Mdot
.46365 .35634 Mdot
.45883 .80157 Mdot
.37896 .41862 Mdot
.41406 .41149 Mdot
.67346 .53403 Mdot
.47744 .23825 Mdot
.35673 .58341 Mdot
.16843 .5702 Mdot
.56407 .6281 Mdot
.82449 .53815 Mdot
.38992 .54379 Mdot
.48562 .38746 Mdot
.32571 .59017 Mdot
.35165 .55238 Mdot
.22639 .492 Mdot
.68804 .48245 Mdot
.4313 .45727 Mdot
.41425 .45782 Mdot
.39207 .34121 Mdot
.51592 .63795 Mdot
.7812 .56989 Mdot
.61875 .55117 Mdot
.37822 .19907 Mdot
.66854 .5084 Mdot
.59272 .55516 Mdot
.32529 .61218 Mdot
.63928 .37006 Mdot
.44651 .40173 Mdot
.37552 .53155 Mdot
.31423 .59958 Mdot
.5697 .36781 Mdot
.62768 .38912 Mdot
.74497 .58372 Mdot
.53729 .6212 Mdot
.474 .36025 Mdot
.44631 .43291 Mdot
.40536 .37469 Mdot
.39795 .40565 Mdot
.56956 .653 Mdot
.40588 .35657 Mdot
.57708 .65995 Mdot
.35743 .30366 Mdot
.81221 .56158 Mdot
.55319 .50203 Mdot
.41908 .55961 Mdot
.34601 .6171 Mdot
.37476 .30208 Mdot
.48441 .33148 Mdot
.73845 .30469 Mdot
.17941 .48185 Mdot
.3977 .35355 Mdot
.65917 .49316 Mdot
.38003 .48081 Mdot
.67552 .54919 Mdot
.39358 .14615 Mdot
.64696 .64095 Mdot
.28341 .74584 Mdot
.4641 .41984 Mdot
.72139 .63717 Mdot
.34567 .36997 Mdot
.38805 .43516 Mdot
.68216 .64632 Mdot
.52958 .73057 Mdot
.42407 .7489 Mdot
.60908 .34456 Mdot
.44636 .3704 Mdot
.32814 .55609 Mdot
.44763 .42678 Mdot
.43842 .40102 Mdot
.44616 .34822 Mdot
.51493 .62322 Mdot
.45125 .45225 Mdot
.39161 .39693 Mdot
.74617 .49284 Mdot
.56915 .27943 Mdot
.62284 .53514 Mdot
.32489 .28518 Mdot
.63633 .36963 Mdot
.3292 .59122 Mdot
.33611 .7223 Mdot
.52622 .62801 Mdot
.22624 .4754 Mdot
.39386 .39656 Mdot
.38029 .69714 Mdot
.49813 .647 Mdot
.62156 .38455 Mdot
.6139 .53507 Mdot
.25468 .71799 Mdot
.66143 .54184 Mdot
.53947 .49665 Mdot
.66196 .53009 Mdot
.51494 .37701 Mdot
.33117 .58177 Mdot
.44898 .34676 Mdot
.52892 .65923 Mdot
.67939 .52979 Mdot
.52427 .25346 Mdot
.41969 .39174 Mdot
.64476 .54271 Mdot
.44721 .34657 Mdot
.44418 .21725 Mdot
.69053 .28974 Mdot
.69308 .53716 Mdot
.5743 .67573 Mdot
.54083 .64927 Mdot
.64061 .3665 Mdot
.33034 .60315 Mdot
.36989 .608 Mdot
.53059 .64323 Mdot
.52876 .17679 Mdot
.4173 .42621 Mdot
.47068 .41279 Mdot
.80395 .50161 Mdot
.44161 .42153 Mdot
.54189 .30575 Mdot
.54118 .48896 Mdot
.33682 .61553 Mdot
.47687 .39559 Mdot
.43184 .35331 Mdot
.43747 .36846 Mdot
.41648 .24706 Mdot
.67347 .5137 Mdot
.42712 .43666 Mdot
.62732 .39198 Mdot
.63008 .50308 Mdot
.47363 .40974 Mdot
.39286 .33919 Mdot
.37119 .60647 Mdot
.83998 .51184 Mdot
.55312 .62868 Mdot
.69513 .51066 Mdot
.63329 .54515 Mdot
.68503 .69417 Mdot
.28268 .60564 Mdot
.54396 .48665 Mdot
.35756 .20895 Mdot
.63412 .71096 Mdot
.62129 .36365 Mdot
.59507 .58715 Mdot
.5133 .47615 Mdot
.67961 .49374 Mdot
.56402 .66659 Mdot
.39792 .42024 Mdot
.41465 .42703 Mdot
.80848 .38396 Mdot
.48577 .3821 Mdot
.60993 .38215 Mdot
.57649 .64808 Mdot
.35415 .60904 Mdot
.62001 .38556 Mdot
.55969 .639 Mdot
.34007 .59432 Mdot
.38239 .3844 Mdot
.38154 .39449 Mdot
.37488 .59384 Mdot
.38268 .59398 Mdot
.45539 .40603 Mdot
.60659 .55854 Mdot
.37311 .61852 Mdot
.36944 .5659 Mdot
.68482 .5394 Mdot
.68148 .53762 Mdot
.37134 .38735 Mdot
.55885 .65165 Mdot
.39 .37967 Mdot
.65624 .54641 Mdot
.61147 .34951 Mdot
.3586 .58923 Mdot
.43774 .35431 Mdot
.45941 .36153 Mdot
.60362 .36713 Mdot
.60258 .34748 Mdot
.62585 .38706 Mdot
.57617 .63026 Mdot
.40955 .379 Mdot
.36063 .57486 Mdot
.5467 .62137 Mdot
.5948 .34755 Mdot
.6481 .38608 Mdot
.69951 .55103 Mdot
.42866 .42173 Mdot
.71685 .4913 Mdot
.61566 .87745 Mdot
.60173 .31427 Mdot
.66535 .48527 Mdot
.70991 .52547 Mdot
.53541 .2729 Mdot
.60919 .57705 Mdot
.53051 .63579 Mdot
.61433 .32329 Mdot
.65558 .36299 Mdot
.41569 .34523 Mdot
.38871 .41692 Mdot
.40031 .4533 Mdot
.62933 .38011 Mdot
.45492 .26051 Mdot
.37141 .55905 Mdot
.25219 .37562 Mdot
.63644 .37179 Mdot
.70295 .50701 Mdot
.69028 .54997 Mdot
.66779 .50798 Mdot
.38882 .41166 Mdot
.24129 .49927 Mdot
.4622 .30324 Mdot
.45923 .80796 Mdot
.51309 .63419 Mdot
.39554 .56813 Mdot
.20826 .38001 Mdot
.37479 .58851 Mdot
.65975 .55839 Mdot
.63285 .37444 Mdot
.3812 .57954 Mdot
.54738 .67183 Mdot
.5368 .66123 Mdot
.67328 .51029 Mdot
.65522 .52164 Mdot
.67117 .49819 Mdot
.3384 .62555 Mdot
.32301 .61002 Mdot
.42347 .378 Mdot
.36101 .59894 Mdot
.83358 .43668 Mdot
.58154 .3715 Mdot
.71027 .52959 Mdot
.55035 .63781 Mdot
.33567 .58006 Mdot
.41555 .3922 Mdot
.58711 .46193 Mdot
.49862 .73338 Mdot
.62225 .39882 Mdot
.70891 .31131 Mdot
.38656 .15234 Mdot
.48026 .36779 Mdot
.51668 .64112 Mdot
.79766 .4115 Mdot
.42779 .39029 Mdot
.65188 .51331 Mdot
.60806 .77077 Mdot
.62876 .50891 Mdot
.38868 .37912 Mdot
.47651 .3569 Mdot
.51325 .66161 Mdot
.32923 .2469 Mdot
.41845 .38199 Mdot
.43791 .64408 Mdot
.53894 .60681 Mdot
.62741 .556 Mdot
.1524 .5563 Mdot
.71351 .67772 Mdot
.53814 .22272 Mdot
.68736 .53534 Mdot
.42223 .41243 Mdot
.68783 .5297 Mdot
.61823 .39755 Mdot
.69152 .5164 Mdot
.39348 .61009 Mdot
.62038 .53908 Mdot
.462 .37148 Mdot
.35353 .57136 Mdot
.53631 .63561 Mdot
.82366 .52185 Mdot
.74679 .46847 Mdot
.66338 .52528 Mdot
.69816 .5226 Mdot
.47681 .37825 Mdot
.40595 .65538 Mdot
.46041 .33274 Mdot
.46709 .41833 Mdot
.56837 .63137 Mdot
.32525 .59525 Mdot
.50882 .63111 Mdot
.47725 .42208 Mdot
.65796 .74406 Mdot
.5463 .62815 Mdot
.37161 .69772 Mdot
.61822 .36478 Mdot
.45743 .53837 Mdot
.41028 .39871 Mdot
.53216 .66574 Mdot
.40841 .37985 Mdot
.38142 .56532 Mdot
.49952 .52707 Mdot
.58409 .73211 Mdot
.52944 .65725 Mdot
.21785 .63225 Mdot
.64423 .57288 Mdot
.50105 .41095 Mdot
.56399 .6585 Mdot
.46923 .29021 Mdot
.69675 .50239 Mdot
.62513 .36083 Mdot
.59802 .34671 Mdot
.63132 .39577 Mdot
.42446 .33188 Mdot
.50555 .40932 Mdot
.59042 .37925 Mdot
.53606 .6745 Mdot
.63033 .35254 Mdot
.27781 .63993 Mdot
.22011 .64397 Mdot
.60212 .35598 Mdot
.44142 .37806 Mdot
.46241 .4684 Mdot
.56353 .27486 Mdot
.70691 .48137 Mdot
.28735 .73954 Mdot
.41966 .577 Mdot
.43969 .41319 Mdot
.34965 .65309 Mdot
.37648 .56486 Mdot
.79335 .41568 Mdot
.54712 .32526 Mdot
.78346 .47818 Mdot
.36316 .6195 Mdot
.59956 .72307 Mdot
.33233 .61073 Mdot
.48167 .37548 Mdot
.4711 .40631 Mdot
.31286 .58124 Mdot
.79121 .57031 Mdot
.65908 .62088 Mdot
.15667 .49591 Mdot
.36489 .56297 Mdot
.55594 .66539 Mdot
.572 .6416 Mdot
.51625 .63138 Mdot
.74348 .37529 Mdot
.32662 .57091 Mdot
.41674 .3735 Mdot
.64882 .54947 Mdot
.42714 .43371 Mdot
.52911 .64924 Mdot
.17101 .57487 Mdot
.3638 .6099 Mdot
.45739 .39857 Mdot
.52639 .18637 Mdot
.64684 .52165 Mdot
.60815 .36157 Mdot
.42054 .22107 Mdot
.76887 .42078 Mdot
.54643 .61648 Mdot
.33039 .56222 Mdot
.61352 .69718 Mdot
.35685 .69914 Mdot
.38021 .36528 Mdot
.36763 .37971 Mdot
.22706 .32906 Mdot
.7597 .411 Mdot
.44306 .34231 Mdot
.69432 .5045 Mdot
.60553 .72306 Mdot
.44381 .35812 Mdot
.36085 .55946 Mdot
.61941 .34407 Mdot
.63539 .38873 Mdot
.41276 .44909 Mdot
.57722 .56135 Mdot
.46184 .51303 Mdot
.40294 .36416 Mdot
.48664 .3345 Mdot
.65864 .55721 Mdot
.63391 .70562 Mdot
.81014 .51576 Mdot
.59157 .36343 Mdot
.4373 .34748 Mdot
.43552 .76901 Mdot
.32172 .61646 Mdot
.63185 .51347 Mdot
.5476 .61378 Mdot
.39606 .25017 Mdot
.62229 .55398 Mdot
.44407 .35721 Mdot
.42803 .35195 Mdot
.51021 .64805 Mdot
.3856 .61227 Mdot
.62992 .3782 Mdot
.64278 .55027 Mdot
.59079 .36583 Mdot
.32261 .58399 Mdot
.36037 .6096 Mdot
.51639 .42723 Mdot
.48266 .43949 Mdot
.6729 .52089 Mdot
.4732 .42424 Mdot
.6935 .46977 Mdot
.32522 .24617 Mdot
.50281 .66713 Mdot
.48095 .36814 Mdot
.34785 .64055 Mdot
.52547 .65571 Mdot
.46688 .39103 Mdot
.19699 .36222 Mdot
.46951 .42198 Mdot
.53815 .7208 Mdot
.69591 .72485 Mdot
.61019 .38956 Mdot
.23275 .37926 Mdot
.32525 .66878 Mdot
.4462 .42106 Mdot
.63756 .51561 Mdot
.40943 .31864 Mdot
.53106 .62938 Mdot
.33322 .6173 Mdot
.41557 .16525 Mdot
.55037 .64909 Mdot
.4569 .4233 Mdot
.62053 .38324 Mdot
.34141 .55507 Mdot
.5858 .51407 Mdot
.79188 .50673 Mdot
.49987 .36764 Mdot
.42926 .44926 Mdot
.39232 .37428 Mdot
.59484 .79414 Mdot
.69416 .50962 Mdot
.34161 .57761 Mdot
.51694 .63726 Mdot
.5282 .64231 Mdot
.67001 .5119 Mdot
.42605 .73982 Mdot
.45984 .53666 Mdot
.65054 .84226 Mdot
.68197 .52182 Mdot
.59552 .39541 Mdot
.4255 .64456 Mdot
.63645 .51546 Mdot
.6446 .53974 Mdot
.65853 .55686 Mdot
.56039 .70398 Mdot
.34288 .59519 Mdot
.45934 .36037 Mdot
.39102 .58001 Mdot
.4209 .41545 Mdot
.45739 .50145 Mdot
.52437 .65762 Mdot
.3372 .62011 Mdot
.20403 .35692 Mdot
.37743 .49467 Mdot
.43549 .38628 Mdot
.22051 .35893 Mdot
.49329 .37389 Mdot
.51358 .28039 Mdot
.49323 .41632 Mdot
.6582 .52594 Mdot
.35226 .367 Mdot
.42856 .32529 Mdot
.8293 .48983 Mdot
.55209 .63811 Mdot
.69444 .49697 Mdot
.44181 .33796 Mdot
.5047 .35956 Mdot
.31158 .5791 Mdot
.37831 .57448 Mdot
.58888 .37306 Mdot
.62961 .27196 Mdot
.53758 .63403 Mdot
.39614 .21041 Mdot
.44587 .41395 Mdot
.75646 .65368 Mdot
.22778 .39943 Mdot
.4658 .39124 Mdot
.23806 .62801 Mdot
.23502 .48964 Mdot
.40647 .4029 Mdot
.50482 .32093 Mdot
.54402 .66265 Mdot
.66454 .74098 Mdot
.44202 .44516 Mdot
.64818 .51472 Mdot
.32373 .60703 Mdot
.35856 .55665 Mdot
.59438 .38456 Mdot
.72992 .27682 Mdot
.50876 .63354 Mdot
.33256 .61822 Mdot
.42129 .39479 Mdot
.54592 .61773 Mdot
.67056 .54582 Mdot
.48579 .40865 Mdot
.55528 .31879 Mdot
.35869 .60146 Mdot
.45125 .44316 Mdot
.45405 .68772 Mdot
.57534 .24538 Mdot
.4666 .84611 Mdot
.51943 .62965 Mdot
.62879 .35527 Mdot
.39882 .32331 Mdot
.43201 .20192 Mdot
.39931 .35045 Mdot
.47824 .22558 Mdot
.27954 .62844 Mdot
.63002 .35551 Mdot
.44402 .39011 Mdot
.43173 .36553 Mdot
.52707 .57436 Mdot
.60025 .35014 Mdot
.44628 .43458 Mdot
.34773 .42797 Mdot
.34087 .59082 Mdot
.60992 .54268 Mdot
.35372 .60236 Mdot
.43518 .37954 Mdot
.46703 .45236 Mdot
.37776 .60272 Mdot
.32053 .22327 Mdot
.62892 .34128 Mdot
.54921 .6262 Mdot
.49537 .42681 Mdot
.40466 .42818 Mdot
.68233 .77564 Mdot
.68164 .48663 Mdot
.51651 .79075 Mdot
.6764 .45602 Mdot
.41971 .77426 Mdot
.71769 .67237 Mdot
.28749 .77092 Mdot
.81574 .54405 Mdot
.41109 .45624 Mdot
.42071 .53043 Mdot
.49163 .31562 Mdot
.52009 .62321 Mdot
.31452 .39385 Mdot
.44071 .41449 Mdot
.43546 .40033 Mdot
.63831 .50526 Mdot
.39358 .72169 Mdot
.7886 .48911 Mdot
.57744 .53921 Mdot
.6283 .37564 Mdot
.33827 .56933 Mdot
.47322 .38618 Mdot
.57114 .44578 Mdot
.62431 .52941 Mdot
.76336 .64154 Mdot
.4541 .39499 Mdot
.73318 .3033 Mdot
.57317 .71135 Mdot
.53654 .61961 Mdot
.62737 .53763 Mdot
.77974 .44548 Mdot
.42425 .42225 Mdot
.56094 .61598 Mdot
.4156 .38588 Mdot
.70064 .56935 Mdot
.47874 .41428 Mdot
.61347 .35422 Mdot
.45554 .35113 Mdot
.58098 .53003 Mdot
.388 .82475 Mdot
.59375 .33333 Mdot
.34084 .56082 Mdot
.71103 .49864 Mdot
.67301 .51526 Mdot
.38212 .58595 Mdot
.67084 .51776 Mdot
.23141 .43627 Mdot
.29816 .48639 Mdot
.62711 .3713 Mdot
.49538 .34372 Mdot
.59692 .361 Mdot
.67936 .4854 Mdot
.43189 .41572 Mdot
.33787 .21414 Mdot
.67629 .52618 Mdot
.70683 .73032 Mdot
.55032 .64274 Mdot
.68852 .49061 Mdot
.45525 .43911 Mdot
.61677 .68035 Mdot
.62771 .54542 Mdot
.58887 .72495 Mdot
.4356 .36952 Mdot
.35543 .61245 Mdot
.43344 .36209 Mdot
.49997 .40096 Mdot
.6136 .55576 Mdot
.39506 .40692 Mdot
.55974 .63918 Mdot
.36205 .62596 Mdot
.23792 .67968 Mdot
.54497 .72386 Mdot
.44128 .4312 Mdot
.42328 .39349 Mdot
.33387 .55561 Mdot
.42342 .43722 Mdot
.56955 .65241 Mdot
.89175 .57255 Mdot
.61766 .36438 Mdot
.69975 .52529 Mdot
.70653 .6878 Mdot
.39145 .36095 Mdot
.41234 .35648 Mdot
.18337 .39375 Mdot
.7003 .7027 Mdot
.56493 .65083 Mdot
.44871 .3257 Mdot
.65057 .55191 Mdot
.61849 .38264 Mdot
.53081 .67483 Mdot
.39286 .38349 Mdot
.44557 .39861 Mdot
.62849 .35573 Mdot
.22798 .59002 Mdot
.77856 .41616 Mdot
.50994 .64056 Mdot
.35038 .37322 Mdot
.64728 .4546 Mdot
.41544 .42376 Mdot
.74518 .37014 Mdot
.37724 .5758 Mdot
.55762 .61895 Mdot
.49986 .80496 Mdot
.43006 .34394 Mdot
.53056 .66946 Mdot
.5403 .63369 Mdot
.43616 .32553 Mdot
.3158 .62925 Mdot
.34421 .63006 Mdot
.34605 .56526 Mdot
.84374 .43777 Mdot
.55581 .24118 Mdot
.6709 .49821 Mdot
.54257 .66325 Mdot
.68387 .54689 Mdot
.58918 .39207 Mdot
.53806 .47286 Mdot
.69608 .53308 Mdot
.38519 .58485 Mdot
.71309 .49574 Mdot
.43529 .36527 Mdot
.53387 .63595 Mdot
.67907 .49468 Mdot
.43987 .3364 Mdot
.3754 .66893 Mdot
.74229 .53532 Mdot
.64694 .373 Mdot
.61434 .34186 Mdot
.47215 .40197 Mdot
.6558 .48725 Mdot
.45345 .40577 Mdot
.55006 .6823 Mdot
.41432 .65556 Mdot
.41489 .34041 Mdot
.66397 .52274 Mdot
.34043 .656 Mdot
.7688 .42118 Mdot
.47706 .34483 Mdot
.44151 .37926 Mdot
.4163 .41864 Mdot
.41467 .3861 Mdot
.39623 .74044 Mdot
.50252 .66091 Mdot
.44619 .60795 Mdot
.64649 .72135 Mdot
.36806 .59673 Mdot
.33192 .63345 Mdot
.71264 .35143 Mdot
.66565 .5984 Mdot
.5578 .65476 Mdot
.41053 .41245 Mdot
.56874 .72966 Mdot
.17597 .58574 Mdot
.29804 .23292 Mdot
.56988 .37851 Mdot
.65799 .49035 Mdot
.32384 .56968 Mdot
.62673 .52852 Mdot
.42524 .4118 Mdot
.39285 .32558 Mdot
.28338 .77228 Mdot
.5808 .62073 Mdot
.63246 .37626 Mdot
.41731 .41706 Mdot
.556 .23539 Mdot
.6469 .54786 Mdot
.68067 .55366 Mdot
.45185 .43409 Mdot
.37221 .62666 Mdot
.59525 .82391 Mdot
.53119 .62073 Mdot
.42191 .58204 Mdot
.35772 .3277 Mdot
.46315 .66783 Mdot
.52335 .64987 Mdot
.77157 .4834 Mdot
.65201 .49099 Mdot
.20292 .47883 Mdot
.36904 .59945 Mdot
.63487 .37315 Mdot
.36945 .36348 Mdot
.3672 .6134 Mdot
.61484 .54762 Mdot
.345 .61835 Mdot
.45811 .35079 Mdot
.50266 .64265 Mdot
.63023 .5338 Mdot
.58004 .66739 Mdot
.31897 .63069 Mdot
.59494 .37704 Mdot
.48869 .58009 Mdot
.33319 .45656 Mdot
.23275 .48555 Mdot
.42186 .43322 Mdot
.56955 .44247 Mdot
.41224 .37463 Mdot
.30729 .58847 Mdot
.41546 .39006 Mdot
.35926 .65232 Mdot
.63392 .52148 Mdot
.44281 .44407 Mdot
.39773 .3665 Mdot
.30499 .35976 Mdot
.45343 .38669 Mdot
.46445 .44196 Mdot
.40631 .40672 Mdot
.38137 .54489 Mdot
.4736 .32926 Mdot
.34341 .60234 Mdot
.78182 .51524 Mdot
.64527 .53773 Mdot
.61046 .34241 Mdot
.642 .38299 Mdot
.49401 .2237 Mdot
.65904 .34349 Mdot
.4104 .73406 Mdot
.35154 .59467 Mdot
.55033 .63269 Mdot
.41212 .39003 Mdot
.41243 .80053 Mdot
.70195 .66496 Mdot
.6559 .55308 Mdot
.54533 .72381 Mdot
.35831 .3928 Mdot
.59985 .79518 Mdot
.46283 .43632 Mdot
.80449 .36858 Mdot
.44128 .46729 Mdot
.48068 .40614 Mdot
.66766 .5584 Mdot
.61606 .33574 Mdot
.43983 .44078 Mdot
.31257 .57698 Mdot
.62773 .35881 Mdot
.39224 .52236 Mdot
.62193 .47931 Mdot
.76883 .49699 Mdot
.30754 .43532 Mdot
.40987 .38209 Mdot
.63161 .53143 Mdot
.33625 .60632 Mdot
.81343 .52237 Mdot
.54918 .62231 Mdot
.58476 .58755 Mdot
.38816 .29137 Mdot
.26055 .30565 Mdot
.63395 .36676 Mdot
.22824 .58027 Mdot
.46289 .37102 Mdot
.72777 .38329 Mdot
.37749 .3916 Mdot
.1787 .58766 Mdot
.60134 .39926 Mdot
.35443 .63444 Mdot
.55771 .66378 Mdot
.38588 .57242 Mdot
.23678 .507 Mdot
.48277 .61699 Mdot
.5183 .54373 Mdot
.65649 .54318 Mdot
.45403 .60226 Mdot
.34809 .57248 Mdot
.42797 .34957 Mdot
.63709 .85427 Mdot
.37233 .56894 Mdot
.31718 .58956 Mdot
.34866 .23423 Mdot
.32669 .23983 Mdot
.35555 .37687 Mdot
.37282 .61266 Mdot
.65487 .54112 Mdot
.59964 .38012 Mdot
.42639 .36234 Mdot
.42345 .37549 Mdot
.37145 .60792 Mdot
.67523 .55637 Mdot
.39166 .50822 Mdot
.65503 .52338 Mdot
.33866 .59109 Mdot
.64298 .53038 Mdot
.6214 .7288 Mdot
.67938 .4916 Mdot
.4072 .4296 Mdot
.41438 .39017 Mdot
.67109 .46256 Mdot
.3601 .60954 Mdot
.40576 .36387 Mdot
.46304 .3595 Mdot
.35791 .57452 Mdot
.61437 .44483 Mdot
.30772 .54745 Mdot
.43663 .42656 Mdot
.44992 .36932 Mdot
.62442 .35244 Mdot
.54844 .45065 Mdot
.65213 .24469 Mdot
.42046 .35643 Mdot
.58369 .3745 Mdot
.33839 .62472 Mdot
.45748 .40378 Mdot
.29647 .6922 Mdot
.6046 .72471 Mdot
.43322 .34462 Mdot
.69485 .49967 Mdot
.40985 .33067 Mdot
.51205 .84121 Mdot
.46582 .42132 Mdot
.35157 .57808 Mdot
.3213 .59492 Mdot
.37391 .2351 Mdot
.37126 .57389 Mdot
.68007 .54076 Mdot
.53353 .64725 Mdot
.19482 .60676 Mdot
.6694 .5463 Mdot
.45134 .33482 Mdot
.47302 .16921 Mdot
.47971 .42752 Mdot
.43052 .33643 Mdot
.64036 .78342 Mdot
.66587 .54669 Mdot
.32755 .58392 Mdot
.57113 .57344 Mdot
.43022 .46098 Mdot
.54807 .61632 Mdot
.40692 .32336 Mdot
.39375 .41312 Mdot
.70201 .71774 Mdot
.54653 .76082 Mdot
.57278 .65942 Mdot
.37388 .41894 Mdot
.41918 .35666 Mdot
.72578 .50242 Mdot
.41622 .3943 Mdot
.59377 .36246 Mdot
.32552 .57581 Mdot
.64826 .50136 Mdot
.60579 .36903 Mdot
.44401 .41779 Mdot
.62884 .38151 Mdot
.66364 .49647 Mdot
.56101 .61769 Mdot
.42651 .41686 Mdot
.63366 .40261 Mdot
.6278 .37724 Mdot
.40997 .37238 Mdot
.32986 .61518 Mdot
.40069 .46849 Mdot
.46064 .40116 Mdot
.44249 .35242 Mdot
.36909 .60846 Mdot
.26825 .24186 Mdot
.46843 .42074 Mdot
.63716 .57122 Mdot
.31497 .59484 Mdot
.48117 .66798 Mdot
.65027 .49807 Mdot
.39482 .41554 Mdot
.56683 .62494 Mdot
.52734 .66299 Mdot
.67409 .55211 Mdot
.35252 .55041 Mdot
.67466 .45836 Mdot
.34528 .6556 Mdot
.46624 .44985 Mdot
.49125 .39905 Mdot
.52009 .16914 Mdot
.273 .74422 Mdot
.3562 .55787 Mdot
.66414 .56202 Mdot
.57465 .53655 Mdot
.54467 .66546 Mdot
.70653 .5306 Mdot
.33479 .55786 Mdot
.32967 .56549 Mdot
.34229 .61578 Mdot
.6371 .38217 Mdot
.65755 .45012 Mdot
.38677 .61279 Mdot
.37048 .62734 Mdot
.43616 .36761 Mdot
.41555 .35761 Mdot
.53879 .34821 Mdot
.59273 .29972 Mdot
.59413 .37923 Mdot
.66553 .51046 Mdot
.86629 .57567 Mdot
.55353 .6805 Mdot
.30159 .36478 Mdot
.41395 .3412 Mdot
.54782 .92131 Mdot
.46469 .43222 Mdot
.41809 .39628 Mdot
.36381 .62412 Mdot
.64583 .39567 Mdot
.60287 .35928 Mdot
.34363 .57235 Mdot
.30753 .60239 Mdot
.59439 .36048 Mdot
.18438 .53593 Mdot
.21819 .64732 Mdot
.51536 .58246 Mdot
.36068 .58133 Mdot
.33425 .47346 Mdot
.54567 .61312 Mdot
.34322 .64587 Mdot
.53628 .68063 Mdot
.64318 .54455 Mdot
.64429 .49522 Mdot
.51566 .63741 Mdot
.43362 .37159 Mdot
.68201 .50058 Mdot
.45203 .45175 Mdot
.20596 .57829 Mdot
.27178 .55817 Mdot
.74635 .62015 Mdot
.38904 .42333 Mdot
.78112 .50306 Mdot
.68628 .59834 Mdot
.45539 .41909 Mdot
.36198 .75176 Mdot
.63201 .37811 Mdot
.36506 .63678 Mdot
.5711 .64674 Mdot
.48548 .85168 Mdot
.41303 .42019 Mdot
.35328 .58175 Mdot
.55562 .64012 Mdot
.41978 .23821 Mdot
.43525 .64606 Mdot
.41941 .41761 Mdot
.67459 .8267 Mdot
.37673 .53613 Mdot
.65041 .50012 Mdot
.60473 .18988 Mdot
.39129 .57794 Mdot
.61101 .41578 Mdot
.64215 .70768 Mdot
.21829 .34919 Mdot
.32954 .59055 Mdot
.70274 .54432 Mdot
.34031 .56941 Mdot
.59257 .37084 Mdot
.39832 .60973 Mdot
.63546 .54522 Mdot
.44996 .38916 Mdot
.66438 .51666 Mdot
.59682 .38527 Mdot
.73741 .37371 Mdot
.57131 .64237 Mdot
.69399 .49681 Mdot
.53914 .65585 Mdot
.58984 .25258 Mdot
.64434 .74775 Mdot
.55788 .62896 Mdot
.40023 .22704 Mdot
.43588 .34146 Mdot
.39273 .59698 Mdot
.68245 .51487 Mdot
.63692 .70241 Mdot
.53045 .5639 Mdot
.3704 .59028 Mdot
.65862 .50675 Mdot
.41015 .29241 Mdot
.49021 .18492 Mdot
.5111 .3823 Mdot
.60919 .26833 Mdot
.36169 .57762 Mdot
.70722 .53351 Mdot
.80449 .50146 Mdot
.3848 .57878 Mdot
.68294 .52107 Mdot
.54671 .66929 Mdot
.52532 .6448 Mdot
.4396 .43823 Mdot
.55984 .69299 Mdot
.67008 .5038 Mdot
.71592 .58748 Mdot
.32143 .6169 Mdot
.43053 .2404 Mdot
.63434 .39817 Mdot
.6508 .53354 Mdot
.48727 .38732 Mdot
.31499 .63704 Mdot
.61306 .72563 Mdot
.39557 .50264 Mdot
.85025 .5929 Mdot
.66913 .51224 Mdot
.32134 .58122 Mdot
.35548 .58614 Mdot
.4736 .34268 Mdot
.56938 .55411 Mdot
.66715 .45643 Mdot
.49977 .19594 Mdot
.46567 .22698 Mdot
.61303 .54934 Mdot
.60371 .53449 Mdot
.46563 .34351 Mdot
.40373 .38609 Mdot
.54823 .66587 Mdot
.44817 .38367 Mdot
.35942 .62951 Mdot
.43274 .43968 Mdot
.52025 .65053 Mdot
.66666 .53851 Mdot
.43115 .41312 Mdot
.60327 .38682 Mdot
.57395 .63439 Mdot
.51189 .66065 Mdot
.65741 .53039 Mdot
.36331 .61687 Mdot
.58251 .34756 Mdot
.65529 .52108 Mdot
.41087 .38212 Mdot
.59651 .59768 Mdot
.46666 .35866 Mdot
.18757 .51113 Mdot
.38611 .58502 Mdot
.63052 .52328 Mdot
.31371 .60721 Mdot
.54439 .65693 Mdot
.6454 .72095 Mdot
.42853 .38365 Mdot
.68241 .5244 Mdot
.66924 .46538 Mdot
.20052 .55676 Mdot
.32713 .55777 Mdot
.61232 .62186 Mdot
.3285 .62829 Mdot
.61514 .53471 Mdot
.33781 .27055 Mdot
.62849 .36414 Mdot
.65122 .55354 Mdot
.26295 .71327 Mdot
.6703 .52394 Mdot
.4571 .38546 Mdot
.47012 .39216 Mdot
.65633 .49512 Mdot
.64259 .3701 Mdot
.82095 .55208 Mdot
.71218 .56851 Mdot
.32752 .58763 Mdot
.25311 .34091 Mdot
.80482 .66852 Mdot
.53039 .6897 Mdot
.55814 .66104 Mdot
.42551 .46122 Mdot
.48296 .40177 Mdot
.54036 .67946 Mdot
.53514 .60921 Mdot
.61352 .39971 Mdot
.65876 .55651 Mdot
.4061 .58327 Mdot
.56277 .6144 Mdot
.5059 .44394 Mdot
.66706 .34285 Mdot
.47601 .34 Mdot
.36683 .32271 Mdot
.38264 .40789 Mdot
.46889 .21962 Mdot
.51673 .64455 Mdot
.47545 .38833 Mdot
.48219 .34125 Mdot
.56454 .62316 Mdot
.59319 .3673 Mdot
.53823 .75194 Mdot
.64004 .52587 Mdot
.13433 .46812 Mdot
.48038 .38952 Mdot
.45943 .38956 Mdot
.51382 .63297 Mdot
.69436 .45753 Mdot
.35929 .61531 Mdot
.38717 .58293 Mdot
.69287 .5069 Mdot
.49136 .57371 Mdot
.40859 .42473 Mdot
.46206 .41453 Mdot
.63949 .51928 Mdot
.68977 .49175 Mdot
.72211 .60593 Mdot
.45884 .3627 Mdot
.55603 .64338 Mdot
.57941 .50792 Mdot
.51744 .6473 Mdot
.47943 .37163 Mdot
.45982 .38387 Mdot
.40891 .43039 Mdot
.4854 .38105 Mdot
.51173 .662 Mdot
.47448 .38405 Mdot
.49297 .44852 Mdot
.34687 .62095 Mdot
.39806 .40897 Mdot
.4586 .22212 Mdot
.44494 .3751 Mdot
.59664 .37637 Mdot
.4636 .48149 Mdot
.41714 .42077 Mdot
.39989 .42113 Mdot
.7069 .57113 Mdot
.44006 .39136 Mdot
.54881 .68241 Mdot
.36421 .5963 Mdot
.54148 .66329 Mdot
.51109 .64671 Mdot
.69159 .52975 Mdot
.59202 .38191 Mdot
.388 .36719 Mdot
.62704 .39623 Mdot
.38189 .3685 Mdot
.43636 .3431 Mdot
.66954 .70078 Mdot
.79882 .35613 Mdot
.77617 .40925 Mdot
.42788 .38283 Mdot
.6765 .53638 Mdot
.64255 .50574 Mdot
.42478 .55552 Mdot
.50838 .37665 Mdot
.5396 .67846 Mdot
.53145 .66495 Mdot
.55668 .31217 Mdot
.69404 .72236 Mdot
.59514 .37371 Mdot
.55822 .45683 Mdot
.4535 .45204 Mdot
.45471 .3556 Mdot
.48438 .41274 Mdot
.68914 .54073 Mdot
.58862 .55514 Mdot
.65496 .55266 Mdot
.55156 .72442 Mdot
.5193 .65377 Mdot
.40825 .41826 Mdot
.26103 .61862 Mdot
.37988 .57511 Mdot
.36399 .59715 Mdot
.5253 .67046 Mdot
.71203 .50813 Mdot
.55762 .36112 Mdot
.34263 .18664 Mdot
.39007 .54957 Mdot
.64898 .38713 Mdot
.45095 .42339 Mdot
.66597 .53454 Mdot
.35333 .56132 Mdot
.62811 .35078 Mdot
.43827 .34648 Mdot
.65724 .4533 Mdot
.42588 .38087 Mdot
.4942 .31783 Mdot
.32952 .61058 Mdot
.19133 .6131 Mdot
.35099 .55368 Mdot
.57441 .63837 Mdot
.56498 .6318 Mdot
.46657 .38821 Mdot
.54639 .17366 Mdot
.39227 .58979 Mdot
.53903 .709 Mdot
.60399 .39983 Mdot
.61146 .68664 Mdot
.59384 .35754 Mdot
.64055 .51099 Mdot
.63039 .36143 Mdot
.62884 .53875 Mdot
.59425 .30989 Mdot
.36245 .54287 Mdot
.61172 .36541 Mdot
.70141 .56074 Mdot
.50895 .38224 Mdot
.60688 .34401 Mdot
.39215 .44745 Mdot
.21122 .42243 Mdot
.64308 .51623 Mdot
.64087 .38047 Mdot
.42819 .35004 Mdot
.37541 .8024 Mdot
.56207 .64107 Mdot
.54771 .67858 Mdot
.47254 .44395 Mdot
.66798 .55622 Mdot
.3158 .5754 Mdot
.34733 .70903 Mdot
.49565 .61095 Mdot
.47012 .40463 Mdot
.43806 .4408 Mdot
.33849 .63665 Mdot
.30403 .56595 Mdot
.46339 .3828 Mdot
.33885 .32489 Mdot
.46771 .37262 Mdot
.54533 .67114 Mdot
.37207 .56166 Mdot
.35946 .59045 Mdot
.66227 .50275 Mdot
.37715 .6127 Mdot
.37297 .65032 Mdot
.60004 .62423 Mdot
.41262 .46132 Mdot
.54862 .65026 Mdot
.59689 .65532 Mdot
.5495 .72512 Mdot
.29366 .74064 Mdot
.33075 .63542 Mdot
.40522 .4314 Mdot
.31806 .61262 Mdot
.61647 .3852 Mdot
.35794 .60824 Mdot
.32009 .57593 Mdot
.45599 .41001 Mdot
.42208 .41206 Mdot
.66482 .54456 Mdot
.57338 .55466 Mdot
.34227 .623 Mdot
.47267 .39704 Mdot
.46911 .4369 Mdot
.46575 .44172 Mdot
.48851 .50884 Mdot
.35414 .55853 Mdot
.29358 .34305 Mdot
.46317 .27261 Mdot
.34428 .6231 Mdot
.54082 .84076 Mdot
.63531 .71251 Mdot
.69299 .48776 Mdot
.57129 .6788 Mdot
.45777 .36164 Mdot
.64948 .49683 Mdot
.42564 .41204 Mdot
.36635 .32299 Mdot
.44236 .39972 Mdot
.59962 .35326 Mdot
.41074 .45607 Mdot
.62186 .5195 Mdot
.65883 .51975 Mdot
.46908 .41454 Mdot
.43384 .41036 Mdot
.75269 .39128 Mdot
.30848 .60942 Mdot
.35567 .61596 Mdot
.7147 .47112 Mdot
.61685 .37182 Mdot
.55338 .61724 Mdot
.40863 .39888 Mdot
.69237 .52489 Mdot
.66183 .51703 Mdot
.38493 .56966 Mdot
.65034 .51453 Mdot
.52453 .6247 Mdot
.42586 .38635 Mdot
.54548 .67929 Mdot
.63678 .38645 Mdot
.34138 .56556 Mdot
.411 .41693 Mdot
.4368 .36734 Mdot
.32141 .59458 Mdot
.4055 .34922 Mdot
.62184 .35149 Mdot
.67027 .52151 Mdot
.33162 .59532 Mdot
.53145 .64698 Mdot
.63264 .52276 Mdot
.43596 .35693 Mdot
.85945 .58016 Mdot
.45516 .38018 Mdot
.44719 .35846 Mdot
.24621 .7072 Mdot
.40793 .45558 Mdot
.67733 .51136 Mdot
.36024 .63336 Mdot
.43119 .45085 Mdot
.50831 .22896 Mdot
.28432 .23875 Mdot
.66297 .55156 Mdot
.44918 .4269 Mdot
.30428 .76756 Mdot
.45919 .42339 Mdot
.40919 .20905 Mdot
.68908 .34533 Mdot
.45547 .57952 Mdot
.47004 .45281 Mdot
.52495 .62935 Mdot
.66691 .54411 Mdot
.63637 .51835 Mdot
.27885 .32856 Mdot
.45876 .41147 Mdot
.52398 .34677 Mdot
.40933 .35316 Mdot
.5232 .64779 Mdot
.5356 .31451 Mdot
.66586 .51289 Mdot
.81439 .44765 Mdot
.41561 .37471 Mdot
.3506 .55783 Mdot
.71386 .49825 Mdot
.6268 .71727 Mdot
.43796 .35383 Mdot
.62657 .39467 Mdot
.57988 .64361 Mdot
.42209 .45484 Mdot
.5456 .6462 Mdot
.4518 .35181 Mdot
.52072 .41905 Mdot
.65553 .21869 Mdot
.33466 .61608 Mdot
.55412 .66549 Mdot
.61886 .59858 Mdot
.37582 .39882 Mdot
.33017 .59361 Mdot
.36951 .59821 Mdot
.61512 .39889 Mdot
.53668 .52962 Mdot
.44558 .69099 Mdot
.32997 .518 Mdot
.27478 .32362 Mdot
.71285 .50022 Mdot
.64148 .62123 Mdot
.42448 .35965 Mdot
.75505 .6475 Mdot
.56713 .67262 Mdot
.45649 .38976 Mdot
.21487 .43658 Mdot
.35024 .56426 Mdot
.45435 .36846 Mdot
.59607 .36156 Mdot
.77649 .59219 Mdot
.77063 .62053 Mdot
.5527 .80547 Mdot
.65275 .54426 Mdot
.39326 .32651 Mdot
.40404 .31138 Mdot
.69934 .51791 Mdot
.38976 .36965 Mdot
.67851 .51642 Mdot
.18593 .43188 Mdot
.63166 .35492 Mdot
.34206 .56308 Mdot
.633 .71454 Mdot
.38506 .39909 Mdot
.48499 .4244 Mdot
.6293 .3482 Mdot
.39868 .38549 Mdot
.73404 .28357 Mdot
.72714 .63762 Mdot
.68234 .4971 Mdot
.34064 .61622 Mdot
.38813 .41046 Mdot
.5498 .50199 Mdot
.46255 .40563 Mdot
.29253 .51269 Mdot
.39846 .42047 Mdot
.44437 .67191 Mdot
.32391 .60789 Mdot
.54499 .64966 Mdot
.38412 .35026 Mdot
.43427 .39753 Mdot
.59515 .4608 Mdot
.4637 .45651 Mdot
.47455 .41209 Mdot
.31955 .56715 Mdot
.37044 .56288 Mdot
.3441 .60136 Mdot
.6207 .54232 Mdot
.70097 .71511 Mdot
.55444 .65327 Mdot
.41463 .32596 Mdot
.55949 .61251 Mdot
.37485 .48144 Mdot
.64662 .36921 Mdot
.38062 .79378 Mdot
.39457 .39798 Mdot
.34701 .59434 Mdot
.46224 .7703 Mdot
.33721 .6252 Mdot
.56089 .47932 Mdot
.53684 .63427 Mdot
.35845 .56375 Mdot
.42452 .39603 Mdot
.58444 .56801 Mdot
.46475 .82033 Mdot
.53438 .66107 Mdot
.39059 .35806 Mdot
.66195 .48829 Mdot
.69147 .70331 Mdot
.85861 .60088 Mdot
.56529 .64887 Mdot
.61549 .59677 Mdot
.45926 .41455 Mdot
.38356 .5832 Mdot
.52386 .62797 Mdot
.55686 .63195 Mdot
.65204 .51103 Mdot
.42002 .41317 Mdot
.41611 .41435 Mdot
.62039 .52454 Mdot
.52858 .66206 Mdot
.49745 .39911 Mdot
.47576 .42221 Mdot
.28448 .77591 Mdot
.41587 .27497 Mdot
.15848 .37078 Mdot
.3591 .65643 Mdot
.21177 .46163 Mdot
.33164 .69346 Mdot
.32205 .57783 Mdot
.41841 .42171 Mdot
.38607 .42391 Mdot
.66914 .50444 Mdot
.44134 .38338 Mdot
.66765 .56044 Mdot
.56012 .65338 Mdot
.53402 .8381 Mdot
.50419 .74598 Mdot
.19428 .40586 Mdot
.44258 .38584 Mdot
.52416 .72398 Mdot
.60683 .37795 Mdot
.54612 .60489 Mdot
.3371 .59689 Mdot
.461 .35134 Mdot
.75889 .39694 Mdot
.65205 .55319 Mdot
.377 .59041 Mdot
.79233 .4917 Mdot
.77447 .49296 Mdot
.47869 .37008 Mdot
.62133 .53325 Mdot
.39913 .76031 Mdot
.33862 .32932 Mdot
.49587 .65384 Mdot
.59682 .35507 Mdot
.65049 .55008 Mdot
.51803 .65914 Mdot
.28011 .64504 Mdot
.36642 .56709 Mdot
.40061 .58685 Mdot
.73238 .3465 Mdot
.70186 .52244 Mdot
.60228 .3733 Mdot
.69124 .72228 Mdot
.75945 .65709 Mdot
.60029 .3533 Mdot
.63962 .50065 Mdot
.3644 .56128 Mdot
.3409 .58236 Mdot
.36415 .59503 Mdot
.81553 .46294 Mdot
.35547 .55141 Mdot
.29307 .40125 Mdot
.47827 .43084 Mdot
.53188 .38387 Mdot
.45189 .42692 Mdot
.52994 .67812 Mdot
.32707 .60417 Mdot
.47476 .59715 Mdot
.42747 .32923 Mdot
.53294 .81931 Mdot
.46615 .41091 Mdot
.50433 .63139 Mdot
.45422 .364 Mdot
.30998 .40656 Mdot
.31511 .60682 Mdot
.43439 .38141 Mdot
.52095 .67884 Mdot
.62349 .37766 Mdot
.38894 .63115 Mdot
.41677 .41851 Mdot
.39395 .71633 Mdot
.40356 .45348 Mdot
.17486 .51241 Mdot
.44012 .24803 Mdot
.64902 .3867 Mdot
.34433 .38414 Mdot
.70038 .54017 Mdot
.5333 .37798 Mdot
.46443 .31689 Mdot
.5336 .65904 Mdot
.60512 .76078 Mdot
.64659 .53901 Mdot
.5925 .32191 Mdot
.42669 .31985 Mdot
.59099 .37639 Mdot
.3154 .5624 Mdot
.51785 .67239 Mdot
.44906 .34005 Mdot
.4503 .33077 Mdot
.18659 .44658 Mdot
.49846 .34601 Mdot
.42796 .4391 Mdot
.64265 .36143 Mdot
.27581 .36625 Mdot
.44296 .37197 Mdot
.55799 .47972 Mdot
.40004 .59188 Mdot
.48628 .43381 Mdot
.30153 .33648 Mdot
.47155 .39913 Mdot
.38013 .58772 Mdot
.37146 .54666 Mdot
.46484 .74849 Mdot
.60346 .39822 Mdot
.39764 .4183 Mdot
.36462 .24888 Mdot
.41098 .37797 Mdot
.55393 .64256 Mdot
.48386 .39222 Mdot
.64171 .54792 Mdot
.80911 .46273 Mdot
.67347 .50006 Mdot
.4295 .42917 Mdot
.36352 .58954 Mdot
.51408 .63615 Mdot
.75992 .37323 Mdot
.69311 .38646 Mdot
.28797 .39242 Mdot
.19849 .36337 Mdot
.64202 .37292 Mdot
.58828 .3571 Mdot
.51275 .66783 Mdot
.43462 .38001 Mdot
.35215 .24043 Mdot
.44409 .46575 Mdot
.44981 .36793 Mdot
.44251 .40085 Mdot
.65703 .73722 Mdot
.55029 .66308 Mdot
.64506 .52179 Mdot
.46139 .38205 Mdot
.47405 .39004 Mdot
.31902 .58954 Mdot
.62552 .37656 Mdot
.64758 .50034 Mdot
.62317 .36794 Mdot
.67339 .53291 Mdot
.52848 .84385 Mdot
.3976 .33741 Mdot
.62059 .37689 Mdot
.57461 .65716 Mdot
.37098 .60745 Mdot
.60024 .61975 Mdot
.64026 .51196 Mdot
.66511 .50931 Mdot
.46743 .40811 Mdot
.3811 .59033 Mdot
.36563 .61971 Mdot
.61698 .38618 Mdot
.55665 .62513 Mdot
.42305 .42048 Mdot
.44265 .3433 Mdot
.43757 .57634 Mdot
.68399 .54478 Mdot
.41225 .29487 Mdot
.43637 .75041 Mdot
.42998 .38106 Mdot
.3693 .61477 Mdot
.44216 .40822 Mdot
.25862 .66525 Mdot
.38403 .59041 Mdot
.47193 .41892 Mdot
.78862 .6282 Mdot
.58814 .52306 Mdot
.42267 .71279 Mdot
.41971 .4382 Mdot
.14704 .46282 Mdot
.4157 .3616 Mdot
.30799 .79142 Mdot
.7353 .40981 Mdot
.40982 .42193 Mdot
.43109 .36122 Mdot
.28765 .56376 Mdot
.44312 .42116 Mdot
.61683 .52796 Mdot
.58773 .32075 Mdot
.31821 .57511 Mdot
.37583 .6829 Mdot
.48763 .48443 Mdot
.6149 .40296 Mdot
.69247 .50601 Mdot
.60376 .5255 Mdot
.60654 .3552 Mdot
.35875 .57919 Mdot
.41418 .38631 Mdot
.48065 .56683 Mdot
.61878 .55516 Mdot
.50207 .38947 Mdot
.54938 .63866 Mdot
.67496 .63567 Mdot
.71063 .53423 Mdot
.53758 .64773 Mdot
.39052 .39034 Mdot
.2979 .55645 Mdot
.67694 .29543 Mdot
.1959 .63249 Mdot
.51064 .63895 Mdot
.52364 .6594 Mdot
.82105 .48766 Mdot
.6173 .40478 Mdot
.20701 .40398 Mdot
.43929 .65864 Mdot
.52628 .62158 Mdot
.38216 .25887 Mdot
.66284 .554 Mdot
.39715 .7097 Mdot
.36497 .63693 Mdot
.4905 .40035 Mdot
.42745 .39595 Mdot
.55914 .62516 Mdot
.27965 .65063 Mdot
.63814 .20826 Mdot
.53761 .65571 Mdot
.49165 .45387 Mdot
.47927 .52662 Mdot
.63571 .71024 Mdot
.68341 .54243 Mdot
.6051 .39802 Mdot
.62428 .4165 Mdot
.32733 .57858 Mdot
.60241 .39348 Mdot
.76973 .61167 Mdot
.3963 .39159 Mdot
.52947 .65481 Mdot
.61274 .71751 Mdot
.53094 .64403 Mdot
.60509 .35698 Mdot
.64922 .38903 Mdot
.34775 .62078 Mdot
.35472 .61543 Mdot
.21665 .47637 Mdot
.52883 .29108 Mdot
.46409 .41964 Mdot
.48657 .80414 Mdot
.32329 .61855 Mdot
.35082 .34816 Mdot
.58761 .36129 Mdot
.62147 .37448 Mdot
.46166 .28941 Mdot
.40812 .40978 Mdot
.37988 .23171 Mdot
.40889 .40583 Mdot
.53499 .3081 Mdot
.37877 .38968 Mdot
.65134 .51249 Mdot
.40571 .41156 Mdot
.59862 .33767 Mdot
.46806 .3459 Mdot
.48007 .40123 Mdot
.67306 .55499 Mdot
.42444 .45394 Mdot
.64005 .54655 Mdot
.43442 .43199 Mdot
.58931 .3916 Mdot
.69426 .52058 Mdot
.54291 .23936 Mdot
.63577 .57649 Mdot
.65788 .48718 Mdot
.60566 .39184 Mdot
.63281 .39743 Mdot
.52916 .21513 Mdot
.33639 .59564 Mdot
.35444 .6493 Mdot
.43885 .37959 Mdot
.68189 .55329 Mdot
.55246 .66409 Mdot
.47335 .38297 Mdot
.38695 .43314 Mdot
.43726 .4432 Mdot
.33258 .57074 Mdot
.67972 .46142 Mdot
.62179 .3815 Mdot
.61968 .54272 Mdot
.62029 .44771 Mdot
.6391 .55995 Mdot
.47275 .33218 Mdot
.36895 .37697 Mdot
.20674 .51002 Mdot
.52967 .78117 Mdot
.83085 .52828 Mdot
.37148 .57137 Mdot
.69413 .49807 Mdot
.62969 .40081 Mdot
.36832 .44567 Mdot
.34172 .59225 Mdot
.63629 .5456 Mdot
.42477 .38167 Mdot
.38909 .35925 Mdot
.56829 .60375 Mdot
.53034 .3676 Mdot
.47266 .23631 Mdot
.64463 .55938 Mdot
.70181 .54532 Mdot
.75702 .65693 Mdot
.58202 .32433 Mdot
.50757 .5688 Mdot
.45379 .39898 Mdot
.62841 .39364 Mdot
.35351 .56133 Mdot
.70029 .31387 Mdot
.56928 .64539 Mdot
.57184 .55519 Mdot
.44105 .38544 Mdot
.46131 .61917 Mdot
.36473 .59076 Mdot
.59481 .36693 Mdot
.55936 .62443 Mdot
.65419 .38469 Mdot
.69806 .52809 Mdot
.28701 .25986 Mdot
.40583 .37995 Mdot
.46469 .42202 Mdot
.57274 .6463 Mdot
.34263 .56934 Mdot
.64173 .35662 Mdot
.18775 .53368 Mdot
.66165 .49545 Mdot
.36513 .22887 Mdot
.37208 .62023 Mdot
.3125 .44253 Mdot
.62052 .54603 Mdot
.5249 .6697 Mdot
.54836 .22537 Mdot
.51995 .6493 Mdot
.42244 .43013 Mdot
.35384 .59284 Mdot
.56112 .64252 Mdot
.57406 .48373 Mdot
.33207 .7837 Mdot
.32707 .46503 Mdot
.4023 .39873 Mdot
.42474 .81905 Mdot
.21765 .61096 Mdot
.36211 .52943 Mdot
.56759 .62558 Mdot
.46214 .40124 Mdot
.38789 .37821 Mdot
.4156 .37725 Mdot
.54009 .6303 Mdot
.66328 .68807 Mdot
.64433 .51287 Mdot
.45762 .42103 Mdot
.61679 .4002 Mdot
.63838 .54215 Mdot
.63332 .71986 Mdot
.67322 .50956 Mdot
.31458 .62141 Mdot
.48416 .39653 Mdot
.58584 .67452 Mdot
.40884 .83882 Mdot
.53962 .663 Mdot
.65628 .48754 Mdot
.47725 .37821 Mdot
.60323 .74696 Mdot
.34415 .59928 Mdot
.66542 .49539 Mdot
.45931 .39028 Mdot
.63747 .68465 Mdot
.75032 .38546 Mdot
.67172 .50999 Mdot
.33671 .5856 Mdot
.29793 .70271 Mdot
.44563 .38289 Mdot
.41154 .36526 Mdot
.34644 .5704 Mdot
.48951 .47854 Mdot
.79847 .49414 Mdot
.43697 .40918 Mdot
.54349 .64963 Mdot
.37908 .19017 Mdot
.44882 .44572 Mdot
.47963 .29024 Mdot
.65981 .54726 Mdot
.42188 .73391 Mdot
.40358 .29549 Mdot
.34806 .37742 Mdot
.26748 .64508 Mdot
.50967 .48579 Mdot
.51105 .83609 Mdot
.68542 .55406 Mdot
.75561 .46041 Mdot
.50656 .84174 Mdot
.50873 .66824 Mdot
.29197 .63477 Mdot
.41995 .60063 Mdot
.81191 .42255 Mdot
.31565 .71213 Mdot
.73399 .47643 Mdot
.76951 .40847 Mdot
.47117 .55088 Mdot
.67482 .52648 Mdot
.56579 .35541 Mdot
.42367 .41672 Mdot
.21442 .60779 Mdot
.32614 .3388 Mdot
.60284 .1821 Mdot
.41241 .81481 Mdot
.37147 .24921 Mdot
.4032 .79992 Mdot
.28543 .73499 Mdot
.19892 .49138 Mdot
.51232 .78249 Mdot
.39201 .2011 Mdot
.78464 .62451 Mdot
.28873 .28584 Mdot
.36201 .37493 Mdot
.57067 .4469 Mdot
.16786 .44852 Mdot
.29526 .43753 Mdot
.53448 .17946 Mdot
.66555 .50006 Mdot
.36305 .63208 Mdot
.42255 .60451 Mdot
.31037 .57549 Mdot
.54679 .58523 Mdot
.27918 .69157 Mdot
.28824 .76403 Mdot
.30802 .39148 Mdot
.14102 .4732 Mdot
.23323 .40601 Mdot
.81233 .3292 Mdot
.73559 .54324 Mdot
.39522 .58886 Mdot
.61775 .43016 Mdot
.746 .67438 Mdot
.48795 .72544 Mdot
.37027 .65611 Mdot
.68254 .70297 Mdot
.56262 .26686 Mdot
.35447 .58195 Mdot
.35649 .31426 Mdot
.69101 .58707 Mdot
.52088 .74312 Mdot
.67343 .32367 Mdot
.29074 .72621 Mdot
.50752 .55546 Mdot
.38701 .70329 Mdot
.6638 .62195 Mdot
.85619 .58462 Mdot
.4625 .2639 Mdot
.24249 .61839 Mdot
.5762 .59628 Mdot
.28987 .68222 Mdot
.7865 .37515 Mdot
.55313 .2939 Mdot
.75025 .66992 Mdot
.68518 .75594 Mdot
.19844 .59701 Mdot
.71157 .75411 Mdot
.35883 .64894 Mdot
.42904 .44043 Mdot
.25065 .58281 Mdot
.3479 .27607 Mdot
.58139 .38824 Mdot
.57375 .79672 Mdot
.63955 .38463 Mdot
.30559 .61642 Mdot
.80411 .46349 Mdot
.30006 .39777 Mdot
.37816 .22685 Mdot
.6405 .35283 Mdot
.38979 .42401 Mdot
.52711 .1148 Mdot
.50183 .83273 Mdot
.45926 .74276 Mdot
.28635 .77875 Mdot
.472 .62393 Mdot
.41809 .24073 Mdot
.55871 .63958 Mdot
.46838 .84759 Mdot
.34526 .58497 Mdot
.61985 .83494 Mdot
.38485 .81975 Mdot
.63256 .21661 Mdot
.27707 .20206 Mdot
.74755 .64318 Mdot
.45778 .59207 Mdot
.47904 .4965 Mdot
.51272 .24407 Mdot
.69052 .25662 Mdot
.58806 .19599 Mdot
.6004 .74067 Mdot
.18535 .39752 Mdot
.47097 .84294 Mdot
.34802 .26658 Mdot
.2867 .26935 Mdot
.80756 .40957 Mdot
.54513 .47791 Mdot
.29968 .61925 Mdot
.64198 .58925 Mdot
.35826 .75971 Mdot
.62537 .79835 Mdot
.46016 .2769 Mdot
.32081 .19342 Mdot
.6015 .33904 Mdot
.72894 .41353 Mdot
.23577 .66552 Mdot
.57422 .25482 Mdot
.39901 .26537 Mdot
.80679 .52244 Mdot
.49525 .36511 Mdot
.80817 .55095 Mdot
.42691 .79324 Mdot
.60676 .60477 Mdot
.78854 .6101 Mdot
.3752 .7375 Mdot
.1818 .47912 Mdot
.2697 .55093 Mdot
.74045 .68568 Mdot
.30941 .59235 Mdot
.53936 .27717 Mdot
.42246 .25658 Mdot
.27745 .76519 Mdot
.61672 .59628 Mdot
.22363 .71729 Mdot
.79213 .47145 Mdot
.37505 .39107 Mdot
.46023 .31285 Mdot
.45038 .47446 Mdot
.51656 .27819 Mdot
.46521 .43834 Mdot
.53742 .72965 Mdot
.26334 .74127 Mdot
.2254 .40495 Mdot
.60885 .62165 Mdot
.60775 .76377 Mdot
.19843 .63725 Mdot
.22032 .54037 Mdot
.75517 .40867 Mdot
.53092 .3293 Mdot
.84846 .48933 Mdot
.64282 .53539 Mdot
.3439 .26673 Mdot
.49865 .6526 Mdot
.70494 .33175 Mdot
.34151 .50985 Mdot
.67743 .25737 Mdot
.26237 .74029 Mdot
.78178 .51741 Mdot
.78609 .43828 Mdot
.59082 .24201 Mdot
.35641 .22362 Mdot
.60021 .77476 Mdot
.40178 .32517 Mdot
.34302 .67126 Mdot
.64526 .37699 Mdot
.23193 .507 Mdot
.31251 .28494 Mdot
.69696 .43023 Mdot
.44705 .45883 Mdot
.65759 .2731 Mdot
.70668 .4759 Mdot
.58138 .56699 Mdot
.7723 .71807 Mdot
.50167 .36519 Mdot
.70584 .69929 Mdot
.18357 .5694 Mdot
.49322 .25824 Mdot
.23774 .65749 Mdot
.36372 .71081 Mdot
.69849 .75923 Mdot
.35466 .80668 Mdot
.68811 .40548 Mdot
.55238 .82391 Mdot
.27137 .76787 Mdot
.73154 .72888 Mdot
.50597 .34986 Mdot
.55464 .68266 Mdot
.80225 .71589 Mdot
.61528 .54542 Mdot
.65529 .7505 Mdot
.27515 .3235 Mdot
.64379 .67725 Mdot
.40452 .61159 Mdot
.36273 .40236 Mdot
.47809 .55457 Mdot
.34218 .53651 Mdot
.43958 .4523 Mdot
.80717 .65939 Mdot
.71906 .72845 Mdot
.76383 .71041 Mdot
.16356 .52064 Mdot
.55253 .82799 Mdot
.44651 .55679 Mdot
.29853 .42385 Mdot
.41303 .53348 Mdot
.48088 .36959 Mdot
.64268 .32624 Mdot
.74784 .64043 Mdot
.67461 .28089 Mdot
.4732 .71006 Mdot
.30685 .58724 Mdot
.52321 .80586 Mdot
.90564 .45053 Mdot
.23174 .42694 Mdot
.3028 .32274 Mdot
.76697 .63275 Mdot
.51117 .28332 Mdot
.38656 .77443 Mdot
.64856 .23886 Mdot
.25308 .71569 Mdot
.4071 .5339 Mdot
.2767 .30815 Mdot
.71618 .45729 Mdot
.45559 .20799 Mdot
.7123 .47267 Mdot
.31599 .7648 Mdot
.43109 .5142 Mdot
.72909 .32273 Mdot
.42501 .64279 Mdot
.63434 .21224 Mdot
.7154 .37154 Mdot
.68254 .63231 Mdot
.31914 .27053 Mdot
.58784 .72911 Mdot
.50276 .28985 Mdot
.49203 .53228 Mdot
.38542 .46887 Mdot
.50728 .48693 Mdot
.49013 .28313 Mdot
.47345 .20883 Mdot
.60969 .80135 Mdot
.28053 .79032 Mdot
.8453 .57421 Mdot
.1388 .48826 Mdot
.42407 .78734 Mdot
.49264 .39961 Mdot
.22399 .66933 Mdot
.71905 .75784 Mdot
.35803 .81482 Mdot
.74778 .56481 Mdot
.59376 .51073 Mdot
.56317 .61191 Mdot
.83335 .59213 Mdot
.7252 .48437 Mdot
.26329 .70121 Mdot
.81558 .5529 Mdot
.57877 .67085 Mdot
.79132 .34492 Mdot
.71174 .7284 Mdot
.35043 .49666 Mdot
.49494 .32616 Mdot
.49417 .37374 Mdot
.31473 .39251 Mdot
.31686 .61933 Mdot
.64858 .61742 Mdot
.53811 .28937 Mdot
.65318 .5299 Mdot
.66369 .328 Mdot
.35188 .66394 Mdot
.41234 .45651 Mdot
.49966 .48241 Mdot
.36114 .63407 Mdot
.52687 .7808 Mdot
.59213 .69171 Mdot
.59486 .82449 Mdot
.74506 .62954 Mdot
.4711 .45369 Mdot
.48643 .26024 Mdot
.75751 .52513 Mdot
.8097 .50946 Mdot
.50358 .641 Mdot
.39027 .80774 Mdot
.57055 .46495 Mdot
.53733 .27869 Mdot
.31746 .38154 Mdot
.1866 .48897 Mdot
.36681 .38233 Mdot
.45052 .75926 Mdot
.27666 .50861 Mdot
.5756 .55315 Mdot
.30059 .61732 Mdot
.29752 .61793 Mdot
.17304 .61913 Mdot
.77896 .57876 Mdot
.65892 .6293 Mdot
.37743 .80116 Mdot
.52608 .63576 Mdot
.34059 .62385 Mdot
.62899 .32721 Mdot
.17916 .49366 Mdot
.29228 .48432 Mdot
.75144 .38635 Mdot
.70493 .6648 Mdot
.70947 .42464 Mdot
.39438 .80172 Mdot
.41887 .81225 Mdot
.5893 .17103 Mdot
.32684 .557 Mdot
.19528 .52669 Mdot
.21335 .37886 Mdot
.33659 .63295 Mdot
.41255 .57472 Mdot
.50045 .72159 Mdot
.6074 .81082 Mdot
.55762 .69784 Mdot
.17783 .40472 Mdot
.48557 .22064 Mdot
.64785 .68994 Mdot
.76407 .37935 Mdot
.32362 .26094 Mdot
.36479 .79437 Mdot
.33768 .3364 Mdot
.36218 .50943 Mdot
.38318 .44055 Mdot
.53436 .36688 Mdot
.86547 .53361 Mdot
.64138 .57415 Mdot
.31303 .43718 Mdot
.36265 .72808 Mdot
.4075 .38553 Mdot
.849 .59349 Mdot
.20388 .57838 Mdot
.82318 .49453 Mdot
.57868 .63508 Mdot
.41097 .35689 Mdot
.47573 .35464 Mdot
.51701 .32477 Mdot
.444 .74229 Mdot
.66496 .75658 Mdot
.31854 .26389 Mdot
.3776 .75465 Mdot
.32562 .34202 Mdot
.70249 .70207 Mdot
.28257 .7121 Mdot
.22672 .62217 Mdot
.54848 .52479 Mdot
.75146 .6294 Mdot
.56935 .23898 Mdot
.14502 .48597 Mdot
.59152 .43932 Mdot
.44252 .57199 Mdot
.47998 .692 Mdot
.40534 .73746 Mdot
.7296 .33555 Mdot
.45401 .35033 Mdot
.79241 .49188 Mdot
.28424 .7305 Mdot
.50573 .16526 Mdot
.73167 .30025 Mdot
.84096 .60926 Mdot
.30041 .51749 Mdot
.38646 .72667 Mdot
.274 .65512 Mdot
.46072 .15622 Mdot
.57899 .43877 Mdot
.51041 .81993 Mdot
.57577 .23813 Mdot
.38577 .80144 Mdot
.53669 .68465 Mdot
.43826 .64122 Mdot
.61219 .76267 Mdot
.58315 .81504 Mdot
.23543 .55228 Mdot
.31137 .75478 Mdot
.46435 .60293 Mdot
.66724 .79453 Mdot
.57122 .74622 Mdot
.46528 .54227 Mdot
.69376 .50058 Mdot
.78843 .53004 Mdot
.40271 .79288 Mdot
.48546 .7913 Mdot
.31923 .27478 Mdot
.69204 .55782 Mdot
.60136 .32268 Mdot
.3474 .46965 Mdot
.60837 .27479 Mdot
.40447 .74616 Mdot
.48695 .25993 Mdot
.29187 .75471 Mdot
.60409 .43456 Mdot
.78617 .45941 Mdot
.69971 .70158 Mdot
.26469 .28379 Mdot
.44931 .74017 Mdot
.78408 .56797 Mdot
.2422 .62793 Mdot
.72013 .39345 Mdot
.39202 .25058 Mdot
.34714 .86779 Mdot
.24989 .31952 Mdot
.54197 .7672 Mdot
.62656 .79729 Mdot
.23173 .64941 Mdot
.5394 .7759 Mdot
.70128 .26368 Mdot
.41413 .27666 Mdot
.6046 .31117 Mdot
.4412 .39985 Mdot
.7636 .7224 Mdot
.58088 .27726 Mdot
.64207 .79572 Mdot
.21146 .65657 Mdot
.31849 .40618 Mdot
.41271 .45602 Mdot
.62982 .55116 Mdot
.65858 .59781 Mdot
.62977 .28921 Mdot
.33385 .52851 Mdot
.37833 .27647 Mdot
.72298 .64578 Mdot
.69983 .51867 Mdot
.71589 .47322 Mdot
.38991 .5363 Mdot
.74724 .60771 Mdot
.42739 .74822 Mdot
.66457 .36551 Mdot
.53762 .549 Mdot
.49314 .27938 Mdot
.38986 .29658 Mdot
.34674 .4967 Mdot
.68509 .26592 Mdot
.53415 .49115 Mdot
.67649 .50909 Mdot
.31603 .52512 Mdot
.19188 .39324 Mdot
.4048 .75919 Mdot
.67791 .76331 Mdot
.79661 .5153 Mdot
.4019 .50032 Mdot
.49384 .28907 Mdot
.67461 .24581 Mdot
.43168 .20094 Mdot
.53644 .7908 Mdot
.39524 .30819 Mdot
.39349 .23221 Mdot
.38328 .65765 Mdot
.52294 .84284 Mdot
.28608 .29042 Mdot
.25103 .34011 Mdot
.68724 .57835 Mdot
.28832 .44598 Mdot
.32776 .42365 Mdot
.53835 .23306 Mdot
.53486 .56342 Mdot
.82257 .34881 Mdot
.37889 .62912 Mdot
.88113 .53498 Mdot
.55496 .66791 Mdot
.82055 .41968 Mdot
.56233 .22585 Mdot
.49215 .52904 Mdot
.52123 .56974 Mdot
.46108 .75972 Mdot
.44593 .67091 Mdot
.15626 .4832 Mdot
.57637 .18032 Mdot
.64014 .56072 Mdot
.32404 .24902 Mdot
.28065 .25891 Mdot
.29826 .54873 Mdot
.3993 .43258 Mdot
.24546 .32185 Mdot
.66475 .5646 Mdot
.6763 .28123 Mdot
.21913 .64649 Mdot
.46045 .78137 Mdot
.51411 .42795 Mdot
.51784 .28471 Mdot
.50071 .81942 Mdot
.3517 .80068 Mdot
.7528 .30554 Mdot
.42721 .79298 Mdot
.55727 .68119 Mdot
.45305 .54819 Mdot
.33195 .76178 Mdot
.44043 .23699 Mdot
.39308 .6894 Mdot
.41324 .25478 Mdot
.8731 .452 Mdot
.64061 .76369 Mdot
.6638 .75659 Mdot
.43343 .24572 Mdot
.36473 .55125 Mdot
.55184 .74554 Mdot
.40341 .26376 Mdot
.47073 .77773 Mdot
.16916 .46274 Mdot
.41544 .25848 Mdot
.55991 .15057 Mdot
.20718 .43065 Mdot
.63619 .44826 Mdot
.33239 .42828 Mdot
.2121 .43147 Mdot
.58062 .65825 Mdot
.63042 .31226 Mdot
.3624 .73266 Mdot
.57408 .6441 Mdot
.41109 .74929 Mdot
.39965 .71815 Mdot
.22646 .37954 Mdot
.3025 .48393 Mdot
.39225 .76522 Mdot
.27237 .57784 Mdot
.28243 .62149 Mdot
.70256 .31713 Mdot
.69976 .48834 Mdot
.34199 .72395 Mdot
.67496 .49231 Mdot
.35435 .35654 Mdot
.56992 .53989 Mdot
.45042 .48497 Mdot
.84023 .57175 Mdot
.64376 .37661 Mdot
.39015 .57867 Mdot
.83136 .42392 Mdot
.35239 .63295 Mdot
.791 .68448 Mdot
.66239 .24953 Mdot
.31645 .37357 Mdot
.6956 .39695 Mdot
.68002 .4437 Mdot
.69813 .2172 Mdot
.38431 .51406 Mdot
.68936 .57969 Mdot
.28834 .59721 Mdot
.37632 .56257 Mdot
.71493 .67607 Mdot
.69312 .53211 Mdot
.45642 .29441 Mdot
.48035 .67414 Mdot
.40948 .5186 Mdot
.3506 .54246 Mdot
.56681 .49392 Mdot
.55848 .32364 Mdot
.59903 .8148 Mdot
.68025 .52102 Mdot
.85631 .44207 Mdot
.37402 .41272 Mdot
.25925 .5424 Mdot
.24708 .71241 Mdot
.77472 .32614 Mdot
.60986 .53046 Mdot
.29868 .23 Mdot
.37966 .37967 Mdot
.39693 .77182 Mdot
.34879 .57952 Mdot
.26407 .32487 Mdot
.63278 .36576 Mdot
.49952 .25285 Mdot
.5525 .60905 Mdot
.73108 .32598 Mdot
.74048 .60897 Mdot
.36144 .54782 Mdot
.45788 .79212 Mdot
.19319 .49958 Mdot
.42173 .66435 Mdot
.67799 .45506 Mdot
.31637 .53308 Mdot
.29798 .47839 Mdot
.35482 .54263 Mdot
.64305 .77321 Mdot
.26726 .31515 Mdot
.49632 .85786 Mdot
.44747 .47378 Mdot
.76478 .48254 Mdot
.46815 .66978 Mdot
.42869 .75887 Mdot
.4591 .30342 Mdot
.25939 .72859 Mdot
.54968 .28672 Mdot
.49345 .70036 Mdot
.52839 .30265 Mdot
.35322 .39147 Mdot
.52531 .54376 Mdot
.68514 .60997 Mdot
.63432 .19137 Mdot
.50978 .33175 Mdot
.7884 .36763 Mdot
.3884 .31186 Mdot
.71749 .68745 Mdot
.39748 .55795 Mdot
.60484 .49202 Mdot
.29679 .44882 Mdot
.61991 .59775 Mdot
.5075 .84617 Mdot
.25622 .72361 Mdot
.57984 .61591 Mdot
.70155 .68758 Mdot
.30864 .68867 Mdot
.43495 .47102 Mdot
.45742 .61338 Mdot
.42554 .43642 Mdot
.4046 .56398 Mdot
.79097 .33867 Mdot
.46147 .77076 Mdot
.40839 .32038 Mdot
.50895 .83762 Mdot
.45803 .84455 Mdot
.6589 .79664 Mdot
.36137 .2276 Mdot
.32521 .57282 Mdot
.75611 .70981 Mdot
.3654 .29275 Mdot
.30374 .7759 Mdot
.52519 .7918 Mdot
.18318 .63508 Mdot
.35241 .51579 Mdot
.35749 .71825 Mdot
.59111 .1914 Mdot
.43104 .68751 Mdot
.21135 .61572 Mdot
.46308 .51903 Mdot
.6404 .63916 Mdot
.20932 .6226 Mdot
.58105 .13616 Mdot
.42724 .30238 Mdot
.38974 .71059 Mdot
.42017 .6284 Mdot
.34909 .7281 Mdot
.7481 .41883 Mdot
.48382 .39109 Mdot
.6165 .72484 Mdot
.77492 .40266 Mdot
.47777 .27322 Mdot
.60344 .32265 Mdot
.7463 .4183 Mdot
.64347 .30273 Mdot
.54412 .31398 Mdot
.28889 .28486 Mdot
.34224 .51794 Mdot
.46261 .29873 Mdot
.37379 .39069 Mdot
.40264 .56863 Mdot
.59196 .38835 Mdot
.63022 .48077 Mdot
.43566 .43438 Mdot
.6044 .54973 Mdot
.42939 .66955 Mdot
.82901 .62833 Mdot
.60602 .62522 Mdot
.18873 .55056 Mdot
.36393 .63681 Mdot
.44695 .74842 Mdot
.25846 .61807 Mdot
.81009 .43873 Mdot
.74658 .45704 Mdot
.45998 .27675 Mdot
.47438 .83172 Mdot
.78669 .61297 Mdot
.18904 .45229 Mdot
.78451 .64292 Mdot
.57073 .66697 Mdot
.51884 .39411 Mdot
.43245 .60778 Mdot
.76642 .54084 Mdot
.29972 .59597 Mdot
.363 .72176 Mdot
.71435 .55919 Mdot
.7857 .58718 Mdot
.18499 .57451 Mdot
.1901 .4921 Mdot
.36121 .48027 Mdot
.43024 .8181 Mdot
.66601 .55068 Mdot
.25138 .3312 Mdot
.38626 .6844 Mdot
.75203 .47467 Mdot
.7018 .71792 Mdot
.57001 .83214 Mdot
.47913 .59493 Mdot
.55648 .25839 Mdot
.41177 .37084 Mdot
.29358 .34409 Mdot
.46854 .76772 Mdot
.53819 .41387 Mdot
.71797 .62856 Mdot
.37493 .60821 Mdot
.70647 .6195 Mdot
.57367 .42703 Mdot
.60657 .30741 Mdot
.33103 .54461 Mdot
.34925 .27873 Mdot
.57675 .37299 Mdot
.47895 .65104 Mdot
.44811 .44876 Mdot
.53805 .25467 Mdot
.37824 .22387 Mdot
.51501 .39635 Mdot
.39442 .78321 Mdot
.33009 .52024 Mdot
.17996 .46814 Mdot
.42481 .77043 Mdot
.5456 .78923 Mdot
.4464 .6776 Mdot
.30912 .45669 Mdot
.75053 .54642 Mdot
.43508 .44309 Mdot
.60236 .49878 Mdot
.35513 .62598 Mdot
.28069 .68783 Mdot
.29555 .51529 Mdot
.54658 .24106 Mdot
.51202 .51748 Mdot
.25725 .60608 Mdot
.50772 .504 Mdot
.23291 .68305 Mdot
.43228 .68874 Mdot
.54226 .29111 Mdot
.52197 .68535 Mdot
.5603 .22719 Mdot
.69426 .26549 Mdot
.4192 .83006 Mdot
.65615 .23357 Mdot
.48156 .57383 Mdot
.78981 .3633 Mdot
.54759 .75745 Mdot
.21188 .64044 Mdot
.54997 .30076 Mdot
.49034 .58819 Mdot
.60407 .32836 Mdot
.57919 .60958 Mdot
.54424 .49997 Mdot
.60194 .47726 Mdot
.4096 .28646 Mdot
.68031 .6607 Mdot
.71177 .58001 Mdot
.36959 .42139 Mdot
.65744 .74257 Mdot
.45637 .82673 Mdot
.26928 .32526 Mdot
.51869 .48749 Mdot
.6923 .33741 Mdot
.60303 .3023 Mdot
.12293 .48761 Mdot
.85879 .58163 Mdot
.41007 .37251 Mdot
.5244 .4811 Mdot
.53383 .26576 Mdot
.63084 .55749 Mdot
.38801 .28187 Mdot
.26877 .6169 Mdot
.53489 .67049 Mdot
.59153 .49544 Mdot
.79158 .57272 Mdot
.47108 .76004 Mdot
.60281 .26312 Mdot
.63159 .73977 Mdot
.82578 .63915 Mdot
.16912 .43382 Mdot
.44182 .7638 Mdot
.12992 .54913 Mdot
.71612 .58697 Mdot
.30696 .63661 Mdot
.24785 .58772 Mdot
.61415 .80203 Mdot
.48268 .25549 Mdot
.72717 .34417 Mdot
.57731 .78143 Mdot
.55195 .29252 Mdot
.38569 .2616 Mdot
.70346 .69819 Mdot
.71155 .62101 Mdot
.48858 .54513 Mdot
.68205 .44454 Mdot
.75133 .68761 Mdot
.32701 .35025 Mdot
.47361 .82326 Mdot
.77614 .40002 Mdot
.53064 .14282 Mdot
.47096 .84865 Mdot
.65088 .32609 Mdot
.74965 .411 Mdot
.24492 .58162 Mdot
.46511 .22583 Mdot
.37105 .27183 Mdot
.696 .29266 Mdot
.28246 .48093 Mdot
.66499 .43241 Mdot
.7862 .3866 Mdot
.50103 .28906 Mdot
.21634 .41985 Mdot
.49296 .58548 Mdot
.33414 .50601 Mdot
.72648 .65499 Mdot
.44432 .2512 Mdot
.58124 .47657 Mdot
.49845 .23077 Mdot
.31194 .53145 Mdot
.24976 .6317 Mdot
.35349 .69523 Mdot
.61505 .15624 Mdot
.54563 .79837 Mdot
.80823 .43139 Mdot
.475 .4339 Mdot
.53602 .84883 Mdot
.36755 .69432 Mdot
.56932 .78741 Mdot
.17298 .52445 Mdot
.62635 .46605 Mdot
.46006 .64372 Mdot
.43696 .44291 Mdot
.46724 .80566 Mdot
.31603 .43928 Mdot
.21004 .44867 Mdot
.74748 .34754 Mdot
.49775 .26519 Mdot
.76081 .4129 Mdot
.52335 .22473 Mdot
.50547 .43054 Mdot
.37793 .61619 Mdot
.75457 .7215 Mdot
.46763 .58847 Mdot
.36194 .34081 Mdot
.53473 .39728 Mdot
.60189 .19377 Mdot
.20338 .34833 Mdot
.45702 .47211 Mdot
.77399 .63576 Mdot
.36481 .26104 Mdot
.38637 .48191 Mdot
.36141 .31945 Mdot
.16047 .31462 Mdot
.28535 .78762 Mdot
.32765 .56314 Mdot
.31295 .30014 Mdot
.37745 .2416 Mdot
.6061 .80502 Mdot
.718 .45624 Mdot
.67319 .47335 Mdot
.53081 .18481 Mdot
.44167 .22411 Mdot
.37617 .40454 Mdot
.17876 .55657 Mdot
.40112 .82271 Mdot
.75843 .35706 Mdot
.49865 .83971 Mdot
.40043 .31487 Mdot
.41487 .32424 Mdot
.13291 .38853 Mdot
.34076 .77094 Mdot
.4943 .36579 Mdot
.60326 .19147 Mdot
.30087 .62261 Mdot
.42666 .40824 Mdot
.64349 .73629 Mdot
.31449 .27135 Mdot
.50102 .29118 Mdot
.58481 .81455 Mdot
.31797 .56045 Mdot
.61292 .58757 Mdot
.53016 .67134 Mdot
.52632 .56713 Mdot
.38968 .3525 Mdot
.54688 .62983 Mdot
.39562 .4843 Mdot
.34206 .71518 Mdot
.58367 .65157 Mdot
.29746 .26353 Mdot
.20942 .69263 Mdot
.31355 .50626 Mdot
.53695 .59979 Mdot
.42209 .47366 Mdot
.20622 .43767 Mdot
.63391 .29348 Mdot
.4237 .54652 Mdot
.2027 .62353 Mdot
.45854 .89432 Mdot
.64899 .64283 Mdot
.5568 .34286 Mdot
.32752 .54585 Mdot
.45742 .29856 Mdot
.34478 .47828 Mdot
.50139 .68414 Mdot
.66993 .54542 Mdot
.43873 .46547 Mdot
.50287 .4333 Mdot
.56371 .61525 Mdot
.87604 .52757 Mdot
.47761 .37456 Mdot
.37346 .30915 Mdot
.309 .77707 Mdot
.70462 .31857 Mdot
.24838 .53667 Mdot
.42571 .33732 Mdot
.53607 .73709 Mdot
.48905 .58988 Mdot
.32155 .72796 Mdot
.78587 .46455 Mdot
.54428 .82159 Mdot
.29282 .51494 Mdot
.34112 .4437 Mdot
.47403 .3966 Mdot
.60692 .40408 Mdot
.40024 .70582 Mdot
.59763 .78482 Mdot
.42717 .3098 Mdot
.33378 .79756 Mdot
.62934 .46257 Mdot
.69251 .66914 Mdot
.37599 .47484 Mdot
.68226 .77416 Mdot
.7673 .34263 Mdot
.32586 .43802 Mdot
.82465 .46999 Mdot
.77321 .56003 Mdot
.60554 .2746 Mdot
.6366 .55308 Mdot
.37546 .33822 Mdot
.32286 .55544 Mdot
.82582 .64738 Mdot
.60412 .78269 Mdot
.6081 .70037 Mdot
.68261 .63483 Mdot
.29052 .37494 Mdot
.40191 .66379 Mdot
.16407 .61847 Mdot
.73328 .48365 Mdot
.83339 .62734 Mdot
.25087 .33784 Mdot
.37318 .5258 Mdot
.38456 .73218 Mdot
.51004 .36926 Mdot
.67247 .5132 Mdot
.58252 .80741 Mdot
.49744 .43675 Mdot
.79873 .45227 Mdot
.40873 .34758 Mdot
.8215 .51084 Mdot
.58563 .53399 Mdot
.67833 .71374 Mdot
.5915 .72838 Mdot
.7034 .2674 Mdot
.26582 .68875 Mdot
.59213 .66675 Mdot
.14317 .56289 Mdot
.28808 .69808 Mdot
.3915 .80905 Mdot
.74475 .3777 Mdot
.73589 .27553 Mdot
.49537 .79196 Mdot
.39628 .76434 Mdot
.6 .68914 Mdot
.4539 .49821 Mdot
.78493 .52666 Mdot
.38862 .47833 Mdot
.41678 .70873 Mdot
.58468 .6201 Mdot
.5759 .91056 Mdot
.63534 .33736 Mdot
.33833 .65593 Mdot
.76949 .52314 Mdot
.43456 .82648 Mdot
.49998 .46643 Mdot
.18845 .59162 Mdot
.5712 .44733 Mdot
.39659 .32839 Mdot
.29578 .4944 Mdot
.28207 .31328 Mdot
.79468 .5302 Mdot
.74132 .24714 Mdot
.16966 .43798 Mdot
.68494 .64999 Mdot
.54402 .54072 Mdot
.33308 .63074 Mdot
.40182 .61607 Mdot
.6929 .42156 Mdot
.16239 .55617 Mdot
.35241 .71706 Mdot
.33308 .76302 Mdot
.68421 .20857 Mdot
.20465 .40747 Mdot
.60918 .80672 Mdot
.52019 .76929 Mdot
.40021 .60655 Mdot
.65649 .32373 Mdot
.67 .38787 Mdot
.60403 .72338 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o
0000X?ooool001cooooo00?o0000ooooooooool0Yoooool2o`000:3ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0
000Booooo`;o0000S_ooool001cooooo00?o0000ooooooooool0^Oooool2o`0008kooooo000Loooo
o`03o`000?oooooooooo0:Wooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`1looooo`;o
0000:oooool2o`0009kooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000dooooo`;o0000
UOooool001cooooo0_l0001kooooo`;o0000=_ooool2o`0000Oooooo0_l0002<ooooo`007?ooool0
0ol0003oooooooooo`1jooooo`;o00005_ooool2o`0002Oooooo0_l00007ooooo`;o0000Poooool0
01cooooo00?o0000ooooooooool0T_ooool2o`00033ooooo0_l00023ooooo`007?ooool00ol0003o
ooooooooo`2eooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Poooool2o`0001cooooo
0_l0000Booooo`;o00002_ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0
000Aooooo`;o00002Oooool2o`0000;ooooo0_l0000Hooooo`Co0000Q_ooool001cooooo00?o0000
ooooooooool0POooool2o`0000Cooooo0_l0000=ooooo`?o000000?oooooo`000?l000002Oooool2
o`0001Gooooo0_l000000ooooooo0000o`000028ooooo`007?ooool00ol0003oooooooooo`21oooo
o`;o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`00000Booooo`;o00003?ooool2o`00
08_ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00006ooooo`;o00001oooool2o`0000Co
oooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o00000_ooool2o`0000?ooooo
1?l0000;ooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00001looooo`007?oo
ool00ol0003oooooooooo`2=ooooo`;o00005?ooool2o`0000?ooooo1?l00005ooooo`;o00001?oo
ool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l00000O?ooool001cooooo00?o0000
ooooooooool0K?ooool2o`0000Kooooo0_l0000Gooooo`;o00003?ooool2o`0000[ooooo1?l00006
ooooo`;o00003Oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo06cooooo0_l00006oooo
o`;o000000?oooooo`000?l000007_ooool2o`0000;ooooo0_l0000:ooooo`Co00005_ooool2o`00
08Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1Tooooo`;o00004Oooool2o`0001kooooo0_l0000Sooooo`Oo00001oooool2
o`0007gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Tooooo`?o00000oooool2o`0001gooooo
0_l0000Dooooo`;o00006_ooool7o`0000Sooooo0_l0001mooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0IOoo
ool2o`0000?ooooo0_l0000;ooooo`;o00004?ooool2o`0001Cooooo0_l0000Jooooo`;o00000_oo
ool2o`0008Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0005Kooooo0_l0000Oooooo`;o00000oooool2o`0000[ooooo0ol00009
ooooo`;o0000=_ooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Fooooo`;o00000oooool2o`00
01oooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00006ooooo`Co00009?ooool2o`00
013ooooo0_l0001kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool2o`0001?ooooo0_l0000:ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo0_l0000Aooooo`;o
00003oooool2o`0000Oooooo0_l00007ooooo`;o00003?ooool2o`0006gooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo06Oooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00003Oooool2
o`0000Cooooo0_l00007ooooo`;o00002?ooool4o`0000?ooooo0_l0000Aooooo`;o00001Oooool4
o`0000cooooo0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l00000
2oooool2o`0000Cooooo0_l0000Pooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00006?ooool2o`0007gooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0
000Fooooo`;o00001oooool4o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`00023ooooo0ol0
00000ooooooo0000o`00000=ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0O?ooool2
o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00001_ooool2o`0000?ooooo0_l0
000<ooooo`Co00007_ooool3o`000004ooooool0003o0000ooooo`;o00002_ooool4o`0006Sooooo
000Looooo`03o`000?oooooooooo06Cooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000000ol00003ooooo`?o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000_ooooo0ol0000Tooooo`;o000000?o
ooooo`000?l00000Loooool001cooooo00?o0000ooooooooool0I?ooool2o`0000[ooooo1?l00003
ooooo`;o00001Oooool3o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`Go00000_ooool4
o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3
o`0001oooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00004oooool3o`00
00;ooooo0_l00005ooooo`;o00004oooool3o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Kooooo0_l00002ooooo`?o0000U?ooool001cooooo00?o0000oooooooo
ool0GOooool2o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o00000_ooool2o`00023o
oooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0001gooooo0_l0001fooooo`00
7?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0_l00006ooooo`Co00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool4o`0000_ooooo0_l00004ooooo`Co00007?ooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo05Wooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`Co00000ooo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo1Ol000000ooooooo0000
o`00000?ooooo`;o00000_ooool8o`0001Kooooo0_l000000ooooooo0000o`00001eooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000000oooool5o`0000;ooooo0_l00007ooooo`Ko00002?ooool2o`0000;ooooo1Ol0
000Booooo`?o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00004Oooool2o`000003oooo
ool0003o000000;ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00004Ooo
ool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`Co00002oooool2o`000003ooooool0
003o000000;o00001oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Wooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo0_l0000Booooo`;o0000
1?ooool3o`0000kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o00002_oo
ool4o`0000gooooo0_l00003ooooo`Co00000oooool2o`0000Sooooo0_l00003ooooo`;o00000_oo
ool2o`0000Wooooo0_l00007ooooo`;o00005oooool2o`0000Gooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0001Jooooo`007?ooool2o`0006Oooooo0ol0000:ooooo`Co00001Oooool3
o`0000Gooooo1_l000000ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l0000B
ooooo`;o00002Oooool3o`0001Oooooo0_l0000;ooooo`;o00002oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo07cooooo0ol00003ooooo`;o00000_ooool4o`0000?ooooo0_l0000:oooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00002_ooool7o`00
017ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo06oooooo0_l0000<ooooo`;o00000oooool5o`0001;ooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0003o000000Cooooo0ol00002
ooooo`;o000000?oooooo`000?l00000Ioooool001cooooo00?o0000ooooooooool0Eoooool2o`00
0003ooooool0003o000000Wooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1?l00007oooo
o`Co00000oooool2o`0000Cooooo0_l00008ooooo`Co00003Oooool2o`0000Cooooo0_l0000Uoooo
o`;o00000oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l000001?oooooo
0000o`000?ooool2o`0000Gooooo0ol0000<ooooo`;o00000oooool4o`0000?ooooo0_l00009oooo
o`;o00000_ooool6o`0000Kooooo0ol00004ooooo`;o00005_ooool2o`0000?ooooo1?l0000Moooo
o`?o0000Ioooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo1?l00004ooooo`?o
000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;ooooo0ol0000=ooooo`;o
00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000Co
oooo0_l00003ooooo`Co00004?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0006Ko
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l00009ooooo`Co00000_ooool5o`000003oooo
ool0003o000000Gooooo0_l00005ooooo`;o00005_ooool2o`0000Kooooo0_l0000:ooooo`;o0000
1oooool2o`0000gooooo0_l0000>ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o
0000I_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Oooooo1Ol00003ooooo`;o0000
2Oooool2o`0001cooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o00005_ooool2o`0000Go
oooo0_l00007ooooo`;o00003Oooool2o`00017ooooo0_l0001Cooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`Co00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000[ooooo
0_l0000;ooooo`Go00000_ooool2o`00017ooooo0_l00007ooooo`Co00002_ooool5o`0000?ooooo
0ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool4o`0000Oooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001oooool2o`0000Oooooo0ol0
0002ooooo`;o00000oooool2o`0000[ooooo0_l0000;ooooo`Co00001Oooool2o`000003ooooool0
003o000000Kooooo0_l00005ooooo`;o00001_ooool4o`0000;ooooo0_l00006ooooo`Go00000ooo
ool3o`0000;ooooo0_l00009ooooo`;o00003_ooool4o`0005cooooo000Looooo`03o`000?oooooo
oooo04Sooooo0_l0000Aooooo`;o00004Oooool2o`0000[ooooo0_l0000Mooooo`Go00000oooool5
o`0000Gooooo0_l00006ooooo`Co00000_ooool2o`0000Sooooo1?l0000<ooooo`;o00000_ooool3
o`0006oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`;o00001_ooool2o`00
00Kooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000001cooooo0_l00004oooo
o`Go00001?ooool2o`0000Oooooo1?l00002ooooo`;o00002_ooool2o`0000Kooooo0_l00004oooo
o`;o00000_ooool3o`00017ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Booooo`;o
00001_ooool2o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`000003ooooool0003o000000Wo
oooo0_l00002ooooo`;o00000_ooool2o`0000gooooo1?l00005ooooo`Co000000?oooooo`000?l0
00000_l00004ooooo`Oo00001?ooool2o`000003ooooool0003o000000?o00002oooool4o`000003
ooooool0003o000000gooooo0_l0000=ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0
D?ooool2o`0000Oooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo
0_l00005ooooo`Ko00002oooool9o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`000?l00000
1ol00007ooooo`;o000000?oooooo`000?l000002oooool4o`00013ooooo0ol000000ooooooo0000
o`00001Wooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001oooool2o`0000_ooooo0_l0
000;ooooo`;o00001Oooool2o`0000;ooooo1ol0000<ooooo`?o000000Coooooo`000?l0003ooooo
0ol00004ooooo`?o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o
00006?ooool2o`0000cooooo1?l000000ooooooo0000o`000003o`0000Sooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`;o00003?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
1_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000=ooooo`;o00007Oooool3o`0000go
oooo0_l00008ooooo`;o00003?ooool4o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0005go
oooo000Looooo`;o0000E?ooool2o`0000cooooo0ol0000Gooooo`;o00005?ooool4o`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001oooool4o`0000?ooooo
0ol00004ooooo`Go00009?ooool2o`000004ooooool0003o0000o`0005gooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo1Ol000000ooooooo0000
o`00000?ooooo`;o00002?ooool4o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co
00000_ooool4o`0000Gooooo0_l00004ooooo`Co00001?ooool5o`0000_ooooo0_l0000Booooo`;o
00001_ooool5o`0005_ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000;ooooo`;o0000
2?ooool4o`0000Cooooo1Ol000000ooooooo0000o`00000?ooooo`;o00002?ooool3o`0000Sooooo
0ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo
0_l000001?oooooo0000o`000?l0000:ooooo`;o000000?oooooo`000?l000000oooool4o`0000?o
oooo0_l00003ooooo`;o00001oooool4o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00000oooool2o`0000Kooooo0_l0000:ooooo`;o00002_ooool2o`0000Gooooo
0_l00008ooooo`;o00008Oooool4o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo
0_l0000=ooooo`;o00000oooool4o`0000?ooooo0_l00007ooooo`;o00001oooool2o`000003oooo
ool0003o000000gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00006?oo
ool4o`0000Cooooo0_l0000Fooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool2o`0000Gooooo0_l00002ooooo`;o00005_ooool2o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o00004Oooool2o`0000;ooooo
1?l000000ooooooo0000o`000007ooooo`;o00004?ooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l0000:ooooo`;o00005Oooool2o`0000?ooooo0_l0000?ooooo`;o00001Ooo
ool2o`0000Sooooo2?l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol0
0007ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l0000=ooooo`?o00001_oo
ool2o`0000Wooooo0_l0000:ooooo`Co00004Oooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l0000Kooooo`;o00000oooool3o`0001Cooooo0_l00005ooooo`Co00001oooool8
o`000003ooooool0003o000000?o00000_ooool3o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000o`0000_ooooo0_l00005ooooo`;o00003Oooool2o`0001;ooooo
0_l0000:ooooo`?o00002oooool2o`0000Gooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00000_ooool3o`0000?ooooo0_l0000;ooooo`;o00004Oooool3o`0000Kooooo0_l0
0004ooooo`;o00000_ooool4o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00002?oo
ool4o`000003ooooool0003o000001kooooo0ol00006ooooo`;o00000oooool4o`0005Oooooo000L
ooooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`?o00000oooool6o`0000Oooooo0_l00009
ooooo`;o00001oooool4o`0000;ooooo3?l000001Ooooooo0000o`000?l0003ooooo00Oo00000ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool3o`000003ooooool0
003o000000Gooooo1_l000001?oooooo0000o`000?ooool3o`0000Oooooo1_l00004ooooo`;o0000
3Oooool2o`000004ooooool0003o0000o`0000Cooooo1?l00004ooooo`;o00004?ooool2o`0003go
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o00000oooool7o`00017ooooo
0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`000004oooo
ool0003o0000ooooo`?o000000Coooooo`000?l0003ooooo0ol00004ooooo`Co00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o00000oooool3o`000003ooooool0003o0000
00Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo1_l00000
1?oooooo0000o`000?ooool2o`0000_ooooo1?l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0
000:ooooo`;o00001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00006
ooooo`;o00001oooool2o`00017ooooo0_l00004ooooo`;o00002_ooool4o`000003ooooool0003o
000000Oo000000?oooooo`000?l000001?l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00005
ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Wooooo1?l00009ooooo`;o000000?oooooo`000?l000003oooool2o`0000gooooo0_l00013
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00004oooool2o`0001Wooooo0_l000000ooo
oooo0000o`000007o`000003ooooool0003o000000Co000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo0_l00004ooooo`;o00004Oooool2o`0000Wooooo0_l00006ooooo`;o00002_ooool2o`00
05;ooooo000Looooo`03o`000?oooooooooo04gooooo0ol0000>ooooo`;o00000oooool2o`0000Go
oooo0_l00008ooooo`Co00001Oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000007o`0000;ooooo2?l00008ooooo`Co00001?ooool2o`0000;o
oooo0_l00009ooooo`Co00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000@ooooo`;o
00002_ooool2o`0000_ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o0000
3?ooool3o`0000Kooooo0_l00002ooooo`;o00001_ooool6o`0000Cooooo2Ol000000ooooooo0000
o`00000;o`0000Cooooo1?l000000ooooooo0000o`00000:ooooo`;o00005Oooool3o`000005oooo
ool0003o0000o`000?ooool01_l0000@ooooo`;o00005oooool2o`000003ooooool0003o000000;o
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00001?ooool3o`0000_ooooo
0ol00007ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`Oo000000?oooooo`000?l00000
1_l00003ooooo`So00000_ooool2o`0001;ooooo0_l00004ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000017ooooo
0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0001:ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00004?ooool4o`0000kooooo0_l000000ooooooo0000o`000005ooooo`Go00003Ooo
ool3o`0000Sooooo1ol000000ooooooo0000o`00000?o`0000Cooooo0ol00006ooooo`;o00002Ooo
ool2o`0000Cooooo1?l00002ooooo`go00002?ooool2o`000003ooooool0003o000000Gooooo0_l0
000:ooooo`Co00000oooool2o`0000Cooooo0_l00006ooooo`;o0000B_ooool001cooooo0_l0000f
ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo1?l00002
ooooo`Go00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004
o`0000?ooooo7?l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00008
ooooo`;o00000_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000006o`00013ooooo0ol00006
ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o00002?ooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l00003ooooo`;o00006?ooool4o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo8?l000001?oooooo0000o`000?l00006
ooooo`?o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00005oooooa;o000000?ooooo
o`000?l000001_ooool2o`0000;ooooo0_l00004ooooo`Go00004Oooool4o`0000cooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001_ooool2o`0000oooooo0_l0000Eoooo
o`;o00000oooool2o`0000;ooooo8Ol00002ooooo`;o00000oooool2o`0000Kooooo0_l00008oooo
o`Co00001OoooolFo`0000Kooooo0_l00008ooooo`Go00003Oooool2o`0000;ooooo1?l00005oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000?ooooo`Co00000oooool4o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000?o
oooo8?l00002ooooo`;o00000oooool2o`00013ooooo1?l00005ooooo`_o00000_ooool7o`0000So
oooo0_l0000Iooooo`?o00002oooool2o`0000Kooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000
o`000004o`0000Oooooo0_l00006ooooo`;o00001oooool6o`000003ooooool0003o000001Go0000
00?oooooo`000?l000001?ooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool;o`000003ooooool0003o000000Ko00000_ooool2o`0000;ooooo1?l0000Iooooo`;o0000
2Oooool2o`0000Wooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0looooo`?o00002?oo
ool2o`0000gooooo0_l00005ooooo`?o00003?ooool2o`0000Cooooo1?l00002ooooo`;o000000?o
ooooo`000?l000007ol000000ooooooo0000o`000004o`0000Cooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001?oooolEo`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000
4_ooool2o`0000_ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00005ooo
ool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`00
000Qo`0000;ooooo1ol00005ooooo`?o00001ooooolPo`000003ooooool0003o000000Kooooo0_l0
000Booooo`;o00002_ooool2o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o0000>oooool^o`0000Cooooo1Ol00005ooooo`?o00001ooooolPo`0000;ooooo0_l00005
ooooo`;o00001oooool2o`0000Oooooo0_l0000<ooooo`;o00001?ooool2o`0004Gooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l0000Looooo`;o00002oooool2o`0000Cooooo1?l00008oooo
o`?o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000002?o00000_ooool2
o`0001Gooooo6?l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000Cooooo1Ol00000
0ooooooo0000o`000002o`0000Oooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o00002_ooool2o`0000_ooooo0_l00004ooooo`Co00002?ooool9o`000003ooooool0003o0000
01So00000oooool;o`0000;ooooo1Ol00003ooooo`;o00002_ooool2o`000003ooooool0003o0000
01Ko000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000;ooooo`Go000000?oooooo`00
0?l000000_l00007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?oooool5o`0000;o
oooo1?l0000<ooooo`;o00002_ooool3o`0000Sooooo1Ol00002ooooo`;o00000_oooolKo`000003
ooooool0003o000000[o000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool2o`0000Ko
oooo1?l000000ooooooo0000o`00000Do`000003ooooool0003o000000Cooooo0_l00005ooooo`;o
00002Oooool2o`0000?ooooo0_l00004ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0
?oooool5o`0000;ooooo1?l0000<ooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`?o0000
00?oooooo`000?l000008ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`000003
ooooool0003o000000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000004ol00002ooooo`;o
00005Oooool3o`0000Wooooo0_l0000=ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0
>_ooool4o`0000Sooooo0_l0000Tooooo`;o00001OoooolVo`000003ooooool0003o000000?o0000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@oooooaSo00000oooool2o`0000Gooooo
0_l00009ooooo`?o00001Oooool4o`0000Sooooo0_l00003ooooo`Co0000A?ooool001cooooo00?o
0000ooooooooool09oooool2o`00017ooooo1?l00008ooooo`?o00006Oooool2o`0000Wooooo0_l0
0006oooooa7o000000?oooooo`000?l000005?l00002ooooo`;o000000?oooooo`000?l000005Ooo
oolHo`0000Gooooo0_l00005ooooo`;o00004Oooool4o`0000Oooooo0ol00003ooooo`;o00000_oo
ool2o`0004;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o00003oooool2o`000003oooo
ool0003o000000[ooooo0_l0000Aooooo`;o00001?ooool5o`000003ooooool0003o000000Gooooo
1ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o000000?oooooo`000?l00000
7_l000001?oooooo0000o`000?ooool2o`0001;ooooo6?l0000Eooooo`;o00002Oooool2o`0000So
oooo0_l00008ooooo`;o0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`Go00002_ooool3o`00
013ooooo0_l00002ooooo`Oo000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00co000000?oooooo`000?l000003_l000001?oooooo0000o`000?ooool3o`0001Gooooo5_l0000<
ooooo`;o00001_ooool2o`0000Wooooo1?l0000?ooooo`;o0000@oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0>Oooool2o`00
00Gooooo0_l00004ooooo`Co00005?ooool2o`0000cooooo1?l00006ooooob[o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00004Oooool?o`0000;ooooo1?l0000<ooooo`;o00002_ooool4
o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0004?ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Wooooo0ol00004
ooooo`;o00001?ooool2o`0001?ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool2
o`0000;ooooo3_l00002oooooaGo000000?oooooo`000?l000000ol00009ooooo`Co00003oooool2
o`000005ooooool0003o0000o`000?ooool02Ol0000Hooooo`;o00000oooool4o`0000Gooooo0_l0
0003ooooo`;o00002_ooool2o`0004?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0fooooo`;o00000_oo
ool3o`0000?ooooo0_l00003ooooo`Go00004Oooool2o`0000Oooooo0_l000000ooooooo0000o`00
0009ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000Co0000
00?oooooo`000?l000005?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00006ooooo`;o
00004?ooool5o`000003ooooool0003o000000Oo00003oooool2o`0000Oooooo0_l00004ooooo`;o
00001_ooool2o`0000?ooooo0_l0000:ooooo`?o0000@_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Kooooo
0_l00002ooooo`?o00000_ooool3o`0000?ooooo1Ol0000Gooooo`;o000000Coooooo`000?l0003o
oooo0ol00009ooooo`;o000000Coooooo`000?l0003ooooo9Ol000001?oooooo0000o`000?l00002
ooooo`;o00006?ooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000A
ooooo`;o00004oooool2o`000003ooooool0003o000000Co00002oooool2o`0004;ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`0oooooo`;o00006oooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo7ol0
00000ooooooo0000o`000003o`000004ooooool0003o0000o`0002Oooooo0_l00002ooooo`;o0000
7?ooool2o`0000?ooooo2_l00005ooooo`;o000000?oooooo`000?l00000AOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo033o
oooo0_l0000Zooooo`;o00002oooool2o`0000[ooooo0ol000000ooooooo0000o`00000Ro`0000;o
oooo0_l0000:ooooo`;o00008?ooool2o`0000?ooooo0_l0000Eooooo`Co00000oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000004Go
oooo000Looooo`03o`000?oooooooooo033ooooo0_l0000gooooo`;o00001_ooool2o`0000?ooooo
0ol000000ooooooo0000o`00000Ro`0000gooooo0_l0000Fooooo`?o000000?oooooo`000?l00000
2Oooool2o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l000001?oooooo0000
o`000?l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l0000[ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000
o`00000Mo`000003ooooool0003o000000?o00001_ooool2o`0001Kooooo0_l00004ooooo`?o0000
00?oooooo`000?l000000_l00002ooooo`;o00003_ooool2o`0000Kooooo0_l00008ooooo`;o0000
0oooool4o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`Co0000
@?ooool001cooooo00?o0000ooooooooool0@Oooool4o`0001Sooooo0_l00008ooooo`;o00001ooo
ool2o`0000;ooooo1?l00002ooooobGo00001_ooool2o`0001Kooooo0_l0000:ooooo`;o00000_oo
ool2o`0000kooooo0_l00004ooooo`;o00002_ooool2o`0000Gooooo0_l0000<ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001Ooo
ool2o`0001?ooooo0_l00008ooooo`;o00001?ooool3o`0000Kooooo0_l00002ooooo`ko000000?o
ooooo`000?l000004Ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`00017o
oooo0_l00006ooooo`;o00008_ooool2o`0001_ooooo0_l00002ooooo`?o00000oooool2o`0003go
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00006ooooo`;o00007_ooool2o`0000?ooooo
0ol00006ooooo`;o00000_ooool2o`000003ooooool0003o000000So000000?oooooo`000?l00000
4_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000gooooo1_l00004oooo
o`Co00001?ooool2o`0001Sooooo0_l0000=ooooo`;o00004?ooool2o`0000?ooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`0000Gooooo0ol0000Uooooo`;o
00002?ooool4o`0000Cooooo6ol00002ooooo`Oo00000_ooool2o`00017ooooo1?l00006ooooo`;o
00001_ooool2o`0000gooooo0_l00009ooooo`;o00003Oooool2o`0000Sooooo0_l00009ooooo`;o
0000A?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l00006ooooo`?o0000
0oooool2o`0001Oooooo1?l0000>ooooo`Co00000_oooolJo`000003ooooool0003o000000oo0000
7?ooool2o`0000?ooooo0_l0000=ooooo`;o00008Oooool4o`0000Sooooo0_l00006ooooo`;o0000
??ooool001cooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004oooool2o`0000;ooooo1Ol000000ooooooo0000o`000008ooooo`Co00000ooo
ool6o`0000Cooooo0ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000;ooooo0_l0
000Dooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000:_ooool2o`0000Cooooo1?l0
00000ooooooo0000o`000005ooooo`;o00001_ooool2o`000003ooooool0003o000003Wooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00006oooool2o`0000Cooooo0ol00000
0ooooooo0000o`000008ooooo`;o00001Oooool6o`0000Sooooo4Ol00003ooooo`Co00000_ooool2
o`0001Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000<oooool2o`0000Wooooo0_l00005
ooooo`;o00002Oooool2o`0000;ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`1Joooo
o`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00000oooool4o`0000Sooooo3?l00002oooo
o`Go00001oooool4o`000003ooooool0003o000000oooooo0ol00007ooooo`;o00000oooool2o`00
00;ooooo0_l0000?ooooo`?o00007Oooool2o`0000Gooooo0_l0000@ooooo`;o0000=Oooool001co
oooo00?o0000ooooooooool09oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000Ko
oooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o
00001Oooool3o`0000Cooooo0_l000000ooooooo0000o`00000:o`0000;ooooo1Ol00004ooooo`;o
00000oooool2o`000003ooooool0003o0000013ooooo0_l00007ooooo`?o00000_ooool6o`000003
ooooool0003o000000cooooo0ol0000Mooooo`;o00001Oooool2o`0000?ooooo0_l00012ooooo`00
7?ooool2o`0002Sooooo0_l00005ooooo`Co000000?oooooo`000?l000001?ooool3o`0000Gooooo
0_l00003ooooo`;o00005Oooool2o`00017ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`00
00Kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`;o00001Oooool2o`00
013ooooo0_l0000Dooooo`;o00001?ooool2o`000003ooooool0003o000000;o00004Oooool2o`00
00Sooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0^ooooo`Co00001oooool3o`00027o
oooo0_l0000Aooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1Ol00002ooooo`Go
000000?oooooo`000?l000000_ooool8o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001?ooool2o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000Dooooo`;o00001?ooool2o`00
0004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000o`000008ooooo`;o00009Oooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0_l00006ooooo`;o00007_ooool2o`00
00Gooooo0ol0000:ooooo`?o000000?oooooo`000?l000000oooool<o`0000?ooooo1?l000000ooo
oooo0000o`000003o`0000Gooooo0_l00008ooooo`;o00002_ooool2o`0000Gooooo1?l0000:oooo
o`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00005oooo
o`;o00002?ooool2o`0002Cooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00001Oooool2o`0000Cooooo0_l0000Gooooo`?o00001Oooool3o`0000[ooooo0_l00002ooooo`;o
00001oooool3o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo0_l0000Aooooo`;o
00002_ooool2o`0000Gooooo0_l00003ooooo`;o00005Oooool6o`000003ooooool0003o000000;o
00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l0
0000B?ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000Gooooo`;o00008?ooool2o`0000;ooooo
1?l00003ooooo`;o00003Oooool2o`0001Sooooo1?l000001?oooooo0000o`000?ooool2o`0000Wo
oooo0_l0000;ooooo`So00005?ooool4o`0000Cooooo1?l000000ooooooo0000o`000007o`00047o
oooo000Looooo`03o`000?oooooooooo02cooooo0_l00005ooooo`;o00000_ooool2o`0002kooooo
0_l00009ooooo`;o00003_ooool4o`0000?ooooo1_l00003ooooo`;o00000oooool4o`000004oooo
ool0003o0000ooooo`;o00005Oooool4o`000003ooooool0003o000000_ooooo0ol0000;ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00004oooool2o`0000Cooooo1Ol00002ooooo`Oo
0000@Oooool001cooooo00?o0000ooooooooool0:?ooool2o`0000gooooo0_l0000Pooooo`;o0000
2?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool4o`0000?ooooo0_l00003ooooo`;o0000
1?ooool2o`0000?ooooo1_l00003ooooo`;o00000oooool4o`0000Cooooo0_l0000=ooooo`;o0000
1?ooool2o`000003ooooool0003o000000;o00003Oooool4o`0000[ooooo0_l00005ooooo`Co0000
0oooool2o`0000Wooooo0_l0000<ooooo`;o00002Oooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo02Sooooo1?l0000;ooooo`;o00000_ooool2o`0001cooooo0_l00008ooooo`;o00001?oo
ool2o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Gooooo`;o
000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000?ooooo`;o00002oooool2o`0000Co
oooo1Ol00002ooooo`?o00002?ooool2o`0000cooooo1?l00007ooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0:_ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o0000027ooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`000003oooo
ool0003o000000?o00000_ooool7o`00013ooooo0_l00005ooooo`?o00001_ooool3o`0000?ooooo
0_l00005ooooo`;o00005Oooool2o`0000Kooooo2?l00004ooooo`;o00000oooool2o`0000_ooooo
1?l00018ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool3o`0000;ooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o00000_oo
ool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0
0006ooooo`;o00001Oooool5o`0000;ooooo1Ol00003ooooo`;o00001Oooool2o`0000Cooooo0_l0
000>ooooo`Co00001oooool3o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0
000Booooo`;o0000>?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Kooooo0_l00005
ooooo`;o00006?ooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`Ko00001_ooool2o`0000oooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool4o`000004ooooool0003o0000o`0001;ooooo0_l000000ooooooo0000o`00
000;ooooo`So00001?ooool2o`00017ooooo1?l00002ooooo`;o00000oooool2o`0000gooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000_ooool2o`0000Kooooo0_l0000?
ooooo`;o00003_ooool2o`000003ooooool0003o000000Co00001oooool2o`0000Gooooo0_l00005
ooooo`Ko000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`Co00001Oooool2o`00013ooooo0_l0
0007ooooo`Co000000?oooooo`000?l000001_l00003ooooo`;o00001?ooool4o`0000Wooooo1Ol0
0006ooooo`;o00001_ooool4o`0003gooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00003
ooooo`Co00000_ooool2o`0000Sooooo0_l0000=ooooo`;o00004?ooool7o`0000kooooo0_l00008
ooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o
000000Cooooo0ol000000ooooooo0000o`000005ooooo`?o000000Coooooo`000?l0003o00001?oo
ool2o`00017ooooo0_l00005ooooo`Go000000?oooooo`000?l000001_l000000ooooooo0000o`00
0006ooooo`Co00003?ooool2o`0000;ooooo0_l00009ooooo`Go00001?ooool2o`0000;ooooo0_l0
000cooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00000oooool2o`0000Cooooo0_l00008
ooooo`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000oooooo0_l00006
ooooo`Co00000_ooool2o`0001[ooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o
000000Cooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o00003_ooool3
o`0000Cooooo1?l00003oooooa?o00000oooool2o`0000;ooooo0_l0000Aooooo`Co00001oooool2
o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000<oooool001cooooo00?o0000oooo
ooooool0;_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo1Ol0000A
ooooo`;o00001?ooool4o`0000;ooooo0_l0000=ooooo`;o00004?ooool2o`0000_ooooo0_l00003
ooooo`;o00002Oooool3o`000003ooooool0003o000000?o00001Oooool2o`0000Kooooo0_l00003
ooooo`?o00001?ooool3o`000003ooooool0003o000001;o00001?ooool3o`0000Sooooo0_l00007
ooooo`;o00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`0003gooooo000Loooo
o`03o`000?oooooooooo02kooooo0ol00006ooooo`;o00003_ooool2o`0001?ooooo0_l00004oooo
o`;o00002Oooool3o`0000Oooooo0_l0000Gooooo`;o00000_ooool6o`00017ooooo1?l00005oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o0000
00oo000000?oooooo`000?l000000oooool3o`0000Wooooo0_l00005ooooo`Co000000Coooooo`00
0?l0003o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000oooooo`007?ooool2o`00
033ooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0_l0000Pooooo`?o00003oooool2o`00
00oooooo0ol000000ooooooo0000o`000002ooooo`;o00002oooool4o`0000;ooooo1_l00007oooo
o`;o00001_ooool2o`0000Sooooo1ol000000ooooooo0000o`00000>o`000004ooooool0003o0000
o`00013ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00015ooooo`007?ooool00ol0
003oooooooooo`0eooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o0000<?ooool4o`00
013ooooo0_l0000>ooooo`;o00000_ooool4o`0000Cooooo1_l000001?oooooo0000o`000?ooool2
o`0000kooooo6ol00002ooooo`;o00000_ooool2o`0000[ooooo1?l00002ooooo`;o000000Cooooo
o`000?l0003ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2
o`0000Kooooo0ol0000Gooooo`;o00001Oooool2o`0001;ooooo0_l0000Rooooo`;o00003?ooool4
o`000003ooooool0003o000000Co00003OoooolAo`000003ooooool0003o000000So000000?ooooo
o`000?l000000_ooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo03Oooooo1?l00004ooooo`;o00001oooool5o`00
00Wooooo0_l0000:ooooo`;o00001Oooool4o`0000Gooooo0_l00007ooooo`;o00007_ooool2o`00
00Kooooo0_l0000Aooooo`Ko000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Io`0000gooooo1?l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00002oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo1_l00004ooooo`;o
00002Oooool3o`0000Wooooo0_l00003ooooo`;o00003_ooool2o`0000Gooooo0_l00005ooooo`Co
00000_ooool2o`0000Oooooo1?l00006ooooo`;o00001oooool2o`0000Kooooo1?l0000:ooooo`;o
00000oooool2o`000003ooooool0003o000000Co00001?ooool2o`0000?ooooo0ol000000ooooooo
0000o`00000Io`0000cooooo2?l00006ooooo`Co00000_ooool2o`0000Cooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`0002?ooooo1?l0000Aooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo1?l00006ooooo`;o
00004Oooool4o`0000Sooooo0_l00007ooooo`?o00002_oooolKo`0000;ooooo0ol0000<ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo1_l00008ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0BOooool2o`0000oooooo1_l00007ooooo`;o00000_ooool2o`0000;ooooo
0_l00003ooooo`?o00002_ooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o0000
3_ooool2o`0000;ooooo0_l0000Aooooo`;o00002_oooolLo`0000;ooooo0_l0000=ooooo`;o0000
1Oooool2o`0000?ooooo0_l00002ooooo`;o00005?ooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l0000Fooooo`;o00000oooool2o`0000cooooo1?l00007ooooo`;o00000_oo
ool2o`0000Oooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l0
0006ooooo`;o00003_ooool2o`0001;ooooo0_l00002ooooo`;o00002?oooolMo`0000?ooooo0_l0
000?ooooo`;o00000_ooool2o`0000Kooooo1?l00002ooooo`;o00003oooool2o`0002kooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l000000ooooooo0000o`00000Hooooo`;o00003?ooool2
o`0000Gooooo0_l0000@ooooo`;o00001Oooool2o`00033ooooo0_l00007ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000005ol000000ooooooo0000o`000002
o`0000_ooooo0_l00002ooooo`;o00002_ooool4o`0000;ooooo0_l0000oooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o000000?oooooo`000?l000001_ooool3o`000003ooooool0003o0000
01Cooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000?ooooo0_l00002ooooo`co000000?oooooo`000?l000003ol000000ooo
oooo0000o`00000=ooooo`;o00001Oooool4o`0000Sooooo0_l00003ooooo`;o00003Oooool2o`00
02kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00005ooooo`?o000000?oooooo`000?l0
00005?ooool4o`0000Sooooo0_l00005ooooo`Co00001Oooool2o`0000;ooooo0_l0000=ooooo`;o
000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000Gooooo3?l000000ooooooo0000o`00000Bo`000004
ooooool0003o0000o`0001Cooooo1ol00005ooooo`;o00000oooool2o`0000gooooo0_l0000^oooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o00000_ooool2o`0001gooooo0_l00008ooooo`?o
00001_ooool2o`0000Wooooo0_l00008ooooo`Co000000?oooooo`000?l000005Oooool2o`00013o
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool<o`000003ooooool0003o0000
01;o000000Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o000000Cooooo0ol00003
ooooo`Co00000_ooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0002gooooo000Loooo
o`03o`000?oooooooooo02cooooo0_l0000:ooooo`?o00004_ooool2o`0001Cooooo0_l00006oooo
o`Ko00001_ooool2o`0000;ooooo0_l00003ooooo`Go00003?ooool3o`0001[ooooo0_l00006oooo
o`?o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000?o`0000Sooooo0_l000000ooooooo0000o`000004oooo
o`?o00002Oooool2o`0000?ooooo0ol0000;ooooo`;o00000oooool2o`0002gooooo000Looooo`03
o`000?oooooooooo02cooooo0_l0000:ooooo`;o00002_ooool2o`0000Oooooo0_l0000Cooooo`Co
00001Oooool7o`0000Gooooo0_l00002ooooo`;o00001Oooool4o`0000_ooooo0ol0000Iooooo`?o
00001Oooool6o`0000Gooooo2ol00002oooooa;o000000Coooooo`000?l0003o00004_ooool2o`00
00kooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`Co00003Oooool4o`0000;o
oooo0_l00004ooooo`Ko00001?ooool2o`000003ooooool0003o000000Oooooo0_l0000=ooooo`;o
00004?ooool4o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001ooooolQo`00
00Sooooo0_l00008ooooo`;o00003_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000=ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`Co00001oooool2o`0000;o
oooo0_l00004ooooo`Co000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Wooooo0_l0000;ooooo`;o00001_ooool2o`0000Sooooo1?l0000@oooo
o`;o00001_oooolLo`000003ooooool0003o000000?o00002?ooool2o`0000?ooooo0_l0000Coooo
o`;o0000@_ooool001cooooo0_l0000Xooooo`;o00004Oooool2o`0000kooooo0_l00008ooooo`;o
00001_ooool3o`000003ooooool0003o000000Cooooo0ol00002ooooo`co00000oooool3o`0000Wo
oooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`0000[o
oooo8Ol0000>ooooo`;o00004Oooool4o`0004;ooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l0000Aooooo`;o00003Oooool2o`0000Wooooo0_l00007ooooo`;o00002Oooool2o`000003oooo
ool0003o000000Go000000?oooooo`000?l000001Oooool3o`0001;ooooo0_l00004ooooo`;o0000
5?ooool2o`0000Sooooo1_l00006ooooo`Oo000000?oooooo`000?l000002?l000000ooooooo0000
o`00000;o`0000Wooooo0_l0000Fooooo`Oo0000@?ooool001cooooo00?o0000ooooooooool0;_oo
ool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00002_ooool4o`00013ooooo0_l0
0006oooooa7o00000oooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l0
0007ooooo`;o00004?ooool<o`0000Cooooo2_l000000ooooooo0000o`00000>o`0000cooooo0_l0
000Fooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o0000=_ooool001cooooo00?o0000
ooooooooool0;_ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00003?ooool2
o`0000Oooooo0ol00006ooooo`;o00001Oooool9o`000003ooooool0003o000000Oo000000Gooooo
o`000?l0003o0000ooooo`03o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool2o`000004ooooool0
003o0000o`0000;ooooo1Ol000000ooooooo0000o`00000Go`0000?ooooo0_l00005ooooo`;o0000
4Oooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0003Kooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l00006ooooo`;o00001_ooool2o`0001Oooooo0ol0000<ooooo`?o000000?o
ooooo`000?l000005_l00005ooooo`;o00003_ooool2o`0000Sooooo0_l0000:ooooo`;o00002_oo
ool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?l000002Ol0
0006ooooo`;o000000?oooooo`000?l000000_ooool2o`00017ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001_ooool4o`0003Kooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00006
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000Gooooo`;o00000oooool2
o`0000;ooooo0_l00002oooooa?o000000?oooooo`000?l000000oooool2o`0000cooooo0_l0000;
ooooo`Co00001oooool2o`000004ooooool0003o0000o`0000cooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000002?l0000:ooooo`;o00003Oooool3o`0001;ooooo0_l00009ooooo`Co0000=_oo
ool001cooooo00?o0000ooooooooool0=?ooool6o`0000Oooooo0_l0000Gooooo`;o00000oooool2
o`000003ooooool0003o000001Oo00000_ooool5o`0000cooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00000oooool8o`0000[ooooo1?l0000=ooooo`;o00002Oooool2
o`0000[ooooo0_l00002ooooo`;o00002Oooool3o`0000Wooooo0_l00002ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0<oooool4o`000003ooooool0003o000002Oooooo6ol000000ooo
oooo0000o`000002o`0000_ooooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo2Ol0000;oooo
o`?o00003oooool2o`0001?ooooo1_l0000Dooooo`Oo00003?ooool2o`0000oooooo0_l0000Yoooo
o`007?ooool00ol0003oooooooooo`0cooooo`?o00000_ooool2o`0000Kooooo0_l00004ooooo`;o
00004oooool2o`0000Cooooo6ol00006ooooo`;o00002?ooool2o`0000_ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000_ooool4o`0000gooooo0_l0000?ooooo`;o00000_ooool4o`0001?o
oooo0_l0000Fooooo`;o000000?oooooo`000?l000003_ooool4o`0000Gooooo0_l00006ooooo`;o
0000:Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000;ooooo0_l00005ooooo`?o0000
00Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000Co
oooo7_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00009ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000=ooooo`;o00001oooool2o`000004
ooooool0003o0000o`0000;ooooo0_l00002ooooo`Co00003?ooool2o`0000[ooooo0_l0000@oooo
o`Co00001oooool2o`0000Wooooo0_l00005ooooo`;o0000<Oooool001cooooo00?o0000oooooooo
ool0?oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00001oooool2o`00
00[ooooo7_l00006ooooo`;o00000oooool2o`0000;ooooo1?l00009ooooo`;o00001oooool2o`00
01Wooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`0000Wooooo0ol00005
ooooo`Ko00004?ooool4o`0000Oooooo0_l0000=ooooo`;o0000=?ooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0000Cooooo1?l0000AoooooaCo000000?oooooo`000?l000001_l00002oooo
o`;o00000oooool2o`0000Wooooo0_l00009ooooo`;o00001oooool2o`0001cooooo0_l0000<oooo
o`;o00002_ooool2o`0000Gooooo1?l00007ooooo`;o00002Oooool2o`0000Gooooo0_l00002oooo
o`;o00003?ooool3o`0003Cooooo000Looooo`03o`000?oooooooooo03Gooooo0ol0000Booooo`;o
000000Coooooo`000?l0003o00002_ooool2o`0000Cooooo4_l000000ooooooo0000o`00000=o`00
00;ooooo0ol0000Eooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`00
00;ooooo0_l00002ooooo`?o00006?ooool2o`0000Kooooo0_l00006ooooo`?o00002oooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000cooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`0eooooo`?o00003_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Sooooo0_l00004ooooob3o00000oooool3o`0000kooooo0_l00005ooooo`?o00000_ooool2o`00
00?ooooo0_l00007ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`00
00kooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`000019oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo0_l00006ooooo`Co00000_oo
ool2o`0000Sooooo8_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?l00007ooooo`;o00008Oooool2o`0000?ooooo0_l0000>ooooo`;o0000
3Oooool2o`0000[ooooo0_l00004ooooo`;o00002oooool2o`0000?ooooo0_l0000gooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000oooooo0_l00004oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000>o`0000;ooooo3_l0000@oooo
o`;o00000oooool4o`0001gooooo0_l0000;ooooo`?o000000?oooooo`000?l000002?ooool2o`00
01?ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0000Aooooo`;o00000oooool2o`00
03Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo03gooooo0_l00004ooooo`;o00005Oooool2o`00
00;ooooo4_l000000ooooooo0000o`00000;o`000003ooooool0003o000001Gooooo1_l0000?oooo
o`;o00002_ooool2o`0000Cooooo0ol00004ooooo`Co00002_ooool4o`0000Gooooo0_l0000:oooo
o`;o00002_ooool2o`0005Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000?Oooool2o`0000Cooooo0_l0000Koooo
oaKo000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o000000Coooooo`00
0?l0003o00002?ooool5o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
0005ooooo`;o00003_ooool5o`0000?ooooo1Ol00004ooooo`;o00001?ooool4o`0000Gooooo0_l0
000fooooo`;o0000=?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0001Cooooo0_l0
0006ooooo`;o00001_ooool6o`000003ooooool0003o000001;o00000_ooool3o`000005ooooool0
003o0000o`000?ooool00ol00008ooooo`Go00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00002?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool4o`0000Kooooo
0ol0000Iooooo`?o0000:Oooool2o`0003Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0jooooo`Ko00000_oo
ool2o`0000cooooo0_l00006ooooo`;o00001_oooolPo`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Oooooo0_l00008ooooo`So00000ooo
ool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0
003o000000;o00003Oooool3o`0000?ooooo1?l0000Looooo`;o0000>_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03cooooo
1?l00002ooooo`?o00006ooooolTo`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo
0_l0000;ooooo`_o00000oooool2o`00017ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000@ooooo`Co00001Oooool2o`0000Cooooo0_l0000?ooooo`;o0000
>_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo03[ooooo1?l00003ooooo`Co00001?ooool2o`0000Kooooo0_l00009oooo
o`;o00000_oooolOo`000003ooooool0003o000000;o00003Oooool2o`0000[ooooo0ol00007oooo
o`;o000000Coooooo`000?l0003ooooo2?l0000=ooooo`;o000000?oooooo`000?l000005?ooool2
o`0001Wooooo0_l00004ooooo`;o00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo1?l00003ooooo`?o000000?oooooo`00
0?l000001_ooool6o`0000;ooooo6?l000000ooooooo0000o`000003o`0000oooooo0_l00006oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`ko00001?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000008ooooo`;o0000:oooool2o`0000Wooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0booooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo0ol000000ooooooo
0000o`000002ooooo`;o00000ooooolNo`0000Cooooo0_l0000Aooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00000Ao`0000Cooooo0ol00003oooo
o`;o000000Coooooo`000?l0003o00001oooool5o`000003ooooool0003o000000;o00003?ooool3
o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l00007ooooo`Co00001?ooool2o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`00
00;ooooo6Ol000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`0000;ooooo0_l00003oooo
o`;o00000_oooolEo`000004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?l0
0007ooooo`?o00000oooool4o`0000cooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo0ol0
00000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00001?ooool2
o`0000;ooooo0ol0000?ooooo`Ko000000?oooooo`000?l000005?l000000ooooooo0000o`000002
o`0001Sooooo0_l000000ooooooo0000o`000008ooooo`Wo000000?oooooo`000?l000002Ol00007
ooooo`Co0000=?ooool3o`000004ooooool0003o0000o`0000gooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`1:ooooo`?o00002_ooool2o`000003ooooool0003o000000?o000000Cooooo
o`000?l0003ooooo3?l000000ooooooo0000o`000007o`000004ooooool0003o0000o`0000;ooooo
0_l00004ooooo`;o00004_ooool2o`000003ooooool0003o000000?ooooo6?l00007ooooo`?o0000
3oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool4o`0000Gooooo
0_l00003ooooo`;o00001Oooool2o`0000Cooooo1?l0000looooo`007?ooool00ol0003ooooooooo
o`0looooo`;o00001Oooool2o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`000004o`0000;ooooo0_l0
0002ooooo`Ko00001?ooool4o`0001?ooooo0_l00002oooooaWo00001oooool2o`0000kooooo1?l0
0006ooooo`Co000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo1?l0
0003ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000;ooooo0ol00004ooooo`;o00002?ooool2o`0000cooooo0ol00002
ooooo`;o000000?oooooo`000?l000000oooool5o`0000;ooooo1_l00008ooooo`;o00002?ooool4
o`0001Gooooo6ol00006ooooo`;o00003Oooool2o`0000Gooooo0_l000000ooooooo0000o`000009
ooooo`Go00002oooool2o`000003ooooool0003o000000Gooooo0_l00018ooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00oooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo3Ol0000Doooo
o`;o00005?oooolLo`0000Gooooo0ol00009ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`Co00001Oooool2o`0000Kooooo0ol0000>ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000;o00003oooool2o`0000oo
oooo0ol000001?oooooo0000o`000?l0000Gooooo`;o00000oooool2o`0001;ooooo7?l00005oooo
o`;o00002_ooool5o`0000Kooooo0_l00005ooooo`;o00001oooool3o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0looooo`;o00001Oooool3o`0000Wooooo0_l00002ooooo`;o00000_ooool4o`00017o
oooo1?l00005ooooo`;o00003oooool2o`0000;ooooo0ol00005ooooo`;o00003?ooool<o`000003
ooooool0003o000000co00004oooool3o`0000Wooooo0_l0000;ooooo`?o00001Oooool2o`0000?o
oooo0_l00003ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo
1?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo1?l0000@ooooo`So0000
0_ooool2o`0000oooooo0_l00002ooooo`;o00001_ooool3o`0000Wooooo6ol0000Iooooo`;o0000
1_ooool2o`0000_ooooo1?l00006ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o0000
?oooool001cooooo0_l00014ooooo`Co000000?oooooo`000?l000003Oooool2o`0001;ooooo0_l0
0002ooooo`So00003oooool2o`0000_ooooo0_l00003ooooo`;o00001?oooolKo`000003ooooool0
003o000001Kooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00001_oo
ool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l00003ooooo`?o00003Oooool4o`00017ooooo1_l000000ooooooo0000o`000006
o`0000Oooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000006ol00002ooooo`;o00000_ooool2o`0001Oooooo0_l00002ooooo`;o00002?ooool2
o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0@?ooool3o`0000;ooooo0ol00002ooooo`;o00002Oooool2o`0000Sooooo0_l00009oooo
o`Ko000000?oooooo`000?l000000_ooool6o`0000Gooooo0_l000001?oooooo0000o`000?l00004
ooooo`?o00001?ooool2o`000003ooooool0003o000000Gooooo8?l00003ooooo`;o00006oooool2
o`0000Wooooo1?l00008ooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0@Oooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00001_ooool2o`00
00Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000Jo`0000Gooooo0_l00002oooo
o`;o00004oooool4o`000003ooooool0003o000000Kooooo0_l0000:ooooo`Go00002oooool2o`00
0003ooooool0003o000004;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`;o
00000_ooool3o`0000gooooo0_l00003ooooo`;o00002_ooool2o`0000cooooo1?l00004ooooo`;o
00004_ooool2o`0000Cooooo7?l00003ooooo`Co00000_ooool2o`0001?ooooo0_l00003ooooo`Go
00004_ooool2o`0000_ooooo0_l000000ooooooo0000o`000012ooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00002_ooool2o`0000Cooooo0ol00009ooooo`;o000000?oooooo`000?l00000
3oooool2o`0000kooooo0_l00004ooooo`;o00002Oooool5o`0000Cooooo0_l00005ooooo`Ko0000
00?oooooo`000?l000004_l00002ooooo`?o00008?ooool3o`0006Kooooo000Looooo`03o`000?oo
oooooooo04Gooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l00007ooooo`Co00001?oo
ool2o`0000Sooooo0_l00007ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0004o`0000?ooooo0_l00004ooooo`Ko00000_oooolDo`0000;ooooo0_l0000Nooooo`;o00004Ooo
ool2o`000003ooooool0003o000000gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00002?ooool2o`0001?ooooo1?l00004ooooo`;o00002?ooool2o`0000Oooooo0_l00007
ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool9o`000003ooooool0003o
000000ko000000?oooooo`000?l000005_ooool2o`0000_ooooo0_l00006ooooo`;o00002?ooool3
o`000003ooooool0003o000000gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00002oooool2o`0001Oooooo0_l0000Eooooo`Go00001oooool2o`0000?ooooo0_l00002oooo
oaGo000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000004_ooool3o`0000Sooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1:oooo
o`Co00002Oooool2o`0000?ooooo0_l00005ooooo`?o00001_ooool4o`0000Gooooo0_l00006oooo
o`;o00003Oooool3o`0001?ooooo4ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`;o00001_ooool2o`0001Gooooo0ol0001Rooooo`007?ooool00ol0003o
ooooooooo`18ooooo`Ko00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_ooool3o`0000;ooooo0_l00002ooooo`Co00001_ooool2o`0000Gooooo0_l00002ooooo`?o
00001?ooool2o`0000?ooooo0_l0000=ooooo`;o00001OoooolBo`000003ooooool0003o000000So
oooo0_l00003ooooo`;o00006Oooool2o`0000;ooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`Co00001oooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000;o
oooo0ol00004ooooo`;o00004_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o
000000?oooooo`000?l000001Ol0000=ooooo`?o00001_ooool2o`000003ooooool0003o000000_o
oooo0_l00003ooooo`Co00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000:oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000;ooooo0_l00008ooooo`?o
00001oooool2o`000004ooooool0003o0000o`0000;ooooo0ol00004ooooo`Go00002Oooool3o`00
00Gooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`Co000000?ooooo
o`000?l000001?ooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000B_ooool001cooooo00?o0000
ooooooooool0@?ooool2o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00002_ooool7
o`000003ooooool0003o000000Kooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`?o00001_ooool4o`0000;ooooo1?l00002ooooo`;o00001?ooool2o`0000?ooooo1?l0
0008ooooo`Co000000?oooooo`000?l000002Oooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo0_l00006ooooo`;o000000?ooooo
o`000?l000001?ooool3o`0000?ooooo0_l0000Eooooo`Co00002?ooool3o`0000Oooooo0_l0000?
ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Cooooo1?l00008ooooo`;o00001Oooool2
o`0000?ooooo0_l0000>ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0C?ooool2o`00
00cooooo0_l0000<ooooo`;o00001?ooool3o`0000?ooooo0ol000000ooooooo0000o`00000Moooo
o`;o00000_ooool2o`0000Cooooo0_l0000>ooooo`?o00002?ooool2o`000003ooooool0003o0000
00Go000000?oooooo`000?l000000oooool2o`0000_ooooo1?l00004ooooo`;o00001oooool3o`00
00Cooooo0_l0000Cooooo`;o0000@Oooool001cooooo0_l0001>ooooo`;o00000oooool3o`0000Go
oooo0_l0000Dooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l0000Fooooo`Co
00001?ooool2o`0000cooooo0_l0000<ooooo`Oo000000?oooooo`000?l000000oooool2o`0000So
oooo0_l000000ooooooo0000o`000004ooooo`Co00001oooool2o`0000Gooooo0_l0000Cooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0ol00008ooooo`;o0000
3Oooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0000Hooooo`;o0000
1?ooool4o`0000_ooooo0_l0000=ooooo`?o000000?oooooo`000?l000000oooool3o`0000Wooooo
0_l00002ooooo`;o000000?oooooo`000?l000001Ol0001Uooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00001?ooool2o`0000Wooooo0_l0000=ooooo`;o00003?ooool2o`0000;ooooo0ol0
000Tooooo`;o00002oooool2o`00017ooooo0_l00003ooooo`Go00002oooool2o`000004ooooool0
003o0000ooooo`Co0000IOooool001cooooo00?o0000ooooooooool0C?ooool2o`0001oooooo0_l0
0003ooooo`;o00001oooool5o`0000Cooooo0_l0000@ooooo`;o00003?ooool2o`0000Gooooo0_l0
0002ooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`Go00008oooool4o`0005?ooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00008
ooooo`;o00000oooool2o`0000Oooooo1Ol00002ooooo`Ko00003_ooool2o`0000cooooo1?l00003
ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00001Oooool6o`0000[ooooo0_l0000G
ooooo`Co0000Doooool001cooooo00?o0000ooooooooool0AOooool2o`0000Kooooo0ol00002oooo
o`;o00001?ooool2o`0000Wooooo0_l00006ooooo`?o000000?oooooo`000?l000002oooool4o`00
00;ooooo0_l00002ooooo`;o00007_ooool2o`0001_ooooo0_l000000ooooooo0000o`000007o`00
00Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0001Sooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00001_ooool4o`0000Sooooo0_l0000@ooooo`?o
000000Coooooo`000?l0003o00002_ooool4o`0001?ooooo0_l0000Dooooo`Co00001_ooool2o`00
00_ooooo1Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Oooooo0_l00008oooo
o`;o00001Oooool2o`0000kooooo0_l00008ooooo`;o0000A_ooool001cooooo00?o0000oooooooo
ool0@_ooool2o`0000_ooooo0ol00007ooooo`;o00003_ooool3o`0000Cooooo1?l00008ooooo`Co
00004oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool4o`0000Kooooo0_l00007ooooo`;o
000000?oooooo`000?l000001Ol00004ooooo`[o00002Oooool5o`0000oooooo0_l000001?oooooo
0000o`000?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000<ooooo`;o
00002Oooool2o`0000cooooo1?l00005ooooo`;o00001_ooool6o`00017ooooo1?l00006ooooo`;o
00000_ooool4o`000003ooooool0003o000000;o00000oooool7o`0000[ooooo0_l000000ooooooo
0000o`000005o`0000Gooooo0_l000000ooooooo0000o`000004o`0000Wooooo0ol0000Aooooo`;o
000000?oooooo`000?l00000Doooool001cooooo00?o0000ooooooooool0DOooool2o`0000Gooooo
0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
0_l00006ooooo`;o00005Oooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo
0_l00002ooooo`So000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool=o`000003
ooooool0003o000000Cooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001Oooool3o`0000[ooooo
0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0000Jooooo`;o00004Oooool5o`0000Kooooo
1?l000000ooooooo0000o`000006o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`?o0000
1?ooool2o`0000_ooooo0ol000000ooooooo0000o`000002ooooo`;o00003oooool2o`0004cooooo
000Looooo`03o`000?oooooooooo05Wooooo0_l000000ooooooo0000o`000003ooooo`Co00003Ooo
ool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000005oooool2o`0000Cooooo0_l0
0002ooooo`;o00004?ooool2o`0000cooooo0_l00003ooooo`?o00001Oooool2o`0000_ooooo0_l0
000Gooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003ooooo`Co00004Oooool2o`0000Sooooo1?l000000ooooooo0000o`00000G
ooooo`;o00001?ooool2o`0000?ooooo1?l00005ooooo`;o00005?ooool2o`0000?ooooo0_l00003
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0D_ooool4o`0000Cooooo1?l0000Hoooo
o`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000oooooo1?l00005ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Cooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1?l0001cooooo`007?ooool00ol0003o
ooooooooo`1Booooo`;o000000?oooooo`000?l000000oooool4o`0001cooooo0_l000000ooooooo
0000o`000008ooooo`;o00000oooool4o`000004ooooool0003o0000o`0000Cooooo0_l00009oooo
o`Co00003oooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00001oooool4o`00
0003ooooool0003o000000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co
000000?oooooo`000?l000008?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o
00000_ooool2o`0000?ooooo0ol00004ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
00002?ooool2o`0000Gooooo0_l00007ooooo`?o00001oooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000?ooooo0_l0001[ooooo`007?ooool2o`0005Cooooo0_l00002ooooo`?o0000
8?ooool2o`0000Cooooo1Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo
0_l0000;ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1oooool3o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`00073ooooo
000Looooo`03o`000?oooooooooo05Oooooo0ol000000ooooooo0000o`000003ooooo`;o00004?oo
ool2o`0000Kooooo1?l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00004?ooool2o`0000Cooooo0_l00004ooooo`Co00001oooool2o`0001?ooooo0ol0
0003ooooo`;o00002_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Sooooo1Ol00003
ooooo`?o00003oooool2o`0000?ooooo0_l00003ooooo`;o00008_ooool2o`0000Wooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Wooooo0_l0000Dooooo`Co00001Oooool2o`0000Kooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00000_ooool4o`0000kooooo0_l00004
ooooo`;o00001Oooool4o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0009ooooo`;o00003?ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o00002ooo
ool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`00067ooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l00007ooooo`;o00001oooool2o`0000_ooooo1?l00006ooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`?o00005_ooool2o`000003ooooool0003o000000Wooooo0_l0
0003ooooo`Co00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Gooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00000_ooool2o`0000Oooooo0_l00003
ooooo`;o00003_ooool2o`0000;ooooo0ol0000=ooooo`;o00002?ooool2o`0001Kooooo0_l0000A
ooooo`Co00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool00ol0
003oooooooooo`1Dooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`00
01?ooooo0_l00002ooooo`Go00002Oooool4o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`00
00Gooooo0_l0000Dooooo`;o00004_ooool4o`000003ooooool0003o000006cooooo000Looooo`03
o`000?oooooooooo05Cooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l0000:ooooo`;o
00004?ooool4o`0000Gooooo0_l00002ooooo`;o00001_ooool5o`0000Kooooo0_l00006ooooo`;o
00001Oooool2o`0001Cooooo0_l0000Booooo`Co0000Koooool001cooooo00?o0000ooooooooool0
F?ooool4o`0000?ooooo0_l0000:ooooo`;o00003Oooool5o`0000Kooooo0ol00008ooooo`Co0000
00?oooooo`000?l000005?ooool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000_ooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001?oo
ool4o`0001Kooooo1?l00008ooooo`;o00002Oooool2o`0000?ooooo0_l0000Dooooo`;o00001?oo
ool2o`0000cooooo0_l0000<ooooo`;o00002oooool4o`0006_ooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l00006ooooo`;o00005_ooool2o`000003ooooool0003o000001Cooooo0_l00000
0ooooooo0000o`00000@ooooo`?o000000?oooooo`000?l000002oooool3o`0008kooooo000Loooo
o`03o`000?oooooooooo06Sooooo0_l0000Booooo`;o00005?ooool2o`0000oooooo0_l00002oooo
o`?o000000?oooooo`000?l000001oooool2o`0000;ooooo0ol00002ooooo`Ko00002Oooool2o`00
07_ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00002ooooo`;o00002Oooool2o`0001;o
oooo0_l00008ooooo`;o00001oooool2o`0001;ooooo0_l0000?ooooo`Go00001?ooool6o`0000Wo
oooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00000_ooool2o`000003oooo
ool0003o000000[ooooo0ol0000Eooooo`Co00001oooool2o`0000Wooooo0_l00007ooooo`?o0000
1?ooool2o`000003ooooool0003o000000;o00001?ooool4o`00093ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Gooooo`;o00001oooool2o`0000[ooooo1_l000000ooooooo0000o`000003oooo
o`;o00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`00
0003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000;o00003?ooool2o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000003oooool2
o`0005kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Yooooo`;o00000oooool4o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`?o00001_ooool2o`0000Sooooo0_l0000:ooooo`;o0000
2?ooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool4o`0000Kooooo0ol00003ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`;o00003oooool2o`0005kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo06Kooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`000003
ooooool0003o000001oooooo0_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`?o
00000_ooool3o`0000?ooooo0_l0001eooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006Kooooo0ol00006ooooo`;o
00001Oooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`Co00001oooool2o`00013ooooo0_l00008ooooo`;o00004oooool4o`000003ooooool0003o0000
00?ooooo0_l0001kooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Wooooo`?o00001Oooool2o`00
00Gooooo0ol000000ooooooo0000o`000002o`0000Sooooo1?l00007ooooo`;o000000?oooooo`00
0?l000000oooool3o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000oooooo1ol0000Noooo
o`;o0000HOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0J?ooool2o`0000Gooooo0_l0000:oooo
o`?o00004oooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00001Oooool2o`00
00Sooooo0_l00007ooooo`;o00001_ooool3o`0000;ooooo0_l0000Iooooo`;o00000oooool2o`00
067ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo07_ooooo0ol00006ooooo`;o00002oooool2o`0002Kooooo0_l0
0007ooooo`;o00007Oooool2o`0006Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo077ooooo0_l0000?ooooo`Co
00003_ooool2o`0001cooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000008Go
oooo000Looooo`03o`000?oooooooooo077ooooo0_l0000?ooooo`;o00000_ooool4o`0000[ooooo
0_l0000Looooo`;o00001_ooool2o`0000?ooooo0_l00028ooooo`007?ooool00ol0003ooooooooo
o`1iooooo`;o00002oooool4o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`1iooooo`?o00000oooool2
o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o
000000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool3o`0008Wooooo000Loooo
o`03o`000?oooooooooo07[ooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l00004oooo
o`;o00004Oooool2o`0000Gooooo0_l0000;ooooo`?o00005_ooool3o`00073ooooo000Looooo`03
o`000?oooooooooo08Cooooo0_l00003ooooo`;o00001Oooool2o`0001Kooooo0_l00006ooooo`;o
00009?ooool3o`00073ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Hooooo`;o0000
4?ooool2o`0000Oooooo0_l00007ooooo`;o00002oooool2o`0009;ooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l0000Zooooo`?o00001_ooool2o`000003ooooool0003o000000Wooooo0_l0
0006ooooo`;o00003oooool2o`0000Kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`21
ooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1Ol0000G
ooooo`;o00001_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000Boooo
o`;o00001oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_l0000Roooo
o`;o0000Moooool001cooooo00?o0000ooooooooool0TOooool2o`000004ooooool0003o0000o`00
00[ooooo1?l000000ooooooo0000o`000002o`0001_ooooo0_l00009ooooo`;o0000Moooool001co
oooo00?o0000ooooooooool0TOooool6o`0000[ooooo0_l00007ooooo`;o00006Oooool2o`0008;o
oooo000Looooo`;o0000U?ooool4o`0000?ooooo0_l0000>ooooo`;o0000WOooool001cooooo00?o
0000ooooooooool0V_ooool2o`0002oooooo0_l0001looooo`007?ooool00ol0003oooooooooo`2M
ooooo`;o0000;?ooool2o`0007cooooo000Looooo`03o`000?oooooooooo09gooooo0_l0000[oooo
o`;o0000OOooool001cooooo00?o0000ooooooooool0b_ooool2o`0007gooooo000Looooo`03o`00
0?oooooooooo06gooooo0_l0003Jooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000f_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`34oooo
o`;o0000Poooool001cooooo00?o0000ooooooooool0a?ooool4o`00087ooooo000Looooo`03o`00
0?oooooooooo0<Kooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2Aooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0
TOooool2o`000;Kooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0R?ooool2o`0002gooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o0000
;Oooool2o`00093ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o0000VOooool001co
oooo00?o0000ooooooooool0[_ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03o`000?oooooo
oooo09gooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05oooo
o`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08cooooo002R
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?oV9RHoa0@4?oMgMd00oooool01OlQ8B7oV9RH
oooooonHV9So8B4Q08cooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00on7QhOoEEEEooooo`02oooo
o`05o`000?ooooooooooooooool00000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2<ooooo`00
X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05olc<c?l0003o
0000o`000?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0I
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413o^[Zjoooooonj^[[o410@08cooooo0032ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ob4Q8OnHV9SoooooogMg
MomEEED00oooool01Ol0003o^[Zjoooooonj^[[o000008cooooo0030ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?l@413o0000oc8b<_o^k^h00ooo
ool01OnYZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60092 .62114 Mdot
.60031 .61375 Mdot
.54318 .3359 Mdot
.42875 .56334 Mdot
.18347 .51831 Mdot
.56169 .37671 Mdot
.70401 .50406 Mdot
.69689 .5015 Mdot
.53544 .32854 Mdot
.67239 .69832 Mdot
.68448 .45786 Mdot
.47483 .57291 Mdot
.67503 .48523 Mdot
.40412 .59811 Mdot
.46932 .87644 Mdot
.43704 .51579 Mdot
.6031 .62455 Mdot
.30494 .31767 Mdot
.45489 .54405 Mdot
.57492 .34777 Mdot
.5697 .68353 Mdot
.40516 .59391 Mdot
.5919 .63735 Mdot
.4037 .59844 Mdot
.40363 .55969 Mdot
.58256 .63292 Mdot
.56611 .58784 Mdot
.36886 .54719 Mdot
.36485 .58668 Mdot
.68746 .4595 Mdot
.30385 .34296 Mdot
.27497 .7313 Mdot
.32605 .55067 Mdot
.27388 .55313 Mdot
.64959 .47519 Mdot
.46751 .76582 Mdot
.53942 .36916 Mdot
.694 .49497 Mdot
.69395 .4856 Mdot
.68162 .50713 Mdot
.68741 .5025 Mdot
.58882 .65415 Mdot
.76158 .53671 Mdot
.74601 .45414 Mdot
.39083 .62215 Mdot
.23346 .34479 Mdot
.36838 .73429 Mdot
.44123 .58377 Mdot
.57601 .67039 Mdot
.47921 .23912 Mdot
.70878 .35963 Mdot
.64283 .48193 Mdot
.55892 .33084 Mdot
.58211 .11821 Mdot
.67449 .46977 Mdot
.35517 .61558 Mdot
.54072 .35415 Mdot
.39278 .58481 Mdot
.39969 .60008 Mdot
.5052 .6837 Mdot
.35282 .53726 Mdot
.39218 .33496 Mdot
.55121 .60187 Mdot
.49019 .4554 Mdot
.551 .35155 Mdot
.69008 .4698 Mdot
.61697 .62629 Mdot
.66862 .46941 Mdot
.31819 .59678 Mdot
.55861 .39766 Mdot
.44706 .56257 Mdot
.6896 .46544 Mdot
.55019 .65727 Mdot
.36722 .56494 Mdot
.45298 .23154 Mdot
.24402 .32134 Mdot
.40438 .32569 Mdot
.47871 .74911 Mdot
.50972 .68099 Mdot
.45084 .28223 Mdot
.34987 .5897 Mdot
.26541 .41313 Mdot
.26536 .3084 Mdot
.5999 .68166 Mdot
.41624 .50871 Mdot
.34359 .31388 Mdot
.36864 .56026 Mdot
.16546 .49716 Mdot
.38191 .52145 Mdot
.52545 .51554 Mdot
.51827 .34671 Mdot
.55809 .63818 Mdot
.4226 .5612 Mdot
.37044 .58891 Mdot
.56224 .71794 Mdot
.44997 .55875 Mdot
.41411 .58175 Mdot
.60048 .67749 Mdot
.64297 .47148 Mdot
.33421 .56135 Mdot
.55844 .29967 Mdot
.58285 .37548 Mdot
.38538 .53124 Mdot
.53968 .39191 Mdot
.55063 .65562 Mdot
.37033 .5877 Mdot
.68967 .48459 Mdot
.40712 .53919 Mdot
.73828 .32026 Mdot
.60684 .63388 Mdot
.35545 .5672 Mdot
.40239 .37411 Mdot
.4123 .69512 Mdot
.55726 .65331 Mdot
.66747 .52324 Mdot
.46125 .55775 Mdot
.40389 .57491 Mdot
.6193 .63214 Mdot
.58889 .3698 Mdot
.18315 .44047 Mdot
.61907 .66522 Mdot
.62461 .45242 Mdot
.60184 .69327 Mdot
.47819 .58181 Mdot
.55713 .35217 Mdot
.72126 .51339 Mdot
.7339 .51837 Mdot
.30437 .3806 Mdot
.37258 .5616 Mdot
.7803 .54353 Mdot
.5828 .35517 Mdot
.57007 .65145 Mdot
.66868 .47404 Mdot
.36943 .51697 Mdot
.61138 .65157 Mdot
.64689 .44313 Mdot
.35921 .34256 Mdot
.69458 .30509 Mdot
.57997 .61296 Mdot
.58703 .44642 Mdot
.64125 .46314 Mdot
.66444 .5095 Mdot
.52891 .83924 Mdot
.60429 .67021 Mdot
.38228 .36196 Mdot
.66203 .4749 Mdot
.4081 .44327 Mdot
.37371 .61711 Mdot
.25551 .39971 Mdot
.79241 .38143 Mdot
.31888 .49238 Mdot
.65757 .32688 Mdot
.37604 .36447 Mdot
.64723 .50148 Mdot
.42145 .57266 Mdot
.57509 .623 Mdot
.58782 .63692 Mdot
.35448 .53608 Mdot
.39569 .54827 Mdot
.43305 .53066 Mdot
.44041 .59428 Mdot
.55126 .55621 Mdot
.39328 .51708 Mdot
.38405 .73783 Mdot
.55874 .63309 Mdot
.42996 .5684 Mdot
.55678 .33065 Mdot
.45163 .60896 Mdot
.69982 .48607 Mdot
.39951 .58801 Mdot
.4258 .56332 Mdot
.34141 .57231 Mdot
.64916 .49533 Mdot
.24894 .6756 Mdot
.36668 .66226 Mdot
.24652 .58993 Mdot
.60486 .56189 Mdot
.50581 .35397 Mdot
.37512 .55549 Mdot
.39504 .35301 Mdot
.53039 .7762 Mdot
.43279 .55247 Mdot
.30088 .19362 Mdot
.41357 .58757 Mdot
.20159 .58012 Mdot
.34125 .50856 Mdot
.25852 .57448 Mdot
.28203 .40508 Mdot
.40195 .56278 Mdot
.74586 .62303 Mdot
.6666 .43585 Mdot
.60784 .33169 Mdot
.67224 .50071 Mdot
.564 .34009 Mdot
.54473 .34189 Mdot
.4348 .41524 Mdot
.46008 .52195 Mdot
.46288 .58556 Mdot
.41688 .52424 Mdot
.5863 .38346 Mdot
.53449 .59738 Mdot
.39814 .37602 Mdot
.54131 .60805 Mdot
.22621 .67728 Mdot
.5364 .24679 Mdot
.69771 .46549 Mdot
.36013 .35722 Mdot
.52478 .37707 Mdot
.5198 .33888 Mdot
.37736 .36885 Mdot
.38414 .60131 Mdot
.60665 .66835 Mdot
.38552 .79969 Mdot
.66293 .25625 Mdot
.7911 .70802 Mdot
.59166 .67834 Mdot
.76388 .57263 Mdot
.7025 .48842 Mdot
.52929 .35995 Mdot
.40721 .57677 Mdot
.3763 .58248 Mdot
.54728 .65493 Mdot
.44754 .56433 Mdot
.63798 .67781 Mdot
.40437 .56881 Mdot
.70351 .46077 Mdot
.38708 .31962 Mdot
.43388 .41548 Mdot
.33693 .41651 Mdot
.55837 .66466 Mdot
.61039 .76475 Mdot
.51542 .34134 Mdot
.54175 .77026 Mdot
.68165 .45826 Mdot
.36062 .33387 Mdot
.51939 .3265 Mdot
.41412 .36684 Mdot
.40822 .51005 Mdot
.57323 .35904 Mdot
.41235 .3619 Mdot
.45676 .46504 Mdot
.40442 .62121 Mdot
.63698 .21546 Mdot
.66696 .50407 Mdot
.57641 .6013 Mdot
.41117 .53756 Mdot
.51185 .36509 Mdot
.33723 .61751 Mdot
.61793 .30439 Mdot
.76256 .41787 Mdot
.58171 .34961 Mdot
.39261 .41797 Mdot
.36103 .33053 Mdot
.68667 .36545 Mdot
.77478 .54822 Mdot
.59178 .60662 Mdot
.42349 .51798 Mdot
.28422 .73573 Mdot
.66252 .47443 Mdot
.41823 .54396 Mdot
.21962 .42131 Mdot
.65322 .46504 Mdot
.39196 .58279 Mdot
.63739 .44818 Mdot
.58831 .6377 Mdot
.52403 .67874 Mdot
.62139 .64262 Mdot
.44854 .56719 Mdot
.6846 .48002 Mdot
.59377 .35823 Mdot
.57834 .63597 Mdot
.41037 .60993 Mdot
.37188 .54803 Mdot
.46311 .44973 Mdot
.43089 .57573 Mdot
.2376 .60991 Mdot
.40295 .56546 Mdot
.53278 .34351 Mdot
.34631 .56833 Mdot
.77405 .62501 Mdot
.43284 .4112 Mdot
.62052 .64889 Mdot
.57754 .34116 Mdot
.55004 .33822 Mdot
.37934 .25918 Mdot
.6819 .52298 Mdot
.43502 .6119 Mdot
.50983 .35602 Mdot
.46118 .49909 Mdot
.66218 .45088 Mdot
.37751 .52601 Mdot
.6011 .42467 Mdot
.55808 .26391 Mdot
.56608 .33745 Mdot
.48823 .60879 Mdot
.56149 .61603 Mdot
.41386 .55717 Mdot
.51513 .36756 Mdot
.41591 .4866 Mdot
.35661 .58173 Mdot
.79091 .49994 Mdot
.43911 .43699 Mdot
.64492 .46033 Mdot
.46718 .58474 Mdot
.42746 .53601 Mdot
.5704 .36446 Mdot
.55093 .64695 Mdot
.65679 .45204 Mdot
.58374 .64708 Mdot
.26527 .5571 Mdot
.6551 .23203 Mdot
.51308 .50956 Mdot
.4131 .33598 Mdot
.55243 .27647 Mdot
.2551 .60445 Mdot
.70751 .72842 Mdot
.51879 .81248 Mdot
.2812 .68877 Mdot
.54993 .39262 Mdot
.51918 .25658 Mdot
.54747 .34663 Mdot
.37934 .54114 Mdot
.55467 .35608 Mdot
.30116 .76664 Mdot
.40817 .57204 Mdot
.55158 .36672 Mdot
.58766 .74337 Mdot
.41752 .56166 Mdot
.59108 .60506 Mdot
.21826 .63248 Mdot
.81451 .59053 Mdot
.65764 .53349 Mdot
.53249 .37539 Mdot
.41377 .81252 Mdot
.41657 .58162 Mdot
.34692 .56543 Mdot
.55975 .62667 Mdot
.32053 .57424 Mdot
.40363 .35321 Mdot
.35779 .35661 Mdot
.60583 .49066 Mdot
.33822 .36718 Mdot
.46769 .5852 Mdot
.57631 .63297 Mdot
.56917 .56723 Mdot
.40342 .26117 Mdot
.49406 .24059 Mdot
.67345 .4417 Mdot
.218 .6301 Mdot
.65793 .63724 Mdot
.63258 .56309 Mdot
.62428 .411 Mdot
.56825 .65954 Mdot
.26814 .7214 Mdot
.6786 .50092 Mdot
.58639 .19491 Mdot
.70212 .68382 Mdot
.3806 .59648 Mdot
.67574 .45971 Mdot
.39179 .63805 Mdot
.78758 .62683 Mdot
.54047 .1939 Mdot
.30941 .69078 Mdot
.38263 .52251 Mdot
.53235 .24691 Mdot
.40343 .58352 Mdot
.61389 .30835 Mdot
.39232 .55865 Mdot
.58095 .64777 Mdot
.68651 .68979 Mdot
.63974 .5133 Mdot
.49102 .6207 Mdot
.67941 .37404 Mdot
.38424 .37019 Mdot
.40163 .56892 Mdot
.38439 .59991 Mdot
.4073 .35104 Mdot
.59168 .62913 Mdot
.44375 .54681 Mdot
.61986 .7598 Mdot
.38306 .60377 Mdot
.69825 .49476 Mdot
.69089 .69679 Mdot
.31981 .66498 Mdot
.45065 .58879 Mdot
.60209 .68478 Mdot
.70799 .48622 Mdot
.68495 .48371 Mdot
.38801 .49214 Mdot
.68133 .45064 Mdot
.42407 .58741 Mdot
.51093 .18669 Mdot
.59009 .61903 Mdot
.78971 .43062 Mdot
.61458 .65548 Mdot
.46755 .73607 Mdot
.64523 .47067 Mdot
.72117 .33004 Mdot
.39607 .63697 Mdot
.67599 .49854 Mdot
.42741 .65382 Mdot
.40699 .61726 Mdot
.41895 .61822 Mdot
.38645 .79718 Mdot
.52324 .34897 Mdot
.45492 .44259 Mdot
.68542 .45689 Mdot
.4204 .60102 Mdot
.45759 .56067 Mdot
.70763 .48986 Mdot
.59851 .23764 Mdot
.7174 .70068 Mdot
.40504 .56799 Mdot
.57391 .64609 Mdot
.57486 .65525 Mdot
.40576 .6269 Mdot
.3925 .535 Mdot
.55772 .3363 Mdot
.58963 .34121 Mdot
.50561 .36659 Mdot
.44258 .43474 Mdot
.74769 .36473 Mdot
.19265 .46249 Mdot
.6798 .50723 Mdot
.73745 .58195 Mdot
.50357 .49657 Mdot
.3851 .52027 Mdot
.54142 .38196 Mdot
.4301 .53728 Mdot
.44008 .56685 Mdot
.74071 .43047 Mdot
.19676 .51358 Mdot
.666 .68443 Mdot
.55377 .6591 Mdot
.64648 .49811 Mdot
.46844 .55023 Mdot
.72065 .45033 Mdot
.37497 .33053 Mdot
.33904 .48014 Mdot
.68225 .45743 Mdot
.5978 .60762 Mdot
.65383 .49014 Mdot
.37311 .58208 Mdot
.33858 .60784 Mdot
.57046 .65976 Mdot
.3925 .33287 Mdot
.35416 .52129 Mdot
.39413 .57999 Mdot
.75757 .30082 Mdot
.39569 .44871 Mdot
.62135 .54122 Mdot
.40545 .56567 Mdot
.41296 .61463 Mdot
.35643 .36977 Mdot
.37854 .5997 Mdot
.41601 .52929 Mdot
.40536 .69761 Mdot
.67534 .57477 Mdot
.38239 .37708 Mdot
.53623 .20013 Mdot
.59148 .67781 Mdot
.27007 .70742 Mdot
.55158 .38141 Mdot
.6238 .51626 Mdot
.70804 .69938 Mdot
.53288 .31998 Mdot
.65298 .33161 Mdot
.26052 .68629 Mdot
.53822 .29827 Mdot
.51236 .38798 Mdot
.55928 .59503 Mdot
.43996 .58949 Mdot
.40066 .57576 Mdot
.39661 .35508 Mdot
.60305 .66828 Mdot
.55717 .50847 Mdot
.31727 .25399 Mdot
.40627 .59198 Mdot
.78719 .49412 Mdot
.52639 .21893 Mdot
.51587 .24279 Mdot
.3866 .34517 Mdot
.35807 .36085 Mdot
.39966 .56896 Mdot
.39218 .68295 Mdot
.58164 .63211 Mdot
.41072 .60956 Mdot
.3894 .51752 Mdot
.52318 .36057 Mdot
.60632 .64018 Mdot
.58957 .36805 Mdot
.69672 .34123 Mdot
.24281 .57707 Mdot
.5554 .16537 Mdot
.66453 .46097 Mdot
.4591 .21965 Mdot
.64864 .44654 Mdot
.26932 .41607 Mdot
.51771 .32159 Mdot
.40866 .54981 Mdot
.55278 .63044 Mdot
.42672 .595 Mdot
.39663 .53807 Mdot
.38667 .60259 Mdot
.45473 .57968 Mdot
.57754 .16294 Mdot
.39079 .3727 Mdot
.39576 .50481 Mdot
.53697 .33903 Mdot
.26987 .31037 Mdot
.33178 .27223 Mdot
.38628 .59961 Mdot
.3825 .55447 Mdot
.60071 .64435 Mdot
.38391 .52801 Mdot
.65259 .44789 Mdot
.57814 .59865 Mdot
.36502 .57118 Mdot
.18437 .59647 Mdot
.36245 .58462 Mdot
.25053 .60285 Mdot
.65451 .48955 Mdot
.6808 .26815 Mdot
.33163 .59723 Mdot
.75482 .46467 Mdot
.4551 .44282 Mdot
.5221 .32445 Mdot
.63376 .45644 Mdot
.54188 .36975 Mdot
.33842 .23096 Mdot
.44762 .62675 Mdot
.41864 .57001 Mdot
.40284 .52199 Mdot
.5059 .35482 Mdot
.15253 .55956 Mdot
.69755 .38701 Mdot
.46172 .62114 Mdot
.56159 .33965 Mdot
.62159 .62276 Mdot
.27596 .65016 Mdot
.59836 .66087 Mdot
.34743 .32922 Mdot
.70109 .49488 Mdot
.39598 .33591 Mdot
.25497 .48808 Mdot
.60703 .62813 Mdot
.5413 .63212 Mdot
.54587 .37969 Mdot
.53679 .66453 Mdot
.86663 .42881 Mdot
.70954 .67893 Mdot
.30054 .40796 Mdot
.57072 .62573 Mdot
.36753 .58874 Mdot
.25959 .44893 Mdot
.69399 .68751 Mdot
.54303 .36781 Mdot
.43867 .55108 Mdot
.5457 .69468 Mdot
.55658 .3345 Mdot
.33267 .55336 Mdot
.53242 .33773 Mdot
.66589 .49814 Mdot
.52988 .3764 Mdot
.59874 .69761 Mdot
.3632 .55677 Mdot
.87806 .42889 Mdot
.35082 .38941 Mdot
.4185 .57842 Mdot
.66616 .51528 Mdot
.63579 .2819 Mdot
.42135 .55201 Mdot
.41631 .34928 Mdot
.55878 .36644 Mdot
.51876 .61926 Mdot
.40014 .56416 Mdot
.56222 .34019 Mdot
.5877 .61008 Mdot
.71476 .51268 Mdot
.55576 .71329 Mdot
.64939 .57486 Mdot
.55445 .63221 Mdot
.6223 .5661 Mdot
.63299 .48225 Mdot
.42084 .61431 Mdot
.44895 .5546 Mdot
.57589 .65072 Mdot
.25997 .35724 Mdot
.35432 .54234 Mdot
.34718 .57626 Mdot
.52568 .3557 Mdot
.54759 .37334 Mdot
.50857 .81203 Mdot
.5788 .38257 Mdot
.32786 .5842 Mdot
.57869 .65293 Mdot
.42515 .56126 Mdot
.60188 .64062 Mdot
.38651 .52849 Mdot
.29652 .56464 Mdot
.591 .62845 Mdot
.73971 .4363 Mdot
.43957 .55643 Mdot
.34325 .52202 Mdot
.41112 .54165 Mdot
.43623 .59551 Mdot
.55768 .33881 Mdot
.39296 .34755 Mdot
.38306 .5188 Mdot
.42381 .33005 Mdot
.38304 .37406 Mdot
.64789 .52587 Mdot
.52238 .35817 Mdot
.39208 .36765 Mdot
.45338 .19546 Mdot
.57026 .35307 Mdot
.39816 .35808 Mdot
.32871 .27405 Mdot
.64828 .47587 Mdot
.55889 .61783 Mdot
.41282 .55932 Mdot
.28282 .49967 Mdot
.36326 .72466 Mdot
.48619 .35114 Mdot
.4086 .56952 Mdot
.4222 .54602 Mdot
.62342 .65737 Mdot
.24914 .29602 Mdot
.5501 .39661 Mdot
.37108 .59803 Mdot
.60564 .61756 Mdot
.17602 .36653 Mdot
.5381 .34397 Mdot
.39978 .35375 Mdot
.65024 .49109 Mdot
.48076 .63248 Mdot
.75878 .47879 Mdot
.67893 .51677 Mdot
.53618 .30699 Mdot
.70677 .3523 Mdot
.44941 .54198 Mdot
.56837 .38225 Mdot
.65483 .7883 Mdot
.54395 .55668 Mdot
.4784 .44825 Mdot
.37851 .78412 Mdot
.56141 .65381 Mdot
.65016 .44686 Mdot
.37704 .36608 Mdot
.58307 .67675 Mdot
.60273 .6256 Mdot
.70196 .50019 Mdot
.35383 .66199 Mdot
.61053 .42288 Mdot
.69636 .4875 Mdot
.34046 .46326 Mdot
.2402 .36739 Mdot
.5538 .38411 Mdot
.40373 .35431 Mdot
.23943 .49805 Mdot
.5876 .65108 Mdot
.24336 .70219 Mdot
.4139 .82018 Mdot
.41422 .58195 Mdot
.37907 .36325 Mdot
.15908 .54031 Mdot
.24318 .30784 Mdot
.65205 .46377 Mdot
.63445 .52049 Mdot
.37171 .32716 Mdot
.41435 .53901 Mdot
.39883 .46275 Mdot
.36122 .54269 Mdot
.69315 .5026 Mdot
.54864 .72159 Mdot
.60526 .62603 Mdot
.66956 .50813 Mdot
.29327 .52616 Mdot
.42129 .58951 Mdot
.43782 .55365 Mdot
.33706 .4391 Mdot
.58334 .67826 Mdot
.51924 .3256 Mdot
.44531 .54274 Mdot
.39658 .58318 Mdot
.33203 .59225 Mdot
.43153 .62689 Mdot
.4513 .69199 Mdot
.38247 .54532 Mdot
.4417 .22853 Mdot
.39222 .52468 Mdot
.43715 .58096 Mdot
.58794 .68448 Mdot
.52089 .15716 Mdot
.70065 .35962 Mdot
.39904 .58607 Mdot
.39462 .61162 Mdot
.66239 .50477 Mdot
.65621 .41894 Mdot
.65027 .70418 Mdot
.52313 .61303 Mdot
.46971 .82207 Mdot
.40777 .62103 Mdot
.61623 .62614 Mdot
.41414 .35566 Mdot
.43135 .61316 Mdot
.60569 .61158 Mdot
.34357 .57981 Mdot
.54834 .327 Mdot
.56909 .35005 Mdot
.56311 .57702 Mdot
.3976 .36804 Mdot
.77753 .60237 Mdot
.73509 .58176 Mdot
.57078 .35997 Mdot
.41487 .56697 Mdot
.66979 .43653 Mdot
.51479 .35629 Mdot
.53172 .29647 Mdot
.2286 .40535 Mdot
.5743 .62119 Mdot
.55644 .63675 Mdot
.2511 .40196 Mdot
.66932 .3169 Mdot
.80264 .47284 Mdot
.66773 .50038 Mdot
.38946 .50723 Mdot
.76055 .59217 Mdot
.55476 .64242 Mdot
.2655 .43281 Mdot
.38504 .36769 Mdot
.65315 .46604 Mdot
.69187 .41106 Mdot
.60522 .65246 Mdot
.56484 .60639 Mdot
.34137 .55102 Mdot
.38513 .58153 Mdot
.53215 .80247 Mdot
.42831 .33621 Mdot
.69928 .50842 Mdot
.40256 .35259 Mdot
.53362 .31819 Mdot
.36041 .54855 Mdot
.59094 .6319 Mdot
.22262 .38554 Mdot
.45322 .59034 Mdot
.53502 .32587 Mdot
.55869 .64873 Mdot
.35615 .33403 Mdot
.41393 .34198 Mdot
.43913 .59719 Mdot
.57115 .78019 Mdot
.6889 .4969 Mdot
.58442 .67151 Mdot
.60728 .44812 Mdot
.36316 .5389 Mdot
.38631 .57403 Mdot
.30841 .54937 Mdot
.6957 .51085 Mdot
.68332 .64729 Mdot
.41938 .34828 Mdot
.58892 .66842 Mdot
.38266 .54837 Mdot
.40197 .36053 Mdot
.74554 .5813 Mdot
.55239 .31988 Mdot
.52656 .37503 Mdot
.41229 .34156 Mdot
.37737 .34316 Mdot
.41849 .35495 Mdot
.24603 .70902 Mdot
.60528 .60475 Mdot
.64597 .59707 Mdot
.36855 .60245 Mdot
.28869 .4048 Mdot
.3806 .50602 Mdot
.64372 .458 Mdot
.52448 .34374 Mdot
.41047 .54597 Mdot
.44261 .59864 Mdot
.31524 .53018 Mdot
.78886 .45693 Mdot
.31068 .61056 Mdot
.60494 .63455 Mdot
.34189 .61297 Mdot
.53192 .37391 Mdot
.25357 .74106 Mdot
.46239 .84426 Mdot
.33576 .60473 Mdot
.63454 .4215 Mdot
.58502 .62274 Mdot
.68254 .50747 Mdot
.30335 .45825 Mdot
.64797 .48042 Mdot
.57949 .66324 Mdot
.37648 .54296 Mdot
.7157 .61109 Mdot
.37236 .38197 Mdot
.42625 .5991 Mdot
.67075 .50364 Mdot
.447 .56534 Mdot
.68448 .51407 Mdot
.27192 .51281 Mdot
.63132 .78476 Mdot
.41318 .58681 Mdot
.44298 .52531 Mdot
.56504 .7946 Mdot
.39609 .6044 Mdot
.40833 .30733 Mdot
.58412 .6218 Mdot
.56172 .72732 Mdot
.46098 .54072 Mdot
.3844 .47362 Mdot
.35581 .5465 Mdot
.59759 .73075 Mdot
.38307 .57505 Mdot
.50689 .23887 Mdot
.35705 .56205 Mdot
.4163 .52767 Mdot
.6765 .46926 Mdot
.66608 .50724 Mdot
.57679 .68513 Mdot
.52 .37993 Mdot
.24787 .6037 Mdot
.39204 .57709 Mdot
.73463 .34954 Mdot
.67863 .60003 Mdot
.38065 .34261 Mdot
.58474 .66542 Mdot
.17267 .38691 Mdot
.65506 .44204 Mdot
.51555 .83584 Mdot
.45503 .81443 Mdot
.69673 .55072 Mdot
.21246 .49565 Mdot
.5981 .25681 Mdot
.36324 .33073 Mdot
.34121 .56796 Mdot
.48217 .31082 Mdot
.50056 .23618 Mdot
.25471 .36101 Mdot
.6303 .4639 Mdot
.52594 .78435 Mdot
.20891 .45749 Mdot
.385 .32292 Mdot
.35351 .35591 Mdot
.6495 .49776 Mdot
.60329 .39171 Mdot
.47136 .54566 Mdot
.37224 .35499 Mdot
.50605 .36199 Mdot
.57287 .34935 Mdot
.51425 .38216 Mdot
.58453 .63293 Mdot
.46561 .84064 Mdot
.62649 .47299 Mdot
.64818 .45716 Mdot
.61037 .3223 Mdot
.28643 .55737 Mdot
.53829 .62043 Mdot
.53364 .36821 Mdot
.55019 .3878 Mdot
.58092 .61772 Mdot
.34879 .60816 Mdot
.45372 .62241 Mdot
.40252 .58958 Mdot
.39348 .35217 Mdot
.38041 .5799 Mdot
.56417 .34893 Mdot
.66115 .4624 Mdot
.53448 .38384 Mdot
.68098 .5196 Mdot
.20835 .39961 Mdot
.42255 .60959 Mdot
.36186 .55559 Mdot
.70648 .24485 Mdot
.55117 .6208 Mdot
.25318 .32745 Mdot
.73126 .46544 Mdot
.54631 .34514 Mdot
.41674 .53018 Mdot
.53435 .61573 Mdot
.41993 .37506 Mdot
.56464 .17317 Mdot
.37936 .53143 Mdot
.59363 .6483 Mdot
.36513 .54602 Mdot
.50674 .52614 Mdot
.82732 .51143 Mdot
.58624 .65631 Mdot
.79875 .44328 Mdot
.37037 .59523 Mdot
.46508 .20261 Mdot
.38918 .52584 Mdot
.4618 .47231 Mdot
.35456 .54214 Mdot
.59398 .67814 Mdot
.39778 .59016 Mdot
.54301 .60631 Mdot
.57498 .36793 Mdot
.6607 .50171 Mdot
.55571 .63179 Mdot
.45216 .57672 Mdot
.76972 .2201 Mdot
.65843 .48573 Mdot
.40512 .57315 Mdot
.64604 .48694 Mdot
.61238 .66239 Mdot
.57099 .66681 Mdot
.30545 .27552 Mdot
.69332 .33883 Mdot
.66463 .49581 Mdot
.36162 .5478 Mdot
.50695 .21982 Mdot
.39885 .54711 Mdot
.44475 .48474 Mdot
.35338 .61477 Mdot
.35531 .60131 Mdot
.28742 .29173 Mdot
.64347 .46252 Mdot
.8041 .46673 Mdot
.25708 .30424 Mdot
.27211 .30822 Mdot
.57626 .68791 Mdot
.39295 .32643 Mdot
.26045 .70494 Mdot
.75275 .37494 Mdot
.53727 .32205 Mdot
.41494 .54708 Mdot
.54452 .59029 Mdot
.69071 .49288 Mdot
.38244 .33315 Mdot
.41257 .58605 Mdot
.54659 .38595 Mdot
.71369 .71692 Mdot
.64648 .49958 Mdot
.59115 .65897 Mdot
.62578 .65022 Mdot
.39811 .18106 Mdot
.39599 .55909 Mdot
.36197 .56148 Mdot
.70119 .49514 Mdot
.61391 .26014 Mdot
.36376 .35649 Mdot
.58838 .74146 Mdot
.66372 .4931 Mdot
.55211 .4813 Mdot
.60169 .60739 Mdot
.42384 .54391 Mdot
.1917 .57905 Mdot
.67973 .40255 Mdot
.75612 .3133 Mdot
.39386 .35412 Mdot
.45451 .49134 Mdot
.5935 .67773 Mdot
.66653 .47489 Mdot
.66747 .2956 Mdot
.41346 .61917 Mdot
.43664 .54121 Mdot
.46779 .49105 Mdot
.64834 .52237 Mdot
.5974 .70595 Mdot
.37632 .53269 Mdot
.45456 .44072 Mdot
.38637 .53084 Mdot
.3912 .49716 Mdot
.37173 .62611 Mdot
.37922 .56555 Mdot
.59255 .63856 Mdot
.49643 .57199 Mdot
.50751 .34243 Mdot
.65373 .69288 Mdot
.54256 .48112 Mdot
.41386 .57545 Mdot
.34861 .57899 Mdot
.32464 .70491 Mdot
.63757 .31696 Mdot
.55868 .62975 Mdot
.55666 .67457 Mdot
.6681 .44317 Mdot
.39261 .62732 Mdot
.52203 .38119 Mdot
.37225 .51199 Mdot
.55457 .33548 Mdot
.5913 .63515 Mdot
.5432 .3449 Mdot
.65386 .49985 Mdot
.57722 .37724 Mdot
.74091 .3526 Mdot
.65735 .47527 Mdot
.56544 .62157 Mdot
.36808 .56938 Mdot
.66861 .51655 Mdot
.31996 .39607 Mdot
.39201 .35402 Mdot
.15667 .47028 Mdot
.36444 .57148 Mdot
.67425 .55195 Mdot
.35965 .49147 Mdot
.54097 .3864 Mdot
.82584 .49499 Mdot
.54929 .64016 Mdot
.37016 .37002 Mdot
.57506 .67563 Mdot
.34149 .48018 Mdot
.37972 .35042 Mdot
.17644 .41094 Mdot
.44481 .44702 Mdot
.4052 .45324 Mdot
.37205 .61983 Mdot
.3522 .43127 Mdot
.55827 .32729 Mdot
.68913 .49183 Mdot
.66231 .30515 Mdot
.42012 .52937 Mdot
.72593 .72847 Mdot
.58988 .68313 Mdot
.51203 .36154 Mdot
.67007 .47288 Mdot
.65047 .45356 Mdot
.38676 .61052 Mdot
.45825 .25829 Mdot
.43425 .53668 Mdot
.6848 .31761 Mdot
.4119 .81019 Mdot
.64924 .61168 Mdot
.40467 .5693 Mdot
.57087 .36518 Mdot
.36546 .54582 Mdot
.41889 .3437 Mdot
.55346 .82539 Mdot
.35275 .51896 Mdot
.71577 .47048 Mdot
.43112 .33916 Mdot
.60733 .67012 Mdot
.31164 .52814 Mdot
.64691 .58838 Mdot
.39305 .55617 Mdot
.50395 .12502 Mdot
.39896 .35987 Mdot
.49277 .30025 Mdot
.4584 .57732 Mdot
.44336 .60537 Mdot
.46688 .42375 Mdot
.77018 .44731 Mdot
.61828 .39331 Mdot
.4031 .60337 Mdot
.32263 .38412 Mdot
.64181 .48349 Mdot
.4079 .53728 Mdot
.4013 .57411 Mdot
.37041 .70335 Mdot
.63858 .47056 Mdot
.54362 .3327 Mdot
.52409 .32087 Mdot
.49635 .33254 Mdot
.42155 .35685 Mdot
.68311 .68327 Mdot
.28354 .42525 Mdot
.76554 .66725 Mdot
.36592 .37231 Mdot
.43637 .60493 Mdot
.54236 .28969 Mdot
.36917 .54164 Mdot
.38158 .33485 Mdot
.63816 .47497 Mdot
.55371 .64503 Mdot
.75578 .59213 Mdot
.55365 .32692 Mdot
.44239 .61294 Mdot
.37301 .36904 Mdot
.57595 .62315 Mdot
.27456 .46803 Mdot
.60567 .67041 Mdot
.67131 .495 Mdot
.68739 .68145 Mdot
.37736 .33232 Mdot
.61861 .64665 Mdot
.6946 .44742 Mdot
.27849 .28519 Mdot
.39945 .63123 Mdot
.7234 .63964 Mdot
.61394 .66725 Mdot
.5434 .65374 Mdot
.61744 .62299 Mdot
.44359 .58121 Mdot
.62779 .42194 Mdot
.37376 .6163 Mdot
.6416 .46881 Mdot
.53522 .33528 Mdot
.63792 .76895 Mdot
.74858 .41705 Mdot
.59024 .49001 Mdot
.35362 .52496 Mdot
.42051 .59062 Mdot
.4001 .5694 Mdot
.42077 .50533 Mdot
.74548 .3568 Mdot
.44229 .5785 Mdot
.67724 .46962 Mdot
.5602 .36153 Mdot
.34153 .57104 Mdot
.55619 .31576 Mdot
.31895 .28481 Mdot
.37386 .32629 Mdot
.60414 .47485 Mdot
.53535 .85157 Mdot
.57277 .62296 Mdot
.58085 .34547 Mdot
.56597 .35771 Mdot
.35742 .34143 Mdot
.69425 .49634 Mdot
.61153 .66685 Mdot
.47264 .51468 Mdot
.38506 .37466 Mdot
.39684 .58762 Mdot
.67342 .42916 Mdot
.70017 .74802 Mdot
.34171 .55839 Mdot
.4238 .55626 Mdot
.52264 .38911 Mdot
.49276 .30357 Mdot
.86854 .56048 Mdot
.30109 .43603 Mdot
.39111 .34014 Mdot
.39794 .33187 Mdot
.58098 .61487 Mdot
.45368 .5996 Mdot
.66086 .51087 Mdot
.57378 .70219 Mdot
.66959 .64801 Mdot
.79435 .55283 Mdot
.73596 .28738 Mdot
.39792 .53585 Mdot
.58011 .23064 Mdot
.42932 .58422 Mdot
.6132 .61316 Mdot
.58978 .64027 Mdot
.57246 .63608 Mdot
.68841 .49274 Mdot
.48571 .76836 Mdot
.68489 .47871 Mdot
.6263 .81349 Mdot
.58203 .67339 Mdot
.43394 .44009 Mdot
.53024 .36863 Mdot
.47273 .61424 Mdot
.36888 .32751 Mdot
.71329 .66153 Mdot
.31768 .59515 Mdot
.39154 .67343 Mdot
.51076 .35429 Mdot
.55834 .62626 Mdot
.61061 .26153 Mdot
.32205 .76522 Mdot
.53593 .66052 Mdot
.30004 .57761 Mdot
.30126 .46033 Mdot
.38392 .34091 Mdot
.75391 .30954 Mdot
.39804 .3395 Mdot
.66746 .50228 Mdot
.36775 .55101 Mdot
.36937 .56007 Mdot
.38423 .53018 Mdot
.4031 .6093 Mdot
.64084 .49702 Mdot
.40645 .51294 Mdot
.77289 .62664 Mdot
.54594 .32339 Mdot
.32705 .32768 Mdot
.40097 .34689 Mdot
.63534 .4607 Mdot
.56107 .36005 Mdot
.64336 .3226 Mdot
.33114 .41314 Mdot
.40221 .56597 Mdot
.4114 .54596 Mdot
.54316 .81689 Mdot
.37643 .53311 Mdot
.47903 .56941 Mdot
.55575 .33091 Mdot
.30783 .65574 Mdot
.37539 .32658 Mdot
.38763 .32746 Mdot
.65567 .47366 Mdot
.59184 .64 Mdot
.39238 .3632 Mdot
.52698 .36303 Mdot
.3439 .53114 Mdot
.42428 .51824 Mdot
.60802 .67151 Mdot
.55348 .81709 Mdot
.41051 .33383 Mdot
.50337 .21641 Mdot
.56443 .61983 Mdot
.60919 .68614 Mdot
.43501 .53973 Mdot
.77969 .36069 Mdot
.61328 .69514 Mdot
.40756 .37779 Mdot
.63371 .46127 Mdot
.31919 .45551 Mdot
.65779 .44351 Mdot
.59429 .66053 Mdot
.36036 .58708 Mdot
.58601 .6292 Mdot
.40203 .56368 Mdot
.37558 .8139 Mdot
.37412 .5648 Mdot
.7736 .65155 Mdot
.25586 .38918 Mdot
.56422 .37743 Mdot
.62871 .29937 Mdot
.55065 .38118 Mdot
.55305 .65434 Mdot
.46195 .56957 Mdot
.35521 .34984 Mdot
.37191 .24705 Mdot
.48666 .64644 Mdot
.5181 .34588 Mdot
.5822 .39073 Mdot
.63867 .44478 Mdot
.35072 .54559 Mdot
.44245 .55094 Mdot
.55076 .36891 Mdot
.64475 .68004 Mdot
.61083 .65382 Mdot
.37871 .55088 Mdot
.42302 .59104 Mdot
.56 .37944 Mdot
.28691 .27628 Mdot
.52132 .57604 Mdot
.37362 .55461 Mdot
.62725 .40465 Mdot
.64726 .45601 Mdot
.46782 .61712 Mdot
.44146 .52583 Mdot
.37417 .34373 Mdot
.48617 .68327 Mdot
.32117 .74551 Mdot
.63788 .47859 Mdot
.56658 .34775 Mdot
.38889 .55395 Mdot
.57029 .36336 Mdot
.40598 .51134 Mdot
.75989 .48066 Mdot
.58059 .3493 Mdot
.34993 .59038 Mdot
.34599 .60252 Mdot
.58933 .68009 Mdot
.40466 .54058 Mdot
.38092 .76312 Mdot
.52024 .33021 Mdot
.38123 .60752 Mdot
.5792 .75815 Mdot
.69495 .47798 Mdot
.42977 .62789 Mdot
.38754 .37404 Mdot
.41107 .47012 Mdot
.71673 .59121 Mdot
.21205 .5179 Mdot
.37111 .3248 Mdot
.44635 .57109 Mdot
.56304 .39636 Mdot
.69992 .50748 Mdot
.80633 .59925 Mdot
.41739 .53968 Mdot
.68235 .50485 Mdot
.66052 .46284 Mdot
.38045 .33139 Mdot
.4928 .15021 Mdot
.45508 .5828 Mdot
.3829 .59616 Mdot
.43509 .75606 Mdot
.55384 .60951 Mdot
.37699 .57352 Mdot
.37377 .59586 Mdot
.67313 .46462 Mdot
.47242 .57576 Mdot
.4604 .8069 Mdot
.5948 .73519 Mdot
.70791 .4835 Mdot
.76005 .61319 Mdot
.57722 .34688 Mdot
.40788 .35548 Mdot
.56628 .65324 Mdot
.36489 .35964 Mdot
.52435 .36822 Mdot
.36933 .58752 Mdot
.69952 .5003 Mdot
.37444 .75117 Mdot
.65127 .50083 Mdot
.21671 .43832 Mdot
.57251 .59927 Mdot
.61954 .48032 Mdot
.49259 .13089 Mdot
.65222 .38574 Mdot
.695 .53007 Mdot
.38012 .34279 Mdot
.59786 .32061 Mdot
.42458 .5896 Mdot
.73829 .28311 Mdot
.43141 .60852 Mdot
.56685 .74245 Mdot
.52737 .32128 Mdot
.50821 .37377 Mdot
.37115 .55176 Mdot
.3853 .78886 Mdot
.70564 .50188 Mdot
.6656 .45194 Mdot
.35512 .59441 Mdot
.67538 .49868 Mdot
.38418 .58609 Mdot
.56232 .34765 Mdot
.76894 .31283 Mdot
.40667 .58693 Mdot
.37956 .50134 Mdot
.70404 .53989 Mdot
.26408 .3038 Mdot
.36858 .31261 Mdot
.32775 .21657 Mdot
.37638 .80639 Mdot
.67646 .49801 Mdot
.37099 .61136 Mdot
.7668 .60128 Mdot
.53478 .39311 Mdot
.60047 .49354 Mdot
.37029 .58077 Mdot
.39711 .61033 Mdot
.40929 .52597 Mdot
.43561 .55534 Mdot
.61783 .2 Mdot
.51509 .64434 Mdot
.48152 .72279 Mdot
.39846 .53817 Mdot
.35645 .42239 Mdot
.65357 .48509 Mdot
.51707 .60484 Mdot
.37871 .37819 Mdot
.40028 .53719 Mdot
.56001 .6868 Mdot
.70278 .47759 Mdot
.65662 .80099 Mdot
.68968 .50447 Mdot
.55074 .33984 Mdot
.66995 .51097 Mdot
.42928 .57642 Mdot
.57454 .65465 Mdot
.47134 .40065 Mdot
.69062 .36674 Mdot
.51096 .33064 Mdot
.41805 .57808 Mdot
.38594 .41944 Mdot
.5089 .34469 Mdot
.24692 .32938 Mdot
.56519 .64648 Mdot
.31616 .36938 Mdot
.58848 .63331 Mdot
.35737 .59116 Mdot
.35652 .5892 Mdot
.65142 .43903 Mdot
.65814 .50469 Mdot
.58941 .63506 Mdot
.40452 .15556 Mdot
.41788 .3466 Mdot
.57513 .6397 Mdot
.45569 .52793 Mdot
.54398 .43216 Mdot
.57177 .64898 Mdot
.42839 .37314 Mdot
.66555 .46223 Mdot
.56039 .61295 Mdot
.37624 .52269 Mdot
.34658 .46274 Mdot
.41261 .34615 Mdot
.50015 .3396 Mdot
.26331 .45455 Mdot
.51908 .33692 Mdot
.63274 .45822 Mdot
.55639 .38126 Mdot
.6512 .45752 Mdot
.6968 .61063 Mdot
.65967 .68563 Mdot
.46899 .34291 Mdot
.62771 .46347 Mdot
.54494 .37926 Mdot
.36665 .54872 Mdot
.33768 .37345 Mdot
.46341 .57811 Mdot
.44866 .55984 Mdot
.6691 .45672 Mdot
.57746 .67395 Mdot
.56868 .68357 Mdot
.42821 .46717 Mdot
.59585 .64305 Mdot
.53128 .32671 Mdot
.44376 .67708 Mdot
.74031 .36787 Mdot
.6728 .44864 Mdot
.65898 .50186 Mdot
.372 .53847 Mdot
.5421 .36919 Mdot
.50119 .34657 Mdot
.65175 .44259 Mdot
.78224 .45723 Mdot
.43245 .51474 Mdot
.56059 .67998 Mdot
.55896 .60782 Mdot
.58324 .65535 Mdot
.59181 .59564 Mdot
.39649 .47453 Mdot
.64917 .46982 Mdot
.56915 .66966 Mdot
.37151 .53776 Mdot
.375 .59511 Mdot
.67746 .70029 Mdot
.41087 .35949 Mdot
.34575 .59024 Mdot
.3707 .62524 Mdot
.42496 .54356 Mdot
.53702 .38106 Mdot
.48469 .5689 Mdot
.58387 .37296 Mdot
.53297 .39051 Mdot
.53175 .39052 Mdot
.75919 .39173 Mdot
.50134 .83147 Mdot
.26627 .65676 Mdot
.38224 .60682 Mdot
.54406 .21944 Mdot
.53519 .35557 Mdot
.52023 .65946 Mdot
.67935 .64201 Mdot
.41808 .53178 Mdot
.42475 .23782 Mdot
.55186 .37245 Mdot
.57208 .6165 Mdot
.37096 .57275 Mdot
.5692 .33017 Mdot
.40194 .37317 Mdot
.41766 .61709 Mdot
.54491 .31657 Mdot
.61918 .6435 Mdot
.4253 .35464 Mdot
.55089 .62386 Mdot
.53459 .39213 Mdot
.47004 .56007 Mdot
.83015 .40346 Mdot
.54922 .31581 Mdot
.41151 .20735 Mdot
.38881 .6474 Mdot
.37425 .54834 Mdot
.58968 .35277 Mdot
.61851 .68354 Mdot
.63416 .45707 Mdot
.5832 .53147 Mdot
.59069 .61773 Mdot
.5084 .37421 Mdot
.52061 .37751 Mdot
.51123 .33031 Mdot
.60131 .62787 Mdot
.42694 .62471 Mdot
.60449 .64335 Mdot
.67441 .51226 Mdot
.40942 .55565 Mdot
.25911 .57816 Mdot
.6253 .26437 Mdot
.57212 .61833 Mdot
.53177 .3323 Mdot
.36082 .37475 Mdot
.42085 .58725 Mdot
.59695 .24552 Mdot
.36728 .54703 Mdot
.65374 .455 Mdot
.42519 .70073 Mdot
.31734 .67169 Mdot
.36312 .60802 Mdot
.3803 .5387 Mdot
.66917 .45322 Mdot
.41487 .58083 Mdot
.3536 .54287 Mdot
.74015 .35073 Mdot
.60928 .64284 Mdot
.40124 .59264 Mdot
.53101 .34109 Mdot
.71808 .36048 Mdot
.41544 .50639 Mdot
.55756 .30316 Mdot
.32861 .38609 Mdot
.39264 .69616 Mdot
.42884 .61025 Mdot
.64134 .42819 Mdot
.4376 .54842 Mdot
.42302 .604 Mdot
.38102 .5412 Mdot
.57016 .19811 Mdot
.55909 .32443 Mdot
.56623 .36554 Mdot
.40472 .3366 Mdot
.32502 .38202 Mdot
.37314 .3548 Mdot
.65808 .46067 Mdot
.46446 .26972 Mdot
.58698 .3676 Mdot
.60515 .66241 Mdot
.42957 .59471 Mdot
.55862 .3202 Mdot
.42422 .53955 Mdot
.42793 .57558 Mdot
.53863 .39157 Mdot
.56663 .33214 Mdot
.23711 .3767 Mdot
.41149 .36247 Mdot
.57007 .63037 Mdot
.34393 .56797 Mdot
.3782 .37212 Mdot
.43925 .60323 Mdot
.28717 .40572 Mdot
.5699 .63486 Mdot
.60844 .64487 Mdot
.59026 .69482 Mdot
.36676 .58054 Mdot
.42607 .58145 Mdot
.6847 .47736 Mdot
.55002 .6447 Mdot
.69686 .48092 Mdot
.55334 .51352 Mdot
.3632 .2856 Mdot
.37032 .58142 Mdot
.70051 .67915 Mdot
.383 .36891 Mdot
.51762 .34971 Mdot
.68543 .75634 Mdot
.40504 .3368 Mdot
.39655 .56073 Mdot
.51391 .37306 Mdot
.36969 .33601 Mdot
.48953 .50726 Mdot
.59506 .81824 Mdot
.35666 .36925 Mdot
.37259 .53755 Mdot
.47271 .56576 Mdot
.34571 .20666 Mdot
.35134 .33375 Mdot
.64986 .48821 Mdot
.36615 .57822 Mdot
.53952 .63911 Mdot
.37241 .36888 Mdot
.58363 .27513 Mdot
.55756 .36874 Mdot
.35633 .46303 Mdot
.33829 .52704 Mdot
.44204 .64513 Mdot
.40616 .34032 Mdot
.58989 .67033 Mdot
.46052 .5188 Mdot
.4349 .54096 Mdot
.3523 .33214 Mdot
.71215 .51606 Mdot
.55636 .35597 Mdot
.69622 .35114 Mdot
.59908 .62429 Mdot
.74177 .4425 Mdot
.52159 .34448 Mdot
.49029 .21295 Mdot
.65701 .72903 Mdot
.46223 .61802 Mdot
.45696 .18609 Mdot
.65772 .56596 Mdot
.3791 .52683 Mdot
.39643 .38407 Mdot
.67416 .51908 Mdot
.69705 .4677 Mdot
.66717 .492 Mdot
.6867 .61126 Mdot
.52225 .61481 Mdot
.52492 .3146 Mdot
.71891 .45434 Mdot
.40738 .35796 Mdot
.33138 .44979 Mdot
.44644 .55033 Mdot
.4153 .59189 Mdot
.34845 .55444 Mdot
.40042 .536 Mdot
.44279 .57311 Mdot
.6899 .5006 Mdot
.6915 .59523 Mdot
.52058 .62975 Mdot
.56994 .64225 Mdot
.51992 .28688 Mdot
.52776 .35785 Mdot
.50462 .37387 Mdot
.36474 .3464 Mdot
.63214 .38021 Mdot
.55149 .31376 Mdot
.54483 .34364 Mdot
.33916 .57916 Mdot
.60637 .65206 Mdot
.48285 .60219 Mdot
.37684 .53785 Mdot
.54177 .32732 Mdot
.49388 .45542 Mdot
.4057 .78978 Mdot
.28866 .32204 Mdot
.41812 .3316 Mdot
.69631 .44268 Mdot
.38062 .32406 Mdot
.45002 .5459 Mdot
.82248 .52397 Mdot
.52534 .37004 Mdot
.54645 .3561 Mdot
.40592 .36573 Mdot
.77956 .35688 Mdot
.56341 .65399 Mdot
.74424 .43843 Mdot
.64274 .47599 Mdot
.35733 .5854 Mdot
.70392 .72731 Mdot
.52068 .60002 Mdot
.44816 .25919 Mdot
.66163 .48922 Mdot
.57684 .36911 Mdot
.43209 .52111 Mdot
.39025 .53972 Mdot
.37368 .36124 Mdot
.18963 .52542 Mdot
.39215 .63195 Mdot
.14801 .56094 Mdot
.63291 .78462 Mdot
.29604 .70368 Mdot
.43845 .54351 Mdot
.60697 .63985 Mdot
.54002 .32018 Mdot
.40464 .35399 Mdot
.42626 .61859 Mdot
.38157 .79887 Mdot
.59867 .67421 Mdot
.66066 .47716 Mdot
.5268 .46495 Mdot
.31404 .44961 Mdot
.44056 .58903 Mdot
.38171 .60302 Mdot
.42917 .60121 Mdot
.84598 .64289 Mdot
.56702 .38342 Mdot
.57698 .61814 Mdot
.37653 .33101 Mdot
.59627 .65064 Mdot
.57074 .37371 Mdot
.43403 .40506 Mdot
.35794 .55709 Mdot
.62086 .65303 Mdot
.58464 .66854 Mdot
.69878 .47316 Mdot
.6368 .48006 Mdot
.54145 .48587 Mdot
.37599 .56598 Mdot
.58478 .37986 Mdot
.57638 .67443 Mdot
.67069 .43167 Mdot
.37799 .34998 Mdot
.66624 .46155 Mdot
.40326 .54061 Mdot
.58403 .37148 Mdot
.33428 .5864 Mdot
.55663 .63448 Mdot
.54421 .34465 Mdot
.23789 .36592 Mdot
.3756 .32597 Mdot
.37651 .59459 Mdot
.32014 .31248 Mdot
.56481 .34379 Mdot
.43163 .58477 Mdot
.42825 .21585 Mdot
.40903 .38594 Mdot
.69604 .38956 Mdot
.50937 .36307 Mdot
.73248 .51232 Mdot
.58282 .61493 Mdot
.76377 .4541 Mdot
.55031 .34937 Mdot
.5217 .22291 Mdot
.21227 .40754 Mdot
.37633 .51718 Mdot
.58612 .64983 Mdot
.71956 .52572 Mdot
.30246 .77526 Mdot
.37314 .21881 Mdot
.40428 .5733 Mdot
.57574 .38423 Mdot
.36765 .3421 Mdot
.67564 .45157 Mdot
.72271 .40254 Mdot
.35775 .38768 Mdot
.59768 .34943 Mdot
.38168 .54171 Mdot
.60946 .66667 Mdot
.67938 .47882 Mdot
.71371 .59791 Mdot
.52624 .35407 Mdot
.53212 .33528 Mdot
.45979 .58034 Mdot
.38761 .36849 Mdot
.65355 .25119 Mdot
.55942 .33727 Mdot
.57065 .80038 Mdot
.51927 .39277 Mdot
.39976 .37553 Mdot
.43203 .55155 Mdot
.4035 .46213 Mdot
.41488 .61801 Mdot
.36736 .23951 Mdot
.52991 .36533 Mdot
.56396 .63032 Mdot
.43645 .53493 Mdot
.59609 .76498 Mdot
.53129 .3273 Mdot
.66789 .42447 Mdot
.61943 .34174 Mdot
.64817 .46628 Mdot
.68657 .75477 Mdot
.3778 .58091 Mdot
.69885 .50829 Mdot
.37061 .35506 Mdot
.37577 .55951 Mdot
.43043 .57854 Mdot
.62096 .66395 Mdot
.69525 .4692 Mdot
.24257 .3693 Mdot
.67174 .50799 Mdot
.65493 .49144 Mdot
.53291 .63213 Mdot
.39214 .59659 Mdot
.54906 .3369 Mdot
.55002 .37166 Mdot
.37224 .52372 Mdot
.70164 .22081 Mdot
.56951 .66078 Mdot
.49712 .34881 Mdot
.86602 .6117 Mdot
.36139 .52966 Mdot
.66953 .75356 Mdot
.18795 .50845 Mdot
.64975 .50147 Mdot
.37107 .53743 Mdot
.61705 .65569 Mdot
.61955 .38889 Mdot
.53461 .33325 Mdot
.37855 .52117 Mdot
.67939 .48107 Mdot
.41418 .3603 Mdot
.51209 .3344 Mdot
.45591 .25967 Mdot
.4177 .61038 Mdot
.40352 .25612 Mdot
.54899 .39066 Mdot
.24531 .66656 Mdot
.64908 .31443 Mdot
.58365 .64605 Mdot
.42934 .57256 Mdot
.55308 .62859 Mdot
.36663 .33283 Mdot
.5297 .46769 Mdot
.6714 .46807 Mdot
.30207 .52839 Mdot
.82015 .54816 Mdot
.5116 .32988 Mdot
.56661 .61774 Mdot
.36189 .60251 Mdot
.77148 .44936 Mdot
.38016 .58578 Mdot
.34093 .50693 Mdot
.25313 .35896 Mdot
.68082 .46258 Mdot
.64359 .487 Mdot
.43978 .56341 Mdot
.35759 .34561 Mdot
.52678 .35983 Mdot
.55693 .34492 Mdot
.22019 .65562 Mdot
.74454 .44441 Mdot
.52496 .80611 Mdot
.3984 .61053 Mdot
.59427 .37296 Mdot
.7511 .44703 Mdot
.6985 .4991 Mdot
.44241 .62208 Mdot
.51548 .37345 Mdot
.32432 .33438 Mdot
.46784 .48797 Mdot
.4374 .54534 Mdot
.46712 .57073 Mdot
.64693 .48961 Mdot
.53035 .63803 Mdot
.57322 .35939 Mdot
.34106 .60698 Mdot
.44624 .38724 Mdot
.48582 .50205 Mdot
.63243 .79248 Mdot
.57037 .63041 Mdot
.47976 .24541 Mdot
.69184 .49971 Mdot
.36458 .50522 Mdot
.37439 .32834 Mdot
.60147 .3702 Mdot
.58393 .35928 Mdot
.39077 .55217 Mdot
.42713 .51883 Mdot
.61265 .7818 Mdot
.60421 .65821 Mdot
.6528 .47889 Mdot
.36391 .56199 Mdot
.74111 .62024 Mdot
.38053 .53008 Mdot
.68861 .47879 Mdot
.82484 .38444 Mdot
.44979 .60363 Mdot
.38128 .59181 Mdot
.6506 .25081 Mdot
.58432 .61048 Mdot
.57271 .67645 Mdot
.73568 .71561 Mdot
.39568 .60966 Mdot
.64642 .7775 Mdot
.56806 .62574 Mdot
.55927 .65232 Mdot
.70281 .32525 Mdot
.41604 .58946 Mdot
.53828 .57526 Mdot
.64416 .46196 Mdot
.65472 .49255 Mdot
.60275 .63501 Mdot
.43256 .63121 Mdot
.63762 .46304 Mdot
.61248 .21254 Mdot
.5407 .36927 Mdot
.8097 .47036 Mdot
.57407 .66566 Mdot
.63553 .54195 Mdot
.6706 .50252 Mdot
.58123 .82813 Mdot
.67608 .41062 Mdot
.3631 .55166 Mdot
.40165 .61081 Mdot
.40564 .36434 Mdot
.34557 .58041 Mdot
.50751 .37215 Mdot
.67478 .49887 Mdot
.36619 .76681 Mdot
.57294 .63611 Mdot
.38335 .57329 Mdot
.42122 .2294 Mdot
.20568 .3875 Mdot
.52912 .25392 Mdot
.59671 .67267 Mdot
.58528 .63657 Mdot
.57527 .3775 Mdot
.56598 .38847 Mdot
.411 .60027 Mdot
.66003 .44843 Mdot
.54996 .63616 Mdot
.68463 .47133 Mdot
.5236 .36791 Mdot
.54883 .33975 Mdot
.54982 .31992 Mdot
.44069 .53808 Mdot
.54097 .33842 Mdot
.29556 .30742 Mdot
.70705 .43027 Mdot
.53558 .62786 Mdot
.76985 .71059 Mdot
.71377 .60347 Mdot
.46047 .63873 Mdot
.39441 .37776 Mdot
.544 .32383 Mdot
.68843 .51172 Mdot
.42181 .5596 Mdot
.41459 .54466 Mdot
.75675 .39392 Mdot
.69716 .50729 Mdot
.37554 .33157 Mdot
.67764 .51574 Mdot
.37822 .33084 Mdot
.41803 .25553 Mdot
.34843 .5468 Mdot
.40422 .51347 Mdot
.67749 .50208 Mdot
.54296 .34105 Mdot
.56238 .36755 Mdot
.34984 .35443 Mdot
.48531 .45458 Mdot
.50955 .3465 Mdot
.56156 .65725 Mdot
.30553 .69861 Mdot
.53816 .38771 Mdot
.37274 .57258 Mdot
.27789 .42337 Mdot
.71602 .25554 Mdot
.42291 .50632 Mdot
.70859 .32208 Mdot
.39429 .7552 Mdot
.42943 .52961 Mdot
.72325 .26208 Mdot
.71374 .49712 Mdot
.59304 .62434 Mdot
.55674 .3301 Mdot
.49983 .3822 Mdot
.48801 .61494 Mdot
.42632 .35073 Mdot
.45396 .60658 Mdot
.62106 .65062 Mdot
.62616 .6495 Mdot
.38976 .45379 Mdot
.37473 .22667 Mdot
.37087 .33703 Mdot
.36636 .3494 Mdot
.55249 .34742 Mdot
.15324 .47657 Mdot
.31044 .53685 Mdot
.38315 .33367 Mdot
.63681 .68177 Mdot
.38579 .54496 Mdot
.31801 .3491 Mdot
.62962 .60151 Mdot
.60222 .632 Mdot
.37472 .43145 Mdot
.53798 .32848 Mdot
.59638 .64116 Mdot
.76336 .57856 Mdot
.40698 .62608 Mdot
.57081 .63644 Mdot
.68413 .47321 Mdot
.64654 .34185 Mdot
.56724 .66415 Mdot
.28491 .41774 Mdot
.64831 .44457 Mdot
.6709 .43226 Mdot
.45077 .47891 Mdot
.1342 .38413 Mdot
.68331 .50083 Mdot
.51886 .37526 Mdot
.55047 .37083 Mdot
.55648 .34442 Mdot
.59799 .65244 Mdot
.51147 .32968 Mdot
.60206 .65936 Mdot
.40683 .18813 Mdot
.74597 .30223 Mdot
.38908 .33793 Mdot
.6937 .34976 Mdot
.59969 .66716 Mdot
.71513 .68754 Mdot
.57325 .12973 Mdot
.36523 .53931 Mdot
.68976 .4588 Mdot
.38808 .33848 Mdot
.15706 .51091 Mdot
.37636 .34068 Mdot
.41935 .82174 Mdot
.37717 .67373 Mdot
.38781 .57974 Mdot
.52354 .77519 Mdot
.3555 .36182 Mdot
.60125 .60948 Mdot
.43079 .58491 Mdot
.52087 .5021 Mdot
.37052 .34467 Mdot
.40985 .37021 Mdot
.4046 .59797 Mdot
.558 .62653 Mdot
.52906 .33225 Mdot
.6612 .50142 Mdot
.36419 .36185 Mdot
.44799 .50954 Mdot
.37838 .61122 Mdot
.36009 .5509 Mdot
.69404 .68794 Mdot
.41852 .37878 Mdot
.67749 .4978 Mdot
.51441 .16379 Mdot
.56265 .39591 Mdot
.47074 .46575 Mdot
.60189 .79882 Mdot
.65848 .6038 Mdot
.53079 .36561 Mdot
.57004 .36587 Mdot
.44246 .57494 Mdot
.29598 .62618 Mdot
.37544 .66177 Mdot
.44211 .42652 Mdot
.50852 .32679 Mdot
.55743 .3505 Mdot
.56559 .675 Mdot
.27066 .61649 Mdot
.40955 .49899 Mdot
.6397 .48444 Mdot
.57929 .34828 Mdot
.73928 .30716 Mdot
.39964 .36665 Mdot
.40779 .68576 Mdot
.34494 .55259 Mdot
.3624 .55427 Mdot
.67464 .48025 Mdot
.68418 .47886 Mdot
.62463 .35998 Mdot
.31629 .73368 Mdot
.38275 .74998 Mdot
.6952 .58309 Mdot
.37931 .69397 Mdot
.58791 .68243 Mdot
.57147 .61834 Mdot
.68582 .37538 Mdot
.6863 .50746 Mdot
.4295 .52828 Mdot
.5912 .63774 Mdot
.32358 .35356 Mdot
.32381 .50741 Mdot
.33677 .48823 Mdot
.65075 .76274 Mdot
.40772 .56785 Mdot
.61402 .6436 Mdot
.58103 .60774 Mdot
.56762 .60465 Mdot
.65427 .53256 Mdot
.4026 .60353 Mdot
.40752 .57109 Mdot
.44312 .54972 Mdot
.78195 .39973 Mdot
.41442 .60578 Mdot
.67546 .54164 Mdot
.54556 .47146 Mdot
.51278 .6807 Mdot
.34601 .61283 Mdot
.68663 .51525 Mdot
.44182 .59424 Mdot
.35685 .34443 Mdot
.35327 .55299 Mdot
.32819 .49572 Mdot
.65695 .48644 Mdot
.49535 .56963 Mdot
.70015 .61421 Mdot
.40159 .52623 Mdot
.40282 .37933 Mdot
.66964 .63511 Mdot
.28388 .73198 Mdot
.39042 .31281 Mdot
.56288 .6575 Mdot
.53557 .36667 Mdot
.69396 .51005 Mdot
.54729 .3481 Mdot
.38877 .51856 Mdot
.67455 .37236 Mdot
.16327 .51157 Mdot
.51598 .48946 Mdot
.40423 .53887 Mdot
.32386 .5241 Mdot
.55636 .65077 Mdot
.53779 .39185 Mdot
.63263 .66356 Mdot
.44343 .58203 Mdot
.39469 .35132 Mdot
.37252 .35789 Mdot
.57335 .52425 Mdot
.22263 .59361 Mdot
.67993 .25875 Mdot
.67692 .4859 Mdot
.55604 .33319 Mdot
.3685 .32736 Mdot
.54672 .23554 Mdot
.71845 .50858 Mdot
.66312 .45352 Mdot
.65513 .48141 Mdot
.3663 .58786 Mdot
.56842 .3328 Mdot
.51659 .68359 Mdot
.57479 .39546 Mdot
.41771 .58079 Mdot
.54029 .383 Mdot
.5119 .35646 Mdot
.40112 .35476 Mdot
.65368 .48247 Mdot
.52574 .36843 Mdot
.36229 .59398 Mdot
.5709 .62359 Mdot
.65091 .52144 Mdot
.25086 .38143 Mdot
.37673 .22947 Mdot
.57848 .56602 Mdot
.58864 .61157 Mdot
.27008 .70534 Mdot
.64287 .45996 Mdot
.78472 .44191 Mdot
.23326 .3818 Mdot
.45585 .58613 Mdot
.72403 .24067 Mdot
.58623 .39908 Mdot
.51338 .35177 Mdot
.43331 .55064 Mdot
.61056 .38251 Mdot
.38362 .57745 Mdot
.51884 .36103 Mdot
.70577 .4185 Mdot
.53652 .60882 Mdot
.53847 .3434 Mdot
.3309 .58604 Mdot
.43569 .57539 Mdot
.60617 .64077 Mdot
.58699 .37261 Mdot
.45439 .60126 Mdot
.24767 .72123 Mdot
.68866 .484 Mdot
.66284 .60114 Mdot
.26445 .42428 Mdot
.69517 .49764 Mdot
.57671 .64317 Mdot
.44954 .56359 Mdot
.36952 .35304 Mdot
.60421 .66627 Mdot
.30425 .51924 Mdot
.39594 .334 Mdot
.81315 .42257 Mdot
.58172 .60741 Mdot
.51829 .34285 Mdot
.35778 .33604 Mdot
.37466 .61589 Mdot
.55427 .3977 Mdot
.62829 .30292 Mdot
.52976 .36115 Mdot
.44526 .56576 Mdot
.72743 .38752 Mdot
.65188 .47928 Mdot
.39998 .57044 Mdot
.51527 .34045 Mdot
.70974 .32517 Mdot
.37542 .60079 Mdot
.4407 .55773 Mdot
.58454 .80571 Mdot
.59582 .71641 Mdot
.37805 .34493 Mdot
.54704 .63026 Mdot
.36961 .53811 Mdot
.38903 .37478 Mdot
.4513 .31738 Mdot
.36068 .57317 Mdot
.60008 .67416 Mdot
.44664 .62055 Mdot
.57804 .38207 Mdot
.69621 .48512 Mdot
.44208 .43377 Mdot
.40049 .37357 Mdot
.21875 .30221 Mdot
.57989 .35556 Mdot
.44994 .55514 Mdot
.38205 .53105 Mdot
.24815 .48145 Mdot
.59579 .63015 Mdot
.64445 .63968 Mdot
.37731 .5959 Mdot
.78532 .40049 Mdot
.38108 .56297 Mdot
.60597 .38539 Mdot
.56271 .65386 Mdot
.38858 .60101 Mdot
.62819 .49203 Mdot
.38476 .5009 Mdot
.41202 .34962 Mdot
.63184 .2587 Mdot
.42439 .62361 Mdot
.81955 .39721 Mdot
.55879 .53439 Mdot
.53741 .34192 Mdot
.32688 .28513 Mdot
.24267 .71938 Mdot
.68861 .61873 Mdot
.59517 .65228 Mdot
.17982 .51051 Mdot
.54861 .33657 Mdot
.38036 .2535 Mdot
.29096 .75502 Mdot
.43561 .56767 Mdot
.44208 .58641 Mdot
.29335 .46229 Mdot
.5481 .39578 Mdot
.57793 .38845 Mdot
.36159 .52161 Mdot
.39002 .49927 Mdot
.544 .33594 Mdot
.4279 .61484 Mdot
.35672 .62417 Mdot
.69207 .46174 Mdot
.58999 .674 Mdot
.67881 .45941 Mdot
.64643 .45337 Mdot
.59533 .22914 Mdot
.53575 .52579 Mdot
.69068 .48162 Mdot
.65547 .50891 Mdot
.33536 .39065 Mdot
.35727 .76467 Mdot
.36443 .35929 Mdot
.22979 .63916 Mdot
.55509 .35518 Mdot
.39281 .60011 Mdot
.56342 .6067 Mdot
.36298 .73379 Mdot
.44895 .33057 Mdot
.79739 .58597 Mdot
.44325 .54694 Mdot
.53004 .32837 Mdot
.65013 .57878 Mdot
.48318 .59059 Mdot
.51863 .31438 Mdot
.36534 .56695 Mdot
.5107 .37857 Mdot
.41883 .80304 Mdot
.52633 .22609 Mdot
.49674 .37674 Mdot
.54066 .64328 Mdot
.36544 .5562 Mdot
.61828 .62792 Mdot
.69746 .49928 Mdot
.35932 .35188 Mdot
.37527 .34872 Mdot
.42009 .593 Mdot
.30209 .56643 Mdot
.40124 .26759 Mdot
.42379 .58583 Mdot
.38956 .54591 Mdot
.70443 .46267 Mdot
.38322 .54104 Mdot
.39022 .53007 Mdot
.42322 .53574 Mdot
.41386 .5251 Mdot
.65423 .49103 Mdot
.63216 .37479 Mdot
.44384 .63634 Mdot
.32114 .57658 Mdot
.63667 .45335 Mdot
.19579 .48937 Mdot
.63947 .46075 Mdot
.30265 .76859 Mdot
.64781 .49666 Mdot
.38242 .3515 Mdot
.20616 .49722 Mdot
.32165 .55751 Mdot
.60414 .67706 Mdot
.60143 .4846 Mdot
.36055 .33675 Mdot
.66973 .49541 Mdot
.5177 .36534 Mdot
.59808 .80652 Mdot
.57434 .58898 Mdot
.54714 .68432 Mdot
.66121 .63082 Mdot
.63842 .3676 Mdot
.5789 .37552 Mdot
.59291 .60563 Mdot
.45649 .80232 Mdot
.39568 .53296 Mdot
.38709 .37461 Mdot
.41273 .59887 Mdot
.70057 .49836 Mdot
.54526 .33052 Mdot
.38977 .20326 Mdot
.37453 .36224 Mdot
.74467 .73357 Mdot
.5601 .37122 Mdot
.40629 .53587 Mdot
.63775 .46313 Mdot
.81274 .64519 Mdot
.67871 .46129 Mdot
.32037 .63342 Mdot
.58115 .61699 Mdot
.32221 .22595 Mdot
.59297 .66261 Mdot
.60565 .28174 Mdot
.8831 .50477 Mdot
.50387 .2282 Mdot
.56649 .6219 Mdot
.42867 .40402 Mdot
.39362 .55765 Mdot
.35926 .55209 Mdot
.46491 .20038 Mdot
.55044 .62032 Mdot
.39067 .536 Mdot
.75624 .41419 Mdot
.74132 .44978 Mdot
.65623 .74655 Mdot
.57262 .37748 Mdot
.37952 .57701 Mdot
.69635 .46092 Mdot
.7096 .49315 Mdot
.57191 .35068 Mdot
.65661 .45345 Mdot
.40948 .57378 Mdot
.59864 .66675 Mdot
.53778 .30388 Mdot
.38436 .36145 Mdot
.16686 .46284 Mdot
.39908 .32694 Mdot
.53144 .367 Mdot
.46493 .57352 Mdot
.54864 .34063 Mdot
.42857 .89164 Mdot
.39509 .56258 Mdot
.56657 .6263 Mdot
.39067 .54197 Mdot
.36909 .55379 Mdot
.4217 .52441 Mdot
.52954 .33419 Mdot
.26724 .34204 Mdot
.37197 .601 Mdot
.66863 .46535 Mdot
.43734 .70895 Mdot
.35494 .60599 Mdot
.49701 .30649 Mdot
.35762 .47499 Mdot
.69033 .67181 Mdot
.56383 .6125 Mdot
.53382 .34777 Mdot
.57508 .63361 Mdot
.79658 .41581 Mdot
.57662 .6434 Mdot
.41192 .72542 Mdot
.47078 .80672 Mdot
.54981 .78745 Mdot
.56822 .78176 Mdot
.47202 .41282 Mdot
.5478 .62585 Mdot
.41693 .32152 Mdot
.55037 .63798 Mdot
.59821 .62782 Mdot
.63399 .13803 Mdot
.62264 .64518 Mdot
.37202 .57909 Mdot
.34108 .57994 Mdot
.55202 .24892 Mdot
.29181 .37858 Mdot
.40718 .55309 Mdot
.40466 .5466 Mdot
.36362 .32896 Mdot
.79385 .42232 Mdot
.68417 .3869 Mdot
.6048 .71808 Mdot
.2168 .38041 Mdot
.40934 .59848 Mdot
.35613 .54721 Mdot
.34489 .62029 Mdot
.8349 .57353 Mdot
.56115 .21068 Mdot
.54292 .65621 Mdot
.3248 .56132 Mdot
.43954 .2238 Mdot
.44164 .54255 Mdot
.37574 .5983 Mdot
.40262 .56407 Mdot
.54824 .33568 Mdot
.55546 .61808 Mdot
.38464 .5204 Mdot
.23554 .48886 Mdot
.36894 .58481 Mdot
.65125 .56453 Mdot
.20452 .33725 Mdot
.37741 .58179 Mdot
.58857 .68661 Mdot
.36097 .54915 Mdot
.60094 .64039 Mdot
.60958 .6285 Mdot
.34578 .52916 Mdot
.37193 .6883 Mdot
.56526 .67576 Mdot
.41854 .58096 Mdot
.5172 .36942 Mdot
.24105 .64577 Mdot
.44228 .57795 Mdot
.36591 .36063 Mdot
.39499 .60894 Mdot
.42066 .36567 Mdot
.39715 .55112 Mdot
.57773 .35154 Mdot
.35736 .71963 Mdot
.54809 .35503 Mdot
.47857 .18549 Mdot
.5583 .32458 Mdot
.71191 .75875 Mdot
.59187 .61367 Mdot
.71094 .37053 Mdot
.80856 .5046 Mdot
.76523 .42888 Mdot
.60276 .4359 Mdot
.50151 .43116 Mdot
.66131 .44905 Mdot
.59117 .62701 Mdot
.77551 .51112 Mdot
.50409 .29127 Mdot
.52052 .26908 Mdot
.50778 .34112 Mdot
.47196 .14486 Mdot
.80894 .41755 Mdot
.44851 .54149 Mdot
.47888 .78155 Mdot
.49764 .7466 Mdot
.43546 .53276 Mdot
.41924 .52067 Mdot
.5414 .40413 Mdot
.39908 .61456 Mdot
.73818 .62791 Mdot
.54071 .37667 Mdot
.35902 .34011 Mdot
.55373 .63882 Mdot
.41464 .35939 Mdot
.44925 .36013 Mdot
.50514 .43011 Mdot
.5203 .36602 Mdot
.44891 .60675 Mdot
.4143 .5545 Mdot
.60481 .64705 Mdot
.4115 .65798 Mdot
.57084 .67208 Mdot
.3827 .33666 Mdot
.55201 .3793 Mdot
.68206 .23349 Mdot
.41328 .55156 Mdot
.57891 .6645 Mdot
.58941 .45341 Mdot
.37524 .53729 Mdot
.68692 .50292 Mdot
.38728 .55448 Mdot
.55454 .63136 Mdot
.38372 .54123 Mdot
.59333 .66162 Mdot
.53717 .36665 Mdot
.41498 .53446 Mdot
.43234 .5459 Mdot
.75684 .71491 Mdot
.39397 .34497 Mdot
.58908 .60213 Mdot
.43262 .44208 Mdot
.36083 .53872 Mdot
.68568 .32758 Mdot
.36754 .56995 Mdot
.55388 .68234 Mdot
.45493 .55052 Mdot
.66273 .60321 Mdot
.34016 .53183 Mdot
.42215 .59735 Mdot
.60753 .55249 Mdot
.48412 .7437 Mdot
.54994 .57958 Mdot
.67868 .51873 Mdot
.59151 .60217 Mdot
.6336 .7476 Mdot
.58809 .31805 Mdot
.58986 .37074 Mdot
.34163 .42881 Mdot
.3703 .52228 Mdot
.38688 .5822 Mdot
.68252 .68129 Mdot
.39104 .37256 Mdot
.61258 .66662 Mdot
.37922 .33105 Mdot
.68734 .75977 Mdot
.39934 .3332 Mdot
.60882 .3813 Mdot
.40029 .25714 Mdot
.64981 .22004 Mdot
.37139 .32751 Mdot
.55295 .63289 Mdot
.45305 .23026 Mdot
.39002 .52772 Mdot
.57287 .53885 Mdot
.39207 .35633 Mdot
.38047 .17151 Mdot
.39351 .53089 Mdot
.60193 .43876 Mdot
.69122 .47593 Mdot
.37164 .328 Mdot
.64685 .44347 Mdot
.42849 .56212 Mdot
.68706 .38894 Mdot
.59393 .65191 Mdot
.63059 .44966 Mdot
.38107 .62296 Mdot
.38434 .33518 Mdot
.5811 .35105 Mdot
.61806 .46789 Mdot
.64597 .49756 Mdot
.20439 .55035 Mdot
.368 .20703 Mdot
.55572 .37879 Mdot
.67197 .72703 Mdot
.68281 .51543 Mdot
.3749 .52679 Mdot
.78806 .4624 Mdot
.36168 .5531 Mdot
.71183 .29129 Mdot
.52851 .35375 Mdot
.63636 .37279 Mdot
.3691 .5387 Mdot
.43792 .58697 Mdot
.62661 .64432 Mdot
.54875 .3636 Mdot
.57563 .6543 Mdot
.53713 .61194 Mdot
.53899 .36882 Mdot
.58526 .65105 Mdot
.34897 .34421 Mdot
.78327 .55477 Mdot
.64262 .47996 Mdot
.65746 .46403 Mdot
.55723 .34484 Mdot
.53395 .34138 Mdot
.54533 .34453 Mdot
.38638 .55381 Mdot
.57955 .66794 Mdot
.42496 .56937 Mdot
.43145 .60908 Mdot
.45646 .70217 Mdot
.55973 .61157 Mdot
.41598 .57074 Mdot
.49667 .48294 Mdot
.31607 .6101 Mdot
.52578 .3794 Mdot
.69183 .48075 Mdot
.74393 .38601 Mdot
.63608 .30296 Mdot
.37862 .57374 Mdot
.29653 .32498 Mdot
.5512 .63628 Mdot
.36905 .34344 Mdot
.39053 .32563 Mdot
.37818 .34171 Mdot
.72466 .47357 Mdot
.56871 .60482 Mdot
.51725 .6611 Mdot
.38186 .57931 Mdot
.54405 .67541 Mdot
.55089 .67078 Mdot
.44337 .23734 Mdot
.69167 .48399 Mdot
.39048 .54014 Mdot
.45254 .44039 Mdot
.35938 .74931 Mdot
.36771 .5494 Mdot
.34981 .60096 Mdot
.26875 .32618 Mdot
.4575 .52727 Mdot
.61102 .67798 Mdot
.798 .66775 Mdot
.35933 .60586 Mdot
.73218 .295 Mdot
.14336 .52711 Mdot
.37313 .56668 Mdot
.43119 .5963 Mdot
.42038 .5507 Mdot
.35157 .55728 Mdot
.577 .68442 Mdot
.31112 .37823 Mdot
.68341 .51709 Mdot
.52761 .64465 Mdot
.68671 .5062 Mdot
.51485 .32429 Mdot
.63514 .37627 Mdot
.58548 .62077 Mdot
.40478 .36538 Mdot
.20629 .37536 Mdot
.76039 .67728 Mdot
.57281 .35884 Mdot
.6296 .22038 Mdot
.3899 .35463 Mdot
.33946 .55601 Mdot
.36296 .36527 Mdot
.56947 .38333 Mdot
.65025 .46472 Mdot
.43951 .62059 Mdot
.56777 .61919 Mdot
.5703 .66599 Mdot
.38515 .53701 Mdot
.38495 .24434 Mdot
.69977 .49018 Mdot
.68701 .52088 Mdot
.36279 .58268 Mdot
.36667 .61222 Mdot
.57744 .65388 Mdot
.56169 .3546 Mdot
.56951 .78842 Mdot
.36816 .35617 Mdot
.44084 .5387 Mdot
.37799 .54059 Mdot
.58656 .80361 Mdot
.66588 .462 Mdot
.58137 .34053 Mdot
.46072 .57395 Mdot
.68638 .56727 Mdot
.452 .59214 Mdot
.33655 .60866 Mdot
.51861 .37325 Mdot
.46759 .62291 Mdot
.40162 .51105 Mdot
.54883 .60152 Mdot
.66805 .44928 Mdot
.56815 .63193 Mdot
.5521 .59952 Mdot
.77739 .5855 Mdot
.67386 .50243 Mdot
.40173 .56118 Mdot
.69123 .4914 Mdot
.36022 .57171 Mdot
.35538 .59655 Mdot
.68891 .47886 Mdot
.57704 .65541 Mdot
.18468 .4949 Mdot
.5967 .28608 Mdot
.34857 .57458 Mdot
.37793 .51705 Mdot
.30288 .35371 Mdot
.40702 .39953 Mdot
.44374 .5821 Mdot
.55374 .65048 Mdot
.42668 .5575 Mdot
.69397 .46888 Mdot
.35332 .35652 Mdot
.56815 .62273 Mdot
.5651 .36606 Mdot
.57725 .36189 Mdot
.69682 .61858 Mdot
.51005 .3586 Mdot
.44251 .58785 Mdot
.47863 .62942 Mdot
.62361 .67235 Mdot
.23419 .33189 Mdot
.54333 .37155 Mdot
.373 .3697 Mdot
.4422 .56397 Mdot
.3455 .46343 Mdot
.68988 .45533 Mdot
.64099 .16177 Mdot
.75146 .65754 Mdot
.37683 .37952 Mdot
.52696 .6668 Mdot
.56906 .33673 Mdot
.38969 .51796 Mdot
.36715 .36144 Mdot
.57598 .37697 Mdot
.35346 .57705 Mdot
.32237 .57352 Mdot
.38206 .65105 Mdot
.50011 .4118 Mdot
.68925 .48959 Mdot
.50556 .35926 Mdot
.39555 .38207 Mdot
.50149 .33469 Mdot
.60438 .62377 Mdot
.40762 .60494 Mdot
.46221 .57924 Mdot
.56341 .35527 Mdot
.59305 .36296 Mdot
.41779 .57605 Mdot
.5571 .62357 Mdot
.5754 .28158 Mdot
.40425 .59593 Mdot
.74195 .46543 Mdot
.54438 .64824 Mdot
.5646 .37993 Mdot
.42776 .59577 Mdot
.40143 .32086 Mdot
.56003 .36679 Mdot
.52895 .38097 Mdot
.35695 .54579 Mdot
.36903 .32666 Mdot
.39496 .50528 Mdot
.64224 .46914 Mdot
.46463 .15075 Mdot
.69457 .46906 Mdot
.56966 .30577 Mdot
.4345 .50528 Mdot
.7276 .533 Mdot
.57627 .61101 Mdot
.40625 .45356 Mdot
.75564 .41227 Mdot
.36392 .62755 Mdot
.24568 .58945 Mdot
.63366 .5393 Mdot
.27034 .30519 Mdot
.26626 .56226 Mdot
.39707 .35742 Mdot
.66712 .49281 Mdot
.43153 .59623 Mdot
.68458 .45318 Mdot
.37307 .36806 Mdot
.48559 .18738 Mdot
.44413 .57539 Mdot
.55912 .65143 Mdot
.41186 .57285 Mdot
.56867 .66159 Mdot
.34738 .56678 Mdot
.41294 .50827 Mdot
.76258 .42282 Mdot
.46211 .47861 Mdot
.45358 .58891 Mdot
.84918 .6323 Mdot
.33939 .63665 Mdot
.36299 .34611 Mdot
.43228 .57122 Mdot
.48503 .36249 Mdot
.69898 .50474 Mdot
.69316 .53589 Mdot
.54604 .33362 Mdot
.63969 .48279 Mdot
.58153 .65212 Mdot
.53116 .35532 Mdot
.57172 .35466 Mdot
.47215 .61942 Mdot
.36424 .37183 Mdot
.66018 .47334 Mdot
.39203 .60362 Mdot
.44051 .5818 Mdot
.69061 .72215 Mdot
.48811 .29252 Mdot
.44106 .66712 Mdot
.84925 .50369 Mdot
.55861 .60203 Mdot
.36596 .33412 Mdot
.53089 .3315 Mdot
.43867 .60048 Mdot
.40393 .57471 Mdot
.69605 .34282 Mdot
.56375 .67143 Mdot
.52796 .47183 Mdot
.43298 .67102 Mdot
.3242 .35191 Mdot
.37939 .42567 Mdot
.55319 .64157 Mdot
.36375 .4168 Mdot
.41234 .38307 Mdot
.1933 .61307 Mdot
.46302 .47563 Mdot
.69305 .47891 Mdot
.33954 .3982 Mdot
.61173 .66651 Mdot
.36458 .59394 Mdot
.51536 .36685 Mdot
.51172 .35865 Mdot
.56696 .64005 Mdot
.51305 .31885 Mdot
.40142 .3589 Mdot
.42337 .60651 Mdot
.71432 .69311 Mdot
.73619 .58268 Mdot
.55563 .33598 Mdot
.47204 .61564 Mdot
.65517 .48314 Mdot
.38315 .53642 Mdot
.39874 .34081 Mdot
.68791 .49865 Mdot
.36605 .77785 Mdot
.73849 .42684 Mdot
.43865 .57727 Mdot
.59211 .80467 Mdot
.67253 .50054 Mdot
.29114 .63616 Mdot
.39677 .59828 Mdot
.64728 .4588 Mdot
.4488 .50178 Mdot
.64264 .33518 Mdot
.53648 .5088 Mdot
.29305 .75933 Mdot
.56041 .50058 Mdot
.52439 .32876 Mdot
.64122 .35334 Mdot
.76067 .38469 Mdot
.67441 .51174 Mdot
.58852 .34092 Mdot
.53415 .52823 Mdot
.65059 .4439 Mdot
.34623 .54372 Mdot
.36822 .56564 Mdot
.55303 .20864 Mdot
.60521 .4997 Mdot
.59031 .267 Mdot
.69844 .64317 Mdot
.35967 .53873 Mdot
.43577 .52458 Mdot
.40177 .57778 Mdot
.59486 .684 Mdot
.68252 .48273 Mdot
.82139 .65349 Mdot
.69698 .49902 Mdot
.42615 .69371 Mdot
.55583 .35084 Mdot
.57168 .37849 Mdot
.3774 .5775 Mdot
.60288 .44146 Mdot
.28343 .67176 Mdot
.4124 .5773 Mdot
.3693 .38696 Mdot
.56192 .22437 Mdot
.34834 .59173 Mdot
.57027 .61405 Mdot
.40835 .63648 Mdot
.41295 .49025 Mdot
.64342 .48271 Mdot
.39746 .36624 Mdot
.38756 .46199 Mdot
.65065 .4679 Mdot
.38845 .58177 Mdot
.7041 .55274 Mdot
.37659 .55488 Mdot
.34952 .57311 Mdot
.40326 .67465 Mdot
.38349 .32417 Mdot
.54012 .355 Mdot
.38161 .34242 Mdot
.59564 .62715 Mdot
.54204 .09275 Mdot
.4022 .33497 Mdot
.32206 .73617 Mdot
.50911 .18225 Mdot
.34323 .39965 Mdot
.61526 .6647 Mdot
.37469 .37572 Mdot
.69729 .48289 Mdot
.24013 .64801 Mdot
.31835 .62253 Mdot
.62015 .51727 Mdot
.39925 .59308 Mdot
.5706 .59153 Mdot
.58067 .67498 Mdot
.63147 .45108 Mdot
.60736 .62171 Mdot
.53419 .57966 Mdot
.35308 .58305 Mdot
.66523 .50486 Mdot
.70448 .58204 Mdot
.68873 .51776 Mdot
.44461 .40798 Mdot
.43024 .57735 Mdot
.5632 .62547 Mdot
.41245 .51431 Mdot
.61248 .69115 Mdot
.57704 .33753 Mdot
.45448 .59898 Mdot
.40294 .35888 Mdot
.71782 .53601 Mdot
.56053 .37809 Mdot
.35034 .40147 Mdot
.60378 .64475 Mdot
.72443 .46185 Mdot
.60773 .64248 Mdot
.62629 .6742 Mdot
.6385 .46195 Mdot
.6181 .63771 Mdot
.42767 .59984 Mdot
.53368 .51416 Mdot
.60075 .65106 Mdot
.67003 .48158 Mdot
.38773 .36697 Mdot
.58793 .65969 Mdot
.60567 .38915 Mdot
.44344 .56559 Mdot
.53153 .33527 Mdot
.43162 .38238 Mdot
.59258 .59513 Mdot
.35072 .33313 Mdot
.58551 .37805 Mdot
.41014 .37016 Mdot
.3019 .27876 Mdot
.6329 .48062 Mdot
.37711 .67669 Mdot
.39328 .39489 Mdot
.60348 .67812 Mdot
.2273 .39258 Mdot
.42236 .61242 Mdot
.44272 .56176 Mdot
.4178 .36842 Mdot
.58055 .67498 Mdot
.16212 .58991 Mdot
.29619 .59033 Mdot
.45484 .39622 Mdot
.71373 .49182 Mdot
.7371 .74414 Mdot
.44777 .4013 Mdot
.14905 .48895 Mdot
.44536 .62717 Mdot
.58179 .38746 Mdot
.38553 .57181 Mdot
.73161 .35841 Mdot
.38977 .34072 Mdot
.50775 .30109 Mdot
.44733 .52714 Mdot
.53582 .35784 Mdot
.42716 .54277 Mdot
.59943 .54695 Mdot
.2918 .5579 Mdot
.39237 .378 Mdot
.40913 .242 Mdot
.59972 .60124 Mdot
.38497 .35957 Mdot
.5576 .38379 Mdot
.4666 .49498 Mdot
.35272 .5783 Mdot
.34706 .54137 Mdot
.32468 .34783 Mdot
.58621 .6718 Mdot
.51771 .34091 Mdot
.64402 .466 Mdot
.39554 .36933 Mdot
.41502 .5561 Mdot
.43419 .60836 Mdot
.69166 .32515 Mdot
.65662 .48989 Mdot
.54318 .39392 Mdot
.68328 .46179 Mdot
.56744 .33855 Mdot
.37074 .60191 Mdot
.57543 .36869 Mdot
.34308 .53596 Mdot
.65001 .54582 Mdot
.3947 .67946 Mdot
.48129 .75381 Mdot
.52767 .35986 Mdot
.38074 .78476 Mdot
.65931 .49254 Mdot
.67389 .45824 Mdot
.5673 .19701 Mdot
.33069 .63668 Mdot
.72147 .7011 Mdot
.23909 .54013 Mdot
.6555 .49573 Mdot
.65966 .47851 Mdot
.53171 .33638 Mdot
.61697 .63568 Mdot
.57371 .60087 Mdot
.56959 .34389 Mdot
.2721 .42372 Mdot
.61126 .66769 Mdot
.22962 .60286 Mdot
.67405 .73895 Mdot
.33042 .57726 Mdot
.61204 .34522 Mdot
.37013 .35025 Mdot
.28654 .42214 Mdot
.59165 .54394 Mdot
.44584 .57395 Mdot
.36358 .44396 Mdot
.55951 .35008 Mdot
.62916 .43155 Mdot
.28948 .74578 Mdot
.42127 .53851 Mdot
.39502 .60057 Mdot
.3943 .57691 Mdot
.35979 .37054 Mdot
.33354 .67821 Mdot
.41934 .6038 Mdot
.26965 .42339 Mdot
.37103 .53469 Mdot
.28505 .58617 Mdot
.37633 .34602 Mdot
.52031 .52792 Mdot
.48144 .31425 Mdot
.78114 .68668 Mdot
.3057 .53477 Mdot
.64137 .47689 Mdot
.54592 .28398 Mdot
.67195 .45431 Mdot
.43442 .73251 Mdot
.43751 .45276 Mdot
.55009 .60616 Mdot
.44422 .57888 Mdot
.53219 .36872 Mdot
.57978 .67429 Mdot
.65691 .34868 Mdot
.59393 .11629 Mdot
.65104 .50105 Mdot
.2072 .70539 Mdot
.65381 .45558 Mdot
.57069 .35371 Mdot
.57702 .65268 Mdot
.44639 .80403 Mdot
.72418 .66783 Mdot
.58828 .65789 Mdot
.16011 .53508 Mdot
.59715 .69959 Mdot
.42779 .47401 Mdot
.62488 .64691 Mdot
.66611 .48282 Mdot
.66855 .43454 Mdot
.5383 .5663 Mdot
.37745 .59832 Mdot
.51075 .43767 Mdot
.27963 .65854 Mdot
.42437 .61175 Mdot
.54364 .37776 Mdot
.36851 .66169 Mdot
.35671 .4334 Mdot
.61954 .64927 Mdot
.73946 .46906 Mdot
.40506 .60249 Mdot
.3695 .54319 Mdot
.35667 .58381 Mdot
.7718 .63001 Mdot
.19061 .61103 Mdot
.3694 .59918 Mdot
.34961 .55494 Mdot
.53294 .35685 Mdot
.3593 .39003 Mdot
.50573 .23235 Mdot
.5743 .71466 Mdot
.41929 .53104 Mdot
.38006 .35622 Mdot
.42101 .37231 Mdot
.42588 .61476 Mdot
.52777 .51535 Mdot
.71568 .54532 Mdot
.39531 .60499 Mdot
.36558 .65843 Mdot
.56918 .41498 Mdot
.55566 .39698 Mdot
.56285 .36354 Mdot
.59744 .60536 Mdot
.56603 .3489 Mdot
.57789 .34818 Mdot
.37625 .7711 Mdot
.54783 .48769 Mdot
.64829 .5312 Mdot
.37882 .33572 Mdot
.39867 .5689 Mdot
.49439 .61496 Mdot
.69029 .55896 Mdot
.65336 .44703 Mdot
.5781 .62372 Mdot
.70768 .4935 Mdot
.42892 .33465 Mdot
.75677 .6307 Mdot
.51725 .32676 Mdot
.64821 .48543 Mdot
.64385 .50304 Mdot
.37815 .35561 Mdot
.66933 .44486 Mdot
.6777 .42055 Mdot
.38749 .61696 Mdot
.45761 .78422 Mdot
.41603 .58219 Mdot
.19025 .39678 Mdot
.6542 .47656 Mdot
.70897 .4659 Mdot
.38296 .58904 Mdot
.55867 .36894 Mdot
.46564 .51641 Mdot
.37356 .5943 Mdot
.56484 .34908 Mdot
.44992 .54109 Mdot
.40857 .33383 Mdot
.54596 .64214 Mdot
.71858 .67202 Mdot
.47354 .14227 Mdot
.36625 .37252 Mdot
.66207 .34294 Mdot
.44668 .55736 Mdot
.35165 .2271 Mdot
.58958 .66266 Mdot
.45703 .57014 Mdot
.37624 .43125 Mdot
.60529 .65703 Mdot
.57873 .63532 Mdot
.38762 .55031 Mdot
.69048 .47252 Mdot
.56331 .37865 Mdot
.37482 .35214 Mdot
.16319 .43034 Mdot
.41219 .59232 Mdot
.43192 .55125 Mdot
.38651 .35687 Mdot
.67418 .50459 Mdot
.44809 .59745 Mdot
.26273 .48317 Mdot
.1766 .62014 Mdot
.64924 .45557 Mdot
.40165 .53207 Mdot
.42796 .74631 Mdot
.29797 .55682 Mdot
.2836 .255 Mdot
.56256 .53513 Mdot
.53839 .34901 Mdot
.37577 .49557 Mdot
.7849 .30768 Mdot
.39367 .36772 Mdot
.75197 .68296 Mdot
.37029 .54208 Mdot
.40906 .54729 Mdot
.56596 .67071 Mdot
.42394 .57215 Mdot
.58285 .62064 Mdot
.57261 .16819 Mdot
.61752 .79321 Mdot
.59586 .60984 Mdot
.61205 .673 Mdot
.36624 .46976 Mdot
.7171 .51779 Mdot
.56944 .64205 Mdot
.35663 .6003 Mdot
.49839 .49722 Mdot
.66303 .68932 Mdot
.37349 .37264 Mdot
.28822 .32128 Mdot
.31667 .55671 Mdot
.3203 .31589 Mdot
.19303 .49226 Mdot
.368 .64282 Mdot
.4413 .42055 Mdot
.66809 .45937 Mdot
.42051 .53714 Mdot
.51184 .36239 Mdot
.51161 .36744 Mdot
.33918 .53931 Mdot
.38797 .56024 Mdot
.59885 .6338 Mdot
.38124 .3687 Mdot
.68707 .51278 Mdot
.40805 .54893 Mdot
.4182 .45899 Mdot
.40593 .36825 Mdot
.61052 .62336 Mdot
.42274 .70372 Mdot
.37989 .31934 Mdot
.37324 .50589 Mdot
.38086 .59819 Mdot
.40777 .56785 Mdot
.53889 .56379 Mdot
.68203 .47784 Mdot
.20446 .48445 Mdot
.34191 .57077 Mdot
.70215 .75351 Mdot
.67287 .53194 Mdot
.41636 .50262 Mdot
.60691 .63045 Mdot
.7381 .46864 Mdot
.5338 .31568 Mdot
.79784 .54056 Mdot
.43421 .58176 Mdot
.39886 .24264 Mdot
.54773 .20866 Mdot
.58891 .34966 Mdot
.59525 .69333 Mdot
.37553 .33891 Mdot
.40996 .57509 Mdot
.36672 .685 Mdot
.37012 .56829 Mdot
.4311 .36983 Mdot
.53725 .38517 Mdot
.67117 .46054 Mdot
.24698 .32514 Mdot
.50778 .36019 Mdot
.57581 .63416 Mdot
.51347 .85372 Mdot
.58128 .61891 Mdot
.5761 .60083 Mdot
.43998 .70737 Mdot
.68229 .47641 Mdot
.7137 .2157 Mdot
.60184 .18763 Mdot
.37885 .60927 Mdot
.66692 .50123 Mdot
.56114 .63564 Mdot
.38754 .5331 Mdot
.61595 .69908 Mdot
.5559 .60789 Mdot
.36047 .59751 Mdot
.41416 .54585 Mdot
.50878 .21933 Mdot
.25879 .66172 Mdot
.37693 .33813 Mdot
.58663 .61395 Mdot
.73868 .63811 Mdot
.38386 .53153 Mdot
.38162 .58036 Mdot
.70986 .30285 Mdot
.35893 .36578 Mdot
.75263 .58398 Mdot
.36986 .54269 Mdot
.53618 .82666 Mdot
.42167 .63849 Mdot
.55596 .66509 Mdot
.66539 .45188 Mdot
.76 .70539 Mdot
.65613 .41608 Mdot
.58415 .62258 Mdot
.40965 .35908 Mdot
.62752 .64855 Mdot
.34964 .76058 Mdot
.68745 .50547 Mdot
.55432 .63166 Mdot
.44397 .4339 Mdot
.68199 .49093 Mdot
.65093 .47399 Mdot
.46739 .70114 Mdot
.55328 .31864 Mdot
.37389 .37992 Mdot
.65926 .47528 Mdot
.7854 .43162 Mdot
.67217 .48798 Mdot
.58195 .18112 Mdot
.41575 .53722 Mdot
.31721 .43992 Mdot
.56711 .30245 Mdot
.31117 .5523 Mdot
.65168 .48206 Mdot
.35593 .33395 Mdot
.35323 .5745 Mdot
.61593 .62318 Mdot
.38077 .37145 Mdot
.60848 .47007 Mdot
.54487 .3355 Mdot
.61024 .6457 Mdot
.60967 .45191 Mdot
.56704 .66185 Mdot
.7741 .51227 Mdot
.47434 .16516 Mdot
.30757 .50877 Mdot
.73061 .66183 Mdot
.35184 .57845 Mdot
.20805 .5603 Mdot
.39774 .52816 Mdot
.38115 .55405 Mdot
.55522 .3808 Mdot
.33558 .43808 Mdot
.576 .65433 Mdot
.16957 .48411 Mdot
.64444 .48277 Mdot
.77774 .69249 Mdot
.32263 .51799 Mdot
.44765 .54884 Mdot
.59916 .64819 Mdot
.55131 .65316 Mdot
.47565 .7309 Mdot
.49849 .3625 Mdot
.4451 .5485 Mdot
.41634 .62799 Mdot
.32833 .5579 Mdot
.64602 .46927 Mdot
.48502 .4801 Mdot
.52731 .32614 Mdot
.42339 .18393 Mdot
.54257 .38715 Mdot
.36109 .29658 Mdot
.61647 .62968 Mdot
.40319 .33589 Mdot
.38029 .58262 Mdot
.41626 .65376 Mdot
.56803 .67512 Mdot
.41624 .36908 Mdot
.36512 .33036 Mdot
.65684 .30552 Mdot
.6892 .47998 Mdot
.37596 .59978 Mdot
.4258 .59774 Mdot
.42083 .56633 Mdot
.38795 .55594 Mdot
.65079 .49957 Mdot
.35771 .5798 Mdot
.66108 .43723 Mdot
.8044 .53975 Mdot
.2945 .46594 Mdot
.56542 .5025 Mdot
.66441 .25262 Mdot
.61878 .65568 Mdot
.77599 .45841 Mdot
.45757 .52316 Mdot
.81783 .48506 Mdot
.47657 .19512 Mdot
.37914 .61936 Mdot
.57866 .36433 Mdot
.38138 .47926 Mdot
.50944 .3408 Mdot
.13703 .51806 Mdot
.73159 .3369 Mdot
.25228 .64585 Mdot
.44173 .57975 Mdot
.53083 .51013 Mdot
.776 .3754 Mdot
.38498 .52649 Mdot
.68476 .30882 Mdot
.70942 .2883 Mdot
.44018 .22802 Mdot
.37413 .32723 Mdot
.42437 .59223 Mdot
.53057 .5906 Mdot
.42485 .60306 Mdot
.38297 .57457 Mdot
.35693 .58168 Mdot
.70584 .50343 Mdot
.45138 .58338 Mdot
.35589 .561 Mdot
.40254 .27421 Mdot
.41454 .44253 Mdot
.57034 .39309 Mdot
.55085 .19307 Mdot
.39861 .33216 Mdot
.60173 .64604 Mdot
.19171 .58661 Mdot
.69315 .47994 Mdot
.48494 .73558 Mdot
.3961 .5609 Mdot
.54107 .24326 Mdot
.74086 .42511 Mdot
.4079 .35894 Mdot
.57945 .37786 Mdot
.25431 .6767 Mdot
.53669 .37169 Mdot
.73487 .45856 Mdot
.55736 .37179 Mdot
.40395 .4932 Mdot
.59754 .63033 Mdot
.39426 .61144 Mdot
.66181 .47159 Mdot
.568 .36302 Mdot
.296 .36868 Mdot
.39979 .57605 Mdot
.53918 .36821 Mdot
.38719 .60856 Mdot
.59576 .71194 Mdot
.62009 .73316 Mdot
.5807 .35569 Mdot
.62862 .47585 Mdot
.67174 .47071 Mdot
.39391 .33389 Mdot
.60764 .6509 Mdot
.58155 .62419 Mdot
.68525 .49888 Mdot
.62622 .61504 Mdot
.41697 .52928 Mdot
.39975 .53689 Mdot
.72753 .73117 Mdot
.43301 .59865 Mdot
.47371 .50507 Mdot
.45587 .44454 Mdot
.60481 .61253 Mdot
.42949 .52143 Mdot
.38534 .54589 Mdot
.44089 .57362 Mdot
.64876 .71514 Mdot
.56251 .34879 Mdot
.41899 .53784 Mdot
.35648 .33812 Mdot
.62503 .37723 Mdot
.38211 .53626 Mdot
.48791 .61374 Mdot
.57925 .62269 Mdot
.83934 .5286 Mdot
.65911 .45524 Mdot
.55444 .38357 Mdot
.52699 .35876 Mdot
.208 .46459 Mdot
.77481 .41979 Mdot
.45966 .44707 Mdot
.33928 .2082 Mdot
.76242 .426 Mdot
.37672 .33131 Mdot
.59982 .38012 Mdot
.6041 .457 Mdot
.52353 .35223 Mdot
.66506 .51224 Mdot
.40579 .53466 Mdot
.41695 .53083 Mdot
.77656 .31311 Mdot
.44471 .60267 Mdot
.37317 .34202 Mdot
.68957 .51499 Mdot
.60472 .67023 Mdot
.40659 .36236 Mdot
.68109 .45933 Mdot
.59883 .60752 Mdot
.37686 .61889 Mdot
.34445 .58659 Mdot
.5811 .62693 Mdot
.56274 .66607 Mdot
.3796 .59445 Mdot
.71266 .40364 Mdot
.60625 .67558 Mdot
.55274 .64185 Mdot
.52841 .32299 Mdot
.51076 .35789 Mdot
.3373 .6176 Mdot
.65951 .48996 Mdot
.35452 .56576 Mdot
.53034 .35931 Mdot
.40252 .33584 Mdot
.5785 .65852 Mdot
.34911 .56736 Mdot
.39324 .54229 Mdot
.37832 .35749 Mdot
.40541 .34435 Mdot
.39619 .3383 Mdot
.62492 .43914 Mdot
.42929 .56666 Mdot
.57693 .64882 Mdot
.68547 .47592 Mdot
.41137 .37943 Mdot
.36305 .36355 Mdot
.58869 .39371 Mdot
.43948 .5964 Mdot
.53618 .30388 Mdot
.79738 .32428 Mdot
.64281 .77563 Mdot
.58224 .34843 Mdot
.53066 .3168 Mdot
.27418 .36561 Mdot
.64474 .58975 Mdot
.69187 .50069 Mdot
.39129 .3998 Mdot
.30876 .5102 Mdot
.41664 .6229 Mdot
.34656 .58368 Mdot
.43518 .52145 Mdot
.39019 .33381 Mdot
.33308 .45257 Mdot
.58742 .62227 Mdot
.51399 .53401 Mdot
.40692 .36854 Mdot
.57939 .3837 Mdot
.60654 .36776 Mdot
.54867 .38753 Mdot
.33885 .5625 Mdot
.49168 .76308 Mdot
.76771 .46607 Mdot
.23825 .51992 Mdot
.65429 .4868 Mdot
.46011 .63357 Mdot
.36981 .22168 Mdot
.58171 .63274 Mdot
.5052 .33351 Mdot
.36878 .33147 Mdot
.56367 .66531 Mdot
.70759 .48834 Mdot
.66103 .47713 Mdot
.55426 .33466 Mdot
.55323 .33603 Mdot
.51799 .35848 Mdot
.54917 .61483 Mdot
.61712 .63284 Mdot
.43501 .57977 Mdot
.58442 .66536 Mdot
.81413 .55644 Mdot
.42368 .3444 Mdot
.48455 .37716 Mdot
.66417 .49157 Mdot
.62106 .63997 Mdot
.40329 .5777 Mdot
.53866 .66249 Mdot
.66923 .5883 Mdot
.36307 .34964 Mdot
.65574 .73166 Mdot
.14741 .46331 Mdot
.39242 .60989 Mdot
.67589 .47044 Mdot
.7457 .67309 Mdot
.39635 .57925 Mdot
.52507 .33568 Mdot
.31392 .29581 Mdot
.49274 .40213 Mdot
.37071 .58967 Mdot
.39514 .61787 Mdot
.64039 .47478 Mdot
.41865 .18555 Mdot
.42446 .58769 Mdot
.76864 .56759 Mdot
.70206 .52113 Mdot
.523 .33231 Mdot
.27284 .77016 Mdot
.34618 .32015 Mdot
.28124 .42449 Mdot
.5391 .32484 Mdot
.36774 .55451 Mdot
.50615 .34068 Mdot
.35649 .34284 Mdot
.57581 .37906 Mdot
.57558 .61598 Mdot
.56917 .38663 Mdot
.43121 .55149 Mdot
.5675 .63811 Mdot
.67251 .50099 Mdot
.7723 .68907 Mdot
.39153 .29194 Mdot
.55824 .3673 Mdot
.57748 .35496 Mdot
.44272 .5377 Mdot
.73873 .61981 Mdot
.36843 .52135 Mdot
.39875 .53266 Mdot
.66583 .50347 Mdot
.60547 .65496 Mdot
.64435 .45745 Mdot
.34647 .52178 Mdot
.28697 .4863 Mdot
.68349 .46363 Mdot
.5131 .23273 Mdot
.39154 .35334 Mdot
.57425 .44031 Mdot
.40426 .57348 Mdot
.64969 .44257 Mdot
.43168 .5677 Mdot
.58977 .62293 Mdot
.57623 .49504 Mdot
.66447 .39324 Mdot
.65549 .46603 Mdot
.33685 .27425 Mdot
.27699 .46244 Mdot
.48243 .62047 Mdot
.67131 .45604 Mdot
.3567 .42517 Mdot
.56982 .35253 Mdot
.37113 .36181 Mdot
.41651 .34256 Mdot
.41091 .36643 Mdot
.35145 .61851 Mdot
.32096 .51887 Mdot
.34599 .34215 Mdot
.69547 .50646 Mdot
.39031 .37783 Mdot
.7065 .26429 Mdot
.16781 .4893 Mdot
.39097 .34571 Mdot
.39771 .59645 Mdot
.45848 .5186 Mdot
.33993 .39545 Mdot
.63801 .323 Mdot
.24725 .62018 Mdot
.63774 .26028 Mdot
.37121 .58646 Mdot
.54404 .65099 Mdot
.56702 .60674 Mdot
.79701 .60991 Mdot
.31298 .72061 Mdot
.60947 .79039 Mdot
.59031 .60026 Mdot
.72291 .38025 Mdot
.61303 .63396 Mdot
.37595 .60309 Mdot
.3955 .5351 Mdot
.56489 .59831 Mdot
.30503 .47688 Mdot
.69695 .36564 Mdot
.20438 .3705 Mdot
.5642 .66186 Mdot
.66749 .44938 Mdot
.63941 .45339 Mdot
.6502 .47735 Mdot
.71145 .72326 Mdot
.59567 .64937 Mdot
.40866 .55628 Mdot
.52861 .36425 Mdot
.42382 .53338 Mdot
.68499 .49071 Mdot
.15166 .52591 Mdot
.59389 .65973 Mdot
.41145 .60382 Mdot
.50781 .58175 Mdot
.5497 .33552 Mdot
.38268 .35299 Mdot
.5831 .70601 Mdot
.59388 .7971 Mdot
.64588 .48372 Mdot
.58613 .59295 Mdot
.60123 .49087 Mdot
.21572 .36431 Mdot
.47197 .61325 Mdot
.45769 .60638 Mdot
.15976 .43694 Mdot
.49279 .83728 Mdot
.44848 .56752 Mdot
.58228 .37089 Mdot
.7001 .34151 Mdot
.37864 .53824 Mdot
.57625 .60765 Mdot
.39144 .32218 Mdot
.40189 .3743 Mdot
.36261 .63442 Mdot
.61049 .70959 Mdot
.58433 .53216 Mdot
.39777 .55897 Mdot
.38716 .50292 Mdot
.52698 .32761 Mdot
.73385 .35138 Mdot
.68695 .76021 Mdot
.40863 .34489 Mdot
.41291 .61515 Mdot
.18265 .48239 Mdot
.57545 .67497 Mdot
.58817 .35125 Mdot
.69002 .46187 Mdot
.5477 .66612 Mdot
.5818 .3756 Mdot
.34855 .58497 Mdot
.44016 .60722 Mdot
.65181 .44897 Mdot
.55149 .6578 Mdot
.39633 .34021 Mdot
.55768 .38186 Mdot
.40529 .35125 Mdot
.60265 .65737 Mdot
.60325 .66781 Mdot
.51083 .59142 Mdot
.47287 .60816 Mdot
.56432 .36709 Mdot
.32929 .56557 Mdot
.67434 .41464 Mdot
.22855 .30066 Mdot
.60143 .48501 Mdot
.4478 .59114 Mdot
.62488 .63496 Mdot
.64942 .46707 Mdot
.41208 .54768 Mdot
.14809 .50434 Mdot
.3739 .53192 Mdot
.70396 .50883 Mdot
.34259 .76301 Mdot
.40204 .3534 Mdot
.55585 .5606 Mdot
.46771 .20252 Mdot
.43176 .60273 Mdot
.5298 .34465 Mdot
.43587 .63142 Mdot
.69321 .47375 Mdot
.61955 .6414 Mdot
.20526 .3172 Mdot
.67317 .48404 Mdot
.41626 .6092 Mdot
.40019 .36791 Mdot
.61712 .67234 Mdot
.56579 .54172 Mdot
.51543 .50013 Mdot
.47971 .56014 Mdot
.43271 .52716 Mdot
.37905 .54712 Mdot
.25675 .49716 Mdot
.53869 .37976 Mdot
.55451 .63826 Mdot
.67137 .46536 Mdot
.6881 .49976 Mdot
.55879 .34214 Mdot
.51269 .30744 Mdot
.57282 .44043 Mdot
.84151 .40888 Mdot
.50396 .34026 Mdot
.40803 .33888 Mdot
.74891 .59677 Mdot
.53585 .37615 Mdot
.543 .36877 Mdot
.52105 .32517 Mdot
.44963 .43072 Mdot
.61242 .66706 Mdot
.34792 .58327 Mdot
.56428 .61259 Mdot
.36555 .55392 Mdot
.71172 .50924 Mdot
.65784 .4687 Mdot
.60085 .66246 Mdot
.22957 .32645 Mdot
.43164 .77508 Mdot
.39201 .58687 Mdot
.35437 .22657 Mdot
.4613 .54765 Mdot
.31682 .33521 Mdot
.45687 .54472 Mdot
.55519 .36086 Mdot
.34067 .54982 Mdot
.33789 .60635 Mdot
.77905 .64412 Mdot
.66257 .49244 Mdot
.58114 .39345 Mdot
.41171 .50386 Mdot
.37922 .50497 Mdot
.5463 .61913 Mdot
.56025 .66272 Mdot
.41795 .34802 Mdot
.49367 .53245 Mdot
.67739 .50292 Mdot
.67103 .22095 Mdot
.37834 .59877 Mdot
.34666 .30807 Mdot
.58085 .76514 Mdot
.41519 .54917 Mdot
.4315 .20783 Mdot
.49175 .75708 Mdot
.40824 .57454 Mdot
.48176 .42347 Mdot
.65792 .49074 Mdot
.27927 .53204 Mdot
.36772 .53683 Mdot
.5404 .33003 Mdot
.61384 .62656 Mdot
.57328 .67723 Mdot
.41261 .33924 Mdot
.80944 .42114 Mdot
.64142 .45958 Mdot
.61592 .65608 Mdot
.39391 .57035 Mdot
.67694 .46951 Mdot
.51746 .32499 Mdot
.4532 .56222 Mdot
.41979 .81554 Mdot
.58136 .66518 Mdot
.44886 .53844 Mdot
.76186 .54533 Mdot
.26582 .39768 Mdot
.35328 .78012 Mdot
.66475 .46102 Mdot
.39099 .33235 Mdot
.3759 .63404 Mdot
.63468 .62532 Mdot
.39366 .51241 Mdot
.29532 .43782 Mdot
.69405 .25915 Mdot
.35041 .35102 Mdot
.38583 .59255 Mdot
.4122 .5552 Mdot
.6192 .55281 Mdot
.41048 .35142 Mdot
.43796 .58535 Mdot
.65519 .63061 Mdot
.56755 .65886 Mdot
.54974 .32397 Mdot
.5938 .67194 Mdot
.39824 .59306 Mdot
.47788 .60179 Mdot
.56353 .6687 Mdot
.27469 .27618 Mdot
.37889 .31773 Mdot
.67355 .45945 Mdot
.41771 .6177 Mdot
.34515 .55171 Mdot
.86146 .59472 Mdot
.59033 .34677 Mdot
.69375 .39937 Mdot
.51757 .243 Mdot
.20092 .46298 Mdot
.33313 .36331 Mdot
.31713 .76924 Mdot
.4844 .83753 Mdot
.45296 .58079 Mdot
.59572 .58025 Mdot
.75774 .51563 Mdot
.6615 .49823 Mdot
.78829 .37473 Mdot
.3782 .59923 Mdot
.38353 .5726 Mdot
.57272 .33612 Mdot
.64845 .39145 Mdot
.6177 .78737 Mdot
.52483 .61591 Mdot
.39912 .34703 Mdot
.59535 .62328 Mdot
.35223 .595 Mdot
.51257 .46128 Mdot
.59026 .37094 Mdot
.40432 .31224 Mdot
.40727 .60474 Mdot
.65286 .71583 Mdot
.67805 .59707 Mdot
.68693 .48208 Mdot
.52663 .35601 Mdot
.56115 .80119 Mdot
.4403 .59847 Mdot
.6492 .44178 Mdot
.41085 .5897 Mdot
.34064 .38067 Mdot
.33867 .52187 Mdot
.37829 .33286 Mdot
.35987 .54765 Mdot
.55243 .28123 Mdot
.77962 .72207 Mdot
.38741 .38759 Mdot
.53944 .63362 Mdot
.57592 .33022 Mdot
.56325 .35127 Mdot
.55575 .65703 Mdot
.5621 .3589 Mdot
.48814 .72341 Mdot
.40218 .79392 Mdot
.39415 .3537 Mdot
.32731 .60332 Mdot
.38631 .3465 Mdot
.58106 .34218 Mdot
.37162 .58961 Mdot
.16689 .38584 Mdot
.56971 .37092 Mdot
.52825 .83955 Mdot
.67334 .49145 Mdot
.59396 .35152 Mdot
.37201 .5348 Mdot
.66185 .60519 Mdot
.5079 .35893 Mdot
.69275 .38336 Mdot
.44029 .57454 Mdot
.60276 .6697 Mdot
.38721 .54115 Mdot
.37463 .60719 Mdot
.57866 .3893 Mdot
.35823 .56616 Mdot
.68124 .459 Mdot
.58651 .60014 Mdot
.23596 .62086 Mdot
.74175 .32411 Mdot
.438 .58697 Mdot
.39518 .57285 Mdot
.62196 .67711 Mdot
.35223 .53824 Mdot
.64949 .49724 Mdot
.33975 .15586 Mdot
.39086 .35352 Mdot
.59691 .36281 Mdot
.53552 .26404 Mdot
.40627 .62537 Mdot
.355 .5764 Mdot
.13771 .58625 Mdot
.28572 .47955 Mdot
.67449 .45635 Mdot
.3267 .56403 Mdot
.50361 .35137 Mdot
.38138 .36735 Mdot
.68547 .51116 Mdot
.41081 .57009 Mdot
.38159 .58535 Mdot
.39961 .33713 Mdot
.3273 .31788 Mdot
.66568 .74517 Mdot
.63832 .44667 Mdot
.43173 .50415 Mdot
.58518 .40116 Mdot
.41465 .52692 Mdot
.70392 .71908 Mdot
.56167 .62489 Mdot
.64779 .48796 Mdot
.19879 .48347 Mdot
.44461 .59382 Mdot
.66101 .44962 Mdot
.67405 .50246 Mdot
.39862 .51102 Mdot
.53692 .59611 Mdot
.57548 .59916 Mdot
.5701 .66358 Mdot
.64042 .16853 Mdot
.29827 .41772 Mdot
.51797 .35842 Mdot
.65992 .49443 Mdot
.57522 .34629 Mdot
.43272 .3677 Mdot
.52322 .49565 Mdot
.57794 .35139 Mdot
.58799 .67366 Mdot
.59597 .35689 Mdot
.43176 .56152 Mdot
.67806 .50233 Mdot
.52357 .34813 Mdot
.37333 .60965 Mdot
.67084 .69874 Mdot
.61375 .27388 Mdot
.35573 .3539 Mdot
.37194 .31959 Mdot
.3907 .53547 Mdot
.5009 .33777 Mdot
.37751 .58924 Mdot
.68392 .45315 Mdot
.72038 .66461 Mdot
.37348 .60543 Mdot
.55866 .36437 Mdot
.61983 .6775 Mdot
.57021 .79916 Mdot
.34138 .60237 Mdot
.39586 .59618 Mdot
.36175 .55879 Mdot
.41175 .58958 Mdot
.23445 .34341 Mdot
.63584 .46401 Mdot
.67767 .26525 Mdot
.21406 .45042 Mdot
.58849 .65379 Mdot
.55283 .62347 Mdot
.66894 .76291 Mdot
.73844 .53265 Mdot
.65886 .48958 Mdot
.38375 .55481 Mdot
.68314 .57286 Mdot
.17644 .61563 Mdot
.18516 .38681 Mdot
.31089 .67332 Mdot
.58882 .34451 Mdot
.58817 .59358 Mdot
.56959 .35822 Mdot
.3679 .55901 Mdot
.3958 .50422 Mdot
.3945 .82722 Mdot
.70161 .50002 Mdot
.39626 .34659 Mdot
.36358 .55352 Mdot
.29269 .41834 Mdot
.53232 .35501 Mdot
.59402 .35035 Mdot
.416 .54175 Mdot
.59281 .68539 Mdot
.76408 .72867 Mdot
.68145 .47762 Mdot
.66437 .2656 Mdot
.77057 .36008 Mdot
.67955 .6384 Mdot
.68496 .48734 Mdot
.63281 .60976 Mdot
.58671 .35342 Mdot
.57402 .74529 Mdot
.58745 .64735 Mdot
.3743 .36673 Mdot
.4316 .50995 Mdot
.55389 .62971 Mdot
.53405 .38621 Mdot
.61586 .6603 Mdot
.35488 .57913 Mdot
.67092 .52142 Mdot
.53921 .34606 Mdot
.66849 .53284 Mdot
.62548 .63823 Mdot
.41006 .35636 Mdot
.69951 .43747 Mdot
.32755 .7077 Mdot
.49235 .75466 Mdot
.41764 .53989 Mdot
.50246 .45718 Mdot
.41162 .55906 Mdot
.60155 .69295 Mdot
.40516 .58211 Mdot
.44867 .64542 Mdot
.53112 .34395 Mdot
.35127 .5517 Mdot
.39217 .55617 Mdot
.58291 .18912 Mdot
.43213 .58906 Mdot
.39895 .52149 Mdot
.40558 .57053 Mdot
.45206 .64225 Mdot
.37379 .63708 Mdot
.60558 .63106 Mdot
.46535 .23075 Mdot
.54491 .36726 Mdot
.41366 .3687 Mdot
.37376 .32631 Mdot
.32631 .43513 Mdot
.5197 .28251 Mdot
.63661 .36542 Mdot
.57043 .65789 Mdot
.68178 .45585 Mdot
.40845 .58519 Mdot
.28263 .72924 Mdot
.53471 .4033 Mdot
.5735 .38649 Mdot
.74457 .33017 Mdot
.30871 .54354 Mdot
.2615 .61303 Mdot
.33671 .54087 Mdot
.7517 .27292 Mdot
.40951 .62889 Mdot
.34983 .50552 Mdot
.50528 .33563 Mdot
.35339 .30045 Mdot
.36331 .53134 Mdot
.58207 .60523 Mdot
.36489 .34094 Mdot
.32416 .51724 Mdot
.60008 .3249 Mdot
.61296 .40253 Mdot
.46452 .65473 Mdot
.43617 .57167 Mdot
.54012 .34644 Mdot
.60891 .6462 Mdot
.66716 .7703 Mdot
.68409 .47416 Mdot
.53531 .3017 Mdot
.78581 .5558 Mdot
.29549 .26651 Mdot
.40867 .36559 Mdot
.54461 .70983 Mdot
.43131 .5541 Mdot
.37559 .27755 Mdot
.3978 .61524 Mdot
.14698 .56622 Mdot
.37302 .32445 Mdot
.60033 .67401 Mdot
.66899 .44885 Mdot
.57797 .60839 Mdot
.47809 .74484 Mdot
.60781 .33322 Mdot
.5553 .47302 Mdot
.53765 .3713 Mdot
.57716 .53393 Mdot
.56324 .63146 Mdot
.37568 .60108 Mdot
.83937 .39953 Mdot
.55321 .63456 Mdot
.62258 .66343 Mdot
.49932 .18105 Mdot
.19855 .33583 Mdot
.45935 .60971 Mdot
.61086 .67323 Mdot
.54556 .3752 Mdot
.37259 .33808 Mdot
.36635 .54061 Mdot
.43823 .56368 Mdot
.56208 .62192 Mdot
.58807 .38568 Mdot
.37852 .71472 Mdot
.55668 .34499 Mdot
.60424 .6717 Mdot
.54787 .35484 Mdot
.71811 .49105 Mdot
.55881 .38289 Mdot
.3444 .5529 Mdot
.40609 .58294 Mdot
.47855 .25266 Mdot
.60219 .66836 Mdot
.40034 .56001 Mdot
.44639 .54373 Mdot
.57455 .64787 Mdot
.62812 .58821 Mdot
.39386 .72365 Mdot
.44313 .54675 Mdot
.44026 .5781 Mdot
.36032 .32924 Mdot
.5254 .48786 Mdot
.59998 .72836 Mdot
.35249 .57221 Mdot
.3533 .36031 Mdot
.59265 .61203 Mdot
.39306 .60453 Mdot
.18274 .56723 Mdot
.6981 .34251 Mdot
.39113 .60893 Mdot
.57022 .35389 Mdot
.32771 .58198 Mdot
.37207 .79227 Mdot
.39418 .53095 Mdot
.56635 .64292 Mdot
.61493 .65293 Mdot
.65629 .21672 Mdot
.57415 .63245 Mdot
.51165 .35856 Mdot
.68342 .49127 Mdot
.21483 .36267 Mdot
.56101 .33742 Mdot
.38575 .62615 Mdot
.51105 .1577 Mdot
.45826 .55676 Mdot
.35826 .60701 Mdot
.5769 .81767 Mdot
.56967 .36385 Mdot
.59795 .6396 Mdot
.67933 .42956 Mdot
.47143 .60516 Mdot
.64669 .48167 Mdot
.38056 .50039 Mdot
.4025 .53259 Mdot
.41871 .82452 Mdot
.23768 .34322 Mdot
.63536 .44398 Mdot
.40142 .5222 Mdot
.35319 .57417 Mdot
.48527 .35857 Mdot
.39972 .57299 Mdot
.37621 .33602 Mdot
.59757 .65095 Mdot
.57682 .37614 Mdot
.38184 .3618 Mdot
.43197 .60653 Mdot
.39631 .33894 Mdot
.53078 .33556 Mdot
.69955 .47255 Mdot
.36775 .56935 Mdot
.37704 .37506 Mdot
.39932 .34461 Mdot
.41173 .56092 Mdot
.61638 .62796 Mdot
.30057 .56995 Mdot
.42823 .59311 Mdot
.34932 .56815 Mdot
.58363 .62585 Mdot
.26671 .77183 Mdot
.39667 .53479 Mdot
.29821 .44494 Mdot
.55047 .6491 Mdot
.59721 .55227 Mdot
.55512 .32859 Mdot
.3801 .52728 Mdot
.69912 .4714 Mdot
.69701 .47088 Mdot
.55467 .38835 Mdot
.59339 .59544 Mdot
.5447 .25668 Mdot
.54582 .60395 Mdot
.39481 .63358 Mdot
.38541 .52095 Mdot
.33929 .63847 Mdot
.26219 .68865 Mdot
.57764 .61236 Mdot
.57591 .30142 Mdot
.52985 .64699 Mdot
.67304 .447 Mdot
.57165 .39258 Mdot
.57576 .59836 Mdot
.58908 .62684 Mdot
.60357 .60956 Mdot
.37434 .36736 Mdot
.47791 .25559 Mdot
.55774 .66647 Mdot
.58859 .68669 Mdot
.441 .56161 Mdot
.35244 .56708 Mdot
.51844 .82731 Mdot
.50374 .82037 Mdot
.35674 .33438 Mdot
.51595 .3557 Mdot
.58327 .12802 Mdot
.70427 .48568 Mdot
.61588 .21256 Mdot
.35143 .59791 Mdot
.62129 .13697 Mdot
.37088 .53687 Mdot
.39384 .56839 Mdot
.57418 .59871 Mdot
.36708 .36618 Mdot
.38757 .34996 Mdot
.55427 .6362 Mdot
.5865 .68957 Mdot
.37889 .33601 Mdot
.44102 .1987 Mdot
.18477 .60631 Mdot
.67588 .41166 Mdot
.58202 .65633 Mdot
.35436 .74501 Mdot
.64511 .44641 Mdot
.41619 .49012 Mdot
.62637 .46661 Mdot
.53577 .36258 Mdot
.58834 .36232 Mdot
.64655 .47469 Mdot
.43564 .58099 Mdot
.51955 .36302 Mdot
.45525 .58089 Mdot
.60978 .25523 Mdot
.46618 .76797 Mdot
.61086 .31802 Mdot
.3838 .48087 Mdot
.63041 .58994 Mdot
.69425 .53165 Mdot
.41329 .61147 Mdot
.17271 .53016 Mdot
.39767 .34978 Mdot
.43425 .63236 Mdot
.65107 .49397 Mdot
.56413 .83095 Mdot
.36777 .57803 Mdot
.5692 .64802 Mdot
.66995 .50197 Mdot
.7927 .55857 Mdot
.76224 .58043 Mdot
.36317 .55607 Mdot
.81665 .36434 Mdot
.63245 .67819 Mdot
.52828 .36875 Mdot
.71725 .68485 Mdot
.5518 .62748 Mdot
.34532 .38177 Mdot
.20192 .5087 Mdot
.25258 .30287 Mdot
.6017 .64452 Mdot
.56828 .32916 Mdot
.60495 .62264 Mdot
.40742 .36334 Mdot
.54029 .62959 Mdot
.53277 .34808 Mdot
.40156 .60359 Mdot
.55924 .3532 Mdot
.36889 .36176 Mdot
.63838 .74612 Mdot
.63575 .44382 Mdot
.52744 .38831 Mdot
.66369 .468 Mdot
.24488 .40399 Mdot
.25291 .48742 Mdot
.67011 .45927 Mdot
.37061 .68046 Mdot
.38295 .52151 Mdot
.54918 .6504 Mdot
.55263 .3305 Mdot
.40353 .30059 Mdot
.69935 .44444 Mdot
.58448 .64264 Mdot
.5205 .37543 Mdot
.74971 .61998 Mdot
.46725 .63421 Mdot
.38186 .51986 Mdot
.37393 .41918 Mdot
.57998 .65196 Mdot
.57182 .33362 Mdot
.74974 .71585 Mdot
.6037 .62329 Mdot
.50269 .34636 Mdot
.66012 .44748 Mdot
.69123 .49707 Mdot
.42849 .53421 Mdot
.70967 .51701 Mdot
.53575 .38213 Mdot
.61966 .50803 Mdot
.61689 .66767 Mdot
.78408 .59007 Mdot
.41025 .37569 Mdot
.54968 .36347 Mdot
.46226 .56488 Mdot
.61447 .69084 Mdot
.71463 .32722 Mdot
.39685 .73502 Mdot
.85197 .49338 Mdot
.55897 .34292 Mdot
.59389 .6453 Mdot
.57249 .65303 Mdot
.34739 .61068 Mdot
.72176 .67125 Mdot
.49476 .23782 Mdot
.40612 .64892 Mdot
.59318 .47221 Mdot
.53247 .31978 Mdot
.5638 .31361 Mdot
.40641 .50247 Mdot
.4299 .58032 Mdot
.66641 .44539 Mdot
.40217 .60206 Mdot
.61741 .62312 Mdot
.41876 .54126 Mdot
.67275 .46754 Mdot
.54021 .37557 Mdot
.36908 .57371 Mdot
.40132 .34608 Mdot
.63721 .46558 Mdot
.70671 .4826 Mdot
.55394 .36693 Mdot
.56204 .62161 Mdot
.58816 .55204 Mdot
.55025 .33276 Mdot
.43639 .57246 Mdot
.48953 .45998 Mdot
.35589 .58291 Mdot
.56842 .57823 Mdot
.60066 .62254 Mdot
.57707 .37539 Mdot
.53361 .62553 Mdot
.66826 .4772 Mdot
.21106 .46038 Mdot
.3987 .58887 Mdot
.50531 .33773 Mdot
.75637 .40716 Mdot
.57275 .56168 Mdot
.62701 .64422 Mdot
.55641 .24614 Mdot
.54705 .64413 Mdot
.51697 .34781 Mdot
.55741 .19025 Mdot
.3903 .37347 Mdot
.58179 .38154 Mdot
.24194 .63166 Mdot
.56509 .37161 Mdot
.42768 .53955 Mdot
.39615 .53771 Mdot
.56248 .38224 Mdot
.38708 .32996 Mdot
.63353 .78792 Mdot
.51899 .31088 Mdot
.59902 .64342 Mdot
.53859 .21127 Mdot
.83397 .58044 Mdot
.64036 .54522 Mdot
.67526 .44915 Mdot
.46522 .60135 Mdot
.3792 .52418 Mdot
.65695 .50153 Mdot
.623 .45225 Mdot
.41783 .35669 Mdot
.50963 .33574 Mdot
.62638 .68041 Mdot
.69934 .46115 Mdot
.52178 .64727 Mdot
.5115 .2718 Mdot
.33716 .59378 Mdot
.76292 .34631 Mdot
.35005 .59438 Mdot
.24334 .47194 Mdot
.66957 .46432 Mdot
.40468 .61537 Mdot
.33905 .53964 Mdot
.676 .50645 Mdot
.37049 .3383 Mdot
.54417 .30259 Mdot
.54561 .3521 Mdot
.25972 .75108 Mdot
.4536 .57369 Mdot
.42411 .54524 Mdot
.65272 .48177 Mdot
.41546 .27908 Mdot
.59282 .65607 Mdot
.55572 .61446 Mdot
.53891 .37975 Mdot
.57101 .42336 Mdot
.41252 .53015 Mdot
.40843 .60921 Mdot
.54523 .34367 Mdot
.52526 .38471 Mdot
.64184 .35899 Mdot
.41395 .55378 Mdot
.66278 .48833 Mdot
.3079 .3153 Mdot
.66211 .46088 Mdot
.36349 .59123 Mdot
.42406 .54823 Mdot
.34333 .55516 Mdot
.4482 .598 Mdot
.64378 .50247 Mdot
.36028 .59383 Mdot
.36306 .51987 Mdot
.59102 .64476 Mdot
.35906 .55507 Mdot
.60274 .44618 Mdot
.40646 .59859 Mdot
.37536 .33706 Mdot
.59358 .72215 Mdot
.36773 .57693 Mdot
.41273 .53797 Mdot
.59686 .347 Mdot
.38677 .58582 Mdot
.69082 .46049 Mdot
.59492 .66636 Mdot
.65658 .4878 Mdot
.69472 .46787 Mdot
.54306 .31624 Mdot
.39348 .32774 Mdot
.41403 .62504 Mdot
.35778 .341 Mdot
.4194 .63103 Mdot
.44514 .59293 Mdot
.4742 .3279 Mdot
.71935 .23696 Mdot
.69884 .73071 Mdot
.40028 .59015 Mdot
.56969 .36741 Mdot
.57041 .35786 Mdot
.59476 .58364 Mdot
.4137 .52056 Mdot
.67797 .51416 Mdot
.67465 .44753 Mdot
.32794 .73765 Mdot
.33624 .47634 Mdot
.37419 .33709 Mdot
.53554 .48789 Mdot
.44885 .56291 Mdot
.4076 .61554 Mdot
.4552 .56463 Mdot
.5787 .35082 Mdot
.28488 .61867 Mdot
.56431 .39256 Mdot
.66455 .55255 Mdot
.65118 .46925 Mdot
.36415 .56592 Mdot
.74496 .318 Mdot
.56878 .66615 Mdot
.59496 .66677 Mdot
.70932 .48803 Mdot
.5321 .39986 Mdot
.57616 .79658 Mdot
.16784 .41083 Mdot
.6239 .70009 Mdot
.37144 .36837 Mdot
.42486 .60715 Mdot
.55616 .37881 Mdot
.61501 .66494 Mdot
.3687 .36518 Mdot
.36773 .59013 Mdot
.47908 .25634 Mdot
.40865 .59249 Mdot
.75866 .50155 Mdot
.61215 .62713 Mdot
.16445 .59281 Mdot
.59812 .59879 Mdot
.64383 .49506 Mdot
.65009 .49594 Mdot
.41365 .54931 Mdot
.64884 .66136 Mdot
.54934 .63033 Mdot
.41714 .40878 Mdot
.40951 .34107 Mdot
.65164 .56801 Mdot
.38386 .36999 Mdot
.52529 .35734 Mdot
.3682 .3554 Mdot
.53305 .34538 Mdot
.58961 .78932 Mdot
.42673 .6669 Mdot
.38449 .3582 Mdot
.7588 .42516 Mdot
.37684 .52491 Mdot
.35155 .34164 Mdot
.39937 .50516 Mdot
.3965 .64614 Mdot
.54782 .34285 Mdot
.41164 .34938 Mdot
.40515 .61433 Mdot
.30314 .74276 Mdot
.67407 .45835 Mdot
.67304 .51411 Mdot
.40316 .5062 Mdot
.55307 .32459 Mdot
.57873 .60164 Mdot
.18063 .46769 Mdot
.69083 .45048 Mdot
.40371 .54001 Mdot
.35828 .53399 Mdot
.54839 .65124 Mdot
.67484 .2456 Mdot
.42282 .55277 Mdot
.53834 .58293 Mdot
.41099 .55068 Mdot
.64607 .45914 Mdot
.58409 .61114 Mdot
.58027 .66016 Mdot
.51945 .37299 Mdot
.58234 .677 Mdot
.48407 .48819 Mdot
.77004 .44347 Mdot
.32709 .53136 Mdot
.67277 .48006 Mdot
.67429 .58339 Mdot
.69217 .53738 Mdot
.24808 .60257 Mdot
.62153 .62231 Mdot
.36885 .60275 Mdot
.58671 .68 Mdot
.37409 .36062 Mdot
.59331 .67025 Mdot
.58788 .59353 Mdot
.37767 .5936 Mdot
.36814 .55434 Mdot
.53417 .37277 Mdot
.72685 .66431 Mdot
.55313 .62965 Mdot
.37234 .53713 Mdot
.33772 .56046 Mdot
.45917 .57375 Mdot
.42241 .41982 Mdot
.58209 .61214 Mdot
.40398 .18556 Mdot
.41934 .45265 Mdot
.55565 .62655 Mdot
.71495 .76293 Mdot
.74199 .37031 Mdot
.61052 .35701 Mdot
.46024 .35702 Mdot
.4067 .54891 Mdot
.5092 .36625 Mdot
.36785 .55978 Mdot
.76568 .35339 Mdot
.3831 .57993 Mdot
.3744 .33545 Mdot
.4532 .58035 Mdot
.5861 .37166 Mdot
.55715 .34298 Mdot
.40713 .54014 Mdot
.37052 .57107 Mdot
.64291 .75331 Mdot
.54073 .62344 Mdot
.60975 .66297 Mdot
.61968 .34059 Mdot
.39194 .36297 Mdot
.64682 .48463 Mdot
.40701 .57576 Mdot
.5567 .32299 Mdot
.55819 .34567 Mdot
.5663 .61336 Mdot
.52996 .331 Mdot
.68255 .47953 Mdot
.39937 .58527 Mdot
.65954 .50555 Mdot
.39064 .37507 Mdot
.58544 .61312 Mdot
.36077 .555 Mdot
.4412 .56184 Mdot
.61471 .65307 Mdot
.40597 .61737 Mdot
.3946 .33501 Mdot
.56287 .36826 Mdot
.603 .64397 Mdot
.68519 .49423 Mdot
.52645 .35351 Mdot
.34869 .57932 Mdot
.79932 .34844 Mdot
.43382 .5401 Mdot
.3954 .54412 Mdot
.26199 .70327 Mdot
.44938 .5722 Mdot
.55638 .3356 Mdot
.61138 .66892 Mdot
.48908 .60607 Mdot
.32807 .41666 Mdot
.24876 .7622 Mdot
.56059 .39175 Mdot
.42343 .60485 Mdot
.25715 .64606 Mdot
.41719 .60548 Mdot
.38678 .751 Mdot
.55499 .39794 Mdot
.58483 .49145 Mdot
.46139 .57711 Mdot
.69386 .48104 Mdot
.5523 .38137 Mdot
.53451 .34059 Mdot
.57734 .2291 Mdot
.38742 .60324 Mdot
.46711 .4211 Mdot
.3618 .58367 Mdot
.6887 .49281 Mdot
.34845 .47858 Mdot
.55634 .33873 Mdot
.82291 .58031 Mdot
.41341 .55893 Mdot
.58615 .62133 Mdot
.59541 .35126 Mdot
.70389 .45884 Mdot
.35042 .56146 Mdot
.37235 .32972 Mdot
.6364 .44001 Mdot
.34245 .51768 Mdot
.67581 .48137 Mdot
.34965 .56972 Mdot
.47965 .54944 Mdot
.81955 .51468 Mdot
.60936 .61364 Mdot
.66545 .44716 Mdot
.47384 .45113 Mdot
.36845 .60066 Mdot
.60247 .64558 Mdot
.58697 .64553 Mdot
.38313 .37376 Mdot
.57483 .5121 Mdot
.76931 .54187 Mdot
.44082 .78713 Mdot
.5533 .2171 Mdot
.59103 .37381 Mdot
.6807 .38978 Mdot
.39022 .54748 Mdot
.43964 .45084 Mdot
.68527 .45494 Mdot
.43558 .54006 Mdot
.52587 .70236 Mdot
.55906 .65868 Mdot
.43796 .54705 Mdot
.38681 .3451 Mdot
.34485 .31807 Mdot
.29931 .32244 Mdot
.21658 .54526 Mdot
.53677 .36922 Mdot
.32469 .56151 Mdot
.50386 .59005 Mdot
.54937 .32466 Mdot
.34014 .58233 Mdot
.54765 .32596 Mdot
.38807 .21416 Mdot
.35421 .34993 Mdot
.58993 .62017 Mdot
.64934 .53766 Mdot
.36278 .61199 Mdot
.40048 .52782 Mdot
.39606 .32757 Mdot
.42944 .57738 Mdot
.80762 .46382 Mdot
.41527 .4197 Mdot
.52184 .35559 Mdot
.60469 .60999 Mdot
.33845 .56545 Mdot
.52651 .50114 Mdot
.41664 .60162 Mdot
.51104 .7901 Mdot
.41061 .53726 Mdot
.76728 .57975 Mdot
.61322 .62397 Mdot
.67136 .47314 Mdot
.42967 .61545 Mdot
.38706 .5744 Mdot
.33064 .45969 Mdot
.41833 .62986 Mdot
.39007 .61188 Mdot
.48675 .62875 Mdot
.59931 .60264 Mdot
.60667 .62696 Mdot
.55156 .38935 Mdot
.27991 .67209 Mdot
.66548 .48446 Mdot
.48833 .5911 Mdot
.71135 .49348 Mdot
.34723 .69363 Mdot
.36237 .35731 Mdot
.25174 .52806 Mdot
.39851 .56253 Mdot
.57147 .66108 Mdot
.19774 .42324 Mdot
.54979 .61456 Mdot
.52893 .47415 Mdot
.67757 .50285 Mdot
.55482 .63317 Mdot
.39038 .56962 Mdot
.63921 .70685 Mdot
.27661 .70843 Mdot
.66057 .47648 Mdot
.37405 .62261 Mdot
.58961 .36886 Mdot
.54523 .26503 Mdot
.82658 .53038 Mdot
.6699 .45603 Mdot
.60278 .46484 Mdot
.3953 .60754 Mdot
.57961 .6737 Mdot
.69259 .48495 Mdot
.64845 .45862 Mdot
.52734 .3339 Mdot
.3689 .55192 Mdot
.37168 .54939 Mdot
.51476 .35993 Mdot
.65525 .48536 Mdot
.3904 .51447 Mdot
.3438 .52131 Mdot
.48873 .86084 Mdot
.76511 .59964 Mdot
.27876 .78395 Mdot
.60267 .57753 Mdot
.49849 .68319 Mdot
.17418 .47864 Mdot
.56861 .61731 Mdot
.42384 .61228 Mdot
.4104 .4993 Mdot
.53669 .38276 Mdot
.39075 .59393 Mdot
.56693 .40062 Mdot
.69925 .4982 Mdot
.55884 .83119 Mdot
.7049 .60963 Mdot
.32661 .25132 Mdot
.38876 .59389 Mdot
.51209 .60828 Mdot
.37269 .35358 Mdot
.64508 .57443 Mdot
.59095 .61529 Mdot
.45609 .54917 Mdot
.64159 .7516 Mdot
.57492 .38599 Mdot
.58013 .62893 Mdot
.66042 .77339 Mdot
.63648 .59957 Mdot
.35648 .58262 Mdot
.55105 .39272 Mdot
.16849 .52041 Mdot
.51305 .64803 Mdot
.69224 .51547 Mdot
.36915 .33863 Mdot
.5707 .3786 Mdot
.66207 .44351 Mdot
.54171 .59142 Mdot
.57059 .626 Mdot
.58122 .60421 Mdot
.67211 .73402 Mdot
.59831 .37437 Mdot
.37451 .35498 Mdot
.28877 .52067 Mdot
.3417 .46603 Mdot
.3814 .33575 Mdot
.5886 .36123 Mdot
.61476 .6188 Mdot
.55551 .6461 Mdot
.59385 .66598 Mdot
.74384 .69083 Mdot
.60451 .68101 Mdot
.58369 .21695 Mdot
.4548 .58607 Mdot
.32084 .59807 Mdot
.4207 .60675 Mdot
.67761 .51268 Mdot
.61393 .64927 Mdot
.67455 .42524 Mdot
.39216 .63036 Mdot
.26162 .50423 Mdot
.42767 .5366 Mdot
.63303 .46831 Mdot
.43571 .55061 Mdot
.75047 .30446 Mdot
.5735 .67458 Mdot
.39614 .5914 Mdot
.62839 .46276 Mdot
.39847 .36297 Mdot
.62522 .63108 Mdot
.36187 .55827 Mdot
.51126 .22331 Mdot
.44781 .58289 Mdot
.35358 .23732 Mdot
.79306 .51871 Mdot
.36823 .36501 Mdot
.7903 .42145 Mdot
.55557 .31949 Mdot
.39399 .6422 Mdot
.47599 .59192 Mdot
.66333 .47218 Mdot
.64969 .56778 Mdot
.54495 .3695 Mdot
.30007 .65843 Mdot
.36908 .51586 Mdot
.3909 .37608 Mdot
.41165 .66344 Mdot
.66134 .50303 Mdot
.33801 .57683 Mdot
.33318 .55121 Mdot
.65584 .25183 Mdot
.37336 .50895 Mdot
.37704 .52762 Mdot
.36146 .32259 Mdot
.6025 .2156 Mdot
.41354 .59648 Mdot
.53442 .48158 Mdot
.54157 .6257 Mdot
.40867 .63388 Mdot
.58644 .21282 Mdot
.3921 .53607 Mdot
.57102 .62214 Mdot
.54255 .58418 Mdot
.7505 .53827 Mdot
.38949 .32617 Mdot
.41073 .53688 Mdot
.64571 .21185 Mdot
.42547 .56512 Mdot
.66688 .49004 Mdot
.41358 .52204 Mdot
.53292 .35113 Mdot
.72164 .72133 Mdot
.52128 .37261 Mdot
.42585 .52854 Mdot
.58918 .66287 Mdot
.65214 .47531 Mdot
.72743 .69039 Mdot
.45069 .25536 Mdot
.64149 .2288 Mdot
.18609 .38988 Mdot
.40762 .34065 Mdot
.41409 .37761 Mdot
.69524 .50436 Mdot
.39794 .59263 Mdot
.50435 .17415 Mdot
.44176 .62447 Mdot
.44312 .57073 Mdot
.3824 .5788 Mdot
.25283 .48214 Mdot
.69972 .47697 Mdot
.55181 .34148 Mdot
.42412 .55113 Mdot
.36782 .59895 Mdot
.57776 .6181 Mdot
.39695 .3586 Mdot
.55866 .33228 Mdot
.39353 .35273 Mdot
.55714 .38069 Mdot
.6167 .80536 Mdot
.365 .52052 Mdot
.40169 .3637 Mdot
.68081 .44664 Mdot
.57521 .62034 Mdot
.74551 .50489 Mdot
.52892 .34561 Mdot
.53903 .38662 Mdot
.40678 .53772 Mdot
.56106 .62433 Mdot
.53993 .60796 Mdot
.3903 .37051 Mdot
.67638 .46548 Mdot
.36816 .57798 Mdot
.44159 .59189 Mdot
.48794 .55771 Mdot
.54831 .32048 Mdot
.7678 .47916 Mdot
.63621 .3982 Mdot
.40106 .5918 Mdot
.61619 .66808 Mdot
.37432 .57479 Mdot
.31458 .28549 Mdot
.57692 .67307 Mdot
.38403 .53462 Mdot
.77292 .71781 Mdot
.61076 .33458 Mdot
.71285 .56238 Mdot
.36064 .53365 Mdot
.14901 .51545 Mdot
.39297 .55393 Mdot
.57108 .83238 Mdot
.29227 .31187 Mdot
.4087 .52559 Mdot
.34948 .56065 Mdot
.4459 .75255 Mdot
.43283 .6002 Mdot
.51688 .3718 Mdot
.50801 .83645 Mdot
.55311 .60834 Mdot
.70107 .53387 Mdot
.56314 .7112 Mdot
.38327 .32527 Mdot
.53918 .37984 Mdot
.5965 .33357 Mdot
.39098 .34117 Mdot
.57875 .65376 Mdot
.41192 .58944 Mdot
.51804 .43967 Mdot
.56194 .33104 Mdot
.29327 .60327 Mdot
.6675 .49282 Mdot
.67777 .32063 Mdot
.35448 .40385 Mdot
.67897 .48229 Mdot
.35972 .55276 Mdot
.42391 .74272 Mdot
.58484 .77979 Mdot
.21038 .62218 Mdot
.63924 .44375 Mdot
.65891 .47469 Mdot
.74709 .698 Mdot
.42345 .35278 Mdot
.65699 .25624 Mdot
.76337 .58287 Mdot
.64797 .47845 Mdot
.61757 .60478 Mdot
.51477 .37129 Mdot
.72644 .42362 Mdot
.40742 .63777 Mdot
.44556 .59587 Mdot
.39 .57131 Mdot
.66728 .45993 Mdot
.58268 .56697 Mdot
.78266 .60664 Mdot
.6613 .46603 Mdot
.45262 .51741 Mdot
.57295 .46243 Mdot
.74587 .41397 Mdot
.52837 .32696 Mdot
.41103 .34119 Mdot
.42676 .35118 Mdot
.59296 .63137 Mdot
.4062 .336 Mdot
.3469 .3149 Mdot
.42096 .58036 Mdot
.65454 .46233 Mdot
.75465 .37929 Mdot
.68551 .4981 Mdot
.392 .34693 Mdot
.41962 .3557 Mdot
.59099 .64559 Mdot
.60976 .6649 Mdot
.4632 .71232 Mdot
.32369 .38001 Mdot
.438 .58465 Mdot
.4444 .33675 Mdot
.58468 .59424 Mdot
.30943 .59005 Mdot
.40906 .33797 Mdot
.39521 .36254 Mdot
.31579 .46185 Mdot
.3956 .56302 Mdot
.31102 .63234 Mdot
.4013 .56816 Mdot
.45961 .49258 Mdot
.3451 .56819 Mdot
.52769 .33324 Mdot
.38523 .55498 Mdot
.30486 .47103 Mdot
.39888 .61957 Mdot
.35294 .53237 Mdot
.57415 .3412 Mdot
.35271 .52085 Mdot
.53424 .35156 Mdot
.43867 .53995 Mdot
.37584 .37625 Mdot
.54095 .3819 Mdot
.31098 .42047 Mdot
.30251 .45603 Mdot
.58703 .35689 Mdot
.36092 .34817 Mdot
.35769 .32924 Mdot
.27192 .42289 Mdot
.58941 .61376 Mdot
.47372 .56668 Mdot
.3956 .59419 Mdot
.57174 .39427 Mdot
.68656 .45971 Mdot
.34711 .57858 Mdot
.37088 .52677 Mdot
.35631 .54012 Mdot
.59189 .62855 Mdot
.48412 .23831 Mdot
.40569 .36273 Mdot
.51443 .36525 Mdot
.57976 .54455 Mdot
.53123 .31953 Mdot
.32906 .57525 Mdot
.43246 .5092 Mdot
.53731 .70125 Mdot
.75031 .44555 Mdot
.76944 .671 Mdot
.57288 .62683 Mdot
.57121 .35543 Mdot
.40944 .37675 Mdot
.46002 .5353 Mdot
.57281 .66348 Mdot
.53314 .34831 Mdot
.40791 .59208 Mdot
.36054 .61568 Mdot
.77064 .41977 Mdot
.28243 .34095 Mdot
.31005 .44109 Mdot
.56043 .38805 Mdot
.58769 .34427 Mdot
.28227 .46839 Mdot
.40517 .30678 Mdot
.70329 .44384 Mdot
.39459 .60407 Mdot
.37609 .32998 Mdot
.60579 .67148 Mdot
.61038 .73577 Mdot
.64218 .47602 Mdot
.71598 .6755 Mdot
.38904 .59212 Mdot
.61378 .5552 Mdot
.59012 .66217 Mdot
.38604 .34206 Mdot
.66278 .45852 Mdot
.4041 .31497 Mdot
.57581 .35235 Mdot
.24172 .30495 Mdot
.43107 .5686 Mdot
.41039 .53904 Mdot
.63783 .45459 Mdot
.5648 .65968 Mdot
.3457 .34291 Mdot
.53873 .21664 Mdot
.53386 .33546 Mdot
.51663 .17507 Mdot
.60895 .67357 Mdot
.35236 .74155 Mdot
.51704 .33625 Mdot
.70889 .47765 Mdot
.2852 .41773 Mdot
.67852 .47558 Mdot
.42265 .53172 Mdot
.56933 .65411 Mdot
.67459 .45055 Mdot
.74806 .64039 Mdot
.2949 .75692 Mdot
.36346 .75162 Mdot
.41451 .5815 Mdot
.37051 .80151 Mdot
.41439 .21466 Mdot
.63689 .69691 Mdot
.67482 .44667 Mdot
.43284 .5372 Mdot
.40797 .53297 Mdot
.42761 .56467 Mdot
.69456 .47268 Mdot
.44537 .35235 Mdot
.54631 .33978 Mdot
.41332 .61041 Mdot
.41717 .35977 Mdot
.53642 .35957 Mdot
.71588 .48564 Mdot
.53574 .3259 Mdot
.55458 .59007 Mdot
.33457 .59219 Mdot
.65145 .60178 Mdot
.86637 .6229 Mdot
.65671 .4804 Mdot
.55017 .31872 Mdot
.40264 .51313 Mdot
.71004 .35247 Mdot
.59717 .61059 Mdot
.53051 .3363 Mdot
.4244 .54384 Mdot
.7569 .44626 Mdot
.66054 .74382 Mdot
.54563 .32847 Mdot
.57534 .66621 Mdot
.21494 .61824 Mdot
.39622 .59983 Mdot
.40678 .5618 Mdot
.56024 .6293 Mdot
.3576 .65555 Mdot
.71388 .73974 Mdot
.37204 .5721 Mdot
.67052 .47082 Mdot
.28247 .25705 Mdot
.37207 .5264 Mdot
.41439 .46348 Mdot
.54161 .37854 Mdot
.72222 .4439 Mdot
.75905 .51712 Mdot
.4342 .61708 Mdot
.62625 .26427 Mdot
.64456 .53627 Mdot
.27517 .67425 Mdot
.57736 .39959 Mdot
.43032 .23427 Mdot
.34353 .77172 Mdot
.63373 .48357 Mdot
.45623 .6489 Mdot
.59242 .24473 Mdot
.5228 .66706 Mdot
.18461 .5587 Mdot
.39654 .28142 Mdot
.64596 .75156 Mdot
.53772 .44131 Mdot
.57044 .37307 Mdot
.34748 .63976 Mdot
.36538 .55984 Mdot
.40843 .21764 Mdot
.80929 .53435 Mdot
.80114 .56414 Mdot
.37222 .80368 Mdot
.38392 .75546 Mdot
.26018 .65924 Mdot
.24694 .63647 Mdot
.42057 .47516 Mdot
.6657 .39806 Mdot
.49825 .16816 Mdot
.57097 .80515 Mdot
.4665 .19097 Mdot
.31846 .58929 Mdot
.51256 .46152 Mdot
.30403 .27958 Mdot
.43598 .66339 Mdot
.42663 .64893 Mdot
.51724 .36281 Mdot
.58812 .61082 Mdot
.64329 .2539 Mdot
.55556 .66725 Mdot
.75142 .53519 Mdot
.2253 .64887 Mdot
.28576 .74035 Mdot
.67054 .23511 Mdot
.15539 .51114 Mdot
.51454 .69617 Mdot
.4347 .13981 Mdot
.51395 .38438 Mdot
.56469 .61491 Mdot
.25281 .46746 Mdot
.30389 .48697 Mdot
.6823 .62398 Mdot
.5457 .23383 Mdot
.50923 .26117 Mdot
.26477 .38358 Mdot
.5716 .65028 Mdot
.78311 .454 Mdot
.73509 .4345 Mdot
.6981 .61492 Mdot
.53938 .81883 Mdot
.22007 .59133 Mdot
.49829 .42977 Mdot
.60069 .26801 Mdot
.68158 .34642 Mdot
.78567 .61195 Mdot
.35267 .41735 Mdot
.48238 .62465 Mdot
.76896 .5875 Mdot
.18266 .43071 Mdot
.42993 .68799 Mdot
.47414 .51226 Mdot
.30836 .4901 Mdot
.63991 .79184 Mdot
.37248 .24607 Mdot
.86322 .56351 Mdot
.56102 .67547 Mdot
.35147 .53928 Mdot
.35398 .6693 Mdot
.60444 .19063 Mdot
.36267 .31997 Mdot
.21207 .53774 Mdot
.41382 .35721 Mdot
.54284 .5943 Mdot
.70377 .73682 Mdot
.59479 .21273 Mdot
.54708 .1705 Mdot
.39265 .38185 Mdot
.48911 .58891 Mdot
.12626 .59696 Mdot
.26407 .56767 Mdot
.70596 .5842 Mdot
.49524 .85923 Mdot
.58546 .44873 Mdot
.78689 .58134 Mdot
.6746 .44982 Mdot
.39087 .80879 Mdot
.55786 .64301 Mdot
.88506 .52354 Mdot
.58512 .82597 Mdot
.56318 .72242 Mdot
.64847 .87598 Mdot
.26762 .47475 Mdot
.58824 .50417 Mdot
.62175 .52115 Mdot
.30206 .38283 Mdot
.73854 .67051 Mdot
.22101 .43495 Mdot
.70146 .34937 Mdot
.14439 .51606 Mdot
.33167 .76828 Mdot
.52698 .16931 Mdot
.30957 .25252 Mdot
.45128 .67681 Mdot
.53346 .50709 Mdot
.4063 .48377 Mdot
.5882 .29099 Mdot
.20169 .53821 Mdot
.66653 .78795 Mdot
.41492 .45047 Mdot
.24326 .75455 Mdot
.39053 .3879 Mdot
.48583 .27238 Mdot
.25802 .73164 Mdot
.26789 .39341 Mdot
.77906 .49657 Mdot
.27103 .59836 Mdot
.31376 .52122 Mdot
.5346 .52524 Mdot
.20737 .5466 Mdot
.71396 .53921 Mdot
.47079 .83753 Mdot
.15712 .54243 Mdot
.66167 .2572 Mdot
.47003 .77687 Mdot
.36948 .45873 Mdot
.62737 .67125 Mdot
.32173 .32717 Mdot
.76407 .51759 Mdot
.32284 .78703 Mdot
.65464 .51205 Mdot
.36807 .81799 Mdot
.70166 .74594 Mdot
.36188 .52128 Mdot
.47207 .5618 Mdot
.62779 .6069 Mdot
.30688 .33385 Mdot
.32075 .57215 Mdot
.74932 .34507 Mdot
.27809 .7314 Mdot
.55461 .78406 Mdot
.71964 .5226 Mdot
.64944 .55664 Mdot
.26097 .74468 Mdot
.40161 .71295 Mdot
.43289 .33431 Mdot
.4681 .82697 Mdot
.74518 .66626 Mdot
.54466 .36315 Mdot
.54344 .17804 Mdot
.61025 .45233 Mdot
.63586 .74188 Mdot
.43512 .78461 Mdot
.50687 .66871 Mdot
.27889 .73371 Mdot
.47372 .22985 Mdot
.68231 .74699 Mdot
.23806 .423 Mdot
.48263 .18037 Mdot
.74927 .42853 Mdot
.38356 .49801 Mdot
.53549 .23065 Mdot
.36523 .32711 Mdot
.47464 .73597 Mdot
.33148 .21337 Mdot
.44436 .29973 Mdot
.41496 .50786 Mdot
.57345 .72574 Mdot
.59895 .32611 Mdot
.65418 .70213 Mdot
.86047 .50268 Mdot
.33795 .55122 Mdot
.29979 .509 Mdot
.45065 .22308 Mdot
.30859 .36825 Mdot
.17975 .60002 Mdot
.24851 .3287 Mdot
.86799 .57647 Mdot
.43204 .83853 Mdot
.44539 .25056 Mdot
.31867 .74784 Mdot
.3351 .7812 Mdot
.85597 .59114 Mdot
.46728 .60614 Mdot
.65623 .51108 Mdot
.76667 .27984 Mdot
.52553 .32725 Mdot
.29114 .50698 Mdot
.55344 .21705 Mdot
.33179 .37566 Mdot
.65426 .61654 Mdot
.2954 .64341 Mdot
.53485 .44747 Mdot
.53878 .62605 Mdot
.3245 .55789 Mdot
.81463 .60932 Mdot
.84105 .63209 Mdot
.83957 .59007 Mdot
.21036 .36306 Mdot
.39526 .80945 Mdot
.59966 .54177 Mdot
.64046 .21521 Mdot
.3051 .58866 Mdot
.41765 .61493 Mdot
.34456 .3231 Mdot
.2644 .47326 Mdot
.62046 .73282 Mdot
.7204 .61391 Mdot
.42087 .6672 Mdot
.21006 .53919 Mdot
.13105 .37794 Mdot
.48773 .71367 Mdot
.55721 .20464 Mdot
.42444 .32648 Mdot
.31616 .36512 Mdot
.18749 .50949 Mdot
.62755 .72812 Mdot
.25302 .67375 Mdot
.5397 .62324 Mdot
.50579 .20268 Mdot
.43235 .30774 Mdot
.47885 .63937 Mdot
.48126 .23997 Mdot
.25665 .58291 Mdot
.65831 .56545 Mdot
.6635 .7217 Mdot
.75025 .59222 Mdot
.37371 .68037 Mdot
.39751 .41019 Mdot
.66611 .33379 Mdot
.40358 .18474 Mdot
.35013 .27708 Mdot
.42581 .46995 Mdot
.56752 .4609 Mdot
.7833 .38272 Mdot
.66401 .5289 Mdot
.45276 .48346 Mdot
.61227 .43716 Mdot
.27515 .56177 Mdot
.9112 .42311 Mdot
.84064 .55977 Mdot
.22289 .6633 Mdot
.22934 .38534 Mdot
.36074 .50748 Mdot
.24602 .66757 Mdot
.87217 .52608 Mdot
.75444 .74037 Mdot
.65148 .33187 Mdot
.52078 .39127 Mdot
.71166 .47983 Mdot
.79181 .65585 Mdot
.4563 .3514 Mdot
.23719 .61043 Mdot
.39211 .44787 Mdot
.69982 .4666 Mdot
.66626 .19197 Mdot
.61888 .79601 Mdot
.4116 .78475 Mdot
.29345 .33341 Mdot
.44767 .52441 Mdot
.79824 .43135 Mdot
.54995 .62776 Mdot
.69964 .38756 Mdot
.33669 .39592 Mdot
.55233 .3602 Mdot
.22515 .48952 Mdot
.50953 .2127 Mdot
.45347 .58033 Mdot
.49692 .47183 Mdot
.61825 .67565 Mdot
.74989 .41817 Mdot
.67437 .56967 Mdot
.7908 .71007 Mdot
.39086 .30835 Mdot
.46342 .56543 Mdot
.31381 .38189 Mdot
.51463 .24443 Mdot
.75111 .71503 Mdot
.70528 .49278 Mdot
.30842 .74825 Mdot
.49274 .4338 Mdot
.31737 .34836 Mdot
.56157 .69807 Mdot
.32238 .61385 Mdot
.36933 .52335 Mdot
.20249 .39306 Mdot
.55741 .77678 Mdot
.53587 .6642 Mdot
.44101 .63358 Mdot
.29661 .60847 Mdot
.24226 .65973 Mdot
.35245 .31398 Mdot
.67912 .32929 Mdot
.30075 .74508 Mdot
.69821 .4909 Mdot
.59003 .68058 Mdot
.43261 .37089 Mdot
.44873 .1936 Mdot
.35358 .75286 Mdot
.6629 .74332 Mdot
.41449 .43265 Mdot
.45316 .29444 Mdot
.30424 .75995 Mdot
.28754 .70871 Mdot
.75702 .30067 Mdot
.63345 .6876 Mdot
.48858 .51451 Mdot
.43161 .19122 Mdot
.58987 .60265 Mdot
.63147 .22824 Mdot
.67449 .26414 Mdot
.58669 .81681 Mdot
.48226 .45513 Mdot
.13903 .53551 Mdot
.3122 .43799 Mdot
.20019 .51307 Mdot
.7401 .68237 Mdot
.47069 .18582 Mdot
.27256 .51672 Mdot
.61282 .70165 Mdot
.43478 .75871 Mdot
.3337 .52661 Mdot
.73718 .29417 Mdot
.77256 .29873 Mdot
.40286 .39214 Mdot
.59531 .49619 Mdot
.15552 .55605 Mdot
.42837 .5829 Mdot
.85162 .50514 Mdot
.5068 .20857 Mdot
.74731 .6946 Mdot
.70527 .47579 Mdot
.35308 .57178 Mdot
.40176 .62601 Mdot
.36995 .77955 Mdot
.74402 .53729 Mdot
.26912 .60556 Mdot
.29419 .25266 Mdot
.1691 .53319 Mdot
.43239 .67111 Mdot
.29571 .5028 Mdot
.22108 .595 Mdot
.40921 .21995 Mdot
.56575 .49691 Mdot
.21502 .44991 Mdot
.27965 .39798 Mdot
.17223 .47385 Mdot
.60408 .45134 Mdot
.50035 .31302 Mdot
.66356 .54505 Mdot
.62075 .3247 Mdot
.69012 .72303 Mdot
.35996 .54795 Mdot
.65964 .77386 Mdot
.24519 .59842 Mdot
.79165 .37894 Mdot
.82527 .51418 Mdot
.83824 .56574 Mdot
.52408 .7792 Mdot
.38887 .24849 Mdot
.44651 .20917 Mdot
.38172 .18202 Mdot
.48054 .41981 Mdot
.24712 .5069 Mdot
.25674 .40416 Mdot
.30289 .75451 Mdot
.63958 .45502 Mdot
.7679 .5648 Mdot
.67976 .53489 Mdot
.29517 .7089 Mdot
.41299 .72379 Mdot
.25092 .62423 Mdot
.58909 .43325 Mdot
.87375 .57078 Mdot
.29233 .30216 Mdot
.55113 .43694 Mdot
.57668 .36059 Mdot
.41713 .24751 Mdot
.22643 .55648 Mdot
.29005 .30595 Mdot
.498 .18674 Mdot
.61287 .35416 Mdot
.57275 .54778 Mdot
.34309 .72426 Mdot
.32551 .3231 Mdot
.19952 .39495 Mdot
.31295 .38069 Mdot
.27439 .71614 Mdot
.40536 .81261 Mdot
.66029 .77172 Mdot
.26668 .4815 Mdot
.19364 .3761 Mdot
.70674 .58106 Mdot
.31903 .31792 Mdot
.50875 .21057 Mdot
.49624 .2831 Mdot
.54259 .65712 Mdot
.66028 .15099 Mdot
.25851 .29649 Mdot
.36648 .2662 Mdot
.6569 .79035 Mdot
.23522 .33944 Mdot
.75205 .42773 Mdot
.38101 .66505 Mdot
.74922 .62949 Mdot
.62327 .77506 Mdot
.38354 .57849 Mdot
.84204 .57461 Mdot
.43838 .45461 Mdot
.84832 .63836 Mdot
.2336 .6324 Mdot
.595 .48723 Mdot
.33285 .58798 Mdot
.52866 .38503 Mdot
.46191 .41083 Mdot
.34703 .48156 Mdot
.36694 .7003 Mdot
.78929 .51359 Mdot
.70051 .52733 Mdot
.50813 .3739 Mdot
.61057 .31405 Mdot
.5525 .67092 Mdot
.25229 .3585 Mdot
.62824 .38308 Mdot
.49609 .37929 Mdot
.48455 .41289 Mdot
.41832 .4483 Mdot
.76452 .50595 Mdot
.39962 .78164 Mdot
.64094 .7291 Mdot
.66802 .62356 Mdot
.52132 .3384 Mdot
.43794 .79178 Mdot
.28526 .28713 Mdot
.16497 .5268 Mdot
.66756 .78621 Mdot
.53125 .51942 Mdot
.38685 .72848 Mdot
.3973 .46379 Mdot
.802 .57686 Mdot
.64842 .64723 Mdot
.69881 .52546 Mdot
.79595 .4366 Mdot
.62411 .60821 Mdot
.61728 .26545 Mdot
.56165 .83043 Mdot
.47697 .19282 Mdot
.42785 .19056 Mdot
.40645 .4035 Mdot
.51242 .57453 Mdot
.47707 .63588 Mdot
.31205 .42709 Mdot
.695 .44359 Mdot
.52062 .14854 Mdot
.43485 .63227 Mdot
.4649 .12077 Mdot
.64858 .45625 Mdot
.48311 .65708 Mdot
.27279 .40262 Mdot
.57147 .4738 Mdot
.60841 .42987 Mdot
.32331 .28579 Mdot
.77489 .56527 Mdot
.39318 .24027 Mdot
.77741 .61089 Mdot
.52128 .38999 Mdot
.24311 .29079 Mdot
.16125 .42789 Mdot
.45372 .76678 Mdot
.44774 .55194 Mdot
.21971 .3269 Mdot
.50182 .36055 Mdot
.62533 .73143 Mdot
.18136 .60531 Mdot
.19848 .43951 Mdot
.33024 .70653 Mdot
.31557 .35436 Mdot
.24922 .50998 Mdot
.40026 .82962 Mdot
.77768 .32384 Mdot
.20778 .53349 Mdot
.64211 .45314 Mdot
.57868 .44161 Mdot
.2567 .54773 Mdot
.79545 .54914 Mdot
.7401 .46373 Mdot
.77952 .5139 Mdot
.39732 .14369 Mdot
.28333 .52142 Mdot
.29589 .52088 Mdot
.80469 .53005 Mdot
.60877 .60783 Mdot
.78477 .54129 Mdot
.77865 .49472 Mdot
.22288 .38023 Mdot
.3327 .25151 Mdot
.77296 .50329 Mdot
.39929 .17045 Mdot
.43086 .64376 Mdot
.65824 .41469 Mdot
.30807 .62211 Mdot
.29409 .5344 Mdot
.66276 .4388 Mdot
.56458 .79838 Mdot
.17403 .55477 Mdot
.69091 .52101 Mdot
.19351 .41541 Mdot
.59364 .2644 Mdot
.30751 .52199 Mdot
.38261 .77868 Mdot
.1839 .49356 Mdot
.41191 .73303 Mdot
.72936 .27538 Mdot
.58868 .73585 Mdot
.49902 .36366 Mdot
.19187 .58323 Mdot
.52421 .35057 Mdot
.2917 .60219 Mdot
.70839 .68246 Mdot
.21882 .44758 Mdot
.76609 .67789 Mdot
.38165 .32591 Mdot
.56343 .61155 Mdot
.77622 .31039 Mdot
.61823 .6624 Mdot
.81611 .61197 Mdot
.51954 .67688 Mdot
.79669 .47334 Mdot
.43693 .25766 Mdot
.42108 .27998 Mdot
.38786 .15593 Mdot
.73473 .44696 Mdot
.53874 .40397 Mdot
.71169 .27603 Mdot
.55983 .61674 Mdot
.40056 .4036 Mdot
.58393 .36096 Mdot
.47458 .38497 Mdot
.66977 .27382 Mdot
.44925 .63873 Mdot
.6316 .64684 Mdot
.47055 .37776 Mdot
.50492 .82386 Mdot
.50125 .84699 Mdot
.55978 .3366 Mdot
.52798 .13492 Mdot
.33133 .56331 Mdot
.47657 .7707 Mdot
.25973 .69493 Mdot
.65892 .18685 Mdot
.5794 .41311 Mdot
.15013 .47252 Mdot
.44941 .60406 Mdot
.20237 .46547 Mdot
.56226 .63979 Mdot
.491 .19807 Mdot
.39975 .37164 Mdot
.30551 .36326 Mdot
.64491 .4928 Mdot
.66341 .72123 Mdot
.6014 .40724 Mdot
.58363 .60386 Mdot
.22379 .38885 Mdot
.42599 .47755 Mdot
.61667 .48013 Mdot
.46135 .23691 Mdot
.44972 .77021 Mdot
.29719 .68602 Mdot
.41462 .65582 Mdot
.31055 .50302 Mdot
.37522 .20103 Mdot
.79743 .70635 Mdot
.63745 .70383 Mdot
.63467 .59999 Mdot
.72001 .3039 Mdot
.19001 .45513 Mdot
.76811 .36627 Mdot
.27856 .73762 Mdot
.44605 .46781 Mdot
.53952 .55719 Mdot
.46619 .49654 Mdot
.30714 .56276 Mdot
.55031 .46949 Mdot
.68497 .35921 Mdot
.80966 .50432 Mdot
.75826 .50132 Mdot
.40882 .68254 Mdot
.75695 .32785 Mdot
.34686 .47188 Mdot
.79364 .48399 Mdot
.4909 .35362 Mdot
.30283 .69306 Mdot
.63988 .56388 Mdot
.50538 .84932 Mdot
.27206 .72286 Mdot
.71493 .48388 Mdot
.56672 .27314 Mdot
.14847 .56821 Mdot
.44732 .62065 Mdot
.58416 .54052 Mdot
.41427 .54006 Mdot
.5165 .51134 Mdot
.61444 .16083 Mdot
.19772 .42414 Mdot
.41295 .50896 Mdot
.30418 .73372 Mdot
.34087 .77204 Mdot
.86483 .59815 Mdot
.48469 .16841 Mdot
.59477 .64741 Mdot
.83678 .61592 Mdot
.78461 .5096 Mdot
.38356 .81795 Mdot
.73281 .39982 Mdot
.33087 .81107 Mdot
.43916 .75702 Mdot
.17726 .47677 Mdot
.38588 .65898 Mdot
.75858 .6003 Mdot
.48147 .22289 Mdot
.58218 .53265 Mdot
.69866 .323 Mdot
.29508 .29296 Mdot
.23566 .28765 Mdot
.32993 .52225 Mdot
.52594 .22929 Mdot
.67515 .64309 Mdot
.1952 .60523 Mdot
.356 .28446 Mdot
.42548 .5207 Mdot
.65098 .55231 Mdot
.73064 .699 Mdot
.42713 .45591 Mdot
.6229 .59154 Mdot
.36669 .28048 Mdot
.61746 .76502 Mdot
.38567 .46679 Mdot
.43853 .19007 Mdot
.444 .76639 Mdot
.4799 .42706 Mdot
.3662 .59949 Mdot
.62268 .68748 Mdot
.36594 .37722 Mdot
.56452 .51996 Mdot
.44519 .55608 Mdot
.58735 .33602 Mdot
.73848 .48002 Mdot
.8041 .61586 Mdot
.70064 .54977 Mdot
.42756 .20202 Mdot
.43805 .64991 Mdot
.70835 .64671 Mdot
.7616 .35473 Mdot
.82808 .57239 Mdot
.43197 .31466 Mdot
.41356 .44954 Mdot
.26122 .65064 Mdot
.41071 .81763 Mdot
.49617 .6369 Mdot
.79576 .69991 Mdot
.68083 .4509 Mdot
.27879 .6163 Mdot
.72929 .62142 Mdot
.5791 .40497 Mdot
.36636 .63371 Mdot
.17912 .4735 Mdot
.32466 .35548 Mdot
.30422 .47767 Mdot
.36024 .24891 Mdot
.53895 .54548 Mdot
.38773 .76391 Mdot
.30653 .74238 Mdot
.56116 .39286 Mdot
.38491 .2082 Mdot
.61167 .49401 Mdot
.38155 .28179 Mdot
.41226 .82059 Mdot
.62434 .79891 Mdot
.61578 .42212 Mdot
.28645 .38682 Mdot
.40733 .5585 Mdot
.41156 .18594 Mdot
.19743 .41972 Mdot
.30497 .52803 Mdot
.66194 .31406 Mdot
.59487 .68032 Mdot
.65324 .36647 Mdot
.50152 .45321 Mdot
.60901 .77564 Mdot
.60242 .68604 Mdot
.79797 .44478 Mdot
.36863 .37299 Mdot
.59054 .50298 Mdot
.48085 .61895 Mdot
.29536 .38659 Mdot
.48525 .1537 Mdot
.45923 .62685 Mdot
.205 .55214 Mdot
.44659 .78394 Mdot
.53617 .21612 Mdot
.19323 .47522 Mdot
.75285 .44625 Mdot
.77414 .5687 Mdot
.32837 .72777 Mdot
.6898 .53599 Mdot
.3675 .53139 Mdot
.508 .38149 Mdot
.59388 .61121 Mdot
.18902 .59609 Mdot
.52043 .78439 Mdot
.30775 .4197 Mdot
.42312 .42 Mdot
.61322 .58997 Mdot
.62127 .52656 Mdot
.30059 .78194 Mdot
.77125 .57798 Mdot
.36283 .41659 Mdot
.48387 .4568 Mdot
.2792 .40355 Mdot
.47661 .67868 Mdot
.61119 .81885 Mdot
.3861 .66509 Mdot
.51397 .43174 Mdot
.49082 .65308 Mdot
.3689 .25528 Mdot
.17689 .60224 Mdot
.47308 .50917 Mdot
.58947 .46354 Mdot
.35204 .32915 Mdot
.76755 .38946 Mdot
.41229 .41071 Mdot
.60498 .56887 Mdot
.47239 .35405 Mdot
.65989 .28704 Mdot
.69173 .67377 Mdot
.45505 .50933 Mdot
.27486 .48338 Mdot
.27184 .68168 Mdot
.5389 .20993 Mdot
.6576 .52534 Mdot
.67632 .40074 Mdot
.56779 .79153 Mdot
.36423 .83834 Mdot
.81636 .42347 Mdot
.41162 .56076 Mdot
.63704 .53048 Mdot
.28179 .37283 Mdot
.5782 .38 Mdot
.77318 .48187 Mdot
.77477 .427 Mdot
.66066 .44913 Mdot
.32039 .34942 Mdot
.32393 .47319 Mdot
.57058 .26555 Mdot
.26941 .35948 Mdot
.6495 .57475 Mdot
.81777 .59496 Mdot
.23482 .3251 Mdot
.19001 .45822 Mdot
.50029 .8908 Mdot
.62408 .49927 Mdot
.35023 .50101 Mdot
.41397 .70942 Mdot
.45262 .83916 Mdot
.31802 .3909 Mdot
.63937 .73841 Mdot
.73485 .36122 Mdot
.47966 .51707 Mdot
.64574 .6952 Mdot
.29026 .48198 Mdot
.65001 .36029 Mdot
.55367 .45477 Mdot
.42329 .28511 Mdot
.80589 .69362 Mdot
.36135 .73494 Mdot
.26433 .67262 Mdot
.74329 .68439 Mdot
.38311 .17937 Mdot
.44477 .8387 Mdot
.30225 .45304 Mdot
.33074 .2942 Mdot
.35839 .6755 Mdot
.62254 .43204 Mdot
.46204 .66383 Mdot
.63109 .73288 Mdot
.45509 .81018 Mdot
.47667 .25622 Mdot
.47436 .66873 Mdot
.42716 .47041 Mdot
.48957 .8154 Mdot
.5905 .46178 Mdot
.41028 .78808 Mdot
.58889 .28913 Mdot
.79917 .52299 Mdot
.52691 .61323 Mdot
.33334 .41898 Mdot
.44925 .79016 Mdot
.70043 .28826 Mdot
.26926 .31186 Mdot
.33234 .1986 Mdot
.46578 .33381 Mdot
.80737 .59509 Mdot
.45965 .57424 Mdot
.89964 .54527 Mdot
.42613 .22822 Mdot
.47943 .22754 Mdot
.36487 .24064 Mdot
.54513 .30528 Mdot
.29729 .59538 Mdot
.36685 .5317 Mdot
.22158 .55824 Mdot
.33393 .70928 Mdot
.52455 .69731 Mdot
.68294 .71315 Mdot
.31073 .35172 Mdot
.38987 .44451 Mdot
.31159 .43203 Mdot
.54941 .57565 Mdot
.59236 .6768 Mdot
.83553 .59743 Mdot
.59979 .42205 Mdot
.31332 .51984 Mdot
.50735 .59588 Mdot
.37063 .67672 Mdot
.13985 .60408 Mdot
.59755 .48725 Mdot
.30776 .51032 Mdot
.40761 .76651 Mdot
.50736 .63146 Mdot
.77291 .3738 Mdot
.72309 .80705 Mdot
.91614 .53653 Mdot
.5761 .60415 Mdot
.56053 .20256 Mdot
.39531 .76252 Mdot
.27135 .64091 Mdot
.44114 .31437 Mdot
.65069 .29941 Mdot
.28171 .5824 Mdot
.63443 .71251 Mdot
.41484 .64128 Mdot
.43073 .22241 Mdot
.53095 .85077 Mdot
.67019 .71566 Mdot
.30094 .72847 Mdot
.3173 .55197 Mdot
.43379 .63833 Mdot
.47661 .89317 Mdot
.25934 .55372 Mdot
.34441 .6067 Mdot
.42333 .6727 Mdot
.47779 .55826 Mdot
.37043 .56056 Mdot
.20353 .49051 Mdot
.24953 .2869 Mdot
.38099 .46667 Mdot
.2927 .70407 Mdot
.58893 .6904 Mdot
.58838 .3201 Mdot
.6459 .458 Mdot
.62168 .42269 Mdot
.37855 .62621 Mdot
.68163 .45702 Mdot
.5029 .51386 Mdot
.15212 .55782 Mdot
.43611 .41523 Mdot
.32074 .23626 Mdot
.39312 .83927 Mdot
.50225 .78773 Mdot
.76755 .44675 Mdot
.44929 .6188 Mdot
.29945 .69237 Mdot
.43015 .81452 Mdot
.58962 .56549 Mdot
.1808 .42233 Mdot
.78263 .2566 Mdot
.76229 .40132 Mdot
.60113 .78797 Mdot
.58393 .59572 Mdot
.45945 .38864 Mdot
.36509 .74898 Mdot
.735 .40724 Mdot
.56693 .34921 Mdot
.317 .57056 Mdot
.6173 .61247 Mdot
.69078 .45523 Mdot
.5375 .12905 Mdot
.44945 .55533 Mdot
.7785 .44689 Mdot
.35723 .79448 Mdot
.59055 .73602 Mdot
.4643 .74434 Mdot
.34902 .59443 Mdot
.69252 .61636 Mdot
.58864 .46458 Mdot
.1976 .55376 Mdot
.64417 .77905 Mdot
.26303 .62781 Mdot
.51748 .78654 Mdot
.38907 .76354 Mdot
.36698 .59865 Mdot
.42123 .35641 Mdot
.72116 .43932 Mdot
.21487 .53676 Mdot
.47938 .58274 Mdot
.44698 .84704 Mdot
.60831 .40422 Mdot
.49159 .4738 Mdot
.60619 .52362 Mdot
.85763 .60384 Mdot
.42469 .69492 Mdot
.44512 .65075 Mdot
.82632 .57697 Mdot
.60652 .39699 Mdot
.30216 .33087 Mdot
.54292 .39223 Mdot
.47294 .60098 Mdot
.62242 .67797 Mdot
.85541 .50244 Mdot
.22193 .51292 Mdot
.70575 .32567 Mdot
.66797 .32831 Mdot
.58284 .22836 Mdot
.61482 .4794 Mdot
.52162 .89246 Mdot
.43299 .24317 Mdot
.85105 .53538 Mdot
.37527 .20379 Mdot
.62665 .6295 Mdot
.23097 .34705 Mdot
.40869 .63591 Mdot
.56191 .3481 Mdot
.27212 .6614 Mdot
.32544 .51464 Mdot
.68767 .7422 Mdot
.40186 .61676 Mdot
.76322 .69357 Mdot
.34313 .35117 Mdot
.53229 .25891 Mdot
.38377 .25243 Mdot
.38301 .68561 Mdot
.24099 .68862 Mdot
.75849 .36158 Mdot
.25108 .69366 Mdot
.22661 .65107 Mdot
.32317 .76645 Mdot
.68993 .733 Mdot
.74152 .26585 Mdot
.37316 .2582 Mdot
.18261 .49174 Mdot
.69352 .38073 Mdot
.35164 .65609 Mdot
.41527 .24824 Mdot
.59804 .58791 Mdot
.7407 .53943 Mdot
.64142 .55529 Mdot
.47808 .07518 Mdot
.35535 .44313 Mdot
.49176 .62406 Mdot
.41212 .25864 Mdot
.37378 .80229 Mdot
.36866 .68128 Mdot
.30667 .28603 Mdot
.51526 .46233 Mdot
.38293 .49712 Mdot
.45851 .80941 Mdot
.5382 .20522 Mdot
.51833 .24061 Mdot
.30364 .19743 Mdot
.28198 .2904 Mdot
.68132 .30426 Mdot
.53995 .46328 Mdot
.57321 .60515 Mdot
.71613 .26739 Mdot
.42976 .28078 Mdot
.18564 .40305 Mdot
.15959 .51501 Mdot
.25773 .55007 Mdot
.39699 .15468 Mdot
.51618 .20924 Mdot
.48324 .84502 Mdot
.21897 .36882 Mdot
.57465 .60304 Mdot
.29099 .44626 Mdot
.49551 .35431 Mdot
.69604 .34302 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o0000[oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o0000Voooool001cooooo00?o0000oooo
ooooool0[?ooool2o`0009_ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;gooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`2iooooo`;o0000
0_ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0000Tooooo`;o0000S_oo
ool001cooooo00?o0000ooooooooool0Toooool2o`0000_ooooo0_l0002Wooooo`007?ooool00ol0
003oooooooooo`2Pooooo`;o00002Oooool2o`0000gooooo0_l0002=ooooo`007?ooool00ol0003o
ooooooooo`2Looooo`;o00003Oooool2o`0000Wooooo0_l00002ooooo`;o0000SOooool001cooooo
00?o0000ooooooooool0W?ooool2o`0000[ooooo0_l0000<ooooo`;o0000TOooool001cooooo00?o
0000ooooooooool0Z?ooool2o`0001cooooo0_l00002ooooo`;o0000OOooool001cooooo00?o0000
ooooooooool0ROooool2o`0003_ooooo0_l00002ooooo`;o0000OOooool001cooooo00?o0000oooo
ooooool0OOooool2o`0000[ooooo0_l0000;ooooo`;o0000/Oooool001cooooo00?o0000oooooooo
ool0OOooool2o`0001Oooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Oooooo0_l0002Rooooo`007?ooool2o`0009Cooooo0_l0
0005ooooo`Co00001oooool2o`0002cooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1[
ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`0003Oooooo0_l0
001dooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00003Oooool2o`000004ooooool0003o
0000ooooo`;o00008?ooool2o`000003ooooool0003o00000:;ooooo000Looooo`03o`000?oooooo
oooo0:;ooooo0_l000000ooooooo0000o`00000Aooooo`;o00002_ooool2o`0000Kooooo0_l0001k
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00002oooool2o`0000cooooo0_l00005oooo
o`;o00002_ooool2o`0000Kooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l0000Dooooo`;o
0000Noooool001cooooo00?o0000ooooooooool0N?ooool2o`0000Cooooo0_l0000Jooooo`;o0000
0_ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0001Cooooo0_l0001kooooo`007?oo
ool00ol0003oooooooooo`1hooooo`;o00001?ooool2o`00023ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2P
ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o0000Toooool001cooooo00?o0000oooo
ooooool0NOooool2o`0000?ooooo0_l0000Iooooo`;o00000oooool2o`0000gooooo0_l0000:oooo
o`;o0000S_ooool001cooooo00?o0000ooooooooool0N?ooool3o`0000?ooooo0_l00006ooooo`;o
00004Oooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`0008kooooo000Looooo`03o`00
0?oooooooooo07Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l00009ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l0000Looooo`;o0000
4?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07oooooo1ol000000ooooooo0000o`00
0002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
0002ooooo`;o00003Oooool2o`0000Oooooo0_l00004ooooo`?o00003oooool2o`0007Gooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1Nooooo`;o00008?ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Fooooo`Co00001oooool2o`0000Gooooo0_l0000Booooo`;o
0000L_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05kooooo0_l0000Xooooo`;o00001?ooool4
o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000002_ooool2
o`0001Sooooo0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Goooool2o`0000Oooooo0_l0000Roooo
o`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0000Oooooo0_l00004oooo
o`;o00002?ooool2o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005oooooo0_l00007ooooo`;o00003?ooool2o`0000oo
oooo0_l00003ooooo`;o00001Oooool3o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000>ooooo`;o0000P_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Kooooo
0_l00003ooooo`;o00002_ooool2o`0000[ooooo0ol0000;ooooo`;o00001oooool3o`0000Cooooo
0ol0002Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o000000Gooooo1?l0
00000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0001;ooooo0_l0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000ol0002Fooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`1Zooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00007ooooo`;o
00001?ooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000006Oooool2o`0007Wooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000@ooooo`;o00001oooool2o`0001Oooooo0_l00003ooooo`?o00001oooool2
o`0000Kooooo0_l00006ooooo`Co00001?ooool3o`0000Kooooo1?l0001iooooo`007?ooool00ol0
003oooooooooo`1Wooooo`?o00004?ooool2o`0000Gooooo1?l00002ooooo`;o00004oooool2o`00
00;ooooo1?l00006ooooo`?o00000oooool2o`0000Sooooo1Ol000001?oooooo0000o`000?ooool3
o`0000Gooooo0ol00003ooooo`;o00004Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l0000<ooooo`;o00002_ooool2o`0000Cooooo0_l00008ooooo`;o00003Oooool4o`00
00?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo0_l00004oooo
o`;o00001oooool4o`0000;ooooo1?l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000@oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0M?ooool3o`0000[ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l00006ooooo`?o00000_ooool3o`0000Co
oooo0_l00004ooooo`;o00005?ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001Co
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001oooool3o`0000?ooooo
1?l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol00007ooooo`;o0000
0_ooool3o`0000[ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001ooo
ool3o`0000Gooooo0ol0000<ooooo`Co00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000003?oo
ool4o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0007[ooooo000Looooo`03o`000?oooooo
oooo06[ooooo0_l0000;ooooo`;o00003?ooool4o`0000;ooooo0ol000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000002?ooool5o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo1?l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001ooo
ool2o`0006gooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o00007?ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`Ko00002?ooool3o`00027ooooo0_l00003
ooooo`;o00000_ooool2o`0000[ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Toooo
o`;o00002Oooool2o`0000?ooooo0_l0000@ooooo`Co00000_ooool2o`0000Cooooo0_l00004oooo
o`Co000000?oooooo`000?l000001?l0000;ooooo`;o00003oooool2o`0001Gooooo0_l0000>oooo
o`;o0000HOooool001cooooo00?o0000ooooooooool0Koooool2o`0000;ooooo0ol00006ooooo`Co
000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool4o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l0000Hooooo`;o00009_ooool2
o`00063ooooo000Looooo`03o`000?oooooooooo07?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0000?ooooo0_l00004oooo
o`Co00001Oooool2o`0000?ooooo0_l0000:ooooo`?o00005oooool2o`0000Wooooo0_l00003oooo
o`;o0000H?ooool001cooooo00?o0000ooooooooool0LOooool2o`0000;ooooo0_l00002ooooo`Co
00001_ooool3o`0001;ooooo0_l00009ooooo`;o00001?ooool5o`0000;ooooo0ol0000:ooooo`?o
00005oooool2o`0000Wooooo0_l0001Uooooo`007?ooool2o`0006Oooooo1?l00007ooooo`;o0000
0_ooool2o`0000Cooooo0_l00006ooooo`?o00001oooool2o`0001[ooooo0ol00004ooooo`;o0000
7_ooool3o`0007Kooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00000ooo
ool4o`000003ooooool0003o000000;o00002_ooool2o`0000;ooooo0ol0000Booooo`Co00001ooo
ool2o`0000kooooo0_l0000Hooooo`;o00002Oooool2o`000005ooooool0003o0000o`000?ooool0
0_l0001cooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000_ooool2o`0000?ooooo1?l0
000?ooooo`?o000000Coooooo`000?l0003o00000oooool3o`0000?ooooo0_l00004ooooo`;o0000
0oooool4o`0000Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo
0_l000000ooooooo0000o`000009ooooo`;o00000oooool4o`0000oooooo0_l0000Cooooo`;o0000
COooool001cooooo00?o0000ooooooooool0F?ooool2o`0001_ooooo1?l00005ooooo`?o000000?o
ooooo`000?l000000_l00004ooooo`;o00000_ooool5o`0000Cooooo0ol00008ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool3o`0000?ooooo1?l0
0005ooooo`Co00000oooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo07Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool4
o`00013ooooo0_l00005ooooo`?o00001_ooool2o`0000Wooooo0_l00004ooooo`?o000000?ooooo
o`000?l000001?l0000:ooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0001Gooooo0_l0000:ooooo`;o0000:Oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Kooooo1Ol0000:oooo
o`;o000000Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o000000;o00001?ooool2
o`0005[ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Eooooo`;o00002_ooool2o`00
01;ooooo0_l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000gooooo0_l00002ooooo`?o00002_ooool2o`0000Kooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`1Xooooo`;o0000:Oooool2o`0000Gooooo0_l00006ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Wooooo0_l00003ooooo`;o00004?ooool2o`000003
ooooool0003o000001Gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo1Ol0000Cooooo`;o00006Oooool2o`0000Kooooo
0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o00004?ooool2o`0000_ooooo
0_l00004ooooo`;o00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
00000ooooooo0000o`000003ooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`;o00001oooool2o`0000;ooooo1?l0000Yooooo`;o00002?ooool2o`0002Oooooo0_l0
0004ooooo`;o00002_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05kooooo0ol0000=
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo1?l00000
0ooooooo0000o`000005ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2
o`0000Sooooo0_l00008ooooo`;o00007oooool2o`0000Oooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1Gooooo`;o00001oooool8o`0000Sooooo1Ol00003ooooo`;o00000oooool2o`00
00Oooooo1?l00005ooooo`;o00003?ooool2o`0000Kooooo0_l00007ooooo`Co00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000008ooooo`;o00007oooool2o`0005_ooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00002ooooo`;o00002?ooool4o`0000Gooooo2?l00008ooooo`Co
00004_ooool2o`0001gooooo0_l00007ooooo`;o00003?ooool4o`0001?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000001_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo04Wooooo
1_l00009ooooo`Co00007oooool2o`0002?ooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo
0ol0000Eooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00002oooool6o`0000[ooooo0_l0000Aooooo`;o00004_oo
ool2o`0000[ooooo0_l00003ooooo`;o00002_ooool2o`0000gooooo0_l0000Vooooo`;o00001Ooo
ool4o`0005_ooooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`00000:
ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o00006oooool2o`0000[ooooo0_l0000<
ooooo`Co0000:?ooool2o`0001?ooooo1?l0001Kooooo`007?ooool2o`0004Sooooo0_l00004oooo
o`;o000000?oooooo`000?l000004?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00003?ooool2o`0000gooooo0_l00003ooooo`;o00001_ooool4o`0000Gooooo0_l00003oooo
o`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00006oooool2o`0000?ooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000Gooooo1_l00007ooooo`;o
00004_ooool2o`0000kooooo0_l0000<ooooo`;o00003Oooool2o`0000?ooooo0_l00007ooooo`Go
00000_ooool5o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo1Ol00003oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Kooooo0_l000000ooooooo
0000o`000006o`0000Cooooo1?l0000Rooooo`?o00001_ooool2o`00017ooooo1?l00003ooooo`;o
00001Oooool5o`0000;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`?o00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00001Oooool5o`0000?ooooo1?l0000?ooooo`;o00003?ooool2
o`0000?ooooo0ol00006ooooo`;o00003_ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool2
o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00003?ooool3o`0000Kooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00001<
ooooo`007?ooool00ol0003oooooooooo`1Booooo`Go00001?ooool2o`0000Oooooo0_l00006oooo
o`Go00000oooool2o`0000Gooooo0_l00003ooooo`;o00005oooool2o`0000Cooooo0_l00004oooo
o`;o00002?ooool2o`0000;ooooo0_l0000?ooooo`;o00005Oooool2o`0001Cooooo0ol00002oooo
o`Co0000Coooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo0_l00003ooooo`;o
00000_ooool2o`0000Kooooo1Ol00003ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o
000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00004ooooo`Oo000000?oooooo`000?l0
00001_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00006_ooool2o`0000;ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
7_ooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00000oooool2o`000003oooo
ool0003o000000Go00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l00008oooooa3o00002?ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l0000;ooooo`;o00003?ooool2o`0000;ooooo0ol00003ooooo`Go0000
0oooool3o`0000?ooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l00003ooooo`;o0000
2Oooool2o`0001;ooooo4Ol00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo
1?l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo
1?l0001Iooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000Coooooo`000?l0003o0000
1Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000006o`0000;ooooo0ol00002ooooo`;o00007OoooolAo`0000[o
oooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`So
00001oooool3o`0000[ooooo0_l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
A?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00003ooooo`;o0000
1oooool2o`0000Kooooo1?l00004oooooaGo00001?ooool2o`0000kooooo0_l00009oooooa?o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0_ooool6o`000003ooooool0003o000000Co00001oooool2o`0000?ooooo0_l00005ooooo`;o0000
1?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Go00003Oooool2o`0000Gooooo1?l00004oooooa?o00001?ooool4o`0000Kooooo
0_l00006ooooo`;o00002OoooolHo`0000Wooooo0_l0000<ooooo`Co000000?oooooo`000?l00000
0_ooool4o`0000Oooooo1?l00006ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l0000Booooo`Ko000000Coooooo`000?l0003ooooo0_l00006oooooago0000
0oooool2o`0000Cooooo0_l00007oooooaco00001Oooool2o`0000;ooooo0ol00008ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000oooooo0_l00006ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0?Oooool4o`0001_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006oooooaKo00000oooool4o`0000;ooooo0_l00005ooooo`;o00001ooooolMo`000004oooo
ool0003o0000ooooo`;o00000_ooool3o`0000Sooooo0_l00006ooooo`;o00004oooool2o`0005go
oooo000Looooo`03o`000?oooooooooo03gooooo1?l00008ooooo`;o00003Oooool2o`0001Cooooo
5_l00003ooooo`?o00000oooool2o`00013ooooo7ol00007ooooo`?o00005Oooool5o`0000Sooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00002?ooool2o`0000?ooooo0_l0
0005ooooo`;o00003?oooolMo`0000_ooooo0_l00008oooooaoo00001oooool3o`0000Kooooo0_l0
0003ooooo`;o00002?ooool5o`0006Oooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00008
ooooo`;o00002_ooool2o`0000Gooooo0_l00005oooooa_o00003Oooool2o`0000Sooooo8Ol00003
ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool3o`0000oooooo0_l00002
ooooo`;o0000Doooool001cooooo0_l00018ooooo`;o00006_ooool5o`0000Oooooo5ol000000ooo
oooo0000o`00000Eoooooago000000?oooooo`000?l000000_l00003ooooo`;o00003Oooool2o`00
00Kooooo0_l00002ooooo`Co00002Oooool4o`000003ooooool0003o000000;ooooo0_l0000:oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0Goooool9o`0000Cooooo7Ol00004ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000;ooooo9_l0000=ooooo`;o00000oooool2o`0000[o
oooo1ol00006ooooo`Co00001_ooool2o`0000Wooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`Wo00001?oooolMo`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`Go000000?oooooo`000?l000007_l00003ooooo`;o00002?ooool2o`0000oooooo
0_l00002ooooo`?o00001_ooool5o`0000Cooooo0ol00002ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0C_ooool5o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`00
0006oooooa[o00001_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo
8?l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00000oooool4o`0000Kooooo
0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o000004kooooo000Looooo`03o`000?oo
oooooooo047ooooo0ol0000:ooooo`Go000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0
0005ooooo`co000000?oooooo`000?l000002?l00008ooooo`;o00002_ooool2o`0000;ooooo3_l0
00001?oooooo0000o`000?ooool@o`0000Oooooo0_l00004ooooo`Co00002_ooool2o`0000?ooooo
1?l000000ooooooo0000o`000003ooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`;o
0000C_ooool001cooooo00?o0000ooooooooool0@Oooool3o`0000Kooooo0_l00003ooooo`;o0000
1?ooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool<o`000003oooo
ool0003o000000Wo00004oooool2o`0000;ooooo3_l000000ooooooo0000o`00000Ao`0000_ooooo
0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000_ooooo0ol00005ooooo`?o00002?ooool2o`0000Gooooo
0_l00003ooooo`Co00001Oooool2o`0000Cooooo5ol00002ooooo`;o00004ooooolLo`000004oooo
ool0003o0000o`0000?ooooo0_l00008ooooo`?o00000_ooool2o`0000Wooooo1_l0000<ooooo`Co
00001Oooool2o`0000gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
2?ooool2o`0000;ooooo0_l00005ooooo`?o00003oooool2o`0000?ooooo1?l00005ooooo`;o0000
1?oooolGo`000004ooooool0003o0000o`0001Gooooo7_l00002ooooo`?o00002Oooool2o`0000;o
oooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0?oooool2o`0001Oooooo0_l0000@ooooo`;o00001?ooool=o`000003oooo
ool0003o000000?o00000_ooool6o`0001Gooooo8_l00008ooooo`?o00002_ooool6o`0000Kooooo
0_l00008ooooo`;o00000_ooool2o`0000Cooooo0ol00002ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool09oooool2o`0001;ooooo0_l00002ooooo`;o00002?ooool2o`0000gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool4o`0000Gooooo6?l0000<ooooo`;o00000ooo
ool2o`0000;ooooo4_l00002ooooo`oo00001_ooool2o`000004ooooool0003o0000o`0000cooooo
1?l0000Dooooo`;o00001?ooool3o`0000;ooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`0Wooooo`;o00004_ooool2o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000_ooooo0_l0
0002ooooo`Go000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`0000oooooo0_l00003ooooo`;o
000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000001Go00000oooool2o`00
0003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00002?ooool2
o`0000Sooooo0_l0000:ooooo`?o0000BOooool001cooooo00?o0000ooooooooool0:?ooool2o`00
01Wooooo1?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000[ooooo0ol000001?oo
oooo0000o`000?ooool3o`0000?ooooo0ol00007ooooo`Co00000oooool5o`000003ooooool0003o
000000;o00000_ooool2o`0001?ooooo8?l00002ooooo`;o000000Coooooo`000?l0003o00000ooo
ool4o`00017ooooo0_l00008ooooo`;o00002?ooool4o`0000Kooooo1Ol00008ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0000Wooooo0ol00002ooooo`;o00001Oooool2
o`0000Cooooo1Ol00008ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2
o`000003ooooool0003o000000;o00001oooool2o`0000;ooooo0ol00003ooooo`Go00000_ooool3
o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00000_oooolF
o`0000Cooooo1?l00003ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002
o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0000;ooooo`;o0000?oooool0
01cooooo00?o0000ooooooooool0<oooool3o`0000;ooooo0ol00004ooooo`;o00001?ooool4o`00
00Kooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00;o00000oooool5o`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00002_ooool2o`00
00;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000001Go00001?ooool2o`00
00;ooooo0_l00009ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000Oooooo0_l00004
ooooo`;o00001_ooool2o`00057ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o00000ooo
ool2o`0000Gooooo0ol00007ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o00000ooo
ool2o`000003ooooool0003o000000cooooo0_l0000@ooooo`;o00004?oooolJo`0000?ooooo0ol0
0002ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000004_oo
ool3o`000003ooooool0003o0000057ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l0000;ooooo`;o00003oooool2o`0000Cooooo0ol0000?ooooo`;o
000000?oooooo`000?l000003oooool2o`0001?ooooo0_l00003oooooa?o00000oooool3o`0000;o
oooo0_l00008ooooo`;o00000oooool2o`0001cooooo0ol0001Dooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0jooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00001?ooool4o`0000gooooo0ol00002ooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`Oo
000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Oo
oooo0_l00008ooooo`;o00002_ooool2o`0000kooooo0_l0000:ooooo`;o00001Oooool2o`0003[o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo
00001oooool3o`0003Wooooo0_l00005ooooo`;o00003?ooool3o`0000;ooooo1_l0000Booooo`Go
00002oooool2o`0000?ooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`?o
00001?ooool6o`0000;ooooo1Ol00006ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`?o
00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool3o`0000Wo
oooo0_l00005ooooo`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o
00000oooool6o`0000?ooooo1ol0000Booooo`?o00003Oooool4o`0000Gooooo1?l00003ooooo`;o
00001Oooool2o`0000Gooooo0_l0000<ooooo`Co00001_ooool2o`0000;ooooo1?l00006ooooo`?o
00000oooool2o`0000kooooo0ol00009ooooo`;o000000?oooooo`000?l000002oooool2o`0000Go
oooo0_l0000=ooooo`;o0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo047ooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`Go00000_ooool2o`0000oooooo0_l0000=ooooo`Co0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001cooooo0ol0000:ooooo`;o0000
1_ooool4o`0000Cooooo0_l0000Jooooo`;o00001Oooool2o`0000Gooooo0_l0000Fooooo`;o0000
0_ooool2o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000002Oooool2o`0001_o
oooo0_l0000Mooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000_o
oooo0_l0000Oooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`;o00003?ooool2o`0000Go
oooo0_l0000Jooooo`;o0000>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00005_ooool2o`0001?ooooo0_l0000Cooooo`;o00000oooool2o`0000Gooooo0ol00006oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o0000
00gooooo0_l00009ooooo`;o00000oooool3o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Fooooo`?o00000oooool6o`0000So
oooo1Ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000_ooooo0ol0000:ooooo`;o
00000_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Gooooo`?o00000oooool2o`0000So
oooo0_l0000;ooooo`So00002Oooool2o`0000;ooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001_ooool2o`0000kooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o
00001?ooool5o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Go
oooo1Ol00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000`ooooo`;o00001Oooool2o`0000Go
oooo0_l00007ooooo`;o00003?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooo
o`Co00000_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`?o
00001Oooool2o`0000Cooooo0_l00006ooooo`Wo00001Oooool3o`0000Kooooo0_l00005ooooo`;o
00001?ooool2o`0000;ooooo0_l00007ooooo`Go00001?ooool2o`0000Kooooo0_l00002ooooo`?o
00006oooool2o`0000Oooooo0_l00002ooooo`Wo00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000>ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000?ooooo0ol00003oooo
o`Co00007Oooool2o`0002?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o
00001?ooool2o`0000_ooooo0_l00006ooooo`Wo00001oooool2o`0000cooooo0_l00006ooooo`;o
00004_ooool2o`0000Kooooo0_l00002ooooo`?o00006oooool2o`0000Oooooo0_l00002ooooo`Oo
00002oooool4o`0000oooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00002oooo
o`;o00001?ooool2o`0000Cooooo0ol0000Mooooo`;o00008oooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0000Gooooo0_l0000Nooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o
00001_ooool2o`0001;ooooo1?l00008ooooo`;o00001?ooool4o`00023ooooo0_l00009ooooo`;o
00002?ooool4o`0000Oooooo0_l00008ooooo`?o000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000003ooooo`;o00005oooool2o`000003ooooool0003o000002kooooo000Looooo`03
o`000?oooooooooo037ooooo0_l00005ooooo`;o00006Oooool2o`0000cooooo0_l00008ooooo`;o
00000_ooool3o`0000Cooooo0_l0000;ooooo`;o00001oooool4o`0000cooooo1_l000000ooooooo
0000o`000008ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Oooooo1Ol00007ooooo`;o00002Oooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooo`Ko00005Oooool2o`000003ooooool0003o000002kooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l0000Booooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo0000
o`000003ooooo`;o00001oooool3o`0000Cooooo0_l0000;ooooo`;o00001_ooool3o`0000kooooo
0_l000000ooooooo0000o`000002ooooo`;o00002?ooool4o`0000_ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`Go00004oooool3o`0000go
oooo0_l00002ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000_ooooo
0_l00004ooooo`?o00005_ooool4o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0001go
oooo1Ol0000Dooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l00007ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000ol00007ooooo`;o00001Oooool2o`0000?ooooo1Ol0000?ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l00004ooooo`;o00005oooool2o`0000?ooooo
1?l00004ooooo`?o00001?ooool2o`0000oooooo1?l00004ooooo`;o00001?ooool3o`00013ooooo
0_l000000ooooooo0000o`000004ooooo`;o00002Oooool4o`0000Kooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Wo00001Oooool3o`0000Gooooo0_l00005ooooo`?o0000
2oooool2o`0000?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00008Ooo
ool4o`0000;ooooo0_l0000=ooooo`Co00001oooool2o`0000Cooooo1?l00004ooooo`;o00001?oo
ool3o`0001Wooooo0_l00009ooooo`Co000000?oooooo`000?l000000oooool2o`0000Wooooo3_l0
0005ooooo`Go00001?ooool2o`0000Cooooo1ol00002ooooo`;o00000oooool2o`0000;ooooo0ol0
0017ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003?ooool2o`0000Sooooo1?l0000C
ooooo`;o00001oooool4o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o00004?ooool2o`0000kooooo0ol00003ooooo`?o00002?ooool@o`0000?ooooo1Ol00004
ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00000_ooool5o`0000Cooooo0_l00018
ooooo`007?ooool2o`0004?ooooo0ol0000<ooooo`;o00003oooool2o`0000Cooooo0_l0000Boooo
o`?o00001?ooool3o`0000Gooooo1?l00003ooooo`?o000000?oooooo`000?l000000_l0000@oooo
o`;o00003_ooool2o`0000Cooooo1?l00003ooooo`Oo000000?oooooo`000?l000002ol000001?oo
oooo0000o`000?l00006ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo1Ol0001>
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`0000kooooo0_l0000:oooo
o`;o00000_ooool4o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo2?l0000?ooooo`;o00002_oo
ool2o`0000;ooooo1?l00003oooooaSo00001oooool2o`0000Gooooo1?l00003ooooo`;o00001Ooo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00004?ooool2
o`0000[ooooo0ol00003ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`?o00003?ooool8o`0000oooooo0_l0000:ooooo`;o00000_oo
ool2o`0000Sooooo3ol000000ooooooo0000o`000003o`0000Oooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`Ko0000Boooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000Cooooo0ol0000Kooooo`?o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00003_ooool2
o`000003ooooool0003o0000013ooooo1?l00002ooooo`;o00000_ooool2o`00013ooooo0_l00005
ooooo`;o00000_ooool2o`0000Sooooo6Ol00005ooooo`;o000000?oooooo`000?l000002oooool6
o`0004_ooooo000Looooo`03o`000?oooooooooo02cooooo0_l00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?o00004oooool2o`0000Cooooo1?l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o0000
00;o00000_ooool3o`0001Gooooo0_l00006ooooo`?o000000?oooooo`000?l000000oooool2o`00
00Oooooo0ol00003ooooo`?o00000_ooool2o`0000Kooooo6ol00005ooooo`;o00000oooool2o`00
00;ooooo0_l00009ooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02co
oooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000co
oooo0_l00005ooooo`?o00001?ooool2o`0000gooooo1?l000000ooooooo0000o`000006ooooo`Co
000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002?ooool2o`00
00?ooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o000001[o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l00014oooo
o`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`0000Gooooo0_l0000>ooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001_ooool2o`0000?ooooo1?l00006ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`00017ooooo0_l00005ooooo`;o00004Oooool2o`000004ooooool0003o0000oooo
oa;o00000_ooool8o`000003ooooool0003o000000?ooooo1Ol00007ooooo`;o00002Oooool4o`00
04Cooooo000Looooo`03o`000?oooooooooo02gooooo1?l00003ooooo`Co00004oooool2o`0000Go
oooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l00007ooooo`;o00000oooool2o`0000Wooooo0_l00008ooooo`Co00002?ooool2o`0000?o
oooo1_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00004oooooaWo00001?ooool2o`000003
ooooool0003o000000;ooooo0_l0000Aooooo`Ko0000A?ooool001cooooo00?o0000ooooooooool0
;Oooool3o`0000Cooooo1?l00003ooooo`;o00003_ooool2o`0000Gooooo0ol0000:ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo
0_l00006ooooo`Co00002Oooool3o`0000Oooooo1?l00008ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`co0000
00?oooooo`000?l000002?l00005ooooo`;o00005Oooool4o`0004Kooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l00005ooooo`?o00000oooool2o`0001Kooooo0_l00004ooooo`;o00001?oo
ool2o`0000Sooooo1_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Kooooo1?l0
0006ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0002Cooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo6_l00007ooooo`;o00001Oooool2o`000003ooooool0003o0000057o
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`00000Cooooo`?o0000
0_ooool3o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000Wooooo1Ol00009ooooo`?o
00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000[o
oooo1?l00002ooooo`;o00004_ooool3o`0000?ooooo2_l000000ooooooo0000o`00000>o`0000Oo
oooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000D?ooool001cooooo00?o0000oooooooo
ool0<oooool2o`0000?ooooo0_l00003ooooo`Co00003?ooool3o`0000;ooooo0ol000001?oooooo
0000o`000?ooool4o`00013ooooo0_l0000:ooooo`;o00001Oooool2o`0000_ooooo1?l0000=oooo
o`;o00002_ooool4o`0000;ooooo0_l0000>ooooo`;o00002?oooolMo`0000cooooo0_l00002oooo
o`;o00001Oooool2o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00001?ooool2o`0000Oooooo1Ol00004ooooo`;o00000_ooool2o`0000?ooooo0ol00008ooooo`;o
00001?ooool2o`0000Wooooo0_l0000Dooooo`;o000000?oooooo`000?l000002?ooool4o`0000?o
oooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Ko00003Oooool5o`00
00Sooooo3?l000001Ooooooo0000o`000?l0003ooooo00co00005oooool2o`0000Kooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003o`0000Gooooo0_l00002ooooo`;o00000oooool3o`0000kooooo0ol00002oooo
o`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o00001_ooool3o`0000_ooooo1_l00003oooo
o`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000[ooooo2Ol00005
ooooo`;o00000oooool<o`000003ooooool0003o000000_o0000H_ooool001cooooo00?o0000oooo
ooooool0>?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000007Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00002oooool6o`00013ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000004o`0000?ooooo0_l00003ooooo`co000000?o
ooooo`000?l000002ol0000Booooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000Gooooo1?l00007
ooooo`;o00001?ooool2o`0001Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o00004oooool2o`0000Sooooo1?l00004ooooo`;o00003?ooool2o`000003ooooool0003o
000000Gooooo0ol00002ooooo`;o00001oooool>o`000003ooooool0003o000000Wo00004oooool2
o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o0000=_ooool001cooooo0_l0000coooo
o`;o00002oooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`0001Cooooo0_l00008oooo
o`Go00001?ooool3o`0000[ooooo0_l00002ooooo`Co00002?ooool4o`0000;ooooo0_l000000ooo
oooo0000o`000009ooooo`Co00002?ooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
oaOo000000?oooooo`000?l000003?ooool3o`0000Cooooo0_l00002ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0;?ooool2o`0002?ooooo0_l00005ooooo`;o00000_ooool2o`0000?o
oooo0_l0000;ooooo`;o00001oooool8o`000003ooooool0003o000000Co00000_ooool2o`0000Co
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo1Ol00009ooooo`Co00001Oooool3o`0000?o
oooo0_l00004ooooo`;o00001?oooolFo`0000_ooooo0_l00002ooooo`?o00000_ooool2o`0000Co
oooo0_l00004ooooo`;o00002oooool6o`0000Gooooo0_l0000/ooooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00007oooool2o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000Co`0000_o
oooo0_l00002ooooo`?o00002?ooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool3o`0000So
oooo0_l00005ooooo`;o00000ooooolAo`0000_ooooo0_l00005ooooo`Co00002_ooool2o`0000_o
oooo1_l00005ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Kooooo
1?l00003ooooo`;o00003Oooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`000003
ooooool0003o000000ko00000oooool4o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000Co
oooo0ol00005ooooo`;o00004oooool2o`0000Wooooo5?l000000ooooooo0000o`00000=ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Dooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0;oooool4o`0000Cooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00007ooooo`;o
00001_ooool2o`0000Oooooo1Ol00008ooooo`;o00002?ooool3o`0000Cooooo2Ol00003ooooo`?o
00000oooool4o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000oooool3o`00
00Cooooo0ol00004ooooo`;o00004oooool2o`0000?ooooo2Ol000000ooooooo0000o`00000;o`00
00;ooooo0_l0000<ooooo`Oo00002Oooool3o`0003kooooo000Looooo`03o`000?oooooooooo02_o
oooo1?l000001?oooooo0000o`000?l00009ooooo`?o00001Oooool2o`0000oooooo0_l0000?oooo
o`;o00003?ooool5o`0000;ooooo0ol000000ooooooo0000o`000003o`0000Gooooo0ol00008oooo
o`Ko000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00Cooooo0_l00005ooooo`;o00003Oooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002Ol00004ooooo`Go00000_ooool2o`0000Kooooo0ol00003ooooo`?o00000_ooool2o`00
00Oooooo1Ol0000nooooo`007?ooool00ol0003oooooooooo`0Yooooo`Ko000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`00
0004ooooool0003o0000ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000001Ol00004ooooo`;o00000_ooool6o`0000?ooooo2ol000000ooooooo0000o`00
000:ooooo`Co00002Oooool2o`00013ooooo0ol0000<ooooo`[o00001?ooool4o`0000Cooooo0_l0
0005ooooo`Co00002?ooool2o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`;o00001oooool2o`0000cooooo1_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000009o`000004ooooool0003o0000o`0000;ooooo2Ol00003ooooo`Go00005Ooo
ool2o`0000Wooooo0_l0000@ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`[o000000?o
ooooo`000?l000000oooool3o`0000?ooooo0_l00007ooooo`;o00002?ooool4o`0004Oooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`;o00007?ooool6o`0000;ooooo1?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Go000000?oooooo`000?l000007?l00000
1?oooooo0000o`000?l0000=ooooo`;o00001oooool2o`0000[ooooo0_l00009ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`Go000000Coooooo`000?l0003o00000_ooool8o`0000Cooooo
0_l0000Hooooo`;o00001Oooool2o`0000kooooo0_l00003ooooo`;o0000:oooool001cooooo00?o
0000ooooooooool0:oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00004_oo
ool2o`0000cooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0ol000000ooooooo0000
o`000002o`0000Cooooo7_l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o0000
2Oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00009ooooo`?o0000
1?ooool2o`0001oooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l0000[ooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00001Oooool4o`0001Sooooo0_l00007ooooo`;o00001Ooo
ool3o`000004ooooool0003o0000o`0000;ooooo2_l000000ooooooo0000o`00000=o`000003oooo
ool0003o000000Oo00000oooool5o`0000[ooooo0_l00006ooooo`;o00000oooool2o`0000gooooo
0ol0000?ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00001Oooool4o`0000[o
oooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0Yooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000Eooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003
ooooool0003o000001_o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool3o`0000?o
oooo1?l0000?ooooo`;o00000_ooool5o`000003ooooool0003o000000Co00000oooool4o`0000Oo
oooo0_l000000ooooooo0000o`000002ooooo`;o00004?ooool3o`0000Cooooo0_l00006ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000009ooooo`Ko00006?ooool2o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Jo`0000;ooooo0_l0000?ooooo`;o00003Oooool3o`000003oooo
ool0003o000000;o00005?ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo1?l00002oooo
o`;o00003Oooool2o`0000cooooo0_l0000Cooooo`;o00008Oooool001cooooo00?o0000oooooooo
ool0<?ooool2o`0000cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00005Oooool2o`00
00Oooooo9_l00002ooooo`;o00008?ooool4o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`00
00;ooooo0ol000001?oooooo0000o`000?l00007ooooo`;o00000_ooool3o`0000;ooooo0_l00000
1?oooooo0000o`000?l00006ooooo`Go00000_ooool4o`0000?ooooo0_l00002ooooo`Co00008ooo
ool2o`00027ooooo000Looooo`03o`000?oooooooooo02oooooo0ol0000?ooooo`;o00001oooool2
o`0001Gooooo0_l00007ooooo`;o000000?oooooo`000?l000009Ol0000Pooooo`;o00000oooool5
o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00001oooool2o`0000;ooooo0_l00007
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00002ooooo`?o00000_ooool4
o`0004Kooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000oooooo0_l0000:ooooobOo000000?oooooo`000?l000005?ooool2o`00
00Wooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000_ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003oooool2o`0000gooooo0_l00004ooooo`;o00009?ooool2
o`0002Oooooo000Looooo`;o0000@?ooool3o`000003ooooool0003o000000_ooooo0_l0000>oooo
o`;o00001?ooool2o`000003ooooool0003o000001go000000?oooooo`000?l000003?l000000ooo
oooo0000o`00000Aooooo`;o00002Oooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000003_ooool3o`0000?ooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l00006oooo
o`;o00005oooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03cooooo0_l000000ooooooo
0000o`00000?ooooo`?o00000_ooool2o`0000Wooooo1Ol000000ooooooo0000o`00000Go`000003
ooooool0003o0000013o00000_ooool2o`0000;ooooo0_l0000Qooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool4o`0001Gooooo0_l00004ooooo`?o00001_ooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo
0_l00009ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`Co0000
0ooooolFo`0000?ooooo3ol000000ooooooo0000o`00000Hooooo`Ko00002_ooool2o`000003oooo
ool0003o000000;ooooo1Ol00006ooooo`Go00000_ooool2o`000003ooooool0003o000000Sooooo
0_l0000Hooooo`;o000000?oooooo`000?l000001Oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo02kooooo0ol00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo1?l0
000:ooooo`;o00001Oooool6o`0000Cooooo1_l00002ooooo`Go000000?oooooo`000?l000005_l0
00000ooooooo0000o`000004o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000
o`00000>ooooo`Ko00004oooool2o`0000Oooooo1?l0000;ooooo`;o00007Oooool2o`000003oooo
ool0003o000000Gooooo0_l00006ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?oo
ool4o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`0000?ooooo2?l000000ooooooo0000o`00000To`000003ooooool0
003o000000?o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l00009ooooo`;o00001ooo
ool2o`00013ooooo0_l00006ooooo`;o00006?ooool2o`0000gooooo0_l00006ooooo`?o0000<Ooo
ool001cooooo00?o0000ooooooooool0;?ooool2o`0002Gooooo0_l000000ooooooo0000o`000005
ooooo`Go00001?ooool6o`000003ooooool0003o000000_o00000ooooolHo`000003ooooool0003o
000001?ooooo0_l00004ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo1?l00002ooooo`Co00004?ooool2o`00013ooooo1?l00006ooooo`;o00002_ooool2
o`0000Oooooo0ol0000aooooo`007?ooool00ol0003oooooooooo`0/ooooo`?o00002Oooool2o`00
01Sooooo0_l00009ooooo`?o00001_ooool3o`000003ooooool0003o000000go00000_oooolJo`00
0003ooooool0003o000000Co000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00000oooool2o`0000?ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o00000_ooool2o`0001Wooooo1?l00006ooooo`;o00002_ooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00006?ooool2o`00
00[ooooo0_l00003ooooo`?o00001Oooool<o`0000;ooooo5ol000000ooooooo0000o`000009o`00
0003ooooool0003o000001Kooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo0ol00005oooo
o`;o00000_ooool2o`0001Oooooo1_l0000?ooooo`;o00003Oooool2o`0002oooooo000Looooo`03
o`000?oooooooooo053ooooo0_l0000<ooooo`;o00000oooool6o`0000;ooooo;Ol00005ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00007Oooool3o`0000Oooooo1?l0000Hooooo`;o
00004oooool4o`000003ooooool0003o000000Sooooo0_l0000_ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`So000000?oooooo`000?l00000
5ol000000ooooooo0000o`00000<o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`0000;ooooo1?l00009ooooo`;o00003?ooool3o`0000Oooooo
1?l0000Hooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo1?l000000ooooooo0000
o`000006ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0
003o000000_ooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo3Ol000000ooooooo0000o`00
000Po`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool4o`0000Oooooo1?l0000=ooooo`;o00004Oooool2o`0000Oooooo1Ol00004ooooo`Go00000ooo
ool2o`0000?ooooo0_l00004ooooo`Ko00002Oooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001_ooool2o`0000gooooo0_l00000
0ooooooo0000o`00000Fo`000003ooooool0003o0000017o00000_ooool2o`0000Oooooo0_l00007
ooooo`Co000000?oooooo`000?l000003?ooool3o`0001Oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o00001oooool5o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000Wooooo
0_l00002ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0:Oooool2o`00013ooooo0_l0
000Cooooo`;o00001_ooool3o`0000cooooo8ol000000ooooooo0000o`000005o`000004ooooool0
003o0000o`0000;ooooo0_l0000Aooooo`?o00001_ooool2o`0000Oooooo0ol0000Gooooo`;o0000
1Oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
:Oooool2o`0000Kooooo0_l00008ooooo`;o00003oooool2o`0000_ooooo0_l000001?oooooo0000
o`000?ooool4o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000Jo`000003
ooooool0003o000000Oo000000Coooooo`000?l0003o00000oooool4o`0000?ooooo0_l00007oooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00001_ooool2o`0000gooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00003oooo
o`;o0000=Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo037ooooo0ol0000@ooooo`?o00001Ooo
ool2o`0000kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1?l0
00000ooooooo0000o`00000So`0000Gooooo1_l00003ooooo`Co00001Oooool2o`000005ooooool0
003o0000o`000?ooool00_l00004ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000;o
oooo1?l00003ooooo`;o00001_ooool2o`0000gooooo0_l00009ooooo`Go00001_ooool2o`0000So
oooo0_l00006ooooo`;o00000oooool2o`0003Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0U
ooooo`;o00002oooool2o`0000Cooooo1?l00008ooooo`?o00005_ooool2o`0000Cooooo0ol00002
ooooo`Co000000?oooooo`000?l000008_l00006ooooo`;o00002?ooool3o`0000Kooooo1Ol00003
ooooo`;o00000_ooool2o`0000;ooooo1Ol00008ooooo`;o00001Oooool2o`0000Sooooo0_l00003
ooooo`;o00004?ooool6o`0000gooooo0_l00002ooooo`;o00003?ooool2o`0003?ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo02Gooooo0_l0000@ooooo`Go00002?ooool2o`0000Kooooo0_l00006
ooooo`;o00001oooool2o`0000Cooooo0ol00002ooooo`;o00001?oooolTo`0000oooooo0_l00002
ooooo`;o00000oooool3o`0000?ooooo4Ol00009ooooo`?o000000?oooooo`000?l000002?ooool3
o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo1?l0000;ooooo`;o00000_ooool2
o`0000Cooooo0_l00006ooooo`?o0000<_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000fooooo`?o00003_ooool2
o`0000?ooooo1?l00004ooooo`;o00001Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002
ooooobOo000000Coooooo`000?l0003ooooo1Ol0000:ooooo`;o00002?ooool;o`000005ooooool0
003o0000o`000?ooool00_l00008ooooo`Co00000oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00009ooooo`;o00003Oooool4o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Zooooo`;o00002_ooool4o`0000;o
oooo0_l00009ooooo`;o00001?ooool4o`0000?ooooo0_l00005ooooo`?o00002Ooooolfo`0000Oo
oooo0_l00007ooooo`Co000000?oooooo`000?l000003ol00002ooooo`;o00000_ooool2o`0000Go
oooo1_l0000>ooooo`;o00003oooool2o`0000;ooooo0ol0000Gooooo`;o0000=?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo02[ooooo0_l0000;ooooo`?o00000_ooool2o`0000oooooo1?l00003ooooo`;o0000
1oooool2o`0000[ooooo2ol00002oooooago000000?oooooo`000?l000000_l00003ooooo`;o0000
1_ooool3o`0000Gooooo6Ol000000ooooooo0000o`000003o`0000Sooooo0ol0000<ooooo`;o0000
5oooool2o`0000Wooooo0_l0000<ooooo`;o0000=?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o
00004_ooool2o`0000;ooooo1?l00005ooooo`Ko000000?oooooo`000?l000006_l000000ooooooo
0000o`000003o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0ol00002ooooo`Ko
000000?oooooo`000?l000002ol000000ooooooo0000o`000005o`0000?ooooo0_l0000:ooooo`;o
00000_ooool4o`0000;ooooo0_l0000Booooo`Co00000_ooool2o`0000Cooooo0_l0000>ooooo`;o
0000<_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`?o00003?ooool2o`0000Kooooo0_l0000>
ooooo`Ko00001?ooool>o`000003ooooool0003o000001;o00002?ooool2o`0000?ooooo1?l00007
ooooo`?o000000Coooooo`000?l0003o00000_oooolHo`000003ooooool0003o000000;o00000ooo
ool2o`0000[ooooo0_l00002ooooo`?o00000oooool3o`0000_ooooo0_l00004ooooo`Co00000_oo
ool4o`0000;ooooo0_l0000>ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0000?ooooo0_l00005ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`Co00002_oo
ool2o`0000?ooooo2Ol00003ooooo`?o000000Coooooo`000?l0003ooooo3_l000000ooooooo0000
o`000002o`0000;ooooo2?l000000ooooooo0000o`000002o`0000Oooooo0ol000000ooooooo0000
o`000003ooooo`oo000000?oooooo`000?l000001Ol00002ooooo`;o00001oooool2o`0000Wooooo
1_l00004ooooo`;o00002oooool2o`0000cooooo0_l00009ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000oooooo1_l00005ooooo`Co000000Coooooo`000?l0003ooooo
2Ol000000ooooooo0000o`000007o`0000;ooooo2Ol000000ooooooo0000o`000007ooooo`Co0000
0_ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000001Ol0000;ooooo`;o0000
2Oooool5o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00006_ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`;o00001_ooool2o`0000;ooooo
0ol0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool5o`000004oooo
ool0003o0000ooooo`_o00000_ooool=o`000004ooooool0003o0000ooooo`;o00001oooool2o`00
00Cooooo7Ol0000=ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000004o`00
00Kooooo0_l0000Looooo`;o0000<Oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000_o
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool4o`000003
ooooool0003o000000Oo000000Goooooo`000?l0003o0000ooooo`07o`0000;ooooo1ol000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000003?oooolNo`0000;ooooo0_l00009oooo
o`;o00000oooool2o`00013ooooo1?l00007ooooo`?o00000_ooool2o`0001Sooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`0000Sooooo0_l0000Dooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000:o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000001Oooool4o`0000Wooooo0_l00003ooooo`ko000000?oooooo`000?l0
00004Ol00005ooooo`Co00005oooool2o`0000;ooooo1?l00003ooooo`;o00000oooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
5?ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000004ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00003ooooo`Go00001?ooool4o`0000;ooooo1?l00005ooooo`;o
00000_ooool2o`0000;ooooo8Ol00007ooooo`Co00006oooool4o`0000?ooooo0_l0000Dooooo`;o
000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000004ooooo`?o0000
0_ooool2o`0000Kooooo1Ol00004ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000;o
oooo0_l00006ooooo`Go000000?oooooo`000?l000006?l00009ooooo`;o00000_ooool2o`0003Go
oooo0_l000000ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
1?ooool2o`0000cooooo0_l0000;ooooo`Oo00000oooool2o`0000;ooooo0_l00004ooooo`?o0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0oooool3o`0000?ooooo0_l0000:ooooo`Co00000_oooolDo`0000;ooooo1?l00005ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2o`000003oooo
ool0003o000001oooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002ooo
ool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0
0003ooooo`Ko00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o00003ooo
oolPo`0000Gooooo0_l00008ooooo`?o00001?ooool2o`0000Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000007_ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o00005_ooool2o`0000Kooooo0ol00004
ooooo`;o00000oooool2o`0000;ooooo1Ol00009ooooo`;o00002?ooool2o`0000;ooooo0_l00002
ooooo`Oo000000?oooooo`000?l000005?l0000>ooooo`?o00001?ooool2o`000003ooooool0003o
000001Gooooo0_l00009ooooo`;o00002Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l0000Yooooo`Co000000?oooooo`00
0?l000001Oooool3o`0000;ooooo1_l00008ooooo`;o00001oooool7o`0000?ooooo7_l00004oooo
o`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o00005Oooool2o`0000Wooooo0_l00013oooo
o`007?ooool2o`0004Kooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000Pooooo`;o
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l0
00004Oooool2o`000003ooooool0003o000000;o00000oooool7o`000003ooooool0003o000001Co
00001?ooool2o`0000Gooooo0_l00002ooooo`;o00006oooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo04Cooooo1?l00009ooooo`;o00000oooool2o`0000Sooooo0_l0000>ooooo`;o0000
1_ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool4o`0000Cooooo0_l00007ooooo`;o0000
3ooooolLo`0002kooooo0_l00004ooooo`;o00002?ooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo1?l0000<ooooo`Co000000?o
ooooo`000?l000001Oooool2o`0000Kooooo0ol00002ooooo`;o00002_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000>oooooa?o000000?oooooo`000?l000001ol0000Wooooo`;o00002ooo
ool2o`0000Sooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000oooool9
o`0000Gooooo0_l0000>ooooo`?o00000_ooool5o`0000;ooooo0_l00006ooooo`;o00005Oooool2
o`0000Wooooo0ol00003oooooaWo000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00004ooo
ool2o`0000Cooooo0_l00004ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0AOooool2
o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000gooooo0_l00009ooooo`;o00000_ooool9
o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`00013ooooo0ol00003ooooo`?o00000ooooolH
o`0000;ooooo0_l00003ooooo`;o00004oooool8o`0005gooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00005ooooo`;o00005_ooool2o`0000gooooo0_l00003ooooo`Co00001_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l00004ooooo`;o00004_ooool3o`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Eo`0000;ooooo0_l0000J
ooooo`Co00001?ooool2o`0000Gooooo0_l00008ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0C?ooool2o`00027ooooo0_l0000Dooooo`Ko000000?oooooo`000?l000002?ooool2o`00
00Wooooo0_l00003ooooo`?o00001OoooolIo`000003ooooool0003o000001gooooo0_l00003oooo
o`Co00001Oooool3o`0000Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o
00000_ooool2o`0000;ooooo1?l00007ooooo`Co00002_ooool2o`0000Kooooo0_l00002ooooo`;o
00002Oooool2o`000003ooooool0003o000000_ooooo0_l00009ooooo`;o00003?ooool3o`000003
ooooool0003o000001Go00004_ooool3o`0000Oooooo0ol00003ooooo`Co00001_ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`Co000000?oooooo`000?l00000
0_ooool4o`0000Oooooo1?l0000<ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o00001_ooool2o`0000;ooooo
6Ol0000Booooo`?o00001_ooool3o`0000Kooooo0_l00003ooooo`;o0000E?ooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000Gooooo1?l0000Hooooo`;o00001_ooool2o`0000;ooooo1?l0
0003ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000Kooooo0_l0
000<ooooo`?o00001Oooool2o`0000;ooooo7?l000000ooooooo0000o`00000@ooooo`;o000000?o
ooooo`000?l000000_l0000<ooooo`Co0000D_ooool001cooooo00?o0000ooooooooool0EOooool2
o`0001;ooooo0_l00009ooooo`Co00001?ooool2o`0000?ooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1_l00008ooooo`Co000000?oooooo`000?l000000ooooolC
o`000003ooooool0003o000000[ooooo0ol00003ooooo`Go00002?ooool2o`000003ooooool0003o
000000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`00
00Kooooo0_l0000Dooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Goooo
o`;o00000_ooool8o`0000Sooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo2Ol00000
0ooooooo0000o`000004ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0ol00003
ooooo`Co000000?oooooo`000?l000001_ooool5o`0000Sooooo0_l0001=ooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00005?ooool4o`00
00;ooooo0_l00006ooooo`;o00001Oooool2o`0001Kooooo0_l0000<ooooo`;o00000_ooool2o`00
00?ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00000_ooool2o`00
00;ooooo0_l00006ooooo`Go00001?ooool2o`000003ooooool0003o000000;o00000_ooool3o`00
00Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000oooooooo
ool0Boooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000001;o
oooo0_l0000Aooooo`;o00001Oooool2o`00027ooooo0_l00003ooooo`;o00000_ooool3o`0000Go
oooo1Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`Co0000C_ooool001cooooo
00?o0000ooooooooool0C_ooool2o`000003ooooool0003o000000_ooooo1Ol0000:ooooo`;o0000
2?ooool2o`0000Wooooo0_l00002ooooo`?o00001_ooool2o`0001cooooo0_l0000=ooooo`Ko0000
00Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o
00001?ooool3o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l000000ooooooo0000o`00000<ooooo`?o00002oooool2o`0000Sooooo
0_l00003ooooo`;o00000_ooool4o`0000;ooooo0ol0000Jooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00001oooool6o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000
o`000006ooooo`?o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo
0_l0000<ooooo`;o0000AOooool001cooooo0_l0001Qooooo`;o00004Oooool2o`0000Oooooo0_l0
0002ooooo`;o00001?ooool2o`0000cooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o00002Oooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0000?ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000oooool2o`0000kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001?ooool2o`0000Sooooo0ol00008ooooo`;o00002oooool4o`0000oooooo0_l00009
ooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2
o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Gooooo0_l00008
ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`00
00Sooooo1?l0000;ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`00
00kooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool3o`000003ooooool0003o0000
02;ooooo0_l00008ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000[o
oooo0_l00006ooooo`Co00000_ooool4o`0000Wooooo1?l0000Hooooo`;o00001Oooool3o`00023o
oooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0002Go
oooo0_l000000ooooooo0000o`000005ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000Sooooo0_l00002ooooo`Co00002oooool2o`0001Cooooo0_l00002ooooo`;o0000
1Oooool2o`0000Oooooo0_l00006ooooo`;o00004?ooool2o`0000;ooooo1?l00009ooooo`;o0000
0oooool2o`0000Gooooo0_l0000>ooooo`;o00006_ooool2o`0000Gooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`1Eooooo`;o00008?ooool2o`0000Kooooo0_l0000Booooo`;o00001_oo
ool2o`0001Cooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`?o00001?oo
ool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo1?l0001Eooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00002?ooool2o`0000_ooooo0_l0000<ooooo`;o00001Oooool2
o`0003[ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0ol00004
ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co00000oooool2
o`00053ooooo000Looooo`03o`000?oooooooooo04_ooooo1?l00004ooooo`Co00002oooool2o`00
00cooooo0_l0000:ooooo`;o00006oooool4o`00017ooooo0_l00003ooooo`;o00002?ooool2o`00
00;ooooo0_l0000Aooooo`;o00001_ooool3o`0000;ooooo1?l00002ooooo`;o00003_ooool4o`00
04kooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`Co00005Oooool2o`0000Co
oooo0_l00008ooooo`;o00001?ooool2o`0001Gooooo1?l0000Aooooo`;o00000oooool2o`0000;o
oooo0_l00004ooooo`;o00005Oooool2o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`00013o
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001?ooool2o`0000Oooooo
0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o0000;oooool2o`0000;ooooo
0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo
0ol00004ooooo`;o00002_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
0004ooooo`Co00001?ooool2o`0000Oooooo0_l0000Aooooo`;o00003Oooool2o`0000cooooo0_l0
000Jooooo`;o00002Oooool3o`0000Gooooo1Ol000000ooooooo0000o`000003ooooo`?o00000_oo
ool2o`0000Oooooo1Ol00004ooooo`?o00002Oooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00004ooooo`Go00001?ooool2o`0000;ooooo0_l0000=ooooo`Co00001oooool2
o`0000?ooooo0_l00005ooooo`;o00002oooool3o`000003ooooool0003o000001oooooo1Ol00002
ooooo`;o00000_ooool5o`0000Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o
000000Sooooo0_l00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Eoooool4o`00
00Cooooo0_l00002ooooo`Ko00002Oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
013ooooo1?l00002ooooo`;o00007oooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`00
00Wooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00001_ooool4o`0000[ooooo1?l00006ooooo`;o00002?ooool2o`0001Wo
oooo0_l0000Uooooo`;o00003_ooool3o`0000Wooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000000_ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co0000
1_ooool2o`0000?ooooo1?l0000=ooooo`;o00005Oooool2o`0000_ooooo0_l00003ooooo`Co0000
6?ooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool3o`0000Kooooo0_l00006ooooo`;o0000
1_ooool2o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001ooo
ool2o`0000;ooooo1?l00002ooooo`?o00002?ooool2o`0001Gooooo0ol0000:ooooo`;o00000ooo
ool4o`0000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo1?l0
0003ooooo`Go00001?ooool2o`0000Cooooo0_l0000:ooooo`;o0000Foooool001cooooo0_l0001B
ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`?o00002_ooool4o`000004ooooool0003o
0000ooooo`?o00002oooool2o`0000oooooo0_l00004ooooo`;o00005oooool2o`00017ooooo1?l0
0003ooooo`;o00001oooool2o`0000Cooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00003?ooool2o`0000kooooo1_l000001?oooooo0000o`000?ooool3o`00017ooooo0_l0
0009ooooo`?o0000<_ooool3o`0000Kooooo0_l00008ooooo`;o0000Ioooool001cooooo00?o0000
ooooooooool0Boooool2o`0000kooooo0ol000000ooooooo0000o`00000>ooooo`;o000000?ooooo
o`000?l000001Oooool2o`000003ooooool0003o000000cooooo1Ol0000:ooooo`;o000000?ooooo
o`000?l00000;oooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l0000>ooooo`?o000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l000000ooooooo0000o`00000;ooooo`Co00003oooool2o`0001[ooooo0_l0000<oooo
o`;o00004oooool2o`0000Kooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
00003?ooool2o`0000;ooooo0_l0000;ooooo`Co00002?ooool2o`000003ooooool0003o000000;o
00002_ooool2o`00017ooooo0_l0000Jooooo`;o00003?ooool2o`0000Sooooo0_l00003ooooo`;o
00001?ooool2o`0000Kooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
3oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
1ol00002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0001_ooooo
0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o0000
3Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05kooooo0ol00002ooooo`Co000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001gooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1C
ooooo`Co00002?ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002?oo
ool2o`0001Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o0000
7Oooool2o`0000Kooooo1?l0001booooo`007?ooool00ol0003oooooooooo`1Cooooo`Co00002?oo
ool2o`0000[ooooo0ol00008ooooo`;o00004?ooool2o`0000Cooooo0_l00007ooooo`;o00003Ooo
ool2o`0000Cooooo0_l0000Dooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Go0000L_oo
ool001cooooo00?o0000ooooooooool0Goooool2o`0001;ooooo0_l00004ooooo`;o00003Oooool2
o`0000_ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001_ooool2o`0000oooooo0_l00003
ooooo`;o00001?ooool3o`0000;ooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o00002Oooool2o`0000Cooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Kooooo0_l00002oooo
o`?o00000_ooool2o`0000Oooooo0_l00008ooooo`?o0000NOooool001cooooo00?o0000oooooooo
ool0Eoooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00004ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooo
o`;o00001Oooool2o`0000_ooooo1?l00007ooooo`;o00000oooool3o`0000;ooooo0_l00007oooo
o`;o00001?ooool3o`0007gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000<ooooo`;o
00004?ooool3o`0000Sooooo0_l00006ooooo`Go00000_ooool2o`0000cooooo0_l00003ooooo`Go
00001_ooool3o`0000gooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`;o
0000L_ooool001cooooo00?o0000ooooooooool0IOooool2o`0001;ooooo0_l00005ooooo`Co0000
1oooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l00004ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Gooooo0ol000000ooooooo0000o`00001booooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0L?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Wooooo0_l00000
0ooooooo0000o`00000Booooo`;o00004Oooool2o`0000Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000oooool4o`0000Cooooo0_l0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
L?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000Wooooo`Go0000
1?ooool2o`0000Kooooo0_l00003ooooo`Co0000Noooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
N?ooool4o`0003Sooooo1Ol00004ooooo`;o000000?oooooo`000?l000000oooool4o`00083ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000MOooool6o`0000Wooooo0_l0000;ooooo`;o00005_ooool2o`0000Sooooo
1Ol00003ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0MOooool4o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo
0_l0000@ooooo`Co00002?ooool2o`000003ooooool0003o000000;ooooo1_l00005ooooo`;o0000
2_ooool2o`0007Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l00002ooooo`Co0000
3_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000@ooooo`;o00003Oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l00005ooooo`;o00008?ooool2o`00063ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000Aooooo`Co000000?oooooo`000?l000000ol0000;ooooo`Co00003Oooool2
o`0000;ooooo0_l00010ooooo`;o0000H?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0J?ooool2o`0000cooooo
0_l00008ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00004ooooo`;o0000
0_ooool2o`00027ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1dooooo`Co000000?o
ooooo`000?l000001oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Wooooo
0_l0000>ooooo`Co000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000ooooo`;o
00000oooool2o`0000?ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1dooooo`;o0000
0oooool2o`0000Oooooo1?l0000?ooooo`;o00002Oooool2o`0000Wooooo1?l000000ooooooo0000
o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000Q?ooool001cooooo
00?o0000ooooooooool0P_ooool4o`0000oooooo0_l00009ooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0O?ooool2o`0000Kooooo0_l0000>ooooo`;o00002_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Oooooo0ol0002=ooooo`007?ooool00ol0003oooooooooo`1l
ooooo`Co00005?ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo1Ol00004
ooooo`?o0000SOooool001cooooo00?o0000ooooooooool0O_ooool2o`0001oooooo0_l0000Aoooo
o`?o000000?oooooo`000?l00000TOooool001cooooo00?o0000ooooooooool0UOooool2o`0000?o
oooo1?l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`00097ooooo000Looooo`03o`00
0?oooooooooo07?ooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo1?l00002ooooo`Co0000
0oooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000Woooool001cooooo00?o
0000ooooooooool0Loooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l0
000Cooooo`;o0000Woooool001cooooo00?o0000ooooooooool0T_ooool2o`0000Gooooo0_l0002^
ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00000oooool2o`0000Gooooo0_l00004oooo
o`?o0000Yoooool001cooooo0_l0002>ooooo`;o00004?ooool3o`0000Oooooo0ol0002Mooooo`00
7?ooool00ol0003oooooooooo`2Sooooo`;o00001?ooool3o`0009gooooo000Looooo`03o`000?oo
oooooooo09gooooo0_l00004ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Voooool4
o`000:[ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000>?ooool2
o`0007Sooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0000hooooo`;o0000N?ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Qoooool2
o`0001Kooooo0_l00005ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0Qoooool2o`00
00kooooo0_l00006ooooo`;o00001Oooool2o`000:7ooooo000Looooo`03o`000?oooooooooo09Oo
oooo0_l0002`ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooo
oooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomD
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00:;ooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0R_ooool00:;ooooo00Go0000oooooooooooo
ooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool0
0:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000008cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
6Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100S?ooool00<;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg08cooooo0030ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}]
}, Closed]],

Cell[BoxData[
    \({18966.5`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["(f) ",
    FontWeight->"Bold"],
  StyleBox["Vortices with opposite signs",
    FontSlant->"Italic"],
  ". One big difference between fluids and self-gravitating systems is that \
fluid vorticity can be both positive and negative, whereas mass density is \
always positive (so far as we know!). Vortices with opposite signs act in \
qualitatively different ways than like-sign vortices. "
}], "Text"],

Cell[TextData[{
  "\t\t(i) Modify the fluid code to handle ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " point vortices, each with arbitrary circulation ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Gamma]\_i\), ",", " ", \(i = 1\), ",", "...", ",", 
          RowBox[{"N", ".", Cell[""]}]}], TraditionalForm]]],
  " (Hint: Define a list ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " whose elements are the circulation of each point vortex.) "
}], "Text"],

Cell[TextData[{
  "\t\t(ii) Analytically determine the dynamics of two isolated point \
vortices with circulations of opposite signs ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Gamma]\)\)]],
  ", separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t\t(iii) Test the code by running an initial condition with ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2\)]],
  " opposite-signed point vortices separated by ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.3\)]],
  ". Compare to the analytics."
}], "Text"],

Cell["\<\
\t\t(iv) Investigate the dynamics of extended regions of vorticity \
with overall zero circulation:\
\>", "Text"],

Cell[TextData[{
  "\t\t\t(A) ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2000\)]],
  " point vorticies randomly distributed in the cell, of which half have one \
sign of circulation, the other half the opposite sign."
}], "Text"],

Cell[TextData[{
  "\t\t\t(B) Create an initial condition consisting of two opposite-signed \
uniform circular vortex patches of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.1\)]],
  ", with centers separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.25\)]],
  ".  Take ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " (500 in each patch),  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = \ \(\[PlusMinus]2\)/N\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ".  (This run requires fine resolution; take ",
  Cell[BoxData[
      \(TraditionalForm\`M > 30\)]],
  "). Do the vortices merge, as they did when they had the same sign of \
vorticity?"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  StyleBox[" SIMULATION PROJECT: PLASMA WAVES. ",
    FontSlant->"Italic"],
  "If one changes the sign of the interaction potential in Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>"(7.3.2)",
    ButtonStyle->"Hyperlink"],
  ", setting ",
  Cell[BoxData[
      \(TraditionalForm\`G = \(-q\^2\)/\((4\ \[Pi]\ m\ \[Epsilon]\_o)\)\)]],
  ", the equations of gravitational dynamics now describe a collection of \
like charges, with charge ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", interacting via the repulsive Coulomb potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " through a mean-field interparticle force ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Del]\[Phi]\)\)]],
  ". This collection of charges is called a ",
  StyleBox["one component plasma",
    FontSlant->"Italic"],
  ", since there is only a single charge species present. "
}], "Text",
  CellTags->"i:92"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Perform this substitution, and show in a simulation of ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  "charges with zero initial velocities and random initial conditions that \
the system is now stable. Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20, \ 
      m = \(q = 1\)\ , \ \ \[Epsilon]\_0 = \((4  \[Pi])\)\^\(-1\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 0.003\)]],
  "and run for 60 steps. Plot the particle positions in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane as an animation. The oscillations one can see here are called ",
  StyleBox["plasma waves",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " We will study the behavior of these plasma oscillations as we vary the \
plasma temperature. First, we will set up an initial condition consisting of \
a single sinusoidal density oscillation with amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`A\_0\)]],
  ". This is done using the rejection method, discussed in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(A0 = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(w[y_]\  = \ 1\  + \ A0\ Cos[2\ Pi\ y];\)\[IndentingNewLine]\), "\n", 
    \(\(sx[]\  := \ Random[Real, {0, 1}];\)\), "\n", 
    \(\(sy[]\  := \ Random[Real, {0, 1.5}];\)\[IndentingNewLine]\), "\n", 
    \(s[]\  := \((xx = sx[]; \ \ While[sy[]\  > \ w[xx], \ \ xx = sx[]]; 
        xx)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.96"],

Cell[TextData[{
  "Positions of the particles can now be obtained using the random variable  \
",
  StyleBox["s[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Take as the initial positions "
}], "Text"],

Cell[BoxData[
    \(r0\  = \ Table[{Random[], s[]}, {1000}]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.97"],

Cell[TextData[{
  "and run the simulation for the same parameters as in part a), wtih zero \
initial velocity and with ",
  Cell[BoxData[
      \(TraditionalForm\`A\_0 = 0.25\)]],
  ". One should see a single well-behaved density oscillation. \n\tDetermine \
the amplitude of the ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2\ \[Pi]\ y)\)]],
  " oscillation by defining"
}], "Text"],

Cell[BoxData[
    \(\(\(amp[n_]\)\(\ \)\(:=\)\(\ \)\(Sum[
        Cos[2\ Pi\ \(r[n]\)[\([\)\(m, 2\)\(]\)]], {m, 1, 
          1000}]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.98"],

Cell[TextData[{
  "This function takes the projection of the density onto ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2\ \[Pi]\ y)\)]],
  ", and is equivalent to ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(amp(t)\), "=", 
          RowBox[{"\[Integral]", 
            RowBox[{
              RowBox[{"n", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              " ", \(cos(2  \[Pi]\ y)\), \(\[DifferentialD]\^2 r\)}]}]}], 
        TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is the number density.\n\tPlot this function versus ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " and from this graph estimate the period of the plasma oscillation."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Using the linearized fluid equations ",
  ButtonBox["(7.3.13)",
    ButtonData:>"(7.3.13)",
    ButtonStyle->"Hyperlink"],
  ", determine the frequency of small-amplitude oscillations versus \
wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". Show that  the oscillation frequency is"
}], "Text",
  CellTags->"i:90"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \(c\^\(\(2\)\(\ \)\)\) 
            k\^2 + \[Omega]\_p\^2\)]],
  ", "
}], "NE3"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the sound speed, as in Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>"(7.3.14)",
    ButtonStyle->"Hyperlink"],
  ",  and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Omega]\_p\)\(=\)\(\@\(\(q\^2\) 
              n/m\ \[Epsilon]\_o\)\)\(\ \)\)\)]],
  " is the ",
  StyleBox["plasma frequency",
    FontSlant->"Italic"],
  " . Evaluate this frequency for the parameters of part (b) and compare to \
the observed period of oscillation. "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Increase the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " of the simulation, and repeat part (b) five times, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\@T = 1, \ 2, 5, 7, 10\)]],
  ". Choose momenta distributed according to a Gaussian distribution using \
the following rejection method algorithm, discussed in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(wv[x_]\  := \ Exp[\(-x^2\)/\((2\ T)\)\ ]/Sqrt[2\ T\ Pi\ ]; \), "\n", 
    \(aa := \(-5\)\ Sqrt[T]; bb = 5\ Sqrt[T]; \), "\n", 
    \(f00\  := \ 1/Sqrt[2\ T\ Pi]; \)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.99"],

Cell[BoxData[{
    \(\(svx[]\  := \ Random[Real, {aa, bb}];\)\), "\n", 
    \(\(svy[]\  := \ Random[Real, {0, f00}];\)\), "\n", 
    \(sp[]\  := \((xx = svx[]; \ \ While[svy[]\  > \ wv[xx], \ \ xx = svx[]]; 
        xx)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.100"],

Cell[BoxData[
    \(p0 = \ Table[{sp[], sp[]}, {1000}]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.101"],

Cell[TextData[{
  "For each temperature, determine the oscillation frequency from the \
simulation. Plot this data versus ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and compare to the prediction of Eq. ",
  ButtonBox["(7.3.26)",
    ButtonData:>"(7.3.26)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 3\)]],
  " (the value for a one-dimensional ideal adiabatic process), and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o = n\ \ T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNote that for the largest temperatures, the oscillation amplitude damps \
away rapidly with time. This is a phase-mixing process called",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Landau",
    ButtonData:>{
      URL[ 
      "http://turnbull.dcs.st-and.ac.uk/~history/Mathematicians/Landau_Lev.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" damping",
    FontSlant->"Italic"],
  ". The process is similar to the phase-mixing observed previously in the \
collisionless Boltzmann equation, in Sec. ",
  ButtonBox["7.1.2",
    ButtonData:>"c:9",
    ButtonStyle->"Hyperlink"],
  ".  It can be understood analytically by solving the linearized \
collisionless Boltzmann equation as an initial-value problem, using methods \
similar to those in Exercise (3).  For more information see ",
  ButtonBox["Birdsall and Langdon (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ", or ",
  ButtonBox["Stix (1962)",
    ButtonData:>{"Chapter5.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  " (in the references for Chapter 5)."
}], "Text",
  CellTags->"i:91"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"refs", "c:41"}],

Cell[TextData[{
  "T. B. Benjamin, ",
  StyleBox["Instability of periodic wavetrains in nonlinear dispersive \
systems",
    FontSlant->"Italic"],
  ", Proc.  R. Soc. London Ser. A ",
  StyleBox["299",
    FontWeight->"Bold"],
  ", 59 (1967)."
}], "Text"],

Cell[TextData[{
  "J. Binney and S. Tremaine, ",
  StyleBox["Galactic Dynamics",
    FontSlant->"Italic"],
  " (Princeton University Press, Princeton, NJ, 1987)"
}], "Text"],

Cell[TextData[{
  "C.K. Birdsall and A. B. Langdon, ",
  StyleBox["Plasma Physics via Computer Simulation",
    FontSlant->"Italic"],
  " (Adam Hilger, Bristol,  1991)"
}], "Text"],

Cell[TextData[{
  "C. F. Driscoll and K. Fine, ",
  StyleBox["Experiments on vortex dynamics in pure electron plasmas",
    FontSlant->"Italic"],
  ", Phys. Fluids B ",
  StyleBox["2",
    FontWeight->"Bold"],
  ", 1359 (1990)."
}], "Text"],

Cell[TextData[{
  "E. Fermi, J. Pasta, and S. Ulam, ",
  StyleBox["Studies of Nonlinear Problems",
    FontSlant->"Italic"],
  ", Los Alamos Report LA-1940  (1955). "
}], "Text"],

Cell[TextData[{
  "K. Fine, W. Flynn, A. Cass and C. F. Driscoll, ",
  StyleBox["Relaxation of 2D turbulence to vortex crystals",
    FontSlant->"Italic"],
  ", Phys. Rev. Lett. ",
  StyleBox["75",
    FontWeight->"Bold"],
  ", 3277 (1995)."
}], "Text"],

Cell[TextData[{
  "J. Glanz, ",
  StyleBox["From a turbulent maelstrom, order",
    FontSlant->"Italic"],
  ", Science ",
  StyleBox["280",
    FontWeight->"Bold"],
  ", 519 (1998)."
}], "Text"],

Cell[TextData[{
  "L. Greengard, ",
  StyleBox["Fast algorithms for classical physics",
    FontSlant->"Italic"],
  ", Science ",
  StyleBox["265",
    FontWeight->"Bold"],
  ", 909 (1994)."
}], "Text"],

Cell[TextData[{
  "A. Hasegawa  and Y. Kodama,  ",
  StyleBox["Solitons in Optical Communications",
    FontSlant->"Italic"],
  ", (Oxford University Press, New York, 1995)."
}], "Text"],

Cell[TextData[{
  "J. Scott Russell, ",
  StyleBox["Report on Waves",
    FontSlant->"Italic"],
  ", Report of the Fourteenth Meeting of the British Association for the \
Advancement of Science, York, September 1844 (London, 1845), pp. 311-390."
}], "Text"],

Cell[TextData[{
  "G.B. Whitham, ",
  StyleBox["Linear and Nonlinear Waves ",
    FontSlant->"Italic"],
  "(John Wiley and Sons, New York, 1999)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 7, Section 7.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 93, "IndexEntries" -> {{"i:10", \
{"Action (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wave action)"}}, {"i:11", "Thermal equilibrium"}, {"i:13", 
  StyleBox[ "Histogram", FontWeight -> "Bold"]}, {"i:27", 
  StyleBox[ "EllipticF", FontWeight -> "Bold"]}, {"i:29", 
  StyleBox[ 
  "EllipticK", FontWeight -> 
    "Bold"]}, {"i:31", "Scott-Russell, J."}, {"i:37", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        RowBox[ {
          RowBox[ {
            RowBox[ {
              FractionBox[ 
                RowBox[ {"\[PartialD]", "\[Rho]"}], 
                RowBox[ {"\[PartialD]", "t"}]], "+", 
              RowBox[ {
                FractionBox[ "\[PartialD]", 
                  RowBox[ {"\[PartialD]", "x"}]], 
                RowBox[ {"(", 
                  RowBox[ {"u", " ", "\[Rho]"}], ")"}]}]}], " ", "=", " ", 
            "0"}], ","}], 
        TraditionalForm]]]}, {"i:43", "Hugoniot relation"}, {"i:48", \
"Hugoniot relation"}, {"i:5", {"Chaotic systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Ordinary differential equations, Lyapunov exponent)"}}, \
{"i:52", "Fermi, Enrico"}, {"i:55", "PIC method"}, {"i:56", "Gravitational \
collapse"}, {"i:57", "Gravitational collapse"}, {"i:58", 
  StyleBox[ "Quotient", FontWeight -> "Bold"]}, {"i:59", 
  StyleBox[ 
  "Mod", FontWeight -> 
    "Bold"]}, {"i:6", "Boltzmann equation, collisionless"}, {"i:6", {"Vlasov \
equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Boltzmann equation, collisionless)"}}, {"i:60", 
  StyleBox[ "Mod", FontWeight -> "Bold"]}, {"i:66", "Vorticity"}, {"i:67", 
  StyleBox[ "Export", FontWeight -> "Bold"]}, {"i:68", 
  StyleBox[ 
  "Unset", FontWeight -> 
    "Bold"]}, {"i:69", "Circulation"}, {"i:72", "Turbulence"}, {"i:77", \
"Viscosity"}, {"i:8", "Phase mixing"}, {"i:80", "Jean's instability"}, \
{"i:81", "Jeans instability"}, {"i:82", "Jeans instability"}, {"i:83", \
"Navier-Stokes equations"}, {"i:84", "Euler equations"}, {"i:85", "Burger's \
equation, neglecting diffusion"}, {"i:86", "grid methods"}, {"i:87", "Grid \
methods"}, {"i:88", "Area weighting"}, {"i:89", "tree codes"}, {"i:91", \
"Landau damping"}, {"i:92", "One component plasma"}, {"i:12", "Density", \
"particle (or number)"}, {"i:15", "Partial differential equations", "first \
order"}, {"i:17", "Burger's equation", "and nonlinear water waves"}, {"i:18", \
"Burger's equation", "characteristics"}, {"i:18", "Characteristics", "for \
Burger's equation"}, {"i:19", "Characteristics", "for the linear \
collisionless Boltzmann equation"}, {"i:2", "Characteristics", "definition"}, \
{"i:20", "Density", "phase space"}, {"i:21", "Galerkin method", "von-Neumann \
basis functions"}, {"i:22", "Burger's equation", "with damping"}, {"i:23", \
"Partial differential equations", {"traffic flow equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Burger's equation)"}}, {"i:32", "Partial differential \
equations", "Boussinesq equations"}, {"i:33", "Solitons", "in other \
systems"}, {"i:34", "Partial differential equations", "sine-Gordon \
equation"}, {"i:35", "Partial differential equations", "Klein-Gordon \
equation"}, {"i:36", "Shroedinger's equation", "nonlinear"}, {"i:37", \
"Continuity equation", "for mass density"}, {"i:38", "Momentum", "equation"},
   {"i:39", "Specific heat(s)", "ratio of"}, {"i:40", "Equations", "of \
state"}, {"i:41", "Equations", "fluid"}, {"i:42", "Dispersion", "relation, \
for sound waves"}, {"i:44", "K-dV equation", "stability of steady \
solutions"}, {"i:47", "Burger's equation", "with diffusion"}, {"i:49", \
"Solitons", "in other systems"}, {"i:50", "Solitons", "in other systems"}, \
{"i:51", "Partial differential equations", {"traffic flow equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Burger's equation)"}}, {"i:52", "Energy", {"equipartition, in \
FPU system (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wavebreaking, suppression of)"}}, {"i:53", "Energy", {"cascade \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wavebreaking)"}}, {"i:54", "Boltzmann equation, \
collisionless", "for self-gravitating systems"}, {"i:55", "Numerical methods \
for solution of PDEs", "particle in cell method"}, {"i:55", "Numerical \
solution of PDEs", {"particle in cell method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " PIC method)"}}, {"i:6", "Partial differential equations", \
{"collisionless Boltzmann equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Boltzmann equation, collisionless)"}}, {"i:60", 
  StyleBox[ "Map", FontWeight -> "Bold"], 
  StyleBox[ 
  "", FontWeight -> 
    "Bold"]}, {"i:61", "Numerical solution of ODEs", "leapfrog method"}, \
{"i:62", "FFTs", "in PIC method"}, {"i:63", 
  StyleBox[ 
  "Interpolation", FontWeight -> 
    "Bold"], "linear, in PIC method"}, {"i:65", "Equations", "2D fluid"}, \
{"i:69", "Vortex", "point"}, {"i:70", "Vortex", "merger"}, {"i:71", "Vortex", \
"crystals"}, {"i:73", "Solitons", "in other systems"}, {"i:74", "Galerkin \
method", "for nonlinear system (k-dV equation)"}, {"i:75", "Grid methods", \
"for nonlinear systems (shock waves)"}, {"i:78", "Function(s)", "pure"}, \
{"i:79", "Grid methods", "operator splitting"}, {"i:9", "Boltzmann equation, \
collisionless", "equilibrium solution"}, {"i:90", "plasma waves", "thermal \
corrections"}, {"i:1", "Characteristics", "method of", ""}, {"i:11", \
"Equilibrium", {"thermal (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Thermal equilibrium)"}, ""}, {"i:14", "Partial differential \
equations", {"Burger's equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Burger's equation)"}, ""}, {"i:14", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"nonlinear (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Burger's equation, K-dV equation)"}, ""}, {"i:16", \
"Wavebreaking", "time, in Burger's equation", ""}, {"i:24", "Partial \
differential equations", {"k-dV equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " K-dV equation)"}, ""}, {"i:25", "K-dV equation", "", ""}, \
{"i:26", "K-dV equation", {"derivation of steady solutions (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Solitons;waves, cnoidal)"}, ""}, {"i:26", "Solitons", "", ""}, \
{"i:26", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "cnoidal", ""}, {"i:27", "Integral,", \
{"Elliptic, of the first kind (", 
  StyleBox[ "EllipticF", FontWeight -> "Bold"], ",", 
  StyleBox[ 
  "EllipticK", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:28", "Function(s)", {"Jacobian Elliptic (", 
  StyleBox[ 
  "JacobiSN,JacobiCN", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:28", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "cnoidal", ""}, {"i:3", "Derivatives", "total \
time", ""}, {"i:30", "Solitons", "in the K-dV equation", ""}, {"i:4", \
{"Mixing dye (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Boltzmann equation, collisionless, Chaotic systems)"}, "", \
""}, {"i:45", "K-dV equation", {"suppression of wavebreaking (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Wavebreaking, suppression of)"}, ""}, {"i:46", {"Waves, shock \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Equations, fluid)"}, "", ""}, {"i:48", {"Waves, shock (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Equations, fluid)"}, {"jump condition (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Hugoniot relation)"}, ""}, {"i:52", "Ordinary differential \
equations", "Fermi Pasta Ulam (FPU) system", ""}, {"i:61", "Leapfrog method", \
"", ""}, {"i:64", "Function(s)", "stream", ""}, {"i:68", "Numerical solution \
of ordinary differential equations", "Adams-Bashforth method", ""}, {"i:68", \
{"Adams-Bashforth method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:7", {"Ideal gas \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Boltzmann equation, collisionless, Thermal equilibrium)"}, \
"", ""}, {"i:73", {"Refraction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories, Snell's law)"}, "index of, \
nonlinear", ""}, {"i:76", {"Ideal gas (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Boltzmann equation, collisionless, Thermal equilibrium)"}, \
"as a model of the galaxy", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
ImageRegion->{{0.01, 1}, {0, Inherited}},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UNNEQ"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, None}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["UNNEQ", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1727, 52, 79, 1, 111, "Title",
      CellTags->"c:1"]},
  "i:1"->{
    Cell[3100, 87, 102, 1, 39, "Subtitle",
      CellTags->{"i:1", "c:3"}]},
  "c:3"->{
    Cell[3100, 87, 102, 1, 39, "Subtitle",
      CellTags->{"i:1", "c:3"}]},
  "i:15"->{
    Cell[3247, 94, 73, 1, 41, "Subsubtitle",
      CellTags->{"i:15", "c:4"}]},
  "c:4"->{
    Cell[3247, 94, 73, 1, 41, "Subsubtitle",
      CellTags->{"i:15", "c:4"}]},
  "(7.1.1)"->{
    Cell[3467, 103, 213, 6, 36, "NumberedEquation",
      CellTags->"(7.1.1)"]},
  "(7.1.2)"->{
    Cell[3793, 116, 140, 5, 26, "NumberedEquation",
      CellTags->"(7.1.2)"]},
  "(7.1.3)"->{
    Cell[6398, 187, 200, 8, 26, "NumberedEquation",
      CellTags->"(7.1.3)"]},
  "i:2"->{
    Cell[6601, 197, 221, 8, 25, "Text",
      CellTags->"i:2"]},
  "i:3"->{
    Cell[7536, 229, 650, 22, 41, "Text",
      CellTags->"i:3"]},
  "(7.1.4)"->{
    Cell[8189, 253, 296, 7, 36, "NumberedEquation",
      CellTags->"(7.1.4)"]},
  "(7.1.5)"->{
    Cell[8657, 269, 173, 3, 36, "NumberedEquation",
      CellTags->"(7.1.5)"]},
  "(7.1.6)"->{
    Cell[9238, 286, 173, 6, 35, "NumberedEquation",
      CellTags->"(7.1.6)"]},
  "(7.1.7)"->{
    Cell[10305, 326, 213, 6, 36, "NumberedEquation",
      CellTags->"(7.1.7)"]},
  "(7.1.8)"->{
    Cell[12357, 399, 264, 7, 40, "NumberedEquation",
      CellTags->"(7.1.8)"]},
  "(7.1.9)"->{
    Cell[13024, 422, 192, 3, 36, "NumberedEquation",
      CellTags->"(7.1.9)"]},
  "c:5"->{
    Cell[13619, 442, 60, 1, 30, "Subsubtitle",
      CellTags->"c:5"]},
  "(7.1.10)"->{
    Cell[14475, 472, 166, 3, 27, "NumberedEquation",
      CellTags->"(7.1.10)"]},
  "(7.1.11)"->{
    Cell[14644, 477, 174, 3, 27, "NumberedEquation",
      CellTags->"(7.1.11)"]},
  "(7.1.12)"->{
    Cell[16225, 533, 247, 7, 33, "NumberedEquation",
      CellTags->"(7.1.12)"]},
  "(7.1.13)"->{
    Cell[17556, 587, 334, 9, 33, "NumberedEquation",
      CellTags->"(7.1.13)"]},
  "c:6"->{
    Cell[18314, 614, 190, 8, 42, "Section",
      CellTags->"c:6"]},
  "(7.1.14)"->{
    Cell[18659, 632, 191, 6, 36, "NumberedEquation",
      CellTags->"(7.1.14)"]},
  "(7.1.15)"->{
    Cell[20865, 708, 226, 6, 26, "NumberedEquation",
      CellTags->"(7.1.15)"]},
  "i:78"->{
    Cell[23322, 792, 452, 13, 41, "Text",
      CellTags->"i:78"]},
  "Cell 7.1"->{
    Cell[23799, 809, 202, 5, 85, "Input",
      CellTags->"Cell 7.1"]},
  "Fig. 7.1"->{
    Cell[113299, 4928, 374, 13, 15, "Caption",
      CellTags->"Fig. 7.1"]},
  "c:7"->{
    Cell[113710, 4946, 196, 9, 32, "Section",
      CellTags->"c:7"]},
  "(7.1.16)"->{
    Cell[114657, 4984, 179, 6, 30, "NumberedEquation",
      CellTags->"(7.1.16)"]},
  "Fig. 7.2"->{
    Cell[192314, 8371, 477, 17, 26, "Caption",
      CellTags->"Fig. 7.2"]},
  "(7.1.17)"->{
    Cell[193140, 8401, 221, 7, 40, "NumberedEquation",
      CellTags->"(7.1.17)"]},
  "Cell 7.2"->{
    Cell[194708, 8460, 303, 7, 110, "Input",
      CellTags->"Cell 7.2"]},
  "c:8"->{
    Cell[749486, 23137, 60, 1, 31, "Section",
      CellTags->"c:8"]},
  "i:4"->{
    Cell[749759, 23148, 287, 7, 42, "NumberedEquation",
      CellTags->{"i:4", "(7.1.18)"}]},
  "(7.1.18)"->{
    Cell[749759, 23148, 287, 7, 42, "NumberedEquation",
      CellTags->{"i:4", "(7.1.18)"}]},
  "(7.1.19)"->{
    Cell[750913, 23189, 156, 5, 39, "NumberedEquation",
      CellTags->"(7.1.19)"]},
  "(7.1.20)"->{
    Cell[751985, 23225, 309, 9, 46, "NumberedEquation",
      CellTags->"(7.1.20)"]},
  "i:5"->{
    Cell[753079, 23262, 323, 10, 78, "Text",
      CellTags->"i:5"]},
  "Cell 7.3"->{
    Cell[754087, 23298, 479, 11, 143, "Input",
      CellTags->"Cell 7.3"]},
  "Cell 7.4"->{
    Cell[754940, 23328, 428, 10, 143, "Input",
      CellTags->"Cell 7.4"]},
  "Cell 7.5"->{
    Cell[1007169, 34083, 456, 10, 124, "Input",
      CellTags->"Cell 7.5"]},
  "c:9"->{
    Cell[1188930, 38636, 85, 1, 31, "Section",
      CellTags->"c:9"]},
  "i:20"->{
    Cell[1189018, 38639, 943, 30, 61, "Text",
      CellTags->"i:20"]},
  "(7.1.21)"->{
    Cell[1189964, 38671, 232, 6, 42, "NumberedEquation",
      CellTags->"(7.1.21)"]},
  "i:19"->{
    Cell[1190403, 38686, 231, 7, 71, "UNNEQ",
      CellTags->"i:19"]},
  "i:6"->{
    Cell[1190826, 38703, 991, 24, 95, "Text",
      CellTags->"i:6"]},
  "i:7"->{
    Cell[1191820, 38729, 690, 24, 63, "Text",
      CellTags->"i:7"]},
  "Cell 7.6"->{
    Cell[1193527, 38789, 933, 21, 314, "Input",
      CellTags->"Cell 7.6"]},
  "(7.1.22)"->{
    Cell[1295394, 43406, 142, 3, 27, "NumberedEquation",
      CellTags->"(7.1.22)"]},
  "i:8"->{
    Cell[1295539, 43411, 627, 14, 95, "Text",
      CellTags->"i:8"]},
  "Cell 7.7"->{
    Cell[1296639, 43444, 467, 11, 143, "Input",
      CellTags->"Cell 7.7"]},
  "i:9"->{
    Cell[1769282, 56498, 1577, 47, 96, "Text",
      CellTags->"i:9"]},
  "(7.1.23)"->{
    Cell[1770862, 56547, 225, 6, 44, "NumberedEquation",
      CellTags->"(7.1.23)"]},
  "(7.1.24)"->{
    Cell[1772125, 56589, 318, 9, 44, "NumberedEquation",
      CellTags->"(7.1.24)"]},
  "(7.1.25)"->{
    Cell[1772507, 56602, 138, 5, 30, "NumberedEquation",
      CellTags->"(7.1.25)"]},
  "(7.1.26)"->{
    Cell[1774361, 56658, 312, 8, 47, "NumberedEquation",
      CellTags->"(7.1.26)"]},
  "Cell 7.8"->{
    Cell[1775781, 56700, 239, 6, 86, "Input",
      CellTags->"Cell 7.8"]},
  "Cell 7.9"->{
    Cell[1776403, 56722, 244, 5, 117, "Input",
      CellTags->"Cell 7.9"]},
  "Cell 7.10"->{
    Cell[1777046, 56745, 393, 10, 181, "Input",
      CellTags->"Cell 7.10"]},
  "Cell 7.11"->{
    Cell[1777649, 56767, 240, 6, 88, "Input",
      CellTags->"Cell 7.11"]},
  "(7.1.27)"->{
    Cell[1812524, 57564, 243, 8, 38, "NumberedEquation",
      CellTags->"(7.1.27)"]},
  "Cell 7.12"->{
    Cell[1813708, 57607, 210, 6, 86, "Input",
      CellTags->"Cell 7.12"]},
  "i:10"->{
    Cell[1813921, 57615, 343, 8, 44, "Text",
      CellTags->"i:10"]},
  "Cell 7.13"->{
    Cell[1814267, 57625, 316, 7, 143, "Input",
      CellTags->"Cell 7.13"]},
  "Cell 7.14"->{
    Cell[1814779, 57644, 225, 5, 67, "Input",
      CellTags->"Cell 7.14"]},
  "Cell 7.15"->{
    Cell[1839219, 58226, 202, 5, 86, "Input",
      CellTags->"Cell 7.15"]},
  "Cell 7.16"->{
    Cell[1839905, 58251, 250, 6, 86, "Input",
      CellTags->"Cell 7.16"]},
  "Cell 7.17"->{
    Cell[1840472, 58271, 298, 6, 88, "Input",
      CellTags->"Cell 7.17"]},
  "i:11"->{
    Cell[2151723, 64122, 1110, 33, 99, "Text",
      CellTags->"i:11"]},
  "Cell 7.18"->{
    Cell[2153010, 64163, 169, 4, 67, "Input",
      CellTags->"Cell 7.18"]},
  "Cell 7.19"->{
    Cell[2153348, 64177, 178, 5, 67, "Input",
      CellTags->"Cell 7.19"]},
  "i:12"->{
    Cell[2153529, 64184, 422, 11, 61, "Text",
      CellTags->"i:12"]},
  "(7.1.28)"->{
    Cell[2153954, 64197, 231, 7, 32, "NumberedEquation",
      CellTags->"(7.1.28)"]},
  "i:13"->{
    Cell[2155328, 64245, 240, 7, 44, "Text",
      CellTags->"i:13"]},
  "Cell 7.20"->{
    Cell[2155571, 64254, 92, 3, 67, "Input",
      CellTags->"Cell 7.20"]},
  "Cell 7.21"->{
    Cell[2156418, 64282, 587, 13, 200, "Input",
      CellTags->"Cell 7.21"]},
  "Cell 7.22"->{
    Cell[2157932, 64328, 173, 5, 67, "Input",
      CellTags->"Cell 7.22"]},
  "Fig. 7.3"->{
    Cell[2189312, 65131, 209, 6, 16, "Caption",
      CellTags->"Fig. 7.3"]},
  "i:14"->{
    Cell[2190466, 65158, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:14", "c:10"}]},
  "c:10"->{
    Cell[2190466, 65158, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:14", "c:10"}]},
  "c:11"->{
    Cell[2190565, 65163, 76, 1, 42, "Section",
      CellTags->"c:11"]},
  "(7.1.29)"->{
    Cell[2190791, 65171, 222, 6, 35, "NumberedEquation",
      CellTags->"(7.1.29)"]},
  "i:17"->{
    Cell[2191016, 65179, 1547, 42, 130, "Text",
      CellTags->"i:17"]},
  "i:85"->{
    Cell[2193617, 65259, 199, 6, 36, "NumberedEquation",
      CellTags->{"i:85", "(7.1.30)"}]},
  "(7.1.30)"->{
    Cell[2193617, 65259, 199, 6, 36, "NumberedEquation",
      CellTags->{"i:85", "(7.1.30)"}]},
  "c:12"->{
    Cell[2194333, 65284, 47, 1, 31, "Section",
      CellTags->"c:12"]},
  "(7.1.31)"->{
    Cell[2194889, 65301, 174, 6, 26, "NumberedEquation",
      CellTags->"(7.1.31)"]},
  "(7.1.32)"->{
    Cell[2195444, 65321, 185, 5, 26, "NumberedEquation",
      CellTags->"(7.1.32)"]},
  "(7.1.33)"->{
    Cell[2195794, 65335, 153, 5, 26, "NumberedEquation",
      CellTags->"(7.1.33)"]},
  "i:18"->{
    Cell[2196254, 65353, 161, 5, 26, "NumberedEquation",
      CellTags->{"i:18", "(7.1.34)"}]},
  "(7.1.34)"->{
    Cell[2196254, 65353, 161, 5, 26, "NumberedEquation",
      CellTags->{"i:18", "(7.1.34)"}]},
  "Fig. 7.4"->{
    Cell[2308940, 70743, 241, 7, 15, "Caption",
      CellTags->"Fig. 7.4"]},
  "Cell 7.23"->{
    Cell[2310295, 70789, 111, 3, 65, "Input",
      CellTags->"Cell 7.23"]},
  "Cell 7.24"->{
    Cell[2310604, 70803, 136, 3, 65, "Input",
      CellTags->"Cell 7.24"]},
  "i:87"->{
    Cell[2311080, 70820, 594, 19, 41, "Text",
      CellTags->"i:87"]},
  "Cell 7.25"->{
    Cell[2311677, 70841, 286, 7, 121, "Input",
      CellTags->"Cell 7.25"]},
  "Cell 7.26"->{
    Cell[2312355, 70867, 273, 7, 85, "Input",
      CellTags->"Cell 7.26"]},
  "i:16"->{
    Cell[2678885, 79288, 66, 1, 31, "Section",
      CellTags->{"i:16", "c:13"}]},
  "c:13"->{
    Cell[2678885, 79288, 66, 1, 31, "Section",
      CellTags->{"i:16", "c:13"}]},
  "(7.1.35)"->{
    Cell[2681293, 79371, 792, 19, 40, "NumberedEquation",
      CellTags->"(7.1.35)"]},
  "(7.1.36)"->{
    Cell[2682852, 79421, 186, 6, 40, "NumberedEquation",
      CellTags->"(7.1.36)"]},
  "(7.1.37)"->{
    Cell[2683261, 79439, 211, 7, 40, "NumberedEquation",
      CellTags->"(7.1.37)"]},
  "(7.1.38)"->{
    Cell[2683777, 79459, 162, 3, 30, "NumberedEquation",
      CellTags->"(7.1.38)"]},
  "(7.1.39)"->{
    Cell[2683964, 79466, 177, 6, 30, "NumberedEquation",
      CellTags->"(7.1.39)"]},
  "Cell 7.27"->{
    Cell[2684602, 79492, 106, 3, 65, "Input",
      CellTags->"Cell 7.27"]},
  "Cell 7.28"->{
    Cell[2685117, 79514, 103, 3, 65, "Input",
      CellTags->"Cell 7.28"]},
  "(7.1.40)"->{
    Cell[2686547, 79559, 1059, 27, 50, "NumberedEquation",
      CellTags->"(7.1.40)"]},
  "(7.1.41)"->{
    Cell[2687846, 79598, 667, 18, 50, "NumberedEquation",
      CellTags->"(7.1.41)"]},
  "c:14"->{
    Cell[2689407, 79651, 65, 1, 30, "Subsubtitle",
      CellTags->"c:14"]},
  "i:21"->{
    Cell[2695260, 79872, 1624, 50, 96, "Text",
      CellTags->"i:21"]},
  "(7.1.42)"->{
    Cell[2696947, 79926, 367, 12, 32, "NumberedEquation",
      CellTags->"(7.1.42)"]},
  "i:22"->{
    Cell[2702617, 80114, 669, 18, 38, "UNNEQ",
      CellTags->"i:22"]},
  "i:23"->{
    Cell[2704296, 80174, 704, 17, 78, "Text",
      CellTags->"i:23"]},
  "(7.1.43)"->{
    Cell[2705003, 80193, 202, 4, 39, "NumberedEquation",
      CellTags->"(7.1.43)"]},
  "i:24"->{
    Cell[2706350, 80236, 71, 1, 40, "Subtitle",
      CellTags->{"i:24", "c:15"}]},
  "c:15"->{
    Cell[2706350, 80236, 71, 1, 40, "Subtitle",
      CellTags->{"i:24", "c:15"}]},
  "c:16"->{
    Cell[2706465, 80243, 84, 1, 41, "Subsubtitle",
      CellTags->"c:16"]},
  "(7.2.1)"->{
    Cell[2707163, 80262, 140, 5, 30, "NE2",
      CellTags->"(7.2.1)"]},
  "Cell 7.29"->{
    Cell[2708361, 80305, 123, 3, 65, "Input",
      CellTags->"Cell 7.29"]},
  "(7.2.2)"->{
    Cell[2709134, 80337, 198, 7, 35, "NE2",
      CellTags->"(7.2.2)"]},
  "(7.2.3)"->{
    Cell[2709534, 80354, 285, 7, 40, "NE2",
      CellTags->"(7.2.3)"]},
  "i:25"->{
    Cell[2710449, 80385, 891, 31, 41, "Text",
      CellTags->"i:25"]},
  "(7.2.4)"->{
    Cell[2711343, 80418, 223, 7, 40, "NE2",
      CellTags->"(7.2.4)"]},
  "i:26"->{
    Cell[2712551, 80458, 103, 1, 30, "Subsubtitle",
      CellTags->{"i:26", "c:17"}]},
  "c:17"->{
    Cell[2712551, 80458, 103, 1, 30, "Subsubtitle",
      CellTags->{"i:26", "c:17"}]},
  "(7.2.5)"->{
    Cell[2715985, 80577, 192, 3, 41, "NE2",
      CellTags->"(7.2.5)"]},
  "(7.2.6)"->{
    Cell[2716312, 80589, 172, 6, 37, "NE2",
      CellTags->"(7.2.6)"]},
  "Cell 7.30"->{
    Cell[2717070, 80619, 515, 11, 160, "Input",
      CellTags->"Cell 7.30"]},
  "Cell 7.31"->{
    Cell[2748208, 81384, 110, 3, 65, "Input",
      CellTags->"Cell 7.31"]},
  "(7.2.7)"->{
    Cell[2749927, 81445, 180, 6, 56, "NE2",
      CellTags->"(7.2.7)"]},
  "(7.2.8)"->{
    Cell[2750179, 81455, 422, 15, 70, "NE2",
      CellTags->"(7.2.8)"]},
  "Cell 7.32"->{
    Cell[2751162, 81489, 134, 3, 65, "Input",
      CellTags->"Cell 7.32"]},
  "(7.2.9)"->{
    Cell[2753552, 81540, 184, 7, 37, "NE2",
      CellTags->"(7.2.9)"]},
  "Cell 7.33"->{
    Cell[2753948, 81558, 431, 8, 191, "Input",
      CellTags->"Cell 7.33"]},
  "i:27"->{
    Cell[2754712, 81576, 359, 10, 42, "Text",
      CellTags->"i:27"]},
  "(7.2.10)"->{
    Cell[2755477, 81604, 481, 13, 60, "NE2",
      CellTags->"(7.2.10)"]},
  "(7.2.11)"->{
    Cell[2755985, 81621, 134, 6, 37, "NE2",
      CellTags->"(7.2.11)"]},
  "(7.2.12)"->{
    Cell[2757438, 81680, 238, 8, 56, "NE2",
      CellTags->"(7.2.12)"]},
  "i:28"->{
    Cell[2757679, 81690, 932, 31, 80, "Text",
      CellTags->"i:28"]},
  "Cell 7.34"->{
    Cell[2758636, 81725, 250, 5, 85, "Input",
      CellTags->"Cell 7.34"]},
  "(7.2.13)"->{
    Cell[2809797, 82838, 131, 6, 28, "NE2",
      CellTags->"(7.2.13)"]},
  "i:29"->{
    Cell[2809931, 82846, 772, 30, 60, "Text",
      CellTags->"i:29"]},
  "Cell 7.35"->{
    Cell[2810728, 82880, 217, 5, 85, "Input",
      CellTags->"Cell 7.35"]},
  "Cell 7.36"->{
    Cell[2840744, 83558, 101, 3, 65, "Input",
      CellTags->"Cell 7.36"]},
  "(7.2.14)"->{
    Cell[2841701, 83597, 220, 7, 56, "NE2",
      CellTags->"(7.2.14)"]},
  "(7.2.15)"->{
    Cell[2842127, 83616, 179, 6, 56, "NE2",
      CellTags->"(7.2.15)"]},
  "Cell 7.37"->{
    Cell[2842924, 83651, 635, 14, 161, "Input",
      CellTags->"Cell 7.37"]},
  "Fig. 7.5"->{
    Cell[4444991, 107195, 317, 9, 28, "Caption",
      CellTags->"Fig. 7.5"]},
  "(7.2.16)"->{
    Cell[4447295, 107268, 131, 5, 37, "NE2",
      CellTags->"(7.2.16)"]},
  "Fig. 7.6"->{
    Cell[4479556, 108037, 329, 12, 15, "Caption",
      CellTags->"Fig. 7.6"]},
  "i:30"->{
    Cell[4480119, 108057, 762, 27, 60, "Text",
      CellTags->"i:30"]},
  "Cell 7.38"->{
    Cell[4480906, 108088, 309, 6, 120, "Input",
      CellTags->"Cell 7.38"]},
  "Cell 7.39"->{
    Cell[4515971, 108894, 114, 3, 75, "Input",
      CellTags->"Cell 7.39"]},
  "(7.2.17)"->{
    Cell[4516249, 108905, 168, 6, 32, "NE2",
      CellTags->"(7.2.17)"]},
  "(7.2.18)"->{
    Cell[4517756, 108962, 143, 5, 27, "NE2",
      CellTags->"(7.2.18)"]},
  "(7.2.19)"->{
    Cell[4517938, 108971, 131, 5, 41, "NE2",
      CellTags->"(7.2.19)"]},
  "i:31"->{
    Cell[4518072, 108978, 232, 5, 42, "Text",
      CellTags->"i:31"]},
  "i:73"->{
    Cell[4519427, 109005, 1339, 28, 165, "Text",
      CellTags->"i:73"]},
  "c:18"->{
    Cell[4520803, 109038, 94, 1, 30, "Subsubtitle",
      CellTags->"c:18"]},
  "c:19"->{
    Cell[4520922, 109043, 51, 1, 42, "Section",
      CellTags->"c:19"]},
  "i:74"->{
    Cell[4521981, 109066, 367, 12, 41, "Text",
      CellTags->"i:74"]},
  "(7.2.20)"->{
    Cell[4522351, 109080, 338, 12, 30, "NE2",
      CellTags->"(7.2.20)"]},
  "(7.2.21)"->{
    Cell[4522849, 109101, 212, 7, 35, "NE2",
      CellTags->"(7.2.21)"]},
  "(7.2.22)"->{
    Cell[4523415, 109121, 912, 23, 45, "NE2",
      CellTags->"(7.2.22)"]},
  "(7.2.23)"->{
    Cell[4525151, 109172, 322, 8, 35, "NE2",
      CellTags->"(7.2.23)"]},
  "(7.2.24)"->{
    Cell[4525843, 109196, 148, 5, 26, "NE2",
      CellTags->"(7.2.24)"]},
  "Cell 7.40"->{
    Cell[4526150, 109210, 155, 4, 65, "Input",
      CellTags->"Cell 7.40"]},
  "i:53"->{
    Cell[4527974, 109268, 790, 20, 75, "Text",
      CellTags->"i:53"]},
  "Cell 7.41"->{
    Cell[4529662, 109314, 125, 3, 65, "Input",
      CellTags->"Cell 7.41"]},
  "i:44"->{
    Cell[4529891, 109324, 72, 1, 31, "Section",
      CellTags->{"i:44", "c:20"}]},
  "c:20"->{
    Cell[4529891, 109324, 72, 1, 31, "Section",
      CellTags->{"i:44", "c:20"}]},
  "Cell 7.42"->{
    Cell[4530068, 109332, 318, 7, 124, "Input",
      CellTags->"Cell 7.42"]},
  "Cell 7.43"->{
    Cell[4530678, 109354, 291, 7, 105, "Input",
      CellTags->"Cell 7.43"]},
  "(7.2.25)"->{
    Cell[4531292, 109377, 273, 9, 33, "NE2",
      CellTags->"(7.2.25)"]},
  "Cell 7.44"->{
    Cell[4531647, 109392, 392, 11, 162, "Input",
      CellTags->"Cell 7.44"]},
  "Cell 7.45"->{
    Cell[4534294, 109476, 1253, 22, 390, "Input",
      CellTags->"Cell 7.45"]},
  "Cell 7.46"->{
    Cell[4535804, 109511, 100, 3, 67, "Input",
      CellTags->"Cell 7.46"]},
  "c:21"->{
    Cell[4536565, 109532, 70, 1, 31, "Section",
      CellTags->"c:21"]},
  "Cell 7.47"->{
    Cell[4536763, 109540, 247, 6, 105, "Input",
      CellTags->"Cell 7.47"]},
  "Cell 7.48"->{
    Cell[4537085, 109550, 375, 11, 162, "Input",
      CellTags->"Cell 7.48"]},
  "Cell 7.49"->{
    Cell[4537870, 109575, 105, 3, 67, "Input",
      CellTags->"Cell 7.49"]},
  "i:45"->{
    Cell[4538908, 109601, 87, 1, 31, "Section",
      CellTags->{"i:45", "c:22"}]},
  "c:22"->{
    Cell[4538908, 109601, 87, 1, 31, "Section",
      CellTags->{"i:45", "c:22"}]},
  "Cell 7.50"->{
    Cell[4539983, 109630, 313, 7, 143, "Input",
      CellTags->"Cell 7.50"]},
  "Cell 7.51"->{
    Cell[4540843, 109655, 541, 11, 181, "Input",
      CellTags->"Cell 7.51"]},
  "Fig. 7.7"->{
    Cell[8351877, 207225, 95, 1, 17, "Caption",
      CellTags->"Fig. 7.7"]},
  "Fig. 7.8"->{
    Cell[8647628, 220769, 194, 6, 16, "Caption",
      CellTags->"Fig. 7.8"]},
  "i:46"->{
    Cell[8649117, 220814, 89, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:23"}]},
  "c:23"->{
    Cell[8649117, 220814, 89, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:23"}]},
  "c:24"->{
    Cell[8649231, 220819, 55, 1, 40, "Section",
      CellTags->"c:24"]},
  "i:47"->{
    Cell[8649289, 220822, 372, 12, 45, "Text",
      CellTags->"i:47"]},
  "(7.2.26)"->{
    Cell[8649664, 220836, 221, 7, 40, "NE2",
      CellTags->"(7.2.26)"]},
  "(7.2.27)"->{
    Cell[8651336, 220885, 720, 21, 40, "NE2",
      CellTags->"(7.2.27)"]},
  "(7.2.28)"->{
    Cell[8652755, 220934, 173, 6, 35, "NE2",
      CellTags->"(7.2.28)"]},
  "i:48"->{
    Cell[8652931, 220942, 266, 9, 25, "Text",
      CellTags->"i:48"]},
  "Cell 7.52"->{
    Cell[8653519, 220966, 234, 5, 85, "Input",
      CellTags->"Cell 7.52"]},
  "c:25"->{
    Cell[8683136, 221728, 67, 1, 30, "Section",
      CellTags->"c:25"]},
  "i:75"->{
    Cell[8683206, 221731, 1331, 43, 75, "Text",
      CellTags->"i:75"]},
  "(7.2.29)"->{
    Cell[8687314, 221856, 1584, 41, 55, "NE2",
      CellTags->"(7.2.29)"]},
  "Cell 7.53"->{
    Cell[8689997, 221937, 239, 6, 85, "Input",
      CellTags->"Cell 7.53"]},
  "(7.2.30)"->{
    Cell[8690563, 221955, 1446, 40, 45, "NE2",
      CellTags->"(7.2.30)"]},
  "Cell 7.54"->{
    Cell[8692840, 222024, 357, 7, 111, "Input",
      CellTags->"Cell 7.54"]},
  "Cell 7.55"->{
    Cell[8693200, 222033, 176, 5, 90, "Input",
      CellTags->"Cell 7.55"]},
  "(7.2.31)"->{
    Cell[8693531, 222047, 429, 13, 35, "NE2",
      CellTags->"(7.2.31)"]},
  "i:79"->{
    Cell[8693963, 222062, 1303, 43, 60, "Text",
      CellTags->"i:79"]},
  "Cell 7.56"->{
    Cell[8696155, 222137, 136, 3, 65, "Input",
      CellTags->"Cell 7.56"]},
  "Cell 7.57"->{
    Cell[8696489, 222150, 255, 7, 65, "Input",
      CellTags->"Cell 7.57"]},
  "Cell 7.58"->{
    Cell[8696996, 222170, 196, 6, 65, "Input",
      CellTags->"Cell 7.58"]},
  "Cell 7.59"->{
    Cell[8697327, 222185, 205, 4, 65, "Input",
      CellTags->"Cell 7.59"]},
  "Cell 7.60"->{
    Cell[8698340, 222220, 281, 6, 121, "Input",
      CellTags->"Cell 7.60"]},
  "Cell 7.61"->{
    Cell[8699320, 222249, 352, 9, 135, "Input",
      CellTags->"Cell 7.61"]},
  "Cell 7.62"->{
    Cell[8699793, 222267, 102, 3, 65, "Input",
      CellTags->"Cell 7.62"]},
  "Cell 7.63"->{
    Cell[8700180, 222283, 395, 9, 121, "Input",
      CellTags->"Cell 7.63"]},
  "Cell 7.64"->{
    Cell[9590343, 245179, 193, 5, 85, "Input",
      CellTags->"Cell 7.64"]},
  "Cell 7.65"->{
    Cell[9590616, 245190, 368, 9, 121, "Input",
      CellTags->"Cell 7.65"]},
  "c:26"->{
    Cell[10313297, 264251, 65, 1, 30, "Subsubtitle",
      CellTags->"c:26"]},
  "i:32"->{
    Cell[10314631, 264303, 742, 23, 78, "Text",
      CellTags->"i:32"]},
  "(7.2.32)"->{
    Cell[10316930, 264385, 413, 7, 78, "NE2",
      CellTags->"(7.2.32)"]},
  "i:33"->{
    Cell[10318427, 264437, 967, 32, 65, "Text",
      CellTags->"i:33"]},
  "i:34"->{
    Cell[10320106, 264498, 168, 8, 27, "Text",
      CellTags->"i:34"]},
  "(7.2.33)"->{
    Cell[10320277, 264508, 454, 10, 43, "NE2",
      CellTags->"(7.2.33)"]},
  "i:35"->{
    Cell[10321164, 264532, 438, 10, 43, "UNNEQ",
      CellTags->"i:35"]},
  "i:49"->{
    Cell[10322002, 264559, 1344, 45, 87, "Text",
      CellTags->"i:49"]},
  "i:36"->{
    Cell[10323476, 264612, 287, 8, 43, "NE2",
      CellTags->{"i:36", "(7.2.34)"}]},
  "(7.2.34)"->{
    Cell[10323476, 264612, 287, 8, 43, "NE2",
      CellTags->{"i:36", "(7.2.34)"}]},
  "i:50"->{
    Cell[10324733, 264647, 413, 13, 44, "Text",
      CellTags->"i:50"]},
  "i:41"->{
    Cell[10325555, 264676, 1019, 35, 61, "Text",
      CellTags->"i:41"]},
  "i:37"->{
    Cell[10326577, 264713, 192, 3, 39, "NE2",
      CellTags->{"i:37", "(7.2.35)"}]},
  "(7.2.35)"->{
    Cell[10326577, 264713, 192, 3, 39, "NE2",
      CellTags->{"i:37", "(7.2.35)"}]},
  "i:38"->{
    Cell[10326813, 264720, 322, 6, 45, "NE2",
      CellTags->{"i:38", "(7.2.36)"}]},
  "(7.2.36)"->{
    Cell[10326813, 264720, 322, 6, 45, "NE2",
      CellTags->{"i:38", "(7.2.36)"}]},
  "i:77"->{
    Cell[10327138, 264728, 453, 15, 31, "Text",
      CellTags->"i:77"]},
  "i:40"->{
    Cell[10327594, 264745, 159, 5, 29, "NE2",
      CellTags->{"i:40", "(7.2.37)"}]},
  "(7.2.37)"->{
    Cell[10327594, 264745, 159, 5, 29, "NE2",
      CellTags->{"i:40", "(7.2.37)"}]},
  "i:39"->{
    Cell[10327756, 264752, 434, 13, 44, "Text",
      CellTags->"i:39"]},
  "i:42"->{
    Cell[10328607, 264782, 185, 6, 33, "UNNEQ",
      CellTags->"i:42"]},
  "(7.2.38)"->{
    Cell[10330184, 264838, 258, 7, 46, "NE2",
      CellTags->"(7.2.38)"]},
  "i:43"->{
    Cell[10330573, 264854, 165, 5, 27, "Text",
      CellTags->"i:43"]},
  "i:51"->{
    Cell[10337281, 265090, 381, 11, 44, "Text",
      CellTags->"i:51"]},
  "i:86"->{
    Cell[10338280, 265123, 475, 9, 78, "Text",
      CellTags->"i:86"]},
  "(7.2.39)"->{
    Cell[10339751, 265166, 2099, 52, 81, "NE2",
      CellTags->"(7.2.39)"]},
  "i:52"->{
    Cell[10342381, 265239, 1476, 39, 99, "Text",
      CellTags->"i:52"]},
  "(7.2.40)"->{
    Cell[10345909, 265346, 300, 10, 38, "NE2",
      CellTags->"(7.2.40)"]},
  "i:55"->{
    Cell[10347391, 265401, 113, 2, 40, "Subtitle",
      CellTags->{"i:55", "c:27"}]},
  "c:27"->{
    Cell[10347391, 265401, 113, 2, 40, "Subtitle",
      CellTags->{"i:55", "c:27"}]},
  "c:28"->{
    Cell[10347548, 265409, 66, 1, 41, "Subsubtitle",
      CellTags->"c:28"]},
  "i:76"->{
    Cell[10347617, 265412, 1441, 31, 175, "Text",
      CellTags->"i:76"]},
  "Fig. 7.9"->{
    Cell[13364717, 302681, 250, 5, 29, "Caption",
      CellTags->"Fig. 7.9"]},
  "i:54"->{
    Cell[13367071, 302747, 779, 22, 42, "NE3",
      CellTags->{"i:54", "(7.3.1)"}]},
  "(7.3.1)"->{
    Cell[13367071, 302747, 779, 22, 42, "NE3",
      CellTags->{"i:54", "(7.3.1)"}]},
  "(7.3.2)"->{
    Cell[13368319, 302786, 140, 5, 32, "NE3",
      CellTags->"(7.3.2)"]},
  "c:29"->{
    Cell[13372511, 302903, 75, 1, 30, "Subsubtitle",
      CellTags->"c:29"]},
  "Fig. 7.10"->{
    Cell[13643453, 309657, 516, 12, 44, "Caption",
      CellTags->"Fig. 7.10"]},
  "i:89"->{
    Cell[13645126, 309700, 926, 15, 129, "Text",
      CellTags->"i:89"]},
  "i:61"->{
    Cell[13646846, 309738, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:61", "c:30"}]},
  "c:30"->{
    Cell[13646846, 309738, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:61", "c:30"}]},
  "Cell 7.66"->{
    Cell[13656655, 310043, 2383, 46, 505, "Input",
      CellTags->"Cell 7.66"]},
  "i:60"->{
    Cell[13659041, 310091, 1674, 49, 114, "Text",
      CellTags->"i:60"]},
  "c:31"->{
    Cell[13662247, 310202, 54, 1, 30, "Subsubtitle",
      CellTags->"c:31"]},
  "c:32"->{
    Cell[13662326, 310207, 63, 1, 42, "Section",
      CellTags->"c:32"]},
  "Cell 7.67"->{
    Cell[13664627, 310293, 222, 6, 121, "Input",
      CellTags->"Cell 7.67"]},
  "i:88"->{
    Cell[13664852, 310301, 542, 13, 60, "Text",
      CellTags->"i:88"]},
  "i:58"->{
    Cell[13665397, 310316, 958, 35, 60, "Text",
      CellTags->"i:58"]},
  "(7.3.3)"->{
    Cell[13666358, 310353, 1263, 38, 45, "NE3",
      CellTags->"(7.3.3)"]},
  "i:59"->{
    Cell[13667624, 310393, 725, 27, 41, "Text",
      CellTags->"i:59"]},
  "(7.3.4)"->{
    Cell[13668352, 310422, 999, 29, 45, "NE3",
      CellTags->"(7.3.4)"]},
  "(7.3.5)"->{
    Cell[13669629, 310462, 424, 14, 40, "NE3",
      CellTags->"(7.3.5)"]},
  "(7.3.6)"->{
    Cell[13673549, 310583, 2541, 75, 85, "NE3",
      CellTags->"(7.3.6)"]},
  "Fig. 7.11"->{
    Cell[14489210, 321902, 96, 1, 15, "Caption",
      CellTags->"Fig. 7.11"]},
  "(7.3.7)"->{
    Cell[14489383, 321907, 1780, 44, 115, "NE3",
      CellTags->"(7.3.7)"]},
  "Cell 7.68"->{
    Cell[14492828, 322003, 2441, 46, 406, "Input",
      CellTags->"Cell 7.68"]},
  "Cell 7.69"->{
    Cell[14497075, 322100, 1333, 29, 220, "Input",
      CellTags->"Cell 7.69"]},
  "Cell 7.70"->{
    Cell[14499365, 322167, 395, 10, 140, "Input",
      CellTags->"Cell 7.70"]},
  "i:62"->{
    Cell[14608105, 325349, 70, 1, 31, "Section",
      CellTags->{"i:62", "c:33"}]},
  "c:33"->{
    Cell[14608105, 325349, 70, 1, 31, "Section",
      CellTags->{"i:62", "c:33"}]},
  "(7.3.8)"->{
    Cell[14609047, 325382, 901, 24, 75, "NE3",
      CellTags->"(7.3.8)"]},
  "Cell 7.71"->{
    Cell[14610461, 325426, 3567, 69, 690, "Input",
      CellTags->"Cell 7.71"]},
  "Cell 7.72"->{
    Cell[14617543, 325597, 201, 5, 105, "Input",
      CellTags->"Cell 7.72"]},
  "Cell 7.73"->{
    Cell[14764859, 328132, 433, 10, 121, "Input",
      CellTags->"Cell 7.73"]},
  "i:63"->{
    Cell[14912630, 331977, 121, 4, 31, "Section",
      CellTags->{"i:63", "c:34"}]},
  "c:34"->{
    Cell[14912630, 331977, 121, 4, 31, "Section",
      CellTags->{"i:63", "c:34"}]},
  "Cell 7.74"->{
    Cell[14913186, 331996, 516, 11, 140, "Input",
      CellTags->"Cell 7.74"]},
  "Cell 7.75"->{
    Cell[14914231, 332024, 121, 4, 85, "Input",
      CellTags->"Cell 7.75"]},
  "Cell 7.76"->{
    Cell[14915701, 332061, 4242, 83, 655, "Input",
      CellTags->"Cell 7.76"]},
  "Cell 7.77"->{
    Cell[14920398, 332162, 907, 21, 180, "Input",
      CellTags->"Cell 7.77"]},
  "c:35"->{
    Cell[14921354, 332189, 57, 1, 30, "Subsubtitle",
      CellTags->"c:35"]},
  "c:36"->{
    Cell[14921436, 332194, 50, 1, 42, "Section",
      CellTags->"c:36"]},
  "Cell 7.78"->{
    Cell[14923199, 332251, 613, 14, 255, "Input",
      CellTags->"Cell 7.78"]},
  "Cell 7.79"->{
    Cell[14924221, 332280, 200, 5, 85, "Input",
      CellTags->"Cell 7.79"]},
  "Cell 7.80"->{
    Cell[15620019, 346498, 349, 8, 105, "Input",
      CellTags->"Cell 7.80"]},
  "Cell 7.81"->{
    Cell[15663799, 347477, 663, 13, 200, "Input",
      CellTags->"Cell 7.81"]},
  "(7.3.9)"->{
    Cell[15712173, 348381, 249, 7, 50, "NE3",
      CellTags->"(7.3.9)"]},
  "(7.3.10)"->{
    Cell[15712659, 348398, 739, 21, 35, "NE3",
      CellTags->"(7.3.10)"]},
  "Cell 7.82"->{
    Cell[15714712, 348468, 1396, 27, 390, "Input",
      CellTags->"Cell 7.82"]},
  "Cell 7.83"->{
    Cell[15776137, 349514, 951, 19, 255, "Input",
      CellTags->"Cell 7.83"]},
  "(7.3.11)"->{
    Cell[15816451, 350361, 953, 26, 45, "NE3",
      CellTags->"(7.3.11)"]},
  "(7.3.12)"->{
    Cell[15821725, 350517, 1323, 38, 41, "NE3",
      CellTags->"(7.3.12)"]},
  "i:56"->{
    Cell[15828185, 350718, 85, 1, 31, "Section",
      CellTags->{"i:56", "c:37"}]},
  "c:37"->{
    Cell[15828185, 350718, 85, 1, 31, "Section",
      CellTags->{"i:56", "c:37"}]},
  "i:80"->{
    Cell[15828273, 350721, 756, 20, 78, "Text",
      CellTags->"i:80"]},
  "Cell 7.84"->{
    Cell[15830224, 350774, 449, 10, 162, "Input",
      CellTags->"Cell 7.84"]},
  "Cell 7.85"->{
    Cell[15830747, 350790, 200, 5, 86, "Input",
      CellTags->"Cell 7.85"]},
  "Cell 7.86"->{
    Cell[15831537, 350812, 187, 4, 67, "Input",
      CellTags->"Cell 7.86"]},
  "i:57"->{
    Cell[15872377, 351629, 97, 1, 31, "Section",
      CellTags->{"i:57", "c:38"}]},
  "c:38"->{
    Cell[15872377, 351629, 97, 1, 31, "Section",
      CellTags->{"i:57", "c:38"}]},
  "Cell 7.87"->{
    Cell[15872958, 351648, 453, 10, 143, "Input",
      CellTags->"Cell 7.87"]},
  "Cell 7.88"->{
    Cell[15873497, 351664, 200, 5, 86, "Input",
      CellTags->"Cell 7.88"]},
  "Cell 7.89"->{
    Cell[15873722, 351673, 338, 7, 105, "Input",
      CellTags->"Cell 7.89"]},
  "i:83"->{
    Cell[15911475, 352464, 856, 27, 61, "Text",
      CellTags->"i:83"]},
  "(7.3.13)"->{
    Cell[15912334, 352493, 1241, 36, 111, "NE3",
      CellTags->"(7.3.13)"]},
  "i:81"->{
    Cell[15914196, 352550, 190, 6, 32, "NE3",
      CellTags->{"i:81", "(7.3.14)"}]},
  "(7.3.14)"->{
    Cell[15914196, 352550, 190, 6, 32, "NE3",
      CellTags->{"i:81", "(7.3.14)"}]},
  "(7.3.15)"->{
    Cell[15915606, 352592, 160, 5, 38, "NE3",
      CellTags->"(7.3.15)"]},
  "(7.3.16)"->{
    Cell[15916248, 352613, 189, 6, 43, "NE3",
      CellTags->"(7.3.16)"]},
  "c:39"->{
    Cell[15917266, 352644, 47, 1, 31, "Section",
      CellTags->"c:39"]},
  "(7.3.17)"->{
    Cell[15920464, 352740, 154, 6, 38, "NE3",
      CellTags->"(7.3.17)"]},
  "Cell 7.90"->{
    Cell[15920921, 352762, 1030, 21, 371, "Input",
      CellTags->"Cell 7.90"]},
  "Cell 7.91"->{
    Cell[15922025, 352789, 200, 5, 86, "Input",
      CellTags->"Cell 7.91"]},
  "Cell 7.92"->{
    Cell[15922250, 352798, 298, 6, 86, "Input",
      CellTags->"Cell 7.92"]},
  "c:40"->{
    Cell[15979709, 353819, 65, 1, 30, "Subsubtitle",
      CellTags->"c:40"]},
  "i:82"->{
    Cell[15981489, 353876, 1231, 36, 65, "Text",
      CellTags->"i:82"]},
  "(7.3.18)"->{
    Cell[15982723, 353914, 1682, 46, 68, "NE3",
      CellTags->"(7.3.18)"]},
  "(7.3.19)"->{
    Cell[15988417, 354108, 120, 2, 33, "NE3",
      CellTags->"(7.3.19)"]},
  "i:65"->{
    Cell[15993185, 354261, 623, 13, 95, "Text",
      CellTags->"i:65"]},
  "(7.3.20)"->{
    Cell[15993908, 354281, 649, 20, 41, "NE3",
      CellTags->"(7.3.20)"]},
  "(7.3.21)"->{
    Cell[15994673, 354308, 675, 23, 29, "NE3",
      CellTags->"(7.3.21)"]},
  "i:64"->{
    Cell[15995351, 354333, 536, 18, 44, "Text",
      CellTags->"i:64"]},
  "(7.3.22)"->{
    Cell[15995890, 354353, 606, 21, 30, "NE3",
      CellTags->"(7.3.22)"]},
  "(7.3.23)"->{
    Cell[15997468, 354409, 380, 12, 38, "NE3",
      CellTags->"(7.3.23)"]},
  "i:66"->{
    Cell[15997851, 354423, 1480, 49, 62, "Text",
      CellTags->"i:66"]},
  "(7.3.24)"->{
    Cell[15999334, 354474, 402, 10, 69, "NE3",
      CellTags->"(7.3.24)"]},
  "i:69"->{
    Cell[15999739, 354486, 2160, 60, 133, "Text",
      CellTags->"i:69"]},
  "(7.3.25)"->{
    Cell[16002205, 354560, 1643, 47, 32, "NE3",
      CellTags->"(7.3.25)"]},
  "i:84"->{
    Cell[16003851, 354609, 1482, 43, 112, "Text",
      CellTags->"i:84"]},
  "Table 7.1"->{
    Cell[16005336, 354654, 734, 26, 187, "Text",
      CellTags->"Table 7.1"]},
  "i:68"->{
    Cell[16006073, 354682, 1418, 40, 129, "Text",
      CellTags->"i:68"]},
  "i:67"->{
    Cell[16007494, 354724, 451, 13, 61, "Text",
      CellTags->"i:67"]},
  "Cell 7.93"->{
    Cell[16007948, 354739, 7403, 150, 854, "Input",
      CellTags->"Cell 7.93"]},
  "i:72"->{
    Cell[16020035, 355039, 1200, 38, 78, "Text",
      CellTags->"i:72"]},
  "i:70"->{
    Cell[16022290, 355106, 1459, 47, 95, "Text",
      CellTags->"i:70"]},
  "i:71"->{
    Cell[16024180, 355170, 1145, 30, 129, "Text",
      CellTags->"i:71"]},
  "Cell 7.94"->{
    Cell[16025328, 355202, 788, 17, 219, "Input",
      CellTags->"Cell 7.94"]},
  "Cell 7.95"->{
    Cell[16028533, 355301, 162, 4, 86, "Input",
      CellTags->"Cell 7.95"]},
  "i:92"->{
    Cell[17092028, 397412, 1028, 30, 82, "Text",
      CellTags->"i:92"]},
  "Cell 7.96"->{
    Cell[17094335, 397484, 418, 8, 181, "Input",
      CellTags->"Cell 7.96"]},
  "Cell 7.97"->{
    Cell[17094975, 397503, 121, 3, 67, "Input",
      CellTags->"Cell 7.97"]},
  "Cell 7.98"->{
    Cell[17095488, 397520, 202, 5, 67, "Input",
      CellTags->"Cell 7.98"]},
  "i:90"->{
    Cell[17097275, 397576, 403, 14, 44, "Text",
      CellTags->"i:90"]},
  "Cell 7.99"->{
    Cell[17098908, 397636, 244, 5, 105, "Input",
      CellTags->"Cell 7.99"]},
  "Cell 7.100"->{
    Cell[17099155, 397643, 283, 6, 105, "Input",
      CellTags->"Cell 7.100"]},
  "Cell 7.101"->{
    Cell[17099441, 397651, 117, 3, 67, "Input",
      CellTags->"Cell 7.101"]},
  "i:91"->{
    Cell[17100082, 397674, 1145, 31, 95, "Text",
      CellTags->"i:91"]},
  "refs"->{
    Cell[17101276, 397711, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:41"}]},
  "c:41"->{
    Cell[17101276, 397711, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:41"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 17145950, 399110},
  {"i:1", 17146026, 399113},
  {"c:3", 17146114, 399116},
  {"i:15", 17146203, 399119},
  {"c:4", 17146294, 399122},
  {"(7.1.1)", 17146389, 399125},
  {"(7.1.2)", 17146485, 399128},
  {"(7.1.3)", 17146581, 399131},
  {"i:2", 17146673, 399134},
  {"i:3", 17146749, 399137},
  {"(7.1.4)", 17146830, 399140},
  {"(7.1.5)", 17146926, 399143},
  {"(7.1.6)", 17147022, 399146},
  {"(7.1.7)", 17147118, 399149},
  {"(7.1.8)", 17147215, 399152},
  {"(7.1.9)", 17147312, 399155},
  {"c:5", 17147405, 399158},
  {"(7.1.10)", 17147493, 399161},
  {"(7.1.11)", 17147592, 399164},
  {"(7.1.12)", 17147691, 399167},
  {"(7.1.13)", 17147790, 399170},
  {"c:6", 17147884, 399173},
  {"(7.1.14)", 17147969, 399176},
  {"(7.1.15)", 17148068, 399179},
  {"i:78", 17148163, 399182},
  {"Cell 7.1", 17148247, 399185},
  {"Fig. 7.1", 17148335, 399188},
  {"c:7", 17148423, 399191},
  {"(7.1.16)", 17148510, 399194},
  {"Fig. 7.2", 17148611, 399197},
  {"(7.1.17)", 17148704, 399200},
  {"Cell 7.2", 17148805, 399203},
  {"c:8", 17148891, 399206},
  {"i:4", 17148973, 399209},
  {"(7.1.18)", 17149084, 399212},
  {"(7.1.19)", 17149195, 399215},
  {"(7.1.20)", 17149297, 399218},
  {"i:5", 17149394, 399221},
  {"Cell 7.3", 17149480, 399224},
  {"Cell 7.4", 17149573, 399227},
  {"Cell 7.5", 17149666, 399230},
  {"c:9", 17149755, 399233},
  {"i:20", 17149839, 399236},
  {"(7.1.21)", 17149927, 399239},
  {"i:19", 17150026, 399242},
  {"i:6", 17150109, 399245},
  {"i:7", 17150191, 399248},
  {"Cell 7.6", 17150278, 399251},
  {"(7.1.22)", 17150372, 399254},
  {"i:8", 17150470, 399257},
  {"Cell 7.7", 17150557, 399260},
  {"i:9", 17150646, 399263},
  {"(7.1.23)", 17150734, 399266},
  {"(7.1.24)", 17150837, 399269},
  {"(7.1.25)", 17150940, 399272},
  {"(7.1.26)", 17151043, 399275},
  {"Cell 7.8", 17151146, 399278},
  {"Cell 7.9", 17151238, 399281},
  {"Cell 7.10", 17151332, 399284},
  {"Cell 7.11", 17151428, 399287},
  {"(7.1.27)", 17151521, 399290},
  {"Cell 7.12", 17151625, 399293},
  {"i:10", 17151714, 399296},
  {"Cell 7.13", 17151802, 399299},
  {"Cell 7.14", 17151897, 399302},
  {"Cell 7.15", 17151991, 399305},
  {"Cell 7.16", 17152085, 399308},
  {"Cell 7.17", 17152179, 399311},
  {"i:11", 17152268, 399314},
  {"Cell 7.18", 17152358, 399317},
  {"Cell 7.19", 17152452, 399320},
  {"i:12", 17152541, 399323},
  {"(7.1.28)", 17152629, 399326},
  {"i:13", 17152728, 399329},
  {"Cell 7.20", 17152816, 399332},
  {"Cell 7.21", 17152909, 399335},
  {"Cell 7.22", 17153005, 399338},
  {"Fig. 7.3", 17153098, 399341},
  {"i:14", 17153188, 399344},
  {"c:10", 17153287, 399347},
  {"c:11", 17153386, 399350},
  {"(7.1.29)", 17153475, 399353},
  {"i:17", 17153574, 399356},
  {"i:85", 17153660, 399359},
  {"(7.1.30)", 17153773, 399362},
  {"c:12", 17153882, 399365},
  {"(7.1.31)", 17153971, 399368},
  {"(7.1.32)", 17154074, 399371},
  {"(7.1.33)", 17154177, 399374},
  {"i:18", 17154276, 399377},
  {"(7.1.34)", 17154389, 399380},
  {"Fig. 7.4", 17154502, 399383},
  {"Cell 7.23", 17154597, 399386},
  {"Cell 7.24", 17154691, 399389},
  {"i:87", 17154780, 399392},
  {"Cell 7.25", 17154869, 399395},
  {"Cell 7.26", 17154964, 399398},
  {"i:16", 17155053, 399401},
  {"c:13", 17155148, 399404},
  {"(7.1.35)", 17155247, 399407},
  {"(7.1.36)", 17155351, 399410},
  {"(7.1.37)", 17155454, 399413},
  {"(7.1.38)", 17155557, 399416},
  {"(7.1.39)", 17155660, 399419},
  {"Cell 7.27", 17155764, 399422},
  {"Cell 7.28", 17155858, 399425},
  {"(7.1.40)", 17155951, 399428},
  {"(7.1.41)", 17156056, 399431},
  {"c:14", 17156156, 399434},
  {"i:21", 17156245, 399437},
  {"(7.1.42)", 17156334, 399440},
  {"i:22", 17156434, 399443},
  {"i:23", 17156519, 399446},
  {"(7.1.43)", 17156607, 399449},
  {"i:24", 17156706, 399452},
  {"c:15", 17156802, 399455},
  {"c:16", 17156898, 399458},
  {"(7.2.1)", 17156990, 399461},
  {"Cell 7.29", 17157080, 399464},
  {"(7.2.2)", 17157172, 399467},
  {"(7.2.3)", 17157260, 399470},
  {"i:25", 17157345, 399473},
  {"(7.2.4)", 17157432, 399476},
  {"i:26", 17157517, 399479},
  {"c:17", 17157617, 399482},
  {"(7.2.5)", 17157720, 399485},
  {"(7.2.6)", 17157808, 399488},
  {"Cell 7.30", 17157898, 399491},
  {"Cell 7.31", 17157994, 399494},
  {"(7.2.7)", 17158086, 399497},
  {"(7.2.8)", 17158174, 399500},
  {"Cell 7.32", 17158265, 399503},
  {"(7.2.9)", 17158357, 399506},
  {"Cell 7.33", 17158447, 399509},
  {"i:27", 17158537, 399512},
  {"(7.2.10)", 17158625, 399515},
  {"(7.2.11)", 17158716, 399518},
  {"(7.2.12)", 17158806, 399521},
  {"i:28", 17158892, 399524},
  {"Cell 7.34", 17158981, 399527},
  {"(7.2.13)", 17159074, 399530},
  {"i:29", 17159160, 399533},
  {"Cell 7.35", 17159249, 399536},
  {"Cell 7.36", 17159343, 399539},
  {"(7.2.14)", 17159436, 399542},
  {"(7.2.15)", 17159526, 399545},
  {"Cell 7.37", 17159617, 399548},
  {"Fig. 7.5", 17159712, 399551},
  {"(7.2.16)", 17159807, 399554},
  {"Fig. 7.6", 17159898, 399557},
  {"i:30", 17159990, 399560},
  {"Cell 7.38", 17160080, 399563},
  {"Cell 7.39", 17160176, 399566},
  {"(7.2.17)", 17160270, 399569},
  {"(7.2.18)", 17160361, 399572},
  {"(7.2.19)", 17160452, 399575},
  {"i:31", 17160539, 399578},
  {"i:73", 17160623, 399581},
  {"c:18", 17160710, 399584},
  {"c:19", 17160800, 399587},
  {"i:74", 17160886, 399590},
  {"(7.2.20)", 17160975, 399593},
  {"(7.2.21)", 17161067, 399596},
  {"(7.2.22)", 17161158, 399599},
  {"(7.2.23)", 17161250, 399602},
  {"(7.2.24)", 17161341, 399605},
  {"Cell 7.40", 17161433, 399608},
  {"i:53", 17161523, 399611},
  {"Cell 7.41", 17161613, 399614},
  {"i:44", 17161703, 399617},
  {"c:20", 17161799, 399620},
  {"Cell 7.42", 17161900, 399623},
  {"Cell 7.43", 17161996, 399626},
  {"(7.2.25)", 17162091, 399629},
  {"Cell 7.44", 17162183, 399632},
  {"Cell 7.45", 17162280, 399635},
  {"Cell 7.46", 17162378, 399638},
  {"c:21", 17162468, 399641},
  {"Cell 7.47", 17162559, 399644},
  {"Cell 7.48", 17162655, 399647},
  {"Cell 7.49", 17162752, 399650},
  {"i:45", 17162842, 399653},
  {"c:22", 17162938, 399656},
  {"Cell 7.50", 17163039, 399659},
  {"Cell 7.51", 17163135, 399662},
  {"Fig. 7.7", 17163231, 399665},
  {"Fig. 7.8", 17163325, 399668},
  {"i:46", 17163416, 399671},
  {"c:23", 17163516, 399674},
  {"c:24", 17163616, 399677},
  {"i:47", 17163702, 399680},
  {"(7.2.26)", 17163791, 399683},
  {"(7.2.27)", 17163882, 399686},
  {"(7.2.28)", 17163974, 399689},
  {"i:48", 17164061, 399692},
  {"Cell 7.52", 17164150, 399695},
  {"c:25", 17164240, 399698},
  {"i:75", 17164326, 399701},
  {"(7.2.29)", 17164416, 399704},
  {"Cell 7.53", 17164510, 399707},
  {"(7.2.30)", 17164604, 399710},
  {"Cell 7.54", 17164698, 399713},
  {"Cell 7.55", 17164794, 399716},
  {"(7.2.31)", 17164888, 399719},
  {"i:79", 17164976, 399722},
  {"Cell 7.56", 17165067, 399725},
  {"Cell 7.57", 17165162, 399728},
  {"Cell 7.58", 17165257, 399731},
  {"Cell 7.59", 17165352, 399734},
  {"Cell 7.60", 17165447, 399737},
  {"Cell 7.61", 17165543, 399740},
  {"Cell 7.62", 17165639, 399743},
  {"Cell 7.63", 17165734, 399746},
  {"Cell 7.64", 17165830, 399749},
  {"Cell 7.65", 17165925, 399752},
  {"c:26", 17166016, 399755},
  {"i:32", 17166107, 399758},
  {"(7.2.32)", 17166197, 399761},
  {"i:33", 17166285, 399764},
  {"i:34", 17166371, 399767},
  {"(7.2.33)", 17166460, 399770},
  {"i:35", 17166549, 399773},
  {"i:49", 17166636, 399776},
  {"i:36", 17166723, 399779},
  {"(7.2.34)", 17166825, 399782},
  {"i:50", 17166923, 399785},
  {"i:41", 17167009, 399788},
  {"i:37", 17167096, 399791},
  {"(7.2.35)", 17167198, 399794},
  {"i:38", 17167296, 399797},
  {"(7.2.36)", 17167398, 399800},
  {"i:77", 17167496, 399803},
  {"i:40", 17167582, 399806},
  {"(7.2.37)", 17167684, 399809},
  {"i:39", 17167782, 399812},
  {"i:42", 17167868, 399815},
  {"(7.2.38)", 17167958, 399818},
  {"i:43", 17168046, 399821},
  {"i:51", 17168131, 399824},
  {"i:86", 17168217, 399827},
  {"(7.2.39)", 17168306, 399830},
  {"i:52", 17168396, 399833},
  {"(7.2.40)", 17168487, 399836},
  {"i:55", 17168576, 399839},
  {"c:27", 17168675, 399842},
  {"c:28", 17168774, 399845},
  {"i:76", 17168865, 399848},
  {"Fig. 7.9", 17168957, 399851},
  {"i:54", 17169049, 399854},
  {"(7.3.1)", 17169150, 399857},
  {"(7.3.2)", 17169251, 399860},
  {"c:29", 17169338, 399863},
  {"Fig. 7.10", 17169434, 399866},
  {"i:89", 17169528, 399869},
  {"i:61", 17169615, 399872},
  {"c:30", 17169716, 399875},
  {"Cell 7.66", 17169822, 399878},
  {"i:60", 17169916, 399881},
  {"c:31", 17170004, 399884},
  {"c:32", 17170095, 399887},
  {"Cell 7.67", 17170187, 399890},
  {"i:88", 17170279, 399893},
  {"i:58", 17170365, 399896},
  {"(7.3.3)", 17170454, 399899},
  {"i:59", 17170543, 399902},
  {"(7.3.4)", 17170632, 399905},
  {"(7.3.5)", 17170723, 399908},
  {"(7.3.6)", 17170814, 399911},
  {"Fig. 7.11", 17170908, 399914},
  {"(7.3.7)", 17171003, 399917},
  {"Cell 7.68", 17171098, 399920},
  {"Cell 7.69", 17171197, 399923},
  {"Cell 7.70", 17171296, 399926},
  {"i:62", 17171389, 399929},
  {"c:33", 17171486, 399932},
  {"(7.3.8)", 17171586, 399935},
  {"Cell 7.71", 17171679, 399938},
  {"Cell 7.72", 17171778, 399941},
  {"Cell 7.73", 17171875, 399944},
  {"i:63", 17171968, 399947},
  {"c:34", 17172066, 399950},
  {"Cell 7.74", 17172169, 399953},
  {"Cell 7.75", 17172267, 399956},
  {"Cell 7.76", 17172363, 399959},
  {"Cell 7.77", 17172462, 399962},
  {"c:35", 17172555, 399965},
  {"c:36", 17172646, 399968},
  {"Cell 7.78", 17172738, 399971},
  {"Cell 7.79", 17172836, 399974},
  {"Cell 7.80", 17172932, 399977},
  {"Cell 7.81", 17173029, 399980},
  {"(7.3.9)", 17173125, 399983},
  {"(7.3.10)", 17173216, 399986},
  {"Cell 7.82", 17173310, 399989},
  {"Cell 7.83", 17173409, 399992},
  {"(7.3.11)", 17173506, 399995},
  {"(7.3.12)", 17173599, 399998},
  {"i:56", 17173689, 400001},
  {"c:37", 17173786, 400004},
  {"i:80", 17173883, 400007},
  {"Cell 7.84", 17173974, 400010},
  {"Cell 7.85", 17174072, 400013},
  {"Cell 7.86", 17174168, 400016},
  {"i:57", 17174259, 400019},
  {"c:38", 17174356, 400022},
  {"Cell 7.87", 17174458, 400025},
  {"Cell 7.88", 17174556, 400028},
  {"Cell 7.89", 17174652, 400031},
  {"i:83", 17174744, 400034},
  {"(7.3.13)", 17174834, 400037},
  {"i:81", 17174925, 400040},
  {"(7.3.14)", 17175027, 400043},
  {"(7.3.15)", 17175129, 400046},
  {"(7.3.16)", 17175221, 400049},
  {"c:39", 17175309, 400052},
  {"(7.3.17)", 17175400, 400055},
  {"Cell 7.90", 17175493, 400058},
  {"Cell 7.91", 17175592, 400061},
  {"Cell 7.92", 17175688, 400064},
  {"c:40", 17175779, 400067},
  {"i:82", 17175870, 400070},
  {"(7.3.18)", 17175961, 400073},
  {"(7.3.19)", 17176055, 400076},
  {"i:65", 17176143, 400079},
  {"(7.3.20)", 17176233, 400082},
  {"(7.3.21)", 17176326, 400085},
  {"i:64", 17176415, 400088},
  {"(7.3.22)", 17176505, 400091},
  {"(7.3.23)", 17176598, 400094},
  {"i:66", 17176687, 400097},
  {"(7.3.24)", 17176778, 400100},
  {"i:69", 17176867, 400103},
  {"(7.3.25)", 17176959, 400106},
  {"i:84", 17177049, 400109},
  {"Table 7.1", 17177142, 400112},
  {"i:68", 17177234, 400115},
  {"i:67", 17177322, 400118},
  {"Cell 7.93", 17177413, 400121},
  {"i:72", 17177508, 400124},
  {"i:70", 17177595, 400127},
  {"i:71", 17177682, 400130},
  {"Cell 7.94", 17177775, 400133},
  {"Cell 7.95", 17177873, 400136},
  {"i:92", 17177964, 400139},
  {"Cell 7.96", 17178056, 400142},
  {"Cell 7.97", 17178153, 400145},
  {"Cell 7.98", 17178249, 400148},
  {"i:90", 17178340, 400151},
  {"Cell 7.99", 17178431, 400154},
  {"Cell 7.100", 17178529, 400157},
  {"Cell 7.101", 17178628, 400160},
  {"i:91", 17178720, 400163},
  {"refs", 17178807, 400166},
  {"c:41", 17178905, 400169}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 79, 1, 111, "Title",
  CellTags->"c:1"],
Cell[1809, 55, 16, 0, 27, "Text"],
Cell[1828, 57, 598, 9, 95, "Text"],
Cell[2429, 68, 474, 9, 61, "Text"],
Cell[2906, 79, 169, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[3100, 87, 102, 1, 39, "Subtitle",
  CellTags->{"i:1", "c:3"}],
Cell[3205, 90, 17, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[3247, 94, 73, 1, 41, "Subsubtitle",
  CellTags->{"i:15", "c:4"}],
Cell[3323, 97, 141, 4, 25, "Text"],
Cell[3467, 103, 213, 6, 36, "NumberedEquation",
  CellTags->"(7.1.1)"],
Cell[3683, 111, 107, 3, 25, "Text"],
Cell[3793, 116, 140, 5, 26, "NumberedEquation",
  CellTags->"(7.1.2)"],
Cell[3936, 123, 467, 10, 60, "Text"],
Cell[4406, 135, 663, 14, 75, "Text"],
Cell[5072, 151, 688, 17, 75, "Text"],
Cell[5763, 170, 632, 15, 75, "Text"],
Cell[6398, 187, 200, 8, 26, "NumberedEquation",
  CellTags->"(7.1.3)"],
Cell[6601, 197, 221, 8, 25, "Text",
  CellTags->"i:2"],
Cell[6825, 207, 457, 12, 60, "Text"],
Cell[7285, 221, 248, 6, 36, "UNNEQ"],
Cell[7536, 229, 650, 22, 41, "Text",
  CellTags->"i:3"],
Cell[8189, 253, 296, 7, 36, "NumberedEquation",
  CellTags->"(7.1.4)"],
Cell[8488, 262, 166, 5, 25, "Text"],
Cell[8657, 269, 173, 3, 36, "NumberedEquation",
  CellTags->"(7.1.5)"],
Cell[8833, 274, 402, 10, 41, "Text"],
Cell[9238, 286, 173, 6, 35, "NumberedEquation",
  CellTags->"(7.1.6)"],
Cell[9414, 294, 508, 18, 41, "Text"],
Cell[9925, 314, 377, 10, 41, "Text"],
Cell[10305, 326, 213, 6, 36, "NumberedEquation",
  CellTags->"(7.1.7)"],
Cell[10521, 334, 771, 23, 75, "Text"],
Cell[11295, 359, 1059, 38, 60, "Text"],
Cell[12357, 399, 264, 7, 40, "NumberedEquation",
  CellTags->"(7.1.8)"],
Cell[12624, 408, 397, 12, 41, "Text"],
Cell[13024, 422, 192, 3, 36, "NumberedEquation",
  CellTags->"(7.1.9)"],
Cell[13219, 427, 363, 10, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13619, 442, 60, 1, 30, "Subsubtitle",
  CellTags->"c:5"],
Cell[13682, 445, 790, 25, 61, "Text"],
Cell[14475, 472, 166, 3, 27, "NumberedEquation",
  CellTags->"(7.1.10)"],
Cell[14644, 477, 174, 3, 27, "NumberedEquation",
  CellTags->"(7.1.11)"],
Cell[14821, 482, 469, 17, 44, "Text"],
Cell[15293, 501, 929, 30, 61, "Text"],
Cell[16225, 533, 247, 7, 33, "NumberedEquation",
  CellTags->"(7.1.12)"],
Cell[16475, 542, 545, 21, 46, "Text"],
Cell[17023, 565, 530, 20, 44, "Text"],
Cell[17556, 587, 334, 9, 33, "NumberedEquation",
  CellTags->"(7.1.13)"],
Cell[17893, 598, 396, 12, 44, "Text"],

Cell[CellGroupData[{
Cell[18314, 614, 190, 8, 42, "Section",
  CellTags->"c:6"],
Cell[18507, 624, 149, 6, 25, "Text"],
Cell[18659, 632, 191, 6, 36, "NumberedEquation",
  CellTags->"(7.1.14)"],
Cell[18853, 640, 428, 12, 41, "Text"],
Cell[19284, 654, 191, 3, 45, "UNNEQ"],
Cell[19478, 659, 589, 19, 41, "Text"],
Cell[20070, 680, 792, 26, 60, "Text"],
Cell[20865, 708, 226, 6, 26, "NumberedEquation",
  CellTags->"(7.1.15)"],
Cell[21094, 716, 325, 12, 25, "Text"],
Cell[21422, 730, 1300, 39, 126, "Text"],
Cell[22725, 771, 393, 12, 41, "Text"],
Cell[23121, 785, 198, 5, 26, "UNNEQ"],
Cell[23322, 792, 452, 13, 41, "Text",
  CellTags->"i:78"],

Cell[CellGroupData[{
Cell[23799, 809, 202, 5, 85, "Input",
  CellTags->"Cell 7.1"],
Cell[24004, 816, 38, 1, 45, "Output"]
}, Open  ]],
Cell[24057, 820, 864, 21, 95, "Text"],
Cell[24924, 843, 88372, 4083, 430, 38393, 3462, "GraphicsData", "PostScript", \
"Picture"],
Cell[113299, 4928, 374, 13, 15, "Caption",
  CellTags->"Fig. 7.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[113710, 4946, 196, 9, 32, "Section",
  CellTags->"c:7"],
Cell[113909, 4957, 267, 10, 25, "Text"],
Cell[114179, 4969, 203, 3, 45, "UNNEQ"],
Cell[114385, 4974, 269, 8, 25, "Text"],
Cell[114657, 4984, 179, 6, 30, "NumberedEquation",
  CellTags->"(7.1.16)"],
Cell[114839, 4992, 157, 6, 25, "Text"],
Cell[114999, 5000, 77312, 3369, 355, 31711, 2802, "GraphicsData", \
"PostScript", "Picture"],
Cell[192314, 8371, 477, 17, 26, "Caption",
  CellTags->"Fig. 7.2"],
Cell[192794, 8390, 343, 9, 30, "Text"],
Cell[193140, 8401, 221, 7, 40, "NumberedEquation",
  CellTags->"(7.1.17)"],
Cell[193364, 8410, 642, 21, 46, "Text"],
Cell[194009, 8433, 303, 8, 40, "UNNEQ"],
Cell[194315, 8443, 368, 13, 31, "Text"],

Cell[CellGroupData[{
Cell[194708, 8460, 303, 7, 110, "Input",
  CellTags->"Cell 7.2"],

Cell[CellGroupData[{
Cell[195036, 8471, 34102, 1309, 230, 12269, 1036, "GraphicsData", \
"PostScript", "Graphics"],
Cell[229141, 9782, 33957, 1260, 70, 11674, 981, "GraphicsData", "PostScript", \
"Graphics"],
Cell[263101, 11044, 33174, 1168, 70, 10668, 886, "GraphicsData", \
"PostScript", "Graphics"],
Cell[296278, 12214, 32262, 1043, 70, 9258, 755, "GraphicsData", "PostScript", \
"Graphics"],
Cell[328543, 13259, 30766, 894, 70, 7628, 604, "GraphicsData", "PostScript", \
"Graphics"],
Cell[359312, 14155, 29697, 773, 70, 6268, 480, "GraphicsData", "PostScript", \
"Graphics"],
Cell[389012, 14930, 28974, 698, 70, 5435, 403, "GraphicsData", "PostScript", \
"Graphics"],
Cell[417989, 15630, 28639, 653, 70, 4955, 357, "GraphicsData", "PostScript", \
"Graphics"],
Cell[446631, 16285, 28411, 620, 70, 4500, 321, "GraphicsData", "PostScript", \
"Graphics"],
Cell[475045, 16907, 28236, 609, 70, 4325, 310, "GraphicsData", "PostScript", \
"Graphics"],
Cell[503284, 17518, 27926, 591, 70, 4043, 292, "GraphicsData", "PostScript", \
"Graphics"],
Cell[531213, 18111, 26881, 576, 70, 4015, 290, "GraphicsData", "PostScript", \
"Graphics"],
Cell[558097, 18689, 25225, 553, 70, 3959, 287, "GraphicsData", "PostScript", \
"Graphics"],
Cell[583325, 19244, 23537, 533, 70, 3980, 288, "GraphicsData", "PostScript", \
"Graphics"],
Cell[606865, 19779, 22452, 521, 70, 4000, 289, "GraphicsData", "PostScript", \
"Graphics"],
Cell[629320, 20302, 21473, 494, 70, 3714, 271, "GraphicsData", "PostScript", \
"Graphics"],
Cell[650796, 20798, 20628, 474, 70, 3525, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[671427, 21274, 19946, 466, 70, 3523, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[691376, 21742, 19452, 460, 70, 3523, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[710831, 22204, 19171, 456, 70, 3522, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[730005, 22662, 18928, 453, 70, 3522, 259, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[748960, 23119, 489, 13, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[749486, 23137, 60, 1, 31, "Section",
  CellTags->"c:8"],
Cell[749549, 23140, 207, 6, 27, "Text"],
Cell[749759, 23148, 287, 7, 42, "NumberedEquation",
  CellTags->{"i:4", "(7.1.18)"}],
Cell[750049, 23157, 861, 30, 63, "Text"],
Cell[750913, 23189, 156, 5, 39, "NumberedEquation",
  CellTags->"(7.1.19)"],
Cell[751072, 23196, 702, 19, 61, "Text"],
Cell[751777, 23217, 205, 6, 27, "Text"],
Cell[751985, 23225, 309, 9, 46, "NumberedEquation",
  CellTags->"(7.1.20)"],
Cell[752297, 23236, 779, 24, 79, "Text"],
Cell[753079, 23262, 323, 10, 78, "Text",
  CellTags->"i:5"],
Cell[753405, 23274, 406, 11, 45, "Text"],
Cell[753814, 23287, 270, 9, 27, "Text"],
Cell[754087, 23298, 479, 11, 143, "Input",
  CellTags->"Cell 7.3"],
Cell[754569, 23311, 346, 13, 27, "Text"],

Cell[CellGroupData[{
Cell[754940, 23328, 428, 10, 143, "Input",
  CellTags->"Cell 7.4"],
Cell[755371, 23340, 251125, 10720, 370, 146362, 9423, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1006511, 34063, 272, 5, 61, "Text"],
Cell[1006786, 34070, 358, 9, 61, "Text"],

Cell[CellGroupData[{
Cell[1007169, 34083, 456, 10, 124, "Input",
  CellTags->"Cell 7.5"],

Cell[CellGroupData[{
Cell[1007650, 34097, 27354, 718, 370, 5312, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1035007, 34817, 29208, 741, 370, 5331, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1064218, 35560, 30215, 753, 370, 5338, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1094436, 36315, 28526, 732, 370, 5334, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1122965, 37049, 31959, 775, 370, 5328, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1154927, 37826, 33592, 795, 370, 5337, 442, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1188546, 38625, 347, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1188930, 38636, 85, 1, 31, "Section",
  CellTags->"c:9"],
Cell[1189018, 38639, 943, 30, 61, "Text",
  CellTags->"i:20"],
Cell[1189964, 38671, 232, 6, 42, "NumberedEquation",
  CellTags->"(7.1.21)"],
Cell[1190199, 38679, 201, 5, 27, "Text"],
Cell[1190403, 38686, 231, 7, 71, "UNNEQ",
  CellTags->"i:19"],
Cell[1190637, 38695, 186, 6, 27, "Text"],
Cell[1190826, 38703, 991, 24, 95, "Text",
  CellTags->"i:6"],
Cell[1191820, 38729, 690, 24, 63, "Text",
  CellTags->"i:7"],
Cell[1192513, 38755, 989, 30, 95, "Text"],

Cell[CellGroupData[{
Cell[1193527, 38789, 933, 21, 314, "Input",
  CellTags->"Cell 7.6"],
Cell[1194463, 38812, 100155, 4572, 233, 64706, 4130, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1294633, 43387, 758, 17, 95, "Text"],
Cell[1295394, 43406, 142, 3, 27, "NumberedEquation",
  CellTags->"(7.1.22)"],
Cell[1295539, 43411, 627, 14, 95, "Text",
  CellTags->"i:8"],
Cell[1296169, 43427, 445, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[1296639, 43444, 467, 11, 143, "Input",
  CellTags->"Cell 7.7"],

Cell[CellGroupData[{
Cell[1297131, 43459, 47198, 1305, 370, 14595, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1344332, 44766, 46509, 1296, 370, 14571, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1390844, 46064, 47012, 1294, 370, 14385, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1437859, 47360, 46017, 1283, 370, 14387, 888, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1483879, 48645, 46520, 1291, 370, 14416, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1530402, 49938, 46907, 1299, 370, 14479, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1577312, 51239, 47675, 1311, 370, 14571, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1624990, 52552, 47349, 1303, 370, 14488, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1672342, 53857, 48361, 1317, 370, 14503, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1720706, 55176, 48549, 1318, 370, 14493, 893, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1769282, 56498, 1577, 47, 96, "Text",
  CellTags->"i:9"],
Cell[1770862, 56547, 225, 6, 44, "NumberedEquation",
  CellTags->"(7.1.23)"],
Cell[1771090, 56555, 1032, 32, 82, "Text"],
Cell[1772125, 56589, 318, 9, 44, "NumberedEquation",
  CellTags->"(7.1.24)"],
Cell[1772446, 56600, 58, 0, 27, "Text"],
Cell[1772507, 56602, 138, 5, 30, "NumberedEquation",
  CellTags->"(7.1.25)"],
Cell[1772648, 56609, 425, 8, 65, "Text"],
Cell[1773076, 56619, 1282, 37, 102, "Text"],
Cell[1774361, 56658, 312, 8, 47, "NumberedEquation",
  CellTags->"(7.1.26)"],
Cell[1774676, 56668, 731, 17, 78, "Text"],
Cell[1775410, 56687, 368, 11, 44, "Text"],
Cell[1775781, 56700, 239, 6, 86, "Input",
  CellTags->"Cell 7.8"],
Cell[1776023, 56708, 377, 12, 46, "Text"],
Cell[1776403, 56722, 244, 5, 117, "Input",
  CellTags->"Cell 7.9"],
Cell[1776650, 56729, 393, 14, 27, "Text"],
Cell[1777046, 56745, 393, 10, 181, "Input",
  CellTags->"Cell 7.10"],
Cell[1777442, 56757, 182, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[1777649, 56767, 240, 6, 88, "Input",
  CellTags->"Cell 7.11"],
Cell[1777892, 56775, 31966, 691, 233, 6648, 374, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1809873, 57469, 300, 11, 44, "Text"],
Cell[1810176, 57482, 339, 9, 44, "Text"],
Cell[1810518, 57493, 181, 5, 32, "UNNEQ"],
Cell[1810702, 57500, 783, 25, 63, "Text"],
Cell[1811488, 57527, 278, 7, 47, "UNNEQ"],
Cell[1811769, 57536, 216, 6, 28, "Text"],
Cell[1811988, 57544, 190, 6, 30, "UNNEQ"],
Cell[1812181, 57552, 22, 0, 27, "Text"],
Cell[1812206, 57554, 244, 6, 47, "UNNEQ"],
Cell[1812453, 57562, 68, 0, 27, "Text"],
Cell[1812524, 57564, 243, 8, 38, "NumberedEquation",
  CellTags->"(7.1.27)"],
Cell[1812770, 57574, 470, 15, 44, "Text"],
Cell[1813243, 57591, 462, 14, 45, "Text"],
Cell[1813708, 57607, 210, 6, 86, "Input",
  CellTags->"Cell 7.12"],
Cell[1813921, 57615, 343, 8, 44, "Text",
  CellTags->"i:10"],
Cell[1814267, 57625, 316, 7, 143, "Input",
  CellTags->"Cell 7.13"],
Cell[1814586, 57634, 168, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[1814779, 57644, 225, 5, 67, "Input",
  CellTags->"Cell 7.14"],
Cell[1815007, 57651, 24010, 564, 233, 6033, 338, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1839032, 58218, 184, 6, 28, "Text"],
Cell[1839219, 58226, 202, 5, 86, "Input",
  CellTags->"Cell 7.15"],
Cell[1839424, 58233, 478, 16, 46, "Text"],
Cell[1839905, 58251, 250, 6, 86, "Input",
  CellTags->"Cell 7.16"],
Cell[1840158, 58259, 289, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[1840472, 58271, 298, 6, 88, "Input",
  CellTags->"Cell 7.17"],
Cell[1840773, 58279, 310674, 5831, 346, 131261, 3612, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2151462, 64113, 258, 7, 44, "Text"],
Cell[2151723, 64122, 1110, 33, 99, "Text",
  CellTags->"i:11"],
Cell[2152836, 64157, 171, 4, 44, "Text"],
Cell[2153010, 64163, 169, 4, 67, "Input",
  CellTags->"Cell 7.18"],
Cell[2153182, 64169, 163, 6, 27, "Text"],
Cell[2153348, 64177, 178, 5, 67, "Input",
  CellTags->"Cell 7.19"],
Cell[2153529, 64184, 422, 11, 61, "Text",
  CellTags->"i:12"],
Cell[2153954, 64197, 231, 7, 32, "NumberedEquation",
  CellTags->"(7.1.28)"],
Cell[2154188, 64206, 1014, 31, 61, "Text"],
Cell[2155205, 64239, 120, 4, 29, "UNNEQ"],
Cell[2155328, 64245, 240, 7, 44, "Text",
  CellTags->"i:13"],
Cell[2155571, 64254, 92, 3, 67, "Input",
  CellTags->"Cell 7.20"],
Cell[2155666, 64259, 749, 21, 78, "Text"],
Cell[2156418, 64282, 587, 13, 200, "Input",
  CellTags->"Cell 7.21"],
Cell[2157008, 64297, 585, 16, 61, "Text"],
Cell[2157596, 64315, 333, 11, 27, "Text"],
Cell[2157932, 64328, 173, 5, 67, "Input",
  CellTags->"Cell 7.22"],
Cell[2158108, 64335, 500, 16, 44, "Text"],
Cell[2158611, 64353, 30698, 776, 233, 6665, 475, "GraphicsData", \
"PostScript", "Picture"],
Cell[2189312, 65131, 209, 6, 16, "Caption",
  CellTags->"Fig. 7.3"],
Cell[2189524, 65139, 893, 13, 146, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2190466, 65158, 74, 1, 30, "Subsubtitle",
  CellTags->{"i:14", "c:10"}],

Cell[CellGroupData[{
Cell[2190565, 65163, 76, 1, 42, "Section",
  CellTags->"c:11"],
Cell[2190644, 65166, 144, 3, 41, "Text"],
Cell[2190791, 65171, 222, 6, 35, "NumberedEquation",
  CellTags->"(7.1.29)"],
Cell[2191016, 65179, 1547, 42, 130, "Text",
  CellTags->"i:17"],
Cell[2192566, 65223, 497, 14, 60, "Text"],
Cell[2193066, 65239, 173, 5, 35, "UNNEQ"],
Cell[2193242, 65246, 372, 11, 41, "Text"],
Cell[2193617, 65259, 199, 6, 36, "NumberedEquation",
  CellTags->{"i:85", "(7.1.30)"}],
Cell[2193819, 65267, 477, 12, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2194333, 65284, 47, 1, 31, "Section",
  CellTags->"c:12"],
Cell[2194383, 65287, 503, 12, 60, "Text"],
Cell[2194889, 65301, 174, 6, 26, "NumberedEquation",
  CellTags->"(7.1.31)"],
Cell[2195066, 65309, 375, 10, 41, "Text"],
Cell[2195444, 65321, 185, 5, 26, "NumberedEquation",
  CellTags->"(7.1.32)"],
Cell[2195632, 65328, 159, 5, 25, "Text"],
Cell[2195794, 65335, 153, 5, 26, "NumberedEquation",
  CellTags->"(7.1.33)"],
Cell[2195950, 65342, 301, 9, 25, "Text"],
Cell[2196254, 65353, 161, 5, 26, "NumberedEquation",
  CellTags->{"i:18", "(7.1.34)"}],
Cell[2196418, 65360, 375, 12, 41, "Text"],
Cell[2196796, 65374, 112141, 5367, 450, 50563, 4602, "GraphicsData", \
"PostScript", "Picture"],
Cell[2308940, 70743, 241, 7, 15, "Caption",
  CellTags->"Fig. 7.4"],
Cell[2309184, 70752, 435, 13, 41, "Text"],
Cell[2309622, 70767, 120, 4, 26, "UNNEQ"],
Cell[2309745, 70773, 547, 14, 60, "Text"],
Cell[2310295, 70789, 111, 3, 65, "Input",
  CellTags->"Cell 7.23"],
Cell[2310409, 70794, 192, 7, 25, "Text"],
Cell[2310604, 70803, 136, 3, 65, "Input",
  CellTags->"Cell 7.24"],
Cell[2310743, 70808, 334, 10, 41, "Text"],
Cell[2311080, 70820, 594, 19, 41, "Text",
  CellTags->"i:87"],
Cell[2311677, 70841, 286, 7, 121, "Input",
  CellTags->"Cell 7.25"],
Cell[2311966, 70850, 364, 13, 41, "Text"],

Cell[CellGroupData[{
Cell[2312355, 70867, 273, 7, 85, "Input",
  CellTags->"Cell 7.26"],

Cell[CellGroupData[{
Cell[2312653, 70878, 28271, 646, 230, 5343, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2340927, 71526, 28085, 643, 70, 5372, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2369015, 72171, 27965, 641, 70, 5374, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2396983, 72814, 28153, 644, 70, 5375, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2425139, 73460, 27948, 641, 70, 5377, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2453090, 74103, 27631, 637, 70, 5376, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2480724, 74742, 28117, 643, 70, 5368, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2508844, 75387, 28136, 644, 70, 5366, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2536983, 76033, 28242, 645, 70, 5375, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2565228, 76680, 28176, 644, 70, 5370, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2593407, 77326, 27923, 641, 70, 5376, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2621333, 77969, 28269, 645, 70, 5374, 358, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2649605, 78616, 28202, 644, 70, 5376, 358, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[2677834, 79264, 1014, 19, 145, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2678885, 79288, 66, 1, 31, "Section",
  CellTags->{"i:16", "c:13"}],
Cell[2678954, 79291, 698, 22, 60, "Text"],
Cell[2679655, 79315, 478, 13, 60, "Text"],
Cell[2680136, 79330, 855, 25, 60, "Text"],
Cell[2680994, 79357, 187, 5, 26, "UNNEQ"],
Cell[2681184, 79364, 106, 5, 25, "Text"],
Cell[2681293, 79371, 792, 19, 40, "NumberedEquation",
  CellTags->"(7.1.35)"],
Cell[2682088, 79392, 761, 27, 25, "Text"],
Cell[2682852, 79421, 186, 6, 40, "NumberedEquation",
  CellTags->"(7.1.36)"],
Cell[2683041, 79429, 217, 8, 25, "Text"],
Cell[2683261, 79439, 211, 7, 40, "NumberedEquation",
  CellTags->"(7.1.37)"],
Cell[2683475, 79448, 299, 9, 41, "Text"],
Cell[2683777, 79459, 162, 3, 30, "NumberedEquation",
  CellTags->"(7.1.38)"],
Cell[2683942, 79464, 19, 0, 25, "Text"],
Cell[2683964, 79466, 177, 6, 30, "NumberedEquation",
  CellTags->"(7.1.39)"],
Cell[2684144, 79474, 433, 14, 45, "Text"],

Cell[CellGroupData[{
Cell[2684602, 79492, 106, 3, 65, "Input",
  CellTags->"Cell 7.27"],
Cell[2684711, 79497, 89, 1, 55, "Output"]
}, Open  ]],
Cell[2684815, 79501, 277, 9, 30, "Text"],

Cell[CellGroupData[{
Cell[2685117, 79514, 103, 3, 65, "Input",
  CellTags->"Cell 7.28"],
Cell[2685223, 79519, 58, 1, 75, "Output"]
}, Open  ]],
Cell[2685296, 79523, 262, 5, 45, "Text"],
Cell[2685561, 79530, 983, 27, 75, "Text"],
Cell[2686547, 79559, 1059, 27, 50, "NumberedEquation",
  CellTags->"(7.1.40)"],
Cell[2687609, 79588, 234, 8, 30, "Text"],
Cell[2687846, 79598, 667, 18, 50, "NumberedEquation",
  CellTags->"(7.1.41)"],
Cell[2688516, 79618, 842, 27, 45, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2689407, 79651, 65, 1, 30, "Subsubtitle",
  CellTags->"c:14"],
Cell[2689475, 79654, 99, 4, 27, "Text"],
Cell[2689577, 79660, 270, 10, 27, "Text"],
Cell[2689850, 79672, 157, 7, 27, "Text"],
Cell[2690010, 79681, 433, 15, 39, "Text"],
Cell[2690446, 79698, 400, 15, 37, "Text"],
Cell[2690849, 79715, 390, 15, 37, "Text"],
Cell[2691242, 79732, 194, 8, 27, "Text"],
Cell[2691439, 79742, 622, 21, 47, "Text"],
Cell[2692064, 79765, 418, 12, 47, "Text"],
Cell[2692485, 79779, 505, 16, 57, "Text"],
Cell[2692993, 79797, 1317, 41, 98, "Text"],
Cell[2694313, 79840, 944, 30, 86, "Text"],
Cell[2695260, 79872, 1624, 50, 96, "Text",
  CellTags->"i:21"],
Cell[2696887, 79924, 57, 0, 27, "Text"],
Cell[2696947, 79926, 367, 12, 32, "NumberedEquation",
  CellTags->"(7.1.42)"],
Cell[2697317, 79940, 1252, 38, 110, "Text"],
Cell[2698572, 79980, 772, 19, 46, "UNNEQ"],
Cell[2699347, 80001, 661, 17, 66, "Text"],
Cell[2700011, 80020, 452, 14, 44, "Text"],
Cell[2700466, 80036, 640, 23, 44, "Text"],
Cell[2701109, 80061, 292, 8, 44, "Text"],
Cell[2701404, 80071, 512, 15, 37, "Text"],
Cell[2701919, 80088, 435, 14, 44, "Text"],
Cell[2702357, 80104, 257, 8, 27, "Text"],
Cell[2702617, 80114, 669, 18, 38, "UNNEQ",
  CellTags->"i:22"],
Cell[2703289, 80134, 306, 10, 27, "Text"],
Cell[2703598, 80146, 340, 13, 27, "Text"],
Cell[2703941, 80161, 352, 11, 44, "Text"],
Cell[2704296, 80174, 704, 17, 78, "Text",
  CellTags->"i:23"],
Cell[2705003, 80193, 202, 4, 39, "NumberedEquation",
  CellTags->"(7.1.43)"],
Cell[2705208, 80199, 135, 5, 27, "Text"],
Cell[2705346, 80206, 955, 24, 98, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2706350, 80236, 71, 1, 40, "Subtitle",
  CellTags->{"i:24", "c:15"}],
Cell[2706424, 80239, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2706465, 80243, 84, 1, 41, "Subsubtitle",
  CellTags->"c:16"],
Cell[2706552, 80246, 16, 0, 25, "Text"],
Cell[2706571, 80248, 454, 7, 75, "Text"],
Cell[2707028, 80257, 132, 3, 25, "Text"],
Cell[2707163, 80262, 140, 5, 30, "NE2",
  CellTags->"(7.2.1)"],
Cell[2707306, 80269, 1030, 32, 80, "Text"],

Cell[CellGroupData[{
Cell[2708361, 80305, 123, 3, 65, "Input",
  CellTags->"Cell 7.29"],
Cell[2708487, 80310, 481, 15, 61, "Output"]
}, Open  ]],
Cell[2708983, 80328, 148, 7, 25, "Text"],
Cell[2709134, 80337, 198, 7, 35, "NE2",
  CellTags->"(7.2.2)"],
Cell[2709335, 80346, 196, 6, 25, "Text"],
Cell[2709534, 80354, 285, 7, 40, "NE2",
  CellTags->"(7.2.3)"],
Cell[2709822, 80363, 166, 4, 41, "Text"],
Cell[2709991, 80369, 263, 6, 35, "UNNEQ"],
Cell[2710257, 80377, 189, 6, 25, "Text"],
Cell[2710449, 80385, 891, 31, 41, "Text",
  CellTags->"i:25"],
Cell[2711343, 80418, 223, 7, 40, "NE2",
  CellTags->"(7.2.4)"],
Cell[2711569, 80427, 232, 8, 30, "Text"],
Cell[2711804, 80437, 387, 7, 75, "Text"],
Cell[2712194, 80446, 320, 7, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2712551, 80458, 103, 1, 30, "Subsubtitle",
  CellTags->{"i:26", "c:17"}],
Cell[2712657, 80461, 455, 12, 60, "Text"],
Cell[2713115, 80475, 577, 19, 42, "Text"],
Cell[2713695, 80496, 238, 6, 42, "UNNEQ"],
Cell[2713936, 80504, 294, 9, 51, "Text"],
Cell[2714233, 80515, 188, 6, 42, "UNNEQ"],
Cell[2714424, 80523, 1558, 52, 131, "Text"],
Cell[2715985, 80577, 192, 3, 41, "NE2",
  CellTags->"(7.2.5)"],
Cell[2716180, 80582, 129, 5, 25, "Text"],
Cell[2716312, 80589, 172, 6, 37, "NE2",
  CellTags->"(7.2.6)"],
Cell[2716487, 80597, 558, 18, 42, "Text"],

Cell[CellGroupData[{
Cell[2717070, 80619, 515, 11, 160, "Input",
  CellTags->"Cell 7.30"],
Cell[2717588, 80632, 30216, 734, 231, 7134, 444, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2747819, 81369, 364, 11, 46, "Text"],

Cell[CellGroupData[{
Cell[2748208, 81384, 110, 3, 65, "Input",
  CellTags->"Cell 7.31"],
Cell[2748321, 81389, 115, 2, 57, "Output"]
}, Open  ]],
Cell[2748451, 81394, 998, 31, 85, "Text"],
Cell[2749452, 81427, 472, 16, 42, "Text"],
Cell[2749927, 81445, 180, 6, 56, "NE2",
  CellTags->"(7.2.7)"],
Cell[2750110, 81453, 66, 0, 25, "Text"],
Cell[2750179, 81455, 422, 15, 70, "NE2",
  CellTags->"(7.2.8)"],
Cell[2750604, 81472, 533, 13, 60, "Text"],

Cell[CellGroupData[{
Cell[2751162, 81489, 134, 3, 65, "Input",
  CellTags->"Cell 7.32"],
Cell[2751299, 81494, 1879, 31, 515, "Output"]
}, Open  ]],
Cell[2753193, 81528, 356, 10, 42, "Text"],
Cell[2753552, 81540, 184, 7, 37, "NE2",
  CellTags->"(7.2.9)"],
Cell[2753739, 81549, 184, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[2753948, 81558, 431, 8, 191, "Input",
  CellTags->"Cell 7.33"],
Cell[2754382, 81568, 315, 5, 138, "Output"]
}, Open  ]],
Cell[2754712, 81576, 359, 10, 42, "Text",
  CellTags->"i:27"],
Cell[2755074, 81588, 211, 7, 65, "UNNEQ"],
Cell[2755288, 81597, 186, 5, 25, "Text"],
Cell[2755477, 81604, 481, 13, 60, "NE2",
  CellTags->"(7.2.10)"],
Cell[2755961, 81619, 21, 0, 25, "Text"],
Cell[2755985, 81621, 134, 6, 37, "NE2",
  CellTags->"(7.2.11)"],
Cell[2756122, 81629, 275, 9, 25, "Text"],
Cell[2756400, 81640, 235, 9, 25, "Text"],
Cell[2756638, 81651, 182, 5, 56, "UNNEQ"],
Cell[2756823, 81658, 612, 20, 45, "Text"],
Cell[2757438, 81680, 238, 8, 56, "NE2",
  CellTags->"(7.2.12)"],
Cell[2757679, 81690, 932, 31, 80, "Text",
  CellTags->"i:28"],

Cell[CellGroupData[{
Cell[2758636, 81725, 250, 5, 85, "Input",
  CellTags->"Cell 7.34"],
Cell[2758889, 81732, 49710, 1062, 231, 10334, 571, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2808614, 82797, 709, 23, 60, "Text"],
Cell[2809326, 82822, 468, 14, 42, "Text"],
Cell[2809797, 82838, 131, 6, 28, "NE2",
  CellTags->"(7.2.13)"],
Cell[2809931, 82846, 772, 30, 60, "Text",
  CellTags->"i:29"],

Cell[CellGroupData[{
Cell[2810728, 82880, 217, 5, 85, "Input",
  CellTags->"Cell 7.35"],
Cell[2810948, 82887, 29387, 650, 231, 6502, 363, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2840350, 83540, 369, 14, 25, "Text"],

Cell[CellGroupData[{
Cell[2840744, 83558, 101, 3, 65, "Input",
  CellTags->"Cell 7.36"],
Cell[2840848, 83563, 47, 1, 45, "Output"]
}, Open  ]],
Cell[2840910, 83567, 400, 12, 42, "Text"],
Cell[2841313, 83581, 385, 14, 45, "Text"],
Cell[2841701, 83597, 220, 7, 56, "NE2",
  CellTags->"(7.2.14)"],
Cell[2841924, 83606, 200, 8, 26, "Text"],
Cell[2842127, 83616, 179, 6, 56, "NE2",
  CellTags->"(7.2.15)"],
Cell[2842309, 83624, 590, 23, 43, "Text"],

Cell[CellGroupData[{
Cell[2842924, 83651, 635, 14, 161, "Input",
  CellTags->"Cell 7.37"],

Cell[CellGroupData[{
Cell[2843584, 83669, 27404, 812, 232, 9731, 589, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2870991, 84483, 30709, 863, 70, 9930, 602, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2901703, 85348, 33534, 888, 70, 9721, 589, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2935240, 86238, 35618, 882, 70, 9108, 550, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2970861, 87122, 35638, 890, 70, 9270, 560, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[3006526, 88016, 800, 24, 77, "Text"],
Cell[3007329, 88042, 1437659, 19151, 257, 855434, 11959, "GraphicsData", \
"PostScript", "Picture"],
Cell[4444991, 107195, 317, 9, 28, "Caption",
  CellTags->"Fig. 7.5"],
Cell[4445311, 107206, 825, 18, 95, "Text"],
Cell[4446139, 107226, 1153, 40, 90, "Text"],
Cell[4447295, 107268, 131, 5, 37, "NE2",
  CellTags->"(7.2.16)"],
Cell[4447429, 107275, 1802, 56, 160, "Text"],
Cell[4449234, 107333, 1135, 38, 77, "Text"],
Cell[4450372, 107373, 29181, 662, 232, 6361, 376, "GraphicsData", \
"PostScript", "Picture"],
Cell[4479556, 108037, 329, 12, 15, "Caption",
  CellTags->"Fig. 7.6"],
Cell[4479888, 108051, 228, 4, 41, "Text"],
Cell[4480119, 108057, 762, 27, 60, "Text",
  CellTags->"i:30"],

Cell[CellGroupData[{
Cell[4480906, 108088, 309, 6, 120, "Input",
  CellTags->"Cell 7.38"],
Cell[4481218, 108096, 34657, 791, 251, 8123, 459, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4515890, 108890, 56, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[4515971, 108894, 114, 3, 75, "Input",
  CellTags->"Cell 7.39"],
Cell[4516088, 108899, 80, 1, 75, "Output"]
}, Open  ]],
Cell[4516183, 108903, 63, 0, 25, "Text"],
Cell[4516249, 108905, 168, 6, 32, "NE2",
  CellTags->"(7.2.17)"],
Cell[4516420, 108913, 334, 10, 42, "Text"],
Cell[4516757, 108925, 107, 4, 31, "UNNEQ"],
Cell[4516867, 108931, 228, 6, 25, "Text"],
Cell[4517098, 108939, 92, 4, 27, "UNNEQ"],
Cell[4517193, 108945, 560, 15, 60, "Text"],
Cell[4517756, 108962, 143, 5, 27, "NE2",
  CellTags->"(7.2.18)"],
Cell[4517902, 108969, 33, 0, 25, "Text"],
Cell[4517938, 108971, 131, 5, 41, "NE2",
  CellTags->"(7.2.19)"],
Cell[4518072, 108978, 232, 5, 42, "Text",
  CellTags->"i:31"],
Cell[4518307, 108985, 1117, 18, 127, "IndentedText"],
Cell[4519427, 109005, 1339, 28, 165, "Text",
  CellTags->"i:73"]
}, Closed]],

Cell[CellGroupData[{
Cell[4520803, 109038, 94, 1, 30, "Subsubtitle",
  CellTags->"c:18"],

Cell[CellGroupData[{
Cell[4520922, 109043, 51, 1, 42, "Section",
  CellTags->"c:19"],
Cell[4520976, 109046, 610, 9, 95, "Text"],
Cell[4521589, 109057, 389, 7, 75, "Text"],
Cell[4521981, 109066, 367, 12, 41, "Text",
  CellTags->"i:74"],
Cell[4522351, 109080, 338, 12, 30, "NE2",
  CellTags->"(7.2.20)"],
Cell[4522692, 109094, 154, 5, 25, "Text"],
Cell[4522849, 109101, 212, 7, 35, "NE2",
  CellTags->"(7.2.21)"],
Cell[4523064, 109110, 348, 9, 46, "Text"],
Cell[4523415, 109121, 912, 23, 45, "NE2",
  CellTags->"(7.2.22)"],
Cell[4524330, 109146, 818, 24, 65, "Text"],
Cell[4525151, 109172, 322, 8, 35, "NE2",
  CellTags->"(7.2.23)"],
Cell[4525476, 109182, 364, 12, 41, "Text"],
Cell[4525843, 109196, 148, 5, 26, "NE2",
  CellTags->"(7.2.24)"],
Cell[4525994, 109203, 153, 5, 25, "Text"],
Cell[4526150, 109210, 155, 4, 65, "Input",
  CellTags->"Cell 7.40"],
Cell[4526308, 109216, 1663, 50, 155, "Text"],
Cell[4527974, 109268, 790, 20, 75, "Text",
  CellTags->"i:53"],
Cell[4528767, 109290, 892, 22, 95, "Text"],
Cell[4529662, 109314, 125, 3, 65, "Input",
  CellTags->"Cell 7.41"],
Cell[4529790, 109319, 64, 0, 25, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4529891, 109324, 72, 1, 31, "Section",
  CellTags->{"i:44", "c:20"}],
Cell[4529966, 109327, 99, 3, 27, "Text"],
Cell[4530068, 109332, 318, 7, 124, "Input",
  CellTags->"Cell 7.42"],
Cell[4530389, 109341, 264, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[4530678, 109354, 291, 7, 105, "Input",
  CellTags->"Cell 7.43"],
Cell[4530972, 109363, 104, 3, 46, "Output"]
}, Open  ]],
Cell[4531091, 109369, 198, 6, 27, "Text"],
Cell[4531292, 109377, 273, 9, 33, "NE2",
  CellTags->"(7.2.25)"],
Cell[4531568, 109388, 54, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[4531647, 109392, 392, 11, 162, "Input",
  CellTags->"Cell 7.44"],
Cell[4532042, 109405, 274, 6, 69, "Message"],
Cell[4532319, 109413, 275, 6, 69, "Message"],
Cell[4532597, 109421, 274, 6, 69, "Message"],
Cell[4532874, 109429, 220, 5, 50, "Message"]
}, Open  ]],
Cell[4533109, 109437, 274, 5, 61, "Text"],
Cell[4533386, 109444, 905, 30, 61, "Text"],
Cell[4534294, 109476, 1253, 22, 390, "Input",
  CellTags->"Cell 7.45"],
Cell[4535550, 109500, 251, 9, 27, "Text"],
Cell[4535804, 109511, 100, 3, 67, "Input",
  CellTags->"Cell 7.46"],
Cell[4535907, 109516, 621, 11, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4536565, 109532, 70, 1, 31, "Section",
  CellTags->"c:21"],
Cell[4536638, 109535, 122, 3, 27, "Text"],
Cell[4536763, 109540, 247, 6, 105, "Input",
  CellTags->"Cell 7.47"],
Cell[4537013, 109548, 69, 0, 27, "Text"],
Cell[4537085, 109550, 375, 11, 162, "Input",
  CellTags->"Cell 7.48"],
Cell[4537463, 109563, 404, 10, 44, "Text"],
Cell[4537870, 109575, 105, 3, 67, "Input",
  CellTags->"Cell 7.49"],
Cell[4537978, 109580, 521, 8, 95, "Text"],
Cell[4538502, 109590, 369, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4538908, 109601, 87, 1, 31, "Section",
  CellTags->{"i:45", "c:22"}],
Cell[4538998, 109604, 594, 11, 95, "Text"],
Cell[4539595, 109617, 385, 11, 44, "Text"],
Cell[4539983, 109630, 313, 7, 143, "Input",
  CellTags->"Cell 7.50"],
Cell[4540299, 109639, 519, 12, 61, "Text"],

Cell[CellGroupData[{
Cell[4540843, 109655, 541, 11, 181, "Input",
  CellTags->"Cell 7.51"],
Cell[4541387, 109668, 186076, 6710, 370, 62427, 5179, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4727478, 116381, 535, 13, 75, "Text"],
Cell[4728016, 116396, 831, 17, 110, "Text"],

Cell[CellGroupData[{
Cell[4728872, 116417, 25698, 677, 233, 6664, 437, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4754573, 117096, 25706, 678, 70, 6672, 438, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4780282, 117776, 25881, 688, 70, 6835, 448, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4806166, 118466, 26939, 735, 70, 7509, 491, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4833108, 119203, 31609, 838, 70, 8380, 547, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4864720, 120043, 38439, 967, 70, 9240, 602, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4903162, 121012, 43448, 1068, 70, 9984, 650, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4946613, 122082, 47549, 1176, 70, 11113, 722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4994165, 123260, 49305, 1202, 70, 11216, 727, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5043473, 124464, 50915, 1261, 70, 11964, 776, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5094391, 125727, 52906, 1321, 70, 12634, 819, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5147300, 127050, 53039, 1316, 70, 12504, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5200342, 128368, 53432, 1318, 70, 12468, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5253777, 129688, 53189, 1293, 70, 12038, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5306969, 130983, 52749, 1297, 70, 12226, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5359721, 132282, 51519, 1243, 70, 11470, 744, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5411243, 133527, 52039, 1285, 70, 12172, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5463285, 134814, 47619, 1173, 70, 11041, 717, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5510907, 135989, 50498, 1274, 70, 12292, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5561408, 137265, 50235, 1234, 70, 11612, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5611646, 138501, 46249, 1158, 70, 11076, 719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5657898, 139661, 52708, 1322, 70, 12699, 823, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5710609, 140985, 51562, 1277, 70, 12125, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5762174, 142264, 46818, 1198, 70, 11718, 760, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5808995, 143464, 45559, 1188, 70, 11800, 767, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5854557, 144654, 52175, 1300, 70, 12430, 805, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5906735, 145956, 52053, 1265, 70, 11769, 763, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5958791, 147223, 51902, 1278, 70, 12027, 781, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6010696, 148503, 47491, 1208, 70, 11743, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6058190, 149713, 43058, 1128, 70, 11243, 731, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6101251, 150843, 44625, 1140, 70, 11109, 722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6145879, 151985, 50842, 1291, 70, 12551, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6196724, 153278, 53304, 1301, 70, 12186, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6250031, 154581, 51977, 1261, 70, 11705, 759, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6302011, 155844, 49974, 1230, 70, 11573, 751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6351988, 157076, 52755, 1302, 70, 12309, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6404746, 158380, 51920, 1292, 70, 12325, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6456669, 159674, 48561, 1202, 70, 11347, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6505233, 160878, 43601, 1141, 70, 11389, 739, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6548837, 162021, 40522, 1076, 70, 10886, 706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6589362, 163099, 43151, 1167, 70, 11996, 778, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6632516, 164268, 49060, 1279, 70, 12749, 826, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6681579, 165549, 51546, 1280, 70, 12181, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6733128, 166831, 53587, 1306, 70, 12181, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6786718, 168139, 51904, 1277, 70, 12009, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6838625, 169418, 51447, 1261, 70, 11819, 767, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6890075, 170681, 49474, 1203, 70, 11179, 726, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6939552, 171886, 48712, 1233, 70, 11927, 774, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6988267, 173121, 50404, 1291, 70, 12651, 820, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7038674, 174414, 50692, 1243, 70, 11639, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7089369, 175659, 51660, 1244, 70, 11453, 743, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7141032, 176905, 50670, 1228, 70, 11366, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7191705, 178135, 52119, 1274, 70, 11916, 773, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7243827, 179411, 51927, 1277, 70, 12044, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7295757, 180690, 50245, 1224, 70, 11415, 740, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7346005, 181916, 47219, 1145, 70, 10592, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7393227, 183063, 44428, 1132, 70, 11013, 715, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7437658, 184197, 40661, 1107, 70, 11417, 741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7478322, 185306, 38232, 1039, 70, 10673, 694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7516557, 186347, 39429, 1060, 70, 10801, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7555989, 187409, 42453, 1130, 70, 11444, 743, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7598445, 188541, 46570, 1240, 70, 12584, 816, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7645018, 189783, 49536, 1279, 70, 12642, 819, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7694557, 191064, 51885, 1283, 70, 12160, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7746445, 192349, 51035, 1248, 70, 11703, 758, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7797483, 193599, 51924, 1268, 70, 11859, 769, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7849410, 194869, 52099, 1278, 70, 11981, 778, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7901512, 196149, 51375, 1236, 70, 11354, 737, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7952890, 197387, 49580, 1198, 70, 11054, 718, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8002473, 198587, 50215, 1205, 70, 11061, 717, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8052691, 199794, 51048, 1266, 70, 12011, 779, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8103742, 201062, 50049, 1247, 70, 11928, 772, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8153794, 202311, 50404, 1240, 70, 11691, 757, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8204201, 203553, 48870, 1217, 70, 11575, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8253074, 204772, 49562, 1221, 70, 11522, 747, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8302639, 205995, 49223, 1227, 70, 11701, 759, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[8351877, 207225, 95, 1, 17, "Caption",
  CellTags->"Fig. 7.7"],
Cell[8351975, 207228, 295650, 13539, 370, 133579, 11534, "GraphicsData", \
"PostScript", "Picture"],
Cell[8647628, 220769, 194, 6, 16, "Caption",
  CellTags->"Fig. 7.8"],
Cell[8647825, 220777, 405, 9, 61, "Text"],
Cell[8648233, 220788, 835, 20, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8649117, 220814, 89, 1, 30, "Subsubtitle",
  CellTags->{"i:46", "c:23"}],

Cell[CellGroupData[{
Cell[8649231, 220819, 55, 1, 40, "Section",
  CellTags->"c:24"],
Cell[8649289, 220822, 372, 12, 45, "Text",
  CellTags->"i:47"],
Cell[8649664, 220836, 221, 7, 40, "NE2",
  CellTags->"(7.2.26)"],
Cell[8649888, 220845, 752, 15, 110, "Text"],
Cell[8650643, 220862, 690, 21, 60, "Text"],
Cell[8651336, 220885, 720, 21, 40, "NE2",
  CellTags->"(7.2.27)"],
Cell[8652059, 220908, 693, 24, 41, "Text"],
Cell[8652755, 220934, 173, 6, 35, "NE2",
  CellTags->"(7.2.28)"],
Cell[8652931, 220942, 266, 9, 25, "Text",
  CellTags->"i:48"],
Cell[8653200, 220953, 294, 9, 41, "Text"],

Cell[CellGroupData[{
Cell[8653519, 220966, 234, 5, 85, "Input",
  CellTags->"Cell 7.52"],
Cell[8653756, 220973, 28490, 720, 230, 9205, 477, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8682261, 221696, 838, 27, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8683136, 221728, 67, 1, 30, "Section",
  CellTags->"c:25"],
Cell[8683206, 221731, 1331, 43, 75, "Text",
  CellTags->"i:75"],
Cell[8684540, 221776, 2137, 61, 110, "Text"],
Cell[8686680, 221839, 631, 15, 75, "Text"],
Cell[8687314, 221856, 1584, 41, 55, "NE2",
  CellTags->"(7.2.29)"],
Cell[8688901, 221899, 314, 11, 41, "Text"],
Cell[8689218, 221912, 776, 23, 60, "Text"],
Cell[8689997, 221937, 239, 6, 85, "Input",
  CellTags->"Cell 7.53"],
Cell[8690239, 221945, 321, 8, 41, "Text"],
Cell[8690563, 221955, 1446, 40, 45, "NE2",
  CellTags->"(7.2.30)"],
Cell[8692012, 221997, 825, 25, 75, "Text"],
Cell[8692840, 222024, 357, 7, 111, "Input",
  CellTags->"Cell 7.54"],
Cell[8693200, 222033, 176, 5, 90, "Input",
  CellTags->"Cell 7.55"],
Cell[8693379, 222040, 149, 5, 30, "Text"],
Cell[8693531, 222047, 429, 13, 35, "NE2",
  CellTags->"(7.2.31)"],
Cell[8693963, 222062, 1303, 43, 60, "Text",
  CellTags->"i:79"],
Cell[8695269, 222107, 822, 26, 70, "Text"],
Cell[8696094, 222135, 58, 0, 25, "Text"],
Cell[8696155, 222137, 136, 3, 65, "Input",
  CellTags->"Cell 7.56"],
Cell[8696294, 222142, 192, 6, 25, "Text"],
Cell[8696489, 222150, 255, 7, 65, "Input",
  CellTags->"Cell 7.57"],
Cell[8696747, 222159, 246, 9, 25, "Text"],
Cell[8696996, 222170, 196, 6, 65, "Input",
  CellTags->"Cell 7.58"],
Cell[8697195, 222178, 129, 5, 30, "Text"],
Cell[8697327, 222185, 205, 4, 65, "Input",
  CellTags->"Cell 7.59"],
Cell[8697535, 222191, 802, 27, 60, "Text"],
Cell[8698340, 222220, 281, 6, 121, "Input",
  CellTags->"Cell 7.60"],
Cell[8698624, 222228, 693, 19, 75, "Text"],
Cell[8699320, 222249, 352, 9, 135, "Input",
  CellTags->"Cell 7.61"],
Cell[8699675, 222260, 115, 5, 25, "Text"],
Cell[8699793, 222267, 102, 3, 65, "Input",
  CellTags->"Cell 7.62"],
Cell[8699898, 222272, 257, 7, 41, "Text"],

Cell[CellGroupData[{
Cell[8700180, 222283, 395, 9, 121, "Input",
  CellTags->"Cell 7.63"],

Cell[CellGroupData[{
Cell[8700600, 222296, 21299, 551, 230, 5459, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8721902, 222849, 21836, 558, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8743741, 223409, 21703, 556, 70, 5462, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8765447, 223967, 21757, 557, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8787207, 224526, 21686, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8808896, 225084, 21494, 553, 70, 5464, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8830393, 225639, 21791, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8852187, 226198, 21670, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8873860, 226756, 21757, 557, 70, 5463, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8895620, 227315, 21684, 556, 70, 5463, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8917307, 227873, 21517, 554, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8938827, 228429, 21775, 557, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8960605, 228988, 21716, 556, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8982324, 229546, 21769, 557, 70, 5467, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9004096, 230105, 21775, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9025874, 230664, 21517, 554, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9047394, 231220, 21803, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9069200, 231779, 21730, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9090933, 232337, 21793, 557, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9112729, 232896, 21649, 555, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9134381, 233453, 21464, 553, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9155848, 234008, 21686, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9177537, 234566, 21682, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9199222, 235124, 21756, 557, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9220981, 235683, 21661, 555, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9242645, 236240, 21446, 553, 70, 5468, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9264094, 236795, 21686, 556, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9285783, 237353, 21734, 556, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9307520, 237911, 21799, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9329322, 238470, 21682, 556, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9351007, 239028, 21543, 554, 70, 5468, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9372553, 239584, 21831, 558, 70, 5468, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9394387, 240144, 21765, 557, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9416155, 240703, 21830, 558, 70, 5467, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9437988, 241263, 21803, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9459794, 241822, 21504, 553, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9481301, 242377, 21775, 557, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9503079, 242936, 21781, 557, 70, 5467, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9524863, 243495, 21848, 558, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9546714, 244055, 21787, 557, 70, 5461, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9568504, 244614, 21539, 554, 70, 5464, 351, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[9590070, 245172, 270, 5, 60, "Text"],
Cell[9590343, 245179, 193, 5, 85, "Input",
  CellTags->"Cell 7.64"],
Cell[9590539, 245186, 52, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[9590616, 245190, 368, 9, 121, "Input",
  CellTags->"Cell 7.65"],

Cell[CellGroupData[{
Cell[9591009, 245203, 16344, 448, 230, 4497, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9607356, 245653, 17151, 457, 70, 4567, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9624510, 246112, 17125, 456, 70, 4586, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9641638, 246570, 17216, 457, 70, 4596, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9658857, 247029, 17192, 457, 70, 4604, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9676052, 247488, 17061, 455, 70, 4607, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9693116, 247945, 17359, 459, 70, 4621, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9710478, 248406, 17318, 458, 70, 4633, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9727799, 248866, 17376, 459, 70, 4638, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9745178, 249327, 17298, 458, 70, 4645, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9762479, 249787, 17282, 457, 70, 4658, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9779764, 250246, 17549, 461, 70, 4657, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9797316, 250709, 17469, 460, 70, 4670, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9814788, 251171, 17586, 461, 70, 4678, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9832377, 251634, 17595, 461, 70, 4683, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9849975, 252097, 17369, 458, 70, 4684, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9867347, 252557, 17655, 462, 70, 4694, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9885005, 253021, 17567, 460, 70, 4696, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9902575, 253483, 17693, 462, 70, 4696, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9920271, 253947, 17504, 460, 70, 4697, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9937778, 254409, 17313, 457, 70, 4697, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9955094, 254868, 17616, 461, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9972713, 255331, 17620, 461, 70, 4700, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9990336, 255794, 17684, 462, 70, 4703, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10008023, 256258, 17594, 461, 70, 4698, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10025620, 256721, 17412, 458, 70, 4699, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10043035, 257181, 17678, 462, 70, 4701, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10060716, 257645, 17762, 463, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10078481, 258110, 17843, 464, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10096327, 258576, 17726, 462, 70, 4701, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10114056, 259040, 17654, 461, 70, 4702, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10131713, 259503, 17926, 465, 70, 4698, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10149642, 259970, 17889, 464, 70, 4702, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10167534, 260436, 17950, 465, 70, 4698, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10185487, 260903, 17941, 465, 70, 4697, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10203431, 261370, 17645, 461, 70, 4705, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10221079, 261833, 17932, 465, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10239014, 262300, 17913, 465, 70, 4701, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10256930, 262767, 17984, 465, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10274917, 263234, 17926, 465, 70, 4702, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10292846, 263701, 17676, 462, 70, 4703, 297, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[10310549, 264167, 1439, 36, 120, "Text"],
Cell[10311991, 264205, 178, 6, 31, "UNNEQ"],
Cell[10312172, 264213, 673, 19, 50, "Text"],
Cell[10312848, 264234, 400, 11, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10313297, 264251, 65, 1, 30, "Subsubtitle",
  CellTags->"c:26"],
Cell[10313365, 264254, 348, 9, 44, "Text"],
Cell[10313716, 264265, 291, 8, 44, "Text"],
Cell[10314010, 264275, 447, 16, 52, "Text"],
Cell[10314460, 264293, 168, 8, 27, "Text"],
Cell[10314631, 264303, 742, 23, 78, "Text",
  CellTags->"i:32"],
Cell[10315376, 264328, 367, 6, 73, "UNNEQ"],
Cell[10315746, 264336, 354, 11, 44, "Text"],
Cell[10316103, 264349, 173, 5, 33, "UNNEQ"],
Cell[10316279, 264356, 247, 9, 27, "Text"],
Cell[10316529, 264367, 398, 16, 29, "Text"],
Cell[10316930, 264385, 413, 7, 78, "NE2",
  CellTags->"(7.2.32)"],
Cell[10317346, 264394, 373, 11, 47, "Text"],
Cell[10317722, 264407, 174, 5, 43, "UNNEQ"],
Cell[10317899, 264414, 525, 21, 29, "Text"],
Cell[10318427, 264437, 967, 32, 65, "Text",
  CellTags->"i:33"],
Cell[10319397, 264471, 706, 25, 49, "Text"],
Cell[10320106, 264498, 168, 8, 27, "Text",
  CellTags->"i:34"],
Cell[10320277, 264508, 454, 10, 43, "NE2",
  CellTags->"(7.2.33)"],
Cell[10320734, 264520, 427, 10, 61, "Text"],
Cell[10321164, 264532, 438, 10, 43, "UNNEQ",
  CellTags->"i:35"],
Cell[10321605, 264544, 106, 3, 27, "Text"],
Cell[10321714, 264549, 285, 8, 53, "Text"],
Cell[10322002, 264559, 1344, 45, 87, "Text",
  CellTags->"i:49"],
Cell[10323349, 264606, 124, 4, 27, "Text"],
Cell[10323476, 264612, 287, 8, 43, "NE2",
  CellTags->{"i:36", "(7.2.34)"}],
Cell[10323766, 264622, 964, 23, 101, "Text"],
Cell[10324733, 264647, 413, 13, 44, "Text",
  CellTags->"i:50"],
Cell[10325149, 264662, 403, 12, 44, "Text"],
Cell[10325555, 264676, 1019, 35, 61, "Text",
  CellTags->"i:41"],
Cell[10326577, 264713, 192, 3, 39, "NE2",
  CellTags->{"i:37", "(7.2.35)"}],
Cell[10326772, 264718, 38, 0, 27, "Text"],
Cell[10326813, 264720, 322, 6, 45, "NE2",
  CellTags->{"i:38", "(7.2.36)"}],
Cell[10327138, 264728, 453, 15, 31, "Text",
  CellTags->"i:77"],
Cell[10327594, 264745, 159, 5, 29, "NE2",
  CellTags->{"i:40", "(7.2.37)"}],
Cell[10327756, 264752, 434, 13, 44, "Text",
  CellTags->"i:39"],
Cell[10328193, 264767, 411, 13, 44, "Text"],
Cell[10328607, 264782, 185, 6, 33, "UNNEQ",
  CellTags->"i:42"],
Cell[10328795, 264790, 473, 15, 51, "Text"],
Cell[10329271, 264807, 910, 29, 61, "Text"],
Cell[10330184, 264838, 258, 7, 46, "NE2",
  CellTags->"(7.2.38)"],
Cell[10330445, 264847, 125, 5, 27, "Text"],
Cell[10330573, 264854, 165, 5, 27, "Text",
  CellTags->"i:43"],
Cell[10330741, 264861, 239, 4, 46, "UNNEQ"],
Cell[10330983, 264867, 149, 5, 27, "Text"],
Cell[10331135, 264874, 1035, 37, 80, "Text"],
Cell[10332173, 264913, 425, 14, 42, "UNNEQ"],
Cell[10332601, 264929, 19, 0, 27, "Text"],
Cell[10332623, 264931, 175, 6, 38, "UNNEQ"],
Cell[10332801, 264939, 1504, 53, 48, "Text"],
Cell[10334308, 264994, 275, 8, 44, "Text"],
Cell[10334586, 265004, 645, 18, 43, "UNNEQ"],
Cell[10335234, 265024, 404, 11, 61, "Text"],
Cell[10335641, 265037, 614, 20, 44, "Text"],
Cell[10336258, 265059, 1020, 29, 95, "Text"],
Cell[10337281, 265090, 381, 11, 44, "Text",
  CellTags->"i:51"],
Cell[10337665, 265103, 216, 6, 43, "UNNEQ"],
Cell[10337884, 265111, 393, 10, 61, "Text"],
Cell[10338280, 265123, 475, 9, 78, "Text",
  CellTags->"i:86"],
Cell[10338758, 265134, 605, 16, 43, "UNNEQ"],
Cell[10339366, 265152, 382, 12, 27, "Text"],
Cell[10339751, 265166, 2099, 52, 81, "NE2",
  CellTags->"(7.2.39)"],
Cell[10341853, 265220, 374, 10, 45, "Text"],
Cell[10342230, 265232, 148, 5, 32, "UNNEQ"],
Cell[10342381, 265239, 1476, 39, 99, "Text",
  CellTags->"i:52"],
Cell[10343860, 265280, 1544, 51, 99, "Text"],
Cell[10345407, 265333, 499, 11, 78, "Text"],
Cell[10345909, 265346, 300, 10, 38, "NE2",
  CellTags->"(7.2.40)"],
Cell[10346212, 265358, 90, 3, 27, "Text"],
Cell[10346305, 265363, 290, 8, 38, "UNNEQ"],
Cell[10346598, 265373, 537, 15, 64, "Text"],
Cell[10347138, 265390, 204, 5, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10347391, 265401, 113, 2, 40, "Subtitle",
  CellTags->{"i:55", "c:27"}],
Cell[10347507, 265405, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[10347548, 265409, 66, 1, 41, "Subsubtitle",
  CellTags->"c:28"],
Cell[10347617, 265412, 1441, 31, 175, "Text",
  CellTags->"i:76"],
Cell[10349061, 265445, 3015653, 37234, 348, 3015531, 37230, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[13364717, 302681, 250, 5, 29, "Caption",
  CellTags->"Fig. 7.9"],
Cell[13364970, 302688, 323, 6, 61, "Text"],
Cell[13365296, 302696, 812, 20, 101, "Text"],
Cell[13366111, 302718, 957, 27, 61, "Text"],
Cell[13367071, 302747, 779, 22, 42, "NE3",
  CellTags->{"i:54", "(7.3.1)"}],
Cell[13367853, 302771, 463, 13, 44, "Text"],
Cell[13368319, 302786, 140, 5, 32, "NE3",
  CellTags->"(7.3.2)"],
Cell[13368462, 302793, 187, 6, 31, "Text"],
Cell[13368652, 302801, 893, 21, 112, "Text"],
Cell[13369548, 302824, 542, 10, 78, "Text"],
Cell[13370093, 302836, 848, 19, 95, "Text"],
Cell[13370944, 302857, 932, 28, 81, "Text"],
Cell[13371879, 302887, 595, 11, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13372511, 302903, 75, 1, 30, "Subsubtitle",
  CellTags->"c:29"],
Cell[13372589, 302906, 798, 21, 78, "Text"],
Cell[13373390, 302929, 926, 20, 115, "Text"],
Cell[13374319, 302951, 75, 0, 27, "Text"],
Cell[13374397, 302953, 275, 8, 44, "Text"],
Cell[13374675, 302963, 445, 12, 44, "Text"],
Cell[13375123, 302977, 245, 5, 44, "Text"],
Cell[13375371, 302984, 170, 6, 27, "Text"],
Cell[13375544, 302992, 267906, 6663, 438, 122612, 4864, "GraphicsData", \
"PostScript", "Picture"],
Cell[13643453, 309657, 516, 12, 44, "Caption",
  CellTags->"Fig. 7.10"],
Cell[13643972, 309671, 344, 8, 44, "Text"],
Cell[13644319, 309681, 386, 8, 61, "Text"],
Cell[13644708, 309691, 415, 7, 78, "Text"],
Cell[13645126, 309700, 926, 15, 129, "Text",
  CellTags->"i:89"],
Cell[13646055, 309717, 754, 16, 112, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13646846, 309738, 74, 1, 30, "Subsubtitle",
  CellTags->{"i:61", "c:30"}],
Cell[13646923, 309741, 2433, 69, 79, "Text"],
Cell[13649359, 309812, 770, 25, 31, "UNNEQ"],
Cell[13650132, 309839, 588, 18, 27, "Text"],
Cell[13650723, 309859, 870, 27, 31, "UNNEQ"],
Cell[13651596, 309888, 4277, 124, 168, "Text"],
Cell[13655876, 310014, 776, 27, 45, "Text"],
Cell[13656655, 310043, 2383, 46, 505, "Input",
  CellTags->"Cell 7.66"],
Cell[13659041, 310091, 1674, 49, 114, "Text",
  CellTags->"i:60"],
Cell[13660718, 310142, 649, 22, 27, "Text"],
Cell[13661370, 310166, 840, 31, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13662247, 310202, 54, 1, 30, "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{
Cell[13662326, 310207, 63, 1, 42, "Section",
  CellTags->"c:32"],
Cell[13662392, 310210, 378, 12, 45, "Text"],
Cell[13662773, 310224, 736, 25, 45, "UNNEQ"],
Cell[13663512, 310251, 833, 29, 41, "Text"],
Cell[13664348, 310282, 276, 9, 41, "Text"],
Cell[13664627, 310293, 222, 6, 121, "Input",
  CellTags->"Cell 7.67"],
Cell[13664852, 310301, 542, 13, 60, "Text",
  CellTags->"i:88"],
Cell[13665397, 310316, 958, 35, 60, "Text",
  CellTags->"i:58"],
Cell[13666358, 310353, 1263, 38, 45, "NE3",
  CellTags->"(7.3.3)"],
Cell[13667624, 310393, 725, 27, 41, "Text",
  CellTags->"i:59"],
Cell[13668352, 310422, 999, 29, 45, "NE3",
  CellTags->"(7.3.4)"],
Cell[13669354, 310453, 272, 7, 45, "Text"],
Cell[13669629, 310462, 424, 14, 40, "NE3",
  CellTags->"(7.3.5)"],
Cell[13670056, 310478, 1615, 42, 81, "Text"],
Cell[13671674, 310522, 1872, 59, 110, "Text"],
Cell[13673549, 310583, 2541, 75, 85, "NE3",
  CellTags->"(7.3.6)"],
Cell[13676093, 310660, 813114, 11240, 185, 778757, 10811, "GraphicsData", \
"PostScript", "Picture"],
Cell[14489210, 321902, 96, 1, 15, "Caption",
  CellTags->"Fig. 7.11"],
Cell[14489309, 321905, 71, 0, 25, "Text"],
Cell[14489383, 321907, 1780, 44, 115, "NE3",
  CellTags->"(7.3.7)"],
Cell[14491166, 321953, 909, 23, 80, "Text"],
Cell[14492078, 321978, 363, 9, 41, "Text"],
Cell[14492444, 321989, 381, 12, 45, "Text"],
Cell[14492828, 322003, 2441, 46, 406, "Input",
  CellTags->"Cell 7.68"],
Cell[14495272, 322051, 1800, 47, 130, "Text"],
Cell[14497075, 322100, 1333, 29, 220, "Input",
  CellTags->"Cell 7.69"],
Cell[14498411, 322131, 655, 23, 25, "Text"],
Cell[14499069, 322156, 271, 7, 41, "Text"],

Cell[CellGroupData[{
Cell[14499365, 322167, 395, 10, 140, "Input",
  CellTags->"Cell 7.70"],
Cell[14499763, 322179, 108128, 3156, 370, 31273, 2203, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14607894, 325337, 36, 1, 45, "Output"]
}, Open  ]],
Cell[14607945, 325341, 123, 3, 25, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14608105, 325349, 70, 1, 31, "Section",
  CellTags->{"i:62", "c:33"}],
Cell[14608178, 325352, 866, 28, 61, "Text"],
Cell[14609047, 325382, 901, 24, 75, "NE3",
  CellTags->"(7.3.8)"],
Cell[14609951, 325408, 507, 16, 41, "Text"],
Cell[14610461, 325426, 3567, 69, 690, "Input",
  CellTags->"Cell 7.71"],
Cell[14614031, 325497, 1936, 50, 175, "Text"],
Cell[14615970, 325549, 1334, 35, 95, "Text"],
Cell[14617307, 325586, 211, 7, 25, "Text"],

Cell[CellGroupData[{
Cell[14617543, 325597, 201, 5, 105, "Input",
  CellTags->"Cell 7.72"],
Cell[14617747, 325604, 146656, 2512, 300, 33748, 1114, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[14764418, 328119, 416, 9, 60, "Text"],

Cell[CellGroupData[{
Cell[14764859, 328132, 433, 10, 121, "Input",
  CellTags->"Cell 7.73"],
Cell[14765295, 328144, 147027, 3820, 370, 53055, 2655, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[14912337, 331967, 256, 5, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14912630, 331977, 121, 4, 31, "Section",
  CellTags->{"i:63", "c:34"}],
Cell[14912754, 331983, 429, 11, 60, "Text"],
Cell[14913186, 331996, 516, 11, 140, "Input",
  CellTags->"Cell 7.74"],
Cell[14913705, 332009, 358, 6, 60, "Text"],
Cell[14914066, 332017, 140, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[14914231, 332024, 121, 4, 85, "Input",
  CellTags->"Cell 7.75"],
Cell[14914355, 332030, 861, 15, 225, "Output"]
}, Open  ]],
Cell[14915231, 332048, 98, 3, 25, "Text"],
Cell[14915332, 332053, 366, 6, 60, "Text"],
Cell[14915701, 332061, 4242, 83, 655, "Input",
  CellTags->"Cell 7.76"],
Cell[14919946, 332146, 449, 14, 25, "Text"],
Cell[14920398, 332162, 907, 21, 180, "Input",
  CellTags->"Cell 7.77"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14921354, 332189, 57, 1, 30, "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{
Cell[14921436, 332194, 50, 1, 42, "Section",
  CellTags->"c:36"],
Cell[14921489, 332197, 1130, 27, 135, "Text"],
Cell[14922622, 332226, 106, 4, 30, "UNNEQ"],
Cell[14922731, 332232, 443, 15, 41, "Text"],

Cell[CellGroupData[{
Cell[14923199, 332251, 613, 14, 255, "Input",
  CellTags->"Cell 7.78"],
Cell[14923815, 332267, 56, 1, 45, "Output"]
}, Open  ]],
Cell[14923886, 332271, 310, 5, 60, "Text"],

Cell[CellGroupData[{
Cell[14924221, 332280, 200, 5, 85, "Input",
  CellTags->"Cell 7.79"],

Cell[CellGroupData[{
Cell[14924446, 332289, 22375, 455, 370, 2255, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14946824, 332746, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14969218, 333203, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14991612, 333660, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15014006, 334117, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15036398, 334574, 22387, 455, 370, 2267, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15058788, 335031, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15081182, 335488, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15103576, 335945, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15125970, 336402, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15148364, 336859, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15170758, 337316, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15193152, 337773, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15215546, 338230, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15237940, 338687, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15260334, 339144, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15282726, 339601, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15305120, 340058, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15327514, 340515, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15349908, 340972, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15372302, 341429, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15394696, 341886, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15417090, 342343, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15439482, 342800, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15461876, 343257, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15484270, 343714, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15506664, 344171, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15529056, 344628, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15551450, 345085, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15573844, 345542, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15596238, 345999, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[15618656, 346458, 429, 9, 60, "Text"],
Cell[15619088, 346469, 906, 25, 60, "Text"],

Cell[CellGroupData[{
Cell[15620019, 346498, 349, 8, 105, "Input",
  CellTags->"Cell 7.80"],
Cell[15620371, 346508, 40525, 887, 320, 9072, 494, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15660911, 347398, 690, 18, 75, "Text"],
Cell[15661604, 347418, 875, 17, 110, "Text"],
Cell[15662482, 347437, 1292, 36, 60, "Text"],

Cell[CellGroupData[{
Cell[15663799, 347477, 663, 13, 200, "Input",
  CellTags->"Cell 7.81"],
Cell[15664465, 347492, 47307, 874, 230, 5742, 356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15711787, 348369, 290, 5, 60, "Text"],
Cell[15712080, 348376, 90, 3, 25, "Text"],
Cell[15712173, 348381, 249, 7, 50, "NE3",
  CellTags->"(7.3.9)"],
Cell[15712425, 348390, 231, 6, 41, "Text"],
Cell[15712659, 348398, 739, 21, 35, "NE3",
  CellTags->"(7.3.10)"],
Cell[15713401, 348421, 403, 10, 60, "Text"],
Cell[15713807, 348433, 384, 10, 60, "Text"],
Cell[15714194, 348445, 339, 11, 50, "UNNEQ"],
Cell[15714536, 348458, 151, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[15714712, 348468, 1396, 27, 390, "Input",
  CellTags->"Cell 7.82"],
Cell[15716111, 348497, 59660, 998, 230, 5168, 321, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15775786, 349498, 127, 3, 25, "Text"],
Cell[15775916, 349503, 196, 7, 25, "Text"],

Cell[CellGroupData[{
Cell[15776137, 349514, 951, 19, 255, "Input",
  CellTags->"Cell 7.83"],
Cell[15777091, 349535, 38609, 804, 230, 7849, 420, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15815715, 350342, 733, 17, 76, "Text"],
Cell[15816451, 350361, 953, 26, 45, "NE3",
  CellTags->"(7.3.11)"],
Cell[15817407, 350389, 363, 12, 30, "Text"],
Cell[15817773, 350403, 791, 23, 40, "UNNEQ"],
Cell[15818567, 350428, 2279, 70, 135, "Text"],
Cell[15820849, 350500, 873, 15, 126, "Text"],
Cell[15821725, 350517, 1323, 38, 41, "NE3",
  CellTags->"(7.3.12)"],
Cell[15823051, 350557, 2551, 77, 120, "Text"],
Cell[15825605, 350636, 997, 29, 80, "Text"],
Cell[15826605, 350667, 248, 5, 41, "Text"],
Cell[15826856, 350674, 326, 6, 60, "Text"],
Cell[15827185, 350682, 324, 10, 25, "Text"],
Cell[15827512, 350694, 323, 10, 25, "Text"],
Cell[15827838, 350706, 310, 7, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15828185, 350718, 85, 1, 31, "Section",
  CellTags->{"i:56", "c:37"}],
Cell[15828273, 350721, 756, 20, 78, "Text",
  CellTags->"i:80"],
Cell[15829032, 350743, 543, 10, 78, "Text"],
Cell[15829578, 350755, 621, 15, 78, "Text"],

Cell[CellGroupData[{
Cell[15830224, 350774, 449, 10, 162, "Input",
  CellTags->"Cell 7.84"],
Cell[15830676, 350786, 56, 1, 46, "Output"]
}, Open  ]],
Cell[15830747, 350790, 200, 5, 86, "Input",
  CellTags->"Cell 7.85"],
Cell[15830950, 350797, 562, 11, 103, "Text"],

Cell[CellGroupData[{
Cell[15831537, 350812, 187, 4, 67, "Input",
  CellTags->"Cell 7.86"],
Cell[15831727, 350818, 39696, 790, 233, 5122, 359, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15871438, 351611, 902, 13, 146, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15872377, 351629, 97, 1, 31, "Section",
  CellTags->{"i:57", "c:38"}],
Cell[15872477, 351632, 456, 12, 61, "Text"],

Cell[CellGroupData[{
Cell[15872958, 351648, 453, 10, 143, "Input",
  CellTags->"Cell 7.87"],
Cell[15873414, 351660, 68, 1, 46, "Output"]
}, Open  ]],
Cell[15873497, 351664, 200, 5, 86, "Input",
  CellTags->"Cell 7.88"],

Cell[CellGroupData[{
Cell[15873722, 351673, 338, 7, 105, "Input",
  CellTags->"Cell 7.89"],
Cell[15874063, 351682, 37397, 779, 233, 6161, 389, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15911475, 352464, 856, 27, 61, "Text",
  CellTags->"i:83"],
Cell[15912334, 352493, 1241, 36, 111, "NE3",
  CellTags->"(7.3.13)"],
Cell[15913578, 352531, 615, 17, 61, "Text"],
Cell[15914196, 352550, 190, 6, 32, "NE3",
  CellTags->{"i:81", "(7.3.14)"}],
Cell[15914389, 352558, 442, 12, 48, "Text"],
Cell[15914834, 352572, 769, 18, 90, "Text"],
Cell[15915606, 352592, 160, 5, 38, "NE3",
  CellTags->"(7.3.15)"],
Cell[15915769, 352599, 476, 12, 70, "Text"],
Cell[15916248, 352613, 189, 6, 43, "NE3",
  CellTags->"(7.3.16)"],
Cell[15916440, 352621, 789, 18, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15917266, 352644, 47, 1, 31, "Section",
  CellTags->"c:39"],
Cell[15917316, 352647, 2764, 79, 106, "Text"],
Cell[15920083, 352728, 378, 10, 44, "Text"],
Cell[15920464, 352740, 154, 6, 38, "NE3",
  CellTags->"(7.3.17)"],
Cell[15920621, 352748, 275, 10, 27, "Text"],

Cell[CellGroupData[{
Cell[15920921, 352762, 1030, 21, 371, "Input",
  CellTags->"Cell 7.90"],
Cell[15921954, 352785, 56, 1, 46, "Output"]
}, Open  ]],
Cell[15922025, 352789, 200, 5, 86, "Input",
  CellTags->"Cell 7.91"],

Cell[CellGroupData[{
Cell[15922250, 352798, 298, 6, 86, "Input",
  CellTags->"Cell 7.92"],
Cell[15922551, 352806, 56081, 984, 233, 5733, 358, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15978647, 353793, 253, 5, 44, "Text"],
Cell[15978903, 353800, 757, 13, 112, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15979709, 353819, 65, 1, 30, "Subsubtitle",
  CellTags->"c:40"],
Cell[15979777, 353822, 418, 13, 44, "Text"],
Cell[15980198, 353837, 1288, 37, 95, "Text"],
Cell[15981489, 353876, 1231, 36, 65, "Text",
  CellTags->"i:82"],
Cell[15982723, 353914, 1682, 46, 68, "NE3",
  CellTags->"(7.3.18)"],
Cell[15984408, 353962, 566, 22, 30, "Text"],
Cell[15984977, 353986, 241, 8, 27, "Text"],
Cell[15985221, 353996, 252, 6, 45, "UNNEQ"],
Cell[15985476, 354004, 666, 20, 73, "Text"],
Cell[15986145, 354026, 146, 5, 32, "UNNEQ"],
Cell[15986294, 354033, 575, 19, 65, "Text"],
Cell[15986872, 354054, 255, 10, 27, "Text"],
Cell[15987130, 354066, 1107, 33, 153, "Text"],
Cell[15988240, 354101, 174, 5, 27, "Text"],
Cell[15988417, 354108, 120, 2, 33, "NE3",
  CellTags->"(7.3.19)"],
Cell[15988540, 354112, 1092, 28, 112, "Text"],
Cell[15989635, 354142, 736, 22, 27, "Text"],
Cell[15990374, 354166, 1759, 58, 79, "Text"],
Cell[15992136, 354226, 1046, 33, 87, "Text"],
Cell[15993185, 354261, 623, 13, 95, "Text",
  CellTags->"i:65"],
Cell[15993811, 354276, 94, 3, 27, "Text"],
Cell[15993908, 354281, 649, 20, 41, "NE3",
  CellTags->"(7.3.20)"],
Cell[15994560, 354303, 110, 3, 27, "Text"],
Cell[15994673, 354308, 675, 23, 29, "NE3",
  CellTags->"(7.3.21)"],
Cell[15995351, 354333, 536, 18, 44, "Text",
  CellTags->"i:64"],
Cell[15995890, 354353, 606, 21, 30, "NE3",
  CellTags->"(7.3.22)"],
Cell[15996499, 354376, 966, 31, 62, "Text"],
Cell[15997468, 354409, 380, 12, 38, "NE3",
  CellTags->"(7.3.23)"],
Cell[15997851, 354423, 1480, 49, 62, "Text",
  CellTags->"i:66"],
Cell[15999334, 354474, 402, 10, 69, "NE3",
  CellTags->"(7.3.24)"],
Cell[15999739, 354486, 2160, 60, 133, "Text",
  CellTags->"i:69"],
Cell[16001902, 354548, 300, 10, 27, "Text"],
Cell[16002205, 354560, 1643, 47, 32, "NE3",
  CellTags->"(7.3.25)"],
Cell[16003851, 354609, 1482, 43, 112, "Text",
  CellTags->"i:84"],
Cell[16005336, 354654, 734, 26, 187, "Text",
  CellTags->"Table 7.1"],
Cell[16006073, 354682, 1418, 40, 129, "Text",
  CellTags->"i:68"],
Cell[16007494, 354724, 451, 13, 61, "Text",
  CellTags->"i:67"],
Cell[16007948, 354739, 7403, 150, 854, "Input",
  CellTags->"Cell 7.93"],
Cell[16015354, 354891, 1297, 42, 91, "Text"],
Cell[16016654, 354935, 482, 15, 44, "Text"],
Cell[16017139, 354952, 578, 18, 48, "Text"],
Cell[16017720, 354972, 1431, 39, 102, "Text"],
Cell[16019154, 355013, 878, 24, 65, "Text"],
Cell[16020035, 355039, 1200, 38, 78, "Text",
  CellTags->"i:72"],
Cell[16021238, 355079, 1049, 25, 112, "Text"],
Cell[16022290, 355106, 1459, 47, 95, "Text",
  CellTags->"i:70"],
Cell[16023752, 355155, 425, 13, 44, "Text"],
Cell[16024180, 355170, 1145, 30, 129, "Text",
  CellTags->"i:71"],
Cell[16025328, 355202, 788, 17, 219, "Input",
  CellTags->"Cell 7.94"],
Cell[16026119, 355221, 453, 9, 61, "Text"],
Cell[16026575, 355232, 366, 9, 44, "Text"],
Cell[16026944, 355243, 1090, 34, 79, "Text"],
Cell[16028037, 355279, 108, 5, 27, "Text"],
Cell[16028148, 355286, 139, 3, 27, "Text"],
Cell[16028290, 355291, 218, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[16028533, 355301, 162, 4, 86, "Input",
  CellTags->"Cell 7.95"],

Cell[CellGroupData[{
Cell[16028720, 355309, 158128, 6768, 370, 116028, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16186851, 362079, 160782, 6802, 370, 115964, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16347636, 368883, 169883, 6913, 370, 116062, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16517522, 375798, 184466, 7095, 370, 115903, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16701991, 382895, 193085, 7200, 370, 116045, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16895079, 390097, 193870, 7210, 370, 115984, 6244, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[17088964, 397310, 58, 1, 48, "Output"]
}, Open  ]],
Cell[17089037, 397314, 435, 10, 55, "Text"],
Cell[17089475, 397326, 488, 13, 46, "Text"],
Cell[17089966, 397341, 302, 9, 44, "Text"],
Cell[17090271, 397352, 283, 8, 44, "Text"],
Cell[17090557, 397362, 123, 3, 27, "Text"],
Cell[17090683, 397367, 233, 6, 44, "Text"],
Cell[17090919, 397375, 1106, 35, 78, "Text"],
Cell[17092028, 397412, 1028, 30, 82, "Text",
  CellTags->"i:92"],
Cell[17093059, 397444, 762, 22, 81, "Text"],
Cell[17093824, 397468, 508, 14, 61, "Text"],
Cell[17094335, 397484, 418, 8, 181, "Input",
  CellTags->"Cell 7.96"],
Cell[17094756, 397494, 216, 7, 27, "Text"],
Cell[17094975, 397503, 121, 3, 67, "Input",
  CellTags->"Cell 7.97"],
Cell[17095099, 397508, 386, 10, 69, "Text"],
Cell[17095488, 397520, 202, 5, 67, "Input",
  CellTags->"Cell 7.98"],
Cell[17095693, 397527, 1579, 47, 73, "Text"],
Cell[17097275, 397576, 403, 14, 44, "Text",
  CellTags->"i:90"],
Cell[17097681, 397592, 151, 5, 33, "NE3"],
Cell[17097835, 397599, 537, 17, 54, "Text"],
Cell[17098375, 397618, 530, 16, 65, "Text"],
Cell[17098908, 397636, 244, 5, 105, "Input",
  CellTags->"Cell 7.99"],
Cell[17099155, 397643, 283, 6, 105, "Input",
  CellTags->"Cell 7.100"],
Cell[17099441, 397651, 117, 3, 67, "Input",
  CellTags->"Cell 7.101"],
Cell[17099561, 397656, 518, 16, 44, "Text"],
Cell[17100082, 397674, 1145, 31, 95, "Text",
  CellTags->"i:91"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17101276, 397711, 60, 1, 40, "Subtitle",
  CellTags->{"refs", "c:41"}],
Cell[17101339, 397714, 255, 9, 44, "Text"],
Cell[17101597, 397725, 173, 5, 27, "Text"],
Cell[17101773, 397732, 180, 5, 27, "Text"],
Cell[17101956, 397739, 240, 8, 27, "Text"],
Cell[17102199, 397749, 178, 5, 27, "Text"],
Cell[17102380, 397756, 253, 8, 44, "Text"],
Cell[17102636, 397766, 194, 8, 27, "Text"],
Cell[17102833, 397776, 202, 8, 27, "Text"],
Cell[17103038, 397786, 186, 5, 27, "Text"],
Cell[17103227, 397793, 257, 6, 44, "Text"],
Cell[17103487, 397801, 158, 5, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

